/********************************************************************
# (C) Copyright IBM Corp.  2005-2006
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
#********************************************************************/
/**
 * Copyright 2000 Systemcorp - All rights reserved. Made in Canada.
 *
 * Description:
 *
 * Author: Tudor Toma
 * Revision: 42
 * Date: 7/31/00 6:18p
 *
 **/
/*
#Stored Procedure  :SP_SEARCH_2
#Short Description :Search and Assign a resource or profile to a element.
#Description       :Search or Search and Assign a resource or profile with effort to a WBS or CRI element.
				   :If search/assign a participant (without effort) all effort related parameters are not required.
				   :Search criteria is a sum of input parameters, witch tells how to filter out the result set.
				   :This function gets called from RPM client, Import and Level/Calculate.
RULE1: cannot assign more then once a resource to a element.
RULE2: cannot assign a resource to a project if the resource is already assigned to a task whitin the project.
RULE3: cannot assign to a task from project reserve more effort then remaining effort at the project.
RULE4: if bitflag = 9 then assignment without effort, otherwise assignment with effort.
RULE5: if bitflag between 1 and 8 the assignment is contoured: contour > 0 and work > 0
RULE6: if search by name then partially ignore the search criteria: org_id, geo_id, pool_id, work_loc, and_roles, and_skills, shw_roles, shw_skills
RULE7: if effort = 0 and bitflag < 9 then both start  finish dates are required
RULE8: if assign units <> 100%, then bitflag < 9 and effort > 0 and both start  finish dates are required
RULE9: cannot assign a resource if is not active, effective date is in the future or discontinue date is in the past
#Table Name        :
#Parameters        :
 $$bitflag  = 0 - ASP ---------------------------------------------------------------------------------------------
            = 1 - Daily         -- contour3
            = 2 - Weekly        -- contour3{, contur1}, {amount falg}
            = 3 - Monthly(C)    -- contour3{, contur2}
            = 4 - Monthly(B)    -- contour3{, contur2}
            = 5 - Monthly(A)    -- contour3{, contur2 | contour2  countour1}
            = 6 - Yearly(C)     -- contour2, contur4
            = 7 - Yearly(B)     -- contour2, contur4, contur1(only one day)
            = 8 - Yearly(A)     -- contour2, contur4, contur1(many days)
            = 9 - Participant
 $$contour (contour structure) ------------------------------------------------------------------------------------
  contur1:  DAY:    bits 0-6    0 = Su, 1 = Mo, 2 = Tu, 3 = We, 4 = Th, 5 = Fr, 6 = Sa,
  contur2:  WEEK:   bits 7-11   A) 7 = week1, 8 = week2, 8 = week3, 9 = week4
                                B) 1-First/2-Second/3-Third/4-Fourth/5-Last
                                C) The Day 1 to 31
  contour3:     EVRY:   bits 12-16  EVRY 1 to 31 day / week / month
  contour4:     MONTH:  bits 17-28  17 = Jan, 18 = Feb, ... 28 = Dec
  2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1
  8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0
                                                S F T W T M S
                                      w1 to w4  A(7 days from the 1st)
                                      5 4 3 2 1 B(Last, Fourth, Third, Second, First)
                                      31 .... 1 C(The Day 6)
                            31 ........ 1 (Day)
                            31 ........ 1 (week)
                            12 ........ 1 (month)
  D N O S A J J M A M F J (Month)
  Exemple:
  2 2 2 2 2 2 2 2 2 2 1 1 1 1 1 1 1 1 1 1 
  9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 9 8 7 6 5 4 3 2 1 0 
                                      5-4-3-2-1               B) 1-First/2-Second/3-Third/4-Fourth/5-Last
  X D N O S A J J M A M F J --EVERY-- -THE-DAY- S F T W T M S C) The Day 1 to 31
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 = 4096      1 (every day) 	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 = 8192      1 (every 2nd day) 
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 0 0 0 0 0 = 12288     1 (every 3rd day) 
  1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 = 536875014 2 (Monday, Tuesday, every week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 = 4102      2 (Monday, Tuesday, every week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 1 1 0 = 8198      2 (Monday, Monday, every 2nd week)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 = 4864      3 (6th day of every month)
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 1 0 0 0 0 0 1 0 = 8322      4 (1st Monday of every 2nd month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 0 = 4224      5 (week1 of every month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 = 4480      5 (week1, week2 of every month)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 1 0 0 0 0 0 0 0 = 8576      5 (week1, week2 of every 2nd month)
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0 1 1 0 = 8454      5 (Monday, Tuesday, week2 every 2nd month)	
  1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 1 0 0 0 0 0 1 1 0 = 536879366 5 (Monday, Tuesday, week2 every 2nd month)	
  0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 1 0 0 0 0 0 0 0 0 = 301990656 6 (6th day of month 9, 12)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 0 1 0 = 301990146 7 (1st Monday of month 1, 2)	
  0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 1 0 0 0 0 0 1 0 0 = 4356      7 (2nd Tuesday, every month)	
  0 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 1 1 0 = 301990534 8 (Monday, Tuesday; week1, week3 of month 9, 12)	
  1 1 0 0 1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0 1 0 0 0 0 1 1 0 = 838861446 8 (Monday, Tuesday; week1, week3 of month 9, 12)	
 $$consider_planned_sched ------------------------------------------------------------------------------------------
  CONSIDER                                              inner current project   outer current project   all projects
  scheduled                                                         1                   2                   3
  scheduled  planned                                               4                   5                   6
  NONE(consider all available time)                                 7
  scheduled outer current project				                                        13                  14
  scheduled  planned outer current project				                                15                  16
  scheduled outer current project  planned all projects            20
  scheduled outer current project  planned inner current project   21
  scheduled all projects    planned outer current project          22
  planned inner current project                                     24
  search from project assignments		= 10  pool_id   = resource_id
  search create new profile				= 12  and_roles = the first role_id is used to create a new profile
  duplicate profile						= 12  pool_id   = profile_id
  assign pool  org as participant to a template folder, all template views
  assign pool	= SC_SRCH_POOL (31)  pool_id	= pool_id
  assign org	= SC_SRCH_ORG  (32)  org_id	= org_id
  Note: bits 30 - 31 (in addition to above values): Consider All Scop Element Exceptions = 1 consider, 0 don't consider
  $$eunit, applies to effort
		= 0 MINUTE (default), 
		= 1 h, 
		= 2 d, 
		= 3 w
  $$unit, applies to work
		= 0 h/d,
		= 3 h/w, 
		= 4 h/m, 
		= 1 d/w, 
		= 2 d/m, 
		= 5 w/m
		= 100 then work = percent units
#Returns           :Result Set of resource(s), Best Start date, Best Finish date and daly contour (5*480,2*0,3*400,...) 
				   :For search the number of rows depends on search criteria and is limited by max_rows parameter.
				   :For search/assign is always only one row, the resource whith has been assigned
#Errors            :The errors are returned only in search/assign
				   : TASK_ASSIGNMENT_ERROR (200062) - many reasons the assignment failed.
				   : CHILD_TASK_ASSIGNMENT_ALREADY_EXISTS (20083) - violation of RULE2
				   : CANNOT_ASSIGN_FROM_PROJECT_AFFECTED (20085) - violation of RULE3
				   : RESOURCE_NOT_ACTIVE (200019) - violation of RULE9
				   : F_DATE_EARLIER_THAN_S_DATE - finish date is earlier then start date
				   : 200220 - violation of RULE7
*/
Prompt == FUNCTION SP_SEARCH_2 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
2fa
2 :e:
1FUNCTION:
1SP_SEARCH_2:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1FNAME:
1COST001:
1ORG_ID001:
1GEO_ID001:
1POOL_ID001:
1WORK_LOCATION001:
1AND_ROLES:
1AND_SKILLS:
1SHW_ROLES:
1SHW_SKILLS:
1MAX_ROWS:
1P_UPDATE:
1WORK_TYPE:
1P_TYPE:
1LAST_ID:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_WBS_ID:
132:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RS_ID:
1H_UNIQUEID:
1H_REC_USER:
1H_FNAME:
1255:
1H_COST:
110:
1H_AND_ROLES:
18000:
1H_AND_SKILLS:
1H_SHW_ROLES:
1H_SHW_SKILLS:
1H_AND_ROLE:
1H_AND_SKILL:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_SOURCE_IDS:
1H_TARGET_IDS:
1H_RES_ID:
1H_LAST_ID:
1H_RANK:
1200:
1H_DAYOFYEAR:
1DATE:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_START_D:
1H_RES_TYPE:
11:
1H_ASSIGN_ID:
1H_ROLE_ID:
1H_SKILL_ID:
1H_FULL_NAME:
1H_REC_STATUS:
1H_BITFLAG:
10:
1H_EXISTS:
1H_TYPE:
1H_COUNT:
1H_UPDATE:
1H_WORK_TYPE:
1H_WORK_LOCATION:
1H_CRI:
1H_MAX_ROWS:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_DURATION:
1H_BIT_MINUTES:
1H_NUMBER:
1H_PRIORITY:
1H_DAYS:
1H_RES_COST:
1NUMBER:
10.00:
1H_RATE_ECHANGE:
1H_TOTAL:
1H_POOL_TYPE:
1H_CURRENCY_ID:
1H_JULIAN_DAY:
1H_J_EFECTIVE_DATE:
1H_J_DISCONTI_DATE:
1H_WEEK:
1H_ACTIVE:
1H_TASK_TYPE:
1H_SCHED_WORK:
1H_PARTICIPANT:
1STMT:
1STWHERE:
13000:
1H_TEMP_STMT:
1H_TABLE_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_PROFILE_ID:
1H_RESOURCE_ID:
1H_CRI_SECURITY_ID:
1H_CHAR:
1H_TEMP_VAR:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1I:
1II:
1I_ROW:
1I_RETURN:
1ISF:
1TOKEN:
1I_NOSKILL:
1NUMITEMS:
1BCREATEPROFILE:
1LEN:
1K:
1NLEN:
1NLEN001:
1NLEN002:
1C12:
1CURSOR:
1C42:
1PROJECT_ASSIGNMENT_ID:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1TASK_ID:
1RESOURCE_ID:
1SELECT PROJECT_ASSIGNMENT_ID:n         FROM TASK_ASSIGNMENTS:n         WHERE +
1PROJECT_ID = h_project_id:n         AND TASK_ID = h_project_id:n         AND +
1RESOURCE_ID = h_res_id:
1CU42:
1RS_ID:
1RES_ID:
1RTRIM:
1ROLE_ID:
1COALESCE:
1ROLE_NAME:
1SKILL_ID:
1SKILL_NAME:
1SHOW_ROLE:
1SHOW_SKILL:
1PMO_TMP_SEARCH:
1SELECT:n         RS_ID:n         , RES_ID:n         , RTRIM(ROLE_ID):n       +
1  , COALESCE(ROLE_NAME , ''):n         , RTRIM(SKILL_ID):n         , COALESCE+
1(SKILL_NAME , ''):n         , COALESCE(SHOW_ROLE , ''):n         , COALESCE(S+
1HOW_SKILL , ''):n         FROM PMO_TMP_SEARCH:n         ORDER BY RES_ID:
1C775C0:
1C775E1:
1C775E0:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_2(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1197:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_2(198) :: cplan.sql(355) :: :
1PMO_CNST:
1!=:
1SC_SRCH_PARTICIPANT:
1IS NULL:
18:
1240:
1      RETURN_INVALID:: SP_SEARCH_2(241) :: cplan.sql(398) :: :
1 :
1STATE:: :
1ELEMENT_ID_REQUIRED:
1243:
1                EXIT:: SP_SEARCH_2(244) :: cplan.sql(401) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_SRCH_FROM_PROJECT:
1=:
1SC_SRCH_PROFILE:
1252:
1      RETURN_INVALID:: SP_SEARCH_2(253) :: cplan.sql(410) :: :
1INVALID_PARAMS:
1                EXIT:: SP_SEARCH_2(256) :: cplan.sql(413) :: :
1ELSIF:
1260:
1      RETURN_INVALID:: SP_SEARCH_2(261) :: cplan.sql(418) :: :
1263:
1                EXIT:: SP_SEARCH_2(264) :: cplan.sql(421) :: :
15:
1271:
1      RETURN_INVALID:: SP_SEARCH_2(272) :: cplan.sql(429) :: :
1274:
1                EXIT:: SP_SEARCH_2(275) :: cplan.sql(432) :: :
1265:
1IS NOT NULL:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1300:
1           EXCEPTION:: SP_SEARCH_2(301) :: cplan.sql(458) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1<:
1307:
1      RETURN_INVALID:: SP_SEARCH_2(308) :: cplan.sql(465) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1310:
1                EXIT:: SP_SEARCH_2(311) :: cplan.sql(468) :: :
1SELECT SYSTIMESTAMP INTO h_start_date FROM DUAL:
1328:
1           EXCEPTION:: SP_SEARCH_2(329) :: cplan.sql(486) :: :
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1SC_SRCH_POOL:
12:
1SC_SRCH_ORG:
13:
1>:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1372:
1           EXCEPTION:: SP_SEARCH_2(373) :: cplan.sql(530) :: :
1REC_STATUS:
1TMT_WBS:
1ELEMENT_ID:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1390:
1           EXCEPTION:: SP_SEARCH_2(391) :: cplan.sql(548) :: :
1STRCMP:
1L:
1397:
1        RETURN_ERROR:: SP_SEARCH_2(398) :: cplan.sql(555) :: :
1LEV_LOCKED_BY_COPY:
1 ID:: :
1400:
1                EXIT:: SP_SEARCH_2(401) :: cplan.sql(558) :: :
1PMO_RETURN_ERROR_SP:
1GETTABLE:
1GETASSNTYPE:
1411:
1      RETURN_INVALID:: SP_SEARCH_2(412) :: cplan.sql(569) :: :
1414:
1                EXIT:: SP_SEARCH_2(415) :: cplan.sql(572) :: :
1SC_TABLE_WBS:
1427:
1      RETURN_INVALID:: SP_SEARCH_2(428) :: cplan.sql(585) :: :
1430:
1                EXIT:: SP_SEARCH_2(431) :: cplan.sql(588) :: :
1ASSIGNRESOURCE:
1RECORD_ALREADY_ASSIGNED:
1449:
1        RETURN_ERROR:: SP_SEARCH_2(450) :: cplan.sql(607) :: :
1452:
1                EXIT:: SP_SEARCH_2(453) :: cplan.sql(610) :: :
1459:
1        RETURN_ERROR:: SP_SEARCH_2(460) :: cplan.sql(617) :: :
1462:
1                EXIT:: SP_SEARCH_2(463) :: cplan.sql(620) :: :
1ISPROJECTTYPE:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1SELECT:n               PROJECT_ID:n               , COALESCE(MINUTE_PER_DAY, +
1480):n               , COALESCE(MINUTE_PER_WEEK, 2400):n               , PRIO+
1RITY:n               INTO:n               h_project_id:n               , h_pe+
1r_day:n               , h_per_week:n               , h_priority:n            +
1   FROM TMT_WBS:n               WHERE ELEMENT_ID = h_task_id:
1489:
1           EXCEPTION:: SP_SEARCH_2(490) :: cplan.sql(647) :: :
1B:
1TASK_TYPE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1A:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1SELECT:n               B.TASK_TYPE:n               , B.UNRESOLVED_START:n    +
1           , B.UNRESOLVED_FINISH:n               , B.PROJECT_ID:n            +
1   , COALESCE(A.MINUTE_PER_DAY, 480):n               , COALESCE(A.MINUTE_PER_+
1WEEK, 2400):n               , A.PRIORITY:n               , B.PLANNED_EFFORT ++
1 B.SCHED_EFFORT:n               INTO:n               h_task_type:n           +
1    , h_task_start_DT:n               , h_task_finish_DT:n               , h_+
1project_id:n               , h_per_day:n               , h_per_week:n        +
1       , h_priority:n               , h_sched_work:n               FROM TMT_W+
1BS A, TMT_WBS B:n               WHERE B.ELEMENT_ID = h_task_id:n             +
1  AND A.ELEMENT_ID = B.PROJECT_ID:
1524:
1           EXCEPTION:: SP_SEARCH_2(525) :: cplan.sql(682) :: :
1532:
1        RETURN_ERROR:: SP_SEARCH_2(533) :: cplan.sql(690) :: :
1RECORD_NOT_FOUND:
1535:
1                EXIT:: SP_SEARCH_2(536) :: cplan.sql(693) :: :
1SC_TABLE_CRI:
1TYPE_ID:
1WBS_ID:
1TMT_CRI:
1SELECT:n            PROJECT_ID:n            , TYPE_ID:n            , WBS_ID:n+
1            INTO:n            h_project_id:n            , h_type:n           +
1 , h_wbs_id:n            FROM TMT_CRI:n            WHERE ELEMENT_ID = h_task_+
1id:
1559:
1           EXCEPTION:: SP_SEARCH_2(560) :: cplan.sql(717) :: :
1566:
1        RETURN_ERROR:: SP_SEARCH_2(567) :: cplan.sql(724) :: :
1569:
1                EXIT:: SP_SEARCH_2(570) :: cplan.sql(727) :: :
1START_DT:
1TO_TIMESTAMP:
1SELECT:n            CASE:n            WHEN START_DT > h_start_DT:n           +
1 THEN START_DT:n            ELSE TO_TIMESTAMP(h_start_DT):n            END:n +
1           , COALESCE(MINUTE_PER_DAY, 480):n            , COALESCE(MINUTE_PER+
1_WEEK, 2400):n            , PRIORITY:n            INTO:n            h_start_D+
1T:n            , h_per_day:n            , h_per_week:n            , h_priorit+
1y:n            FROM TMT_WBS:n            WHERE PROJECT_ID = h_project_id:n   +
1         AND ELEMENT_ID = h_project_id:
1602:
1           EXCEPTION:: SP_SEARCH_2(603) :: cplan.sql(760) :: :
1609:
1        RETURN_ERROR:: SP_SEARCH_2(610) :: cplan.sql(767) :: :
1612:
1                EXIT:: SP_SEARCH_2(613) :: cplan.sql(770) :: :
1FC_MIRROR_TYPE:
1627:
1        RETURN_ERROR:: SP_SEARCH_2(628) :: cplan.sql(785) :: :
1630:
1                EXIT:: SP_SEARCH_2(631) :: cplan.sql(788) :: :
1NICK_NAME:
1JULIAN_DAY:
1ACTIVE:
1EFFECTIVE_DATE:
1DISCONTINUE_DATE:
1RESOURCES:
1SELECT:n            NICK_NAME:n            , PMO_ORASTD.JULIAN_DAY(h_start_DT+
1):n            , ACTIVE:n            , EFFECTIVE_DATE:n            , COALESCE+
1(PMO_ORASTD.JULIAN_DAY(EFFECTIVE_DATE) ,0):n            , COALESCE(PMO_ORASTD+
1.JULIAN_DAY(DISCONTINUE_DATE) ,0):n            INTO:n            h_full_name+
1:n            , h_julian_day:n            , h_active:n            , h_start_D+
1:n            , h_j_efective_date:n            , h_j_disconti_date:n         +
1   FROM RESOURCES:n            WHERE RESOURCE_ID = h_res_id:
1663:
1           EXCEPTION:: SP_SEARCH_2(664) :: cplan.sql(821) :: :
1SC_SQL_NO_DATA:
1670:
1        RETURN_ERROR:: SP_SEARCH_2(671) :: cplan.sql(828) :: :
1673:
1                EXIT:: SP_SEARCH_2(674) :: cplan.sql(831) :: :
1680:
1        RETURN_ERROR:: SP_SEARCH_2(681) :: cplan.sql(838) :: :
1RESOURCE_NOT_ACTIVE:
1683:
1                EXIT:: SP_SEARCH_2(684) :: cplan.sql(841) :: :
1DB2TIMESTAMP:
1TO_DATE:
1TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_D, 1, 10)), PMO_ORASTD.+
1TIME('00.00.00')) INTO h_start_DT:n                  FROM DUAL:
1701:
1           EXCEPTION:: SP_SEARCH_2(702) :: cplan.sql(859) :: :
1721:
1        RETURN_ERROR:: SP_SEARCH_2(722) :: cplan.sql(879) :: :
1CANNOT_ASSIGN_COMPETENCY:
1724:
1                EXIT:: SP_SEARCH_2(725) :: cplan.sql(882) :: :
1SELECT:n            PRIORITY:n            , COALESCE(MINUTE_PER_DAY, 480):n  +
1          , COALESCE(MINUTE_PER_WEEK, 2400):n            INTO:n            h_+
1priority:n            , h_per_day:n            , h_per_week:n            FROM+
1 TMT_WBS:n            WHERE ELEMENT_ID = h_project_id:
1751:
1           EXCEPTION:: SP_SEARCH_2(752) :: cplan.sql(909) :: :
1TMT_POOLS:
1SELECT:n               480:n               , 2400:n               INTO:n     +
1          h_per_day:n               , h_per_week:n               FROM TMT_POO+
1LS WHERE ELEMENT_ID = h_project_id:
1775:
1           EXCEPTION:: SP_SEARCH_2(776) :: cplan.sql(933) :: :
1782:
1        RETURN_ERROR:: SP_SEARCH_2(783) :: cplan.sql(940) :: :
1785:
1                EXIT:: SP_SEARCH_2(786) :: cplan.sql(943) :: :
1100:
11899-12-31 00::00::00:
1:
1FC_CALC_DURATION:
1823:
1      RETURN_INVALID:: SP_SEARCH_2(824) :: cplan.sql(981) :: :
1826:
1                EXIT:: SP_SEARCH_2(827) :: cplan.sql(984) :: :
1831:
1        RETURN_ERROR:: SP_SEARCH_2(832) :: cplan.sql(989) :: :
1834:
1                EXIT:: SP_SEARCH_2(835) :: cplan.sql(992) :: :
1*:
14:
1SYS_GUID:
1PROFILES:
1PROFILE_ID:
1SELECT REC_STATUS INTO h_rec_status:n            FROM PROFILES:n            W+
1HERE PROFILE_ID = h_res_id:
1895:
1           EXCEPTION:: SP_SEARCH_2(896) :: cplan.sql(1053) :: :
1RES_ASSIGNMENT_ID:
1RESOURCE_ASSIGNMENTS:
1RESOURCE_TYPE:
1PARTICIPANT:
1SC_TEAMMEMBER:
1SELECT:n                  RES_ASSIGNMENT_ID:n                  INTO:n        +
1          h_uniqueID:n                  FROM RESOURCE_ASSIGNMENTS:n          +
1        WHERE ELEMENT_ID = h_task_id:n                  AND RESOURCE_ID = h_r+
1es_id:n                  AND RESOURCE_TYPE = '1':n                  AND PARTI+
1CIPANT = pmo_cnst.SC_TEAMMEMBER:
1920:
1           EXCEPTION:: SP_SEARCH_2(921) :: cplan.sql(1078) :: :
1MAX:
1PROF_NUMBER:
1SELECT:n            COALESCE(MAX(PROF_NUMBER),0)+1:n            INTO:n       +
1     h_number:n            FROM PROFILES:n            WHERE PROJECT_ID=h_proj+
1ect_id:n            AND ROLE_ID=h_role_id:
1947:
1           EXCEPTION:: SP_SEARCH_2(948) :: cplan.sql(1105) :: :
1STRINGCONCAT:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1PARENT_ID:
1SELECT:n            PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORAST+
1D.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEM+
1ENT_NAME):n            , ', '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(+
1h_number))), ')'):n            INTO h_full_name:n            FROM TMT_COMPETE+
1NCIES TC, TMT_COMPETENCIES TCP:n            WHERE TC.ELEMENT_ID = h_role_id:n+
1            AND TCP.ELEMENT_ID = TC.PARENT_ID:
1968:
1           EXCEPTION:: SP_SEARCH_2(969) :: cplan.sql(1126) :: :
1975:
1        RETURN_ERROR:: SP_SEARCH_2(976) :: cplan.sql(1133) :: :
1978:
1                EXIT:: SP_SEARCH_2(979) :: cplan.sql(1136) :: :
1U:
1D:
1PROFILE_NAME:
1POOL_ID:
1GEO_ID:
1ORG_ID:
1INSERT INTO PROFILES:n            (:n            PROFILE_ID:n            , PR+
1OJECT_ID:n            , ROLE_ID:n            , PROF_NUMBER:n            , PRO+
1FILE_NAME:n            , REC_STATUS:n            , POOL_ID:n            , GEO+
1_ID:n            , ORG_ID:n            ):n            VALUES:n            (:n+
1            h_res_id:n            , h_project_id:n            , h_role_id:n  +
1          , h_number:n            , h_full_name:n            , h_char:n      +
1      , pool_id001:n            , geo_id001:n            , org_id001:n       +
1     ):
1FOUND:
11026:
1           EXCEPTION:: SP_SEARCH_2(1027) :: cplan.sql(1184) :: :
1UPDATE PROFILES SET REC_STATUS = 'U' :n            WHERE PROFILE_ID = h_res_i+
1d:
11048:
1           EXCEPTION:: SP_SEARCH_2(1049) :: cplan.sql(1206) :: :
1RESOURCE_ASSIGN_SKILLS:
1DELETE FROM RESOURCE_ASSIGN_SKILLS:n         WHERE RES_ASSIGNMENT_ID IN (:n  +
1       SELECT PROFILE_ID:n         FROM PROFILES:n         WHERE PROJECT_ID =+
1 h_project_id:n         AND REC_STATUS='D':n         AND PROFILE_ID <> h_res_+
1id):
11076:
1           EXCEPTION:: SP_SEARCH_2(1077) :: cplan.sql(1234) :: :
1RESOURCE_ASSIGN_ROLES:
1DELETE FROM RESOURCE_ASSIGN_ROLES:n         WHERE RES_ASSIGNMENT_ID IN (:n   +
1      SELECT PROFILE_ID:n         FROM PROFILES:n         WHERE PROJECT_ID = +
1h_project_id:n         AND REC_STATUS='D':n         AND PROFILE_ID <> h_res_i+
1d):
11101:
1           EXCEPTION:: SP_SEARCH_2(1102) :: cplan.sql(1259) :: :
1DELETE FROM PROFILES:n         WHERE PROJECT_ID = h_project_id:n         AND +
1REC_STATUS='D':n         AND PROFILE_ID <> h_res_id:
11123:
1           EXCEPTION:: SP_SEARCH_2(1124) :: cplan.sql(1281) :: :
1FC_DECLARE_PMO_TMP_SEARCH:
1SC_MAX_ROWS:
1SELECT ':
1' AS RESOURCE_ID :
1FROM TMT_COMPETENCIES r :
1WHERE r.TYPE_ID=73 :
1      AND r.ELEMENT_ID = ':
1SELECT ra.RESOURCE_ID :
1FROM RESOURCE_ASSIGNMENTS ra :
1JOIN TASK_ASSIGNMENTS ta ON ra.ELEMENT_ID=':
1' :
1AND ra.RESOURCE_ID=':
1AND ra.RES_ASSIGNMENT_ID=ta.RES_ASSIGNMENT_ID :
1SELECT r.RESOURCE_ID :
1FROM RESOURCES r :
1WHERE r.CALENDAR_ID IS NOT NuLL :
1        AND r.RESOURCE_ID = ':
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN_0007:
1DELETE FROM PMO_TMP_CPLN_007a:
1PMO_TMP_CPLN_007A:
1RANK:
1PUBLIC_FLAG:
1P:
1JOIN:
1RA:
1ELEMENT_TYPE:
1INSERT INTO PMO_TMP_CPLN_007a:n               SELECT ELEMENT_ID, RANK:n      +
1         FROM TMT_POOLS:n               WHERE PUBLIC_FLAG = '1':n            +
1   UNION ALL:n               ---- All pools to which the resource is assigned+
1:n               SELECT P.ELEMENT_ID, P.RANK:n               FROM TMT_POOLS P+
1:n               JOIN RESOURCE_ASSIGNMENTS RA ON:n               P.ELEMENT_ID+
1 = RA.ELEMENT_ID:n               AND RA.ELEMENT_TYPE = 11:n               AND+
1 RA.RESOURCE_ID = h_rec_user:
11250:
1           EXCEPTION:: SP_SEARCH_2(1251) :: cplan.sql(1408) :: :
1PMO_TMP_CPLN_0007:
1M:
1LENGTH:
1INSERT INTO PMO_TMP_CPLN_0007:n               SELECT M.RANK:n               F+
1ROM PMO_TMP_CPLN_007a M:n               WHERE NOT EXISTS (:n               SE+
1LECT A.ELEMENT_ID:n               FROM PMO_TMP_CPLN_007a A:n               WH+
1ERE A.RANK < M.RANK:n               AND SUBSTR(M.RANK, 1, LENGTH(A.RANK)) = A+
1.RANK):
11278:
1           EXCEPTION:: SP_SEARCH_2(1279) :: cplan.sql(1436) :: :
132767:
165535:
1-:
165536:
1WHILE:
1LOOP:
1ASCII:
137:
195:
1EXIT:
11305:
1      RETURN_INVALID:: SP_SEARCH_2(1306) :: cplan.sql(1463) :: :
11308:
1                EXIT:: SP_SEARCH_2(1309) :: cplan.sql(1466) :: :
1REPLACE:
1SELECT REPLACE(h_fname,'''',''''''):n            INTO h_fname:n            FR+
1OM DUAL:
11325:
1           EXCEPTION:: SP_SEARCH_2(1326) :: cplan.sql(1483) :: :
1SELECT p.PROFILE_ID AS RESOURCE_ID FROM PROFILES p JOIN TMT_COMPETENCIES r ON+
1 p.ROLE_ID = r.ELEMENT_ID:
1 WHERE p.PROFILE_ID=':
1SELECT r.RESOURCE_ID FROM RESOURCES r JOIN RESOURCE_ASSIGNMENTS ra ON BITAND(+
1ra.PARTICIPANT,4096)>0 AND ra.ELEMENT_ID=':
1' AND ra.RESOURCE_ID=r.RESOURCE_ID:
1 WHERE 0=0 :
1SELECT DISTINCT r.RESOURCE_ID FROM RESOURCES r:
1 AND r.CALENDAR_ID IS NOT NuLL :
1AND UPPER(r.FULL_NAME) like UPPER(':
1%'):
1SELECT r.RESOURCE_ID FROM RESOURCES r:
1SELECT DISTINCT r.RESOURCE_ID :
1FROM TMT_POOLS TP, PMO_TMP_CPLN_0007 MP, RESOURCES r:
1AND TP.ELEMENT_ID=R.RESOURCE_ID :
1  AND (MP.RANK >= SUBSTR(TP.RANK, 1, 8) :
1        AND MP.RANK <= TP.RANK :
1        AND length(MP.RANK) <= length(TP.RANK) :
1        AND substr(TP.RANK, 1, length(MP.RANK)) = MP.RANK) :
1  AND r.CALENDAR_ID IS NOT NuLL :
1  AND UPPER(r.FULL_NAME) LIKE UPPER(':
1 AND r.RESOURCE_ID > ':
1SELECT RANK INTO h_rank:n               FROM TMT_POOLS:n               WHERE +
1ELEMENT_ID = pool_id001:
11407:
1           EXCEPTION:: SP_SEARCH_2(1408) :: cplan.sql(1565) :: :
1,TMT_POOLS p:
1 AND r.RESOURCE_ID = p.ELEMENT_ID :
1AND p.RANK LIKE ':
1%' :
11422:
1        RETURN_ERROR:: SP_SEARCH_2(1423) :: cplan.sql(1580) :: :
11425:
1                EXIT:: SP_SEARCH_2(1426) :: cplan.sql(1583) :: :
1TMT_ORGANIZATIONS:
1SELECT RANK INTO h_rank:n               FROM TMT_ORGANIZATIONS:n             +
1  WHERE ELEMENT_ID = org_id001:
11444:
1           EXCEPTION:: SP_SEARCH_2(1445) :: cplan.sql(1602) :: :
1,TMT_ORGANIZATIONS o:
1 AND r.RESOURCE_ID=o.ELEMENT_ID :
1AND o.RANK LIKE ':
11455:
1        RETURN_ERROR:: SP_SEARCH_2(1456) :: cplan.sql(1613) :: :
11458:
1                EXIT:: SP_SEARCH_2(1459) :: cplan.sql(1616) :: :
1TMT_GEOGRAPHIES:
1SELECT RANK INTO h_rank:n               FROM TMT_GEOGRAPHIES:n               +
1WHERE ELEMENT_ID = geo_id001:
11477:
1           EXCEPTION:: SP_SEARCH_2(1478) :: cplan.sql(1635) :: :
1,TMT_GEOGRAPHIES g:
1 AND r.RESOURCE_ID=g.ELEMENT_ID :
1AND g.RANK LIKE ':
11488:
1        RETURN_ERROR:: SP_SEARCH_2(1489) :: cplan.sql(1646) :: :
11491:
1                EXIT:: SP_SEARCH_2(1492) :: cplan.sql(1649) :: :
1 AND r.WORK_LOCATION=:
1PMO_STPU:
1STRNPCPY:
1SELECT RANK INTO h_rank:n               FROM TMT_COMPETENCIES:n              +
1 WHERE ELEMENT_ID = h_role_id:
11523:
1           EXCEPTION:: SP_SEARCH_2(1524) :: cplan.sql(1681) :: :
11530:
1        RETURN_ERROR:: SP_SEARCH_2(1531) :: cplan.sql(1688) :: :
11533:
1                EXIT:: SP_SEARCH_2(1534) :: cplan.sql(1691) :: :
1 AND EXISTS :
1(SELECT t1.ELEMENT_ID :
1  FROM TMT_COMPETENCIES t1:
1  WHERE t1.RANK LIKE ':
1%':
1 AND r.ELEMENT_ID=t1.ELEMENT_ID) :
1 AND r.RESOURCE_ID=t1.RESOURCE_ID) :
11578:
1           EXCEPTION:: SP_SEARCH_2(1579) :: cplan.sql(1736) :: :
11585:
1        RETURN_ERROR:: SP_SEARCH_2(1586) :: cplan.sql(1743) :: :
11588:
1                EXIT:: SP_SEARCH_2(1589) :: cplan.sql(1746) :: :
1     AND r.RESOURCE_ID=t1.RESOURCE_ID) :
1 ORDER BY RESOURCE_ID  :
1OPEN:
1CLOSE:
11652:
1           EXCEPTION:: SP_SEARCH_2(1653) :: cplan.sql(1810) :: :
1CONTINUE0000:
11672:
1           EXCEPTION:: SP_SEARCH_2(1673) :: cplan.sql(1830) :: :
1COUNT:
1TSK_ASSIGNMENT_ID:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_temp_var :n                  FROM TASK+
1_ASSIGNMENTS:n                  WHERE PROJECT_ID = h_project_id:n            +
1      AND RESOURCE_ID = h_res_id:n                  AND RESOURCE_TYPE = '0':
11703:
1           EXCEPTION:: SP_SEARCH_2(1704) :: cplan.sql(1861) :: :
11719:
1           EXCEPTION:: SP_SEARCH_2(1720) :: cplan.sql(1877) :: :
11725:
1        RETURN_ERROR:: SP_SEARCH_2(1726) :: cplan.sql(1883) :: :
1CHILD_TASK_ASSIGNMENT_ALREADY_:
11728:
1                EXIT:: SP_SEARCH_2(1729) :: cplan.sql(1886) :: :
1FC_SEARCH_2:
11754:
1           EXCEPTION:: SP_SEARCH_2(1755) :: cplan.sql(1912) :: :
1DB_OFFSET:
1TASK_ASSIGNMENT_ERROR:
11764:
1        RETURN_ERROR:: SP_SEARCH_2(1765) :: cplan.sql(1922) :: :
11767:
1                EXIT:: SP_SEARCH_2(1768) :: cplan.sql(1925) :: :
1UPDATE PROFILES SET REC_STATUS='U' WHERE PROFILE_ID = h_res_id AND REC_STATUS+
1='D':
11785:
1           EXCEPTION:: SP_SEARCH_2(1786) :: cplan.sql(1943) :: :
11829:
1           EXCEPTION:: SP_SEARCH_2(1830) :: cplan.sql(1987) :: :
1ASSIGN_STRING_TOLONG:
11838:
1        RETURN_ERROR:: SP_SEARCH_2(1839) :: cplan.sql(1996) :: :
11841:
1                EXIT:: SP_SEARCH_2(1842) :: cplan.sql(1999) :: :
1NOTNULL:
1UPDATE PMO_TMP_SEARCH SET:n                  ROLE_ID = h_source_ids:n        +
1          , ROLE_NAME = h_and_roles:n                  , SKILL_ID = h_target_+
1ids:n                  , SKILL_NAME = h_and_skills:n                  , SHOW_+
1ROLE = h_shw_roles:n                  , SHOW_SKILL = h_shw_skills:n          +
1        WHERE RS_ID = h_last_id:
11909:
1           EXCEPTION:: SP_SEARCH_2(1910) :: cplan.sql(2067) :: :
1UPDATE PMO_TMP_SEARCH SET:n               ROLE_ID = NuLL:n               , RO+
1LE_NAME = NuLL:n               , SKILL_ID = NuLL:n               , SKILL_NAME+
1 = NuLL:n               , SHOW_ROLE = NuLL:n               , SHOW_SKILL = NuL+
1L:n               WHERE RS_ID = h_last_id:
11952:
1           EXCEPTION:: SP_SEARCH_2(1953) :: cplan.sql(2110) :: :
1,:
12013:
1           EXCEPTION:: SP_SEARCH_2(2014) :: cplan.sql(2171) :: :
1UPDATE PMO_TMP_SEARCH SET:n            ROLE_ID = h_source_ids:n            , +
1ROLE_NAME = h_and_roles:n            , SKILL_ID = h_target_ids:n            ,+
1 SKILL_NAME = h_and_skills:n            , SHOW_ROLE = h_shw_roles:n          +
1  , SHOW_SKILL = h_shw_skills:n            WHERE RS_ID = h_last_id:
12041:
1           EXCEPTION:: SP_SEARCH_2(2042) :: cplan.sql(2199) :: :
1SUM:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1DAY_YEAR:
1SELECT COALESCE(SUM(AVAILABLE_MIN),0) INTO h_effort:n            FROM CALENDA+
1R_DAY_OF_YEAR:n            WHERE ELEMENT_ID=h_project_id:n            AND DAY+
1_YEAR BETWEEN TO_DATE(SubStr(h_start_DT, 1, 10)) AND TO_DATE(SubStr(h_finish_+
1DT, 1, 10)):
12063:
1           EXCEPTION:: SP_SEARCH_2(2064) :: cplan.sql(2221) :: :
1CURRENCY_ID:
1TODECIMAL:
1TD:
1TW:
1TMT_DATAFIELDS:
1SELECT CURRENCY_ID, PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4) INTO h_currenc+
1y_id, h_rate_echange:n      FROM TMT_WBS tw JOIN TMT_DATAFIELDS td on tw.CURR+
1ENCY_ID = td.ELEMENT_ID:n      WHERE tw.ELEMENT_ID = h_project_id:
12085:
1           EXCEPTION:: SP_SEARCH_2(2086) :: cplan.sql(2243) :: :
1DELETE FROM PMO_TMP_CPLN_0005:
1PMO_TMP_CPLN_0005:
1REGULAR_COST:
1REGULAR_SALE:
1SPECIAL_COST:
1SPECIAL_SALE:
1INSERT INTO PMO_TMP_CPLN_0005:n         SELECT RES_ID:n         , REGULAR_COS+
1T:n         , REGULAR_SALE:n         , SPECIAL_COST:n         , SPECIAL_SALE+
1:n         FROM PMO_TMP_SEARCH:n         WHERE RS_ID = h_rs_id:n         AND +
1(REGULAR_COST + REGULAR_SALE) > 0:
12123:
1           EXCEPTION:: SP_SEARCH_2(2124) :: cplan.sql(2281) :: :
1INSERT INTO PMO_TMP_CPLN_0005:n            SELECT RES_ID:n            , MAX(R+
1EGULAR_COST) AS REGULAR_COST:n            , MAX(REGULAR_SALE) AS REGULAR_SALE+
1:n            , MAX(SPECIAL_COST) AS SPECIAL_COST:n            , MAX(SPECIAL_+
1SALE) AS SPECIAL_SALE:n            FROM PMO_TMP_SEARCH:n            WHERE RS_+
1ID <> h_rs_id:n            GROUP BY RES_ID:
12152:
1           EXCEPTION:: SP_SEARCH_2(2153) :: cplan.sql(2310) :: :
1INSERT INTO PMO_TMP_CPLN_0005:n               SELECT RES_ID, 0.00, 0.00, 0.00+
1, 0.00:n               FROM PMO_TMP_SEARCH:n               WHERE RS_ID = h_rs+
1_id:n               GROUP BY RES_ID:
12176:
1           EXCEPTION:: SP_SEARCH_2(2177) :: cplan.sql(2334) :: :
1RS:
1WORK_LOCATION:
1O1:
1ORGANIZATION:
1G1:
1GEOGRAPHY:
1ROUND:
1PA:
1RES_SALE_RATE:
1TEMP:
1REGULAR_RATE:
1SPECIAL_RATE:
1START_DATE:
1FINISH_DATE:
1ASSIGNABLE:
1PLANNED:
1SCHED:
1PROPOSED:
1WORK_EFFORT:
1UNIT_EFFORT:
1AVAILABLE:
1VERIFIED:
1STATUS2_ID:
1FULL_NAME:
1PP:
1POOL_NAME:
1E_MAIL_ADDRESS:
1UNIQUE_ID:
1CONTOUR:
1ASSIGN_STRING:
1ASSIGNED_FLAG:
1FS_LABOR_CODE:
1RES_MODIFIED_DATE:
1EXTERNAL_ID:
1LOGON_NAME:
1RESOURCE_E_MAIL:
1WORK_PHONE:
1LEFT:
1OUTER:
1PROJECT_ASSIGNMENTS:
1R:
1RATES:
1RATE_ID:
1SELECT h_res_id AS ELEMENT_ID, 41 AS TYPE_ID, p.PROFILE_NAME AS ELEMENT_NAME,+
1 rs.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, h_work_location AS+
1 WORK_LOCATION,:n      o1.ELEMENT_NAME AS ORGANIZATION,g1.ELEMENT_NAME AS GEO+
1GRAPHY,:n      ROUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.REGULAR_COST WHEN rs+
1.RES_SALE_RATE=0 THEN temp.REGULAR_COST * h_rate_echange ELSE a.REGULAR_COST +
1* h_rate_echange END,2) AS REGULAR_COST,:n      ROUND(CASE WHEN pa.REGULAR_RA+
1TE>0 THEN pa.REGULAR_RATE WHEN rs.RES_SALE_RATE=0 THEN temp.REGULAR_SALE * h_+
1rate_echange ELSE a.REGULAR_SALE * h_rate_echange END,2) AS REGULAR_SALE,:n  +
1    ROUND(CASE WHEN pa.SPECIAL_COST>0 THEN pa.SPECIAL_COST WHEN rs.RES_SALE_R+
1ATE=0 THEN temp.SPECIAL_COST * h_rate_echange ELSE a.SPECIAL_COST * h_rate_ec+
1hange END,2) AS SPECIAL_COST,:n      ROUND(CASE WHEN pa.SPECIAL_RATE>0 THEN p+
1a.SPECIAL_RATE WHEN rs.RES_SALE_RATE=0 THEN temp.SPECIAL_SALE * h_rate_echang+
1e ELSE a.SPECIAL_SALE * h_rate_echange END,2) AS SPECIAL_SALE,:n      rs.STAR+
1T_DATE,rs.FINISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PROPOSE+
1D > 0 THEN rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT_EFFO+
1RT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n      '' AS VERIFIE+
1D, 0 AS STATUS2_ID, '' AS FULL_NAME, pp.ELEMENT_NAME AS POOL_NAME, '' AS E_MA+
1IL_ADDRESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIG+
1N_STRING, h_and_roles AS ROLE_ID, h_and_skills AS SKILL_ID, 0 AS ASSIGNED_FLA+
1G,:n      'PMOFFICE' AS FS_LABOR_CODE, TO_TIMESTAMP('1899-12-31 00::00::00') +
1AS RES_MODIFIED_DATE, '' AS EXTERNAL_ID,:n      '' AS LOGON_NAME, '' AS NICK_+
1NAME, '' AS RESOURCE_E_MAIL, '' AS WORK_PHONE:n      FROM PMO_TMP_CPLN_0005 t+
1emp :n      JOIN PMO_TMP_SEARCH rs ON rs.RES_ID = temp.RES_ID:n      LEFT OUT+
1ER JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID=h_project_id :n      AND pa.R+
1ESOURCE_ID=rs.RES_ID:n      JOIN PROFILES p ON p.PROFILE_ID = h_res_id:n     +
1 JOIN TMT_COMPETENCIES r ON p.ROLE_ID=r.ELEMENT_ID:n      LEFT OUTER JOIN RAT+
1ES a ON r.RATE_ID=a.RATE_ID:n      LEFT OUTER JOIN TMT_ORGANIZATIONS o1 ON p.+
1ORG_ID = o1.ELEMENT_ID:n      LEFT OUTER JOIN TMT_GEOGRAPHIES g1 ON p.GEO_ID +
1= g1.ELEMENT_ID:n      LEFT OUTER JOIN TMT_POOLS pp ON pp.ELEMENT_ID = p.POOL+
1_ID:n      WHERE NOT (rs.ROLE_NAME IS NuLL AND rs.SKILL_NAME IS NuLL AND rs.S+
1HOW_ROLE IS NuLL AND rs.SHOW_SKILL IS NuLL):
12206:
1                EXIT:: SP_SEARCH_2(2207) :: cplan.sql(2364) :: :
1O2:
1G2:
1DEFAULT_FLAG:
1RV:
1RM:
1PLANNED_WORK:
1SCHED_WORK:
1REC_DATETIME:
1MANAGER_ID:
1VERIFIED_1:
1SELECT rs.RES_ID AS ELEMENT_ID, 13 AS TYPE_ID, :n         r.FULL_NAME AS ELEM+
1ENT_NAME, :n         rs.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL+
1, :n         r.WORK_LOCATION,:n         o2.ELEMENT_NAME AS ORGANIZATION,g2.EL+
1EMENT_NAME AS GEOGRAPHY,:n         ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THEN r+
1s.REGULAR_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID +
1* h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20+
1,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORAST+
1D.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRE+
1NCY_ID) END WHEN rs.DEFAULT_FLAG='1' THEN rs.REGULAR_COST ELSE rs.REGULAR_COS+
1T * h_rate_echange END,2) AS REGULAR_COST,:n         ROUND(CASE WHEN rs.DEFAU+
1LT_FLAG='0' THEN rs.REGULAR_SALE * CASE WHEN (r.CURRENCY_ID = h_currency_id) +
1OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIM+
1AL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) /+
1 (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE EL+
1EMENT_ID = r.CURRENCY_ID) END WHEN rs.DEFAULT_FLAG='1' THEN rs.REGULAR_SALE E+
1LSE rs.REGULAR_SALE * h_rate_echange END,2) AS REGULAR_SALE,:n         ROUND(+
1CASE WHEN rs.DEFAULT_FLAG='0' THEN rs.SPECIAL_COST * CASE WHEN (r.CURRENCY_ID+
1 = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT +
1PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID +
1= h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_D+
1ATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END WHEN rs.DEFAULT_FLAG='1' THEN+
1 rs.SPECIAL_COST ELSE rs.SPECIAL_COST * h_rate_echange END,2) AS SPECIAL_COST+
1,:n         ROUND(CASE WHEN rs.DEFAULT_FLAG='0' THEN rs.SPECIAL_SALE * CASE W+
1HEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) TH+
1EN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS+
1 WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAM+
1E,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END WHEN rs.DEF+
1AULT_FLAG='1' THEN rs.SPECIAL_SALE ELSE rs.SPECIAL_SALE * h_rate_echange END,+
12) AS SPECIAL_SALE,:n         rs.START_DATE, rs.FINISH_DATE,rs.ASSIGNABLE,rs.+
1PLANNED,rs.SCHED, CASE WHEN rs.PROPOSED > 0 THEN rs.PROPOSED ELSE h_effort EN+
1D AS WORK_EFFORT, h_eunit AS UNIT_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCH+
1ED) AS AVAILABLE,:n         rv.FULL_NAME AS VERIFIED, r.STATUS2_ID, pp.ELEMEN+
1T_NAME AS POOL_NAME, :n         RM.FULL_NAME, RM.E_MAIL_ADDRESS, :n         '+
1' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, rs.+
1ROLE_ID, rs.SKILL_ID, COALESCE(pa.PLANNED_WORK + pa.SCHED_WORK,0) AS ASSIGNED+
1_FLAG,:n         r.FS_LABOR_CODE, r.REC_DATETIME AS RES_MODIFIED_DATE, r.EXTE+
1RNAL_ID,:n         r.LOGON_NAME, r.NICK_NAME, r.E_MAIL_ADDRESS AS RESOURCE_E_+
1MAIL, r.WORK_PHONE:n         FROM PMO_TMP_SEARCH rs :n         JOIN TMT_POOLS+
1 p ON rs.RES_ID=p.ELEMENT_ID:n         JOIN TMT_POOLS pp ON pp.ELEMENT_ID=p.P+
1ARENT_ID:n         LEFT OUTER JOIN RESOURCES RM ON pp.MANAGER_ID=RM.RESOURCE_+
1ID:n         JOIN RESOURCES r ON rs.RES_ID=r.RESOURCE_ID :n         LEFT OUTE+
1R JOIN RESOURCES rv ON rv.RESOURCE_ID=r.VERIFIED_1:n         LEFT OUTER JOIN +
1PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID=h_project_id AND pa.RESOURCE_ID=rs.RE+
1S_ID:n         LEFT OUTER JOIN TMT_ORGANIZATIONS o1 ON r.RESOURCE_ID=o1.ELEME+
1NT_ID:n         LEFT OUTER JOIN TMT_ORGANIZATIONS o2 ON o1.PARENT_ID=o2.ELEME+
1NT_ID:n         LEFT OUTER JOIN TMT_GEOGRAPHIES g1 ON r.RESOURCE_ID=g1.ELEMEN+
1T_ID:n         LEFT OUTER JOIN TMT_GEOGRAPHIES g2 ON g1.PARENT_ID=g2.ELEMENT_+
1ID:n         ORDER BY ELEMENT_ID:
12241:
1                EXIT:: SP_SEARCH_2(2242) :: cplan.sql(2399) :: :
1DELETE FROM PMO_TMP_CPLN_0006:
1PMO_TMP_CPLN_0006:
1INSERT INTO PMO_TMP_CPLN_0006:n            SELECT RES_ID, REGULAR_COST, REGUL+
1AR_SALE, SPECIAL_COST, SPECIAL_SALE, 1:n            FROM PMO_TMP_SEARCH WHERE+
1 DEFAULT_FLAG = '1':
12266:
1           EXCEPTION:: SP_SEARCH_2(2267) :: cplan.sql(2424) :: :
1INSERT INTO PMO_TMP_CPLN_0006:n            SELECT  RES_ID,                   +
1          MAX(REGULAR_COST) AS REGULAR_COST,:n            MAX(REGULAR_SALE) A+
1S REGULAR_SALE,  MAX(SPECIAL_COST) AS SPECIAL_COST,:n            MAX(SPECIAL_+
1SALE) AS SPECIAL_SALE , 0:n            FROM PMO_TMP_SEARCH:n            WHERE+
1 RES_ID NOT IN (SELECT RES_ID FROM PMO_TMP_SEARCH WHERE DEFAULT_FLAG = '1' AN+
1D RES_ID IS NOT NuLL):n            GROUP BY RES_ID:
12291:
1           EXCEPTION:: SP_SEARCH_2(2292) :: cplan.sql(2449) :: :
1DEF:
1PRF:
1RR:
1SELECT rs.RES_ID AS ELEMENT_ID, 13 AS TYPE_ID, r.FULL_NAME AS ELEMENT_NAME,:n+
1         rs.ROLE_NAME, rs.SKILL_NAME, rs.SHOW_ROLE, rs.SHOW_SKILL, r.WORK_LOC+
1ATION,:n         o2.ELEMENT_NAME AS ORGANIZATION,g2.ELEMENT_NAME AS GEOGRAPHY+
1,:n         :n         ROUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.REGULAR_COST+
1:n         WHEN a.REGULAR_COST>0 THEN a.REGULAR_COST * CASE WHEN (r.CURRENCY_+
1ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELEC+
1T PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_I+
1D = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT+
1_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         WHEN def.REGULAR_+
1COST>0 THEN def.REGULAR_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (+
1r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(E+
1LEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SE+
1LECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMEN+
1T_ID = r.CURRENCY_ID) END:n         else prf.REGULAR_COST * h_rate_echange:n +
1        END,2) AS REGULAR_COST,:n         :n         ROUND(CASE WHEN pa.REGUL+
1AR_COST> 0 THEN pa.REGULAR_RATE:n         WHEN a.REGULAR_COST > 0 THEN a.REGU+
1LAR_SALE * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_cu+
1rrency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FR+
1OM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODE+
1CIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID+
1) END:n         WHEN def.REGULAR_COST>0 THEN def.REGULAR_SALE * CASE WHEN (r.+
1CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 EL+
1SE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE +
1ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4)+
1 FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         else prf+
1.REGULAR_SALE * h_rate_echange:n         END,2) AS REGULAR_SALE,:n         :n+
1         ROUND(CASE WHEN pa.REGULAR_COST>0 THEN pa.SPECIAL_COST:n         WHE+
1N a.REGULAR_COST>0 THEN a.SPECIAL_COST * CASE WHEN (r.CURRENCY_ID = h_currenc+
1y_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.T+
1ODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency+
1_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WH+
1ERE ELEMENT_ID = r.CURRENCY_ID) END:n         WHEN def.REGULAR_COST>0 THEN de+
1f.SPECIAL_COST * CASE WHEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID +
1* h_currency_id = 0) THEN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20+
1,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORAST+
1D.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRE+
1NCY_ID) END:n         else prf.SPECIAL_COST * h_rate_echange:n         END,2)+
1 AS SPECIAL_COST,:n         :n         ROUND(CASE WHEN pa.REGULAR_RATE>0 THEN+
1 pa.SPECIAL_RATE:n         WHEN a.REGULAR_SALE>0 THEN a.SPECIAL_SALE * CASE W+
1HEN (r.CURRENCY_ID = h_currency_id) OR (r.CURRENCY_ID * h_currency_id = 0) TH+
1EN 1 ELSE (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS+
1 WHERE ELEMENT_ID = h_currency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAM+
1E,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         W+
1HEN def.REGULAR_COST>0 THEN def.SPECIAL_SALE * CASE WHEN (r.CURRENCY_ID = h_c+
1urrency_id) OR (r.CURRENCY_ID * h_currency_id = 0) THEN 1 ELSE (SELECT PMO_OR+
1ASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIELDS WHERE ELEMENT_ID = h_cu+
1rrency_id) / (SELECT PMO_ORASTD.TODECIMAL(ELEMENT_NAME,20,4) FROM TMT_DATAFIE+
1LDS WHERE ELEMENT_ID = r.CURRENCY_ID) END:n         else prf.SPECIAL_SALE * h+
1_rate_echange:n         END,2) AS SPECIAL_SALE,:n         :n         rs.START+
1_DATE,rs.FINISH_DATE,rs.ASSIGNABLE,rs.PLANNED,rs.SCHED, CASE WHEN rs.PROPOSED+
1 > 0 THEN rs.PROPOSED ELSE h_effort END AS WORK_EFFORT, h_eunit AS UNIT_EFFOR+
1T,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS AVAILABLE,:n         rv.FULL_NAM+
1E AS VERIFIED, r.STATUS2_ID, pp.ELEMENT_NAME AS POOL_NAME, RM.FULL_NAME, RM.E+
1_MAIL_ADDRESS, '' AS UNIQUE_ID, h_per_day AS MINUTE_PER_DAY, rs.CONTOUR AS AS+
1SIGN_STRING,:n         rs.ROLE_ID, rs.SKILL_ID, COALESCE(pa.PLANNED_WORK + pa+
1.SCHED_WORK,0) AS ASSIGNED_FLAG,:n         r.FS_LABOR_CODE, r.REC_DATETIME AS+
1 RES_MODIFIED_DATE, r.EXTERNAL_ID,:n         :n         R.LOGON_NAME, R.NICK_+
1NAME, R.E_MAIL_ADDRESS AS RESOURCE_E_MAIL, R.WORK_PHONE  :n         FROM PMO_+
1TMP_SEARCH rs:n         LEFT JOIN PMO_TMP_CPLN_0006 def ON rs.RES_ID=def.RES_+
1ID AND def.DEFAULT_FLAG = 1:n         LEFT JOIN PMO_TMP_CPLN_0006 prf ON rs.R+
1ES_ID=prf.RES_ID AND prf.DEFAULT_FLAG = 0:n         JOIN TMT_POOLS p ON rs.RE+
1S_ID=p.ELEMENT_ID:n         JOIN TMT_POOLS pp ON pp.ELEMENT_ID=p.PARENT_ID:n +
1        LEFT OUTER JOIN RESOURCES RM ON pp.MANAGER_ID=RM.RESOURCE_ID:n       +
1  JOIN RESOURCES r ON rs.RES_ID=r.RESOURCE_ID LEFT OUTER JOIN RESOURCES rv ON+
1 rv.RESOURCE_ID=r.VERIFIED_1:n         LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa+
1 ON pa.PROJECT_ID=h_project_id AND pa.RESOURCE_ID=rs.RES_ID:n         LEFT OU+
1TER JOIN RESOURCES rr ON r.VERIFIED_1=rr.RESOURCE_ID:n         LEFT OUTER JOI+
1N TMT_ORGANIZATIONS o1 ON r.RESOURCE_ID=o1.ELEMENT_ID LEFT OUTER JOIN TMT_ORG+
1ANIZATIONS o2 ON o1.PARENT_ID=o2.ELEMENT_ID:n         LEFT OUTER JOIN TMT_GEO+
1GRAPHIES g1 ON r.RESOURCE_ID=g1.ELEMENT_ID LEFT OUTER JOIN TMT_GEOGRAPHIES g2+
1 ON g1.PARENT_ID=g2.ELEMENT_ID:n         LEFT OUTER JOIN RATES a ON r.RATE_ID+
1=a.RATE_ID:n         WHERE NOT (rs.ROLE_NAME IS NuLL AND rs.SKILL_NAME IS NuL+
1L AND rs.SHOW_ROLE IS NuLL AND rs.SHOW_SKILL IS NuLL):n         ORDER BY ELEM+
1ENT_ID:
12345:
1                EXIT:: SP_SEARCH_2(2346) :: cplan.sql(2503) :: :
1RETURN_ERROR_EXCEPTION:
12358:
1           EXCEPTION:: SP_SEARCH_2(2359) :: cplan.sql(2516) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
12370:
1           EXCEPTION:: SP_SEARCH_2(2371) :: cplan.sql(2528) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
3732
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a0 f4
b4 bf c8 :8 a0 12a bd b7 11
a4 b1 a0 f4 b4 bf c8 :10 a0
12a bd b7 11 a4 b1 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d a0 51 d a0 51 d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a0 7e b4 2e :2 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a a 10
a0 7e b4 2e :2 5a a 10 a0
7e b4 2e :2 5a a 10 :2 a0 51
a5 b a0 7e a0 6b b4 2e
5a a 10 a0 7e b4 2e :2 5a
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 a0 b7 a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 :2 19 3c b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e a
10 :2 a0 51 a5 b 7e 51 b4
2e a 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c a0 7e b4
2e :2 5a a0 51 d b7 :2 a0 d
b7 :2 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e 5a a0 7e
b4 2e :2 5a a 10 a0 7e b4
2e :2 5a a 10 :8 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c a0 51 d b7
19 3c a0 7e b4 2e :2 5a a0
7e b4 2e :2 5a a 10 :3 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c :2 a0 d :3 a0 6b :3 a0
51 a5 b :2 a0 6b a5 b 5a
51 a5 b d :4 a0 51 a5 b
:2 a0 6b a5 b d :3 a0 6b :3 a0
51 a5 b :2 a0 6b a5 b 5a
51 a5 b d :4 a0 51 a5 b
:2 a0 6b a5 b d :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
6e d a0 b7 :2 a0 51 a5 b
a0 7e a0 6b b4 2e a0 6e
d b7 19 :2 a0 51 a5 b a0
7e a0 6b b4 2e a0 6e d
b7 a0 6e d b7 :2 19 3c b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e a0 51 d :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 6e a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 19 3c
:4 a0 51 a5 b a5 b d :2 a0
51 a5 b 7e 51 b4 2e :4 a0
51 a5 b a5 b d :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:3 a0 6b d b7 19 3c :2 a0 d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 d b7 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 :2 19 3c :8 a0 a5 b
d :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 51 a5 b 7e
51 b4 2e :3 a0 6b d b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 51 a5 b :2 a0 a5
57 b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
51 a5 b :2 a0 a5 57 b7 19
3c :2 a0 51 a5 b a0 7e a0
6b b4 2e :3 a0 51 a5 b a5
b 7e 51 b4 2e :d a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:27 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
a0 b7 :2 a0 51 a5 b a0 7e
a0 6b b4 2e :9 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :13 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c a0 7e
b4 2e 5a :3 a0 6b d :3 a0 a5
b d b7 19 3c b7 19 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 19
3c :2 a0 51 a5 b a0 7e a0
6b b4 2e :17 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 a0 b7 :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 :2 51 a5 b 7e 6e b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e a 10 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :9 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c b7 :2 19 3c b7
19 3c b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
7e b4 2e 5a a 10 :2 a0 51
a5 b 7e 51 b4 2e a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :2 a0 51 a5 b a0 7e
a0 6b b4 2e :b a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c b7 19 3c b7
19 3c b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e a 10 a0
51 d b7 19 3c :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
7e b4 2e 5a a0 6e d a0
6e d b7 :2 a0 d :2 a0 d b7
:2 19 3c a0 51 d b7 a0 7e
51 b4 2e a0 6e d :6 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :3 a0 a5
b d :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 a0 b7 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 b7 :2 19 3c
b7 :2 a0 d :2 a0 51 a5 b 7e
51 b4 2e :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e d b7
19 3c b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 a0 51 d
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e a0 51 d a0 b7 19
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 a0 51 d a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 :2 19 3c
b7 19 3c b7 :2 19 3c :2 a0 51
a5 b a0 7e a0 6b b4 2e
a0 51 d :2 a0 d :2 a0 d :3 a0
:2 51 a5 b d a0 4d d :2 a0
51 a5 b 7e 51 b4 2e :2 a0
b4 2e d a0 51 d b7 :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e :b a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
a0 51 d b7 :2 19 3c b7 :2 19
3c a0 7e 51 b4 2e :9 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:1f a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e a0 6e d
b7 a0 6e d b7 :2 19 3c :13 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
b7 :2 a0 :2 51 a5 b 7e 6e b4
2e :4 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :6 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c :2 a0
b4 2e d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b a0
7e a0 6b b4 2e a 10 :2 a0
51 a5 b a0 7e a0 6b b4
2e a 10 a0 7e b4 2e 5a
:2 a0 d b7 19 3c b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b d b7 19 3c a0 7e
b4 2e 5a a0 7e b4 2e 5a
a 10 a0 7e b4 2e 5a a
10 a0 7e b4 2e :2 5a a 10
a0 51 d b7 19 3c a0 6e
d a0 6e d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
a0 7e a0 6b b4 2e a0 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e d a0 b7 :2 a0
51 a5 b 7e 51 b4 2e a0
6e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e d b7 19 a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d b7 :2 19 3c b7 :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 51 a5 b a0 7e a0
6b b4 2e a 10 :2 a0 51 a5
b a0 7e a0 6b b4 2e a
10 :2 a0 6e 11e 11d :2 a0 6b 51
d a0 7e b4 2e 5a :2 a0 6e
11e 11d :2 a0 6b 51 d :17 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :15 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 a0
d b7 :2 19 3c b7 19 3c a0
7e b4 2e 5a :4 a0 a5 b 51
a5 b 7e 51 b4 2e :4 a0 a5
b 51 a5 b 51 a5 b 7e
51 b4 2e a6 122 :4 a0 a5 b
51 a5 b 51 a5 b 122 124
d a0 51 d :3 a0 7e a0 b4
2e 82 :5 a0 7e 51 b4 2e 51
a5 b a5 b 51 a5 b 7e
51 b4 2e :5 a0 7e 51 b4 2e
51 a5 b a5 b 51 a5 b
7e 51 b4 2e a 10 a0 2b
b7 19 3c :2 a0 7e 51 b4 2e
d b7 a0 47 :2 a0 7e b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c :4 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c :2 a0
51 a5 b a0 7e a0 6b b4
2e a0 6e d a0 6e d :2 a0
7e a0 b4 2e d :2 a0 7e 6e
b4 2e d a0 b7 :2 a0 51 a5
b a0 7e a0 6b b4 2e a0
6e d :2 a0 7e a0 b4 2e d
:2 a0 7e 6e b4 2e d a0 6e
d b7 19 :2 a0 51 a5 b a0
7e a0 6b b4 2e a0 6e d
a0 6e d :2 a0 7e 6e b4 2e
d a0 7e b4 2e 5a :2 a0 7e
6e b4 2e d :2 a0 7e a0 b4
2e d :2 a0 7e 6e b4 2e d
b7 19 3c b7 a0 7e b4 2e
5a :2 a0 7e 6e b4 2e d a0
6e d b7 :2 a0 7e 6e b4 2e
7e 6e b4 2e d a0 6e d
:2 a0 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e d b7 :2 19 3c a0 7e b4
2e 5a :2 a0 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e d
b7 19 3c b7 :2 19 3c a0 7e
b4 2e 5a :2 a0 7e 6e b4 2e
d :2 a0 7e a0 b4 2e d :2 a0
7e 6e b4 2e d b7 19 3c
b7 :2 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e a0 7e b4
2e 5a :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :4 a0 a5 b
51 a5 b d :2 a0 7e 6e b4
2e d :2 a0 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e d b7 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 19 3c b7
19 3c a0 7e b4 2e 5a :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 7e 6e b4 2e d
:2 a0 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e d b7 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 19 3c b7 19 3c
a0 7e b4 2e 5a :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 7e 6e b4 2e d :2 a0 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e d
b7 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e :2 a0 51
a5 b 7e 51 b4 2e a 10
:2 a0 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e d b7 19 3c b7 19
3c a0 7e b4 2e 5a :4 a0 a5
b 51 a5 b d a0 51 d
:3 a0 7e a0 b4 2e 82 :3 a0 6b
:2 51 a0 7e 51 b4 2e a0 a5
b d :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
d :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 7e 6e b4 2e
d b7 :2 a0 7e 6e b4 2e d
b7 :2 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e a0 2b b7
19 3c :2 a0 7e 51 b4 2e d
b7 a0 47 b7 19 3c :2 a0 51
a5 b a0 7e a0 6b b4 2e
:4 a0 a5 b 51 a5 b d a0
51 d :3 a0 7e a0 b4 2e 82
:3 a0 6b :2 51 a0 7e 51 b4 2e
a0 a5 b d :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :2 a0 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e d :2 a0
7e 51 b4 2e d b7 a0 47
b7 19 3c :2 a0 7e a0 b4 2e
d b7 :2 19 3c :2 a0 7e 6e b4
2e d :3 a0 11c 11d :3 a0 e9 d3
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
2b b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
a0 7e a0 6b b4 2e a 10
:2 a0 51 a5 b a0 7e a0 6b
b4 2e a 10 :2 a0 51 a5 b
a0 7e a0 6b b4 2e a0 7e
b4 2e 5a 52 10 5a a 10
:2 a0 e9 dd b3 :2 a0 e9 d3 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 3b b7 :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 19 3c :2 a0 d :2 a0
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 :2 51 a5 b 7e 6e b4
2e :2 a0 b4 2e d a0 51 d
b7 :3 a0 51 a5 b a5 b 7e
51 b4 2e :9 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c b7 19 3c b7 :2 19 3c
:20 a0 51 a5 b :5 51 a5 b d
a0 7e 51 b4 2e :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 7e a0 6b b4 2e :3 a0 6b
d b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :3 a0 a5 57
a0 b7 :2 a0 :2 51 a5 b 7e 6e
b4 2e 5a :2 a0 :2 51 a5 b 7e
6e b4 2e 5a a 10 :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c a0 2b b7 :2 a0 51 a5 b
a0 7e a0 6b b4 2e :2 a0 d
:2 a0 d b7 19 3c :1e a0 :6 51 a5
b d a0 7e 51 b4 2e :2 a0
7e 51 b4 2e d a0 b7 a0
7e 51 b4 2e a0 2b b7 :2 19
3c :2 a0 7e a0 51 a5 b b4
2e a0 2b b7 19 3c b7 :2 19
3c 93 4f b0 46 b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 7e a0 6b b4
2e 5a a0 7e 51 b4 2e 5a
52 10 a0 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e a
10 5a 52 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :3 a0 a5 57
b7 19 3c a0 7e 51 b4 2e
a0 6e d a0 6e d a0 6e
d :2 a0 e9 dd b3 a0 51 d
:a a0 e9 d3 5 :2 a0 f :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 2b b7 19 3c
a0 7e b4 2e 5a :2 a0 6b :2 a0
a5 b 7e 51 b4 2e a 10
:3 a0 a5 b 51 a5 b 7e 51
b4 2e a 10 :2 a0 d b7 19
3c :2 a0 6b :2 a0 a5 b 7e 51
b4 2e a0 7e 51 b4 2e :f a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c a0 6e d a0 6e d
a0 6e d a0 6e d a0 6e
d a0 6e d :2 a0 d a0 51
d b7 19 3c a0 7e 51 b4
2e a0 7e b4 2e 5a a 10
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c a0 7e b4 2e 5a
a0 7e b4 2e 5a :3 a0 7e 6e
b4 2e :2 51 a5 b d b7 19
3c :3 a0 7e a0 b4 2e :2 51 a5
b d b7 19 3c a0 7e b4
2e 5a :3 a0 7e a0 b4 2e :2 51
a5 b d b7 19 3c a0 7e
b4 2e 5a a0 7e b4 2e 5a
:3 a0 7e 6e b4 2e :2 51 a5 b
d b7 19 3c :3 a0 7e a0 b4
2e :2 51 a5 b d b7 19 3c
a0 7e b4 2e 5a :3 a0 7e a0
b4 2e :2 51 a5 b d b7 19
3c a0 7e b4 2e 5a a0 7e
b4 2e 5a :3 a0 7e 6e b4 2e
:2 51 a5 b d b7 19 3c :3 a0
7e a0 b4 2e :2 51 a5 b d
b7 19 3c a0 7e b4 2e 5a
a0 7e b4 2e 5a :3 a0 7e 6e
b4 2e :2 51 a5 b d b7 19
3c :3 a0 7e a0 b4 2e :2 51 a5
b d b7 19 3c :2 a0 7e 51
b4 2e d :2 a0 d b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e 51 b4 2e
:f a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 19 3c a0 7e
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e :e a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 a0 51
d 4f b7 :2 19 3c b7 19 3c
:13 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 6e 11e 11d
:2 a0 6b 51 d :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :12 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :6 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c b7 19 3c :d1 a0 12a e9 dd
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 65 b7 a0 7e
51 b4 2e :138 a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 b7 :2 a0 6e 11e
11d :2 a0 6b 51 d :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :15 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :1c2 a0 12a e9
dd :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 65 b7 :2 19
3c b7 :2 19 3c b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
3732
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 168
164 13a 170 179 175 163 181 18e
18a 160 196 19f 19b 189 1a7 1b4
1b0 186 1bc 1c5 1c1 1af 1cd 1da
1d6 1ac 1e2 1eb 1e7 1d5 1f3 200
1fc 1d2 208 211 20d 1fb 219 1f8
21e 222 226 22a 22d 231 24e 239
23d 240 241 249 238 26b 259 235
25d 25e 266 258 288 276 255 27a
27b 283 275 2a5 293 272 297 298
2a0 292 2c2 2b0 28f 2b4 2b5 2bd
2af 2df 2cd 2ac 2d1 2d2 2da 2cc
2fc 2ea 2c9 2ee 2ef 2f7 2e9 319
307 2e6 30b 30c 314 306 336 324
303 328 329 331 323 353 341 320
345 346 34e 340 370 35e 33d 362
363 36b 35d 38d 37b 35a 37f 380
388 37a 3aa 398 377 39c 39d 3a5
397 3c7 3b5 394 3b9 3ba 3c2 3b4
3e4 3d2 3b1 3d6 3d7 3df 3d1 401
3ef 3ce 3f3 3f4 3fc 3ee 41e 40c
3eb 410 411 419 40b 43b 429 408
42d 42e 436 428 458 446 425 44a
44b 453 445 475 463 442 467 468
470 462 492 480 45f 484 485 48d
47f 4ae 49d 4a1 4a9 47c 4ca 4b5
4b9 4bc 4bd 4c5 49c 4e7 4d5 499
4d9 4da 4e2 4d4 504 4f2 4d1 4f6
4f7 4ff 4f1 521 50f 4ee 513 514
51c 50e 53e 52c 50b 530 531 539
52b 55a 549 54d 555 528 576 561
565 568 569 571 548 593 581 545
585 586 58e 580 5b0 59e 57d 5a2
5a3 5ab 59d 5cd 5bb 59a 5bf 5c0
5c8 5ba 5ea 5d8 5b7 5dc 5dd 5e5
5d7 607 5f5 5d4 5f9 5fa 602 5f4
623 612 616 5f1 61e 611 63f 62e
632 60e 63a 62d 65b 64a 64e 62a
656 649 677 666 66a 646 672 665
693 682 686 662 68e 681 6af 69e
6a2 67e 6aa 69d 6cb 6ba 6be 69a
6c6 6b9 6e7 6d6 6da 6b6 6e2 6d5
703 6f2 6f6 6d2 6fe 6f1 71f 70e
712 6ee 71a 70d 73b 72a 72e 70a
736 729 757 746 74a 726 752 745
773 762 766 742 76e 761 78f 77e
782 75e 78a 77d 7ab 79a 79e 77a
7a6 799 7c7 7b6 7ba 796 7c2 7b5
7e3 7d2 7d6 7b2 7de 7d1 7ff 7ee
7f2 7ce 7fa 7ed 81b 80a 80e 7ea
816 809 837 826 82a 806 832 825
853 842 846 822 84e 841 86f 85e
862 83e 86a 85d 88b 87a 87e 85a
886 879 8a7 896 89a 876 8a2 895
8c3 8b2 8b6 892 8be 8b1 8df 8ce
8d2 8ae 8da 8cd 8fb 8ea 8ee 8ca
8f6 8e9 917 906 90a 8e6 912 905
933 922 926 902 92e 921 94f 93e
942 91e 94a 93d 96b 95a 95e 93a
966 959 987 976 97a 956 982 975
9a3 992 996 972 99e 991 9c0 9ae
98e 9b2 9b3 9bb 9ad 9dc 9cb 9cf
9aa 9d7 9ca 9f8 9e7 9eb 9c7 9f3
9e6 a14 a03 a07 9e3 a0f a02 a31
a1f 9ff a23 a24 a2c a1e a4e a3c
a1b a40 a41 a49 a3b a6b a59 a38
a5d a5e a66 a58 a87 a76 a7a a55
a82 a75 aa3 a92 a96 a72 a9e a91
ac0 aae a8e ab2 ab3 abb aad add
acb aaa acf ad0 ad8 aca afa ae8
ac7 aec aed af5 ae7 b17 b05 ae4
b09 b0a b12 b04 b34 b22 b01 b26
b27 b2f b21 b51 b3f b1e b43 b44
b4c b3e b6d b5c b60 b3b b68 b5b
b89 b78 b7c b58 b84 b77 ba5 b94
b98 b74 ba0 b93 bc1 bb0 bb4 b90
bbc baf bdd bcc bd0 bac bd8 bcb
bf9 be8 bec bc8 bf4 be7 c15 c04
c08 be4 c10 c03 c31 c20 c24 c00
c2c c1f c4e c3c c1c c40 c41 c49
c3b c6a c59 c5d c38 c65 c58 c86
c75 c79 c81 c55 c9e c8d c91 c99
c74 cba ca9 cad cb5 c71 cd2 cc1
cc5 ccd ca8 cee cdd ce1 ce9 ca5
d06 cf5 cf9 d01 cdc d22 d11 d15
d1d cd9 d41 d29 d2d d31 d34 d3c
d10 d48 d4c d0d d5d d60 d64 d68
d6c d70 d74 d78 d7c d80 d84 d90
d95 d97 da3 da7 da9 dad dbe dbf
dc2 dc6 dca dce dd2 dd6 dda dde
de2 de6 dea dee df2 df6 dfa dfe
e02 e06 e12 e17 e19 e25 e29 e47
e2f e33 e37 e3a e42 e2e e67 e52
e56 e2b e5a e62 e51 e87 e72 e76
e4e e7a e82 e71 ea7 e92 e96 e6e
e9a ea2 e91 eae eb2 e8e eb6 eba
ebe ec1 ec6 ec7 1 ec9 ece ed2
ed6 ed9 ede ee2 ee6 ee9 eee eef
ef1 ef6 ef9 efd efe f03 f08 f0b
f10 f11 f16 f19 f1d f1e f23 f26
f2b f2c f31 f34 f39 f3a f3f f42
f47 f48 f4d f50 f54 f55 f5a f5d
f62 f63 f68 f6b f70 f71 f76 f79
f7e f7f f84 f87 f8b f8c f91 f94
f99 f9a f9f fa2 fa7 fa8 fad fb0
fb4 fb8 fbc fbd fbf fc4 fc5 fc7
fc8 fcd fd0 fd5 fd6 fdb fde fe2
fe6 fea feb fed ff2 ff3 ff5 ff6
ffb ffe 1003 1004 1009 100c 1010 1014
1018 1019 101b 1020 1021 1023 1024 1029
102c 1031 1032 1037 103a 103e 1042 1046
1047 1049 104e 104f 1051 1052 1057 105a
105f 1060 1065 1068 106c 1070 1074 1075
1077 107c 107d 107f 1080 1085 1088 108d
108e 1093 1096 109a 109e 10a2 10a3 10a5
10aa 10ab 10ad 10ae 10b3 10b6 10bb 10bc
10c1 10c4 10c8 10cc 10d0 10d1 10d3 10d8
10d9 10db 10dc 10e1 10e4 10e9 10ea 10ef
10f2 10f6 10fa 10fe 10ff 1101 1106 1107
1109 110a 110f 1112 1117 1118 111d 1120
1125 1126 112b 112e 1132 1133 1138 113b
1140 1141 1146 1149 114e 114f 1154 1157
115c 115d 1162 1165 1169 116a 116f 1172
1177 1178 117d 1180 1185 1186 118b 118e
1193 1194 1199 119c 11a0 11a1 11a6 11a9
11ae 11af 11b4 11b7 11bc 11bd 11c2 11c5
11ca 11cb 11d0 11d3 11d7 11d8 11dd 11e0
11e5 11e6 11eb 11ee 11f3 11f4 11f9 11fc
1201 1202 1207 120a 120e 120f 1214 1217
121c 121d 1222 1225 122a 122b 1230 1233
1237 123b 123f 1240 1242 1247 1248 124a
124b 1250 1253 1258 1259 125e 1261 1266
1267 126c 126f 1273 1274 1279 127c 1281
1282 1287 128a 128f 1290 1295 1298 129d
129e 12a3 12a6 12aa 12ab 12b0 12b3 12b8
12b9 12be 12c1 12c6 12c7 12cc 12cf 12d4
12d5 12da 12dd 12e1 12e2 12e7 12ea 12ef
12f0 12f5 12f8 12fd 12fe 1303 1306 130b
130c 1311 1314 1318 1319 131e 1321 1326
1327 132c 132f 1334 1335 133a 133d 1341
1345 1349 134a 134c 1351 1352 1354 1355
135a 135d 1362 1363 1368 136b 136f 1373
1377 1378 137a 137f 1380 1382 1383 1388
138b 1390 1391 1396 1399 139d 13a1 13a5
13a6 13a8 13ad 13ae 13b0 13b1 13b6 13b9
13be 13bf 13c4 13c7 13cb 13cf 13d3 13d4
13d6 13db 13dc 13de 13df 13e4 13e7 13ec
13ed 13f2 13f5 13fa 13fb 1400 1403 1407
1408 140d 1410 1415 1416 141b 141e 1423
1424 1429 142c 1431 1432 1437 143a 143e
143f 1444 1447 144c 144d 1452 1455 145a
145b 1460 1461 1466 1468 146c 146f 1473
1477 147a 147e 1482 1485 1488 148d 1490
1493 1496 1497 149c 149d 1 149f 14a4
14a8 14ac 14af 14b4 14b9 14bc 14c0 14c1
14c6 14c7 14cc 14ce 14d2 14d5 14d9 14dd
14e1 14e5 14e9 14ed 14f1 14f5 14f9 14fd
1501 1505 1509 150d 1511 1515 1519 151d
1521 1525 1529 152d 1531 1535 1539 153d
1541 1545 1549 154d 1551 1555 1559 155d
1561 1565 1569 156d 1571 1575 1579 157d
1581 1585 1589 158d 1591 1595 1599 159d
15a1 15a5 15a9 15ad 15b1 15b5 15b9 15bd
15c1 15c5 15c9 15cd 15d1 15d5 15d9 15dd
15e1 15e4 15e8 15ec 15ef 15f3 15f7 15fb
15fe 15ff 1601 1605 1608 160c 160f 1610
1615 1618 161c 161f 1620 1625 1628 1
162b 1630 1634 1638 163b 163f 1643 1646
1649 164e 1651 1654 1657 1658 165d 165e
1 1660 1665 1669 166d 1670 1675 167a
167d 1681 1682 1687 168a 168f 1690 1695
1698 169d 169e 16a3 16a6 16aa 16ae 16b2
16b6 16b9 16ba 16bc 16c1 16c2 16c4 16c5
16ca 16cb 16d0 16d2 16d6 16d9 16dd 16e1
16e4 16e8 16ec 16ef 16f2 16f7 16fa 16fd
1700 1701 1706 1707 1 1709 170e 1712
1716 1719 171e 1723 1726 172a 172b 1730
1731 1736 1738 173c 173f 1743 1747 174a
174e 1752 1755 1759 175a 175f 1761 1765
1768 176c 176f 1770 1775 1778 177b 177f
1782 1783 1788 178b 1 178e 1793 1797
179a 179b 17a0 17a3 1 17a6 17ab 17af
17b2 17b3 17b8 17bb 1 17be 17c3 17c7
17cb 17ce 17cf 17d1 17d5 17d8 17dc 17df
17e0 17e5 1 17e8 17ed 17f1 17f4 17f5
17fa 17fd 1800 1804 1808 180b 180c 180e
1812 1815 1819 181c 181d 1822 1 1825
182a 182e 1832 1835 1839 183d 1840 1843
1848 184b 184e 1851 1852 1857 1858 1
185a 185f 1863 1867 186a 186f 1874 1877
187b 187c 1881 1884 1889 188a 188f 1892
1897 1898 189d 18a0 18a4 18a8 18ac 18b0
18b3 18b4 18b6 18bb 18bc 18be 18bf 18c4
18c5 18ca 18cc 18d0 18d3 18d7 18db 18de
18e2 18e6 18e9 18ec 18f1 18f4 18f7 18fa
18fb 1900 1901 1 1903 1908 190c 1910
1913 1918 191d 1920 1924 1925 192a 192b
1930 1932 1936 1939 193d 1941 1944 1948
194c 194f 1953 1954 1959 195d 195f 1963
1966 1967 196c 196f 1972 1976 1979 197a
197f 1982 1 1985 198a 198e 1992 1995
1999 199d 19a0 19a3 19a8 19ab 19ae 19b1
19b2 19b7 19b8 1 19ba 19bf 19c3 19c7
19ca 19cf 19d4 19d7 19db 19dc 19e1 19e4
19e9 19ea 19ef 19f2 19f7 19f8 19fd 1a00
1a04 1a08 1a0c 1a10 1a13 1a14 1a16 1a1b
1a1c 1a1e 1a1f 1a24 1a25 1a2a 1a2c 1a30
1a33 1a37 1a3b 1a3e 1a42 1a46 1a49 1a4c
1a51 1a54 1a57 1a5a 1a5b 1a60 1a61 1
1a63 1a68 1a6c 1a70 1a73 1a78 1a7d 1a80
1a84 1a85 1a8a 1a8b 1a90 1a92 1a96 1a99
1a9d 1aa1 1aa4 1aa8 1aac 1aaf 1ab3 1ab4
1ab9 1abb 1abf 1ac3 1ac6 1ac8 1acc 1acf
1ad3 1ad7 1ada 1adb 1add 1ae0 1ae3 1ae4
1ae9 1aed 1af1 1af4 1af5 1af7 1afa 1afd
1afe 1 1b03 1b08 1b0c 1b10 1b13 1b14
1b16 1b19 1b1c 1b1d 1 1b22 1b27 1b2b
1b2f 1b32 1b36 1b3a 1b3d 1b40 1b45 1b48
1b4b 1b4e 1b4f 1b54 1b55 1 1b57 1b5c
1b60 1b64 1b67 1b6c 1b71 1b74 1b78 1b79
1b7e 1b81 1b86 1b87 1b8c 1b8f 1b94 1b95
1b9a 1b9d 1ba1 1ba5 1ba9 1bad 1bb0 1bb1
1bb3 1bb8 1bb9 1bbb 1bbc 1bc1 1bc2 1bc7
1bc9 1bcd 1bd0 1bd4 1bd8 1bdb 1bdf 1be3
1be6 1be9 1bee 1bf1 1bf4 1bf7 1bf8 1bfd
1bfe 1 1c00 1c05 1c09 1c0d 1c10 1c15
1c1a 1c1d 1c21 1c22 1c27 1c28 1c2d 1c2f
1c33 1c36 1c3a 1c3e 1c41 1c45 1c49 1c4c
1c50 1c51 1c56 1c58 1c5c 1c5f 1c63 1c66
1c67 1c6c 1c6f 1c72 1c76 1c79 1c7d 1c7f
1c83 1c87 1c8b 1c8d 1c91 1c95 1c98 1c9c
1ca0 1ca3 1ca4 1ca6 1caa 1cad 1cb1 1cb4
1cb5 1cba 1cbd 1cc1 1cc4 1cc5 1cca 1ccd
1 1cd0 1cd5 1cd9 1cdc 1cdd 1ce2 1ce5
1 1ce8 1ced 1cf1 1cf5 1cf9 1cfd 1d01
1d05 1d09 1d0d 1d19 1d1d 1d21 1d24 1d28
1d2c 1d2e 1d32 1d36 1d3a 1d3d 1d41 1d45
1d47 1d48 1d4d 1 1d51 1d55 1d59 1d5c
1d60 1d64 1d68 1d6c 1d6f 1d73 1d77 1d7a
1d7d 1d82 1d85 1d88 1d8b 1d8c 1d91 1d92
1 1d94 1d99 1d9d 1da1 1da4 1da9 1dae
1db1 1db5 1db6 1dbb 1dbe 1dc3 1dc4 1dc9
1dcc 1dd1 1dd2 1dd7 1dda 1dde 1ddf 1de4
1de7 1dec 1ded 1df2 1df5 1df9 1dfd 1e00
1e03 1e04 1e06 1e07 1e0c 1e0d 1e12 1e14
1e18 1e1b 1e1d 1e21 1e23 1e2f 1e31 1e33
1e34 1e39 1e3d 1e3f 1e4b 1e4d 1e51 1e55
1e58 1e5c 1e5f 1e63 1e66 1e67 1e6c 1e6f
1e73 1e77 1e7a 1e7b 1e7d 1e80 1e83 1e84
1e89 1 1e8c 1e91 1e95 1e99 1e9c 1ea0
1ea4 1ea7 1eaa 1eaf 1eb2 1eb5 1eb8 1eb9
1ebe 1ebf 1 1ec1 1ec6 1eca 1ece 1ed1
1ed6 1edb 1ede 1ee2 1ee3 1ee8 1eeb 1ef0
1ef1 1ef6 1ef9 1efe 1eff 1f04 1f07 1f0b
1f0f 1f13 1f17 1f1a 1f1b 1f1d 1f22 1f23
1f25 1f26 1f2b 1f2c 1f31 1f33 1f37 1f3a
1f3e 1f42 1f45 1f49 1f4d 1f50 1f53 1f58
1f5b 1f5e 1f61 1f62 1f67 1f68 1 1f6a
1f6f 1f73 1f77 1f7a 1f7f 1f84 1f87 1f8b
1f8c 1f91 1f92 1f97 1f99 1f9d 1fa0 1fa4
1fa8 1fab 1faf 1fb3 1fb6 1fba 1fbb 1fc0
1fc2 1fc6 1fc9 1fcd 1fd0 1fd4 1fd6 1fda
1fdd 1fe1 1fe4 1fe5 1fea 1fed 1ff0 1ff4
1ff7 1ff8 1ffd 2000 1 2003 2008 200c
2010 2014 2020 2024 2028 202b 202f 2033
2035 2039 203d 2041 2044 2048 204c 204e
204f 2054 1 2058 205c 2060 2063 2067
206b 206f 2073 2076 207a 207e 2081 2084
2089 208c 208f 2092 2093 2098 2099 1
209b 20a0 20a4 20a8 20ab 20b0 20b5 20b8
20bc 20bd 20c2 20c5 20ca 20cb 20d0 20d3
20d8 20d9 20de 20e1 20e5 20e6 20eb 20ee
20f3 20f4 20f9 20fc 2100 2104 2107 210a
210b 210d 210e 2113 2114 2119 211b 211f
2122 2124 2128 212a 2136 2138 213a 213b
2140 2144 2146 2152 2154 2156 215a 215d
2161 2165 2169 216d 2171 2175 2178 217c
2180 2184 2187 2188 218a 218e 2192 2195
2196 2198 219b 219e 219f 21a1 21a5 21a9
21ad 21b1 21b5 21b8 21b9 21bb 21bf 21c3
21c6 21c7 21c9 21cd 21d1 21d5 21d9 21dc
21e0 21e4 21e8 21eb 21ec 21ee 21f2 21f6
21f9 21fa 21fc 21ff 2202 2203 2205 2209
220d 2211 2215 2219 221c 221d 221f 2223
2227 222a 222b 222d 2231 2235 2239 223c
223d 223f 2243 2246 224a 224d 224e 2253
2257 225c 2260 2264 2266 226a 226e 2271
2272 2274 2278 227b 227f 2282 2283 2288
228c 2291 2295 2297 229b 229f 22a3 22a6
22a7 22a9 22ad 22b0 22b4 22b7 22b8 22bd
22c1 22c6 22ca 22cc 22d0 22d5 22d9 22db
22df 22e3 22e6 22e8 22ec 22f0 22f3 22f7
22fb 22fe 22ff 2301 2304 2307 2308 230d
2311 2314 2318 231c 2320 2324 2328 232c
2338 233c 2340 2343 2347 234b 234d 2351
2355 2359 235c 2360 2364 2366 2367 236c
1 2370 2374 2378 237b 237f 2383 2387
238b 238e 2392 2396 2399 239c 23a1 23a4
23a7 23aa 23ab 23b0 23b1 1 23b3 23b8
23bc 23c0 23c3 23c8 23cd 23d0 23d4 23d5
23da 23dd 23e2 23e3 23e8 23eb 23f0 23f1
23f6 23f9 23fd 23fe 2403 2406 240b 240c
2411 2414 2418 241c 241f 2422 2423 2425
2426 242b 242c 2431 2433 2437 243a 243c
2440 2442 244e 2450 2452 2453 2458 245c
245e 246a 246c 2470 2474 2477 2478 247a
247d 2480 2481 2486 248a 248e 2492 2496
249a 24a6 24aa 24ae 24b1 24b5 24b9 24bb
24bf 24c3 24c7 24ca 24ce 24d2 24d4 24d5
24da 1 24de 24e2 24e6 24e9 24ed 24f1
24f5 24f9 24fc 2500 2504 2507 250a 250f
2512 2515 2518 2519 251e 251f 1 2521
2526 252a 252e 2531 2536 253b 253e 2542
2543 2548 254b 2550 2551 2556 2559 255e
255f 2564 2567 256b 256c 2571 2574 2579
257a 257f 2582 2586 258a 258d 2590 2591
2593 2594 2599 259a 259f 25a1 25a5 25a8
25aa 25ae 25b0 25bc 25be 25c0 25c1 25c6
25ca 25cc 25d8 25da 25de 25e2 25e5 25e9
25ee 25ef 25f1 25f4 25f7 25f8 25fd 2601
2605 2608 260c 2610 2613 2616 261b 261e
2621 2624 2625 262a 262b 1 262d 2632
2636 263a 263d 2642 2647 264a 264e 264f
2654 2657 265c 265d 2662 2665 266a 266b
2670 2673 2677 267b 267f 2683 2686 2687
2689 268e 268f 2691 2692 2697 269a 269f
26a0 26a5 26a8 26ad 26ae 26b3 26b6 26ba
26bb 26c0 26c3 26c8 26c9 26ce 26cf 26d4
26d6 26da 26dd 26e1 26e5 26e8 26ec 26f0
26f3 26f6 26fb 26fe 2701 2704 2705 270a
270b 1 270d 2712 2716 271a 271d 2722
2727 272a 272e 272f 2734 2735 273a 273c
2740 2743 2747 274b 274e 2752 2756 2759
275d 2761 2762 2767 2769 276d 2770 2772
2776 2779 277d 2781 2785 2789 278c 278d
278f 2790 2792 2796 279a 279e 27a1 27a2
27a4 27a7 27aa 27ab 27b0 27b4 27b8 27bc
27c0 27c3 27c4 27c6 27c7 27c9 27cd 27d1
27d5 27d8 27d9 27db 27de 27e1 27e2 27e7
27eb 27ef 27f2 27f6 27fa 27fd 2800 2805
2808 280b 280e 280f 2814 2815 1 2817
281c 2820 2824 2827 282c 2831 2834 2838
2839 283e 2841 2846 2847 284c 284f 2854
2855 285a 285d 2861 2865 2869 286d 2870
2871 2873 2878 2879 287b 287c 2881 2882
2887 2889 288d 2890 2894 2898 289b 289f
28a3 28a6 28a9 28ae 28b1 28b4 28b7 28b8
28bd 28be 1 28c0 28c5 28c9 28cd 28d0
28d5 28da 28dd 28e1 28e2 28e7 28e8 28ed
28ef 28f3 28f6 28fa 28fe 2901 2905 2909
290c 2910 2911 2916 2918 291c 291f 2923
2927 292b 292e 2932 2934 2938 293b 293f
2943 2947 294b 294f 2952 2953 2955 2958
295b 295c 2961 2965 2969 296d 296f 2973
2977 297a 297e 2982 2985 2988 298d 2990
2993 2996 2997 299c 299d 1 299f 29a4
29a8 29ac 29af 29b4 29b9 29bc 29c0 29c1
29c6 29c9 29ce 29cf 29d4 29d7 29dc 29dd
29e2 29e5 29e9 29ed 29f1 29f5 29f8 29f9
29fb 2a00 2a01 2a03 2a04 2a09 2a0a 2a0f
2a11 2a15 2a18 2a1c 2a20 2a23 2a27 2a2b
2a2e 2a31 2a36 2a39 2a3c 2a3f 2a40 2a45
2a46 1 2a48 2a4d 2a51 2a55 2a58 2a5d
2a62 2a65 2a69 2a6a 2a6f 2a70 2a75 2a77
2a7b 2a7e 2a82 2a86 2a89 2a8d 2a91 2a94
2a98 2a99 2a9e 2aa0 2aa4 2aa8 2aab 2aaf
2ab3 2ab7 2abb 2abf 2ac3 2ac7 2acb 2acc
2ace 2ad2 2ad6 2ada 2add 2ade 2ae0 2ae4
2ae7 2aeb 2aee 2aef 2af4 2af8 2afc 2aff
2b00 2b02 2b05 2b08 2b09 2b0e 2b12 2b16
2b1a 2b1d 2b21 2b23 2b27 2b2a 2b2e 2b32
2b35 2b39 2b3d 2b40 2b43 2b48 2b4b 2b4e
2b51 2b52 2b57 2b58 1 2b5a 2b5f 2b63
2b67 2b6a 2b6f 2b74 2b77 2b7b 2b7c 2b81
2b84 2b89 2b8a 2b8f 2b92 2b97 2b98 2b9d
2ba0 2ba4 2ba8 2bac 2bad 2baf 2bb4 2bb5
2bb7 2bb8 2bbd 2bc0 2bc5 2bc6 2bcb 2bce
2bd3 2bd4 2bd9 2bdc 2be0 2be1 2be6 2be9
2bee 2bef 2bf4 2bf5 2bfa 2bfc 2c00 2c03
2c07 2c0b 2c0e 2c12 2c16 2c19 2c1c 2c21
2c24 2c27 2c2a 2c2b 2c30 2c31 1 2c33
2c38 2c3c 2c40 2c43 2c48 2c4d 2c50 2c54
2c55 2c5a 2c5b 2c60 2c62 2c66 2c69 2c6d
2c71 2c74 2c78 2c7c 2c7f 2c80 2c82 2c86
2c8a 2c8b 2c90 2c92 2c96 2c99 2c9d 2ca1
2ca4 2ca5 2ca7 2caa 2cad 2cae 2cb3 2cb7
2cbb 2cbe 2cbf 2cc1 2cc4 2cc7 2cc8 1
2ccd 2cd2 2cd6 2cda 2cdd 2ce1 2ce5 2ce8
2ceb 2cf0 2cf3 2cf6 2cf9 2cfa 2cff 2d00
1 2d02 2d07 2d0b 2d0f 2d12 2d17 2d1c
2d1f 2d23 2d24 2d29 2d2c 2d31 2d32 2d37
2d3a 2d3f 2d40 2d45 2d48 2d4c 2d50 2d54
2d55 2d57 2d5c 2d5d 2d5f 2d60 2d65 2d68
2d6d 2d6e 2d73 2d76 2d7b 2d7c 2d81 2d84
2d88 2d89 2d8e 2d91 2d96 2d97 2d9c 2d9d
2da2 2da4 2da8 2dab 2daf 2db3 2db6 2dba
2dbe 2dc1 2dc4 2dc9 2dcc 2dcf 2dd2 2dd3
2dd8 2dd9 1 2ddb 2de0 2de4 2de8 2deb
2df0 2df5 2df8 2dfc 2dfd 2e02 2e03 2e08
2e0a 2e0e 2e11 2e15 2e19 2e1c 2e20 2e24
2e27 2e28 2e2a 2e2e 2e32 2e33 2e38 2e3a
2e3e 2e41 2e45 2e49 2e4c 2e4d 2e4f 2e53
2e56 2e5a 2e5d 2e5e 2e63 2e67 2e6b 2e6f
2e72 2e73 2e75 2e76 2e78 2e7b 2e7e 2e7f
2e84 2e88 2e8c 2e90 2e94 2e98 2e9c 2ea0
2ea4 2ea8 2eac 2eb0 2eb4 2eb8 2ec4 2ec8
2ecc 2ecf 2ed3 2ed7 2ed9 2edd 2ee1 2ee5
2ee8 2eec 2ef0 2ef2 2ef3 2ef8 1 2efc
2f00 2f04 2f07 2f0b 2f0f 2f13 2f17 2f1a
2f1e 2f22 2f25 2f28 2f2d 2f30 2f33 2f36
2f37 2f3c 2f3d 1 2f3f 2f44 2f48 2f4c
2f4f 2f54 2f59 2f5c 2f60 2f61 2f66 2f69
2f6e 2f6f 2f74 2f77 2f7c 2f7d 2f82 2f85
2f89 2f8a 2f8f 2f92 2f97 2f98 2f9d 2fa0
2fa4 2fa8 2fab 2fae 2faf 2fb1 2fb2 2fb7
2fb8 2fbd 2fbf 2fc3 2fc6 2fc8 2fcc 2fce
2fda 2fdc 2fde 2fdf 2fe4 2fe8 2fea 2ff6
2ff8 2ffa 2ffe 3002 3006 300a 300e 3012
3016 301a 301e 3022 3026 302a 302e 3032
3036 303a 303e 3042 3046 304a 304e 3052
3056 305a 305e 3062 3066 306a 306e 3072
3076 307a 307e 3082 3086 308a 308e 3092
3096 30a2 30a6 30aa 30ad 30b1 30b5 30b7
30bb 30bf 30c3 30c6 30ca 30ce 30d0 30d1
30d6 1 30da 30de 30e2 30e5 30e9 30ed
30f1 30f5 30f8 30fc 3100 3103 3106 310b
310e 3111 3114 3115 311a 311b 1 311d
3122 3126 312a 312d 3132 3137 313a 313e
313f 3144 3147 314c 314d 3152 3155 315a
315b 3160 3163 3167 3168 316d 3170 3175
3176 317b 317e 3182 3186 3189 318c 318d
318f 3190 3195 3196 319b 319d 31a1 31a4
31a6 31aa 31ac 31b8 31ba 31bc 31bd 31c2
31c6 31c8 31d4 31d6 31d8 31dc 31e0 31e3
31e7 31eb 31ee 31f2 31f5 31f9 31fc 31fd
3202 3205 3209 320d 3210 3214 3218 321b
321e 3223 3226 3229 322c 322d 3232 3233
1 3235 323a 323e 3242 3245 324a 324f
3252 3256 3257 325c 325f 3264 3265 326a
326d 3272 3273 3278 327b 327f 3283 3287
328b 328e 328f 3291 3296 3297 3299 329a
329f 32a2 32a7 32a8 32ad 32b0 32b5 32b6
32bb 32be 32c2 32c3 32c8 32cb 32d0 32d1
32d6 32d7 32dc 32de 32e2 32e5 32e9 32ed
32f0 32f4 32f8 32fb 32fe 3303 3306 3309
330c 330d 3312 3313 1 3315 331a 331e
3322 3325 332a 332f 3332 3336 3337 333c
333d 3342 3344 3348 334b 334f 3353 3356
335a 335e 3361 3365 3369 336a 336f 3371
3375 3378 337c 337e 3382 3386 3389 338a
338c 3390 3393 3397 339a 339b 33a0 33a4
33a8 33ac 33b0 33b4 33b8 33bc 33c0 33c4
33d0 33d4 33d8 33db 33df 33e3 33e5 33e9
33ed 33f1 33f4 33f8 33fc 33fe 33ff 3404
1 3408 340c 3410 3413 3417 341b 341f
3423 3426 342a 342e 3431 3434 3439 343c
343f 3442 3443 3448 3449 1 344b 3450
3454 3458 345b 3460 3465 3468 346c 346d
3472 3475 347a 347b 3480 3483 3488 3489
348e 3491 3495 3496 349b 349e 34a3 34a4
34a9 34ac 34b0 34b4 34b7 34ba 34bb 34bd
34be 34c3 34c4 34c9 34cb 34cf 34d2 34d4
34d8 34da 34e6 34e8 34ea 34eb 34f0 34f4
34f6 3502 3504 3508 350c 350f 3513 3516
351a 351d 351e 3523 3526 352a 352e 3531
3535 3539 353c 353f 3544 3547 354a 354d
354e 3553 3554 1 3556 355b 355f 3563
3566 356b 3570 3573 3577 3578 357d 3580
3585 3586 358b 358e 3593 3594 3599 359c
35a0 35a4 35a8 35ac 35af 35b0 35b2 35b7
35b8 35ba 35bb 35c0 35c3 35c8 35c9 35ce
35d1 35d6 35d7 35dc 35df 35e3 35e4 35e9
35ec 35f1 35f2 35f7 35f8 35fd 35ff 3603
3606 360a 360e 3611 3615 3619 361c 361f
3624 3627 362a 362d 362e 3633 3634 1
3636 363b 363f 3643 3646 364b 3650 3653
3657 3658 365d 365e 3663 3665 3669 366c
3670 3674 3677 367b 367f 3682 3686 368a
368b 3690 3692 3696 3699 369d 36a1 36a5
36a9 36ad 36b1 36b5 36b9 36bd 36c1 36c5
36c9 36cd 36d1 36d5 36d9 36dd 36e1 36e5
36f1 36f5 36f9 36fc 3700 3704 3706 370a
370e 3712 3715 3719 371d 371f 3720 3725
1 3729 372d 3731 3734 3738 373c 3740
3744 3747 374b 374f 3752 3755 375a 375d
3760 3763 3764 3769 376a 1 376c 3771
3775 3779 377c 3781 3786 3789 378d 378e
3793 3796 379b 379c 37a1 37a4 37a9 37aa
37af 37b2 37b6 37b7 37bc 37bf 37c4 37c5
37ca 37cd 37d1 37d5 37d8 37db 37dc 37de
37df 37e4 37e5 37ea 37ec 37f0 37f3 37f5
37f9 37fb 3807 3809 380b 380c 3811 3815
3817 3823 3825 3829 382d 3830 3834 3837
383b 383e 383f 3844 3847 384b 384f 3852
3856 385a 385d 3860 3865 3868 386b 386e
386f 3874 3875 1 3877 387c 3880 3884
3887 388c 3891 3894 3898 3899 389e 38a1
38a6 38a7 38ac 38af 38b4 38b5 38ba 38bd
38c1 38c5 38c9 38cd 38d0 38d1 38d3 38d8
38d9 38db 38dc 38e1 38e4 38e9 38ea 38ef
38f2 38f7 38f8 38fd 3900 3904 3905 390a
390d 3912 3913 3918 3919 391e 3920 3924
3927 392b 392f 3932 3936 393a 393d 3940
3945 3948 394b 394e 394f 3954 3955 1
3957 395c 3960 3964 3967 396c 3971 3974
3978 3979 397e 397f 3984 3986 398a 398d
3991 3995 3998 399c 39a0 39a3 39a7 39ab
39ac 39b1 39b3 39b7 39ba 39be 39c1 39c2
39c7 39ca 39ce 39d2 39d6 39d9 39dd 39e1
39e5 39e9 39ea 39ec 39f0 39f2 39f6 39f9
39fb 39ff 3a03 3a07 3a0a 3a0e 3a12 3a15
3a18 3a1d 3a20 3a23 3a26 3a27 3a2c 3a2d
1 3a2f 3a34 3a38 3a3c 3a3f 3a44 3a49
3a4c 3a50 3a51 3a56 3a59 3a5e 3a5f 3a64
3a67 3a6c 3a6d 3a72 3a75 3a79 3a7d 3a81
3a85 3a88 3a89 3a8b 3a90 3a91 3a93 3a94
3a99 3a9c 3aa1 3aa2 3aa7 3aaa 3aaf 3ab0
3ab5 3ab8 3abc 3abd 3ac2 3ac5 3aca 3acb
3ad0 3ad1 3ad6 3ad8 3adc 3adf 3ae3 3ae7
3aea 3aee 3af2 3af5 3af8 3afd 3b00 3b03
3b06 3b07 3b0c 3b0d 1 3b0f 3b14 3b18
3b1c 3b1f 3b24 3b29 3b2c 3b30 3b31 3b36
3b37 3b3c 3b3e 3b42 3b45 3b49 3b4d 3b50
3b54 3b58 3b5b 3b5f 3b63 3b64 3b69 3b6b
3b6f 3b73 3b76 3b7a 3b7e 3b81 3b82 3b84
3b88 3b8b 3b8f 3b92 3b93 3b98 3b9c 3ba0
3ba4 3ba8 3bac 3bb0 3bb4 3bb8 3bbc 3bc0
3bc4 3bc8 3bcc 3bd0 3bd4 3bd8 3bdc 3be0
3be4 3be8 3bec 3bf0 3bf4 3c00 3c04 3c08
3c0b 3c0f 3c13 3c15 3c19 3c1d 3c21 3c24
3c28 3c2c 3c2e 3c2f 3c34 1 3c38 3c3c
3c40 3c43 3c47 3c4b 3c4f 3c53 3c56 3c5a
3c5e 3c61 3c64 3c69 3c6c 3c6f 3c72 3c73
3c78 3c79 1 3c7b 3c80 3c84 3c88 3c8b
3c90 3c95 3c98 3c9c 3c9d 3ca2 3ca5 3caa
3cab 3cb0 3cb3 3cb8 3cb9 3cbe 3cc1 3cc5
3cc6 3ccb 3cce 3cd3 3cd4 3cd9 3cdc 3ce0
3ce4 3ce7 3cea 3ceb 3ced 3cee 3cf3 3cf4
3cf9 3cfb 3cff 3d02 3d04 3d08 3d0a 3d16
3d18 3d1a 3d1b 3d20 3d24 3d26 3d32 3d34
3d38 3d3c 3d3f 3d43 3d46 3d4a 3d4d 3d4e
3d53 3d56 3d5a 3d5e 3d61 3d65 3d69 3d6c
3d6f 3d74 3d77 3d7a 3d7d 3d7e 3d83 3d84
1 3d86 3d8b 3d8f 3d93 3d96 3d9b 3da0
3da3 3da7 3da8 3dad 3db0 3db5 3db6 3dbb
3dbe 3dc3 3dc4 3dc9 3dcc 3dd0 3dd4 3dd8
3ddc 3ddf 3de0 3de2 3de7 3de8 3dea 3deb
3df0 3df3 3df8 3df9 3dfe 3e01 3e06 3e07
3e0c 3e0f 3e13 3e14 3e19 3e1c 3e21 3e22
3e27 3e28 3e2d 3e2f 3e33 3e36 3e3a 3e3e
3e41 3e45 3e49 3e4c 3e4f 3e54 3e57 3e5a
3e5d 3e5e 3e63 3e64 1 3e66 3e6b 3e6f
3e73 3e76 3e7b 3e80 3e83 3e87 3e88 3e8d
3e8e 3e93 3e95 3e99 3e9c 3ea0 3ea4 3ea7
3eab 3eaf 3eb2 3eb6 3eba 3ebb 3ec0 3ec4
3ec6 3eca 3ece 3ed1 3ed5 3ed8 3edc 3edf
3ee0 3ee5 3ee8 3eec 3ef0 3ef3 3ef6 3ef7
3ef9 3efc 3f01 3f02 3f07 3f0b 3f0f 3f12
3f13 3f15 3f18 3f1b 3f1c 3f21 3f25 3f29
3f2c 3f2d 3f2f 3f33 3f36 3f3a 3f3d 3f3e
3f40 3f41 1 3f46 3f4b 1 3f4e 3f53
3f57 3f5b 3f5e 3f62 3f66 3f69 3f6c 3f71
3f74 3f77 3f7a 3f7b 3f80 3f81 1 3f83
3f88 3f8c 3f90 3f93 3f98 3f9d 3fa0 3fa4
3fa5 3faa 3fad 3fb2 3fb3 3fb8 3fbb 3fc0
3fc1 3fc6 3fc9 3fcd 3fd1 3fd5 3fd9 3fdc
3fdd 3fdf 3fe4 3fe5 3fe7 3fe8 3fed 3ff0
3ff5 3ff6 3ffb 3ffe 4003 4004 4009 400c
4010 4011 4016 4019 401e 401f 4024 4025
402a 402c 4030 4033 4037 403b 403e 4042
4046 4049 404c 4051 4054 4057 405a 405b
4060 4061 1 4063 4068 406c 4070 4073
4078 407d 4080 4084 4085 408a 408b 4090
4092 4096 4099 409d 40a1 40a4 40a8 40ac
40af 40b3 40b7 40b8 40bd 40bf 40c3 40c6
40ca 40ce 40d1 40d2 40d4 40d8 40db 40df
40e2 40e3 40e5 40e6 40eb 40ef 40f3 40f7
40fb 40ff 4103 4107 410b 410f 411b 411f
4123 4126 412a 412e 4130 4134 4138 413c
413f 4143 4147 4149 414a 414f 1 4153
4157 415b 415e 4162 4166 416a 416e 4171
4175 4179 417c 417f 4184 4187 418a 418d
418e 4193 4194 1 4196 419b 419f 41a3
41a6 41ab 41b0 41b3 41b7 41b8 41bd 41c0
41c5 41c6 41cb 41ce 41d3 41d4 41d9 41dc
41e0 41e1 41e6 41e9 41ee 41ef 41f4 41f7
41fb 41ff 4202 4205 4206 4208 4209 420e
420f 4214 4216 421a 421d 421f 4223 4225
4231 4233 4235 4236 423b 423f 4241 424d
424f 4251 4255 4258 425a 425e 4262 4265
4267 426b 426e 4270 4274 4277 427b 427f
4282 4283 4285 4288 428b 428c 4291 4295
4299 429c 429d 429f 42a3 42a6 42aa 42ad
42ae 42b3 42b7 42ba 42bb 42c0 1 42c3
42c8 42cc 42d0 42d3 42d4 42d6 42d9 42dc
42dd 1 42e2 42e7 42eb 42ef 42f2 42f6
42fa 42fd 4300 4305 4308 430b 430e 430f
4314 4315 1 4317 431c 4320 4324 4327
432c 4331 4334 4338 4339 433e 4341 4346
4347 434c 434f 4354 4355 435a 435d 4361
4365 4369 436d 4370 4371 4373 4378 4379
437b 437c 4381 4384 4389 438a 438f 4392
4397 4398 439d 43a0 43a4 43a5 43aa 43ad
43b2 43b3 43b8 43b9 43be 43c0 43c4 43c7
43cb 43cf 43d2 43d6 43da 43dd 43e0 43e5
43e8 43eb 43ee 43ef 43f4 43f5 1 43f7
43fc 4400 4404 4407 440c 4411 4414 4418
4419 441e 441f 4424 4426 442a 442d 4431
4435 4438 443c 4440 4443 4447 444b 444c
4451 4453 4457 445a 445e 4462 4465 4466
4468 446c 446f 4473 4476 4477 447c 4480
4484 4488 448c 4490 4494 4498 449c 44a0
44a4 44a8 44b4 44b8 44bc 44bf 44c3 44c7
44c9 44cd 44d1 44d5 44d8 44dc 44e0 44e2
44e3 44e8 1 44ec 44f0 44f4 44f7 44fb
44ff 4503 4507 450a 450e 4512 4515 4518
451d 4520 4523 4526 4527 452c 452d 1
452f 4534 4538 453c 453f 4544 4549 454c
4550 4551 4556 4559 455e 455f 4564 4567
456c 456d 4572 4575 4579 457a 457f 4582
4587 4588 458d 4590 4594 4598 459b 459e
459f 45a1 45a2 45a7 45a8 45ad 45af 45b3
45b6 45b8 45bc 45be 45ca 45cc 45ce 45cf
45d4 45d8 45da 45e6 45e8 45ec 45f0 45f3
45f7 45fa 45fe 4601 4602 4607 460a 460e
4612 4616 461a 461e 462a 462e 4632 4635
4639 463d 463f 4643 4647 464b 464e 4652
4656 4658 4659 465e 1 4662 4666 466a
466d 4671 4675 4679 467d 4680 4684 4688
468b 468e 4693 4696 4699 469c 469d 46a2
46a3 1 46a5 46aa 46ae 46b2 46b5 46ba
46bf 46c2 46c6 46c7 46cc 46cf 46d4 46d5
46da 46dd 46e2 46e3 46e8 46eb 46ef 46f0
46f5 46f8 46fd 46fe 4703 4706 470a 470e
4711 4714 4715 4717 4718 471d 471e 4723
4725 4729 472c 472e 4732 4734 4740 4742
4744 4745 474a 474e 4750 475c 475e 4762
4766 4769 476d 4770 4774 4777 4778 477d
4780 4784 4788 478b 478f 4793 4796 4799
479e 47a1 47a4 47a7 47a8 47ad 47ae 1
47b0 47b5 47b9 47bd 47c0 47c5 47ca 47cd
47d1 47d2 47d7 47da 47df 47e0 47e5 47e8
47ed 47ee 47f3 47f6 47fa 47fe 4802 4806
4809 480a 480c 4811 4812 4814 4815 481a
481d 4822 4823 4828 482b 4830 4831 4836
4839 483d 483e 4843 4846 484b 484c 4851
4852 4857 4859 485d 4860 4864 4868 486b
486f 4873 4876 4879 487e 4881 4884 4887
4888 488d 488e 1 4890 4895 4899 489d
48a0 48a5 48aa 48ad 48b1 48b2 48b7 48b8
48bd 48bf 48c3 48c6 48ca 48ce 48d1 48d5
48d9 48dc 48e0 48e4 48e5 48ea 48ec 48f0
48f3 48f5 48f9 48fc 48fe 4902 4905 4907
490b 490e 4912 4916 4919 491a 491c 491f
4922 4923 4928 492c 4930 4933 4934 4936
4939 493c 493d 1 4942 4947 494b 494e
4952 4954 4958 495b 495f 4963 4966 4967
4969 496d 4970 4974 4977 4978 497d 4981
4984 4985 498a 498d 4991 4996 499a 499e
49a3 49a7 49a9 49ad 49b1 49b5 49b9 49bd
49c1 49c3 49c7 49cb 49ce 49d2 49d5 49d9
49db 49df 49e2 49e5 49e6 49eb 49ef 49f4
49f8 49fc 4a00 4a04 4a08 4a0c 4a10 4a13
4a14 4a16 4a1a 4a1e 4a21 4a22 4a24 4a28
4a2c 4a2f 4a30 4a32 4a36 4a3a 4a3d 4a3e
4a40 4a44 4a48 4a4b 4a4c 4a4e 4a52 4a56
4a59 4a5a 4a5c 4a60 4a64 4a67 4a68 4a6a
4a6e 4a72 4a75 4a76 4a78 4a7c 4a80 4a84
4a85 4a87 4a8b 4a8f 4a93 4a96 4a97 4a99
4a9d 4aa0 4aa4 4aa7 4aa8 4aad 4ab1 4ab5
4ab8 4abc 4ac0 4ac3 4ac6 4acb 4ace 4ad1
4ad4 4ad5 4ada 4adb 1 4add 4ae2 4ae6
4aea 4aed 4af2 4af7 4afa 4afe 4aff 4b04
4b07 4b0c 4b0d 4b12 4b15 4b1a 4b1b 4b20
4b23 4b27 4b2b 4b2f 4b33 4b36 4b37 4b39
4b3e 4b3f 4b41 4b42 4b47 4b48 4b4d 4b4f
4b53 4b56 4b5a 4b5e 4b61 4b65 4b69 4b6c
4b6f 4b74 4b77 4b7a 4b7d 4b7e 4b83 4b84
1 4b86 4b8b 4b8f 4b93 4b96 4b9b 4ba0
4ba3 4ba7 4ba8 4bad 4bae 4bb3 4bb5 4bb9
4bbc 4bc0 4bc4 4bc7 4bcb 4bcf 4bd2 4bd6
4bd7 4bdc 4be0 4be2 4be6 4bea 4bed 4bee
4bf0 4bf3 4bf6 4bf7 4bfc 4c00 4c04 4c07
4c0b 4c0f 4c12 4c15 4c1a 4c1d 4c20 4c23
4c24 4c29 4c2a 1 4c2c 4c31 4c35 4c39
4c3c 4c41 4c46 4c49 4c4d 4c4e 4c53 4c56
4c5b 4c5c 4c61 4c64 4c69 4c6a 4c6f 4c72
4c76 4c7a 4c7e 4c7f 4c81 4c86 4c87 4c89
4c8a 4c8f 4c92 4c97 4c98 4c9d 4ca0 4ca5
4ca6 4cab 4cae 4cb2 4cb3 4cb8 4cbb 4cc0
4cc1 4cc6 4cc7 4ccc 4cce 4cd2 4cd5 4cd9
4cdd 4ce0 4ce4 4ce8 4ceb 4cee 4cf3 4cf6
4cf9 4cfc 4cfd 4d02 4d03 1 4d05 4d0a
4d0e 4d12 4d15 4d1a 4d1f 4d22 4d26 4d27
4d2c 4d2d 4d32 4d34 4d38 4d3b 4d3f 4d43
4d46 4d4a 4d4e 4d51 4d52 4d54 4d58 4d5c
4d5d 4d62 4d64 4d68 4d6c 4d6f 4d71 4d75
4d79 4d7d 4d81 4d85 4d88 4d89 4d8b 4d8e
4d91 4d92 4d97 4d9b 4d9f 4da3 4da6 4da7
4da9 4dac 4db0 4db4 4db7 4db8 4dba 4dbb
4dc0 4dc4 4dc6 4dca 4dcd 4dcf 4dd3 4dd7
4dda 4dde 4de2 4de5 4de6 4de8 4deb 4dee
4def 4df4 4df7 4dfb 4dff 4e02 4e03 4e05
4e08 4e0b 4e0c 4e11 1 4e14 4e19 4e1d
4e21 4e24 4e25 4e27 4e2a 4e2d 4e2e 4e33
4e36 4e3a 4e3e 4e41 4e42 4e44 4e47 4e4a
4e4b 4e50 1 4e53 4e58 4e5c 4e5f 4e63
4e67 4e69 4e6d 4e71 4e74 4e75 4e77 4e7a
4e7d 4e7e 4e83 4e87 4e8a 4e8e 4e92 4e94
4e98 4e9c 4ea0 4ea3 4ea4 4ea6 4ea9 4eac
4ead 4eb2 4eb5 4eb9 4ebd 4ec0 4ec1 4ec3
4ec6 4ec9 4eca 4ecf 1 4ed2 4ed7 4edb
4ede 4ee2 4ee6 4ee8 4eec 4ef0 4ef4 4ef7
4ef8 4efa 4efd 4f00 4f01 4f06 4f0a 4f0d
4f11 4f13 4f17 4f1b 4f1e 4f20 4f24 4f27
4f29 4f2d 4f31 4f34 4f38 4f3c 4f3f 4f40
4f42 4f46 4f49 4f4d 4f50 4f51 4f56 4f5a
4f5d 4f61 4f65 4f69 4f6d 4f71 4f75 4f79
4f7d 4f81 4f85 4f88 4f8b 4f8c 4f8e 4f92
4f96 4f97 4f9b 4f9f 4fa3 4fa6 4fa7 4fa9
4fac 4faf 4fb0 4fb5 4fb9 4fbd 4fbe 4fc3
4fc7 4fcb 4fce 4fd2 4fd4 4fd8 4fdc 4fe0
4fe4 4fe8 4ff4 4ff8 4ffc 4fff 5003 5007
5009 500d 5011 5015 5018 501c 5020 5022
5023 5028 1 502c 5030 5034 5037 503b
503f 5043 5047 504a 504e 5052 5055 5058
505d 5060 5063 5066 5067 506c 506d 1
506f 5074 5078 507c 507f 5084 5089 508c
5090 5091 5096 5099 509e 509f 50a4 50a7
50ac 50ad 50b2 50b5 50b9 50ba 50bf 50c2
50c7 50c8 50cd 50d0 50d4 50d8 50db 50de
50df 50e1 50e2 50e7 50e8 50ed 50ef 50f3
50f6 50f8 50fc 50fe 510a 510c 510e 510f
5114 5118 511a 5126 5128 512c 5130 5133
5137 513a 513e 5141 5142 5147 514a 514e
5152 5155 5156 5158 515b 515e 515f 5164
5168 516c 5170 5174 5178 517c 5180 5184
5188 518c 5190 519c 51a0 51a4 51a7 51ab
51af 51b1 51b5 51b9 51bd 51c0 51c4 51c8
51ca 51cb 51d0 1 51d4 51d8 51dc 51df
51e3 51e7 51eb 51ef 51f2 51f6 51fa 51fd
5200 5205 5208 520b 520e 520f 5214 5215
1 5217 521c 5220 5224 5227 522c 5231
5234 5238 5239 523e 5241 5246 5247 524c
524f 5254 5255 525a 525d 5261 5262 5267
526a 526f 5270 5275 5278 527c 5280 5283
5286 5287 5289 528a 528f 5290 5295 5297
529b 529e 52a0 52a4 52a6 52b2 52b4 52b6
52b7 52bc 52c0 52c2 52ce 52d0 52d2 52d6
52d9 52db 52df 52e2 52e6 52e8 52ec 52f0
52f3 52f5 52f9 52fd 5300 5304 5307 530a
530b 5310 5314 5318 531c 5320 5324 5328
532c 5330 5334 5340 5344 5348 534b 534f
5353 5355 5359 535d 5361 5364 5368 536c
536e 536f 5374 1 5378 537c 5380 5383
5387 538b 538f 5393 5396 539a 539e 53a1
53a4 53a9 53ac 53af 53b2 53b3 53b8 53b9
1 53bb 53c0 53c4 53c8 53cb 53d0 53d5
53d8 53dc 53dd 53e2 53e5 53ea 53eb 53f0
53f3 53f8 53f9 53fe 5401 5405 5406 540b
540e 5413 5414 5419 541c 5420 5424 5427
542a 542b 542d 542e 5433 5434 5439 543b
543f 5442 5444 5448 544a 5456 5458 545a
545b 5460 5464 5466 5472 5474 5478 547c
5480 5484 5488 548c 5490 5494 5498 549c
54a0 54a4 54a8 54ac 54b0 54b4 54b8 54bc
54c0 54c4 54c8 54cc 54d0 54d4 54d8 54dc
54e0 54e4 54e8 54ec 54f0 54fc 5500 5504
5507 550b 550f 5511 5515 5519 551d 5520
5524 5528 552a 552b 5530 1 5534 5538
553c 553f 5543 5547 554b 554f 5552 5556
555a 555d 5560 5565 5568 556b 556e 556f
5574 5575 1 5577 557c 5580 5584 5587
558c 5591 5594 5598 5599 559e 55a1 55a6
55a7 55ac 55af 55b4 55b5 55ba 55bd 55c1
55c2 55c7 55ca 55cf 55d0 55d5 55d8 55dc
55e0 55e3 55e6 55e7 55e9 55ea 55ef 55f0
55f5 55f7 55fb 55fe 5600 5604 5606 5612
5614 5616 5617 561c 5620 5622 562e 5630
5634 5638 563b 563f 5642 5646 5649 564a
564f 5652 5656 565a 565d 5661 5665 5668
566b 5670 5673 5676 5679 567a 567f 5680
1 5682 5687 568b 568f 5692 5697 569c
569f 56a3 56a4 56a9 56ac 56b1 56b2 56b7
56ba 56bf 56c0 56c5 56c8 56cc 56d0 56d4
56d8 56db 56dc 56de 56e3 56e4 56e6 56e7
56ec 56ef 56f4 56f5 56fa 56fd 5702 5703
5708 570b 570f 5710 5715 5718 571d 571e
5723 5724 5729 572b 572f 5732 5736 573a
573d 5741 5745 5748 574b 5750 5753 5756
5759 575a 575f 5760 1 5762 5767 576b
576f 5772 5777 577c 577f 5783 5784 5789
578a 578f 5791 5795 5798 579c 57a0 57a3
57a7 57ab 57ae 57b2 57b6 57b7 57bc 57be
57c2 57c5 57c9 57cd 57d0 57d1 57d3 57d6
57d9 57da 57df 57e3 57e8 57ec 57ee 57f2
57f7 57fb 57fd 5801 5805 5808 580c 5810
5814 5818 581c 5820 5824 5828 582c 5830
5834 5838 583c 5840 5844 5848 584c 5850
5854 5860 5864 5869 586d 5870 5871 5876
587a 587e 5881 5884 5888 588a 588e 5892
5895 5898 589c 589e 58a2 58a6 58a9 58ab
58af 58b3 58b7 58ba 58be 58c2 58c4 58c5
58ca 1 58ce 58d2 58d6 58d9 58dd 58e1
58e5 58e9 58ec 58f0 58f4 58f7 58fa 58ff
5902 5905 5908 5909 590e 590f 1 5911
5916 591a 591e 5921 5926 592b 592e 5932
5933 5938 593b 5940 5941 5946 5949 594e
594f 5954 5957 595b 595c 5961 5964 5969
596a 596f 5972 5976 597a 597d 5980 5981
5983 5984 5989 598a 598f 5991 5995 5998
599a 599e 59a0 59ac 59ae 59b0 59b1 59b6
59ba 59bc 59c8 59ca 59ce 59d0 59d4 59d8
59db 59de 59df 59e1 59e4 59e9 59ea 59ef
59f3 59f7 59fb 59ff 5a0b 5a0f 5a14 5a18
5a1b 5a1c 5a21 5a25 5a29 5a2c 5a2f 5a33
5a35 5a39 5a3d 5a40 5a43 5a47 5a49 5a4d
5a51 5a54 5a56 5a5a 5a5e 5a62 5a65 5a69
5a6d 5a6f 5a70 5a75 1 5a79 5a7d 5a81
5a84 5a88 5a8c 5a90 5a94 5a97 5a9b 5a9f
5aa2 5aa5 5aaa 5aad 5ab0 5ab3 5ab4 5ab9
5aba 1 5abc 5ac1 5ac5 5ac9 5acc 5ad1
5ad6 5ad9 5add 5ade 5ae3 5ae6 5aeb 5aec
5af1 5af4 5af9 5afa 5aff 5b02 5b06 5b07
5b0c 5b0f 5b14 5b15 5b1a 5b1d 5b21 5b25
5b28 5b2b 5b2c 5b2e 5b2f 5b34 5b35 5b3a
5b3c 5b40 5b43 5b45 5b49 5b4b 5b57 5b59
5b5b 5b5c 5b61 5b65 5b67 5b73 5b75 5b77
5b7b 5b7f 5b82 5b86 5b8a 5b8e 5b92 5b96
5b9a 5b9e 5ba2 5ba6 5bb2 5bb6 5bbb 5bbf
5bc2 5bc3 5bc8 5bcc 5bd0 5bd3 5bd6 5bda
5bdc 5be0 5be4 5be7 5bea 5bee 5bf0 5bf4
5bf8 5bfb 5bfd 5c01 5c05 5c09 5c0c 5c10
5c14 5c16 5c17 5c1c 1 5c20 5c24 5c28
5c2b 5c2f 5c33 5c37 5c3b 5c3e 5c42 5c46
5c49 5c4c 5c51 5c54 5c57 5c5a 5c5b 5c60
5c61 1 5c63 5c68 5c6c 5c70 5c73 5c78
5c7d 5c80 5c84 5c85 5c8a 5c8d 5c92 5c93
5c98 5c9b 5ca0 5ca1 5ca6 5ca9 5cad 5cae
5cb3 5cb6 5cbb 5cbc 5cc1 5cc4 5cc8 5ccc
5ccf 5cd2 5cd3 5cd5 5cd6 5cdb 5cdc 5ce1
5ce3 5ce7 5cea 5cec 5cf0 5cf2 5cfe 5d00
5d02 5d03 5d08 5d0c 5d0e 5d1a 5d1c 5d20
5d24 5d28 5d2c 5d30 5d34 5d38 5d3c 5d40
5d4c 5d50 5d55 5d59 5d5c 5d5d 5d62 5d66
5d6a 5d6d 5d70 5d74 5d76 5d7a 5d7e 5d81
5d84 5d88 5d8a 5d8e 5d92 5d95 5d97 5d9b
5d9f 5da3 5da6 5daa 5dae 5db0 5db1 5db6
1 5dba 5dbe 5dc2 5dc5 5dc9 5dcd 5dd1
5dd5 5dd8 5ddc 5de0 5de3 5de6 5deb 5dee
5df1 5df4 5df5 5dfa 5dfb 1 5dfd 5e02
5e06 5e0a 5e0d 5e12 5e17 5e1a 5e1e 5e1f
5e24 5e27 5e2c 5e2d 5e32 5e35 5e3a 5e3b
5e40 5e43 5e47 5e48 5e4d 5e50 5e55 5e56
5e5b 5e5e 5e62 5e66 5e69 5e6c 5e6d 5e6f
5e70 5e75 5e76 5e7b 5e7d 5e81 5e84 5e86
5e8a 5e8c 5e98 5e9a 5e9c 5e9d 5ea2 5ea6
5ea8 5eb4 5eb6 5eba 5ebe 5ec2 5ec6 5eca
5ece 5eda 5ede 5ee3 5ee7 5eea 5eeb 5ef0
5ef4 5ef8 5efb 5efe 5f02 5f04 5f08 5f0c
5f0f 5f12 5f16 5f18 5f1c 5f20 5f23 5f25
5f29 5f2d 5f31 5f34 5f38 5f3c 5f3e 5f3f
5f44 1 5f48 5f4c 5f50 5f53 5f57 5f5b
5f5f 5f63 5f66 5f6a 5f6e 5f71 5f74 5f79
5f7c 5f7f 5f82 5f83 5f88 5f89 1 5f8b
5f90 5f94 5f98 5f9b 5fa0 5fa5 5fa8 5fac
5fad 5fb2 5fb5 5fba 5fbb 5fc0 5fc3 5fc8
5fc9 5fce 5fd1 5fd5 5fd6 5fdb 5fde 5fe3
5fe4 5fe9 5fec 5ff0 5ff4 5ff7 5ffa 5ffb
5ffd 5ffe 6003 6004 6009 600b 600f 6012
6014 6018 601a 6026 6028 602a 602b 6030
6034 6036 6042 6044 6046 604a 604d 6051
6055 6056 605b 605f 6063 6067 606a 606b
606d 6070 6073 6074 6079 607d 6081 6084
6085 6087 608b 608e 6092 6095 6096 1
609b 60a0 60a4 60a8 60ab 60ac 60ae 60b2
60b5 60b9 60bc 60bd 1 60c2 60c7 60cb
60ce 60cf 60d4 60d7 60db 60df 60e3 60e5
60e9 60ec 60ee 60f2 60f5 60f9 60fd 6100
6101 6103 6106 6109 610a 610f 6113 6117
611b 611e 6122 6124 6128 612b 612f 6132
6133 6138 613b 613f 6142 6143 6148 1
614b 6150 6154 6157 6158 615d 1 6160
6165 6169 616c 616d 6172 6175 1 6178
617d 6181 6184 6188 618a 618e 6191 6195
619a 619e 61a2 61a7 61ab 61af 61b3 61b6
61b7 61b9 61bc 61bf 61c0 61c5 61c9 61cd
61d0 61d1 61d3 61d7 61da 61de 61e1 61e2
61e7 61eb 61f0 61f3 61f7 61f8 61fd 6200
6205 6206 620b 620e 6213 6214 6219 621c
6221 6222 6227 622a 622f 6230 6235 6238
623c 623d 6242 6245 624a 624b 6250 6254
6258 625a 625e 6262 6265 6266 6268 626b
626e 626f 6274 6278 627d 6280 6285 6286
628b 628e 6293 6294 6299 629c 62a0 62a1
62a6 62a9 62ae 62af 62b4 62b7 62bc 62bd
62c2 62c5 62c9 62ca 62cf 62d2 62d7 62d8
62dd 62e0 62e5 62e6 62eb 62ef 62f1 62f5
62f9 62fe 6301 6306 6307 630c 630f 6314
6315 631a 631d 6322 6323 6328 632b 632f
6330 6335 6338 633d 633e 6343 6347 6349
634d 6351 6354 6356 635a 635e 6361 6362
6364 6368 636b 636f 6372 6373 6378 637c
6380 6383 6384 6386 638a 638d 6391 6394
6395 1 639a 639f 63a3 63a7 63aa 63ab
63ad 63b1 63b4 63b8 63bb 63bc 1 63c1
63c6 63ca 63ce 63d3 63d8 63dc 63e0 63e4
63e7 63ea 63ee 63f2 63f5 63f6 63fb 63fe
6402 6406 640b 6410 6414 6418 641c 641f
6422 6426 642a 642e 6432 6436 643a 643e
6442 6446 644a 644e 6452 6456 645a 645e
6462 6466 646a 646e 6472 6476 647a 647e
6482 648e 6492 6497 649b 649e 649f 64a4
64a8 64ac 64af 64b2 64b6 64b8 64bc 64c0
64c3 64c6 64ca 64cc 64d0 64d4 64d7 64d9
64dd 64e1 64e5 64e8 64ec 64f0 64f2 64f3
64f8 1 64fc 6500 6504 6507 650b 650f
6513 6517 651a 651e 6522 6525 6528 652d
6530 6533 6536 6537 653c 653d 1 653f
6544 6548 654c 654f 6554 6559 655c 6560
6561 6566 6569 656e 656f 6574 6577 657c
657d 6582 6585 6589 658a 658f 6592 6597
6598 659d 65a0 65a4 65a8 65ab 65ae 65af
65b1 65b2 65b7 65b8 65bd 65bf 65c3 65c6
65c8 65cc 65ce 65da 65dc 65de 65df 65e4
65e8 65ea 65f6 65f8 65fc 6600 6604 6608
660c 6610 6614 6618 661c 6620 6624 6628
662c 6630 6634 6638 663c 6640 6644 6648
664c 6658 665c 6661 6665 6668 6669 666e
6672 6676 6679 667c 6680 6682 6686 668a
668d 6690 6694 6696 669a 669e 66a1 66a3
66a7 66ab 66af 66b2 66b6 66ba 66bc 66bd
66c2 1 66c6 66ca 66ce 66d1 66d5 66d9
66dd 66e1 66e4 66e8 66ec 66ef 66f2 66f7
66fa 66fd 6700 6701 6706 6707 1 6709
670e 6712 6716 6719 671e 6723 6726 672a
672b 6730 6733 6738 6739 673e 6741 6746
6747 674c 674f 6753 6754 6759 675c 6761
6762 6767 676a 676e 6772 6775 6778 6779
677b 677c 6781 6782 6787 6789 678d 6790
6792 6796 6798 67a4 67a6 67a8 67a9 67ae
67b2 67b4 67c0 67c2 67c4 67c8 67cc 67d0
67d2 67d6 67da 67dd 67df 67e3 67e6 67ea
67ed 67ee 67f3 67f6 67fa 67fe 6802 6806
6807 6809 680c 680d 680f 6812 6815 6816
681b 681f 6823 6827 682b 682c 682e 6831
6832 6834 6837 6838 683a 683d 6840 6841
6846 6847 6849 684d 6851 6855 6859 685a
685c 685f 6860 6862 6865 6866 6868 686a
686e 6872 6876 6879 687d 6881 6885 6889
688c 6890 6891 6896 6898 689c 68a0 68a4
68a8 68ac 68af 68b2 68b3 68b8 68bb 68bc
68be 68bf 68c1 68c4 68c5 68c7 68ca 68cd
68ce 68d3 68d7 68db 68df 68e3 68e7 68ea
68ed 68ee 68f3 68f6 68f7 68f9 68fa 68fc
68ff 6900 6902 6905 6908 6909 1 690e
6913 6917 691d 691f 6923 6926 692a 692e
6931 6934 6935 693a 693e 6940 6944 694b
694f 6953 6956 6957 695c 6960 6964 6967
696b 696f 6972 6975 697a 697d 6980 6983
6984 6989 698a 1 698c 6991 6995 6999
699c 69a1 69a6 69a9 69ad 69ae 69b3 69b6
69bb 69bc 69c1 69c4 69c9 69ca 69cf 69d2
69d6 69da 69de 69e2 69e5 69e6 69e8 69ed
69ee 69f0 69f1 69f6 69f7 69fc 69fe 6a02
6a05 6a09 6a0d 6a10 6a14 6a18 6a1b 6a1e
6a23 6a26 6a29 6a2c 6a2d 6a32 6a33 1
6a35 6a3a 6a3e 6a42 6a45 6a4a 6a4f 6a52
6a56 6a57 6a5c 6a5d 6a62 6a64 6a68 6a6b
6a6f 6a73 6a76 6a7a 6a7e 6a81 6a85 6a86
6a8b 6a8d 6a91 6a94 6a98 6a9c 6aa0 6aa4
6ab0 6ab4 6ab8 6abb 6abf 6ac3 6ac5 6ac9
6acd 6ad1 6ad4 6ad8 6adc 6ade 6adf 6ae4
1 6ae8 6aec 6af0 6af3 6af7 6afb 6aff
6b03 6b06 6b0a 6b0e 6b11 6b14 6b19 6b1c
6b1f 6b22 6b23 6b28 6b29 1 6b2b 6b30
6b34 6b38 6b3b 6b40 6b45 6b48 6b4c 6b4d
6b52 6b55 6b5a 6b5b 6b60 6b63 6b68 6b69
6b6e 6b71 6b75 6b76 6b7b 6b7e 6b83 6b84
6b89 6b8c 6b90 6b94 6b97 6b9a 6b9b 6b9d
6b9e 6ba3 6ba4 6ba9 6bab 6baf 6bb2 6bb4
6bb8 6bba 6bc6 6bc8 6bca 6bcb 6bd0 6bd4
6bd6 6be2 6be4 6be6 6bea 6bed 6bf1 6bf5
6bf8 6bf9 6bfb 6bff 6c02 6c06 6c09 6c0a
6c0f 6c13 6c18 6c1c 6c20 6c25 6c29 6c2d
6c31 6c34 6c38 6c39 6c3e 6c42 6c46 6c4a
6c4d 6c52 6c53 6c58 6c5c 6c60 6c62 6c66
6c6a 6c6d 6c6e 6c70 6c74 6c77 6c7b 6c7e
6c7f 6c84 6c88 6c8d 6c91 6c95 6c99 6c9c
6ca0 6ca1 6ca6 6caa 6cae 6cb2 6cb5 6cba
6cbb 6cc0 6cc4 6cc8 6ccd 6cd1 6cd3 6cd7
6cdb 6cdf 6ce2 6ce3 6ce5 6ce9 6cec 6cf0
6cf3 6cf4 6cf9 6cfd 6d02 6d06 6d0a 6d0f
6d13 6d17 6d1b 6d1e 6d23 6d24 6d29 6d2d
6d31 6d34 6d35 6d3a 6d3d 6d41 6d45 6d48
6d4d 6d4e 6d53 6d57 6d5b 6d5f 6d62 6d66
6d67 6d6c 6d70 6d74 6d78 6d7b 6d80 6d81
6d86 6d8a 6d8c 6d90 6d93 6d95 6d99 6d9c
6d9d 6da2 6da5 6da9 6dad 6db0 6db5 6db6
6dbb 6dbf 6dc3 6dc8 6dcc 6dce 6dd2 6dd6
6dd9 6dde 6ddf 6de4 6de7 6dec 6ded 6df2
6df6 6dfa 6dff 6e03 6e07 6e0b 6e0e 6e13
6e14 6e19 6e1c 6e21 6e22 6e27 6e2a 6e2f
6e30 6e35 6e38 6e3d 6e3e 6e43 6e46 6e4b
6e4c 6e51 6e54 6e59 6e5a 6e5f 6e63 6e65
6e69 6e6d 6e70 6e74 6e77 6e78 6e7d 6e80
6e84 6e88 6e8b 6e90 6e91 6e96 6e99 6e9d
6e9e 6ea3 6ea6 6eab 6eac 6eb1 6eb5 6eb7
6ebb 6ebe 6ec0 6ec4 6ec8 6ecb 6ecf 6ed2
6ed3 6ed8 6edb 6edf 6ee3 6ee6 6eeb 6eec
6ef1 6ef5 6ef9 6efd 6f00 6f04 6f05 6f0a
6f0e 6f12 6f16 6f19 6f1e 6f1f 6f24 6f28
6f2a 6f2e 6f31 6f33 6f37 6f3b 6f3e 6f42
6f46 6f49 6f4a 6f4c 6f50 6f53 6f57 6f5a
6f5b 6f60 6f64 6f67 6f68 6f6d 6f70 6f74
6f78 6f7c 6f80 6f84 6f90 6f94 6f98 6f9b
6f9f 6fa3 6fa5 6fa9 6fad 6fb1 6fb4 6fb8
6fbc 6fbe 6fbf 6fc4 1 6fc8 6fcc 6fd0
6fd3 6fd7 6fdb 6fdf 6fe3 6fe6 6fea 6fee
6ff1 6ff4 6ff9 6ffc 6fff 7002 7003 7008
7009 1 700b 7010 7014 7018 701b 7020
7025 7028 702c 702d 7032 7035 703a 703b
7040 7043 7048 7049 704e 7051 7055 7056
705b 705e 7063 7064 7069 706c 7070 7074
7077 707a 707b 707d 707e 7083 7084 7089
708b 708f 7092 7094 7098 709a 70a6 70a8
70aa 70ab 70b0 70b4 70b6 70c2 70c4 70c8
70cc 70cf 70d3 70d6 70da 70dd 70de 70e3
70e6 70ea 70ee 70f2 70f6 70f7 70f9 70fc
70fd 70ff 7103 7107 710b 710e 7113 7114
7119 711d 7121 7125 7128 712d 712e 7133
7136 713b 713c 7141 7144 7148 7149 714e
7151 7156 7157 715c 7160 7162 7166 716a
716d 7171 7175 7178 717b 7180 7183 7186
7189 718a 718f 7190 1 7192 7197 719b
719f 71a2 71a7 71ac 71af 71b3 71b4 71b9
71bc 71c1 71c2 71c7 71ca 71cf 71d0 71d5
71d8 71dc 71e0 71e4 71e8 71eb 71ec 71ee
71f3 71f4 71f6 71f7 71fc 71ff 7204 7205
720a 720d 7212 7213 7218 721b 721f 7220
7225 7228 722d 722e 7233 7234 7239 723b
723f 7242 7246 724a 724d 7251 7255 7258
725b 7260 7263 7266 7269 726a 726f 7270
1 7272 7277 727b 727f 7282 7287 728c
728f 7293 7294 7299 729a 729f 72a1 72a5
72a8 72ac 72b0 72b3 72b7 72bb 72be 72c2
72c6 72c7 72cc 72ce 72d2 72d6 72d9 72db
72df 72e2 72e6 72e9 72ea 72ef 72f2 72f6
72fa 72fe 7302 7306 7312 7316 731a 731d
7321 7325 7327 732b 732f 7333 7336 733a
733e 7340 7341 7346 1 734a 734e 7352
7355 7359 735d 7361 7365 7368 736c 7370
7373 7376 737b 737e 7381 7384 7385 738a
738b 1 738d 7392 7396 739a 739d 73a2
73a7 73aa 73ae 73af 73b4 73b7 73bc 73bd
73c2 73c5 73ca 73cb 73d0 73d3 73d7 73d8
73dd 73e0 73e5 73e6 73eb 73ee 73f2 73f6
73f9 73fc 73fd 73ff 7400 7405 7406 740b
740d 7411 7414 7416 741a 741c 7428 742a
742c 742d 7432 7436 7438 7444 7446 744a
744e 7451 7455 7458 745c 745f 7460 7465
7468 746c 7470 7473 7478 7479 747e 7482
7486 748a 748d 7492 7493 7498 749b 74a0
74a1 74a6 74a9 74ad 74ae 74b3 74b6 74bb
74bc 74c1 74c5 74c7 74cb 74cf 74d2 74d6
74da 74dd 74e0 74e5 74e8 74eb 74ee 74ef
74f4 74f5 1 74f7 74fc 7500 7504 7507
750c 7511 7514 7518 7519 751e 7521 7526
7527 752c 752f 7534 7535 753a 753d 7541
7545 7549 754d 7550 7551 7553 7558 7559
755b 755c 7561 7564 7569 756a 756f 7572
7577 7578 757d 7580 7584 7585 758a 758d
7592 7593 7598 7599 759e 75a0 75a4 75a7
75ab 75af 75b2 75b6 75ba 75bd 75c0 75c5
75c8 75cb 75ce 75cf 75d4 75d5 1 75d7
75dc 75e0 75e4 75e7 75ec 75f1 75f4 75f8
75f9 75fe 75ff 7604 7606 760a 760d 7611
7615 7618 761c 7620 7623 7627 762b 762c
7631 7633 7637 763b 763e 7640 7644 7647
764b 764e 764f 7654 7657 765b 765f 7663
7667 766b 7677 767b 767f 7682 7686 768a
768c 7690 7694 7698 769b 769f 76a3 76a5
76a6 76ab 1 76af 76b3 76b7 76ba 76be
76c2 76c6 76ca 76cd 76d1 76d5 76d8 76db
76e0 76e3 76e6 76e9 76ea 76ef 76f0 1
76f2 76f7 76fb 76ff 7702 7707 770c 770f
7713 7714 7719 771c 7721 7722 7727 772a
772f 7730 7735 7738 773c 773d 7742 7745
774a 774b 7750 7753 7757 775b 775e 7761
7762 7764 7765 776a 776b 7770 7772 7776
7779 777b 777f 7781 778d 778f 7791 7792
7797 779b 779d 77a9 77ab 77af 77b3 77b6
77ba 77bd 77c1 77c4 77c5 77ca 77cd 77d1
77d5 77d8 77dd 77de 77e3 77e7 77eb 77ef
77f2 77f7 77f8 77fd 7800 7805 7806 780b
780e 7812 7813 7818 781b 7820 7821 7826
782a 782c 7830 7834 7837 783b 783f 7842
7845 784a 784d 7850 7853 7854 7859 785a
1 785c 7861 7865 7869 786c 7871 7876
7879 787d 787e 7883 7886 788b 788c 7891
7894 7899 789a 789f 78a2 78a6 78aa 78ae
78b2 78b5 78b6 78b8 78bd 78be 78c0 78c1
78c6 78c9 78ce 78cf 78d4 78d7 78dc 78dd
78e2 78e5 78e9 78ea 78ef 78f2 78f7 78f8
78fd 78fe 7903 7905 7909 790c 7910 7914
7917 791b 791f 7922 7925 792a 792d 7930
7933 7934 7939 793a 1 793c 7941 7945
7949 794c 7951 7956 7959 795d 795e 7963
7964 7969 796b 796f 7972 7976 797a 797d
7981 7985 7988 798c 7990 7991 7996 7998
799c 79a0 79a3 79a5 79a9 79ac 79b0 79b4
79b7 79b8 79ba 79bd 79c0 79c1 79c6 79ca
79ce 79d1 79d2 79d4 79d7 79da 79db 1
79e0 79e5 79e9 79ed 79f0 79f5 79f6 79fb
79fe 7a02 7a06 7a0a 7a0d 7a0e 7a10 7a11
7a13 7a14 7a19 7a1c 7a21 7a22 7a27 7a2b
7a2d 7a31 7a34 7a36 7a3a 7a3d 7a41 7a44
7a45 7a4a 7a4d 7a51 7a55 7a59 7a5d 7a5e
7a60 7a63 7a64 7a66 7a6a 7a6e 7a71 7a75
7a79 7a7d 7a81 7a84 7a88 7a89 7a8e 7a90
7a94 7a98 7a9c 7a9f 7aa2 7aa5 7aa9 7aac
7aaf 7ab0 7ab5 7ab9 7aba 7abc 7ac0 7ac4
7ac8 7acc 7ad0 7ad4 7ae0 7ae4 7ae8 7aeb
7aef 7af3 7af5 7af9 7afd 7b01 7b04 7b08
7b0c 7b0e 7b0f 7b14 1 7b18 7b1c 7b20
7b23 7b27 7b2b 7b2f 7b33 7b36 7b3a 7b3e
7b41 7b44 7b49 7b4c 7b4f 7b52 7b53 7b58
7b59 1 7b5b 7b60 7b64 7b68 7b6b 7b70
7b75 7b78 7b7c 7b7d 7b82 7b85 7b8a 7b8b
7b90 7b93 7b98 7b99 7b9e 7ba1 7ba5 7ba6
7bab 7bae 7bb3 7bb4 7bb9 7bbc 7bc0 7bc4
7bc7 7bca 7bcb 7bcd 7bce 7bd3 7bd4 7bd9
7bdb 7bdf 7be2 7be4 7be8 7bea 7bf6 7bf8
7bfa 7bfb 7c00 7c04 7c06 7c12 7c14 7c18
7c1c 7c1f 7c23 7c26 7c2a 7c2d 7c2e 7c33
7c36 7c3a 7c3e 7c41 7c45 7c49 7c4c 7c4f
7c54 7c57 7c5a 7c5d 7c5e 7c63 7c64 1
7c66 7c6b 7c6f 7c73 7c76 7c7b 7c80 7c83
7c87 7c88 7c8d 7c90 7c95 7c96 7c9b 7c9e
7ca3 7ca4 7ca9 7cac 7cb0 7cb4 7cb8 7cbc
7cbf 7cc0 7cc2 7cc7 7cc8 7cca 7ccb 7cd0
7cd3 7cd8 7cd9 7cde 7ce1 7ce6 7ce7 7cec
7cef 7cf3 7cf4 7cf9 7cfc 7d01 7d02 7d07
7d08 7d0d 7d0f 7d13 7d16 7d1a 7d1e 7d21
7d25 7d29 7d2c 7d2f 7d34 7d37 7d3a 7d3d
7d3e 7d43 7d44 1 7d46 7d4b 7d4f 7d53
7d56 7d5b 7d60 7d63 7d67 7d68 7d6d 7d6e
7d73 7d75 7d79 7d7c 7d80 7d84 7d87 7d8b
7d8f 7d92 7d96 7d9a 7d9b 7da0 7da2 7da6
7da9 7dad 7db1 7db4 7db9 7dba 7dbf 7dc2
7dc7 7dc8 7dcd 7dd0 7dd5 7dd6 7ddb 7dde
7de3 7de4 7de9 7dec 7df0 7df1 7df6 7df9
7dfe 7dff 7e04 7e08 7e0c 7e10 7e13 7e14
7e16 7e1a 7e1d 7e21 7e24 7e25 7e2a 7e2e
7e32 7e35 7e3a 7e3b 7e40 7e44 7e46 7e4a
7e4e 7e51 7e56 7e57 7e5c 7e60 7e62 7e66
7e6a 7e6d 7e71 7e75 7e78 7e79 7e7b 7e7f
7e82 7e86 7e89 7e8a 7e8f 7e93 7e99 7e9b
7e9f 7ea2 7ea6 7eaa 7ead 7eb0 7eb1 7eb6
7eba 7ebc 7ec0 7ec7 7ec9 7ecd 7ed0 7ed4
7ed8 7edb 7edc 7ede 7ee2 7ee5 7ee9 7eec
7eed 7ef2 7ef6 7efa 7efe 7f02 7f03 7f05
7f08 7f09 7f0b 7f0f 7f13 7f16 7f1a 7f1e
7f22 7f26 7f29 7f2d 7f2e 7f33 7f35 7f39
7f3d 7f41 7f44 7f47 7f4a 7f4e 7f51 7f54
7f55 7f5a 7f5e 7f5f 7f61 7f65 7f69 7f6d
7f71 7f75 7f79 7f85 7f89 7f8d 7f90 7f94
7f98 7f9a 7f9e 7fa2 7fa6 7fa9 7fad 7fb1
7fb3 7fb4 7fb9 1 7fbd 7fc1 7fc5 7fc8
7fcc 7fd0 7fd4 7fd8 7fdb 7fdf 7fe3 7fe6
7fe9 7fee 7ff1 7ff4 7ff7 7ff8 7ffd 7ffe
1 8000 8005 8009 800d 8010 8015 801a
801d 8021 8022 8027 802a 802f 8030 8035
8038 803d 803e 8043 8046 804a 804b 8050
8053 8058 8059 805e 8061 8065 8069 806c
806f 8070 8072 8073 8078 8079 807e 8080
8084 8087 8089 808d 808f 809b 809d 809f
80a0 80a5 80a9 80ab 80b7 80b9 80bd 80c1
80c4 80c8 80cb 80cf 80d2 80d3 80d8 80db
80df 80e3 80e6 80ea 80ee 80f1 80f4 80f9
80fc 80ff 8102 8103 8108 8109 1 810b
8110 8114 8118 811b 8120 8125 8128 812c
812d 8132 8135 813a 813b 8140 8143 8148
8149 814e 8151 8155 8159 815d 8161 8164
8165 8167 816c 816d 816f 8170 8175 8178
817d 817e 8183 8186 818b 818c 8191 8194
8198 8199 819e 81a1 81a6 81a7 81ac 81ad
81b2 81b4 81b8 81bb 81bf 81c3 81c6 81ca
81ce 81d1 81d4 81d9 81dc 81df 81e2 81e3
81e8 81e9 1 81eb 81f0 81f4 81f8 81fb
8200 8205 8208 820c 820d 8212 8213 8218
821a 821e 8221 8225 8229 822c 8230 8234
8237 823b 823f 8240 8245 8247 824b 824e
8252 8256 8259 825e 825f 8264 8267 826c
826d 8272 8275 827a 827b 8280 8283 8288
8289 828e 8291 8295 8296 829b 829e 82a3
82a4 82a9 82ac 82b1 82b2 82b7 82bb 82bf
82c3 82c6 82c9 82ca 82cf 82d3 82d5 82d9
82e0 82e2 82e6 82e9 82ed 82f1 82f4 82f8
82f9 82fe 8302 8304 8308 830c 830f 8313
8317 831a 831f 8320 8325 8329 832d 8331
8335 8338 833c 8340 8344 8348 834d 8352
8356 835a 835f 8363 8367 836a 836d 8371
8373 8377 837b 837e 8381 8385 8387 838b
838f 8392 8396 839a 839d 83a1 83a4 83a8
83ab 83ac 83b1 83b4 83b8 83be 83c0 83c4
83c7 83cb 83cf 83d2 83d3 83d5 83d8 83db
83dc 83e1 83e5 83e9 83ec 83ed 83ef 83f3
83f6 83fa 83fd 83fe 1 8403 8408 840c
8410 8413 8414 8416 841a 841d 8421 8424
8425 1 842a 842f 8433 8437 843a 843b
843d 8441 8444 8448 844b 844c 8451 8455
8458 8459 845e 1 8461 8466 1 8469
846e 8472 8476 847b 847f 8480 8484 8488
848d 8492 8496 849a 849f 84a3 84a7 84aa
84ad 84b1 84b3 84b7 84bb 84be 84c1 84c5
84c7 84cb 84cf 84d2 84d6 84da 84dd 84e1
84e4 84e8 84eb 84ec 84f1 84f4 84f8 84fc
8501 8503 8507 850b 850e 8512 8516 8518
851c 8520 8524 8527 852b 852f 8531 8532
8537 1 853b 853f 8543 8546 854a 854e
8552 8556 8559 855d 8561 8564 8567 856c
856f 8572 8575 8576 857b 857c 1 857e
8583 8587 858b 858e 8593 8598 859b 859f
85a0 85a5 85a8 85ad 85ae 85b3 85b6 85bb
85bc 85c1 85c4 85c8 85c9 85ce 85d1 85d6
85d7 85dc 85df 85e3 85e7 85ea 85ed 85ee
85f0 85f1 85f6 85f7 85fc 85fe 8602 8605
8607 860b 860d 8619 861b 861d 861e 8623
8627 8629 8635 8637 863b 8641 8643 8647
864b 8650 8652 8656 865a 865d 8661 8665
8667 866b 866f 8673 8676 867a 867e 8680
8681 8686 1 868a 868e 8692 8695 8699
869d 86a1 86a5 86a8 86ac 86b0 86b3 86b6
86bb 86be 86c1 86c4 86c5 86ca 86cb 1
86cd 86d2 86d6 86da 86dd 86e2 86e7 86ea
86ee 86ef 86f4 86f7 86fc 86fd 8702 8705
870a 870b 8710 8713 8717 8718 871d 8720
8725 8726 872b 872e 8732 8736 8739 873c
873d 873f 8740 8745 8746 874b 874d 8751
8754 8756 875a 875c 8768 876a 876c 876d
8772 8776 8778 8784 8786 8788 878c 8790
8793 8795 8799 879c 87a0 87a4 87a8 87ac
87b0 87b4 87b8 87bc 87bf 87c0 87c2 87c5
87c8 87c9 87ce 87d2 87d6 87d9 87dc 87dd
87df 87e2 87e7 87e8 87ed 87f1 87f5 87f6
87fb 87ff 8803 8806 880a 880c 8810 8814
8818 881b 881c 881e 881f 8821 8824 8827
8828 882d 8831 8835 8839 883d 8841 8845
8849 884d 8851 885d 8861 8865 8868 886c
8870 8872 8876 887a 887e 8881 8885 8889
888b 888c 8891 1 8895 8899 889d 88a0
88a4 88a8 88ac 88b0 88b3 88b7 88bb 88be
88c1 88c6 88c9 88cc 88cf 88d0 88d5 88d6
1 88d8 88dd 88e1 88e5 88e8 88ed 88f2
88f5 88f9 88fa 88ff 8902 8907 8908 890d
8910 8915 8916 891b 891e 8922 8923 8928
892b 8930 8931 8936 8939 893d 8941 8944
8947 8948 894a 894b 8950 8951 8956 8958
895c 895f 8961 8965 8967 8973 8975 8977
8978 897d 8981 8983 898f 8991 8995 8999
899c 899d 899f 89a2 89a5 89a6 89ab 89af
89b3 89b8 89ba 89be 89c2 89c5 89c9 89cd
89cf 89d3 89d7 89db 89de 89e2 89e6 89e8
89e9 89ee 1 89f2 89f6 89fa 89fd 8a01
8a05 8a09 8a0d 8a10 8a14 8a18 8a1b 8a1e
8a23 8a26 8a29 8a2c 8a2d 8a32 8a33 1
8a35 8a3a 8a3e 8a42 8a45 8a4a 8a4f 8a52
8a56 8a57 8a5c 8a5f 8a64 8a65 8a6a 8a6d
8a72 8a73 8a78 8a7b 8a7f 8a80 8a85 8a88
8a8d 8a8e 8a93 8a96 8a9a 8a9e 8aa1 8aa4
8aa5 8aa7 8aa8 8aad 8aae 8ab3 8ab5 8ab9
8abc 8abe 8ac2 8ac4 8ad0 8ad2 8ad4 8ad5
8ada 8ade 8ae0 8aec 8aee 8af2 8af6 8af9
8afd 8b01 8b04 8b07 8b0c 8b0f 8b12 8b15
8b16 8b1b 8b1c 1 8b1e 8b23 8b27 8b2b
8b2e 8b33 8b38 8b3b 8b3f 8b40 8b45 8b48
8b4d 8b4e 8b53 8b56 8b5b 8b5c 8b61 8b64
8b68 8b6c 8b70 8b74 8b77 8b78 8b7a 8b7f
8b80 8b82 8b83 8b88 8b8b 8b90 8b91 8b96
8b99 8b9e 8b9f 8ba4 8ba7 8bab 8bac 8bb1
8bb4 8bb9 8bba 8bbf 8bc0 8bc5 8bc7 8bcb
8bce 8bd2 8bd6 8bd9 8bdd 8be1 8be4 8be7
8bec 8bef 8bf2 8bf5 8bf6 8bfb 8bfc 1
8bfe 8c03 8c07 8c0b 8c0e 8c13 8c18 8c1b
8c1f 8c20 8c25 8c26 8c2b 8c2d 8c31 8c34
8c38 8c3c 8c3f 8c43 8c47 8c4a 8c4e 8c52
8c53 8c58 8c5a 8c5e 8c61 8c63 8c67 8c6a
8c6c 8c70 8c74 8c77 8c7b 8c7f 8c83 8c87
8c8b 8c8f 8c93 8c97 8c9b 8c9f 8ca3 8ca7
8cab 8caf 8cb3 8cb7 8cbb 8cbf 8cc3 8cc7
8ccb 8ccf 8cd3 8cd7 8cdb 8cdf 8ce3 8ce7
8ceb 8cef 8cf3 8cf7 8cfa 8cfb 8cfd 8d00
8d03 8d06 8d09 8d0c 8d0d 8d0f 8d13 8d17
8d1a 8d1d 8d1e 8d23 8d27 8d2b 8d30 8d32
8d36 8d3a 8d3d 8d41 8d45 8d47 8d4b 8d4f
8d53 8d56 8d5a 8d5e 8d60 8d61 8d66 1
8d6a 8d6e 8d72 8d75 8d79 8d7d 8d81 8d85
8d88 8d8c 8d90 8d93 8d96 8d9b 8d9e 8da1
8da4 8da5 8daa 8dab 1 8dad 8db2 8db6
8dba 8dbd 8dc2 8dc7 8dca 8dce 8dcf 8dd4
8dd7 8ddc 8ddd 8de2 8de5 8dea 8deb 8df0
8df3 8df7 8df8 8dfd 8e00 8e05 8e06 8e0b
8e0e 8e12 8e16 8e19 8e1c 8e1d 8e1f 8e20
8e25 8e26 8e2b 8e2d 8e31 8e34 8e36 8e3a
8e3c 8e48 8e4a 8e4c 8e4d 8e52 8e56 8e58
8e64 8e66 8e6a 8e6e 8e71 8e75 8e78 8e79
8e7e 8e82 8e86 8e8a 8e8d 8e91 8e93 8e97
8e9a 8e9e 8ea2 8ea5 8ea9 8ead 8eb0 8eb3
8eb8 8ebb 8ebe 8ec1 8ec2 8ec7 8ec8 1
8eca 8ecf 8ed3 8ed7 8eda 8edf 8ee4 8ee7
8eeb 8eec 8ef1 8ef4 8ef9 8efa 8eff 8f02
8f07 8f08 8f0d 8f10 8f14 8f18 8f1c 8f1d
8f1f 8f24 8f25 8f27 8f28 8f2d 8f30 8f35
8f36 8f3b 8f3e 8f43 8f44 8f49 8f4c 8f50
8f51 8f56 8f59 8f5e 8f5f 8f64 8f65 8f6a
8f6c 8f70 8f73 8f77 8f7b 8f7e 8f82 8f86
8f89 8f8c 8f91 8f94 8f97 8f9a 8f9b 8fa0
8fa1 1 8fa3 8fa8 8fac 8fb0 8fb3 8fb8
8fbd 8fc0 8fc4 8fc5 8fca 8fcb 8fd0 8fd2
8fd6 8fd9 8fdd 8fe1 8fe4 8fe8 8fec 8ff0
8ff1 8ff6 8ffa 8ffc 9000 9004 9007 900a
900b 900d 9010 9015 9016 901b 901e 9022
9026 9029 902c 902d 902f 9032 9037 9038
903d 1 9040 9045 9049 904d 9051 9055
9059 9065 9069 906e 9072 9075 9076 907b
907f 9083 9086 9089 908d 908f 9093 9097
909a 909d 90a1 90a3 90a7 90ab 90ae 90b0
90b4 90b8 90bc 90bf 90c3 90c7 90c9 90ca
90cf 1 90d3 90d7 90db 90de 90e2 90e6
90ea 90ee 90f1 90f5 90f9 90fc 90ff 9104
9107 910a 910d 910e 9113 9114 1 9116
911b 911f 9123 9126 912b 9130 9133 9137
9138 913d 9140 9145 9146 914b 914e 9153
9154 9159 915c 9160 9161 9166 9169 916e
916f 9174 9177 917b 917f 9182 9185 9186
9188 9189 918e 918f 9194 9196 919a 919d
919f 91a3 91a5 91b1 91b3 91b5 91b6 91bb
91bf 91c1 91cd 91cf 91d1 91d5 91d9 91dc
91e0 91e6 91e8 91ec 91f0 91f3 91f4 91f6
91fa 91fd 9201 9204 9205 920a 920e 9212
9216 921a 921e 9222 9224 9228 922b 922f
9233 9237 923b 923f 9243 9247 924b 924f
9253 9257 925b 925f 9263 9267 926b 926f
9273 9277 927b 927f 9283 9287 928b 928f
9293 9297 929b 929f 92a3 92a6 92a9 92ac
92af 92b2 92b5 92b6 92b8 92bc 92c0 92c3
92c6 92c7 92cc 92d0 92d4 92d7 92da 92db
92e0 92e4 92e8 92ea 92ee 92f1 92f4 92f5
92fa 92fe 9304 9306 930a 930e 9311 9315
9319 931c 9320 9323 9324 9326 9327 932c
9330 9336 9338 933c 933f 9341 9345 9349
934c 9354 9356 9357 935a 935c 9360 9367
936b 936f 9374 9376 937a 937e 9381 9385
9389 938b 938f 9393 9397 939a 939e 93a2
93a4 93a5 93aa 1 93ae 93b2 93b6 93b9
93bd 93c1 93c5 93c9 93cc 93d0 93d4 93d7
93da 93df 93e2 93e5 93e8 93e9 93ee 93ef
1 93f1 93f6 93fa 93fe 9401 9406 940b
940e 9412 9413 9418 941b 9420 9421 9426
9429 942e 942f 9434 9437 943b 943c 9441
9444 9449 944a 944f 9452 9456 945a 945d
9460 9461 9463 9464 9469 946a 946f 9471
9475 9478 947a 947e 9480 948c 948e 9490
9491 9496 949a 949c 94a8 94aa 94ae 94b2
94b5 94b9 94bc 94bd 94c2 94c5 94c9 94cc
94cf 94d0 94d5 1 94d8 94dd 94e1 94e4
94e7 94e8 94ed 94f1 94f5 94f8 94f9 94fb
94fe 9501 9502 1 9507 950c 1 950f
9514 9518 951c 951f 9523 9527 952a 952d
9532 9535 9538 953b 953c 9541 9542 1
9544 9549 954d 9551 9554 9559 955e 9561
9565 9566 956b 956e 9573 9574 9579 957c
9581 9582 9587 958a 958e 9592 9596 9597
9599 959e 959f 95a1 95a2 95a7 95aa 95af
95b0 95b5 95b8 95bd 95be 95c3 95c6 95ca
95cb 95d0 95d3 95d8 95d9 95de 95df 95e4
95e6 95ea 95ed 95f1 95f5 95f8 95fc 9600
9603 9606 960b 960e 9611 9614 9615 961a
961b 1 961d 9622 9626 962a 962d 9632
9637 963a 963e 963f 9644 9645 964a 964c
9650 9653 9657 965b 965e 9662 9666 966a
966b 9670 9672 9676 9679 967d 9680 9683
9684 9689 968d 9692 9696 969a 969f 96a3
96a7 96ac 96b0 96b4 96b8 96bd 96c1 96c2
96c6 96c9 96cd 96d1 96d5 96d9 96dd 96e1
96e5 96e9 96ed 96f1 96f5 96fa 96ff 9703
9707 970b 9710 9714 9718 971b 971e 9722
9724 9728 972c 972f 9732 9736 9738 973c
9740 9743 9747 974b 974e 9752 9755 9759
975c 975d 9762 9765 9769 976f 9771 9775
9778 977c 977f 9780 9785 9788 978c 9790
9793 9797 979b 979c 979e 97a1 97a4 97a5
1 97aa 97af 97b3 97b7 97bb 97bc 97be
97c1 97c2 97c4 97c7 97ca 97cb 1 97d0
97d5 97d9 97dd 97e1 97e3 97e7 97ea 97ee
97f2 97f5 97f9 97fd 97fe 9800 9803 9806
9807 980c 9810 9813 9816 9817 981c 9820
9824 9828 982c 9830 9834 9838 983c 9840
9844 9848 984c 9850 9854 9858 9864 9868
986d 9871 9874 9875 987a 987e 9882 9885
9888 988c 988e 9892 9896 9899 989c 98a0
98a2 98a6 98aa 98ad 98af 98b3 98b7 98bb
98be 98c2 98c6 98c8 98c9 98ce 1 98d2
98d6 98da 98dd 98e1 98e5 98e9 98ed 98f0
98f4 98f8 98fb 98fe 9903 9906 9909 990c
990d 9912 9913 1 9915 991a 991e 9922
9925 992a 992f 9932 9936 9937 993c 993f
9944 9945 994a 994d 9952 9953 9958 995b
995f 9960 9965 9968 996d 996e 9973 9976
997a 997e 9981 9984 9985 9987 9988 998d
998e 9993 9995 9999 999c 999e 99a2 99a4
99b0 99b2 99b4 99b5 99ba 99be 99c0 99cc
99ce 99d0 99d4 99d7 99db 99e0 99e4 99e8
99ed 99f1 99f5 99fa 99fe 9a02 9a07 9a0b
9a0f 9a14 9a18 9a1c 9a21 9a25 9a29 9a2d
9a31 9a35 9a38 9a3c 9a3e 9a42 9a45 9a49
9a4c 9a4f 9a50 9a55 9a59 9a5c 9a5d 9a62
1 9a65 9a6a 9a6e 9a72 9a76 9a7a 9a7e
9a82 9a86 9a8a 9a8e 9a9a 9a9e 9aa3 9aa7
9aaa 9aab 9ab0 9ab4 9ab8 9abb 9abe 9ac2
9ac4 9ac8 9acc 9acf 9ad2 9ad6 9ad8 9adc
9ae0 9ae3 9ae5 9ae9 9aed 9af1 9af4 9af8
9afc 9afe 9aff 9b04 1 9b08 9b0c 9b10
9b13 9b17 9b1b 9b1f 9b23 9b26 9b2a 9b2e
9b31 9b34 9b39 9b3c 9b3f 9b42 9b43 9b48
9b49 1 9b4b 9b50 9b54 9b58 9b5b 9b60
9b65 9b68 9b6c 9b6d 9b72 9b75 9b7a 9b7b
9b80 9b83 9b88 9b89 9b8e 9b91 9b95 9b96
9b9b 9b9e 9ba3 9ba4 9ba9 9bac 9bb0 9bb4
9bb7 9bba 9bbb 9bbd 9bbe 9bc3 9bc4 9bc9
9bcb 9bcf 9bd2 9bd4 9bd8 9bda 9be6 9be8
9bea 9beb 9bf0 9bf4 9bf6 9c02 9c04 9c06
9c0a 9c0d 9c11 9c14 9c15 9c1a 9c1d 9c21
9c24 9c25 9c2a 9c2d 9c31 9c35 9c39 9c3c
9c41 9c42 9c47 9c4a 9c4d 9c4e 9c50 9c54
9c56 9c5a 9c5d 9c61 9c65 9c69 9c6c 9c70
9c71 9c76 9c79 9c7c 9c7d 9c7f 9c83 9c85
9c89 9c8c 9c90 9c93 9c94 9c99 9c9c 9ca0
9ca4 9ca8 9cab 9caf 9cb0 9cb5 9cb8 9cbb
9cbc 9cbe 9cc2 9cc4 9cc8 9ccb 9ccf 9cd2
9cd3 9cd8 9cdb 9cdf 9ce2 9ce3 9ce8 9ceb
9cef 9cf3 9cf7 9cfa 9cff 9d00 9d05 9d08
9d0b 9d0c 9d0e 9d12 9d14 9d18 9d1b 9d1f
9d23 9d27 9d2a 9d2e 9d2f 9d34 9d37 9d3a
9d3b 9d3d 9d41 9d43 9d47 9d4a 9d4e 9d51
9d52 9d57 9d5a 9d5e 9d62 9d66 9d69 9d6d
9d6e 9d73 9d76 9d79 9d7a 9d7c 9d80 9d82
9d86 9d89 9d8d 9d90 9d91 9d96 9d99 9d9d
9da0 9da1 9da6 9da9 9dad 9db1 9db5 9db8
9dbd 9dbe 9dc3 9dc6 9dc9 9dca 9dcc 9dd0
9dd2 9dd6 9dd9 9ddd 9de1 9de5 9de8 9dec
9ded 9df2 9df5 9df8 9df9 9dfb 9dff 9e01
9e05 9e08 9e0c 9e0f 9e10 9e15 9e18 9e1c
9e1f 9e20 9e25 9e28 9e2c 9e30 9e34 9e37
9e3c 9e3d 9e42 9e45 9e48 9e49 9e4b 9e4f
9e51 9e55 9e58 9e5c 9e60 9e64 9e67 9e6b
9e6c 9e71 9e74 9e77 9e78 9e7a 9e7e 9e80
9e84 9e87 9e8b 9e8f 9e92 9e95 9e96 9e9b
9e9f 9ea3 9ea7 9eab 9ead 9eb1 9eb8 9ebc
9ec0 9ec5 9ec7 9ecb 9ecf 9ed2 9ed6 9eda
9edc 9ee0 9ee4 9ee8 9eeb 9eef 9ef3 9ef5
9ef6 9efb 1 9eff 9f03 9f07 9f0a 9f0e
9f12 9f16 9f1a 9f1d 9f21 9f25 9f28 9f2b
9f30 9f33 9f36 9f39 9f3a 9f3f 9f40 1
9f42 9f47 9f4b 9f4f 9f52 9f57 9f5c 9f5f
9f63 9f64 9f69 9f6c 9f71 9f72 9f77 9f7a
9f7f 9f80 9f85 9f88 9f8c 9f8d 9f92 9f95
9f9a 9f9b 9fa0 9fa3 9fa7 9fab 9fae 9fb1
9fb2 9fb4 9fb5 9fba 9fbb 9fc0 9fc2 9fc6
9fc9 9fcb 9fcf 9fd1 9fdd 9fdf 9fe1 9fe2
9fe7 9feb 9fed 9ff9 9ffb 9fff a002 a005
a006 a00b a00f a013 a017 a01b a01f a023
a027 a02b a02f a033 a037 a03b a03f a043
a047 a053 a057 a05c a060 a063 a064 a069
a06d a071 a074 a077 a07b a07d a081 a085
a088 a08b a08f a091 a095 a099 a09c a09e
a0a2 a0a6 a0aa a0ad a0b1 a0b5 a0b7 a0b8
a0bd 1 a0c1 a0c5 a0c9 a0cc a0d0 a0d4
a0d8 a0dc a0df a0e3 a0e7 a0ea a0ed a0f2
a0f5 a0f8 a0fb a0fc a101 a102 1 a104
a109 a10d a111 a114 a119 a11e a121 a125
a126 a12b a12e a133 a134 a139 a13c a141
a142 a147 a14a a14e a14f a154 a157 a15c
a15d a162 a165 a169 a16d a170 a173 a174
a176 a177 a17c a17d a182 a184 a188 a18b
a18d a191 a193 a19f a1a1 a1a3 a1a4 a1a9
a1ad a1af a1bb a1bd a1bf a1c3 a1c6 a1c8
a1cc a1cf a1d3 a1d6 a1d7 a1dc a1df a1e3
a1e7 a1ea a1eb a1ed a1f0 a1f3 a1f4 a1f9
a1fd a201 a205 a209 a20d a211 a215 a219
a21d a221 a225 a229 a22d a231 a23d a241
a245 a248 a24c a250 a252 a256 a25a a25e
a261 a265 a269 a26b a26c a271 1 a275
a279 a27d a280 a284 a288 a28c a290 a293
a297 a29b a29e a2a1 a2a6 a2a9 a2ac a2af
a2b0 a2b5 a2b6 1 a2b8 a2bd a2c1 a2c5
a2c8 a2cd a2d2 a2d5 a2d9 a2da a2df a2e2
a2e7 a2e8 a2ed a2f0 a2f5 a2f6 a2fb a2fe
a302 a303 a308 a30b a310 a311 a316 a319
a31d a321 a324 a327 a328 a32a a32b a330
a331 a336 a338 a33c a33f a341 a345 a347
a353 a355 a357 a358 a35d a361 a363 a36f
a371 a373 a377 a37a a37e a380 a382 a386
a38a a38d a38f a393 a396 a39a a39e a3a2
a3a6 a3aa a3ae a3b2 a3b6 a3ba a3be a3c2
a3c6 a3ca a3ce a3d2 a3d6 a3da a3de a3e2
a3ee a3f2 a3f6 a3f9 a3fd a401 a403 a407
a40b a40f a412 a416 a41a a41c a41d a422
1 a426 a42a a42e a431 a435 a439 a43d
a441 a444 a448 a44c a44f a452 a457 a45a
a45d a460 a461 a466 a467 1 a469 a46e
a472 a476 a479 a47e a483 a486 a48a a48b
a490 a493 a498 a499 a49e a4a1 a4a6 a4a7
a4ac a4af a4b3 a4b4 a4b9 a4bc a4c1 a4c2
a4c7 a4ca a4ce a4d2 a4d5 a4d8 a4d9 a4db
a4dc a4e1 a4e2 a4e7 a4e9 a4ed a4f0 a4f2
a4f6 a4f8 a504 a506 a508 a509 a50e a512
a514 a520 a522 a526 a52a a52d a52e a530
a534 a537 a53b a53e a53f a544 a548 a54c
a551 a556 a55a a55e a562 a565 a568 a56c
a570 a574 a578 a57c a580 a584 a588 a58c
a590 a594 a598 a5a4 a5a8 a5ad a5b1 a5b4
a5b5 a5ba a5be a5c2 a5c5 a5c8 a5cc a5ce
a5d2 a5d6 a5d9 a5dc a5e0 a5e2 a5e6 a5ea
a5ed a5ef a5f3 a5f7 a5fb a5fe a602 a606
a608 a609 a60e 1 a612 a616 a61a a61d
a621 a625 a629 a62d a630 a634 a638 a63b
a63e a643 a646 a649 a64c a64d a652 a653
1 a655 a65a a65e a662 a665 a66a a66f
a672 a676 a677 a67c a67f a684 a685 a68a
a68d a692 a693 a698 a69b a69f a6a0 a6a5
a6a8 a6ad a6ae a6b3 a6b6 a6ba a6be a6c1
a6c4 a6c5 a6c7 a6c8 a6cd a6ce a6d3 a6d5
a6d9 a6dc a6de a6e2 a6e4 a6f0 a6f2 a6f4
a6f5 a6fa a6fe a700 a70c a70e a712 a716
a719 a71d a720 a724 a727 a728 a72d a730
a734 a738 a73c a740 a744 a748 a74c a750
a754 a758 a75c a760 a764 a768 a76c a770
a774 a778 a784 a788 a78d a791 a794 a795
a79a a79e a7a2 a7a5 a7a8 a7ac a7ae a7b2
a7b6 a7b9 a7bc a7c0 a7c2 a7c6 a7ca a7cd
a7cf a7d3 a7d7 a7db a7de a7e2 a7e6 a7e8
a7e9 a7ee 1 a7f2 a7f6 a7fa a7fd a801
a805 a809 a80d a810 a814 a818 a81b a81e
a823 a826 a829 a82c a82d a832 a833 1
a835 a83a a83e a842 a845 a84a a84f a852
a856 a857 a85c a85f a864 a865 a86a a86d
a872 a873 a878 a87b a87f a880 a885 a888
a88d a88e a893 a896 a89a a89e a8a1 a8a4
a8a5 a8a7 a8a8 a8ad a8ae a8b3 a8b5 a8b9
a8bc a8be a8c2 a8c4 a8d0 a8d2 a8d4 a8d5
a8da a8de a8e0 a8ec a8ee a8f2 a8f6 a8f9
a8fd a900 a904 a907 a908 a90d a910 a914
a918 a91c a920 a924 a928 a934 a938 a93d
a941 a944 a945 a94a a94e a952 a955 a958
a95c a95e a962 a966 a969 a96c a970 a972
a976 a97a a97d a97f a983 a987 a98b a98e
a992 a996 a998 a999 a99e 1 a9a2 a9a6
a9aa a9ad a9b1 a9b5 a9b9 a9bd a9c0 a9c4
a9c8 a9cb a9ce a9d3 a9d6 a9d9 a9dc a9dd
a9e2 a9e3 1 a9e5 a9ea a9ee a9f2 a9f5
a9fa a9ff aa02 aa06 aa07 aa0c aa0f aa14
aa15 aa1a aa1d aa22 aa23 aa28 aa2b aa2f
aa30 aa35 aa38 aa3d aa3e aa43 aa46 aa4a
aa4e aa51 aa54 aa55 aa57 aa58 aa5d aa5e
aa63 aa65 aa69 aa6c aa6e aa72 aa74 aa80
aa82 aa84 aa85 aa8a aa8e aa90 aa9c aa9e
aaa0 aaa4 aaa7 aaa9 aaad aab0 aab4 aab8
aabc aac0 aac4 aac8 aacc aad0 aad4 aad8
aadc aae0 aae4 aae8 aaec aaf0 aaf4 aaf8
aafc ab00 ab04 ab08 ab0c ab10 ab14 ab18
ab1c ab20 ab24 ab28 ab2c ab30 ab34 ab38
ab3c ab40 ab44 ab48 ab4c ab50 ab54 ab58
ab5c ab60 ab64 ab68 ab6c ab70 ab74 ab78
ab7c ab80 ab84 ab88 ab8c ab90 ab94 ab98
ab9c aba0 aba4 aba8 abac abb0 abb4 abb8
abbc abc0 abc4 abc8 abcc abd0 abd4 abd8
abdc abe0 abe4 abe8 abec abf0 abf4 abf8
abfc ac00 ac04 ac08 ac0c ac10 ac14 ac18
ac1c ac20 ac24 ac28 ac2c ac30 ac34 ac38
ac3c ac40 ac44 ac48 ac4c ac50 ac54 ac58
ac5c ac60 ac64 ac68 ac6c ac70 ac74 ac78
ac7c ac80 ac84 ac88 ac8c ac90 ac94 ac98
ac9c aca0 aca4 aca8 acac acb0 acb4 acb8
acbc acc0 acc4 acc8 accc acd0 acd4 acd8
acdc ace0 ace4 ace8 acec acf0 acf4 acf8
acfc ad00 ad04 ad08 ad0c ad10 ad14 ad18
ad1c ad20 ad24 ad28 ad2c ad30 ad34 ad38
ad3c ad40 ad44 ad48 ad4c ad50 ad54 ad58
ad5c ad60 ad64 ad68 ad6c ad70 ad74 ad78
ad7c ad80 ad84 ad88 ad8c ad90 ad94 ad98
ad9c ada0 ada4 ada8 adac adb0 adb4 adb8
adbc adc0 adc4 adc8 adcc add0 add4 add8
addc ade0 ade4 ade8 adec adf0 adf4 ae00
ae05 ae09 ae0d ae11 ae14 ae18 ae1c ae1f
ae22 ae27 ae2a ae2d ae30 ae31 ae36 ae37
1 ae39 ae3e ae42 ae46 ae49 ae4e ae53
ae56 ae5a ae5b ae60 ae61 ae66 ae68 ae6c
ae6f ae73 ae77 ae7b ae7d ae81 ae84 ae87
ae88 ae8d ae91 ae95 ae99 ae9d aea1 aea5
aea9 aead aeb1 aeb5 aeb9 aebd aec1 aec5
aec9 aecd aed1 aed5 aed9 aedd aee1 aee5
aee9 aeed aef1 aef5 aef9 aefd af01 af05
af09 af0d af11 af15 af19 af1d af21 af25
af29 af2d af31 af35 af39 af3d af41 af45
af49 af4d af51 af55 af59 af5d af61 af65
af69 af6d af71 af75 af79 af7d af81 af85
af89 af8d af91 af95 af99 af9d afa1 afa5
afa9 afad afb1 afb5 afb9 afbd afc1 afc5
afc9 afcd afd1 afd5 afd9 afdd afe1 afe5
afe9 afed aff1 aff5 aff9 affd b001 b005
b009 b00d b011 b015 b019 b01d b021 b025
b029 b02d b031 b035 b039 b03d b041 b045
b049 b04d b051 b055 b059 b05d b061 b065
b069 b06d b071 b075 b079 b07d b081 b085
b089 b08d b091 b095 b099 b09d b0a1 b0a5
b0a9 b0ad b0b1 b0b5 b0b9 b0bd b0c1 b0c5
b0c9 b0cd b0d1 b0d5 b0d9 b0dd b0e1 b0e5
b0e9 b0ed b0f1 b0f5 b0f9 b0fd b101 b105
b109 b10d b111 b115 b119 b11d b121 b125
b129 b12d b131 b135 b139 b13d b141 b145
b149 b14d b151 b155 b159 b15d b161 b165
b169 b16d b171 b175 b179 b17d b181 b185
b189 b18d b191 b195 b199 b19d b1a1 b1a5
b1a9 b1ad b1b1 b1b5 b1b9 b1bd b1c1 b1c5
b1c9 b1cd b1d1 b1d5 b1d9 b1dd b1e1 b1e5
b1e9 b1ed b1f1 b1f5 b1f9 b1fd b201 b205
b209 b20d b211 b215 b219 b21d b221 b225
b229 b22d b231 b235 b239 b23d b241 b245
b249 b24d b251 b255 b259 b25d b261 b265
b269 b26d b271 b275 b279 b27d b281 b285
b289 b28d b291 b295 b299 b29d b2a1 b2a5
b2a9 b2ad b2b1 b2b5 b2b9 b2bd b2c1 b2c5
b2c9 b2cd b2d1 b2d5 b2d9 b2dd b2e1 b2e5
b2e9 b2ed b2f1 b2f5 b2f9 b2fd b301 b305
b309 b30d b311 b315 b319 b31d b321 b325
b329 b32d b331 b335 b339 b33d b341 b345
b349 b34d b351 b355 b359 b35d b361 b365
b369 b36d b379 b37e b382 b386 b38a b38d
b391 b395 b398 b39b b3a0 b3a3 b3a6 b3a9
b3aa b3af b3b0 1 b3b2 b3b7 b3bb b3bf
b3c2 b3c7 b3cc b3cf b3d3 b3d4 b3d9 b3da
b3df b3e1 b3e5 b3e8 b3ec b3f0 b3f4 b3f6
b3fa b3fe b403 b408 b40c b410 b414 b417
b41a b41e b422 b426 b42a b42e b432 b436
b43a b43e b44a b44e b453 b457 b45a b45b
b460 b464 b468 b46b b46e b472 b474 b478
b47c b47f b482 b486 b488 b48c b490 b493
b495 b499 b49d b4a1 b4a4 b4a8 b4ac b4ae
b4af b4b4 1 b4b8 b4bc b4c0 b4c3 b4c7
b4cb b4cf b4d3 b4d6 b4da b4de b4e1 b4e4
b4e9 b4ec b4ef b4f2 b4f3 b4f8 b4f9 1
b4fb b500 b504 b508 b50b b510 b515 b518
b51c b51d b522 b525 b52a b52b b530 b533
b538 b539 b53e b541 b545 b546 b54b b54e
b553 b554 b559 b55c b560 b564 b567 b56a
b56b b56d b56e b573 b574 b579 b57b b57f
b582 b584 b588 b58a b596 b598 b59a b59b
b5a0 b5a4 b5a6 b5b2 b5b4 b5b8 b5bc b5c0
b5c4 b5c8 b5cc b5d0 b5d4 b5d8 b5dc b5e0
b5e4 b5e8 b5ec b5f0 b5f4 b5f8 b5fc b600
b604 b608 b614 b618 b61d b621 b624 b625
b62a b62e b632 b635 b638 b63c b63e b642
b646 b649 b64c b650 b652 b656 b65a b65d
b65f b663 b667 b66b b66e b672 b676 b678
b679 b67e 1 b682 b686 b68a b68d b691
b695 b699 b69d b6a0 b6a4 b6a8 b6ab b6ae
b6b3 b6b6 b6b9 b6bc b6bd b6c2 b6c3 1
b6c5 b6ca b6ce b6d2 b6d5 b6da b6df b6e2
b6e6 b6e7 b6ec b6ef b6f4 b6f5 b6fa b6fd
b702 b703 b708 b70b b70f b710 b715 b718
b71d b71e b723 b726 b72a b72e b731 b734
b735 b737 b738 b73d b73e b743 b745 b749
b74c b74e b752 b754 b760 b762 b764 b765
b76a b76e b770 b77c b77e b782 b786 b78a
b78e b792 b796 b79a b79e b7a2 b7a6 b7aa
b7ae b7b2 b7b6 b7ba b7be b7c2 b7c6 b7ca
b7ce b7d2 b7d6 b7da b7de b7e2 b7e6 b7ea
b7ee b7f2 b7f6 b7fa b7fe b802 b806 b80a
b80e b812 b816 b81a b81e b822 b826 b82a
b82e b832 b836 b83a b83e b842 b846 b84a
b84e b852 b856 b85a b85e b862 b866 b86a
b86e b872 b876 b87a b87e b882 b886 b88a
b88e b892 b896 b89a b89e b8a2 b8a6 b8aa
b8ae b8b2 b8b6 b8ba b8be b8c2 b8c6 b8ca
b8ce b8d2 b8d6 b8da b8de b8e2 b8e6 b8ea
b8ee b8f2 b8f6 b8fa b8fe b902 b906 b90a
b90e b912 b916 b91a b91e b922 b926 b92a
b92e b932 b936 b93a b93e b942 b946 b94a
b94e b952 b956 b95a b95e b962 b966 b96a
b96e b972 b976 b97a b97e b982 b986 b98a
b98e b992 b996 b99a b99e b9a2 b9a6 b9aa
b9ae b9b2 b9b6 b9ba b9be b9c2 b9c6 b9ca
b9ce b9d2 b9d6 b9da b9de b9e2 b9e6 b9ea
b9ee b9f2 b9f6 b9fa b9fe ba02 ba06 ba0a
ba0e ba12 ba16 ba1a ba1e ba22 ba26 ba2a
ba2e ba32 ba36 ba3a ba3e ba42 ba46 ba4a
ba4e ba52 ba56 ba5a ba5e ba62 ba66 ba6a
ba6e ba72 ba76 ba7a ba7e ba82 ba86 ba8a
ba8e ba92 ba96 ba9a ba9e baa2 baa6 baaa
baae bab2 bab6 baba babe bac2 bac6 baca
bace bad2 bad6 bada bade bae2 bae6 baea
baee baf2 baf6 bafa bafe bb02 bb06 bb0a
bb0e bb12 bb16 bb1a bb1e bb22 bb26 bb2a
bb2e bb32 bb36 bb3a bb3e bb42 bb46 bb4a
bb4e bb52 bb56 bb5a bb5e bb62 bb66 bb6a
bb6e bb72 bb76 bb7a bb7e bb82 bb86 bb8a
bb8e bb92 bb96 bb9a bb9e bba2 bba6 bbaa
bbae bbb2 bbb6 bbba bbbe bbc2 bbc6 bbca
bbce bbd2 bbd6 bbda bbde bbe2 bbe6 bbea
bbee bbf2 bbf6 bbfa bbfe bc02 bc06 bc0a
bc0e bc12 bc16 bc1a bc1e bc22 bc26 bc2a
bc2e bc32 bc36 bc3a bc3e bc42 bc46 bc4a
bc4e bc52 bc56 bc5a bc5e bc62 bc66 bc6a
bc6e bc72 bc76 bc7a bc7e bc82 bc86 bc8a
bc8e bc92 bc96 bc9a bc9e bca2 bca6 bcaa
bcae bcb2 bcb6 bcba bcbe bcc2 bcc6 bcca
bcce bcd2 bcd6 bcda bcde bce2 bce6 bcea
bcee bcf2 bcf6 bcfa bcfe bd02 bd06 bd0a
bd0e bd12 bd16 bd1a bd1e bd22 bd26 bd2a
bd2e bd32 bd36 bd3a bd3e bd42 bd46 bd4a
bd4e bd52 bd56 bd5a bd5e bd62 bd66 bd6a
bd6e bd72 bd76 bd7a bd7e bd82 bd86 bd8a
bd8e bd92 bd96 bd9a bd9e bda2 bda6 bdaa
bdae bdb2 bdb6 bdba bdbe bdc2 bdc6 bdca
bdce bdd2 bdd6 bdda bdde bde2 bde6 bdea
bdee bdf2 bdf6 bdfa bdfe be02 be06 be0a
be0e be12 be16 be1a be1e be22 be26 be2a
be2e be32 be36 be3a be3e be42 be46 be4a
be4e be52 be56 be5a be5e be62 be66 be6a
be6e be72 be76 be7a be7e be82 be86 be92
be97 be9b be9f bea3 bea6 beaa beae beb1
beb4 beb9 bebc bebf bec2 bec3 bec8 bec9
1 becb bed0 bed4 bed8 bedb bee0 bee5
bee8 beec beed bef2 bef3 bef8 befa befe
bf01 bf05 bf09 bf0d bf0f bf13 bf17 bf1a
bf1c bf20 bf24 bf27 bf29 bf2d bf31 bf34
bf38 bf3c bf3f bf43 bf47 bf4a bf4d bf52
bf55 bf58 bf5b bf5c bf61 bf62 1 bf64
bf69 bf6d bf71 bf74 bf79 bf7e bf81 bf85
bf86 bf8b bf8c bf91 bf95 bf99 bf9c bfa1
bfa6 bfa9 bfad bfb1 bfb4 bfb5 bfba bfbd
bfc2 bfc3 bfc8 bfcb bfcf bfd3 bfd6 bfd7
bfdc bfdd bfe2 bfe4 bfe8 bfeb bfef bff3
bff7 bffb bfff c003 c007 c00b c00f c01b
c020 c024 c028 c02c c030 c032 c033 c038
1 c03c c040 c044 c047 c04b c04f c053
c057 c05a c05e c062 c065 c068 c06d c070
c073 c076 c077 c07c c07d 1 c07f c084
c088 c08c c08f c094 c099 c09c c0a0 c0a1
c0a6 c0a7 c0ac c0b0 c0b4 c0b7 c0bc c0c1
c0c4 c0c8 c0c9 c0ce c0d1 c0d6 c0d7 c0dc
c0df c0e3 c0e7 c0ea c0ed c0ee c0f0 c0f1
c0f6 c0f7 c0fc c0fe c102 c105 c109 c10d
c111 c115 c119 c11d c121 c12d c132 c136
c13a c13e c142 c144 c148 c14a c156 c158
c15a c15b c160 c164 c166 c172 c176 c178
c179 c182 
3732
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 c :3 6 e :3 6 10 :3 6
10 :3 6 11 :3 6 17 :3 6 10 :3 6
11 :3 6 10 :3 6 11 :3 6 f :3 6
f :3 6 10 :3 6 d :3 6 e :3 6
12 :2 6 1 3 a 13 a :2 1
4 d 16 15 :2 d :2 4 11 1a
19 :2 11 :2 4 e 17 16 :2 e :2 4
c 15 14 :2 c :2 4 f 18 17
:2 f :2 4 f 18 17 :2 f :2 4 c
15 14 :2 c :2 4 b 14 13 :2 b
:2 4 10 19 18 :2 10 :2 4 11 1a
19 :2 11 :2 4 10 19 18 :2 10 :2 4
11 1a 19 :2 11 :2 4 f 18 17
:2 f :2 4 10 19 18 :2 10 :2 4 f
18 17 :2 f :2 4 10 19 18 :2 10
:2 4 11 1a 19 :2 11 :2 4 11 1a
19 :2 11 :2 4 d 16 15 :2 d :2 4
e 17 16 :2 e :2 4 b 14 13
:2 b :2 4 :3 10 :2 4 11 1a 19 :2 11
:2 4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 14 1d 1c :2 14 :2 4
15 1e 1d :2 15 :2 4 :3 e :2 4 f
18 17 :2 f :2 4 10 19 18 :2 10
:2 4 e 17 16 :2 e :2 4 f 18
17 :2 f :2 4 10 19 18 :2 10 :2 4
11 1a 19 :2 11 :2 4 :2 e 1d e
:2 4 :2 d 1c d :2 4 :2 b 1a b
:2 4 :2 c 1b c :2 4 :2 d 1c d
:2 4 :2 10 1f 10 :2 4 :2 14 23 14
:2 4 :2 a 19 a :2 4 :2 f 1e f
:2 4 :2 b 1a b :2 4 :2 11 20 11
:2 4 :2 d 1c d :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 c 1b c
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 f 1e f :2 4 :2 12 21 12
:2 4 :2 d 1c d :2 4 :2 f 1e f
:2 4 :2 b 1a b :2 4 :2 f 19 f
:2 4 :2 13 1d 13 :2 4 :2 c 1b c
:2 4 :2 10 1f 10 :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 16 25 16
:2 4 :2 16 25 16 :2 4 :2 b 1a b
:2 4 d 16 15 :2 d :2 4 :2 10 1f
10 :2 4 :2 11 20 11 :2 4 :2 12 21
12 :2 4 9 12 11 :2 9 :2 4 c
15 14 :2 c :2 4 10 19 18 :2 10
:2 4 :2 11 20 11 :2 4 :2 17 26 17
:2 4 17 1c 1b :2 17 :2 4 18 1d
1c :2 18 :2 4 11 1a 19 :2 11 :2 4
12 1b 1a :2 12 :2 4 16 1f 1e
:2 16 :2 4 b 14 13 :2 b :2 4 :2 f
1e f :2 4 :2 13 22 13 :2 4 :2 14
23 14 :2 4 :2 6 1e 6 :2 4 :2 7
1f 7 :2 4 :2 a 22 a :2 4 :2 d
25 d :2 4 :2 8 20 8 :2 4 a
13 12 :2 a :2 4 :2 e 26 e :2 4
:3 d :2 4 :3 13 :2 4 :3 8 :2 4 :3 6 :2 4
:3 9 :2 4 :3 c :2 4 :3 c 4 7 b
14 :3 b :2 7 e 0 :2 7 11 f
10 1d e 18 e 1c a :6 7
e 0 :2 7 a :2 c 12 c 15
c 12 c 15 c 15 c 15
f 13 fffa :6 7 e 17 :3 e :2 7
e 17 :3 e :2 7 e 17 :3 e 7
4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 53 59 5c :2 53 6a 7f
8 :2 6a d 10 :2 6a 17 1a :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 2c 2f :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 2d 30 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
33 :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 31 :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 34 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 2f :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 2e :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 34
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 34 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 40 :2 16 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 24 27 :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 26 29 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 28 2b :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 28 2b :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 29 2c :2 6a b e :2 6a 13
16 1f 27 :2 1f 3a :2 16 :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
28 2b :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 29 2c :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
28 2b :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 29 2c :2 6a b
e :2 6a 13 16 1f 27 :2 1f 32
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 32 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 33 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
30 :2 16 :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 26 29 :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
2a 2d :2 6a 32 35 :2 6a :2 7 49
:2 4 7 :2 11 23 :2 2d 39 3c 4b
4e 4f :2 4b :2 23 :3 7 :2 d 12 1e
5b 5e :2 1e :2 7 52 :3 4 14 :2 4
14 :2 4 13 :2 4 f :2 4 e :2 4
13 :2 4 14 :2 4 13 :2 4 14 :2 4
12 :2 4 10 :2 4 e :2 4 14 :2 4
12 :2 4 f :2 4 12 :2 4 e :2 4
e :2 4 11 :2 4 11 :2 4 10 :2 4
13 :2 4 13 :2 4 14 4 8 11
1c :2 8 22 1f :2 2b :2 1f 7 :4 46
45 44 :2 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 6e 71 :2 21
75 78 :2 21 82 85 8e 96 :2 9f
:2 8e b5 :2 85 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 46
:2 7 57 :2 4 :4 9 8 7 :4 1f 1e
1d :2 7 :4 39 38 37 :2 7 :4 53 52
51 :2 7 f 18 24 :2 f 2a 27
:2 33 :2 27 e :2 7 :4 c b a 25
2e 3a :2 25 3f 3d :2 48 :2 3d 24
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
61 64 :2 24 71 74 :2 24 78 7b
:2 24 85 88 91 99 :2 a2 :2 91 b3
:2 88 :2 24 :2 d 58 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 61 64 :2 24 :2 d
58 :3 a :2 15 2b :2 34 44 :2 a 7
59 :4 f e d :4 29 28 27 :3 d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 61 64
:2 24 71 74 :2 24 78 7b :2 24 85
88 91 99 :2 a2 :2 91 b3 :2 88 :2 24
:2 d 58 :2 a d :2 17 29 :2 33 3f
42 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 61 64 :2 24 :2 d 58 :3 a
:2 15 2b :2 34 44 :2 a 3e 59 :2 7
49 :2 4 7 10 1b :2 7 1e 20
:2 1e 26 2f 37 :2 26 3a 3c :2 3a
:2 7 42 4b 53 :2 42 56 58 :2 56
:2 7 a :2 14 26 :2 30 3c 3f 4e
51 52 :2 4e :2 26 :3 a :2 10 15 21
5e 61 :2 21 6e 71 :2 21 75 78
:2 21 82 85 8e 96 :2 9f :2 8e b0
:2 85 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4e 51 52 :2 4e :2 26
:3 a :2 10 15 21 5e 61 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 41 :2 7 5a
:2 4 :4 9 8 :2 7 1a 7 24 7
1a 7 :4 4 8 11 1c :2 8 22
1f :2 2b :2 1f 7 :4 46 45 44 :2 7
:4 14 13 12 :2 7 11 1c 21 33
3e 43 :2 f :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 8a 8d :2 27 95
98 :2 27 a4 a7 ae b7 ba :2 a7
:2 27 :2 10 5c :2 d :2 a :4 16 :2 a 7
:3 31 b :2 14 1f 1d :2 28 :2 1d a
3d 46 4f :2 3d 52 54 :2 52 3c
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
61 64 :2 24 71 74 :2 24 78 7b
:2 24 85 88 91 99 :2 a2 :2 91 bf
:2 88 :2 24 :2 d 58 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 61 64 :2 24 :2 d
58 :3 a :2 15 2b :2 34 50 :2 a 57
:3 7 e 7 31 :2 4 :4 9 8 7
:4 27 26 25 :2 7 11 23 35 :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 74 77 :2 27 7b 7e :2 27
8a 8d :2 27 95 98 :2 27 a4 a7
ae b7 ba :2 a7 :2 27 :2 10 5c :2 d
:2 a :4 16 :2 a 7 :4 40 :3 4 12 :2 4
13 :2 1c 28 2f 38 40 :2 2f 44
:2 4d :2 28 27 5c :2 13 :2 4 e 15
1e 26 :2 15 2a :2 33 :2 e :2 4 d
:2 16 22 29 32 3e :2 29 42 :2 4b
:2 22 21 5a :2 d :2 4 12 19 22
2e :2 19 32 :2 3b :2 12 4 7 10
1c :2 7 21 1f :2 2a :2 1f 7 15
7 4 37 a 13 1f :2 a 24
22 :2 2d :2 22 7 15 7 39 37
a 13 1f :2 a 24 22 :2 2d :2 22
a 18 a 3d a 18 a :4 7
:4 4 7 10 18 :2 7 1b 1d :2 1b
7 15 7 11 21 f 10 1d
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
64 67 :2 27 74 77 :2 27 7b 7e
:2 27 8a 8d :2 27 95 98 :2 27 a4
a7 ae b7 ba :2 a7 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 1f a 13
1f :2 a 22 24 :2 22 14 24 12
13 20 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 67 6a :2 2a 77 7a :2 2a
7e 81 :2 2a 8d 90 :2 2a 98 9b
:2 2a a7 aa b1 ba bd :2 aa :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 26
d :2 18 1f 2d :2 d 32 34 :2 32
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 74 77 :2 27 7b 7e :2 27
88 8b 94 9c :2 a5 :2 94 ba :2 8b
:2 27 c2 c5 :2 27 cd d0 :2 27 d5
d8 :2 27 e5 e8 :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 :2 10 5b :3 d :2 18 2c :2 35
49 57 :2 d 36 :2 a 26 :3 7 17
20 29 31 :2 20 :2 17 7 a 13
21 :2 a 24 26 :2 24 a 14 20
29 31 :2 20 :2 14 a d 16 1e
:2 d 21 23 :2 21 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 88 8b 94 9c
:2 a5 :2 94 b6 :2 8b :2 27 :2 10 5b :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 64
67 :2 27 :2 10 5b :3 d :2 18 2e :2 37
47 :2 d 25 :3 a 1a :2 23 a 28
:3 7 14 7 a 13 20 :2 a 23
26 :2 23 a 16 a 28 d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 61 64 :2 24
71 74 :2 24 78 7b :2 24 85 88
91 99 :2 a2 :2 91 b3 :2 88 :2 24 :2 d
58 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 61 64 :2 24 :2 d 58 :3 a :2 15
2b :2 34 44 :2 a :5 7 1a 29 37
3f 4a 54 25 :2 1a 7 a 13
1e :2 a 23 21 :2 2c :2 21 d 16
27 :2 d 2a 2c :2 2a d 20 :2 29
d 2e :2 a d :2 17 29 :2 33 3f
43 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 61 64 :2 24 71 74 :2 24
78 7b :2 24 85 88 91 99 :2 91
ab :2 88 :2 24 b3 b6 :2 24 be c1
:2 24 c6 c9 :2 24 d5 d8 :2 24 :2 d
59 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 61 64 :2 24 :2 d 58 :3 a :2 15
29 32 43 :2 29 47 54 :2 a 40
:2 7 a 13 24 :2 a 27 2a :2 27
30 39 4a :2 30 4d 50 :2 4d :2 a
d :2 17 29 :2 33 3f 43 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 61
64 :2 24 71 74 :2 24 78 7b :2 24
85 88 91 99 :2 91 ab :2 88 :2 24
b3 b6 :2 24 be c1 :2 24 c6 c9
:2 24 d5 d8 :2 24 :2 d 59 :2 a d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 61 64
:2 24 :2 d 58 :3 a :2 15 29 32 43
:2 29 47 54 :2 a 52 :2 7 a 13
21 :2 a 26 24 :2 2f :2 24 d 1b
24 2c :2 1b :2 d 30 33 :2 30 10
12 1b 12 1b 12 10 :3 12 15
16 23 fffa 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5e 5f :2 5b :2 32 :3 16
:2 1c 21 2d 6a 6d :2 2d 7a 7d
:2 2d 81 84 :2 2d 90 93 :2 2d 9b
9e :2 2d aa ad b4 bd c0 :2 ad
:2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10 d
:4 35 10 :2 12 14 12 14 12 14
12 1b 1d 12 1b 1d 12 14
12 14 25 27 10 :7 12 15 1d
20 28 16 18 25 14 16 23
25 fffa 10 :2 19 25 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5e 5f :2 5b :2 32 :3 16 :2 1c
21 2d 6a 6d :2 2d 7a 7d :2 2d
81 84 :2 2d 90 93 :2 2d 9b 9e
:2 2d aa ad b4 bd c0 :2 ad :2 2d
:2 16 62 :2 13 :2 10 :4 1c :2 10 d :7 a
e :2 17 23 20 :2 2c :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 64 67
:2 27 74 77 :2 27 7b 7e :2 27 88
8b 94 9c :2 a5 :2 94 b8 :2 8b :2 27
c0 c3 :2 27 cb ce :2 27 d3 d6
:2 27 e0 e3 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 64 67
:2 27 :2 10 5b :3 d :2 18 2c :2 35 47
52 :2 d 3c :2 a 7 3c d 16
24 :2 d 29 27 :2 32 :2 27 d :2 f
d :2 f 12 13 20 fffa d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 67 6a
:2 2a 77 7a :2 2a 7e 81 :2 2a 8d
90 :2 2a 98 9b :2 2a a7 aa b1
ba bd :2 aa :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 3f e :2 17 23 20
:2 2c :2 20 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 74 77 :2 27
7b 7e :2 27 88 8b 94 9c :2 a5
:2 94 b8 :2 8b :2 27 c0 c3 :2 27 cb
ce :2 27 d3 d6 :2 27 e0 e3 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 47 52 :2 d 3c :2 a
12 1d :2 12 1f f 18 f 18
f d :3 f 12 13 20 11 1e
fffa d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a 77 7a :2 2a 7e
81 :2 2a 8d 90 :2 2a 98 9b :2 2a
a7 aa b1 ba bd :2 aa :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 3f e
:2 17 23 20 :2 2c :2 20 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
74 77 :2 27 7b 7e :2 27 88 8b
94 9c :2 a5 :2 94 b8 :2 8b :2 27 c0
c3 :2 27 cb ce :2 27 d3 d6 :2 27
e3 e6 :2 27 :2 10 5c :2 d 10 :2 1a
2c :2 36 42 45 54 57 58 :2 54
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
:2 10 5b :3 d :2 18 2c :2 35 47 55
:2 d 3c :2 a :4 e :2 d 1d :2 26 :2 d
17 26 :2 17 d 24 :2 a 3f 3c
d :2 17 29 :2 33 3f 43 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 61
64 :2 24 71 74 :2 24 78 7b :2 24
85 88 91 99 :2 a2 :2 91 b3 :2 88
:2 24 bb be :2 24 c6 c9 :2 24 ce
d1 :2 24 de e1 :2 24 :2 d 59 :2 a
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 61
64 :2 24 :2 d 58 :3 a :2 15 29 :2 32
42 50 :2 a :4 7 a 13 1f :2 a
25 22 :2 2e :2 22 d f 1a 25
:3 f 18 23 2e f 18 23 2e
d :5 f 12 13 21 fffa d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 67 6a
:2 2a 77 7a :2 2a 7e 81 :2 2a 8d
90 :2 2a 98 9b :2 2a a7 aa b1
ba bd :2 aa :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 3e e :2 17 22 20
:2 2b :2 20 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 74 77 :2 27
7b 7e :2 27 88 8b 94 9c :2 a5
:2 94 b8 :2 8b :2 27 c0 c3 :2 27 cb
ce :2 27 d3 d6 :2 27 df e2 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 47 51 :2 d a 3b
11 :2 1a 25 23 :2 2e :2 23 :2 10 17
21 24 :2 10 27 29 :2 27 31 3a
4d :2 31 50 52 :2 50 58 13 21
:2 58 26 24 2f 42 :2 26 :2 24 :2 31
30 :2 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a 77 7a :2 2a 7e
81 :2 2a 8b 8e 97 9f :2 a8 :2 97
be :2 8e :2 2a c6 c9 :2 2a d1 d4
:2 2a d9 dc :2 2a e5 e8 :2 2a :2 13
5f :2 10 13 :2 1d 2f :2 39 45 48
57 5a 5b :2 57 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a :2 13 5e :3 10 :2 1b
2f :2 38 4d 57 :2 10 46 :2 d 10
19 27 :2 10 2c 2a 35 48 :2 2c
:2 2a 1a 25 32 3a 41 55 60
77 18 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5e 61 62 :2 5e :2 35 :3 19 :2 1f
24 30 6d 70 :2 30 7d 80 :2 30
84 87 :2 30 93 96 :2 30 9e a1
:2 30 ad b0 b7 c0 c3 :2 b0 :2 30
:2 19 65 :2 16 :2 13 :4 1f :2 13 10 :4 4b
:2 d 3e 3b :2 a 3e :2 7 1f :2 4
7 10 18 :2 7 1b 1d :2 1b a
13 1f :2 a 24 22 :2 2d :2 22 :4 42
41 :2 a 59 d 1a :2 59 1d 1f
:2 1d :2 a d :2 17 29 :2 33 3f 43
52 55 56 :2 52 :2 29 :3 d :2 13 18
24 61 64 :2 24 71 74 :2 24 78
7b :2 24 85 88 91 99 :2 a2 :2 91
bd :2 88 :2 24 c5 c8 :2 24 d0 d3
:2 24 d8 db :2 24 e8 eb :2 24 :2 d
59 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 61 64 :2 24 :2 d 58 :3 a :2 15
29 :2 32 4c 12 :2 a 21 :2 7 a
13 1e :2 a 24 21 :2 2d :2 21 d
f 18 f 18 d :2 f 12 13
20 fffa d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 67 6a :2 2a 77 7a :2 2a
7e 81 :2 2a 8d 90 :2 2a 98 9b
:2 2a a7 aa b1 ba bd :2 aa :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 41
e :2 17 22 20 :2 2b :2 20 d 10
12 15 25 32 fffa 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5e 5f :2 5b
:2 32 :3 16 :2 1c 21 2d 6a 6d :2 2d
7a 7d :2 2d 81 84 :2 2d 90 93
:2 2d 9b 9e :2 2d aa ad b4 bd
c0 :2 ad :2 2d :2 16 62 :2 13 :2 10 :4 1c
:2 10 d :3 3b 11 :2 1a 25 23 :2 2e
:2 23 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a 77 7a :2 2a 7e
81 :2 2a 8b 8e 97 9f :2 a8 :2 97
b9 :2 8e :2 2a c1 c4 :2 2a cc cf
:2 2a d4 d7 :2 2a e4 e7 :2 2a :2 13
5f :2 10 13 :2 1d 2f :2 39 45 48
57 5a 5b :2 57 :2 2f :3 13 :2 19 1e
2a 67 6a :2 2a :2 13 5e :3 10 :2 1b
2f :2 38 48 56 :2 10 3e :2 d 3b
:2 a 41 :2 7 1f :2 4 7 10 1c
:2 7 1f 21 :2 1f 27 30 38 :2 27
3b 3e :2 3b :3 7 11 7 42 :2 4
7 10 1b :2 7 20 1e :2 29 :2 1e
:4 b :2 a 18 :2 a 19 a 22 a
18 :2 a 19 a :5 7 13 7 3d
a e 10 :2 e a 19 :2 a 18
29 35 42 4b 54 :2 42 58 61
69 :2 58 22 2b 37 :2 22 3b 44
4f :2 3b 53 20 2b :2 53 2f 38
46 :2 2f 4a 53 5e :2 4a 22 2b
37 :2 22 3b 43 4d :2 18 a d
16 22 :2 d 27 25 :2 30 :2 25 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 64 67
:2 27 74 77 :2 27 7b 7e :2 27 88
8b 94 9c :2 a5 :2 94 b6 :2 8b :2 27
:2 10 5b :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 64 67 :2 27 :2 10 5b :3 d
:2 18 2e :2 37 47 :2 d a 3f 10
19 25 :2 10 28 2b :2 28 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
74 77 :2 27 7b 7e :2 27 88 8b
94 9c :2 94 a9 :2 8b :2 27 b1 b4
:2 27 bc bf :2 27 c4 c7 :2 27 d4
d7 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 64 67 :2 27 :2 10
5b :3 d :2 18 2c 35 41 :2 2c 45
53 :2 d 2d 3f :2 a 12 a 19
a d 16 1e :2 d 21 23 :2 21
d 17 20 28 :2 17 2b 2d 36
42 :2 2d :2 17 d 25 :2 a :4 7 b
14 1c :2 b 1f 21 :2 1f a 29
32 3a :2 29 3d 40 :2 3d 28 :2 a
e 17 1f :2 e 22 24 :2 22 d
2b 34 3c :2 2b 3f 41 :2 3f 2a
:3 d 18 d a 44 10 19 21
:2 10 24 26 :2 24 d 18 d a
28 44 11 1a 22 :2 11 25 27
:2 25 10 2e 37 3f :2 2e 42 44
:2 42 2d :2 10 d 18 d a 47
44 10 19 21 :2 10 24 26 :2 24
d 18 d 28 44 :2 a 45 :2 7
:4 4 7 10 1c :2 7 21 1f :2 2a
:2 1f 7 19 :2 7 16 :2 7 17 :2 7
14 1b 28 2b :2 14 :2 7 17 7
a 13 20 :2 a 23 25 :2 23 a
:3 16 :2 a 1c a 27 14 24 12
13 20 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 7
e :2 17 22 20 :2 2b :2 20 d 10
19 21 :2 10 24 26 :2 24 :2 13 18
19 26 17 25 :2 17 25 2e fffa
13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 5e
61 62 :2 5e :2 35 :3 19 :2 1f 24 30
6e 71 :2 30 7e 81 :2 30 85 88
:2 30 94 97 :2 30 9f a2 :2 30 ae
b1 b8 c1 c4 :2 b1 :2 30 :2 19 65
:2 16 :2 13 :4 1f :2 13 10 :4 28 :2 d 3b
d 1f d :4 a :4 7 a 19 1c
:2 19 d 16 1a d 12 13 1e
11 19 fffa d :2 16 22 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 1e d 18 25 30 3d 48 55
60 6d 78 85 8b 8f 16 1c
1f 35 3b 43 :2 12 23 27 38
13 16 23 11 15 22 25 fffa
d :2 16 22 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :3 1e e :2 17
22 20 :2 2b :2 20 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 b9 :2 8c :2 27 c1 c4
:2 27 cc cf :2 27 d4 d7 :2 27 e1
e4 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 47 52 :2 d
3b :2 a d 16 1e :2 d 21 23
:2 21 d 17 d 25 d 17 d
:4 a 19 d :8 f d :8 f d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5c 5d :2 58 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8f 92 :2 2a 9a 9d :2 2a
a9 ac b3 bc bf :2 ac :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :3 1e 7
1e d 14 22 25 :2 d 28 2a
:2 28 14 21 13 20 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5c 5d :2 58 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a 79 7c :2 2a 80 83
:2 2a 8f 92 :2 2a 9a 9d :2 2a a9
ac b3 bc bf :2 ac :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :4 2e 1e :2 7
16 10 11 f 10 1d :2 e 1c
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 59 5a :2 55 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 3a 16 10 11 f 10 1d :2 e
1c a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 59 5a :2 55 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 3a 16 10 1d :2 e 1c a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 59 5a :2 55 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8c 8f :2 27 97 9a
:2 27 a6 a9 b0 b9 bc :2 a9 :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :4 3a
:3 4 :3 17 4 7 10 18 :2 7 1b
1d :2 1b 23 2c 38 :2 23 3e 3b
:2 47 :2 3b :2 7 5b d 19 :2 5b 1f
1c :2 28 :2 1c :2 7 :4 b :2 a 17 a
20 :2 7 3d :2 4 7 10 1c :2 7
1f 21 :2 1f 7 15 :2 1e 7 23
:2 4 :4 8 7 :4 20 1f :2 7 :4 39 38
:2 7 :4 10 f e :3 7 14 7 25
:3 4 c :2 4 f 4 7 10 18
:2 7 1b 1d :2 1b a 13 1f :2 a
24 22 :2 2d :2 22 a 12 1e 21
:2 12 2a 2d :2 12 11 14 :2 12 11
14 :2 12 11 14 :2 12 32 35 :2 12
3f 42 :2 12 a 7 3d d 16
22 :2 d 25 27 :2 25 a 12 11
14 :2 12 11 14 :2 12 43 46 :2 12
53 56 :2 12 11 14 :2 12 2c 2f
:2 12 38 3b :2 12 11 14 :2 12 a
2a 3d a 12 11 14 :2 12 11
14 :2 12 11 14 :2 12 35 38 :2 12
41 44 :2 12 a :4 7 1f a 13
1f :2 a 25 22 :2 2e :2 22 42 d
19 :2 42 1f 1c :2 28 :2 1c :2 a 41
d 19 :2 41 1f 1c :2 28 :2 1c :3 a
12 1c :3 a :2 13 1f a :4 e :2 d
15 1f :3 d :2 16 22 d 1c 17
23 15 16 17 19 25 27 15
1f 10 15 2a 10 12 1f 22
14 17 14 17 25 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5b
5f 60 :2 5b :2 32 :3 16 :2 1c 21 2d
6c 6f :2 2d 7c 7f :2 2d 83 86
:2 2d 92 95 :2 2d 9d a0 :2 2d ac
af b6 bf c2 :2 af :2 2d :2 16 63
:2 13 :2 10 :4 1c :2 10 d :3 22 1c 17
19 15 27 17 19 15 27 16
18 1f 21 14 1b 1d 26 2d
2f 38 3a 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :4 22 d 19 d :4 a
3c :2 7 :4 b :2 a 12 1b 22 :2 1b
2a :2 12 2d 2f :2 2d 3a 41 4a
51 :2 4a 59 :2 41 5d :2 3a 64 66
:2 3a :2 16 71 78 81 88 :2 81 90
:2 78 94 :2 71 :2 11 :2 a f :2 a 10
14 12 18 :2 12 a 10 19 1f
26 2f 31 33 :2 2f 36 :2 1f :2 19
3b :2 10 3e 41 :2 3e 17 20 26
2d 36 38 3a :2 36 3d :2 26 :2 20
42 :2 17 45 48 :2 45 :4 10 4b :3 d
12 14 16 :2 12 d 18 e a
d 11 :3 f 10 :2 1a 2c :2 36 42
45 54 58 59 :2 54 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8a 8d 96 9e :2 a7
:2 96 b8 :2 8d :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 58 59
:2 54 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 :2 10 5c :3 d :2 18 2e :2 37 47
:2 d 15 :2 a 14 1c :2 12 :2 d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5c 5d
:2 58 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a 79 7c :2 2a 80 83 :2 2a 8f
92 :2 2a 9a 9d :2 2a a9 ac b3
bc bf :2 ac :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :4 1e :2 7 a 13 1f
:2 a 24 22 :2 2d :2 22 a 10 :2 a
15 :2 a 15 1d 20 :2 15 :2 a 15
1d 20 :2 15 a 7 3d d 16
22 :2 d 27 25 :2 30 :2 25 a 10
:2 a 12 17 1a :2 12 :2 a 12 17
1a :2 12 :2 a 15 a 45 3d d
16 22 :2 d 27 25 :2 30 :2 25 d
15 :2 d 18 :2 d 18 20 23 :2 18
d :4 11 :2 10 1b 23 26 :2 1b :2 10
1b 23 26 :2 1b :2 10 1b 23 26
:2 1b 10 24 :2 d 44 :4 11 :2 10 18
1d 20 :2 18 :2 10 1b 10 29 10
18 1d 20 :2 18 17 1a :2 18 :2 10
1b :2 10 1b 23 26 :2 1b 17 1a
:2 1b 17 1a :2 1b 17 1a :2 1b 17
1a :2 1b 17 1a :2 1b 10 :4 d :4 11
:2 10 1b 23 26 :2 1b 4f 52 :2 1b
5a 5d :2 1b 10 24 :2 d :4 a :4 e
:2 d 18 20 23 :2 18 :2 d 18 20
23 :2 18 :2 d 18 20 23 :2 18 d
23 :2 a :4 7 a 13 1f :2 a 25
22 :2 2e :2 22 :4 e d 17 21 15
16 23 :2 10 :2 19 25 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5b 5f 60 :2 5b :2 32 :3 16 :2 1c
21 2d 6c 6f :2 2d 7c 7f :2 2d
83 86 :2 2d 92 95 :2 2d 9d a0
:2 2d ac af b6 bf c2 :2 af :2 2d
:2 16 63 :2 13 :2 10 :4 1c :2 10 d :3 26
11 :2 1a 25 23 :2 2e :2 23 :2 10 18
21 28 :2 21 31 :2 18 :2 10 18 1d
20 :2 18 :2 10 1b 23 26 :2 1b 17
1a :2 1b 2f 32 :2 1b 39 3c :2 1b
10 3e 13 :2 1d 2f :2 39 45 49
58 5c 5d :2 58 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8d 90 99 a1 :2 aa :2 99
bb :2 90 :2 2a c3 c6 :2 2a ce d1
:2 2a d6 d9 :2 2a e4 e7 :2 2a :2 13
60 :2 10 13 :2 1d 2f :2 39 45 48
57 5b 5c :2 57 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a :2 13 5f :3 10 :2 1b
2f :2 38 48 54 :2 10 :4 d 26 :2 a
:4 e d 17 21 15 16 23 :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
92 95 :2 2d 9d a0 :2 2d ac af
b6 bf c2 :2 af :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :3 25 11 :2 1a 25
23 :2 2e :2 23 :2 10 18 1d 20 :2 18
:2 10 1b 23 26 :2 1b 17 1a :2 1b
2f 32 :2 1b 39 3c :2 1b 10 3e
13 :2 1d 2f :2 39 45 49 58 5c
5d :2 58 :2 2f :3 13 :2 19 1e 2a 69
6c :2 2a 79 7c :2 2a 80 83 :2 2a
8d 90 99 a1 :2 aa :2 99 bb :2 90
:2 2a c3 c6 :2 2a ce d1 :2 2a d6
d9 :2 2a e3 e6 :2 2a :2 13 60 :2 10
13 :2 1d 2f :2 39 45 48 57 5b
5c :2 57 :2 2f :3 13 :2 19 1e 2a 69
6c :2 2a :2 13 5f :3 10 :2 1b 2f :2 38
48 53 :2 10 :4 d 25 :2 a :4 e d
17 21 15 16 23 :2 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5b 5f 60 :2 5b
:2 32 :3 16 :2 1c 21 2d 6c 6f :2 2d
7c 7f :2 2d 83 86 :2 2d 92 95
:2 2d 9d a0 :2 2d ac af b6 bf
c2 :2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c
:2 10 d :3 25 11 :2 1a 25 23 :2 2e
:2 23 :2 10 18 1d 20 :2 18 :2 10 1b
23 26 :2 1b 17 1a :2 1b 2f 32
:2 1b 39 3c :2 1b 10 3e 13 :2 1d
2f :2 39 45 49 58 5c 5d :2 58
:2 2f :3 13 :2 19 1e 2a 69 6c :2 2a
79 7c :2 2a 80 83 :2 2a 8d 90
99 a1 :2 aa :2 99 bb :2 90 :2 2a c3
c6 :2 2a ce d1 :2 2a d6 d9 :2 2a
e3 e6 :2 2a :2 13 60 :2 10 13 :2 1d
2f :2 39 45 48 57 5b 5c :2 57
:2 2f :3 13 :2 19 1e 2a 69 6c :2 2a
:2 13 5f :3 10 :2 1b 2f :2 38 48 53
:2 10 :4 d 25 :2 a d 16 27 :2 d
2a 2c :2 2a 32 3b 4c :2 32 4f
52 :2 4f :3 d 18 20 23 :2 18 3b
3e 46 4f 61 :2 46 :2 3e :2 18 65
68 :2 18 d 56 :2 a 3e :2 7 :4 b
:2 a 15 1e 25 :2 1e 33 :2 15 :2 a
f :2 a 10 14 12 1c :2 12 a
d 1a :2 23 2c 30 34 35 36
:2 34 39 :2 1a d 17 21 15 16
23 :2 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5b 5f 60 :2 5b :2 32 :3 16 :2 1c 21
2d 6c 6f :2 2d 7c 7f :2 2d 83
86 :2 2d 92 95 :2 2d 9d a0 :2 2d
ac af b6 bf c2 :2 af :2 2d :2 16
63 :2 13 :2 10 :4 1c :2 10 d :3 1c 11
:2 1a 26 23 :2 2f :2 23 10 13 :2 1d
2f :2 39 45 49 58 5c 5d :2 58
:2 2f :3 13 :2 19 1e 2a 69 6c :2 2a
79 7c :2 2a 80 83 :2 2a 8d 90
99 a1 :2 aa :2 99 bb :2 90 :2 2a c3
c6 :2 2a ce d1 :2 2a d6 d9 :2 2a
e3 e6 :2 2a :2 13 60 :2 10 13 :2 1d
2f :2 39 45 48 57 5b 5c :2 57
:2 2f :3 13 :2 19 1e 2a 69 6c :2 2a
:2 13 5f :3 10 :2 1b 2f :2 38 48 53
:2 10 3f :3 d 18 20 23 :2 18 14
17 :2 18 14 17 :2 18 14 17 :2 18
31 34 :2 18 3b 3e :2 18 d 10
19 25 :2 10 2a 28 :2 33 :2 28 10
1b 23 26 :2 1b 10 43 10 1b
23 26 :2 1b 10 :4 d 10 19 25
:2 10 2a 28 :2 33 :2 28 :2 10 43 :2 d
a f 11 13 :2 f a 1c e
a 22 :2 7 a 13 1f :2 a 25
22 :2 2e :2 22 a 15 1e 25 :2 1e
34 :2 15 :2 a f :2 a 10 14 12
1c :2 12 a d 1a :2 23 2c 30
34 35 36 :2 34 39 :2 1a d 17
21 15 16 23 :2 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5b 5f 60 :2 5b :2 32
:3 16 :2 1c 21 2d 6c 6f :2 2d 7c
7f :2 2d 83 86 :2 2d 92 95 :2 2d
9d a0 :2 2d ac af b6 bf c2
:2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10
d :3 1c 11 :2 1a 26 23 :2 2f :2 23
10 13 :2 1d 2f :2 39 45 49 58
5c 5d :2 58 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a 79 7c :2 2a 80 83
:2 2a 8d 90 99 a1 :2 aa :2 99 bb
:2 90 :2 2a c3 c6 :2 2a ce d1 :2 2a
d6 d9 :2 2a e3 e6 :2 2a :2 13 60
:2 10 13 :2 1d 2f :2 39 45 48 57
5b 5c :2 57 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a :2 13 5f :3 10 :2 1b 2f
:2 38 48 53 :2 10 3f :3 d 18 20
23 :2 18 14 17 :2 18 14 17 :2 18
14 17 :2 18 31 34 :2 18 3b 3e
:2 18 14 17 :2 18 d a f 11
13 :2 f a 1c e a 3e :3 7
f 14 17 :2 f 7 :5 4 c 11
14 :2 c :2 4 9 :2 11 :2 4 d 16
:2 7 a e :2 a :2 13 1f a 14
a :2 13 1f a :4 7 b :2 14 20
1d :2 29 :2 1d :3 a 39 :2 7 a 13
1b :2 a 1e 20 :2 1e 26 2f 3b
:2 26 41 3e :2 4a :2 3e :2 a 62 d
19 :2 62 1f 1c :2 28 :2 1c :2 a 42
d 19 :2 42 1f 1c :2 28 :2 1c :4 3c
3b :2 42 41 :3 a f :3 a 10 19
:2 a d 11 :2 d :2 16 22 d 17
d :2 16 22 d :4 a e :2 17 22
20 :2 2b :2 20 d 10 16 :3 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :3 3b 12 d 3b 10
16 :3 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5b 5f 60 :2 5b :2 32 :3 16 :2 1c 21
2d 6c 6f :2 2d 7c 7f :2 2d 83
86 :2 2d 92 95 :2 2d 9d a0 :2 2d
ac af b6 bf c2 :2 af :2 2d :2 16
63 :2 13 :2 10 :4 1c :2 10 d :7 a 51
:3 7 16 :2 7 17 7 a 13 1b
:2 a 1e 20 :2 1e d 14 20 23
:2 d 26 28 :2 26 d :3 1c :2 d 19
d 2c 10 1e 27 2f :2 1e :2 10
33 36 :2 33 1a 20 38 18 19
26 17 25 17 :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 5e 62 63 :2 5e :2 35
:3 19 :2 1f 24 30 6f 72 :2 30 7f
82 :2 30 86 89 :2 30 95 98 :2 30
a0 a3 :2 30 af b2 b9 c2 c5
:2 b2 :2 30 :2 19 66 :2 16 :2 13 :4 1f :2 13
10 :3 38 13 1c 28 :2 13 2b 2d
:2 2b 16 1c :3 16 :2 1f 2b 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 61 65 66 :2 61 :2 38 :3 1c
:2 22 27 33 72 75 :2 33 82 85
:2 33 89 8c :2 33 98 9b :2 33 a3
a6 :2 33 b2 b5 bc c5 c8 :2 b5
:2 33 :2 1c 69 :2 19 :2 16 :4 22 :2 16 13
:3 2f 16 :2 20 32 :2 3c 48 4c 5b
5f 60 :2 5b :2 32 :3 16 :2 1c 21 2d
6c 6f :2 2d 7c 7f :2 2d 83 86
:2 2d 90 93 9c a4 :2 ad :2 9c ce
:2 93 :2 2d d6 d9 :2 2d e1 e4 :2 2d
e9 ec :2 2d f5 f8 :2 2d :2 16 63
:2 13 16 :2 20 32 :2 3c 48 4b 5a
5e 5f :2 5a :2 32 :3 16 :2 1c 21 2d
6c 6f :2 2d :2 16 62 :3 13 :2 1e 32
:2 3b 5b 1b :2 13 2f :2 10 38 :2 d
:5 a 16 22 2f 3d 48 52 5e
1b 28 36 43 51 1b 28 34
3e 46 4f 57 1b 27 33 40
4b 56 1b 25 30 3c 48 51
5c :2 48 60 1b 21 27 2a :2 16
a d 16 19 :2 16 10 16 :3 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5f
60 :2 5b :2 32 :3 16 :2 1c 21 2d 6c
6f :2 2d 7c 7f :2 2d 83 86 :2 2d
92 95 :2 2d 9d a0 :2 2d ac af
b6 bf c2 :2 af :2 2d :2 16 63 :2 13
:2 10 :4 1c :2 10 d :3 1b 10 1b 19
:2 24 :2 19 10 1c :2 25 10 2e :2 d
10 :2 1a 2c :2 36 42 46 55 59
5a :2 55 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8a 8d 96 9e :2 96 a9 :2 8d :2 27
b1 b4 :2 27 bc bf :2 27 c4 c7
:2 27 d3 d6 :2 27 :2 10 5d :2 d 10
:2 1a 2c :2 36 42 45 54 58 59
:2 54 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 :2 10 5c :3 d :2 18 2c 36 43
:2 d a 1b 11 18 24 27 :2 11
2a 2c :2 2a 10 36 3d 4b 4e
:2 36 51 53 :2 51 35 :2 10 17 24
39 46 53 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5f 60
:2 5b :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :4 58 1b :4 a 22 d
16 21 :2 d 27 24 :2 30 :2 24 d
1b :2 d 1c d 44 :3 a 16 22
2f 3d 48 52 5e 1b 28 36
43 51 1b 28 34 3e 46 4f
57 1b 27 33 40 4b 56 1b
25 30 3c 48 4b 4e 54 5a
5d :2 16 a d 16 18 :2 16 d
16 1c 1e :2 16 d a 1a 10
19 1b :2 19 :2 d 1d 1a :2 a d
15 13 1e 2a :2 15 :2 13 :2 d 2d
:2 a :4 7 9 7 :3 4 8 1 7
d :3 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
52 56 57 :2 52 :2 29 :3 d :2 13 18
24 63 66 :2 24 73 76 :2 24 7a
7d :2 24 89 8c :2 24 94 97 :2 24
a3 a6 ad b6 b9 :2 a6 :2 24 :2 d
5a :2 a :2 7 :4 13 :2 7 4 :3 1 8
13 11 :2 1c :2 11 7 36 3f 41
:2 3f 35 :2 7 48 51 54 :2 51 5a
a 12 :2 5a 15 17 :2 15 :2 48 47
:2 7 a :2 14 26 :2 30 3c 40 4f
53 54 :2 4f :2 26 :3 a :2 10 15 21
60 63 :2 21 70 73 :2 21 77 7a
:2 21 84 87 90 98 :2 90 a3 :2 87
:2 21 ab ae :2 21 b6 b9 :2 21 be
c1 :2 21 cd d0 :2 21 :2 a 57 :2 7
a :2 14 26 :2 30 3c 3f 4e 52
53 :2 4e :2 26 :3 a :2 10 15 21 60
63 :2 21 :2 a 56 :3 7 :2 12 26 30
3d :2 7 1a :2 4 7 11 14 :2 11
7 12 :2 7 15 :2 7 14 :2 7 c
:4 7 c :2 7 10 a :7 c :3 a d
12 :2 d :2 16 22 d 18 d :2 16
22 d :4 a e :2 17 23 20 :2 2c
:2 20 :3 d 3c :2 a :4 e d 29 :2 34
3b 46 :2 29 50 52 :2 50 :2 d 14
1d 24 :2 1d 2e :2 14 31 33 :2 31
:3 d 18 d 35 :2 a d :2 18 1f
2b :2 d 35 38 :2 35 10 12 15
:2 12 1a 13 1d 15 21 15 20
15 22 15 21 15 22 19 21
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5e 62 63 :2 5e :2 35 :3 19
:2 1f 24 30 6f 72 :2 30 7f 82
:2 30 86 89 :2 30 95 98 :2 30 a0
a3 :2 30 af b2 b9 c2 c5 :2 b2
:2 30 :2 19 66 :2 16 :2 13 :4 1f :2 13 10
:4 17 :3 d 1c :2 d 1d :2 d 1c :2 d
1d :2 d 1d :2 d 1d :2 d 1b :2 d
12 d 3a :2 a d f 12 :2 f
:4 19 18 :2 d 17 10 :5 12 16 1e
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5f 60 :2 5b :2 32 :3 16
:2 1c 21 2d 6c 6f :2 2d 7c 7f
:2 2d 83 86 :2 2d 92 95 :2 2d 9d
a0 :2 2d ac af b6 bf c2 :2 af
:2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10 d
:4 30 :2 a :4 e d :4 11 :2 10 1f 26
32 35 :2 26 3a 3d :2 1f 10 2a
:3 d 1c 23 2f 32 :2 23 3e 41
:2 1c d 26 :2 a :4 e :2 d 1d 24
31 34 :2 24 3f 42 :2 1d d 25
:2 a :4 e d :4 11 :2 10 20 27 34
37 :2 27 3c 3f :2 20 10 2b :3 d
1d 24 31 34 :2 24 41 44 :2 1d
d 27 :2 a :4 e :2 d 1d 24 31
34 :2 24 40 43 :2 1d d 26 :2 a
:4 e d :4 11 :2 10 1f 26 32 35
:2 26 3a 3d :2 1f 10 2a :3 d 1c
23 2f 32 :2 23 3e 41 :2 1c d
26 :2 a :4 e d :4 11 :2 10 20 27
34 37 :2 27 3c 3f :2 20 10 2b
:3 d 1d 24 31 34 :2 24 41 44
:2 1d d 27 :3 a f 11 13 :2 f
:2 a 17 a 7 b 16 a 10
:3 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
59 5a :2 55 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 76 79 :2 27 7d 80
:2 27 8c 8f :2 27 97 9a :2 27 a6
a9 b0 b9 bc :2 a9 :2 27 :2 10 5d
:2 d :2 a :4 16 :2 a 7 :3 16 a c
f :2 c 14 d 17 f 1b f
1a f 1c f 1b f 1c 13
1b d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5c 5d :2 58 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :4 11 :2 7 16 :2 4 :4 8 7 a
13 1b :2 a 1e 20 :2 1e 14 1d
21 38 12 13 1e 11 22 2a
31 49 51 58 :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5c 5d :2 58 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :4 22 a 18 :2 a :4 7 24 :2 4
e 1b 26 30 33 4b 5a c
14 17 1c 2b 31 34 42 45
d 10 1d :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 52 56 57 :2 52 :2 29 :3 d
:2 13 18 24 63 66 :2 24 73 76
:2 24 7a 7d :2 24 89 8c :2 24 94
97 :2 24 a3 a6 ad b6 b9 :2 a6
:2 24 :2 d 5a :2 a :2 7 :4 13 :2 7 4
:3 1 7 10 1c :2 7 21 1f :2 2a
:2 1f 7 f 19 :3 7 :2 10 1c 7
16 11 :4 c f 10 18 f 1e
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 59 5a :2 55 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 3a b :2 14 1f 1d :2 28 :2 1d a
19 14 f 13 24 f 13 24
f 13 24 f 13 24 12 13
1c 16 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5c 5d :2 58
:2 2f :3 13 :2 19 1e 2a 69 6c :2 2a
79 7c :2 2a 80 83 :2 2a 8f 92
:2 2a 9a 9d :2 2a a9 ac b3 bc
bf :2 ac :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :3 38 e :2 17 22 20 :2 2b
:2 20 d 1c 17 15 16 1e 19
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5f 60 :2 5b :2 32 :3 16
:2 1c 21 2d 6c 6f :2 2d 7c 7f
:2 2d 83 86 :2 2d 92 95 :2 2d 9d
a0 :2 2d ac af b6 bf c2 :2 af
:2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10 d
:4 3b :2 a 38 :3 7 c 1e 2a 3c
45 47 57 65 68 73 76 82
85 90 93 9f b2 7 a 1a
27 2a 3a 7 17 1a 2e 31
43 46 5b 60 6f 83 85 94
ad 7 17 1a 2e 31 43 46
5b 60 6f 83 85 94 ad 7
17 1a 2e 31 43 46 5b 60
6f 83 85 94 ad 7 17 1a
2e 31 43 46 5b 60 6f 83
85 94 ad 7 a 15 18 24
27 32 35 3d 40 51 54 66
69 77 87 94 9f ac af bc
bf c9 cc d6 d 1c 2e 39
3c 4c 5d 73 7e 8b 9b 9e
a9 b8 c7 d0 e0 ef 15 24
4b 64 d 1f 30 47 c 1e
7 c 1b 21 24 2d 32 7
c 12 17 2b 31 34 3f b
e 1a 1d 7 c 15 1a 1c
29 7 c 1d 22 24 2c 2e
7 c 12 17 1d 22 24 2c
2e 7 c 12 17 29 2f 31
3a 3d 7 c 12 17 27 2d
2f 38 3b 7 c 12 17 21
27 2a 37 39 12 15 2b 2e
45 48 5e 61 17 7 17 a
:2 14 26 :2 30 3c 3f 4e 52 53
:2 4e :2 26 :3 a :2 10 15 21 60 63
:2 21 :2 a 56 :3 7 e 7 3a a
14 16 :2 14 a f 21 24 2e
40 a c 19 a d 18 1b
27 2a 35 38 a c a d
1d 2a 2d 3d a 1a 1d 33
36 50 52 60 73 75 83 aa
b5 bf d7 ec f9 112 11d 127
13f 154 161 163 179 17c 192 195
1a7 1aa 1b9 1d2 a 1a 1d 33
36 50 52 60 73 75 83 aa
b5 bf d7 ec f9 112 11d 127
13f 154 161 163 179 17c 192 195
1a7 1aa 1b9 1d2 a 1a 1d 33
36 50 52 60 73 75 83 aa
b5 bf d7 ec f9 112 11d 127
13f 154 161 163 179 17c 192 195
1a7 1aa 1b9 1d2 a 1a 1d 33
36 50 52 60 73 75 83 aa
b5 bf d7 ec f9 112 11d 127
13f 154 161 163 179 17c 192 195
1a7 1aa 1b9 1d2 a d 19 1c
28 2b 36 39 41 44 55 58
6a 6d 7b 8b 98 a3 b0 b3
c0 c3 cd d0 da a d 1a
24 26 32 35 45 a d 18
1b 10 1b 28 38 3b 46 55
58 61 64 6e 77 7a 89 8c
9d a c 1b 1d 2d 40 42
a c 18 1a 25 27 39 4a
4c f 1e a f 19 1e 21
28 2a a f 19 1f 22 2d
2f a f 15 1a 24 2a 2d
38 3b a f 19 1e 21 28
2a a f 15 1a 24 2a 2d
39 3b a f 15 1a 2e 34
37 42 53 56 62 65 a f
15 1a 2c 32 34 40 43 a
f 15 1a 2c 32 35 3f 42
a f 15 1a 2a 30 32 3e
41 a f 15 1a 2a 30 33
3d 40 13 1a a 1a d :2 17
29 :2 33 3f 42 51 55 56 :2 51
:2 29 :3 d :2 13 18 24 63 66 :2 24
:2 d 59 :3 a 11 a 18 a 12
1c :3 a :2 13 1f a 19 14 1c
2a 38 46 12 27 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5c 5d :2 58 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a 79 7c :2 2a 80 83
:2 2a 8f 92 :2 2a 9a 9d :2 2a a9
ac b3 bc bf :2 ac :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 7 19 15
39 3d 4e d 11 22 31 35
46 d 11 22 12 13 29 35
4a 61 16 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5c 5d
:2 58 :2 2f :3 13 :2 19 1e 2a 69 6c
:2 2a 79 7c :2 2a 80 83 :2 2a 8f
92 :2 2a 9a 9d :2 2a a9 ac b3
bc bf :2 ac :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :3 7 a f 21 24
2e 40 49 4b 58 a d 18
1b 27 2a 35 38 44 46 a
d 1d 2a 2d 3d a 1a 1d
31 34 f 11 25 27 41 43
51 64 66 74 9b a6 b0 c8
dd ea 103 10e 118 130 145 152
154 f 13 27 2b 45 47 55
68 6a 78 9f aa b4 cc e1
ee 107 112 11c 134 149 156 158
f 13 22 14 a 1a 1d 32
35 f 11 27 29 43 45 53
66 68 76 9d a8 b2 ca df
ec 105 110 11a 132 147 154 156
f 13 27 2b 45 47 55 68
6a 78 9f aa b4 cc e1 ee
107 112 11c 134 149 156 158 f
13 22 14 a 1a 1d 31 34
f 11 25 27 41 43 51 64
66 74 9b a6 b0 c8 dd ea
103 10e 118 130 145 152 154 f
13 27 2b 45 47 55 68 6a
78 9f aa b4 cc e1 ee 107
112 11c 134 149 156 158 f 13
22 14 a 1a 1d 31 34 f
11 25 27 41 43 51 64 66
74 9b a6 b0 c8 dd ea 103
10e 118 130 145 152 154 f 13
27 2b 45 47 55 68 6a 78
9f aa b4 cc e1 ee 107 112
11c 134 149 156 158 f 13 22
14 a d 18 1b 27 2a 35
38 40 43 54 57 69 6c 7a
8a 97 a2 af b2 bf c2 cc
cf d9 a d 1a 24 26 32
35 45 50 53 5e 61 77 82
8f 9f a2 ad a d 16 19
23 2c 2f 3e 41 52 a c
1b 1d 2d 40 42 a c 18
1a 25 27 39 4a 4c f 1e
a f 14 26 2d 30 37 3b
46 4a a f 14 26 2d 30
37 3b 46 4a a f 19 1e
21 28 2a a f 19 1f 22
2d 2f a f 15 1a 24 2a
2d 38 3b a f 19 1e 21
28 2a 36 3b 41 46 50 56
59 65 67 a f 15 1a 2e
34 37 42 53 56 62 65 a
f 15 1a 24 2a 2c 37 3a
a f 15 1a 2c 32 34 40
43 4e 53 59 5e 70 76 79
83 86 a f 15 1a 2a 30
32 3e 41 4c 51 57 5c 6c
72 75 7f 82 a f 15 1a
20 25 27 2f 31 15 18 2e
31 48 4b 61 64 13 1a a
1a d :2 17 29 :2 33 3f 42 51
55 56 :2 51 :2 29 :3 d :2 13 18 24
63 66 :2 24 :2 d 59 :3 a 11 a
:4 7 :4 4 1 9 12 9 a :2 14
26 :2 30 3c 40 4f 53 54 :2 4f
:2 26 :3 a :2 10 15 21 60 63 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
57 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4c 50 51 :2 4c
:2 23 :3 7 :2 d 12 1e 5d 60 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 54 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
3732
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 :4 14
:4 15 :4 16 :4 17 :4 18
:4 19 :4 1a :4 1b :4 1c
:4 1d 2 :4 1e :2 1
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :7 26 :7 27
:7 28 :7 29 :7 2a :7 2b
:7 2c :7 2d :7 2e :7 2f
:7 30 :7 31 :7 32 :7 33
:7 34 :5 35 :7 36 :7 37
:7 38 :7 39 :7 3a :5 3b
:7 3c :7 3d :7 3e :7 3f
:7 40 :7 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :6 5a :6 5b
:6 5c :6 5d :6 5e :6 5f
:6 60 :6 61 :6 62 :7 63
:6 64 :6 65 :6 66 :7 67
:7 68 :7 69 :6 6a :6 6b
:7 6c :7 6d :7 6e :7 6f
:7 70 :7 71 :6 72 :6 73
:6 74 :6 75 :6 76 :6 77
:6 78 :6 79 :7 7a :6 7b
:5 7c :5 7d :5 7e :5 7f
:5 80 :5 81 :5 82 :7 85
:2 87 0 :2 87 88
89 :2 8a :2 8b :2 8c
88 :5 87 :2 8e 0
:2 8e 90 91 :2 92
:2 93 :2 94 :2 95 :2 96
:2 97 98 99 90
:5 8e :7 9c :7 9f :7 a2
:7 a4 :b a6 :11 a7 a8
:2 a7 :2 a8 :2 a7 :2 a8
:2 a7 :2 a9 :2 a7 :2 a9
:2 a7 :2 a9 :2 a7 :2 a9
:2 a7 :2 aa :2 a7 :2 aa
:2 a7 :2 aa :2 a7 :2 aa
:2 a7 :2 ab :2 a7 :9 ab
:2 a7 :2 ac :2 a7 :9 ac
:2 a7 :2 ad :2 a7 :9 ad
:2 a7 :2 ae :2 a7 :9 ae
:2 a7 :2 af :2 a7 :9 af
:2 a7 :2 b0 :2 a7 :9 b0
:2 a7 :2 b1 :2 a7 :9 b1
:2 a7 :2 b2 :2 a7 :9 b2
:2 a7 :2 b3 :2 a7 :2 b3
:2 a7 :2 b3 :2 a7 :2 b3
:2 a7 :2 b4 :2 a7 :2 b4
:2 a7 :2 b4 :2 a7 :2 b4
:2 a7 :2 b5 :2 a7 :2 b5
:2 a7 :2 b5 :2 a7 :2 b5
:2 a7 :2 b6 :2 a7 :2 b6
:2 a7 :2 b6 :2 a7 :2 b6
:2 a7 :2 b7 :2 a7 :2 b7
:2 a7 :2 b7 :2 a7 :2 b7
:2 a7 :2 b8 :2 a7 :9 b8
:2 a7 :2 b9 :2 a7 :2 b9
:2 a7 :2 b9 :2 a7 :2 b9
:2 a7 :2 ba :2 a7 :2 ba
:2 a7 :2 ba :2 a7 :2 ba
:2 a7 :2 bb :2 a7 :2 bb
:2 a7 :2 bb :2 a7 :2 bb
:2 a7 :2 bc :2 a7 :2 bc
:2 a7 :2 bc :2 a7 :2 bc
:2 a7 :2 bd :2 a7 :9 bd
:2 a7 :2 be :2 a7 :9 be
:2 a7 :2 bf :2 a7 :9 bf
:2 a7 :2 c0 :2 a7 :9 c0
:2 a7 :2 c1 :2 a7 :2 c1
:2 a7 :2 c1 :2 a7 :2 c1
:2 a7 :2 c2 :2 a7 :2 c2
:2 a7 :2 c2 :2 a7 :2 c2
:2 a7 :2 c2 :4 a7 :3 a6
:11 c5 :b c6 :3 c5 :3 ce
:3 cf :3 d0 :3 d1 :3 d2
:3 d3 :3 d4 :3 d5 :3 d6
:3 d7 :3 d9 :3 db :3 dd
:3 df :3 e0 :3 e1 :3 e2
:3 e3 :3 e4 :3 e5 :3 e6
:3 e7 :3 e9 :3 ea :14 ef
:11 f0 :20 f1 :3 f0 :11 f3
:b f4 :3 f3 :9 f6 :3 ef
:1e f9 :c fa :2 f9 :14 fb
:11 fc :20 fd :3 fc :11 ff
:b 100 :3 ff :9 102 103
fb :e 103 :11 104 :20 105
:3 104 :11 107 :b 108 :3 107
:9 10a 103 :3 fb fa
:2 f9 :1f 10e :11 10f :20 110
:3 10f :11 112 :b 113 :3 112
:9 115 :3 10e :6 119 :3 11a
119 :3 11c 11b :3 119
:14 11f :6 120 :2 11f :6 122
123 124 122 :5 125
121 127 :5 128 :3 127
:2 129 :5 12b :11 12c :24 12d
:3 12c :2 12a :6 129 126
:3 120 :16 132 :11 133 :20 134
:3 133 :11 136 :b 137 :3 136
:9 139 :3 132 :3 13b 120
:2 11f :e 13e :4 140 :5 141
13f 143 :5 144 :3 143
:2 145 :5 147 :11 148 :24 149
:3 148 :2 146 :6 145 142
:6 13e :3 14f :14 153 :d 155
:14 157 :d 159 :b 15b :3 15c
15d 15b :b 15d :3 15e
15d 15b :b 160 :3 161
160 :3 163 162 :3 160
15f :3 15b :9 167 :3 168
:2 16a 16b :2 16c 16a
:5 16d 169 16f :5 170
:3 16f :2 171 :5 173 :11 174
:24 175 :3 174 :2 172 :6 171
16e :3 167 :9 17a :2 17c
17d :2 17e 17c :5 17f
17b 181 :5 182 :3 181
:2 183 :5 185 :11 186 :24 187
:3 186 :2 184 :6 183 180
:3 17a :b 18c :11 18d :30 18e
:3 18d :11 190 :b 191 :3 190
:a 193 :3 18c :3 17a :a 197
:9 198 :a 199 :9 19a :11 19b
:20 19c :3 19b :11 19e :b 19f
:3 19e :9 1a1 :3 19a :5 1a3
:3 198 :3 1a5 :9 1a7 :3 1a8
1a7 :11 1ab :20 1ac :3 1ab
:11 1ae :b 1af :3 1ae :9 1b1
1a9 :3 1a7 :7 1b9 1ba
:3 1b9 :b 1bc :9 1bd :5 1be
:3 1bd :11 1c1 :2e 1c2 :3 1c1
:11 1c4 :b 1c5 :3 1c4 :c 1c7
:3 1bc :14 1ca :11 1cb :2e 1cc
:3 1cb :11 1ce :b 1cf :3 1ce
:c 1d1 :3 1ca :b 1d3 :c 1d4
1d7 :2 1d8 :2 1d9 1da
1dc 1dd 1de 1df
1e0 :2 1e1 1d7 :5 1e2
1d5 1e4 :5 1e5 :3 1e4
:2 1e6 :5 1e8 :11 1e9 :24 1ea
:3 1e9 :2 1e7 :6 1e6 1e3
:4 1d4 :2 1f1 :2 1f2 :2 1f3
:2 1f4 :3 1f5 :3 1f6 :2 1f7
:4 1f8 1fa 1fb 1fc
1fd 1fe 1ff 200
201 :4 202 :3 203 :4 204
1f1 :5 205 1ef 207
:5 208 :3 207 :2 209 :5 20b
:11 20c :24 20d :3 20c :2 20a
:6 209 206 :4 1ee :3 1d4
:a 213 :11 214 :30 215 :3 214
:11 217 :b 218 :3 217 :a 21a
:3 213 21c 1d3 :b 21c
21f 220 221 223
224 225 226 :2 227
21f :5 228 21d 22a
:5 22b :3 22a :2 22c :5 22e
:11 22f :24 230 :3 22f :2 22d
:6 22c 229 :3 21c :a 235
:11 236 :30 237 :3 236 :11 239
:b 23a :3 239 :a 23c :3 235
:2 244 245 :2 246 :2 248
:2 249 24a 24c 24d
24e 24f 250 :2 251
:2 252 243 :5 253 241
255 :5 256 :3 255 :2 257
:5 259 :11 25a :24 25b :3 25a
:2 258 :6 257 254 :3 21c
:a 260 :11 261 :30 262 :3 261
:11 264 :b 265 :3 264 :a 267
:3 260 :5 26a :5 26e :6 26f
:3 26a 21c 1d3 :11 273
:30 274 :3 273 :11 276 :b 277
:3 276 :a 279 271 :3 1d3
:b 27d 281 :3 282 283
284 :4 285 :4 286 288
289 28a 28b 28c
28d 28e :2 28f 281
:5 290 27f 292 :5 293
:3 292 :2 294 :5 296 :11 297
:24 298 :3 297 :2 295 :6 294
291 :3 27d :a 29d :11 29e
:30 29f :3 29e :11 2a1 :b 2a2
:3 2a1 :a 2a4 2a5 29d
:a 2a5 :14 2a6 :2 2a7 :2 2a6
:8 2a7 :5 2a6 :11 2a8 :30 2a9
:3 2a8 :11 2ab :b 2ac :3 2ab
:a 2ae 2a7 :2 2a6 :d 2b1
:8 2b4 2b5 2b4 :5 2b6
2b3 2b8 :5 2b9 :3 2b8
:2 2ba :5 2bc :11 2bd :24 2be
:3 2bd :2 2bb :6 2ba 2b7
:6 2b1 2a5 :3 29d :3 27d
:3 167 :9 2c9 :13 2cf :2 2d0
:2 2cf :4 2d0 :2 2cf :11 2d1
:30 2d2 :3 2d1 :11 2d4 :b 2d5
:3 2d4 :7 2d7 2d8 :2 2d7
2d0 :2 2cf :b 2dc 2df
:2 2e0 :2 2e1 2e3 2e4
2e5 2e6 :2 2e7 2df
:5 2e8 2dd 2ea :5 2eb
:3 2ea :2 2ec :5 2ee :11 2ef
:24 2f0 :3 2ef :2 2ed :6 2ec
2e9 :3 2dc :a 2f7 2fd
2fe :3 2ff 2fa :5 300
2f8 302 :5 303 :3 302
:2 304 :5 306 :11 307 :24 308
:3 307 :2 305 :6 304 301
:3 2f7 :a 30d :11 30e :30 30f
:3 30e :11 311 :b 312 :3 311
:a 314 :3 30d :3 2f7 :3 2dc
:3 2c9 :14 31b :3 31c :3 31b
:b 31f :5 321 :3 322 :3 323
321 :3 325 :3 326 324
:3 321 :3 329 31f :5 32c
:3 32f :e 331 :b 332 :2 333
:2 332 :a 333 :8 334 :3 331
:b 336 :11 337 :20 338 :3 337
:11 33a :b 33b :3 33a :9 33d
33e 336 :9 33e :11 33f
:2e 340 :3 33f :11 342 :b 343
:3 342 :c 345 33e :3 336
32c :3 348 :9 34a :f 34b
:3 34a 347 :3 32c :16 34e
:16 34f :3 350 351 34f
:9 351 :3 352 353 351
34f :16 353 :3 354 355
353 34f :9 355 :3 356
355 :3 34f :3 34e 32a
:3 31f :b 360 :3 361 :3 363
:3 364 :8 367 :3 368 :9 36f
:5 370 :3 371 36f :2 375
376 :2 377 375 :5 378
374 37a :5 37b :3 37a
:2 37c :5 37e :11 37f :24 380
:3 37f :2 37d :6 37c 379
:3 372 :a 385 :9 386 389
38b 38c :2 38d :2 38e
38f :3 390 389 :5 391
387 393 :5 394 :3 393
:2 395 :5 397 :11 398 :24 399
:3 398 :2 396 :6 395 392
:6 386 385 :3 39f 39e
:3 385 372 :3 36f :5 3a3
:3 3a6 3a8 3a9 :2 3aa
:2 3ab 3a6 :5 3ac 3a4
3ae :5 3af :3 3ae :2 3b0
:5 3b2 :11 3b3 :24 3b4 :3 3b3
:2 3b1 :6 3b0 3ad :3 3a3
:d 3bb :6 3bc 3bd :4 3be
:3 3bf :4 3c0 3bb :5 3c1
3b9 3c3 :5 3c4 :3 3c3
:2 3c5 :5 3c7 :11 3c8 :24 3c9
:3 3c8 :2 3c6 :6 3c5 3c2
:3 3a3 :a 3ce :11 3cf :30 3d0
:3 3cf :11 3d2 :b 3d3 :3 3d2
:a 3d5 :3 3ce :9 3d8 :3 3d9
3d8 :3 3db 3da :3 3d8
3df 3e1 3e2 3e3
3e4 3e5 3e6 3e7
3e8 3e9 3ed 3ee
3ef 3f0 3f1 3f2
3f3 3f4 3f5 3df
:6 3f7 :5 3f8 3f7 :5 3fa
3f9 :3 3f7 3de 3fd
:5 3fe :3 3fd :2 3ff :5 401
:11 402 :24 403 :3 402 :2 400
:6 3ff 3fc :3 3a3 407
3a3 :a 407 :2 40b :2 40c
40b :6 40d :5 40e 40d
:5 410 40f :3 40d 40a
413 :5 414 :3 413 :2 415
:5 417 :11 418 :24 419 :3 418
:2 416 :6 415 412 :4 407
:3 3a3 422 423 424
425 :2 426 427 :2 428
422 :6 429 :5 42a 429
:5 42c 42b :3 429 421
42f :5 430 :3 42f :2 431
:5 433 :11 434 :24 435 :3 434
:2 432 :6 431 42e :3 360
43b 43c 43d 43e
:2 43f 440 :2 441 43b
:6 442 :5 443 442 :5 445
444 :3 442 43a 448
:5 449 :3 448 :2 44a :5 44c
:11 44d :24 44e :3 44d :2 44b
:6 44a 447 :3 360 454
:2 455 456 :2 457 454
:6 458 :5 459 458 :5 45b
45a :3 458 453 45e
:5 45f :3 45e :2 460 :5 462
:11 463 :24 464 :3 463 :2 461
:6 460 45d :6 360 :5 486
:17 488 :2 489 :2 488 :6 489
:2 488 :5 48a :3 48b :3 48a
489 :2 488 :9 48f :5 490
:3 48f :13 493 :6 494 :2 493
:3 495 494 :2 493 :3 499
:3 49a :9 49b :b 4a2 :a 4a3
:2 4a4 :2 4a3 :2 4a5 :2 4a3
:2 4a6 :2 4a3 :2 4a6 :2 4a3
:2 4a6 :3 4a3 4a7 4a2
:9 4a7 :2 4a8 :2 4a9 :2 4a8
:2 4aa :2 4a8 :2 4aa :2 4a8
:2 4aa :2 4a8 :2 4ab :2 4a8
:2 4ab :2 4a8 :2 4ab :2 4a8
:2 4ac :3 4a8 4a7 4a2
:2 4ae :2 4af :2 4ae :2 4b0
:2 4ae :2 4b1 :2 4ae :2 4b1
:2 4ae :2 4b1 :3 4ae 4ad
:3 4a2 49b :c 4bb :2 4bc
:2 4bb :6 4bc :2 4bb 4bc
:2 4bd :2 4bc :6 4bd :2 4bb
:5 4c1 :5 4c2 :5 4c4 :5 4c7
:5 4c8 4cb :2 4cc 4cd
4ce :4 4d1 :2 4d2 :3 4d3
:4 4d4 :2 4d5 :3 4d6 4cb
:6 4d7 :5 4d8 4d7 :5 4da
4d9 :3 4d7 4ca 4dd
:5 4de :3 4dd :2 4df :5 4e1
:11 4e2 :24 4e3 :3 4e2 :2 4e0
:6 4df 4dc :3 4c4 4eb
:2 4ec :2 4ed :2 4ef :2 4f0
:4 4f1 :8 4f2 4eb :6 4f3
:5 4f4 4f3 :5 4f6 4f5
:3 4f3 4ea 4f9 :5 4fa
:3 4f9 :2 4fb :5 4fd :11 4fe
:24 4ff :3 4fe :2 4fc :6 4fb
4f8 :4 4c4 :3 505 503
:3 4c4 4bd :2 4bb :5 509
50b :1c 50c :2 50b :c 50c
:3 50b :3 50d :8 510 :15 511
:15 512 :2 511 :2 513 512
:2 511 :7 515 510 516
510 :5 518 :11 519 :20 51a
:3 519 :11 51c :b 51d :3 51c
:9 51f :3 518 :2 523 524
525 523 :5 526 522
528 :5 529 :3 528 :2 52a
:5 52c :11 52d :24 52e :3 52d
:2 52b :6 52a 527 :6 509
:b 534 536 537 536
:3 538 :7 539 :7 53a 53b
534 :b 53b 53d 53e
53d :7 53f :7 540 :3 541
53b 534 :b 543 :3 546
:3 547 :7 549 :5 54c :7 54d
:7 54e :7 54f :3 54c 543
:5 552 :7 553 :3 554 552
:6 557 :2 558 :3 557 :3 55a
:6 55c :2 55d :2 55c :2 55e
:2 55c :2 55f :2 55c :2 560
:2 55c :2 561 :3 55c 555
:3 552 :5 566 :f 567 :3 566
551 :3 543 :5 56b :7 56c
:7 56d :7 56e :3 56b 542
:3 534 :b 572 :5 573 :2 575
576 :2 577 575 :5 578
574 57a :5 57b :3 57a
:2 57c :5 57e :11 57f :24 580
:3 57f :2 57d :6 57c 579
:3 573 :a 585 :a 586 :7 589
:6 58a :2 58b :2 58a :2 58b
:2 58a :2 58b :3 58a 585
:11 58e :30 58f :3 58e :11 591
:b 592 :3 591 :a 594 58d
:3 585 :3 573 :5 598 :2 59a
59b :2 59c 59a :5 59d
599 59f :5 5a0 :3 59f
:2 5a1 :5 5a3 :11 5a4 :24 5a5
:3 5a4 :2 5a2 :6 5a1 59e
:3 598 :a 5aa :7 5ab :6 5ac
:2 5ad :2 5ac :2 5ad :2 5ac
:2 5ad :3 5ac 5aa :11 5af
:30 5b0 :3 5af :11 5b2 :b 5b3
:3 5b2 :a 5b5 5ae :3 5aa
:3 598 :5 5b9 :2 5bb 5bc
:2 5bd 5bb :5 5be 5ba
5c0 :5 5c1 :3 5c0 :2 5c2
:5 5c4 :11 5c5 :24 5c6 :3 5c5
:2 5c3 :6 5c2 5bf :3 5b9
:a 5cb :7 5cc :6 5cd :2 5ce
:2 5cd :2 5ce :2 5cd :2 5ce
:3 5cd 5cb :11 5d0 :30 5d1
:3 5d0 :11 5d3 :b 5d4 :3 5d3
:a 5d6 5cf :3 5cb :3 5b9
:14 5da :16 5db :3 5da :3 572
:5 5e0 :a 5e1 :3 5e3 :8 5e4
:f 5e6 :2 5e9 5ea :2 5eb
5e9 :5 5ec 5e8 5ee
:5 5ef :3 5ee :2 5f0 :5 5f2
:11 5f3 :24 5f4 :3 5f3 :2 5f1
:6 5f0 5ed :3 5e4 :a 5f9
:11 5fa :30 5fb :3 5fa :11 5fd
:b 5fe :3 5fd :a 600 :3 5f9
:6 603 :2 604 :2 603 :2 605
:2 603 :2 606 :2 603 :2 606
:2 603 :2 606 :3 603 :b 608
:7 609 608 :7 60b 60a
:3 608 :b 60f :2 610 :3 60f
:7 612 5e4 613 5e4
:3 5e0 :b 617 :a 618 :3 61a
:8 61b :f 61d :2 620 621
:2 622 620 :5 623 61f
625 :5 626 :3 625 :2 627
:5 629 :11 62a :24 62b :3 62a
:2 628 :6 627 624 :3 61b
:a 630 :11 631 :30 632 :3 631
:11 634 :b 635 :3 634 :a 637
:3 630 :6 63a :2 63b :2 63a
:2 63c :2 63a :2 63d :2 63a
:2 63d :2 63a :2 63d :2 63a
:2 63e :3 63a :7 63f 61b
640 61b :3 617 :7 643
4b3 :3 49b :7 646 :5 64a
64d :4 64e :3 64f :5 650
64f :5 652 651 :3 64f
:a 656 :2 657 :3 656 :17 65c
:2 65d :2 65c :6 65d :2 65c
65d :2 65e :2 65d :b 65e
:3 65d :2 65c :5 661 :4 663
:3 664 :5 665 664 :5 667
666 :3 664 :a 66a :4 66c
:5 66d 66b 66f :5 670
:3 66f :2 671 :5 673 :11 674
:24 675 :3 674 :2 672 :6 671
66e :3 66a :2 67d 66a
:4 680 :5 681 67f 683
:5 684 :3 683 :2 685 :5 687
:11 688 :24 689 :3 688 :2 686
:6 685 682 :4 67e :3 66a
65e :2 65c :3 690 :3 691
:9 692 :a 693 :5 695 :3 696
693 :c 698 :3 69b 69c
:2 69d :2 69e 69f 69b
:5 6a0 69a 6a2 :5 6a3
:3 6a2 :2 6a4 :5 6a6 :11 6a7
:24 6a8 :3 6a7 :2 6a5 :6 6a4
6a1 :3 698 :9 6ad :4 6af
:5 6b0 6ae 6b2 :5 6b3
:3 6b2 :2 6b4 :5 6b6 :11 6b7
:24 6b8 :3 6b7 :2 6b5 :6 6b4
6b1 :3 6ad :11 6bd :30 6be
:3 6bd :11 6c0 :b 6c1 :3 6c0
:7 6c3 6c4 :2 6c3 :3 6ad
:3 698 697 :3 693 :8 6c9
:5 6ca :7 6cb :6 6cc :a 6cd
:4 6ce :3 6c9 :5 6d0 :4 6d2
:5 6d3 6d1 6d5 :5 6d6
:3 6d5 :2 6d7 :5 6d9 :11 6da
:24 6db :3 6da :2 6d8 :6 6d7
6d4 :3 6d0 :7 6e0 :5 6e1
:3 6e0 :11 6e4 :2e 6e5 :3 6e4
:11 6e7 :b 6e8 :3 6e7 :8 6ea
6eb 6d0 :18 6eb :6 6ed
:6 6ee :5 6ef 6ee :5 6f1
6f0 :3 6ee 6ec 6f4
:5 6f5 :3 6f4 :2 6f6 :5 6f8
:11 6f9 :24 6fa :3 6f9 :2 6f7
:6 6f6 6f3 :4 6eb :3 6d0
:2 700 692 :b 702 :3 703
:3 704 :3 702 :8 707 :5 708
:7 709 :6 70a :a 70b :3 707
:5 70d :7 70e 70f 70d
:5 70f :2 710 70f :3 70d
:9 713 :2 714 :3 713 701
:3 692 717 718 :3 64d
719 a5 :4 71d :5 71e
71c 720 :5 721 :3 720
:2 722 :5 724 :11 725 :24 726
:3 725 :2 723 :6 722 71f
:3 a5 :16 72c :2 72d :2 72c
:4 72d :5 72c :11 72e :2e 72f
:3 72e :11 731 :b 732 :3 731
:8 734 72d :2 72c :5 737
:3 738 :3 739 :3 73a :5 73c
:3 73e 740 741 742
743 744 745 746
747 748 749 :3 741
:3 74a :5 74b 74a :5 74d
74c :3 74a :a 750 :2 751
:3 750 :12 756 :c 757 :2 756
:3 759 757 :2 756 :b 75d
:5 75f 762 :2 763 :2 764
:2 765 :2 766 :2 767 :2 768
:2 769 762 :6 76a :5 76b
76a :5 76d 76c :3 76a
761 770 :5 771 :3 770
:2 772 :5 774 :11 775 :24 776
:3 775 :2 773 :6 772 76f
:6 75f :3 77c :3 77d :3 77e
:3 77f :3 780 :3 782 :3 786
:3 787 :3 75d :c 78a 78d
78e 78f 790 791
792 793 :2 794 78d
:6 795 :5 796 795 :5 798
797 :3 795 78c 79b
:5 79c :3 79b :2 79d :5 79f
:11 7a0 :24 7a1 :3 7a0 :2 79e
:6 79d 79a :6 78a :5 7a7
:5 7a8 :c 7a9 :3 7a8 :c 7ac
:3 7a7 :5 7af :c 7b0 :3 7af
:5 7b3 :5 7b4 :c 7b5 :3 7b4
:c 7b8 :3 7b3 :5 7bb :c 7bc
:3 7bb :5 7bf :5 7c0 :c 7c1
:3 7c0 :c 7c4 :3 7bf :5 7c7
:5 7c8 :c 7c9 :3 7c8 :c 7cc
:3 7c7 :7 7d0 :3 7d2 740
7d3 737 :4 7d5 :5 7d6
7d4 7d8 :5 7d9 :3 7d8
:2 7da :5 7dc :11 7dd :24 7de
:3 7dd :2 7db :6 7da 7d7
:3 737 :5 7e3 7e6 :2 7e7
:2 7e8 :2 7e9 :2 7ea :2 7eb
:2 7ec :2 7ed 7e6 :6 7ee
:5 7ef 7ee :5 7f1 7f0
:3 7ee 7e5 7f4 :5 7f5
:3 7f4 :2 7f6 :5 7f8 :11 7f9
:24 7fa :3 7f9 :2 7f7 :6 7f6
7f3 :6 7e3 :3 737 :5 801
:9 802 :4 804 805 :2 806
:7 807 804 :5 808 803
80a :5 80b :3 80a :2 80c
:5 80e :11 80f :24 810 :3 80f
:2 80d :6 80c 809 :4 802
:3 815 816 814 :3 802
:3 801 :7 81b :9 81c :3 81d
81b :5 81e 81a 820
:5 821 :3 820 :2 822 :5 824
:11 825 :24 826 :3 825 :2 823
:6 822 81f :3 a5 :b 82e
:5 831 :5 832 837 838
839 83a 83b 83c
83d :2 83e :2 83f 837
:6 840 :5 841 840 :5 843
842 :3 840 836 846
:5 847 :3 846 :2 848 :5 84a
:11 84b :24 84c :3 84b :2 849
:6 848 845 :3 82e :a 852
854 855 :3 856 :3 857
:3 858 :3 859 85a :2 85b
85c 854 :6 85d :5 85e
85d :5 860 85f :3 85d
853 863 :5 864 :3 863
:2 865 :5 867 :11 868 :24 869
:3 868 :2 866 :6 865 862
:3 852 :a 86e 870 871
872 :2 873 874 870
:6 875 :5 876 875 :5 878
877 :3 875 86f 87b
:5 87c :3 87b :2 87d :5 87f
:11 880 :24 881 :3 880 :2 87e
:6 87d 87a :6 86e :3 852
:12 889 :6 88a :e 88b :e 88c
:e 88d :e 88e :19 88f :12 890
:4 891 :4 892 :2 893 :7 894
:8 895 :4 896 :6 897 :7 898
:9 899 :9 89a :9 89b :9 89c
:8 89d :3 889 :11 89e :b 89f
:3 89e :3 8a1 82e :5 8a5
:6 8a6 :3 8a7 :8 8a8 :2 8a9
:6 8aa :20 8ab :20 8ac :20 8ad
:20 8ae :19 8af :8 8b0 :4 8b1
:10 8b2 :7 8b3 :9 8b4 :2 8b5
:7 8b6 :7 8b7 :9 8b8 :7 8b9
:9 8ba :c 8bb :9 8bc :9 8bd
:9 8be :9 8bf 8c0 :3 8a6
:11 8c1 :b 8c2 :3 8c1 :3 8c4
8a5 :5 8c9 :5 8ca 8cc
:5 8cd :2 8ce 8cc :6 8cf
:5 8d0 8cf :5 8d2 8d1
:3 8cf 8cb 8d5 :5 8d6
:3 8d5 :2 8d7 :5 8d9 :11 8da
:24 8db :3 8da :2 8d8 :6 8d7
8d4 :3 8c7 8e1 :4 8e2
:6 8e3 :3 8e4 8e5 :5 8e6
8e7 8e1 :6 8e8 :5 8e9
8e8 :5 8eb 8ea :3 8e8
8e0 8ee :5 8ef :3 8ee
:2 8f0 :5 8f2 :11 8f3 :24 8f4
:3 8f3 :2 8f1 :6 8f0 8ed
:3 8c7 :9 8f9 :a 8fa :6 8fb
:5 8fd :17 8fe :17 8ff :3 900
901 :5 903 :17 904 :17 905
:3 906 907 :5 909 :17 90a
:17 90b :3 90c 90d :5 90f
:17 910 :17 911 :3 912 913
:19 915 :12 916 :a 917 :7 918
:9 91a :2 91b :a 91c :a 91d
:7 91e :7 91f :9 920 :10 921
:c 922 :9 923 :12 924 :12 925
:9 926 :8 927 928 :3 8f9
:11 929 :b 92a :3 929 :3 92c
8c7 :3 8a5 8a4 :3 82e
a5 :3 935 :11 936 :b 937
:17 938 :3 936 :2 93a :3 93b
:3 93c 93d 93b 93a
93b :3 93e :3 935 :2 93f
:5 941 :11 942 :b 943 :18 944
:3 942 :2 946 947 :3 948
949 947 946 947
:3 94a :2 940 :6 93f 934
:7 1 
c184
4
:3 0 1 :3 0 2
:a 0 372d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 4 :3 0 10
:7 0 31 30 :3 0
4 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 4
:3 0 12 :7 0 39
38 :3 0 4 :3 0
13 :7 0 3d 3c
:3 0 25 160 0
23 4 :3 0 14
:7 0 41 40 :3 0
8 :3 0 15 :7 0
45 44 :3 0 29
186 0 27 4
:3 0 16 :7 0 49
48 :3 0 4 :3 0
17 :7 0 4d 4c
:3 0 2d 1ac 0
2b 4 :3 0 18
:7 0 51 50 :3 0
4 :3 0 19 :7 0
55 54 :3 0 31
1d2 0 2f 8
:3 0 1a :7 0 59
58 :3 0 8 :3 0
1b :7 0 5d 5c
:3 0 35 1f8 0
33 8 :3 0 1c
:7 0 61 60 :3 0
8 :3 0 1d :7 0
65 64 :3 0 39
:2 0 37 4 :3 0
1e :7 0 69 68
:3 0 4 :3 0 1f
:7 0 6d 6c :3 0
20 :3 0 21 :3 0
22 :2 0 4 71
72 0 6f 73
0 372d 2 74
:2 0 24 :2 0 57
4 :3 0 24 :2 0
55 77 79 :6 0
7c 7a 0 372b
0 23 :6 0 24
:2 0 5b 4 :3 0
59 7e 80 :6 0
83 81 0 372b
0 25 :6 0 24
:2 0 5f 4 :3 0
5d 85 87 :6 0
8a 88 0 372b
0 26 :6 0 24
:2 0 63 4 :3 0
61 8c 8e :6 0
91 8f 0 372b
0 27 :6 0 24
:2 0 67 4 :3 0
65 93 95 :6 0
98 96 0 372b
0 28 :6 0 2b
:2 0 6b 4 :3 0
69 9a 9c :6 0
9f 9d 0 372b
0 29 :6 0 2d
:2 0 6f 4 :3 0
6d a1 a3 :6 0
a6 a4 0 372b
0 2a :6 0 2f
:2 0 73 4 :3 0
71 a8 aa :6 0
ad ab 0 372b
0 2c :6 0 2f
:2 0 77 4 :3 0
75 af b1 :6 0
b4 b2 0 372b
0 2e :6 0 2f
:2 0 7b 4 :3 0
79 b6 b8 :6 0
bb b9 0 372b
0 30 :6 0 2f
:2 0 7f 4 :3 0
7d bd bf :6 0
c2 c0 0 372b
0 31 :6 0 2f
:2 0 83 4 :3 0
81 c4 c6 :6 0
c9 c7 0 372b
0 32 :6 0 2f
:2 0 87 4 :3 0
85 cb cd :6 0
d0 ce 0 372b
0 33 :6 0 2f
:2 0 8b 4 :3 0
89 d2 d4 :6 0
d7 d5 0 372b
0 34 :6 0 2f
:2 0 8f 4 :3 0
8d d9 db :6 0
de dc 0 372b
0 35 :6 0 2f
:2 0 93 4 :3 0
91 e0 e2 :6 0
e5 e3 0 372b
0 36 :6 0 2f
:2 0 97 4 :3 0
95 e7 e9 :6 0
ec ea 0 372b
0 37 :6 0 24
:2 0 9b 4 :3 0
99 ee f0 :6 0
f3 f1 0 372b
0 38 :6 0 24
:2 0 9f 4 :3 0
9d f5 f7 :6 0
fa f8 0 372b
0 39 :6 0 3c
:2 0 a3 4 :3 0
a1 fc fe :6 0
101 ff 0 372b
0 3a :6 0 a9
499 0 a7 4
:3 0 a5 103 105
:6 0 108 106 0
372b 0 3b :6 0
40 :2 0 ad 3e
:3 0 10a :7 0 10d
10b 0 372b 0
3d :6 0 4 :3 0
40 :2 0 ab 10f
111 :6 0 114 112
0 372b 0 3f
:6 0 40 :2 0 b1
4 :3 0 af 116
118 :6 0 11b 119
0 372b 0 41
:6 0 40 :2 0 b5
4 :3 0 b3 11d
11f :6 0 122 120
0 372b 0 42
:6 0 40 :2 0 b9
4 :3 0 b7 124
126 :6 0 129 127
0 372b 0 43
:6 0 bf 545 0
bd 4 :3 0 bb
12b 12d :6 0 130
12e 0 372b 0
44 :6 0 24 :2 0
c3 3e :3 0 132
:7 0 135 133 0
372b 0 45 :6 0
4 :3 0 47 :2 0
c1 137 139 :6 0
13c 13a 0 372b
0 46 :6 0 24
:2 0 c7 4 :3 0
c5 13e 140 :6 0
143 141 0 372b
0 48 :6 0 24
:2 0 cb 4 :3 0
c9 145 147 :6 0
14a 148 0 372b
0 49 :6 0 2b
:2 0 cf 4 :3 0
cd 14c 14e :6 0
151 14f 0 372b
0 4a :6 0 47
:2 0 d3 4 :3 0
d1 153 155 :6 0
158 156 0 372b
0 4b :6 0 4e
:2 0 d7 4 :3 0
d5 15a 15c :6 0
15f 15d 0 372b
0 4c :6 0 4e
:2 0 d9 8 :3 0
161 :7 0 165 162
163 372b 0 4d
:6 0 4e :2 0 db
8 :3 0 167 :7 0
16b 168 169 372b
0 4f :6 0 4e
:2 0 dd 8 :3 0
16d :7 0 171 16e
16f 372b 0 50
:6 0 4e :2 0 df
8 :3 0 173 :7 0
177 174 175 372b
0 51 :6 0 4e
:2 0 e1 8 :3 0
179 :7 0 17d 17a
17b 372b 0 52
:6 0 4e :2 0 e3
8 :3 0 17f :7 0
183 180 181 372b
0 53 :6 0 4e
:2 0 e5 8 :3 0
185 :7 0 189 186
187 372b 0 54
:6 0 4e :2 0 e7
8 :3 0 18b :7 0
18f 18c 18d 372b
0 55 :6 0 4e
:2 0 e9 8 :3 0
191 :7 0 195 192
193 372b 0 56
:6 0 4e :2 0 eb
8 :3 0 197 :7 0
19b 198 199 372b
0 57 :6 0 4e
:2 0 ed 8 :3 0
19d :7 0 1a1 19e
19f 372b 0 58
:6 0 4e :2 0 ef
8 :3 0 1a3 :7 0
1a7 1a4 1a5 372b
0 59 :6 0 4e
:2 0 f1 8 :3 0
1a9 :7 0 1ad 1aa
1ab 372b 0 5a
:6 0 4e :2 0 f3
8 :3 0 1af :7 0
1b3 1b0 1b1 372b
0 5b :6 0 4e
:2 0 f5 8 :3 0
1b5 :7 0 1b9 1b6
1b7 372b 0 5c
:6 0 4e :2 0 f7
8 :3 0 1bb :7 0
1bf 1bc 1bd 372b
0 5d :6 0 4e
:2 0 f9 8 :3 0
1c1 :7 0 1c5 1c2
1c3 372b 0 5e
:6 0 4e :2 0 fb
8 :3 0 1c7 :7 0
1cb 1c8 1c9 372b
0 5f :6 0 4e
:2 0 fd 8 :3 0
1cd :7 0 1d1 1ce
1cf 372b 0 60
:6 0 4e :2 0 ff
8 :3 0 1d3 :7 0
1d7 1d4 1d5 372b
0 61 :6 0 4e
:2 0 101 8 :3 0
1d9 :7 0 1dd 1da
1db 372b 0 62
:6 0 4e :2 0 103
8 :3 0 1df :7 0
1e3 1e0 1e1 372b
0 63 :6 0 4e
:2 0 105 8 :3 0
1e5 :7 0 1e9 1e6
1e7 372b 0 64
:6 0 68 :2 0 107
8 :3 0 1eb :7 0
1ef 1ec 1ed 372b
0 65 :6 0 68
:2 0 109 67 :3 0
1f1 :7 0 1f5 1f2
1f3 372b 0 66
:6 0 4e :2 0 10b
67 :3 0 1f7 :7 0
1fb 1f8 1f9 372b
0 69 :6 0 4e
:2 0 10d 8 :3 0
1fd :7 0 201 1fe
1ff 372b 0 6a
:6 0 4e :2 0 10f
8 :3 0 203 :7 0
207 204 205 372b
0 6b :6 0 4e
:2 0 111 8 :3 0
209 :7 0 20d 20a
20b 372b 0 6c
:6 0 4e :2 0 113
8 :3 0 20f :7 0
213 210 211 372b
0 6d :6 0 4e
:2 0 115 8 :3 0
215 :7 0 219 216
217 372b 0 6e
:6 0 4e :2 0 117
8 :3 0 21b :7 0
21f 21c 21d 372b
0 6f :6 0 47
:2 0 119 8 :3 0
221 :7 0 225 222
223 372b 0 70
:6 0 4e :2 0 11d
4 :3 0 11b 227
229 :6 0 22c 22a
0 372b 0 71
:6 0 4e :2 0 11f
8 :3 0 22e :7 0
232 22f 230 372b
0 72 :6 0 4e
:2 0 121 8 :3 0
234 :7 0 238 235
236 372b 0 73
:6 0 2f :2 0 123
8 :3 0 23a :7 0
23e 23b 23c 372b
0 74 :6 0 77
:2 0 127 4 :3 0
125 240 242 :6 0
245 243 0 372b
0 75 :6 0 2f
:2 0 12b 4 :3 0
129 247 249 :6 0
24c 24a 0 372b
0 76 :6 0 4e
:2 0 12f 4 :3 0
12d 24e 250 :6 0
253 251 0 372b
0 78 :6 0 4e
:2 0 131 8 :3 0
255 :7 0 259 256
257 372b 0 79
:6 0 24 :2 0 133
8 :3 0 25b :7 0
25f 25c 25d 372b
0 7a :6 0 24
:2 0 137 7c :3 0
135 261 263 :6 0
266 264 0 372b
0 7b :6 0 24
:2 0 13b 7c :3 0
139 268 26a :6 0
26d 26b 0 372b
0 7d :6 0 24
:2 0 13f 4 :3 0
13d 26f 271 :6 0
274 272 0 372b
0 7e :6 0 24
:2 0 143 4 :3 0
141 276 278 :6 0
27b 279 0 372b
0 7f :6 0 47
:2 0 147 4 :3 0
145 27d 27f :6 0
282 280 0 372b
0 80 :6 0 4e
:2 0 14b 4 :3 0
149 284 286 :6 0
289 287 0 372b
0 81 :6 0 4e
:2 0 14d 8 :3 0
28b :7 0 28f 28c
28d 372b 0 82
:6 0 4e :2 0 14f
8 :3 0 291 :7 0
295 292 293 372b
0 83 :6 0 47
:2 0 151 8 :3 0
297 :7 0 29b 298
299 372b 0 84
:6 0 47 :2 0 153
8 :3 0 29d 0
2 :5 0 2a1 29e
29f 372b 0 85
:6 0 4e :2 0 155
8 :3 0 2a3 0
2 :5 0 2a7 2a4
2a5 372b 0 86
:6 0 4e :2 0 157
8 :3 0 2a9 0
2 :5 0 2ad 2aa
2ab 372b 0 87
:6 0 4e :2 0 159
8 :3 0 2af 0
2 :5 0 2b3 2b0
2b1 372b 0 88
:6 0 24 :2 0 15b
8 :3 0 2b5 0
2 :5 0 2b9 2b6
2b7 372b 0 89
:6 0 4e :2 0 15f
4 :3 0 15d 2bb
2bd :6 0 2c0 2be
0 372b 0 8a
:6 0 163 c71 0
161 8 :3 0 2c2
0 2 :5 0 2c6
2c3 2c4 372b 0
8b :6 0 167 ca5
0 165 8 :3 0
2c8 :7 0 2cb 2c9
0 372b 0 8c
:6 0 8 :3 0 2cd
:7 0 2d0 2ce 0
372b 0 8d :6 0
16b cd9 0 169
8 :3 0 2d2 :7 0
2d5 2d3 0 372b
0 8e :6 0 8
:3 0 2d7 :7 0 2da
2d8 0 372b 0
8f :6 0 16f d0d
0 16d 8 :3 0
2dc :7 0 2df 2dd
0 372b 0 90
:6 0 8 :3 0 2e1
:7 0 2e4 2e2 0
372b 0 91 :9 0
171 8 :3 0 2e6
:7 0 2e9 2e7 0
372b 0 92 :6 0
21 :3 0 22 :2 0
4 2eb 2ec 0
2ed :7 0 2f0 2ee
0 372b 0 93
:6 0 94 :3 0 95
:a 0 2 2ff :4 0
2f2 2f5 0 2f3
:3 0 96 :3 0 97
:3 0 98 :3 0 25
:3 0 99 :3 0 25
:3 0 9a :3 0 39
:4 0 9b 1 :8 0
300 2f2 2f5 301
0 372b 173 301
303 300 302 :6 0
2ff :7 0 301 94
:3 0 9c :a 0 3
31a :5 0 305 308
0 306 :3 0 9d
:3 0 9e :3 0 9f
:3 0 a0 :3 0 a1
:3 0 a2 :3 0 9f
:3 0 a3 :3 0 a1
:3 0 a4 :3 0 a1
:3 0 a5 :3 0 a1
:3 0 a6 :3 0 a7
:3 0 9e :4 0 a8
1 :8 0 31b 305
308 31c 0 372b
175 31c 31e 31b
31d :6 0 31a :7 0
31c 327 328 0
177 21 :3 0 22
:2 0 4 320 321
0 322 :7 0 325
323 0 372b 0
a9 :6 0 32e 32f
0 179 21 :3 0
22 :2 0 4 329
:7 0 32c 32a 0
372b 0 aa :6 0
335 336 0 17b
21 :3 0 22 :2 0
4 330 :7 0 333
331 0 372b 0
ab :6 0 33b 33c
0 17d 21 :3 0
22 :2 0 4 337
:7 0 33a 338 0
372b 0 ac :6 0
ad :3 0 ae :3 0
ad :3 0 af :3 0
33e 33f 0 2
:4 0 17f 340 342
33d 344 343 :2 0
b0 :3 0 b1 :3 0
346 347 0 b2
:4 0 ad :3 0 b3
:3 0 34a 34b 0
2 :4 0 181 34c
34e b4 :4 0 b5
:2 0 b6 :3 0 183
351 353 :3 0 b7
:4 0 b5 :2 0 b8
:4 0 186 356 358
:3 0 b5 :2 0 3
:3 0 189 35a 35c
:3 0 b5 :2 0 b8
:4 0 18c 35e 360
:3 0 b5 :2 0 b9
:4 0 18f 362 364
:3 0 b5 :2 0 b8
:4 0 192 366 368
:3 0 b5 :2 0 5
:3 0 195 36a 36c
:3 0 b5 :2 0 b8
:4 0 198 36e 370
:3 0 b5 :2 0 b9
:4 0 19b 372 374
:3 0 b5 :2 0 b8
:4 0 19e 376 378
:3 0 b5 :2 0 6
:3 0 1a1 37a 37c
:3 0 b5 :2 0 b8
:4 0 1a4 37e 380
:3 0 b5 :2 0 b9
:4 0 1a7 382 384
:3 0 b5 :2 0 a1
:3 0 ba :3 0 7
:3 0 1aa 388 38a
bb :4 0 1ac 387
38d 1af 386 38f
:3 0 b5 :2 0 b9
:4 0 1b2 391 393
:3 0 b5 :2 0 a1
:3 0 ba :3 0 9
:3 0 1b5 397 399
bb :4 0 1b7 396
39c 1ba 395 39e
:3 0 b5 :2 0 b9
:4 0 1bd 3a0 3a2
:3 0 b5 :2 0 a1
:3 0 ba :3 0 a
:3 0 1c0 3a6 3a8
bb :4 0 1c2 3a5
3ab 1c5 3a4 3ad
:3 0 b5 :2 0 b9
:4 0 1c8 3af 3b1
:3 0 b5 :2 0 a1
:3 0 ba :3 0 b
:3 0 1cb 3b5 3b7
bb :4 0 1cd 3b4
3ba 1d0 3b3 3bc
:3 0 b5 :2 0 b9
:4 0 1d3 3be 3c0
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c
:3 0 1d6 3c4 3c6
bb :4 0 1d8 3c3
3c9 1db 3c2 3cb
:3 0 b5 :2 0 b9
:4 0 1de 3cd 3cf
:3 0 b5 :2 0 a1
:3 0 ba :3 0 d
:3 0 1e1 3d3 3d5
bb :4 0 1e3 3d2
3d8 1e6 3d1 3da
:3 0 b5 :2 0 b9
:4 0 1e9 3dc 3de
:3 0 b5 :2 0 a1
:3 0 ba :3 0 e
:3 0 1ec 3e2 3e4
bb :4 0 1ee 3e1
3e7 1f1 3e0 3e9
:3 0 b5 :2 0 b9
:4 0 1f4 3eb 3ed
:3 0 b5 :2 0 a1
:3 0 ba :3 0 f
:3 0 1f7 3f1 3f3
bb :4 0 1f9 3f0
3f6 1fc 3ef 3f8
:3 0 b5 :2 0 b9
:4 0 1ff 3fa 3fc
:3 0 b5 :2 0 b8
:4 0 202 3fe 400
:3 0 b5 :2 0 10
:3 0 205 402 404
:3 0 b5 :2 0 b8
:4 0 208 406 408
:3 0 b5 :2 0 b9
:4 0 20b 40a 40c
:3 0 b5 :2 0 b8
:4 0 20e 40e 410
:3 0 b5 :2 0 11
:3 0 211 412 414
:3 0 b5 :2 0 b8
:4 0 214 416 418
:3 0 b5 :2 0 b9
:4 0 217 41a 41c
:3 0 b5 :2 0 b8
:4 0 21a 41e 420
:3 0 b5 :2 0 12
:3 0 21d 422 424
:3 0 b5 :2 0 b8
:4 0 220 426 428
:3 0 b5 :2 0 b9
:4 0 223 42a 42c
:3 0 b5 :2 0 b8
:4 0 226 42e 430
:3 0 b5 :2 0 13
:3 0 229 432 434
:3 0 b5 :2 0 b8
:4 0 22c 436 438
:3 0 b5 :2 0 b9
:4 0 22f 43a 43c
:3 0 b5 :2 0 b8
:4 0 232 43e 440
:3 0 b5 :2 0 14
:3 0 235 442 444
:3 0 b5 :2 0 b8
:4 0 238 446 448
:3 0 b5 :2 0 b9
:4 0 23b 44a 44c
:3 0 b5 :2 0 a1
:3 0 ba :3 0 15
:3 0 23e 450 452
bb :4 0 240 44f
455 243 44e 457
:3 0 b5 :2 0 b9
:4 0 246 459 45b
:3 0 b5 :2 0 b8
:4 0 249 45d 45f
:3 0 b5 :2 0 16
:3 0 24c 461 463
:3 0 b5 :2 0 b8
:4 0 24f 465 467
:3 0 b5 :2 0 b9
:4 0 252 469 46b
:3 0 b5 :2 0 b8
:4 0 255 46d 46f
:3 0 b5 :2 0 17
:3 0 258 471 473
:3 0 b5 :2 0 b8
:4 0 25b 475 477
:3 0 b5 :2 0 b9
:4 0 25e 479 47b
:3 0 b5 :2 0 b8
:4 0 261 47d 47f
:3 0 b5 :2 0 18
:3 0 264 481 483
:3 0 b5 :2 0 b8
:4 0 267 485 487
:3 0 b5 :2 0 b9
:4 0 26a 489 48b
:3 0 b5 :2 0 b8
:4 0 26d 48d 48f
:3 0 b5 :2 0 19
:3 0 270 491 493
:3 0 b5 :2 0 b8
:4 0 273 495 497
:3 0 b5 :2 0 b9
:4 0 276 499 49b
:3 0 b5 :2 0 a1
:3 0 ba :3 0 1a
:3 0 279 49f 4a1
bb :4 0 27b 49e
4a4 27e 49d 4a6
:3 0 b5 :2 0 b9
:4 0 281 4a8 4aa
:3 0 b5 :2 0 a1
:3 0 ba :3 0 1b
:3 0 284 4ae 4b0
bb :4 0 286 4ad
4b3 289 4ac 4b5
:3 0 b5 :2 0 b9
:4 0 28c 4b7 4b9
:3 0 b5 :2 0 a1
:3 0 ba :3 0 1c
:3 0 28f 4bd 4bf
bb :4 0 291 4bc
4c2 294 4bb 4c4
:3 0 b5 :2 0 b9
:4 0 297 4c6 4c8
:3 0 b5 :2 0 a1
:3 0 ba :3 0 1d
:3 0 29a 4cc 4ce
bb :4 0 29c 4cb
4d1 29f 4ca 4d3
:3 0 b5 :2 0 b9
:4 0 2a2 4d5 4d7
:3 0 b5 :2 0 b8
:4 0 2a5 4d9 4db
:3 0 b5 :2 0 1e
:3 0 2a8 4dd 4df
:3 0 b5 :2 0 b8
:4 0 2ab 4e1 4e3
:3 0 b5 :2 0 b9
:4 0 2ae 4e5 4e7
:3 0 b5 :2 0 b8
:4 0 2b1 4e9 4eb
:3 0 b5 :2 0 1f
:3 0 2b4 4ed 4ef
:3 0 b5 :2 0 b8
:4 0 2b7 4f1 4f3
:3 0 b5 :2 0 bc
:4 0 2ba 4f5 4f7
:3 0 2bd 348 4f9
:2 0 4fb 2c2 4fc
345 4fb 0 4fd
2c4 0 368b ad
:3 0 ae :3 0 4fe
4ff 0 ad :3 0
bd :3 0 501 502
0 47 :2 0 2
:4 0 be :2 0 bf
:2 0 47 :2 0 2c6
507 509 :3 0 2c9
503 50b 500 50d
50c :2 0 b0 :3 0
c0 :3 0 50f 510
0 b2 :4 0 c1
:4 0 b5 :2 0 b6
:3 0 2cd 514 516
:3 0 2d0 511 518
:2 0 51a 2d3 51b
50e 51a 0 51c
2d5 0 368b 25
:3 0 3 :3 0 51d
51e 0 368b 3f
:3 0 5 :3 0 520
521 0 368b 42
:3 0 6 :3 0 523
524 0 368b 2a
:3 0 10 :3 0 526
527 0 368b 2c
:3 0 11 :3 0 529
52a 0 368b 2e
:3 0 16 :3 0 52c
52d 0 368b 30
:3 0 17 :3 0 52f
530 0 368b 31
:3 0 18 :3 0 532
533 0 368b 32
:3 0 19 :3 0 535
536 0 368b 29
:3 0 1f :3 0 538
539 0 368b 59
:3 0 7 :3 0 53b
53c 0 368b 57
:3 0 9 :3 0 53e
53f 0 368b 58
:3 0 e :3 0 541
542 0 368b 56
:3 0 1a :3 0 544
545 0 368b 5a
:3 0 b :3 0 547
548 0 368b 5c
:3 0 f :3 0 54a
54b 0 368b 5b
:3 0 c :3 0 54d
54e 0 368b 50
:3 0 1d :3 0 550
551 0 368b 4d
:3 0 a :3 0 553
554 0 368b 5d
:3 0 d :3 0 556
557 0 368b 52
:3 0 1b :3 0 559
55a 0 368b 53
:3 0 1c :3 0 55c
55d 0 368b 72
:3 0 4e :2 0 55f
560 0 368b 73
:3 0 4e :2 0 562
563 0 368b a1
:3 0 4d :3 0 4e
:2 0 2d7 565 568
c2 :3 0 c3 :2 0
c4 :3 0 56a 56c
0 2dc 56b 56e
:3 0 56f :2 0 3
:3 0 c5 :2 0 2df
572 573 :3 0 574
:2 0 575 :2 0 570
577 576 :2 0 ad
:3 0 ae :3 0 579
57a 0 ad :3 0
bd :3 0 57c 57d
0 c6 :2 0 2
:4 0 c7 :2 0 bf
:2 0 47 :2 0 2e1
582 584 :3 0 2e4
57e 586 57b 588
587 :2 0 b0 :3 0
c0 :3 0 58a 58b
0 b2 :4 0 c8
:4 0 b5 :2 0 b6
:3 0 2e8 58f 591
:3 0 b5 :2 0 c9
:4 0 2eb 593 595
:3 0 b5 :2 0 ca
:4 0 2ee 597 599
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 cb :3 0 59e
59f 0 2f1 59d
5a1 bb :4 0 2f3
59c 5a4 2f6 59b
5a6 :3 0 2f9 58c
5a8 :2 0 5aa 2fc
5ab 589 5aa 0
5ac 2fe 0 5d5
ad :3 0 ae :3 0
5ad 5ae 0 ad
:3 0 bd :3 0 5b0
5b1 0 47 :2 0
2 :4 0 cc :2 0
bf :2 0 47 :2 0
300 5b6 5b8 :3 0
303 5b2 5ba 5af
5bc 5bb :2 0 b0
:3 0 c0 :3 0 5be
5bf 0 b2 :4 0
cd :4 0 b5 :2 0
b6 :3 0 307 5c3
5c5 :3 0 30a 5c0
5c7 :2 0 5c9 30d
5ca 5bd 5c9 0
5cb 30f 0 5d5
ce :3 0 cf :3 0
5cc 5cd 0 c2
:3 0 cb :3 0 5cf
5d0 0 d0 :3 0
311 5ce 5d3 :2 0
5d5 314 5d6 578
5d5 0 5d7 318
0 368b 10 :3 0
c5 :2 0 31a 5d9
5da :3 0 5db :2 0
5dc :2 0 12 :3 0
c5 :2 0 31c 5df
5e0 :3 0 5e1 :2 0
5e2 :2 0 5dd 5e4
5e3 :2 0 13 :3 0
c5 :2 0 31e 5e7
5e8 :3 0 5e9 :2 0
5ea :2 0 5e5 5ec
5eb :2 0 14 :3 0
c5 :2 0 320 5ef
5f0 :3 0 5f1 :2 0
5f2 :2 0 5ed 5f4
5f3 :2 0 a1 :3 0
5c :3 0 4e :2 0
322 5f6 5f9 c2
:3 0 c3 :2 0 d1
:3 0 5fb 5fd 0
327 5fc 5ff :3 0
600 :2 0 5f5 602
601 :2 0 16 :3 0
c5 :2 0 32a 605
606 :3 0 607 :2 0
608 :2 0 a1 :3 0
5c :3 0 4e :2 0
32c 60a 60d c2
:3 0 d2 :2 0 d3
:3 0 60f 611 0
331 610 613 :3 0
614 :2 0 609 616
615 :2 0 ad :3 0
ae :3 0 618 619
0 ad :3 0 bd
:3 0 61b 61c 0
c6 :2 0 2 :4 0
d4 :2 0 bf :2 0
47 :2 0 334 621
623 :3 0 337 61d
625 61a 627 626
:2 0 b0 :3 0 c0
:3 0 629 62a 0
b2 :4 0 d5 :4 0
b5 :2 0 b6 :3 0
33b 62e 630 :3 0
b5 :2 0 c9 :4 0
33e 632 634 :3 0
b5 :2 0 ca :4 0
341 636 638 :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
d6 :3 0 63d 63e
0 344 63c 640
bb :4 0 346 63b
643 349 63a 645
:3 0 34c 62b 647
:2 0 649 34f 64a
628 649 0 64b
351 0 675 ad
:3 0 ae :3 0 64c
64d 0 ad :3 0
bd :3 0 64f 650
0 47 :2 0 2
:4 0 2b :2 0 bf
:2 0 47 :2 0 353
655 657 :3 0 356
651 659 64e 65b
65a :2 0 b0 :3 0
c0 :3 0 65d 65e
0 b2 :4 0 d7
:4 0 b5 :2 0 b6
:3 0 35a 662 664
:3 0 35d 65f 666
:2 0 668 360 669
65c 668 0 66a
362 0 675 ce
:3 0 cf :3 0 66b
66c 0 c2 :3 0
d6 :3 0 66e 66f
0 d0 :3 0 364
66d 672 :2 0 675
d8 :3 0 367 6e2
16 :3 0 c5 :2 0
36b 677 678 :3 0
679 :2 0 67a :2 0
17 :3 0 c5 :2 0
36d 67d 67e :3 0
67f :2 0 680 :2 0
67b 682 681 :2 0
ad :3 0 ae :3 0
684 685 0 ad
:3 0 bd :3 0 687
688 0 c6 :2 0
2 :4 0 d9 :2 0
bf :2 0 47 :2 0
36f 68d 68f :3 0
372 689 691 686
693 692 :2 0 b0
:3 0 c0 :3 0 695
696 0 b2 :4 0
da :4 0 b5 :2 0
b6 :3 0 376 69a
69c :3 0 b5 :2 0
c9 :4 0 379 69e
6a0 :3 0 b5 :2 0
ca :4 0 37c 6a2
6a4 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 d6 :3 0
6a9 6aa 0 37f
6a8 6ac bb :4 0
381 6a7 6af 384
6a6 6b1 :3 0 387
697 6b3 :2 0 6b5
38a 6b6 694 6b5
0 6b7 38c 0
6e0 ad :3 0 ae
:3 0 6b8 6b9 0
ad :3 0 bd :3 0
6bb 6bc 0 47
:2 0 2 :4 0 db
:2 0 bf :2 0 47
:2 0 38e 6c1 6c3
:3 0 391 6bd 6c5
6ba 6c7 6c6 :2 0
b0 :3 0 c0 :3 0
6c9 6ca 0 b2
:4 0 dc :4 0 b5
:2 0 b6 :3 0 395
6ce 6d0 :3 0 398
6cb 6d2 :2 0 6d4
39b 6d5 6c8 6d4
0 6d6 39d 0
6e0 ce :3 0 cf
:3 0 6d7 6d8 0
c2 :3 0 d6 :3 0
6da 6db 0 d0
:3 0 39f 6d9 6de
:2 0 6e0 3a2 6e1
683 6e0 0 6e3
617 675 0 6e3
3a6 0 6e4 3a9
6e5 603 6e4 0
6e6 3ab 0 368b
a1 :3 0 4d :3 0
4e :2 0 3ad 6e7
6ea d2 :2 0 dd
:2 0 3b2 6ec 6ee
:3 0 a1 :3 0 5b
:3 0 4e :2 0 3b5
6f0 6f3 d2 :2 0
dd :2 0 3ba 6f5
6f7 :3 0 6ef 6f9
6f8 :2 0 a1 :3 0
57 :3 0 4e :2 0
3bd 6fb 6fe d2
:2 0 dd :2 0 3c2
700 702 :3 0 6fa
704 703 :2 0 ad
:3 0 ae :3 0 706
707 0 ad :3 0
bd :3 0 709 70a
0 c6 :2 0 2
:4 0 de :2 0 bf
:2 0 47 :2 0 3c5
70f 711 :3 0 3c8
70b 713 708 715
714 :2 0 b0 :3 0
c0 :3 0 717 718
0 b2 :4 0 df
:4 0 b5 :2 0 b6
:3 0 3cc 71c 71e
:3 0 b5 :2 0 c9
:4 0 3cf 720 722
:3 0 b5 :2 0 ca
:4 0 3d2 724 726
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 d6 :3 0 72b
72c 0 3d5 72a
72e bb :4 0 3d7
729 731 3da 728
733 :3 0 3dd 719
735 :2 0 737 3e0
738 716 737 0
739 3e2 0 762
ad :3 0 ae :3 0
73a 73b 0 ad
:3 0 bd :3 0 73d
73e 0 47 :2 0
2 :4 0 e0 :2 0
bf :2 0 47 :2 0
3e4 743 745 :3 0
3e7 73f 747 73c
749 748 :2 0 b0
:3 0 c0 :3 0 74b
74c 0 b2 :4 0
e1 :4 0 b5 :2 0
b6 :3 0 3eb 750
752 :3 0 3ee 74d
754 :2 0 756 3f1
757 74a 756 0
758 3f3 0 762
ce :3 0 cf :3 0
759 75a 0 c2
:3 0 d6 :3 0 75c
75d 0 d0 :3 0
3f5 75b 760 :2 0
762 3f8 763 705
762 0 764 3fc
0 368b 15 :3 0
c5 :2 0 3fe 766
767 :3 0 768 :2 0
769 :2 0 54 :3 0
e2 :2 0 76b 76c
0 76e 400 773
54 :3 0 15 :3 0
76f 770 0 772
402 774 76a 76e
0 775 0 772
0 775 404 0
368b a1 :3 0 4d
:3 0 4e :2 0 407
776 779 c2 :3 0
c3 :2 0 c4 :3 0
77b 77d 0 40c
77c 77f :3 0 780
:2 0 5 :3 0 e3
:2 0 40f 783 784
:3 0 785 :2 0 786
:2 0 781 788 787
:2 0 6 :3 0 e3
:2 0 411 78b 78c
:3 0 78d :2 0 78e
:2 0 789 790 78f
:2 0 e4 :3 0 e5
:3 0 6 :3 0 e4
:3 0 e5 :3 0 5
:3 0 6a :3 0 e6
:4 0 e7 1 :8 0
7a0 21 :3 0 e8
:3 0 79b 79c 0
e9 :3 0 79d 79e
0 7a0 413 7f3
ea :3 0 21 :3 0
e8 :3 0 7a2 7a3
0 e9 :3 0 7a4
7a5 0 7a7 416
7a9 418 7a8 7a7
:2 0 7f1 eb :3 0
21 :3 0 e8 :3 0
7ac 7ad 0 e9
:3 0 7ae 7af 0
7e9 ad :3 0 ae
:3 0 7b1 7b2 0
ad :3 0 bd :3 0
7b4 7b5 0 ec
:2 0 2 :4 0 ed
:2 0 bf :2 0 47
:2 0 41a 7ba 7bc
:3 0 41d 7b6 7be
7b3 7c0 7bf :2 0
b0 :3 0 c0 :3 0
7c2 7c3 0 b2
:4 0 ee :4 0 b5
:2 0 b6 :3 0 421
7c7 7c9 :3 0 b5
:2 0 c9 :4 0 424
7cb 7cd :3 0 b5
:2 0 ef :4 0 427
7cf 7d1 :3 0 b5
:2 0 e9 :3 0 42a
7d3 7d5 :3 0 b5
:2 0 f0 :4 0 42d
7d7 7d9 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 47 :2 0 f3
:2 0 430 7dc 7e0
434 7db 7e2 :3 0
437 7c4 7e4 :2 0
7e6 43a 7e7 7c1
7e6 0 7e8 43c
0 7e9 43e 7ec
:3 0 7ec 0 7ec
7eb 7e9 7ea :6 0
7ee 4 :3 0 441
7f0 443 7ef 7ee
:2 0 7f1 445 :2 0
7f3 0 7f3 7f2
7a0 7f1 :6 0 86d
1 :3 0 21 :3 0
e8 :3 0 7f5 7f6
0 21 :3 0 d2
:2 0 f4 :3 0 7f8
7fa 0 44a 7f9
7fc :3 0 7fd :2 0
a1 :3 0 6a :3 0
4e :2 0 44d 7ff
802 f5 :2 0 4e
:2 0 452 804 806
:3 0 807 :2 0 7fe
809 808 :2 0 ad
:3 0 ae :3 0 80b
80c 0 ad :3 0
bd :3 0 80e 80f
0 c6 :2 0 2
:4 0 f6 :2 0 bf
:2 0 47 :2 0 455
814 816 :3 0 458
810 818 80d 81a
819 :2 0 b0 :3 0
c0 :3 0 81c 81d
0 b2 :4 0 f7
:4 0 b5 :2 0 b6
:3 0 45c 821 823
:3 0 b5 :2 0 c9
:4 0 45f 825 827
:3 0 b5 :2 0 ca
:4 0 462 829 82b
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 f8 :3 0 830
831 0 465 82f
833 bb :4 0 467
82e 836 46a 82d
838 :3 0 46d 81e
83a :2 0 83c 470
83d 81b 83c 0
83e 472 0 867
ad :3 0 ae :3 0
83f 840 0 ad
:3 0 bd :3 0 842
843 0 47 :2 0
2 :4 0 f9 :2 0
bf :2 0 47 :2 0
474 848 84a :3 0
477 844 84c 841
84e 84d :2 0 b0
:3 0 c0 :3 0 850
851 0 b2 :4 0
fa :4 0 b5 :2 0
b6 :3 0 47b 855
857 :3 0 47e 852
859 :2 0 85b 481
85c 84f 85b 0
85d 483 0 867
ce :3 0 cf :3 0
85e 85f 0 c2
:3 0 f8 :3 0 861
862 0 d0 :3 0
485 860 865 :2 0
867 488 868 80a
867 0 869 48c
0 86d 89 :3 0
47 :2 0 86a 86b
0 86d 48e 86e
791 86d 0 86f
492 0 368b 5
:3 0 c5 :2 0 494
871 872 :3 0 873
:2 0 874 :2 0 6
:3 0 c5 :2 0 496
877 878 :3 0 879
:2 0 87a :2 0 875
87c 87b :2 0 b6
:3 0 3f :3 0 e6
:4 0 fb 1 :8 0
887 21 :3 0 e8
:3 0 882 883 0
e9 :3 0 884 885
0 887 498 8da
ea :3 0 21 :3 0
e8 :3 0 889 88a
0 e9 :3 0 88b
88c 0 88e 49b
890 49d 88f 88e
:2 0 8d8 eb :3 0
21 :3 0 e8 :3 0
893 894 0 e9
:3 0 895 896 0
8d0 ad :3 0 ae
:3 0 898 899 0
ad :3 0 bd :3 0
89b 89c 0 ec
:2 0 2 :4 0 fc
:2 0 bf :2 0 47
:2 0 49f 8a1 8a3
:3 0 4a2 89d 8a5
89a 8a7 8a6 :2 0
b0 :3 0 c0 :3 0
8a9 8aa 0 b2
:4 0 fd :4 0 b5
:2 0 b6 :3 0 4a6
8ae 8b0 :3 0 b5
:2 0 c9 :4 0 4a9
8b2 8b4 :3 0 b5
:2 0 ef :4 0 4ac
8b6 8b8 :3 0 b5
:2 0 e9 :3 0 4af
8ba 8bc :3 0 b5
:2 0 f0 :4 0 4b2
8be 8c0 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 47 :2 0 f3
:2 0 4b5 8c3 8c7
4b9 8c2 8c9 :3 0
4bc 8ab 8cb :2 0
8cd 4bf 8ce 8a8
8cd 0 8cf 4c1
0 8d0 4c3 8d3
:3 0 8d3 0 8d3
8d2 8d0 8d1 :6 0
8d5 6 :3 0 4c6
8d7 4c8 8d6 8d5
:2 0 8d8 4ca :2 0
8da 0 8da 8d9
887 8d8 :6 0 8dc
1 :3 0 4cd 8dd
87d 8dc 0 8de
4cf 0 368b 41
:3 0 3f :3 0 8df
8e0 0 368b 6b
:3 0 fe :3 0 ff
:3 0 8e3 8e4 0
100 :3 0 a1 :3 0
50 :3 0 4e :2 0
4d1 8e7 8ea c2
:3 0 101 :3 0 8ec
8ed 0 4d4 8e6
8ef 8f0 :2 0 102
:2 0 4d7 8e5 8f3
8e2 8f4 0 368b
50 :3 0 100 :3 0
a1 :3 0 50 :3 0
4e :2 0 4da 8f8
8fb c2 :3 0 103
:3 0 8fd 8fe 0
4dd 8f7 900 8f6
901 0 368b 55
:3 0 fe :3 0 ff
:3 0 904 905 0
100 :3 0 a1 :3 0
5c :3 0 4e :2 0
4e0 908 90b c2
:3 0 101 :3 0 90d
90e 0 4e3 907
910 911 :2 0 102
:2 0 4e6 906 914
903 915 0 368b
5c :3 0 100 :3 0
a1 :3 0 5c :3 0
4e :2 0 4e9 919
91c c2 :3 0 103
:3 0 91e 91f 0
4ec 918 921 917
922 0 368b a1
:3 0 5c :3 0 4e
:2 0 4ef 924 927
c2 :3 0 d2 :2 0
104 :3 0 929 92b
0 4f4 92a 92d
:3 0 46 :3 0 105
:4 0 92f 930 0
933 d8 :3 0 4f7
95b a1 :3 0 5c
:3 0 4e :2 0 4f9
934 937 c2 :3 0
d2 :2 0 106 :3 0
939 93b 0 4fe
93a 93d :3 0 46
:3 0 107 :4 0 93f
940 0 942 501
943 93e 942 0
95d a1 :3 0 5c
:3 0 4e :2 0 503
944 947 c2 :3 0
d2 :2 0 d3 :3 0
949 94b 0 508
94a 94d :3 0 46
:3 0 47 :4 0 94f
950 0 952 50b
957 46 :3 0 4e
:4 0 953 954 0
956 50d 958 94e
952 0 959 0
956 0 959 50f
0 95a 512 95c
92e 933 0 95d
0 95a 0 95d
514 0 368b a1
:3 0 50 :3 0 4e
:2 0 518 95e 961
108 :2 0 4e :2 0
51d 963 965 :3 0
82 :3 0 4e :2 0
967 968 0 12b2
109 :3 0 82 :3 0
10a :3 0 98 :3 0
25 :4 0 10b 1
:8 0 975 21 :3 0
e8 :3 0 970 971
0 e9 :3 0 972
973 0 975 520
9c8 ea :3 0 21
:3 0 e8 :3 0 977
978 0 e9 :3 0
979 97a 0 97c
523 97e 525 97d
97c :2 0 9c6 eb
:3 0 21 :3 0 e8
:3 0 981 982 0
e9 :3 0 983 984
0 9be ad :3 0
ae :3 0 986 987
0 ad :3 0 bd
:3 0 989 98a 0
ec :2 0 2 :4 0
10c :2 0 bf :2 0
47 :2 0 527 98f
991 :3 0 52a 98b
993 988 995 994
:2 0 b0 :3 0 c0
:3 0 997 998 0
b2 :4 0 10d :4 0
b5 :2 0 b6 :3 0
52e 99c 99e :3 0
b5 :2 0 c9 :4 0
531 9a0 9a2 :3 0
b5 :2 0 ef :4 0
534 9a4 9a6 :3 0
b5 :2 0 e9 :3 0
537 9a8 9aa :3 0
b5 :2 0 f0 :4 0
53a 9ac 9ae :3 0
b5 :2 0 f1 :3 0
f2 :3 0 47 :2 0
f3 :2 0 53d 9b1
9b5 541 9b0 9b7
:3 0 544 999 9b9
:2 0 9bb 547 9bc
996 9bb 0 9bd
549 0 9be 54b
9c1 :3 0 9c1 0
9c1 9c0 9be 9bf
:6 0 9c3 8 :3 0
54e 9c5 550 9c4
9c3 :2 0 9c6 552
:2 0 9c8 0 9c8
9c7 975 9c6 :6 0
12b2 1 :3 0 a1
:3 0 82 :3 0 4e
:2 0 555 9ca 9cd
108 :2 0 4e :2 0
55a 9cf 9d1 :3 0
10e :3 0 4c :3 0
10f :3 0 110 :3 0
25 :4 0 111 1
:8 0 9de 21 :3 0
e8 :3 0 9d9 9da
0 e9 :3 0 9db
9dc 0 9de 55d
a31 ea :3 0 21
:3 0 e8 :3 0 9e0
9e1 0 e9 :3 0
9e2 9e3 0 9e5
560 9e7 562 9e6
9e5 :2 0 a2f eb
:3 0 21 :3 0 e8
:3 0 9ea 9eb 0
e9 :3 0 9ec 9ed
0 a27 ad :3 0
ae :3 0 9ef 9f0
0 ad :3 0 bd
:3 0 9f2 9f3 0
ec :2 0 2 :4 0
112 :2 0 bf :2 0
47 :2 0 564 9f8
9fa :3 0 567 9f4
9fc 9f1 9fe 9fd
:2 0 b0 :3 0 c0
:3 0 a00 a01 0
b2 :4 0 113 :4 0
b5 :2 0 b6 :3 0
56b a05 a07 :3 0
b5 :2 0 c9 :4 0
56e a09 a0b :3 0
b5 :2 0 ef :4 0
571 a0d a0f :3 0
b5 :2 0 e9 :3 0
574 a11 a13 :3 0
b5 :2 0 f0 :4 0
577 a15 a17 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 47 :2 0
f3 :2 0 57a a1a
a1e 57e a19 a20
:3 0 581 a02 a22
:2 0 a24 584 a25
9ff a24 0 a26
586 0 a27 588
a2a :3 0 a2a 0
a2a a29 a27 a28
:6 0 a2c a :3 0
58b a2e 58d a2d
a2c :2 0 a2f 58f
:2 0 a31 0 a31
a30 9de a2f :6 0
aae 1 :3 0 e4
:3 0 114 :3 0 a33
a34 0 4c :3 0
115 :4 0 592 a35
a38 d2 :2 0 4e
:2 0 597 a3a a3c
:3 0 ad :3 0 ae
:3 0 a3e a3f 0
ad :3 0 bd :3 0
a41 a42 0 24
:2 0 2 :4 0 116
:2 0 bf :2 0 47
:2 0 59a a47 a49
:3 0 59d a43 a4b
a40 a4d a4c :2 0
b0 :3 0 c0 :3 0
a4f a50 0 b2
:4 0 117 :4 0 b5
:2 0 b6 :3 0 5a1
a54 a56 :3 0 b5
:2 0 c9 :4 0 5a4
a58 a5a :3 0 b5
:2 0 ca :4 0 5a7
a5c a5e :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 118
:3 0 a63 a64 0
5aa a62 a66 bb
:4 0 5ac a61 a69
5af a60 a6b :3 0
b5 :2 0 119 :4 0
5b2 a6d a6f :3 0
b5 :2 0 b8 :4 0
5b5 a71 a73 :3 0
b5 :2 0 25 :3 0
5b8 a75 a77 :3 0
b5 :2 0 b8 :4 0
5bb a79 a7b :3 0
5be a51 a7d :2 0
a7f 5c1 a80 a4e
a7f 0 a81 5c3
0 aab ad :3 0
ae :3 0 a82 a83
0 ad :3 0 bd
:3 0 a85 a86 0
47 :2 0 2 :4 0
11a :2 0 bf :2 0
47 :2 0 5c5 a8b
a8d :3 0 5c8 a87
a8f a84 a91 a90
:2 0 b0 :3 0 c0
:3 0 a93 a94 0
b2 :4 0 11b :4 0
b5 :2 0 b6 :3 0
5cc a98 a9a :3 0
5cf a95 a9c :2 0
a9e 5d2 a9f a92
a9e 0 aa0 5d4
0 aab ce :3 0
11c :3 0 aa1 aa2
0 c2 :3 0 118
:3 0 aa4 aa5 0
25 :3 0 d0 :3 0
5d6 aa3 aa9 :2 0
aab 5da aac a3d
aab 0 aad 5de
0 aae 5e0 aaf
9d2 aae 0 ab0
5e3 0 12b2 79
:3 0 11d :3 0 a1
:3 0 50 :3 0 4e
:2 0 5e5 ab3 ab6
5e8 ab2 ab8 ab1
ab9 0 12b2 a1
:3 0 79 :3 0 4e
:2 0 5ea abb abe
d2 :2 0 4e :2 0
5ef ac0 ac2 :3 0
50 :3 0 11e :3 0
a1 :3 0 50 :3 0
4e :2 0 5f2 ac6
ac9 5f5 ac5 acb
ac4 acc 0 b3b
a1 :3 0 50 :3 0
4e :2 0 5f7 ace
ad1 d2 :2 0 4e
:2 0 5fc ad3 ad5
:3 0 ad :3 0 ae
:3 0 ad7 ad8 0
ad :3 0 bd :3 0
ada adb 0 c6
:2 0 2 :4 0 11f
:2 0 bf :2 0 47
:2 0 5ff ae0 ae2
:3 0 602 adc ae4
ad9 ae6 ae5 :2 0
b0 :3 0 c0 :3 0
ae8 ae9 0 b2
:4 0 120 :4 0 b5
:2 0 b6 :3 0 606
aed aef :3 0 b5
:2 0 c9 :4 0 609
af1 af3 :3 0 b5
:2 0 ca :4 0 60c
af5 af7 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 d6
:3 0 afc afd 0
60f afb aff bb
:4 0 611 afa b02
614 af9 b04 :3 0
617 aea b06 :2 0
b08 61a b09 ae7
b08 0 b0a 61c
0 b33 ad :3 0
ae :3 0 b0b b0c
0 ad :3 0 bd
:3 0 b0e b0f 0
47 :2 0 2 :4 0
121 :2 0 bf :2 0
47 :2 0 61e b14
b16 :3 0 621 b10
b18 b0d b1a b19
:2 0 b0 :3 0 c0
:3 0 b1c b1d 0
b2 :4 0 122 :4 0
b5 :2 0 b6 :3 0
625 b21 b23 :3 0
628 b1e b25 :2 0
b27 62b b28 b1b
b27 0 b29 62d
0 b33 ce :3 0
cf :3 0 b2a b2b
0 c2 :3 0 d6
:3 0 b2d b2e 0
d0 :3 0 62f b2c
b31 :2 0 b33 632
b34 ad6 b33 0
b35 636 0 b3b
79 :3 0 c2 :3 0
123 :3 0 b37 b38
0 b36 b39 0
b3b 638 b3c ac3
b3b 0 b3d 63c
0 12b2 26 :3 0
25 :3 0 b3e b3f
0 12b2 a1 :3 0
6b :3 0 4e :2 0
63e b41 b44 c3
:2 0 4e :2 0 643
b46 b48 :3 0 39
:3 0 14 :3 0 b4a
b4b 0 b4d 646
bab ad :3 0 ae
:3 0 b4e b4f 0
ad :3 0 bd :3 0
b51 b52 0 c6
:2 0 2 :4 0 124
:2 0 bf :2 0 47
:2 0 648 b57 b59
:3 0 64b b53 b5b
b50 b5d b5c :2 0
b0 :3 0 c0 :3 0
b5f b60 0 b2
:4 0 125 :4 0 b5
:2 0 b6 :3 0 64f
b64 b66 :3 0 b5
:2 0 c9 :4 0 652
b68 b6a :3 0 b5
:2 0 ca :4 0 655
b6c b6e :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 d6
:3 0 b73 b74 0
658 b72 b76 bb
:4 0 65a b71 b79
65d b70 b7b :3 0
660 b61 b7d :2 0
b7f 663 b80 b5e
b7f 0 b81 665
0 baa ad :3 0
ae :3 0 b82 b83
0 ad :3 0 bd
:3 0 b85 b86 0
47 :2 0 2 :4 0
126 :2 0 bf :2 0
47 :2 0 667 b8b
b8d :3 0 66a b87
b8f b84 b91 b90
:2 0 b0 :3 0 c0
:3 0 b93 b94 0
b2 :4 0 127 :4 0
b5 :2 0 b6 :3 0
66e b98 b9a :3 0
671 b95 b9c :2 0
b9e 674 b9f b92
b9e 0 ba0 676
0 baa ce :3 0
cf :3 0 ba1 ba2
0 c2 :3 0 d6
:3 0 ba4 ba5 0
d0 :3 0 678 ba3
ba8 :2 0 baa 67b
bac b49 b4d 0
bad 0 baa 0
bad 67f 0 12b2
84 :3 0 128 :3 0
79 :3 0 50 :3 0
26 :3 0 39 :3 0
29 :3 0 48 :3 0
682 baf bb6 bae
bb7 0 12b2 a1
:3 0 4d :3 0 4e
:2 0 689 bb9 bbc
c2 :3 0 d2 :2 0
c4 :3 0 bbe bc0
0 68e bbf bc2
:3 0 a1 :3 0 84
:3 0 4e :2 0 691
bc4 bc7 d2 :2 0
47 :2 0 696 bc9
bcb :3 0 84 :3 0
c2 :3 0 129 :3 0
bce bcf 0 bcd
bd0 0 bd2 699
bd3 bcc bd2 0
bd4 69b 0 c42
ad :3 0 ae :3 0
bd5 bd6 0 ad
:3 0 bd :3 0 bd8
bd9 0 24 :2 0
2 :4 0 12a :2 0
bf :2 0 47 :2 0
69d bde be0 :3 0
6a0 bda be2 bd7
be4 be3 :2 0 b0
:3 0 c0 :3 0 be6
be7 0 b2 :4 0
12b :4 0 b5 :2 0
b6 :3 0 6a4 beb
bed :3 0 b5 :2 0
c9 :4 0 6a7 bef
bf1 :3 0 b5 :2 0
ca :4 0 6aa bf3
bf5 :3 0 b5 :2 0
a1 :3 0 ba :3 0
84 :3 0 6ad bf9
bfb bb :4 0 6af
bf8 bfe 6b2 bf7
c00 :3 0 b5 :2 0
119 :4 0 6b5 c02
c04 :3 0 b5 :2 0
b8 :4 0 6b8 c06
c08 :3 0 b5 :2 0
48 :3 0 6bb c0a
c0c :3 0 b5 :2 0
b8 :4 0 6be c0e
c10 :3 0 6c1 be8
c12 :2 0 c14 6c4
c15 be5 c14 0
c16 6c6 0 c42
ad :3 0 ae :3 0
c17 c18 0 ad
:3 0 bd :3 0 c1a
c1b 0 47 :2 0
2 :4 0 12c :2 0
bf :2 0 47 :2 0
6c8 c20 c22 :3 0
6cb c1c c24 c19
c26 c25 :2 0 b0
:3 0 c0 :3 0 c28
c29 0 b2 :4 0
12d :4 0 b5 :2 0
b6 :3 0 6cf c2d
c2f :3 0 6d2 c2a
c31 :2 0 c33 6d5
c34 c27 c33 0
c35 6d7 0 c42
ce :3 0 11c :3 0
c36 c37 0 a1
:3 0 84 :3 0 4e
:2 0 6d9 c39 c3c
48 :3 0 d0 :3 0
6dc c38 c40 :2 0
c42 6e0 c43 bc3
c42 0 c44 6e5
0 12b2 a1 :3 0
84 :3 0 4e :2 0
6e7 c45 c48 c3
:2 0 4e :2 0 6ec
c4a c4c :3 0 a1
:3 0 84 :3 0 4e
:2 0 6ef c4e c51
c3 :2 0 47 :2 0
6f4 c53 c55 :3 0
c4d c57 c56 :2 0
ad :3 0 ae :3 0
c59 c5a 0 ad
:3 0 bd :3 0 c5c
c5d 0 24 :2 0
2 :4 0 12e :2 0
bf :2 0 47 :2 0
6f7 c62 c64 :3 0
6fa c5e c66 c5b
c68 c67 :2 0 b0
:3 0 c0 :3 0 c6a
c6b 0 b2 :4 0
12f :4 0 b5 :2 0
b6 :3 0 6fe c6f
c71 :3 0 b5 :2 0
c9 :4 0 701 c73
c75 :3 0 b5 :2 0
ca :4 0 704 c77
c79 :3 0 b5 :2 0
a1 :3 0 ba :3 0
84 :3 0 707 c7d
c7f bb :4 0 709
c7c c82 70c c7b
c84 :3 0 b5 :2 0
119 :4 0 70f c86
c88 :3 0 b5 :2 0
b8 :4 0 712 c8a
c8c :3 0 b5 :2 0
48 :3 0 715 c8e
c90 :3 0 b5 :2 0
b8 :4 0 718 c92
c94 :3 0 71b c6c
c96 :2 0 c98 71e
c99 c69 c98 0
c9a 720 0 cc6
ad :3 0 ae :3 0
c9b c9c 0 ad
:3 0 bd :3 0 c9e
c9f 0 47 :2 0
2 :4 0 130 :2 0
bf :2 0 47 :2 0
722 ca4 ca6 :3 0
725 ca0 ca8 c9d
caa ca9 :2 0 b0
:3 0 c0 :3 0 cac
cad 0 b2 :4 0
131 :4 0 b5 :2 0
b6 :3 0 729 cb1
cb3 :3 0 72c cae
cb5 :2 0 cb7 72f
cb8 cab cb7 0
cb9 731 0 cc6
ce :3 0 11c :3 0
cba cbb 0 a1
:3 0 84 :3 0 4e
:2 0 733 cbd cc0
48 :3 0 d0 :3 0
736 cbc cc4 :2 0
cc6 73a cc7 c58
cc6 0 cc8 73e
0 12b2 a1 :3 0
79 :3 0 4e :2 0
740 cc9 ccc c2
:3 0 d2 :2 0 123
:3 0 cce cd0 0
745 ccf cd2 :3 0
132 :3 0 a1 :3 0
50 :3 0 4e :2 0
748 cd5 cd8 74b
cd4 cda c3 :2 0
4e :2 0 74f cdc
cde :3 0 98 :3 0
a1 :3 0 133 :3 0
a1 :3 0 134 :3 0
135 :3 0 25 :3 0
5f :3 0 60 :3 0
64 :3 0 10f :3 0
110 :3 0 26 :4 0
136 1 :8 0 cf3
21 :3 0 e8 :3 0
cee cef 0 e9
:3 0 cf0 cf1 0
cf3 752 d46 ea
:3 0 21 :3 0 e8
:3 0 cf5 cf6 0
e9 :3 0 cf7 cf8
0 cfa 755 cfc
757 cfb cfa :2 0
d44 eb :3 0 21
:3 0 e8 :3 0 cff
d00 0 e9 :3 0
d01 d02 0 d3c
ad :3 0 ae :3 0
d04 d05 0 ad
:3 0 bd :3 0 d07
d08 0 ec :2 0
2 :4 0 137 :2 0
bf :2 0 47 :2 0
759 d0d d0f :3 0
75c d09 d11 d06
d13 d12 :2 0 b0
:3 0 c0 :3 0 d15
d16 0 b2 :4 0
138 :4 0 b5 :2 0
b6 :3 0 760 d1a
d1c :3 0 b5 :2 0
c9 :4 0 763 d1e
d20 :3 0 b5 :2 0
ef :4 0 766 d22
d24 :3 0 b5 :2 0
e9 :3 0 769 d26
d28 :3 0 b5 :2 0
f0 :4 0 76c d2a
d2c :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
76f d2f d33 773
d2e d35 :3 0 776
d17 d37 :2 0 d39
779 d3a d14 d39
0 d3b 77b 0
d3c 77d d3f :3 0
d3f 0 d3f d3e
d3c d3d :6 0 d41
c :3 0 780 d43
782 d42 d41 :2 0
d44 784 :2 0 d46
0 d46 d45 cf3
d44 :6 0 d48 1
:3 0 787 dcc 139
:3 0 13a :3 0 139
:3 0 13b :3 0 139
:3 0 13c :3 0 139
:3 0 98 :3 0 a1
:3 0 13d :3 0 133
:3 0 a1 :3 0 13d
:3 0 134 :3 0 13d
:3 0 135 :3 0 139
:3 0 13e :3 0 139
:3 0 13f :3 0 72
:3 0 43 :3 0 44
:3 0 25 :3 0 5f
:3 0 60 :3 0 64
:3 0 73 :3 0 10f
:3 0 13d :3 0 10f
:3 0 139 :3 0 139
:3 0 110 :3 0 26
:3 0 13d :3 0 110
:3 0 139 :3 0 98
:4 0 140 1 :8 0
d76 21 :3 0 e8
:3 0 d71 d72 0
e9 :3 0 d73 d74
0 d76 789 dc9
ea :3 0 21 :3 0
e8 :3 0 d78 d79
0 e9 :3 0 d7a
d7b 0 d7d 78c
d7f 78e d7e d7d
:2 0 dc7 eb :3 0
21 :3 0 e8 :3 0
d82 d83 0 e9
:3 0 d84 d85 0
dbf ad :3 0 ae
:3 0 d87 d88 0
ad :3 0 bd :3 0
d8a d8b 0 ec
:2 0 2 :4 0 141
:2 0 bf :2 0 47
:2 0 790 d90 d92
:3 0 793 d8c d94
d89 d96 d95 :2 0
b0 :3 0 c0 :3 0
d98 d99 0 b2
:4 0 142 :4 0 b5
:2 0 b6 :3 0 797
d9d d9f :3 0 b5
:2 0 c9 :4 0 79a
da1 da3 :3 0 b5
:2 0 ef :4 0 79d
da5 da7 :3 0 b5
:2 0 e9 :3 0 7a0
da9 dab :3 0 b5
:2 0 f0 :4 0 7a3
dad daf :3 0 b5
:2 0 f1 :3 0 f2
:3 0 47 :2 0 f3
:2 0 7a6 db2 db6
7aa db1 db8 :3 0
7ad d9a dba :2 0
dbc 7b0 dbd d97
dbc 0 dbe 7b2
0 dbf 7b4 dc2
:3 0 dc2 0 dc2
dc1 dbf dc0 :6 0
dc4 e :3 0 7b7
dc6 7b9 dc5 dc4
:2 0 dc7 7bb :2 0
dc9 0 dc9 dc8
d76 dc7 :6 0 dcb
1 :3 0 7be dcd
cdf d48 0 dce
0 dcb 0 dce
7c0 0 e4a 21
:3 0 e8 :3 0 dcf
dd0 0 21 :3 0
c3 :2 0 f4 :3 0
dd2 dd4 0 7c5
dd3 dd6 :3 0 dd7
:2 0 ad :3 0 ae
:3 0 dd9 dda 0
ad :3 0 bd :3 0
ddc ddd 0 24
:2 0 2 :4 0 143
:2 0 bf :2 0 47
:2 0 7c8 de2 de4
:3 0 7cb dde de6
ddb de8 de7 :2 0
b0 :3 0 c0 :3 0
dea deb 0 b2
:4 0 144 :4 0 b5
:2 0 b6 :3 0 7cf
def df1 :3 0 b5
:2 0 c9 :4 0 7d2
df3 df5 :3 0 b5
:2 0 ca :4 0 7d5
df7 df9 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 145
:3 0 dfe dff 0
7d8 dfd e01 bb
:4 0 7da dfc e04
7dd dfb e06 :3 0
b5 :2 0 119 :4 0
7e0 e08 e0a :3 0
b5 :2 0 b8 :4 0
7e3 e0c e0e :3 0
b5 :2 0 26 :3 0
7e6 e10 e12 :3 0
b5 :2 0 b8 :4 0
7e9 e14 e16 :3 0
7ec dec e18 :2 0
e1a 7ef e1b de9
e1a 0 e1c 7f1
0 e46 ad :3 0
ae :3 0 e1d e1e
0 ad :3 0 bd
:3 0 e20 e21 0
47 :2 0 2 :4 0
146 :2 0 bf :2 0
47 :2 0 7f3 e26
e28 :3 0 7f6 e22
e2a e1f e2c e2b
:2 0 b0 :3 0 c0
:3 0 e2e e2f 0
b2 :4 0 147 :4 0
b5 :2 0 b6 :3 0
7fa e33 e35 :3 0
7fd e30 e37 :2 0
e39 800 e3a e2d
e39 0 e3b 802
0 e46 ce :3 0
11c :3 0 e3c e3d
0 c2 :3 0 145
:3 0 e3f e40 0
26 :3 0 d0 :3 0
804 e3e e44 :2 0
e46 808 e47 dd8
e46 0 e48 80c
0 e4a d8 :3 0
80e 109f a1 :3 0
79 :3 0 4e :2 0
811 e4b e4e c2
:3 0 d2 :2 0 148
:3 0 e50 e52 0
816 e51 e54 :3 0
98 :3 0 149 :3 0
14a :3 0 25 :3 0
50 :3 0 23 :3 0
14b :3 0 110 :3 0
26 :4 0 14c 1
:8 0 e65 21 :3 0
e8 :3 0 e60 e61
0 e9 :3 0 e62
e63 0 e65 819
eb8 ea :3 0 21
:3 0 e8 :3 0 e67
e68 0 e9 :3 0
e69 e6a 0 e6c
81c e6e 81e e6d
e6c :2 0 eb6 eb
:3 0 21 :3 0 e8
:3 0 e71 e72 0
e9 :3 0 e73 e74
0 eae ad :3 0
ae :3 0 e76 e77
0 ad :3 0 bd
:3 0 e79 e7a 0
ec :2 0 2 :4 0
14d :2 0 bf :2 0
47 :2 0 820 e7f
e81 :3 0 823 e7b
e83 e78 e85 e84
:2 0 b0 :3 0 c0
:3 0 e87 e88 0
b2 :4 0 14e :4 0
b5 :2 0 b6 :3 0
827 e8c e8e :3 0
b5 :2 0 c9 :4 0
82a e90 e92 :3 0
b5 :2 0 ef :4 0
82d e94 e96 :3 0
b5 :2 0 e9 :3 0
830 e98 e9a :3 0
b5 :2 0 f0 :4 0
833 e9c e9e :3 0
b5 :2 0 f1 :3 0
f2 :3 0 47 :2 0
f3 :2 0 836 ea1
ea5 83a ea0 ea7
:3 0 83d e89 ea9
:2 0 eab 840 eac
e86 eab 0 ead
842 0 eae 844
eb1 :3 0 eb1 0
eb1 eb0 eae eaf
:6 0 eb3 10 :3 0
847 eb5 849 eb4
eb3 :2 0 eb6 84b
:2 0 eb8 0 eb8
eb7 e65 eb6 :6 0
102f 1 :3 0 21
:3 0 e8 :3 0 eba
ebb 0 21 :3 0
c3 :2 0 f4 :3 0
ebd ebf 0 850
ebe ec1 :3 0 ec2
:2 0 ad :3 0 ae
:3 0 ec4 ec5 0
ad :3 0 bd :3 0
ec7 ec8 0 24
:2 0 2 :4 0 14f
:2 0 bf :2 0 47
:2 0 853 ecd ecf
:3 0 856 ec9 ed1
ec6 ed3 ed2 :2 0
b0 :3 0 c0 :3 0
ed5 ed6 0 b2
:4 0 150 :4 0 b5
:2 0 b6 :3 0 85a
eda edc :3 0 b5
:2 0 c9 :4 0 85d
ede ee0 :3 0 b5
:2 0 ca :4 0 860
ee2 ee4 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 145
:3 0 ee9 eea 0
863 ee8 eec bb
:4 0 865 ee7 eef
868 ee6 ef1 :3 0
b5 :2 0 119 :4 0
86b ef3 ef5 :3 0
b5 :2 0 b8 :4 0
86e ef7 ef9 :3 0
b5 :2 0 26 :3 0
871 efb efd :3 0
b5 :2 0 b8 :4 0
874 eff f01 :3 0
877 ed7 f03 :2 0
f05 87a f06 ed4
f05 0 f07 87c
0 f31 ad :3 0
ae :3 0 f08 f09
0 ad :3 0 bd
:3 0 f0b f0c 0
47 :2 0 2 :4 0
151 :2 0 bf :2 0
47 :2 0 87e f11
f13 :3 0 881 f0d
f15 f0a f17 f16
:2 0 b0 :3 0 c0
:3 0 f19 f1a 0
b2 :4 0 152 :4 0
b5 :2 0 b6 :3 0
885 f1e f20 :3 0
888 f1b f22 :2 0
f24 88b f25 f18
f24 0 f26 88d
0 f31 ce :3 0
11c :3 0 f27 f28
0 c2 :3 0 145
:3 0 f2a f2b 0
26 :3 0 d0 :3 0
88f f29 f2f :2 0
f31 893 f32 ec3
f31 0 f33 897
0 102f 153 :3 0
41 :3 0 153 :3 0
154 :3 0 41 :3 0
a1 :3 0 133 :3 0
a1 :3 0 134 :3 0
135 :3 0 41 :3 0
5f :3 0 60 :3 0
64 :3 0 10f :3 0
98 :3 0 25 :3 0
110 :3 0 25 :4 0
155 1 :8 0 f4d
21 :3 0 e8 :3 0
f48 f49 0 e9
:3 0 f4a f4b 0
f4d 899 fa0 ea
:3 0 21 :3 0 e8
:3 0 f4f f50 0
e9 :3 0 f51 f52
0 f54 89c f56
89e f55 f54 :2 0
f9e eb :3 0 21
:3 0 e8 :3 0 f59
f5a 0 e9 :3 0
f5b f5c 0 f96
ad :3 0 ae :3 0
f5e f5f 0 ad
:3 0 bd :3 0 f61
f62 0 ec :2 0
2 :4 0 156 :2 0
bf :2 0 47 :2 0
8a0 f67 f69 :3 0
8a3 f63 f6b f60
f6d f6c :2 0 b0
:3 0 c0 :3 0 f6f
f70 0 b2 :4 0
157 :4 0 b5 :2 0
b6 :3 0 8a7 f74
f76 :3 0 b5 :2 0
c9 :4 0 8aa f78
f7a :3 0 b5 :2 0
ef :4 0 8ad f7c
f7e :3 0 b5 :2 0
e9 :3 0 8b0 f80
f82 :3 0 b5 :2 0
f0 :4 0 8b3 f84
f86 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
8b6 f89 f8d 8ba
f88 f8f :3 0 8bd
f71 f91 :2 0 f93
8c0 f94 f6e f93
0 f95 8c2 0
f96 8c4 f99 :3 0
f99 0 f99 f98
f96 f97 :6 0 f9b
12 :3 0 8c7 f9d
8c9 f9c f9b :2 0
f9e 8cb :2 0 fa0
0 fa0 f9f f4d
f9e :6 0 102f 1
:3 0 21 :3 0 e8
:3 0 fa2 fa3 0
21 :3 0 c3 :2 0
f4 :3 0 fa5 fa7
0 8d0 fa6 fa9
:3 0 faa :2 0 ad
:3 0 ae :3 0 fac
fad 0 ad :3 0
bd :3 0 faf fb0
0 24 :2 0 2
:4 0 158 :2 0 bf
:2 0 47 :2 0 8d3
fb5 fb7 :3 0 8d6
fb1 fb9 fae fbb
fba :2 0 b0 :3 0
c0 :3 0 fbd fbe
0 b2 :4 0 159
:4 0 b5 :2 0 b6
:3 0 8da fc2 fc4
:3 0 b5 :2 0 c9
:4 0 8dd fc6 fc8
:3 0 b5 :2 0 ca
:4 0 8e0 fca fcc
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 145 :3 0 fd1
fd2 0 8e3 fd0
fd4 bb :4 0 8e5
fcf fd7 8e8 fce
fd9 :3 0 b5 :2 0
119 :4 0 8eb fdb
fdd :3 0 b5 :2 0
b8 :4 0 8ee fdf
fe1 :3 0 b5 :2 0
25 :3 0 8f1 fe3
fe5 :3 0 b5 :2 0
b8 :4 0 8f4 fe7
fe9 :3 0 8f7 fbf
feb :2 0 fed 8fa
fee fbc fed 0
fef 8fc 0 1019
ad :3 0 ae :3 0
ff0 ff1 0 ad
:3 0 bd :3 0 ff3
ff4 0 47 :2 0
2 :4 0 15a :2 0
bf :2 0 47 :2 0
8fe ff9 ffb :3 0
901 ff5 ffd ff2
fff ffe :2 0 b0
:3 0 c0 :3 0 1001
1002 0 b2 :4 0
15b :4 0 b5 :2 0
b6 :3 0 905 1006
1008 :3 0 908 1003
100a :2 0 100c 90b
100d 1000 100c 0
100e 90d 0 1019
ce :3 0 11c :3 0
100f 1010 0 c2
:3 0 145 :3 0 1012
1013 0 25 :3 0
d0 :3 0 90f 1011
1017 :2 0 1019 913
101a fab 1019 0
101b 917 0 102f
23 :3 0 e3 :2 0
919 101d 101e :3 0
101f :2 0 79 :3 0
c2 :3 0 123 :3 0
1022 1023 0 1021
1024 0 102c 50
:3 0 15c :3 0 50
:3 0 91b 1027 1029
1026 102a 0 102c
91d 102d 1020 102c
0 102e 920 0
102f 922 1030 e55
102f 0 10a1 ad
:3 0 ae :3 0 1031
1032 0 ad :3 0
bd :3 0 1034 1035
0 24 :2 0 2
:4 0 15d :2 0 bf
:2 0 47 :2 0 928
103a 103c :3 0 92b
1036 103e 1033 1040
103f :2 0 b0 :3 0
c0 :3 0 1042 1043
0 b2 :4 0 15e
:4 0 b5 :2 0 b6
:3 0 92f 1047 1049
:3 0 b5 :2 0 c9
:4 0 932 104b 104d
:3 0 b5 :2 0 ca
:4 0 935 104f 1051
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 d6 :3 0 1056
1057 0 938 1055
1059 bb :4 0 93a
1054 105c 93d 1053
105e :3 0 b5 :2 0
119 :4 0 940 1060
1062 :3 0 b5 :2 0
b8 :4 0 943 1064
1066 :3 0 b5 :2 0
25 :3 0 946 1068
106a :3 0 b5 :2 0
b8 :4 0 949 106c
106e :3 0 94c 1044
1070 :2 0 1072 94f
1073 1041 1072 0
1074 951 0 109e
ad :3 0 ae :3 0
1075 1076 0 ad
:3 0 bd :3 0 1078
1079 0 47 :2 0
2 :4 0 15f :2 0
bf :2 0 47 :2 0
953 107e 1080 :3 0
956 107a 1082 1077
1084 1083 :2 0 b0
:3 0 c0 :3 0 1086
1087 0 b2 :4 0
160 :4 0 b5 :2 0
b6 :3 0 95a 108b
108d :3 0 95d 1088
108f :2 0 1091 960
1092 1085 1091 0
1093 962 0 109e
ce :3 0 11c :3 0
1094 1095 0 c2
:3 0 d6 :3 0 1097
1098 0 25 :3 0
d0 :3 0 964 1096
109c :2 0 109e 968
10a0 cd3 e4a 0
10a1 0 109e 0
10a1 96c 0 12b2
a1 :3 0 5c :3 0
4e :2 0 970 10a2
10a5 c2 :3 0 c3
:2 0 d3 :3 0 10a7
10a9 0 975 10a8
10ab :3 0 161 :3 0
e4 :3 0 162 :3 0
41 :3 0 163 :3 0
164 :3 0 a1 :3 0
e4 :3 0 162 :3 0
164 :3 0 a1 :3 0
e4 :3 0 162 :3 0
165 :3 0 4b :3 0
6d :3 0 71 :3 0
45 :3 0 6e :3 0
6f :3 0 166 :3 0
9a :3 0 39 :4 0
167 1 :8 0 10ca
21 :3 0 e8 :3 0
10c5 10c6 0 e9
:3 0 10c7 10c8 0
10ca 978 111d ea
:3 0 21 :3 0 e8
:3 0 10cc 10cd 0
e9 :3 0 10ce 10cf
0 10d1 97b 10d3
97d 10d2 10d1 :2 0
111b eb :3 0 21
:3 0 e8 :3 0 10d6
10d7 0 e9 :3 0
10d8 10d9 0 1113
ad :3 0 ae :3 0
10db 10dc 0 ad
:3 0 bd :3 0 10de
10df 0 ec :2 0
2 :4 0 168 :2 0
bf :2 0 47 :2 0
97f 10e4 10e6 :3 0
982 10e0 10e8 10dd
10ea 10e9 :2 0 b0
:3 0 c0 :3 0 10ec
10ed 0 b2 :4 0
169 :4 0 b5 :2 0
b6 :3 0 986 10f1
10f3 :3 0 b5 :2 0
c9 :4 0 989 10f5
10f7 :3 0 b5 :2 0
ef :4 0 98c 10f9
10fb :3 0 b5 :2 0
e9 :3 0 98f 10fd
10ff :3 0 b5 :2 0
f0 :4 0 992 1101
1103 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
995 1106 110a 999
1105 110c :3 0 99c
10ee 110e :2 0 1110
99f 1111 10eb 1110
0 1112 9a1 0
1113 9a3 1116 :3 0
1116 0 1116 1115
1113 1114 :6 0 1118
14 :3 0 9a6 111a
9a8 1119 1118 :2 0
111b 9aa :2 0 111d
0 111d 111c 10ca
111b :6 0 12af 1
:3 0 21 :3 0 e8
:3 0 111f 1120 0
21 :3 0 d2 :2 0
16a :3 0 1122 1124
0 9af 1123 1126
:3 0 1127 :2 0 ad
:3 0 ae :3 0 1129
112a 0 ad :3 0
bd :3 0 112c 112d
0 24 :2 0 2
:4 0 16b :2 0 bf
:2 0 47 :2 0 9b2
1132 1134 :3 0 9b5
112e 1136 112b 1138
1137 :2 0 b0 :3 0
c0 :3 0 113a 113b
0 b2 :4 0 16c
:4 0 b5 :2 0 b6
:3 0 9b9 113f 1141
:3 0 b5 :2 0 c9
:4 0 9bc 1143 1145
:3 0 b5 :2 0 ca
:4 0 9bf 1147 1149
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 145 :3 0 114e
114f 0 9c2 114d
1151 bb :4 0 9c4
114c 1154 9c7 114b
1156 :3 0 b5 :2 0
119 :4 0 9ca 1158
115a :3 0 b5 :2 0
b8 :4 0 9cd 115c
115e :3 0 b5 :2 0
39 :3 0 9d0 1160
1162 :3 0 b5 :2 0
b8 :4 0 9d3 1164
1166 :3 0 9d6 113c
1168 :2 0 116a 9d9
116b 1139 116a 0
116c 9db 0 1197
ad :3 0 ae :3 0
116d 116e 0 ad
:3 0 bd :3 0 1170
1171 0 47 :2 0
2 :4 0 16d :2 0
bf :2 0 47 :2 0
9dd 1176 1178 :3 0
9e0 1172 117a 116f
117c 117b :2 0 b0
:3 0 c0 :3 0 117e
117f 0 b2 :4 0
16e :4 0 b5 :2 0
b6 :3 0 9e4 1183
1185 :3 0 9e7 1180
1187 :2 0 1189 9ea
118a 117d 1189 0
118b 9ec 0 1197
ce :3 0 11c :3 0
118c 118d 0 c2
:3 0 145 :3 0 118f
1190 0 39 :3 0
d0 :3 0 9ee 118e
1194 :2 0 1197 d8
:3 0 9f2 12ad 21
:3 0 e8 :3 0 1198
1199 0 21 :3 0
d2 :2 0 f4 :3 0
119b 119d 0 9f8
119c 119f :3 0 11a0
:2 0 f1 :3 0 71
:3 0 47 :2 0 47
:2 0 9fb 11a2 11a6
d2 :2 0 4e :4 0
a01 11a8 11aa :3 0
a1 :3 0 6f :3 0
4e :2 0 a04 11ac
11af 108 :2 0 4e
:2 0 a09 11b1 11b3
:3 0 a1 :3 0 6d
:3 0 4e :2 0 a0c
11b5 11b8 a1 :3 0
108 :2 0 6f :3 0
4e :2 0 a0f 11ba
11be a14 11bb 11c0
:3 0 11b4 11c2 11c1
:2 0 11c3 :2 0 11ab
11c5 11c4 :2 0 ad
:3 0 ae :3 0 11c7
11c8 0 ad :3 0
bd :3 0 11ca 11cb
0 24 :2 0 2
:4 0 16f :2 0 bf
:2 0 47 :2 0 a17
11d0 11d2 :3 0 a1a
11cc 11d4 11c9 11d6
11d5 :2 0 b0 :3 0
c0 :3 0 11d8 11d9
0 b2 :4 0 170
:4 0 b5 :2 0 b6
:3 0 a1e 11dd 11df
:3 0 b5 :2 0 c9
:4 0 a21 11e1 11e3
:3 0 b5 :2 0 ca
:4 0 a24 11e5 11e7
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 171 :3 0 11ec
11ed 0 a27 11eb
11ef bb :4 0 a29
11ea 11f2 a2c 11e9
11f4 :3 0 b5 :2 0
119 :4 0 a2f 11f6
11f8 :3 0 b5 :2 0
b8 :4 0 a32 11fa
11fc :3 0 b5 :2 0
39 :3 0 a35 11fe
1200 :3 0 b5 :2 0
b8 :4 0 a38 1202
1204 :3 0 a3b 11da
1206 :2 0 1208 a3e
1209 11d7 1208 0
120a a40 0 1234
ad :3 0 ae :3 0
120b 120c 0 ad
:3 0 bd :3 0 120e
120f 0 47 :2 0
2 :4 0 172 :2 0
bf :2 0 47 :2 0
a42 1214 1216 :3 0
a45 1210 1218 120d
121a 1219 :2 0 b0
:3 0 c0 :3 0 121c
121d 0 b2 :4 0
173 :4 0 b5 :2 0
b6 :3 0 a49 1221
1223 :3 0 a4c 121e
1225 :2 0 1227 a4f
1228 121b 1227 0
1229 a51 0 1234
ce :3 0 11c :3 0
122a 122b 0 c2
:3 0 171 :3 0 122d
122e 0 39 :3 0
d0 :3 0 a53 122c
1232 :2 0 1234 a57
1235 11c6 1234 0
1236 a5b 0 12ab
a1 :3 0 6d :3 0
4e :2 0 a5d 1237
123a a1 :3 0 f5
:2 0 6e :3 0 4e
:2 0 a60 123c 1240
a65 123d 1242 :3 0
e4 :3 0 174 :3 0
175 :3 0 f1 :3 0
45 :3 0 e4 :3 0
176 :3 0 41 :3 0
e6 :4 0 177 1
:8 0 1253 21 :3 0
e8 :3 0 124e 124f
0 e9 :3 0 1250
1251 0 1253 a68
12a6 ea :3 0 21
:3 0 e8 :3 0 1255
1256 0 e9 :3 0
1257 1258 0 125a
a6b 125c a6d 125b
125a :2 0 12a4 eb
:3 0 21 :3 0 e8
:3 0 125f 1260 0
e9 :3 0 1261 1262
0 129c ad :3 0
ae :3 0 1264 1265
0 ad :3 0 bd
:3 0 1267 1268 0
ec :2 0 2 :4 0
178 :2 0 bf :2 0
47 :2 0 a6f 126d
126f :3 0 a72 1269
1271 1266 1273 1272
:2 0 b0 :3 0 c0
:3 0 1275 1276 0
b2 :4 0 179 :4 0
b5 :2 0 b6 :3 0
a76 127a 127c :3 0
b5 :2 0 c9 :4 0
a79 127e 1280 :3 0
b5 :2 0 ef :4 0
a7c 1282 1284 :3 0
b5 :2 0 e9 :3 0
a7f 1286 1288 :3 0
b5 :2 0 f0 :4 0
a82 128a 128c :3 0
b5 :2 0 f1 :3 0
f2 :3 0 47 :2 0
f3 :2 0 a85 128f
1293 a89 128e 1295
:3 0 a8c 1277 1297
:2 0 1299 a8f 129a
1274 1299 0 129b
a91 0 129c a93
129f :3 0 129f 0
129f 129e 129c 129d
:6 0 12a1 16 :3 0
a96 12a3 a98 12a2
12a1 :2 0 12a4 a9a
:2 0 12a6 0 12a6
12a5 1253 12a4 :6 0
12a8 1 :3 0 a9d
12a9 1243 12a8 0
12aa a9f 0 12ab
aa1 12ac 11a1 12ab
0 12ae 1128 1197
0 12ae aa4 0
12af aa7 12b0 10ac
12af 0 12b1 aaa
0 12b2 aac 12b3
966 12b2 0 12b4
ab9 0 368b a1
:3 0 50 :3 0 4e
:2 0 abb 12b5 12b8
d2 :2 0 4e :2 0
ac0 12ba 12bc :3 0
a1 :3 0 5c :3 0
4e :2 0 ac3 12be
12c1 c2 :3 0 d2
:2 0 d3 :3 0 12c3
12c5 0 ac8 12c4
12c7 :3 0 16 :3 0
c5 :2 0 acb 12ca
12cb :3 0 12cc :2 0
12c8 12ce 12cd :2 0
a1 :3 0 6b :3 0
4e :2 0 acd 12d0
12d3 d2 :2 0 4e
:2 0 ad2 12d5 12d7
:3 0 12cf 12d9 12d8
:2 0 ad :3 0 ae
:3 0 12db 12dc 0
ad :3 0 bd :3 0
12de 12df 0 24
:2 0 2 :4 0 17a
:2 0 bf :2 0 47
:2 0 ad5 12e4 12e6
:3 0 ad8 12e0 12e8
12dd 12ea 12e9 :2 0
b0 :3 0 c0 :3 0
12ec 12ed 0 b2
:4 0 17b :4 0 b5
:2 0 b6 :3 0 adc
12f1 12f3 :3 0 b5
:2 0 c9 :4 0 adf
12f5 12f7 :3 0 b5
:2 0 ca :4 0 ae2
12f9 12fb :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 17c
:3 0 1300 1301 0
ae5 12ff 1303 bb
:4 0 ae7 12fe 1306
aea 12fd 1308 :3 0
b5 :2 0 119 :4 0
aed 130a 130c :3 0
b5 :2 0 b8 :4 0
af0 130e 1310 :3 0
b5 :2 0 25 :3 0
af3 1312 1314 :3 0
b5 :2 0 b8 :4 0
af6 1316 1318 :3 0
af9 12ee 131a :2 0
131c afc 131d 12eb
131c 0 131e afe
0 1348 ad :3 0
ae :3 0 131f 1320
0 ad :3 0 bd
:3 0 1322 1323 0
47 :2 0 2 :4 0
17d :2 0 bf :2 0
47 :2 0 b00 1328
132a :3 0 b03 1324
132c 1321 132e 132d
:2 0 b0 :3 0 c0
:3 0 1330 1331 0
b2 :4 0 17e :4 0
b5 :2 0 b6 :3 0
b07 1335 1337 :3 0
b0a 1332 1339 :2 0
133b b0d 133c 132f
133b 0 133d b0f
0 1348 ce :3 0
11c :3 0 133e 133f
0 c2 :3 0 17c
:3 0 1341 1342 0
25 :3 0 d0 :3 0
b11 1340 1346 :2 0
1348 b15 1349 12da
1348 0 134a b19
0 14a6 a1 :3 0
4d :3 0 4e :2 0
b1b 134b 134e c2
:3 0 c3 :2 0 c4
:3 0 1350 1352 0
b20 1351 1354 :3 0
135 :3 0 a1 :3 0
133 :3 0 a1 :3 0
134 :3 0 64 :3 0
5f :3 0 60 :3 0
10f :3 0 110 :3 0
25 :4 0 17f 1
:8 0 1367 21 :3 0
e8 :3 0 1362 1363
0 e9 :3 0 1364
1365 0 1367 b23
13ba ea :3 0 21
:3 0 e8 :3 0 1369
136a 0 e9 :3 0
136b 136c 0 136e
b26 1370 b28 136f
136e :2 0 13b8 eb
:3 0 21 :3 0 e8
:3 0 1373 1374 0
e9 :3 0 1375 1376
0 13b0 ad :3 0
ae :3 0 1378 1379
0 ad :3 0 bd
:3 0 137b 137c 0
ec :2 0 2 :4 0
180 :2 0 bf :2 0
47 :2 0 b2a 1381
1383 :3 0 b2d 137d
1385 137a 1387 1386
:2 0 b0 :3 0 c0
:3 0 1389 138a 0
b2 :4 0 181 :4 0
b5 :2 0 b6 :3 0
b31 138e 1390 :3 0
b5 :2 0 c9 :4 0
b34 1392 1394 :3 0
b5 :2 0 ef :4 0
b37 1396 1398 :3 0
b5 :2 0 e9 :3 0
b3a 139a 139c :3 0
b5 :2 0 f0 :4 0
b3d 139e 13a0 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 47 :2 0
f3 :2 0 b40 13a3
13a7 b44 13a2 13a9
:3 0 b47 138b 13ab
:2 0 13ad b4a 13ae
1388 13ad 0 13af
b4c 0 13b0 b4e
13b3 :3 0 13b3 0
13b3 13b2 13b0 13b1
:6 0 13b5 18 :3 0
b51 13b7 b53 13b6
13b5 :2 0 13b8 b55
:2 0 13ba 0 13ba
13b9 1367 13b8 :6 0
14a3 1 :3 0 21
:3 0 e8 :3 0 13bc
13bd 0 21 :3 0
d2 :2 0 16a :3 0
13bf 13c1 0 b5a
13c0 13c3 :3 0 13c4
:2 0 5f :3 0 60
:3 0 182 :3 0 110
:3 0 25 :4 0 183
1 :8 0 13d1 21
:3 0 e8 :3 0 13cc
13cd 0 e9 :3 0
13ce 13cf 0 13d1
b5d 1424 ea :3 0
21 :3 0 e8 :3 0
13d3 13d4 0 e9
:3 0 13d5 13d6 0
13d8 b60 13da b62
13d9 13d8 :2 0 1422
eb :3 0 21 :3 0
e8 :3 0 13dd 13de
0 e9 :3 0 13df
13e0 0 141a ad
:3 0 ae :3 0 13e2
13e3 0 ad :3 0
bd :3 0 13e5 13e6
0 ec :2 0 2
:4 0 184 :2 0 bf
:2 0 47 :2 0 b64
13eb 13ed :3 0 b67
13e7 13ef 13e4 13f1
13f0 :2 0 b0 :3 0
c0 :3 0 13f3 13f4
0 b2 :4 0 185
:4 0 b5 :2 0 b6
:3 0 b6b 13f8 13fa
:3 0 b5 :2 0 c9
:4 0 b6e 13fc 13fe
:3 0 b5 :2 0 ef
:4 0 b71 1400 1402
:3 0 b5 :2 0 e9
:3 0 b74 1404 1406
:3 0 b5 :2 0 f0
:4 0 b77 1408 140a
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 47
:2 0 f3 :2 0 b7a
140d 1411 b7e 140c
1413 :3 0 b81 13f5
1415 :2 0 1417 b84
1418 13f2 1417 0
1419 b86 0 141a
b88 141d :3 0 141d
0 141d 141c 141a
141b :6 0 141f 1a
:3 0 b8b 1421 b8d
1420 141f :2 0 1422
b8f :2 0 1424 0
1424 1423 13d1 1422
:6 0 14a0 1 :3 0
21 :3 0 e8 :3 0
1426 1427 0 21
:3 0 d2 :2 0 16a
:3 0 1429 142b 0
b94 142a 142d :3 0
142e :2 0 ad :3 0
ae :3 0 1430 1431
0 ad :3 0 bd
:3 0 1433 1434 0
24 :2 0 2 :4 0
186 :2 0 bf :2 0
47 :2 0 b97 1439
143b :3 0 b9a 1435
143d 1432 143f 143e
:2 0 b0 :3 0 c0
:3 0 1441 1442 0
b2 :4 0 187 :4 0
b5 :2 0 b6 :3 0
b9e 1446 1448 :3 0
b5 :2 0 c9 :4 0
ba1 144a 144c :3 0
b5 :2 0 ca :4 0
ba4 144e 1450 :3 0
b5 :2 0 a1 :3 0
ba :3 0 c2 :3 0
d6 :3 0 1455 1456
0 ba7 1454 1458
bb :4 0 ba9 1453
145b bac 1452 145d
:3 0 b5 :2 0 119
:4 0 baf 145f 1461
:3 0 b5 :2 0 b8
:4 0 bb2 1463 1465
:3 0 b5 :2 0 25
:3 0 bb5 1467 1469
:3 0 b5 :2 0 b8
:4 0 bb8 146b 146d
:3 0 bbb 1443 146f
:2 0 1471 bbe 1472
1440 1471 0 1473
bc0 0 149d ad
:3 0 ae :3 0 1474
1475 0 ad :3 0
bd :3 0 1477 1478
0 47 :2 0 2
:4 0 188 :2 0 bf
:2 0 47 :2 0 bc2
147d 147f :3 0 bc5
1479 1481 1476 1483
1482 :2 0 b0 :3 0
c0 :3 0 1485 1486
0 b2 :4 0 189
:4 0 b5 :2 0 b6
:3 0 bc9 148a 148c
:3 0 bcc 1487 148e
:2 0 1490 bcf 1491
1484 1490 0 1492
bd1 0 149d ce
:3 0 11c :3 0 1493
1494 0 c2 :3 0
d6 :3 0 1496 1497
0 25 :3 0 d0
:3 0 bd3 1495 149b
:2 0 149d bd7 149e
142f 149d 0 149f
bdb 0 14a0 bdd
14a1 13c5 14a0 0
14a2 be0 0 14a3
be2 14a4 1355 14a3
0 14a5 be5 0
14a6 be7 14a7 12bd
14a6 0 14a8 bea
0 368b a1 :3 0
d :3 0 4e :2 0
bec 14a9 14ac d2
:2 0 4e :2 0 bf1
14ae 14b0 :3 0 a1
:3 0 5b :3 0 4e
:2 0 bf4 14b2 14b5
c3 :2 0 18a :2 0
bf9 14b7 14b9 :3 0
14b1 14bb 14ba :2 0
57 :3 0 4e :2 0
14bd 14be 0 14c0
bfc 14c1 14bc 14c0
0 14c2 bfe 0
368b a1 :3 0 4d
:3 0 4e :2 0 c00
14c3 14c6 c2 :3 0
d2 :2 0 c4 :3 0
14c8 14ca 0 c05
14c9 14cc :3 0 5
:3 0 c5 :2 0 c08
14cf 14d0 :3 0 14d1
:2 0 41 :3 0 18b
:4 0 14d3 14d4 0
14d9 42 :3 0 18b
:4 0 14d6 14d7 0
14d9 c0a 14e1 41
:3 0 5 :3 0 14da
14db 0 14e0 42
:3 0 5 :3 0 14dd
14de 0 14e0 c0d
14e2 14d2 14d9 0
14e3 0 14e0 0
14e3 c10 0 14e7
59 :3 0 4e :2 0
14e4 14e5 0 14e7
c13 1698 89 :3 0
d2 :2 0 4e :2 0
c18 14e9 14eb :3 0
42 :3 0 18c :4 0
14ed 14ee 0 1605
82 :3 0 18d :3 0
41 :3 0 42 :3 0
a1 :3 0 5a :3 0
4e :2 0 c1b 14f4
14f7 a1 :3 0 5b
:3 0 4e :2 0 c1e
14f9 14fc a1 :3 0
5c :3 0 4e :2 0
c21 14fe 1501 a1
:3 0 4d :3 0 4e
:2 0 c24 1503 1506
a1 :3 0 5d :3 0
4e :2 0 c27 1508
150b a1 :3 0 58
:3 0 4e :2 0 c2a
150d 1510 a1 :3 0
5f :3 0 4e :2 0
c2d 1512 1515 a1
:3 0 60 :3 0 4e
:2 0 c30 1517 151a
57 :3 0 59 :3 0
61 :3 0 c33 14f1
151f 14f0 1520 0
1605 a1 :3 0 82
:3 0 4e :2 0 c41
1522 1525 c2 :3 0
d2 :2 0 d6 :3 0
1527 1529 0 c46
1528 152b :3 0 ad
:3 0 ae :3 0 152d
152e 0 ad :3 0
bd :3 0 1530 1531
0 c6 :2 0 2
:4 0 18e :2 0 bf
:2 0 47 :2 0 c49
1536 1538 :3 0 c4c
1532 153a 152f 153c
153b :2 0 b0 :3 0
c0 :3 0 153e 153f
0 b2 :4 0 18f
:4 0 b5 :2 0 b6
:3 0 c50 1543 1545
:3 0 b5 :2 0 c9
:4 0 c53 1547 1549
:3 0 b5 :2 0 ca
:4 0 c56 154b 154d
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 d6 :3 0 1552
1553 0 c59 1551
1555 bb :4 0 c5b
1550 1558 c5e 154f
155a :3 0 c61 1540
155c :2 0 155e c64
155f 153d 155e 0
1560 c66 0 158a
ad :3 0 ae :3 0
1561 1562 0 ad
:3 0 bd :3 0 1564
1565 0 47 :2 0
2 :4 0 190 :2 0
bf :2 0 47 :2 0
c68 156a 156c :3 0
c6b 1566 156e 1563
1570 156f :2 0 b0
:3 0 c0 :3 0 1572
1573 0 b2 :4 0
191 :4 0 b5 :2 0
b6 :3 0 c6f 1577
1579 :3 0 c72 1574
157b :2 0 157d c75
157e 1571 157d 0
157f c77 0 158a
ce :3 0 cf :3 0
1580 1581 0 c2
:3 0 d6 :3 0 1583
1584 0 d0 :3 0
c79 1582 1587 :2 0
158a d8 :3 0 c7c
1603 a1 :3 0 82
:3 0 4e :2 0 c80
158b 158e c3 :2 0
4e :2 0 c85 1590
1592 :3 0 ad :3 0
ae :3 0 1594 1595
0 ad :3 0 bd
:3 0 1597 1598 0
24 :2 0 2 :4 0
192 :2 0 bf :2 0
47 :2 0 c88 159d
159f :3 0 c8b 1599
15a1 1596 15a3 15a2
:2 0 b0 :3 0 c0
:3 0 15a5 15a6 0
b2 :4 0 193 :4 0
b5 :2 0 b6 :3 0
c8f 15aa 15ac :3 0
b5 :2 0 c9 :4 0
c92 15ae 15b0 :3 0
b5 :2 0 ca :4 0
c95 15b2 15b4 :3 0
b5 :2 0 a1 :3 0
ba :3 0 82 :3 0
c98 15b8 15ba bb
:4 0 c9a 15b7 15bd
c9d 15b6 15bf :3 0
b5 :2 0 119 :4 0
ca0 15c1 15c3 :3 0
b5 :2 0 b8 :4 0
ca3 15c5 15c7 :3 0
b5 :2 0 25 :3 0
ca6 15c9 15cb :3 0
b5 :2 0 b8 :4 0
ca9 15cd 15cf :3 0
cac 15a7 15d1 :2 0
15d3 caf 15d4 15a4
15d3 0 15d5 cb1
0 1601 ad :3 0
ae :3 0 15d6 15d7
0 ad :3 0 bd
:3 0 15d9 15da 0
47 :2 0 2 :4 0
194 :2 0 bf :2 0
47 :2 0 cb3 15df
15e1 :3 0 cb6 15db
15e3 15d8 15e5 15e4
:2 0 b0 :3 0 c0
:3 0 15e7 15e8 0
b2 :4 0 195 :4 0
b5 :2 0 b6 :3 0
cba 15ec 15ee :3 0
cbd 15e9 15f0 :2 0
15f2 cc0 15f3 15e6
15f2 0 15f4 cc2
0 1601 ce :3 0
11c :3 0 15f5 15f6
0 a1 :3 0 82
:3 0 4e :2 0 cc4
15f8 15fb 25 :3 0
d0 :3 0 cc7 15f7
15ff :2 0 1601 ccb
1602 1593 1601 0
1604 152c 158a 0
1604 ccf 0 1605
cd2 1625 42 :3 0
6 :3 0 1606 1607
0 1624 a1 :3 0
5b :3 0 4e :2 0
cd6 1609 160c d2
:2 0 dd :2 0 cdb
160e 1610 :3 0 57
:3 0 a1 :3 0 57
:3 0 4e :2 0 cde
1613 1616 196 :2 0
a1 :3 0 60 :3 0
4e :2 0 ce1 1619
161c ce4 1618 161e
:3 0 1612 161f 0
1621 ce7 1622 1611
1621 0 1623 ce9
0 1624 ceb 1626
14ec 1605 0 1627
0 1624 0 1627
cee 0 1697 a1
:3 0 57 :3 0 4e
:2 0 cf1 1628 162b
108 :2 0 4e :2 0
cf6 162d 162f :3 0
1630 :2 0 a1 :3 0
5b :3 0 4e :2 0
cf9 1632 1635 c3
:2 0 18a :2 0 cfe
1637 1639 :3 0 163a
:2 0 1631 163c 163b
:2 0 a1 :3 0 5b
:3 0 4e :2 0 d01
163e 1641 d2 :2 0
47 :2 0 d06 1643
1645 :3 0 1646 :2 0
a1 :3 0 5b :3 0
4e :2 0 d09 1648
164b d2 :2 0 105
:2 0 d0e 164d 164f
:3 0 1650 :2 0 1647
1652 1651 :2 0 5a
:3 0 105 :2 0 1654
1655 0 1658 d8
:3 0 d11 1692 a1
:3 0 5b :3 0 4e
:2 0 d13 1659 165c
d2 :2 0 4e :2 0
d18 165e 1660 :3 0
5a :3 0 47 :2 0
1662 1663 0 1666
d8 :3 0 d1b 1667
1661 1666 0 1693
a1 :3 0 5b :3 0
4e :2 0 d1d 1668
166b d2 :2 0 107
:2 0 d22 166d 166f
:3 0 1670 :2 0 a1
:3 0 5b :3 0 4e
:2 0 d25 1672 1675
d2 :2 0 197 :2 0
d2a 1677 1679 :3 0
167a :2 0 1671 167c
167b :2 0 5a :3 0
47 :2 0 167e 167f
0 1682 d8 :3 0
d2d 1683 167d 1682
0 1693 a1 :3 0
5b :3 0 4e :2 0
d2f 1684 1687 d2
:2 0 dd :2 0 d34
1689 168b :3 0 5a
:3 0 107 :2 0 168d
168e 0 1690 d37
1691 168c 1690 0
1693 1653 1658 0
1693 d39 0 1694
d3e 1695 163d 1694
0 1696 d40 0
1697 d42 1699 14cd
14e7 0 169a 0
1697 0 169a d45
0 368b a1 :3 0
5c :3 0 4e :2 0
d48 169b 169e c2
:3 0 d2 :2 0 d3
:3 0 16a0 16a2 0
d4d 16a1 16a4 :3 0
8d :3 0 4e :2 0
16a6 16a7 0 1b7b
2e :3 0 16 :3 0
16a9 16aa 0 1b7b
30 :3 0 17 :3 0
16ac 16ad 0 1b7b
49 :3 0 f1 :3 0
2e :3 0 47 :2 0
24 :2 0 d50 16b0
16b4 16af 16b5 0
1b7b 4c :4 0 16b7
16b8 0 1b7b a1
:3 0 6b :3 0 4e
:2 0 d54 16ba 16bd
d2 :2 0 4e :2 0
d59 16bf 16c1 :3 0
39 :3 0 198 :4 0
16c4 16c5 :3 0 16c3
16c6 0 16cb 8d
:3 0 47 :2 0 16c8
16c9 0 16cb d5c
17b1 10e :3 0 4c
:3 0 199 :3 0 19a
:3 0 39 :4 0 19b
1 :8 0 16d7 21
:3 0 e8 :3 0 16d2
16d3 0 e9 :3 0
16d4 16d5 0 16d7
d5f 172a ea :3 0
21 :3 0 e8 :3 0
16d9 16da 0 e9
:3 0 16db 16dc 0
16de d62 16e0 d64
16df 16de :2 0 1728
eb :3 0 21 :3 0
e8 :3 0 16e3 16e4
0 e9 :3 0 16e5
16e6 0 1720 ad
:3 0 ae :3 0 16e8
16e9 0 ad :3 0
bd :3 0 16eb 16ec
0 ec :2 0 2
:4 0 19c :2 0 bf
:2 0 47 :2 0 d66
16f1 16f3 :3 0 d69
16ed 16f5 16ea 16f7
16f6 :2 0 b0 :3 0
c0 :3 0 16f9 16fa
0 b2 :4 0 19d
:4 0 b5 :2 0 b6
:3 0 d6d 16fe 1700
:3 0 b5 :2 0 c9
:4 0 d70 1702 1704
:3 0 b5 :2 0 ef
:4 0 d73 1706 1708
:3 0 b5 :2 0 e9
:3 0 d76 170a 170c
:3 0 b5 :2 0 f0
:4 0 d79 170e 1710
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 47
:2 0 f3 :2 0 d7c
1713 1717 d80 1712
1719 :3 0 d83 16fb
171b :2 0 171d d86
171e 16f8 171d 0
171f d88 0 1720
d8a 1723 :3 0 1723
0 1723 1722 1720
1721 :6 0 1725 1c
:3 0 d8d 1727 d8f
1726 1725 :2 0 1728
d91 :2 0 172a 0
172a 1729 16d7 1728
:6 0 17b0 1 :3 0
21 :3 0 e8 :3 0
172c 172d 0 21
:3 0 d2 :2 0 f4
:3 0 172f 1731 0
d96 1730 1733 :3 0
1734 :2 0 a1 :3 0
50 :3 0 4e :2 0
d99 1736 1739 108
:2 0 4e :2 0 d9e
173b 173d :3 0 19e
:3 0 28 :3 0 19f
:3 0 110 :3 0 26
:3 0 9a :3 0 39
:3 0 1a0 :3 0 1a1
:3 0 c2 :3 0 1a2
:4 0 1a3 1 :8 0
1750 21 :3 0 e8
:3 0 174b 174c 0
e9 :3 0 174d 174e
0 1750 da1 17a3
ea :3 0 21 :3 0
e8 :3 0 1752 1753
0 e9 :3 0 1754
1755 0 1757 da4
1759 da6 1758 1757
:2 0 17a1 eb :3 0
21 :3 0 e8 :3 0
175c 175d 0 e9
:3 0 175e 175f 0
1799 ad :3 0 ae
:3 0 1761 1762 0
ad :3 0 bd :3 0
1764 1765 0 ec
:2 0 2 :4 0 1a4
:2 0 bf :2 0 47
:2 0 da8 176a 176c
:3 0 dab 1766 176e
1763 1770 176f :2 0
b0 :3 0 c0 :3 0
1772 1773 0 b2
:4 0 1a5 :4 0 b5
:2 0 b6 :3 0 daf
1777 1779 :3 0 b5
:2 0 c9 :4 0 db2
177b 177d :3 0 b5
:2 0 ef :4 0 db5
177f 1781 :3 0 b5
:2 0 e9 :3 0 db8
1783 1785 :3 0 b5
:2 0 f0 :4 0 dbb
1787 1789 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 47 :2 0 f3
:2 0 dbe 178c 1790
dc2 178b 1792 :3 0
dc5 1774 1794 :2 0
1796 dc8 1797 1771
1796 0 1798 dca
0 1799 dcc 179c
:3 0 179c 0 179c
179b 1799 179a :6 0
179e 1e :3 0 dcf
17a0 dd1 179f 179e
:2 0 17a1 dd3 :2 0
17a3 0 17a3 17a2
1750 17a1 :6 0 17a5
1 :3 0 dd6 17a6
173e 17a5 0 17a7
dd8 0 17a8 dda
17ad 8d :3 0 47
:2 0 17a9 17aa 0
17ac ddc 17ae 1735
17a8 0 17af 0
17ac 0 17af dde
0 17b0 de1 17b2
16c2 16cb 0 17b3
0 17b0 0 17b3
de4 0 1b7b 8d
:3 0 c3 :2 0 4e
:2 0 de9 17b5 17b7
:3 0 a1 :3 0 1a6
:3 0 1a7 :3 0 63
:3 0 199 :3 0 98
:3 0 25 :3 0 a0
:3 0 49 :4 0 1a8
1 :8 0 17c8 21
:3 0 e8 :3 0 17c3
17c4 0 e9 :3 0
17c5 17c6 0 17c8
dec 181b ea :3 0
21 :3 0 e8 :3 0
17ca 17cb 0 e9
:3 0 17cc 17cd 0
17cf def 17d1 df1
17d0 17cf :2 0 1819
eb :3 0 21 :3 0
e8 :3 0 17d4 17d5
0 e9 :3 0 17d6
17d7 0 1811 ad
:3 0 ae :3 0 17d9
17da 0 ad :3 0
bd :3 0 17dc 17dd
0 ec :2 0 2
:4 0 1a9 :2 0 bf
:2 0 47 :2 0 df3
17e2 17e4 :3 0 df6
17de 17e6 17db 17e8
17e7 :2 0 b0 :3 0
c0 :3 0 17ea 17eb
0 b2 :4 0 1aa
:4 0 b5 :2 0 b6
:3 0 dfa 17ef 17f1
:3 0 b5 :2 0 c9
:4 0 dfd 17f3 17f5
:3 0 b5 :2 0 ef
:4 0 e00 17f7 17f9
:3 0 b5 :2 0 e9
:3 0 e03 17fb 17fd
:3 0 b5 :2 0 f0
:4 0 e06 17ff 1801
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 47
:2 0 f3 :2 0 e09
1804 1808 e0d 1803
180a :3 0 e10 17ec
180c :2 0 180e e13
180f 17e9 180e 0
1810 e15 0 1811
e17 1814 :3 0 1814
0 1814 1813 1811
1812 :6 0 1816 20
:3 0 e1a 1818 e1c
1817 1816 :2 0 1819
e1e :2 0 181b 0
181b 181a 17c8 1819
:6 0 19a4 1 :3 0
e4 :3 0 1ab :3 0
e4 :3 0 1ab :3 0
e4 :3 0 1ab :3 0
e4 :3 0 1ab :3 0
e4 :3 0 1ab :3 0
9f :3 0 1ac :3 0
1ad :3 0 9f :3 0
1ae :3 0 1ad :3 0
9f :3 0 ba :3 0
63 :3 0 4b :3 0
1af :3 0 1ae :3 0
1af :3 0 1ac :3 0
1ae :3 0 110 :3 0
49 :3 0 1ac :3 0
110 :3 0 1ae :3 0
1b0 :4 0 1b1 1
:8 0 1842 21 :3 0
e8 :3 0 183d 183e
0 e9 :3 0 183f
1840 0 1842 e21
1895 ea :3 0 21
:3 0 e8 :3 0 1844
1845 0 e9 :3 0
1846 1847 0 1849
e24 184b e26 184a
1849 :2 0 1893 eb
:3 0 21 :3 0 e8
:3 0 184e 184f 0
e9 :3 0 1850 1851
0 188b ad :3 0
ae :3 0 1853 1854
0 ad :3 0 bd
:3 0 1856 1857 0
ec :2 0 2 :4 0
1b2 :2 0 bf :2 0
47 :2 0 e28 185c
185e :3 0 e2b 1858
1860 1855 1862 1861
:2 0 b0 :3 0 c0
:3 0 1864 1865 0
b2 :4 0 1b3 :4 0
b5 :2 0 b6 :3 0
e2f 1869 186b :3 0
b5 :2 0 c9 :4 0
e32 186d 186f :3 0
b5 :2 0 ef :4 0
e35 1871 1873 :3 0
b5 :2 0 e9 :3 0
e38 1875 1877 :3 0
b5 :2 0 f0 :4 0
e3b 1879 187b :3 0
b5 :2 0 f1 :3 0
f2 :3 0 47 :2 0
f3 :2 0 e3e 187e
1882 e42 187d 1884
:3 0 e45 1866 1886
:2 0 1888 e48 1889
1863 1888 0 188a
e4a 0 188b e4c
188e :3 0 188e 0
188e 188d 188b 188c
:6 0 1890 22 :3 0
e4f 1892 e51 1891
1890 :2 0 1893 e53
:2 0 1895 0 1895
1894 1842 1893 :6 0
19a4 1 :3 0 21
:3 0 e8 :3 0 1897
1898 0 21 :3 0
d2 :2 0 16a :3 0
189a 189c 0 e58
189b 189e :3 0 189f
:2 0 ad :3 0 ae
:3 0 18a1 18a2 0
ad :3 0 bd :3 0
18a4 18a5 0 24
:2 0 2 :4 0 1b4
:2 0 bf :2 0 47
:2 0 e5b 18aa 18ac
:3 0 e5e 18a6 18ae
18a3 18b0 18af :2 0
b0 :3 0 c0 :3 0
18b2 18b3 0 b2
:4 0 1b5 :4 0 b5
:2 0 b6 :3 0 e62
18b7 18b9 :3 0 b5
:2 0 c9 :4 0 e65
18bb 18bd :3 0 b5
:2 0 ca :4 0 e68
18bf 18c1 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 145
:3 0 18c6 18c7 0
e6b 18c5 18c9 bb
:4 0 e6d 18c4 18cc
e70 18c3 18ce :3 0
b5 :2 0 119 :4 0
e73 18d0 18d2 :3 0
b5 :2 0 b8 :4 0
e76 18d4 18d6 :3 0
b5 :2 0 49 :3 0
e79 18d8 18da :3 0
b5 :2 0 b8 :4 0
e7c 18dc 18de :3 0
e7f 18b4 18e0 :2 0
18e2 e82 18e3 18b1
18e2 0 18e4 e84
0 190e ad :3 0
ae :3 0 18e5 18e6
0 ad :3 0 bd
:3 0 18e8 18e9 0
47 :2 0 2 :4 0
1b6 :2 0 bf :2 0
47 :2 0 e86 18ee
18f0 :3 0 e89 18ea
18f2 18e7 18f4 18f3
:2 0 b0 :3 0 c0
:3 0 18f6 18f7 0
b2 :4 0 1b7 :4 0
b5 :2 0 b6 :3 0
e8d 18fb 18fd :3 0
e90 18f8 18ff :2 0
1901 e93 1902 18f5
1901 0 1903 e95
0 190e ce :3 0
11c :3 0 1904 1905
0 c2 :3 0 145
:3 0 1907 1908 0
49 :3 0 d0 :3 0
e97 1906 190c :2 0
190e e9b 190f 18a0
190e 0 1910 e9f
0 19a4 a1 :3 0
50 :3 0 4e :2 0
ea1 1911 1914 108
:2 0 4e :2 0 ea6
1916 1918 :3 0 81
:3 0 1b8 :4 0 191a
191b 0 191d ea9
1922 81 :3 0 1b9
:4 0 191e 191f 0
1921 eab 1923 1919
191d 0 1924 0
1921 0 1924 ead
0 19a4 199 :3 0
19a :3 0 98 :3 0
a0 :3 0 1a7 :3 0
1ba :3 0 10e :3 0
1bb :3 0 1bc :3 0
1bd :3 0 39 :3 0
25 :3 0 49 :3 0
63 :3 0 4b :3 0
81 :3 0 14 :3 0
13 :3 0 12 :4 0
1be 1 :8 0 194e
1bf :4 0 1939 :3 0
d0 :3 0 d2 :2 0
eb2 193c 193d :3 0
21 :3 0 e8 :3 0
193f 1940 0 4e
:2 0 1941 1942 0
1944 eb5 194b 21
:3 0 e8 :3 0 1945
1946 0 18a :2 0
1947 1948 0 194a
eb7 194c 193e 1944
0 194d 0 194a
0 194d eb9 0
194e ebc 19a1 ea
:3 0 21 :3 0 e8
:3 0 1950 1951 0
e9 :3 0 1952 1953
0 1955 ebf 1957
ec1 1956 1955 :2 0
199f eb :3 0 21
:3 0 e8 :3 0 195a
195b 0 e9 :3 0
195c 195d 0 1997
ad :3 0 ae :3 0
195f 1960 0 ad
:3 0 bd :3 0 1962
1963 0 ec :2 0
2 :4 0 1c0 :2 0
bf :2 0 47 :2 0
ec3 1968 196a :3 0
ec6 1964 196c 1961
196e 196d :2 0 b0
:3 0 c0 :3 0 1970
1971 0 b2 :4 0
1c1 :4 0 b5 :2 0
b6 :3 0 eca 1975
1977 :3 0 b5 :2 0
c9 :4 0 ecd 1979
197b :3 0 b5 :2 0
ef :4 0 ed0 197d
197f :3 0 b5 :2 0
e9 :3 0 ed3 1981
1983 :3 0 b5 :2 0
f0 :4 0 ed6 1985
1987 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
ed9 198a 198e edd
1989 1990 :3 0 ee0
1972 1992 :2 0 1994
ee3 1995 196f 1994
0 1996 ee5 0
1997 ee7 199a :3 0
199a 0 199a 1999
1997 1998 :6 0 199c
24 :3 0 eea 199e
eec 199d 199c :2 0
199f eee :2 0 19a1
0 19a1 19a0 194e
199f :6 0 19a4 1
:3 0 d8 :3 0 ef1
1a20 f1 :3 0 4c
:3 0 47 :2 0 47
:2 0 ef7 19a5 19a9
d2 :2 0 1b9 :4 0
efd 19ab 19ad :3 0
199 :3 0 10e :3 0
19a :3 0 39 :4 0
1c2 1 :8 0 19c9
1bf :4 0 19b4 :3 0
d0 :3 0 d2 :2 0
f02 19b7 19b8 :3 0
21 :3 0 e8 :3 0
19ba 19bb 0 4e
:2 0 19bc 19bd 0
19bf f05 19c6 21
:3 0 e8 :3 0 19c0
19c1 0 18a :2 0
19c2 19c3 0 19c5
f07 19c7 19b9 19bf
0 19c8 0 19c5
0 19c8 f09 0
19c9 f0c 1a1c ea
:3 0 21 :3 0 e8
:3 0 19cb 19cc 0
e9 :3 0 19cd 19ce
0 19d0 f0f 19d2
f11 19d1 19d0 :2 0
1a1a eb :3 0 21
:3 0 e8 :3 0 19d5
19d6 0 e9 :3 0
19d7 19d8 0 1a12
ad :3 0 ae :3 0
19da 19db 0 ad
:3 0 bd :3 0 19dd
19de 0 ec :2 0
2 :4 0 1c3 :2 0
bf :2 0 47 :2 0
f13 19e3 19e5 :3 0
f16 19df 19e7 19dc
19e9 19e8 :2 0 b0
:3 0 c0 :3 0 19eb
19ec 0 b2 :4 0
1c4 :4 0 b5 :2 0
b6 :3 0 f1a 19f0
19f2 :3 0 b5 :2 0
c9 :4 0 f1d 19f4
19f6 :3 0 b5 :2 0
ef :4 0 f20 19f8
19fa :3 0 b5 :2 0
e9 :3 0 f23 19fc
19fe :3 0 b5 :2 0
f0 :4 0 f26 1a00
1a02 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
f29 1a05 1a09 f2d
1a04 1a0b :3 0 f30
19ed 1a0d :2 0 1a0f
f33 1a10 19ea 1a0f
0 1a11 f35 0
1a12 f37 1a15 :3 0
1a15 0 1a15 1a14
1a12 1a13 :6 0 1a17
26 :3 0 f3a 1a19
f3c 1a18 1a17 :2 0
1a1a f3e :2 0 1a1c
0 1a1c 1a1b 19c9
1a1a :6 0 1a1e 1
:3 0 f41 1a1f 19ae
1a1e 0 1a21 17b8
19a4 0 1a21 f43
0 1b7b 1c5 :3 0
19e :3 0 19a :3 0
199 :3 0 98 :3 0
25 :3 0 10e :3 0
19a :3 0 39 :4 0
1c6 1 :8 0 1a41
1bf :4 0 1a2c :3 0
d0 :3 0 d2 :2 0
f48 1a2f 1a30 :3 0
21 :3 0 e8 :3 0
1a32 1a33 0 4e
:2 0 1a34 1a35 0
1a37 f4b 1a3e 21
:3 0 e8 :3 0 1a38
1a39 0 18a :2 0
1a3a 1a3b 0 1a3d
f4d 1a3f 1a31 1a37
0 1a40 0 1a3d
0 1a40 f4f 0
1a41 f52 1a94 ea
:3 0 21 :3 0 e8
:3 0 1a43 1a44 0
e9 :3 0 1a45 1a46
0 1a48 f55 1a4a
f57 1a49 1a48 :2 0
1a92 eb :3 0 21
:3 0 e8 :3 0 1a4d
1a4e 0 e9 :3 0
1a4f 1a50 0 1a8a
ad :3 0 ae :3 0
1a52 1a53 0 ad
:3 0 bd :3 0 1a55
1a56 0 ec :2 0
2 :4 0 1c7 :2 0
bf :2 0 47 :2 0
f59 1a5b 1a5d :3 0
f5c 1a57 1a5f 1a54
1a61 1a60 :2 0 b0
:3 0 c0 :3 0 1a63
1a64 0 b2 :4 0
1c8 :4 0 b5 :2 0
b6 :3 0 f60 1a68
1a6a :3 0 b5 :2 0
c9 :4 0 f63 1a6c
1a6e :3 0 b5 :2 0
ef :4 0 f66 1a70
1a72 :3 0 b5 :2 0
e9 :3 0 f69 1a74
1a76 :3 0 b5 :2 0
f0 :4 0 f6c 1a78
1a7a :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
f6f 1a7d 1a81 f73
1a7c 1a83 :3 0 f76
1a65 1a85 :2 0 1a87
f79 1a88 1a62 1a87
0 1a89 f7b 0
1a8a f7d 1a8d :3 0
1a8d 0 1a8d 1a8c
1a8a 1a8b :6 0 1a8f
28 :3 0 f80 1a91
f82 1a90 1a8f :2 0
1a92 f84 :2 0 1a94
0 1a94 1a93 1a41
1a92 :6 0 1b7b 1
:3 0 1c9 :3 0 19e
:3 0 19a :3 0 199
:3 0 98 :3 0 25
:3 0 10e :3 0 19a
:3 0 39 :4 0 1ca
1 :8 0 1ab5 1bf
:4 0 1aa0 :3 0 d0
:3 0 d2 :2 0 f89
1aa3 1aa4 :3 0 21
:3 0 e8 :3 0 1aa6
1aa7 0 4e :2 0
1aa8 1aa9 0 1aab
f8c 1ab2 21 :3 0
e8 :3 0 1aac 1aad
0 18a :2 0 1aae
1aaf 0 1ab1 f8e
1ab3 1aa5 1aab 0
1ab4 0 1ab1 0
1ab4 f90 0 1ab5
f93 1b08 ea :3 0
21 :3 0 e8 :3 0
1ab7 1ab8 0 e9
:3 0 1ab9 1aba 0
1abc f96 1abe f98
1abd 1abc :2 0 1b06
eb :3 0 21 :3 0
e8 :3 0 1ac1 1ac2
0 e9 :3 0 1ac3
1ac4 0 1afe ad
:3 0 ae :3 0 1ac6
1ac7 0 ad :3 0
bd :3 0 1ac9 1aca
0 ec :2 0 2
:4 0 1cb :2 0 bf
:2 0 47 :2 0 f9a
1acf 1ad1 :3 0 f9d
1acb 1ad3 1ac8 1ad5
1ad4 :2 0 b0 :3 0
c0 :3 0 1ad7 1ad8
0 b2 :4 0 1cc
:4 0 b5 :2 0 b6
:3 0 fa1 1adc 1ade
:3 0 b5 :2 0 c9
:4 0 fa4 1ae0 1ae2
:3 0 b5 :2 0 ef
:4 0 fa7 1ae4 1ae6
:3 0 b5 :2 0 e9
:3 0 faa 1ae8 1aea
:3 0 b5 :2 0 f0
:4 0 fad 1aec 1aee
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 47
:2 0 f3 :2 0 fb0
1af1 1af5 fb4 1af0
1af7 :3 0 fb7 1ad9
1af9 :2 0 1afb fba
1afc 1ad6 1afb 0
1afd fbc 0 1afe
fbe 1b01 :3 0 1b01
0 1b01 1b00 1afe
1aff :6 0 1b03 2a
:3 0 fc1 1b05 fc3
1b04 1b03 :2 0 1b06
fc5 :2 0 1b08 0
1b08 1b07 1ab5 1b06
:6 0 1b7b 1 :3 0
199 :3 0 98 :3 0
25 :3 0 10e :3 0
19a :3 0 39 :4 0
1cd 1 :8 0 1b26
1bf :4 0 1b11 :3 0
d0 :3 0 d2 :2 0
fca 1b14 1b15 :3 0
21 :3 0 e8 :3 0
1b17 1b18 0 4e
:2 0 1b19 1b1a 0
1b1c fcd 1b23 21
:3 0 e8 :3 0 1b1d
1b1e 0 18a :2 0
1b1f 1b20 0 1b22
fcf 1b24 1b16 1b1c
0 1b25 0 1b22
0 1b25 fd1 0
1b26 fd4 1b79 ea
:3 0 21 :3 0 e8
:3 0 1b28 1b29 0
e9 :3 0 1b2a 1b2b
0 1b2d fd7 1b2f
fd9 1b2e 1b2d :2 0
1b77 eb :3 0 21
:3 0 e8 :3 0 1b32
1b33 0 e9 :3 0
1b34 1b35 0 1b6f
ad :3 0 ae :3 0
1b37 1b38 0 ad
:3 0 bd :3 0 1b3a
1b3b 0 ec :2 0
2 :4 0 1ce :2 0
bf :2 0 47 :2 0
fdb 1b40 1b42 :3 0
fde 1b3c 1b44 1b39
1b46 1b45 :2 0 b0
:3 0 c0 :3 0 1b48
1b49 0 b2 :4 0
1cf :4 0 b5 :2 0
b6 :3 0 fe2 1b4d
1b4f :3 0 b5 :2 0
c9 :4 0 fe5 1b51
1b53 :3 0 b5 :2 0
ef :4 0 fe8 1b55
1b57 :3 0 b5 :2 0
e9 :3 0 feb 1b59
1b5b :3 0 b5 :2 0
f0 :4 0 fee 1b5d
1b5f :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
ff1 1b62 1b66 ff5
1b61 1b68 :3 0 ff8
1b4a 1b6a :2 0 1b6c
ffb 1b6d 1b47 1b6c
0 1b6e ffd 0
1b6f fff 1b72 :3 0
1b72 0 1b72 1b71
1b6f 1b70 :6 0 1b74
2c :3 0 1002 1b76
1004 1b75 1b74 :2 0
1b77 1006 :2 0 1b79
0 1b79 1b78 1b26
1b77 :6 0 1b7b 1
:3 0 1009 1b7c 16a5
1b7b 0 1b7d 1014
0 368b 84 :3 0
1d0 :4 0 1b7f 1b80
:3 0 1b7e 1b81 0
368b a1 :3 0 50
:3 0 4e :2 0 1016
1b83 1b86 d2 :2 0
4e :2 0 101b 1b88
1b8a :3 0 a1 :3 0
5c :3 0 4e :2 0
101e 1b8c 1b8f c2
:3 0 c3 :2 0 d3
:3 0 1b91 1b93 0
1023 1b92 1b95 :3 0
1b8b 1b97 1b96 :2 0
a1 :3 0 5c :3 0
4e :2 0 1026 1b99
1b9c c2 :3 0 c3
:2 0 d1 :3 0 1b9e
1ba0 0 102b 1b9f
1ba2 :3 0 1b98 1ba4
1ba3 :2 0 1e :3 0
e3 :2 0 102e 1ba7
1ba8 :3 0 1ba9 :2 0
3a :3 0 1e :3 0
1bab 1bac 0 1bae
1030 1baf 1baa 1bae
0 1bb0 1032 0
1bb1 1034 1bb2 1ba5
1bb1 0 1bb3 1036
0 368b a1 :3 0
56 :3 0 4e :2 0
1038 1bb4 1bb7 d2
:2 0 4e :2 0 103d
1bb9 1bbb :3 0 56
:3 0 c2 :3 0 1d1
:3 0 1bbe 1bbf 0
1bbd 1bc0 0 1bc2
1040 1bc3 1bbc 1bc2
0 1bc4 1042 0
368b 16 :3 0 c5
:2 0 1044 1bc6 1bc7
:3 0 1bc8 :2 0 17
:3 0 c5 :2 0 1046
1bcb 1bcc :3 0 1bcd
:2 0 1bc9 1bcf 1bce
:2 0 18 :3 0 c5
:2 0 1048 1bd2 1bd3
:3 0 1bd4 :2 0 1bd0
1bd6 1bd5 :2 0 19
:3 0 c5 :2 0 104a
1bd9 1bda :3 0 1bdb
:2 0 1bdc :2 0 1bd7
1bde 1bdd :2 0 8b
:3 0 47 :2 0 1be0
1be1 0 1be3 104c
1be4 1bdf 1be3 0
1be5 104e 0 368b
75 :3 0 18c :4 0
1be6 1be7 0 368b
76 :3 0 18c :4 0
1be9 1bea 0 368b
a1 :3 0 50 :3 0
4e :2 0 1050 1bec
1bef 108 :2 0 4e
:2 0 1055 1bf1 1bf3
:3 0 a1 :3 0 5c
:3 0 4e :2 0 1058
1bf5 1bf8 c2 :3 0
d2 :2 0 d3 :3 0
1bfa 1bfc 0 105d
1bfb 1bfe :3 0 75
:3 0 1d2 :4 0 b5
:2 0 39 :3 0 1060
1c02 1c04 :3 0 b5
:2 0 1d3 :4 0 1063
1c06 1c08 :3 0 b5
:2 0 1d4 :4 0 1066
1c0a 1c0c :3 0 b5
:2 0 1d5 :4 0 1069
1c0e 1c10 :3 0 b5
:2 0 1d6 :4 0 106c
1c12 1c14 :3 0 b5
:2 0 49 :3 0 106f
1c16 1c18 :3 0 b5
:2 0 b8 :4 0 1072
1c1a 1c1c :3 0 1c00
1c1d 0 1c20 d8
:3 0 1075 1c67 a1
:3 0 5c :3 0 4e
:2 0 1077 1c21 1c24
d2 :2 0 2d :2 0
107c 1c26 1c28 :3 0
75 :3 0 1d7 :4 0
b5 :2 0 1d8 :4 0
107f 1c2c 1c2e :3 0
b5 :2 0 1d9 :4 0
1082 1c30 1c32 :3 0
b5 :2 0 25 :3 0
1085 1c34 1c36 :3 0
b5 :2 0 1da :4 0
1088 1c38 1c3a :3 0
b5 :2 0 1db :4 0
108b 1c3c 1c3e :3 0
b5 :2 0 39 :3 0
108e 1c40 1c42 :3 0
b5 :2 0 1da :4 0
1091 1c44 1c46 :3 0
b5 :2 0 1dc :4 0
1094 1c48 1c4a :3 0
1c2a 1c4b 0 1c4d
1097 1c4e 1c29 1c4d
0 1c69 75 :3 0
1dd :4 0 b5 :2 0
1de :4 0 1099 1c51
1c53 :3 0 b5 :2 0
1df :4 0 109c 1c55
1c57 :3 0 b5 :2 0
1e0 :4 0 109f 1c59
1c5b :3 0 b5 :2 0
39 :3 0 10a2 1c5d
1c5f :3 0 b5 :2 0
1da :4 0 10a5 1c61
1c63 :3 0 1c4f 1c64
0 1c66 10a8 1c68
1bff 1c20 0 1c69
0 1c66 0 1c69
10aa 0 1c6a 10ae
25bb a1 :3 0 5c
:3 0 4e :2 0 10b0
1c6b 1c6e c2 :3 0
c3 :2 0 d3 :3 0
1c70 1c72 0 10b5
1c71 1c74 :3 0 a1
:3 0 5c :3 0 4e
:2 0 10b8 1c76 1c79
c2 :3 0 c3 :2 0
d1 :3 0 1c7b 1c7d
0 10bd 1c7c 1c7f
:3 0 1c75 1c81 1c80
:2 0 a1 :3 0 a
:3 0 4e :2 0 10c0
1c83 1c86 c2 :3 0
c3 :2 0 c4 :3 0
1c88 1c8a 0 10c5
1c89 1c8c :3 0 1c82
1c8e 1c8d :2 0 1e1
:3 0 1e2 :3 0 1e3
:4 0 1c92 :4 0 1c93
:2 0 1db3 21 :3 0
e8 :3 0 1c95 1c96
0 4e :2 0 1c97
1c98 0 1db3 14
:3 0 c5 :2 0 10c8
1c9b 1c9c :3 0 1c9d
:2 0 1e1 :3 0 1e2
:3 0 1e4 :4 0 1ca1
:4 0 1ca2 :2 0 1dab
21 :3 0 e8 :3 0
1ca4 1ca5 0 4e
:2 0 1ca6 1ca7 0
1dab 1e5 :3 0 110
:3 0 1e6 :3 0 182
:3 0 1e7 :3 0 1e8
:3 0 110 :3 0 1e8
:3 0 1e6 :3 0 182
:3 0 1e8 :3 0 1e9
:3 0 19f :3 0 1ea
:3 0 1e8 :3 0 110
:3 0 1ea :3 0 110
:3 0 1ea :3 0 1eb
:3 0 1ea :3 0 9a
:3 0 29 :4 0 1ec
1 :8 0 1cd6 1bf
:4 0 1cc1 :3 0 d0
:3 0 d2 :2 0 10cc
1cc4 1cc5 :3 0 21
:3 0 e8 :3 0 1cc7
1cc8 0 4e :2 0
1cc9 1cca 0 1ccc
10cf 1cd3 21 :3 0
e8 :3 0 1ccd 1cce
0 18a :2 0 1ccf
1cd0 0 1cd2 10d1
1cd4 1cc6 1ccc 0
1cd5 0 1cd2 0
1cd5 10d3 0 1cd6
10d6 1d29 ea :3 0
21 :3 0 e8 :3 0
1cd8 1cd9 0 e9
:3 0 1cda 1cdb 0
1cdd 10d9 1cdf 10db
1cde 1cdd :2 0 1d27
eb :3 0 21 :3 0
e8 :3 0 1ce2 1ce3
0 e9 :3 0 1ce4
1ce5 0 1d1f ad
:3 0 ae :3 0 1ce7
1ce8 0 ad :3 0
bd :3 0 1cea 1ceb
0 ec :2 0 2
:4 0 1ed :2 0 bf
:2 0 47 :2 0 10dd
1cf0 1cf2 :3 0 10e0
1cec 1cf4 1ce9 1cf6
1cf5 :2 0 b0 :3 0
c0 :3 0 1cf8 1cf9
0 b2 :4 0 1ee
:4 0 b5 :2 0 b6
:3 0 10e4 1cfd 1cff
:3 0 b5 :2 0 c9
:4 0 10e7 1d01 1d03
:3 0 b5 :2 0 ef
:4 0 10ea 1d05 1d07
:3 0 b5 :2 0 e9
:3 0 10ed 1d09 1d0b
:3 0 b5 :2 0 f0
:4 0 10f0 1d0d 1d0f
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 47
:2 0 f3 :2 0 10f3
1d12 1d16 10f7 1d11
1d18 :3 0 10fa 1cfa
1d1a :2 0 1d1c 10fd
1d1d 1cf7 1d1c 0
1d1e 10ff 0 1d1f
1101 1d22 :3 0 1d22
0 1d22 1d21 1d1f
1d20 :6 0 1d24 2e
:3 0 1104 1d26 1106
1d25 1d24 :2 0 1d27
1108 :2 0 1d29 0
1d29 1d28 1cd6 1d27
:6 0 1dab 1 :3 0
1ef :3 0 1f0 :3 0
1e6 :3 0 1e5 :3 0
1f0 :3 0 13d :3 0
110 :3 0 1e5 :3 0
13d :3 0 13d :3 0
1e6 :3 0 1f0 :3 0
1e6 :3 0 f1 :3 0
1f0 :3 0 1e6 :3 0
1f1 :3 0 13d :3 0
1e6 :3 0 13d :3 0
1e6 :4 0 1f2 1
:8 0 1d56 1bf :4 0
1d41 :3 0 d0 :3 0
d2 :2 0 110d 1d44
1d45 :3 0 21 :3 0
e8 :3 0 1d47 1d48
0 4e :2 0 1d49
1d4a 0 1d4c 1110
1d53 21 :3 0 e8
:3 0 1d4d 1d4e 0
18a :2 0 1d4f 1d50
0 1d52 1112 1d54
1d46 1d4c 0 1d55
0 1d52 0 1d55
1114 0 1d56 1117
1da9 ea :3 0 21
:3 0 e8 :3 0 1d58
1d59 0 e9 :3 0
1d5a 1d5b 0 1d5d
111a 1d5f 111c 1d5e
1d5d :2 0 1da7 eb
:3 0 21 :3 0 e8
:3 0 1d62 1d63 0
e9 :3 0 1d64 1d65
0 1d9f ad :3 0
ae :3 0 1d67 1d68
0 ad :3 0 bd
:3 0 1d6a 1d6b 0
ec :2 0 2 :4 0
1f3 :2 0 bf :2 0
47 :2 0 111e 1d70
1d72 :3 0 1121 1d6c
1d74 1d69 1d76 1d75
:2 0 b0 :3 0 c0
:3 0 1d78 1d79 0
b2 :4 0 1f4 :4 0
b5 :2 0 b6 :3 0
1125 1d7d 1d7f :3 0
b5 :2 0 c9 :4 0
1128 1d81 1d83 :3 0
b5 :2 0 ef :4 0
112b 1d85 1d87 :3 0
b5 :2 0 e9 :3 0
112e 1d89 1d8b :3 0
b5 :2 0 f0 :4 0
1131 1d8d 1d8f :3 0
b5 :2 0 f1 :3 0
f2 :3 0 47 :2 0
f3 :2 0 1134 1d92
1d96 1138 1d91 1d98
:3 0 113b 1d7a 1d9a
:2 0 1d9c 113e 1d9d
1d77 1d9c 0 1d9e
1140 0 1d9f 1142
1da2 :3 0 1da2 0
1da2 1da1 1d9f 1da0
:6 0 1da4 30 :3 0
1145 1da6 1147 1da5
1da4 :2 0 1da7 1149
:2 0 1da9 0 1da9
1da8 1d56 1da7 :6 0
1dab 1 :3 0 114c
1db0 39 :3 0 14
:3 0 1dac 1dad 0
1daf 1151 1db1 1c9e
1dab 0 1db2 0
1daf 0 1db2 1153
0 1db3 1156 1db4
1c8f 1db3 0 1db5
115a 0 25ba 10
:3 0 e3 :2 0 115c
1db7 1db8 :3 0 1db9
:2 0 8e :3 0 a1
:3 0 1f1 :3 0 10
:3 0 115e 1dbd 1dbf
4e :2 0 1160 1dbc
1dc2 108 :2 0 1f5
:2 0 1165 1dc4 1dc6
:3 0 100 :3 0 a1
:3 0 1f1 :3 0 10
:3 0 1168 1dca 1dcc
4e :2 0 116a 1dc9
1dcf 1f6 :2 0 116d
1dc8 1dd2 1f7 :2 0
1f8 :2 0 1170 1dd4
1dd6 :3 0 1173 1dd8
1dd7 100 :3 0 a1
:3 0 1f1 :3 0 10
:3 0 1175 1ddc 1dde
4e :2 0 1177 1ddb
1de1 1f6 :2 0 117a
1dda 1de4 0 1de5
0 117d :2 0 1dbb
1de7 0 1ef2 8f
:3 0 4e :2 0 1de9
1dea 0 1ef2 1f9
:3 0 8f :3 0 8e
:3 0 f5 :2 0 1fa
:3 0 1182 1def 1df1
:3 0 1df2 1e2e a1
:3 0 1fb :3 0 f1
:3 0 2a :3 0 8f
:3 0 bf :2 0 47
:2 0 1185 1df9 1dfb
:3 0 47 :2 0 1188
1df6 1dfe 118c 1df5
1e00 4e :2 0 118e
1df4 1e03 c3 :2 0
1fc :2 0 1193 1e05
1e07 :3 0 a1 :3 0
1fb :3 0 f1 :3 0
2a :3 0 8f :3 0
bf :2 0 47 :2 0
1196 1e0e 1e10 :3 0
47 :2 0 1199 1e0b
1e13 119d 1e0a 1e15
4e :2 0 119f 1e09
1e18 c3 :2 0 1fd
:2 0 11a4 1e1a 1e1c
:3 0 1e08 1e1e 1e1d
:2 0 1fe :8 0 1e22
11a7 1e23 1e1f 1e22
0 1e24 11a9 0
1e2c 8f :3 0 8f
:3 0 bf :2 0 47
:2 0 11ab 1e27 1e29
:3 0 1e25 1e2a 0
1e2c 11ae 1e2e 1fa
:3 0 1df3 1e2c :4 0
1ef2 8f :3 0 8e
:3 0 d2 :2 0 11b3
1e31 1e32 :3 0 ad
:3 0 ae :3 0 1e34
1e35 0 ad :3 0
bd :3 0 1e37 1e38
0 c6 :2 0 2
:4 0 1ff :2 0 bf
:2 0 47 :2 0 11b6
1e3d 1e3f :3 0 11b9
1e39 1e41 1e36 1e43
1e42 :2 0 b0 :3 0
c0 :3 0 1e45 1e46
0 b2 :4 0 200
:4 0 b5 :2 0 b6
:3 0 11bd 1e4a 1e4c
:3 0 b5 :2 0 c9
:4 0 11c0 1e4e 1e50
:3 0 b5 :2 0 ca
:4 0 11c3 1e52 1e54
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 d6 :3 0 1e59
1e5a 0 11c6 1e58
1e5c bb :4 0 11c8
1e57 1e5f 11cb 1e56
1e61 :3 0 11ce 1e47
1e63 :2 0 1e65 11d1
1e66 1e44 1e65 0
1e67 11d3 0 1e90
ad :3 0 ae :3 0
1e68 1e69 0 ad
:3 0 bd :3 0 1e6b
1e6c 0 47 :2 0
2 :4 0 201 :2 0
bf :2 0 47 :2 0
11d5 1e71 1e73 :3 0
11d8 1e6d 1e75 1e6a
1e77 1e76 :2 0 b0
:3 0 c0 :3 0 1e79
1e7a 0 b2 :4 0
202 :4 0 b5 :2 0
b6 :3 0 11dc 1e7e
1e80 :3 0 11df 1e7b
1e82 :2 0 1e84 11e2
1e85 1e78 1e84 0
1e86 11e4 0 1e90
ce :3 0 cf :3 0
1e87 1e88 0 c2
:3 0 d6 :3 0 1e8a
1e8b 0 d0 :3 0
11e6 1e89 1e8e :2 0
1e90 11e9 1e91 1e33
1e90 0 1e92 11ed
0 1ef2 203 :3 0
2a :3 0 2a :3 0
e6 :4 0 204 1
:8 0 1e9d 21 :3 0
e8 :3 0 1e98 1e99
0 e9 :3 0 1e9a
1e9b 0 1e9d 11ef
1ef0 ea :3 0 21
:3 0 e8 :3 0 1e9f
1ea0 0 e9 :3 0
1ea1 1ea2 0 1ea4
11f2 1ea6 11f4 1ea5
1ea4 :2 0 1eee eb
:3 0 21 :3 0 e8
:3 0 1ea9 1eaa 0
e9 :3 0 1eab 1eac
0 1ee6 ad :3 0
ae :3 0 1eae 1eaf
0 ad :3 0 bd
:3 0 1eb1 1eb2 0
ec :2 0 2 :4 0
205 :2 0 bf :2 0
47 :2 0 11f6 1eb7
1eb9 :3 0 11f9 1eb3
1ebb 1eb0 1ebd 1ebc
:2 0 b0 :3 0 c0
:3 0 1ebf 1ec0 0
b2 :4 0 206 :4 0
b5 :2 0 b6 :3 0
11fd 1ec4 1ec6 :3 0
b5 :2 0 c9 :4 0
1200 1ec8 1eca :3 0
b5 :2 0 ef :4 0
1203 1ecc 1ece :3 0
b5 :2 0 e9 :3 0
1206 1ed0 1ed2 :3 0
b5 :2 0 f0 :4 0
1209 1ed4 1ed6 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 47 :2 0
f3 :2 0 120c 1ed9
1edd 1210 1ed8 1edf
:3 0 1213 1ec1 1ee1
:2 0 1ee3 1216 1ee4
1ebe 1ee3 0 1ee5
1218 0 1ee6 121a
1ee9 :3 0 1ee9 0
1ee9 1ee8 1ee6 1ee7
:6 0 1eeb 33 :3 0
121d 1eed 121f 1eec
1eeb :2 0 1eee 1221
:2 0 1ef0 0 1ef0
1eef 1e9d 1eee :6 0
1ef2 1 :3 0 1224
1ef3 1dba 1ef2 0
1ef4 122a 0 25ba
a1 :3 0 5c :3 0
4e :2 0 122c 1ef5
1ef8 c2 :3 0 d2
:2 0 d3 :3 0 1efa
1efc 0 1231 1efb
1efe :3 0 75 :3 0
207 :4 0 1f00 1f01
0 1f15 76 :3 0
208 :4 0 1f03 1f04
0 1f15 76 :3 0
76 :3 0 b5 :2 0
39 :3 0 1234 1f08
1f0a :3 0 1f06 1f0b
0 1f15 76 :3 0
76 :3 0 b5 :2 0
b8 :4 0 1237 1f0f
1f11 :3 0 1f0d 1f12
0 1f15 d8 :3 0
123a 1fe3 a1 :3 0
5c :3 0 4e :2 0
123f 1f16 1f19 c2
:3 0 d2 :2 0 d1
:3 0 1f1b 1f1d 0
1244 1f1c 1f1f :3 0
75 :3 0 209 :4 0
1f21 1f22 0 1f35
75 :3 0 75 :3 0
b5 :2 0 25 :3 0
1247 1f26 1f28 :3 0
1f24 1f29 0 1f35
75 :3 0 75 :3 0
b5 :2 0 20a :4 0
124a 1f2d 1f2f :3 0
1f2b 1f30 0 1f35
76 :3 0 20b :4 0
1f32 1f33 0 1f35
124d 1f36 1f20 1f35
0 1fe5 a1 :3 0
a :3 0 4e :2 0
1252 1f37 1f3a c2
:3 0 d2 :2 0 c4
:3 0 1f3c 1f3e 0
1257 1f3d 1f40 :3 0
75 :3 0 20c :4 0
1f42 1f43 0 1f6c
76 :3 0 20b :4 0
1f45 1f46 0 1f6c
76 :3 0 76 :3 0
b5 :2 0 20d :4 0
125a 1f4a 1f4c :3 0
1f48 1f4d 0 1f6c
10 :3 0 e3 :2 0
125d 1f50 1f51 :3 0
1f52 :2 0 76 :3 0
76 :3 0 b5 :2 0
20e :4 0 125f 1f56
1f58 :3 0 1f54 1f59
0 1f69 76 :3 0
76 :3 0 b5 :2 0
2a :3 0 1262 1f5d
1f5f :3 0 1f5b 1f60
0 1f69 76 :3 0
76 :3 0 b5 :2 0
20f :4 0 1265 1f64
1f66 :3 0 1f62 1f67
0 1f69 1268 1f6a
1f53 1f69 0 1f6b
126c 0 1f6c 126e
1fc2 14 :3 0 e3
:2 0 1273 1f6e 1f6f
:3 0 1f70 :2 0 75
:3 0 75 :3 0 b5
:2 0 210 :4 0 1275
1f74 1f76 :3 0 1f72
1f77 0 1f7c 76
:3 0 20b :4 0 1f79
1f7a 0 1f7c 1278
1fa7 75 :3 0 75
:3 0 b5 :2 0 211
:4 0 127b 1f7f 1f81
:3 0 b5 :2 0 212
:4 0 127e 1f83 1f85
:3 0 1f7d 1f86 0
1fa6 76 :3 0 20b
:4 0 1f88 1f89 0
1fa6 76 :3 0 76
:3 0 b5 :2 0 213
:4 0 1281 1f8d 1f8f
:3 0 b5 :2 0 214
:4 0 1284 1f91 1f93
:3 0 b5 :2 0 215
:4 0 1287 1f95 1f97
:3 0 b5 :2 0 216
:4 0 128a 1f99 1f9b
:3 0 b5 :2 0 217
:4 0 128d 1f9d 1f9f
:3 0 b5 :2 0 218
:4 0 1290 1fa1 1fa3
:3 0 1f8b 1fa4 0
1fa6 1293 1fa8 1f71
1f7c 0 1fa9 0
1fa6 0 1fa9 1297
0 1fc1 10 :3 0
e3 :2 0 129a 1fab
1fac :3 0 1fad :2 0
76 :3 0 76 :3 0
b5 :2 0 219 :4 0
129c 1fb1 1fb3 :3 0
b5 :2 0 2a :3 0
129f 1fb5 1fb7 :3 0
b5 :2 0 20f :4 0
12a2 1fb9 1fbb :3 0
1faf 1fbc 0 1fbe
12a5 1fbf 1fae 1fbe
0 1fc0 12a7 0
1fc1 12a9 1fc3 1f41
1f6c 0 1fc4 0
1fc1 0 1fc4 12ac
0 1fe2 1e :3 0
e3 :2 0 12af 1fc6
1fc7 :3 0 1fc8 :2 0
76 :3 0 76 :3 0
b5 :2 0 21a :4 0
12b1 1fcc 1fce :3 0
1fca 1fcf 0 1fdf
76 :3 0 76 :3 0
b5 :2 0 3a :3 0
12b4 1fd3 1fd5 :3 0
1fd1 1fd6 0 1fdf
76 :3 0 76 :3 0
b5 :2 0 1da :4 0
12b7 1fda 1fdc :3 0
1fd8 1fdd 0 1fdf
12ba 1fe0 1fc9 1fdf
0 1fe1 12be 0
1fe2 12c0 1fe4 1eff
1f15 0 1fe5 0
1fe2 0 1fe5 12c3
0 25ba a1 :3 0
5c :3 0 4e :2 0
12c7 1fe6 1fe9 c2
:3 0 c3 :2 0 d3
:3 0 1feb 1fed 0
12cc 1fec 1fef :3 0
14 :3 0 e3 :2 0
12cf 1ff2 1ff3 :3 0
1ff4 :2 0 1e6 :3 0
3b :3 0 182 :3 0
110 :3 0 14 :4 0
21b 1 :8 0 2001
21 :3 0 e8 :3 0
1ffc 1ffd 0 e9
:3 0 1ffe 1fff 0
2001 12d1 2054 ea
:3 0 21 :3 0 e8
:3 0 2003 2004 0
e9 :3 0 2005 2006
0 2008 12d4 200a
12d6 2009 2008 :2 0
2052 eb :3 0 21
:3 0 e8 :3 0 200d
200e 0 e9 :3 0
200f 2010 0 204a
ad :3 0 ae :3 0
2012 2013 0 ad
:3 0 bd :3 0 2015
2016 0 ec :2 0
2 :4 0 21c :2 0
bf :2 0 47 :2 0
12d8 201b 201d :3 0
12db 2017 201f 2014
2021 2020 :2 0 b0
:3 0 c0 :3 0 2023
2024 0 b2 :4 0
21d :4 0 b5 :2 0
b6 :3 0 12df 2028
202a :3 0 b5 :2 0
c9 :4 0 12e2 202c
202e :3 0 b5 :2 0
ef :4 0 12e5 2030
2032 :3 0 b5 :2 0
e9 :3 0 12e8 2034
2036 :3 0 b5 :2 0
f0 :4 0 12eb 2038
203a :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
12ee 203d 2041 12f2
203c 2043 :3 0 12f5
2025 2045 :2 0 2047
12f8 2048 2022 2047
0 2049 12fa 0
204a 12fc 204d :3 0
204d 0 204d 204c
204a 204b :6 0 204f
35 :3 0 12ff 2051
1301 2050 204f :2 0
2052 1303 :2 0 2054
0 2054 2053 2001
2052 :6 0 20f6 1
:3 0 21 :3 0 e8
:3 0 2056 2057 0
21 :3 0 d2 :2 0
f4 :3 0 2059 205b
0 1308 205a 205d
:3 0 205e :2 0 90
:3 0 a1 :3 0 1f1
:3 0 3b :3 0 130b
2062 2064 4e :2 0
130d 2061 2067 2060
2068 0 2084 75
:3 0 75 :3 0 b5
:2 0 21e :4 0 1310
206c 206e :3 0 206a
206f 0 2084 76
:3 0 76 :3 0 b5
:2 0 21f :4 0 1313
2073 2075 :3 0 b5
:2 0 220 :4 0 1316
2077 2079 :3 0 b5
:2 0 3b :3 0 1319
207b 207d :3 0 b5
:2 0 221 :4 0 131c
207f 2081 :3 0 2071
2082 0 2084 131f
20f3 ad :3 0 ae
:3 0 2085 2086 0
ad :3 0 bd :3 0
2088 2089 0 24
:2 0 2 :4 0 222
:2 0 bf :2 0 47
:2 0 1323 208e 2090
:3 0 1326 208a 2092
2087 2094 2093 :2 0
b0 :3 0 c0 :3 0
2096 2097 0 b2
:4 0 223 :4 0 b5
:2 0 b6 :3 0 132a
209b 209d :3 0 b5
:2 0 c9 :4 0 132d
209f 20a1 :3 0 b5
:2 0 ca :4 0 1330
20a3 20a5 :3 0 b5
:2 0 a1 :3 0 ba
:3 0 c2 :3 0 d6
:3 0 20aa 20ab 0
1333 20a9 20ad bb
:4 0 1335 20a8 20b0
1338 20a7 20b2 :3 0
b5 :2 0 119 :4 0
133b 20b4 20b6 :3 0
b5 :2 0 b8 :4 0
133e 20b8 20ba :3 0
b5 :2 0 14 :3 0
1341 20bc 20be :3 0
b5 :2 0 b8 :4 0
1344 20c0 20c2 :3 0
1347 2098 20c4 :2 0
20c6 134a 20c7 2095
20c6 0 20c8 134c
0 20f2 ad :3 0
ae :3 0 20c9 20ca
0 ad :3 0 bd
:3 0 20cc 20cd 0
47 :2 0 2 :4 0
224 :2 0 bf :2 0
47 :2 0 134e 20d2
20d4 :3 0 1351 20ce
20d6 20cb 20d8 20d7
:2 0 b0 :3 0 c0
:3 0 20da 20db 0
b2 :4 0 225 :4 0
b5 :2 0 b6 :3 0
1355 20df 20e1 :3 0
1358 20dc 20e3 :2 0
20e5 135b 20e6 20d9
20e5 0 20e7 135d
0 20f2 ce :3 0
11c :3 0 20e8 20e9
0 c2 :3 0 d6
:3 0 20eb 20ec 0
14 :3 0 d0 :3 0
135f 20ea 20f0 :2 0
20f2 1363 20f4 205f
2084 0 20f5 0
20f2 0 20f5 1367
0 20f6 136a 20f7
1ff5 20f6 0 20f8
136d 0 2322 12
:3 0 e3 :2 0 136f
20fa 20fb :3 0 20fc
:2 0 1e6 :3 0 3b
:3 0 226 :3 0 110
:3 0 12 :4 0 227
1 :8 0 2109 21
:3 0 e8 :3 0 2104
2105 0 e9 :3 0
2106 2107 0 2109
1371 215c ea :3 0
21 :3 0 e8 :3 0
210b 210c 0 e9
:3 0 210d 210e 0
2110 1374 2112 1376
2111 2110 :2 0 215a
eb :3 0 21 :3 0
e8 :3 0 2115 2116
0 e9 :3 0 2117
2118 0 2152 ad
:3 0 ae :3 0 211a
211b 0 ad :3 0
bd :3 0 211d 211e
0 ec :2 0 2
:4 0 228 :2 0 bf
:2 0 47 :2 0 1378
2123 2125 :3 0 137b
211f 2127 211c 2129
2128 :2 0 b0 :3 0
c0 :3 0 212b 212c
0 b2 :4 0 229
:4 0 b5 :2 0 b6
:3 0 137f 2130 2132
:3 0 b5 :2 0 c9
:4 0 1382 2134 2136
:3 0 b5 :2 0 ef
:4 0 1385 2138 213a
:3 0 b5 :2 0 e9
:3 0 1388 213c 213e
:3 0 b5 :2 0 f0
:4 0 138b 2140 2142
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 47
:2 0 f3 :2 0 138e
2145 2149 1392 2144
214b :3 0 1395 212d
214d :2 0 214f 1398
2150 212a 214f 0
2151 139a 0 2152
139c 2155 :3 0 2155
0 2155 2154 2152
2153 :6 0 2157 37
:3 0 139f 2159 13a1
2158 2157 :2 0 215a
13a3 :2 0 215c 0
215c 215b 2109 215a
:6 0 21f4 1 :3 0
21 :3 0 e8 :3 0
215e 215f 0 21
:3 0 d2 :2 0 f4
:3 0 2161 2163 0
13a8 2162 2165 :3 0
2166 :2 0 75 :3 0
75 :3 0 b5 :2 0
22a :4 0 13ab 216a
216c :3 0 2168 216d
0 2182 76 :3 0
76 :3 0 b5 :2 0
22b :4 0 13ae 2171
2173 :3 0 b5 :2 0
22c :4 0 13b1 2175
2177 :3 0 b5 :2 0
3b :3 0 13b4 2179
217b :3 0 b5 :2 0
221 :4 0 13b7 217d
217f :3 0 216f 2180
0 2182 13ba 21f1
ad :3 0 ae :3 0
2183 2184 0 ad
:3 0 bd :3 0 2186
2187 0 24 :2 0
2 :4 0 22d :2 0
bf :2 0 47 :2 0
13bd 218c 218e :3 0
13c0 2188 2190 2185
2192 2191 :2 0 b0
:3 0 c0 :3 0 2194
2195 0 b2 :4 0
22e :4 0 b5 :2 0
b6 :3 0 13c4 2199
219b :3 0 b5 :2 0
c9 :4 0 13c7 219d
219f :3 0 b5 :2 0
ca :4 0 13ca 21a1
21a3 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 d6 :3 0
21a8 21a9 0 13cd
21a7 21ab bb :4 0
13cf 21a6 21ae 13d2
21a5 21b0 :3 0 b5
:2 0 119 :4 0 13d5
21b2 21b4 :3 0 b5
:2 0 b8 :4 0 13d8
21b6 21b8 :3 0 b5
:2 0 12 :3 0 13db
21ba 21bc :3 0 b5
:2 0 b8 :4 0 13de
21be 21c0 :3 0 13e1
2196 21c2 :2 0 21c4
13e4 21c5 2193 21c4
0 21c6 13e6 0
21f0 ad :3 0 ae
:3 0 21c7 21c8 0
ad :3 0 bd :3 0
21ca 21cb 0 47
:2 0 2 :4 0 22f
:2 0 bf :2 0 47
:2 0 13e8 21d0 21d2
:3 0 13eb 21cc 21d4
21c9 21d6 21d5 :2 0
b0 :3 0 c0 :3 0
21d8 21d9 0 b2
:4 0 230 :4 0 b5
:2 0 b6 :3 0 13ef
21dd 21df :3 0 13f2
21da 21e1 :2 0 21e3
13f5 21e4 21d7 21e3
0 21e5 13f7 0
21f0 ce :3 0 11c
:3 0 21e6 21e7 0
c2 :3 0 d6 :3 0
21e9 21ea 0 12
:3 0 d0 :3 0 13f9
21e8 21ee :2 0 21f0
13fd 21f2 2167 2182
0 21f3 0 21f0
0 21f3 1401 0
21f4 1404 21f5 20fd
21f4 0 21f6 1407
0 2322 13 :3 0
e3 :2 0 1409 21f8
21f9 :3 0 21fa :2 0
1e6 :3 0 3b :3 0
231 :3 0 110 :3 0
13 :4 0 232 1
:8 0 2207 21 :3 0
e8 :3 0 2202 2203
0 e9 :3 0 2204
2205 0 2207 140b
225a ea :3 0 21
:3 0 e8 :3 0 2209
220a 0 e9 :3 0
220b 220c 0 220e
140e 2210 1410 220f
220e :2 0 2258 eb
:3 0 21 :3 0 e8
:3 0 2213 2214 0
e9 :3 0 2215 2216
0 2250 ad :3 0
ae :3 0 2218 2219
0 ad :3 0 bd
:3 0 221b 221c 0
ec :2 0 2 :4 0
233 :2 0 bf :2 0
47 :2 0 1412 2221
2223 :3 0 1415 221d
2225 221a 2227 2226
:2 0 b0 :3 0 c0
:3 0 2229 222a 0
b2 :4 0 234 :4 0
b5 :2 0 b6 :3 0
1419 222e 2230 :3 0
b5 :2 0 c9 :4 0
141c 2232 2234 :3 0
b5 :2 0 ef :4 0
141f 2236 2238 :3 0
b5 :2 0 e9 :3 0
1422 223a 223c :3 0
b5 :2 0 f0 :4 0
1425 223e 2240 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 47 :2 0
f3 :2 0 1428 2243
2247 142c 2242 2249
:3 0 142f 222b 224b
:2 0 224d 1432 224e
2228 224d 0 224f
1434 0 2250 1436
2253 :3 0 2253 0
2253 2252 2250 2251
:6 0 2255 39 :3 0
1439 2257 143b 2256
2255 :2 0 2258 143d
:2 0 225a 0 225a
2259 2207 2258 :6 0
22f2 1 :3 0 21
:3 0 e8 :3 0 225c
225d 0 21 :3 0
d2 :2 0 f4 :3 0
225f 2261 0 1442
2260 2263 :3 0 2264
:2 0 75 :3 0 75
:3 0 b5 :2 0 235
:4 0 1445 2268 226a
:3 0 2266 226b 0
2280 76 :3 0 76
:3 0 b5 :2 0 236
:4 0 1448 226f 2271
:3 0 b5 :2 0 237
:4 0 144b 2273 2275
:3 0 b5 :2 0 3b
:3 0 144e 2277 2279
:3 0 b5 :2 0 221
:4 0 1451 227b 227d
:3 0 226d 227e 0
2280 1454 22ef ad
:3 0 ae :3 0 2281
2282 0 ad :3 0
bd :3 0 2284 2285
0 24 :2 0 2
:4 0 238 :2 0 bf
:2 0 47 :2 0 1457
228a 228c :3 0 145a
2286 228e 2283 2290
228f :2 0 b0 :3 0
c0 :3 0 2292 2293
0 b2 :4 0 239
:4 0 b5 :2 0 b6
:3 0 145e 2297 2299
:3 0 b5 :2 0 c9
:4 0 1461 229b 229d
:3 0 b5 :2 0 ca
:4 0 1464 229f 22a1
:3 0 b5 :2 0 a1
:3 0 ba :3 0 c2
:3 0 d6 :3 0 22a6
22a7 0 1467 22a5
22a9 bb :4 0 1469
22a4 22ac 146c 22a3
22ae :3 0 b5 :2 0
119 :4 0 146f 22b0
22b2 :3 0 b5 :2 0
b8 :4 0 1472 22b4
22b6 :3 0 b5 :2 0
13 :3 0 1475 22b8
22ba :3 0 b5 :2 0
b8 :4 0 1478 22bc
22be :3 0 147b 2294
22c0 :2 0 22c2 147e
22c3 2291 22c2 0
22c4 1480 0 22ee
ad :3 0 ae :3 0
22c5 22c6 0 ad
:3 0 bd :3 0 22c8
22c9 0 47 :2 0
2 :4 0 23a :2 0
bf :2 0 47 :2 0
1482 22ce 22d0 :3 0
1485 22ca 22d2 22c7
22d4 22d3 :2 0 b0
:3 0 c0 :3 0 22d6
22d7 0 b2 :4 0
23b :4 0 b5 :2 0
b6 :3 0 1489 22db
22dd :3 0 148c 22d8
22df :2 0 22e1 148f
22e2 22d5 22e1 0
22e3 1491 0 22ee
ce :3 0 11c :3 0
22e4 22e5 0 c2
:3 0 d6 :3 0 22e7
22e8 0 13 :3 0
d0 :3 0 1493 22e6
22ec :2 0 22ee 1497
22f0 2265 2280 0
22f1 0 22ee 0
22f1 149b 0 22f2
149e 22f3 21fb 22f2
0 22f4 14a1 0
2322 a1 :3 0 54
:3 0 4e :2 0 14a3
22f5 22f8 108 :2 0
4e :2 0 14a8 22fa
22fc :3 0 a1 :3 0
54 :3 0 4e :2 0
14ab 22fe 2301 c3
:2 0 e2 :2 0 14b0
2303 2305 :3 0 22fd
2307 2306 :2 0 76
:3 0 76 :3 0 b5
:2 0 23c :4 0 14b3
230b 230d :3 0 b5
:2 0 ba :3 0 a1
:3 0 15 :3 0 4e
:2 0 14b6 2311 2314
14b9 2310 2316 14bb
230f 2318 :3 0 b5
:2 0 c9 :4 0 14be
231a 231c :3 0 2309
231d 0 231f 14c1
2320 2308 231f 0
2321 14c3 0 2322
14c5 2323 1ff0 2322
0 2324 14ca 0
25ba 16 :3 0 e3
:2 0 14cc 2326 2327
:3 0 2328 :2 0 91
:3 0 a1 :3 0 1f1
:3 0 2e :3 0 14ce
232c 232e 4e :2 0
14d0 232b 2331 232a
2332 0 247b 85
:3 0 4e :2 0 2334
2335 0 247b 1f9
:3 0 85 :3 0 91
:3 0 f5 :2 0 1fa
:3 0 14d5 233a 233c
:3 0 233d 247a 49
:3 0 23d :3 0 23e
:3 0 2340 2341 0
24 :2 0 24 :2 0
85 :3 0 bf :2 0
47 :2 0 14d8 2346
2348 :3 0 2e :3 0
14db 2342 234b 233f
234c 0 2478 1e6
:3 0 3b :3 0 1af
:3 0 110 :3 0 49
:4 0 23f 1 :8 0
2359 21 :3 0 e8
:3 0 2354 2355 0
e9 :3 0 2356 2357
0 2359 14e0 23ac
ea :3 0 21 :3 0
e8 :3 0 235b 235c
0 e9 :3 0 235d
235e 0 2360 14e3
2362 14e5 2361 2360
:2 0 23aa eb :3 0
21 :3 0 e8 :3 0
2365 2366 0 e9
:3 0 2367 2368 0
23a2 ad :3 0 ae
:3 0 236a 236b 0
ad :3 0 bd :3 0
236d 236e 0 ec
:2 0 2 :4 0 240
:2 0 bf :2 0 47
:2 0 14e7 2373 2375
:3 0 14ea 236f 2377
236c 2379 2378 :2 0
b0 :3 0 c0 :3 0
237b 237c 0 b2
:4 0 241 :4 0 b5
:2 0 b6 :3 0 14ee
2380 2382 :3 0 b5
:2 0 c9 :4 0 14f1
2384 2386 :3 0 b5
:2 0 ef :4 0 14f4
2388 238a :3 0 b5
:2 0 e9 :3 0 14f7
238c 238e :3 0 b5
:2 0 f0 :4 0 14fa
2390 2392 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 47 :2 0 f3
:2 0 14fd 2395 2399
1501 2394 239b :3 0
1504 237d 239d :2 0
239f 1507 23a0 237a
239f 0 23a1 1509
0 23a2 150b 23a5
:3 0 23a5 0 23a5
23a4 23a2 23a3 :6 0
23a7 3c :3 0 150e
23a9 1510 23a8 23a7
:2 0 23aa 1512 :2 0
23ac 0 23ac 23ab
2359 23aa :6 0 2478
3b :3 0 21 :3 0
e8 :3 0 23ae 23af
0 21 :3 0 c3
:2 0 f4 :3 0 23b1
23b3 0 1517 23b2
23b5 :3 0 23b6 :2 0
ad :3 0 ae :3 0
23b8 23b9 0 ad
:3 0 bd :3 0 23bb
23bc 0 24 :2 0
2 :4 0 242 :2 0
bf :2 0 47 :2 0
151a 23c1 23c3 :3 0
151d 23bd 23c5 23ba
23c7 23c6 :2 0 b0
:3 0 c0 :3 0 23c9
23ca 0 b2 :4 0
243 :4 0 b5 :2 0
b6 :3 0 1521 23ce
23d0 :3 0 b5 :2 0
c9 :4 0 1524 23d2
23d4 :3 0 b5 :2 0
ca :4 0 1527 23d6
23d8 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 d6 :3 0
23dd 23de 0 152a
23dc 23e0 bb :4 0
152c 23db 23e3 152f
23da 23e5 :3 0 b5
:2 0 119 :4 0 1532
23e7 23e9 :3 0 b5
:2 0 b8 :4 0 1535
23eb 23ed :3 0 b5
:2 0 49 :3 0 1538
23ef 23f1 :3 0 b5
:2 0 b8 :4 0 153b
23f3 23f5 :3 0 153e
23cb 23f7 :2 0 23f9
1541 23fa 23c8 23f9
0 23fb 1543 0
2425 ad :3 0 ae
:3 0 23fc 23fd 0
ad :3 0 bd :3 0
23ff 2400 0 47
:2 0 2 :4 0 244
:2 0 bf :2 0 47
:2 0 1545 2405 2407
:3 0 1548 2401 2409
23fe 240b 240a :2 0
b0 :3 0 c0 :3 0
240d 240e 0 b2
:4 0 245 :4 0 b5
:2 0 b6 :3 0 154c
2412 2414 :3 0 154f
240f 2416 :2 0 2418
1552 2419 240c 2418
0 241a 1554 0
2425 ce :3 0 11c
:3 0 241b 241c 0
c2 :3 0 d6 :3 0
241e 241f 0 49
:3 0 d0 :3 0 1556
241d 2423 :2 0 2425
155a 2426 23b7 2425
0 2427 155e 0
2478 76 :3 0 76
:3 0 b5 :2 0 246
:4 0 1560 242a 242c
:3 0 b5 :2 0 247
:4 0 1563 242e 2430
:3 0 b5 :2 0 248
:4 0 1566 2432 2434
:3 0 b5 :2 0 249
:4 0 1569 2436 2438
:3 0 b5 :2 0 3b
:3 0 156c 243a 243c
:3 0 b5 :2 0 24a
:4 0 156f 243e 2440
:3 0 2428 2441 0
2478 a1 :3 0 5c
:3 0 4e :2 0 1572
2443 2446 c2 :3 0
d2 :2 0 d3 :3 0
2448 244a 0 1577
2449 244c :3 0 76
:3 0 76 :3 0 b5
:2 0 24b :4 0 157a
2450 2452 :3 0 244e
2453 0 2455 157d
245e 76 :3 0 76
:3 0 b5 :2 0 24c
:4 0 157f 2458 245a
:3 0 2456 245b 0
245d 1582 245f 244d
2455 0 2460 0
245d 0 2460 1584
0 2478 a1 :3 0
5c :3 0 4e :2 0
1587 2461 2464 c2
:3 0 d2 :2 0 d3
:3 0 2466 2468 0
158c 2467 246a :3 0
1fe :8 0 246e 158f
246f 246b 246e 0
2470 1591 0 2478
85 :3 0 85 :3 0
bf :2 0 24 :2 0
1593 2473 2475 :3 0
2471 2476 0 2478
1596 247a 1fa :3 0
233e 2478 :4 0 247b
159e 247c 2329 247b
0 247d 15a2 0
25ba a1 :3 0 5c
:3 0 4e :2 0 15a4
247e 2481 c2 :3 0
c3 :2 0 d3 :3 0
2483 2485 0 15a9
2484 2487 :3 0 92
:3 0 a1 :3 0 1f1
:3 0 30 :3 0 15ac
248b 248d 4e :2 0
15ae 248a 2490 2489
2491 0 25b0 85
:3 0 4e :2 0 2493
2494 0 25b0 1f9
:3 0 85 :3 0 92
:3 0 f5 :2 0 1fa
:3 0 15b3 2499 249b
:3 0 249c 25af 49
:3 0 23d :3 0 23e
:3 0 249f 24a0 0
24 :2 0 24 :2 0
85 :3 0 bf :2 0
47 :2 0 15b6 24a5
24a7 :3 0 30 :3 0
15b9 24a1 24aa 249e
24ab 0 25ad 1e6
:3 0 3b :3 0 1af
:3 0 110 :3 0 49
:4 0 23f 1 :8 0
24b8 21 :3 0 e8
:3 0 24b3 24b4 0
e9 :3 0 24b5 24b6
0 24b8 15be 250b
ea :3 0 21 :3 0
e8 :3 0 24ba 24bb
0 e9 :3 0 24bc
24bd 0 24bf 15c1
24c1 15c3 24c0 24bf
:2 0 2509 eb :3 0
21 :3 0 e8 :3 0
24c4 24c5 0 e9
:3 0 24c6 24c7 0
2501 ad :3 0 ae
:3 0 24c9 24ca 0
ad :3 0 bd :3 0
24cc 24cd 0 ec
:2 0 2 :4 0 24d
:2 0 bf :2 0 47
:2 0 15c5 24d2 24d4
:3 0 15c8 24ce 24d6
24cb 24d8 24d7 :2 0
b0 :3 0 c0 :3 0
24da 24db 0 b2
:4 0 24e :4 0 b5
:2 0 b6 :3 0 15cc
24df 24e1 :3 0 b5
:2 0 c9 :4 0 15cf
24e3 24e5 :3 0 b5
:2 0 ef :4 0 15d2
24e7 24e9 :3 0 b5
:2 0 e9 :3 0 15d5
24eb 24ed :3 0 b5
:2 0 f0 :4 0 15d8
24ef 24f1 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 47 :2 0 f3
:2 0 15db 24f4 24f8
15df 24f3 24fa :3 0
15e2 24dc 24fc :2 0
24fe 15e5 24ff 24d9
24fe 0 2500 15e7
0 2501 15e9 2504
:3 0 2504 0 2504
2503 2501 2502 :6 0
2506 3f :3 0 15ec
2508 15ee 2507 2506
:2 0 2509 15f0 :2 0
250b 0 250b 250a
24b8 2509 :6 0 25ad
3e :3 0 21 :3 0
e8 :3 0 250d 250e
0 21 :3 0 c3
:2 0 f4 :3 0 2510
2512 0 15f5 2511
2514 :3 0 2515 :2 0
ad :3 0 ae :3 0
2517 2518 0 ad
:3 0 bd :3 0 251a
251b 0 24 :2 0
2 :4 0 24f :2 0
bf :2 0 47 :2 0
15f8 2520 2522 :3 0
15fb 251c 2524 2519
2526 2525 :2 0 b0
:3 0 c0 :3 0 2528
2529 0 b2 :4 0
250 :4 0 b5 :2 0
b6 :3 0 15ff 252d
252f :3 0 b5 :2 0
c9 :4 0 1602 2531
2533 :3 0 b5 :2 0
ca :4 0 1605 2535
2537 :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 d6 :3 0
253c 253d 0 1608
253b 253f bb :4 0
160a 253a 2542 160d
2539 2544 :3 0 b5
:2 0 119 :4 0 1610
2546 2548 :3 0 b5
:2 0 b8 :4 0 1613
254a 254c :3 0 b5
:2 0 49 :3 0 1616
254e 2550 :3 0 b5
:2 0 b8 :4 0 1619
2552 2554 :3 0 161c
252a 2556 :2 0 2558
161f 2559 2527 2558
0 255a 1621 0
2584 ad :3 0 ae
:3 0 255b 255c 0
ad :3 0 bd :3 0
255e 255f 0 47
:2 0 2 :4 0 251
:2 0 bf :2 0 47
:2 0 1623 2564 2566
:3 0 1626 2560 2568
255d 256a 2569 :2 0
b0 :3 0 c0 :3 0
256c 256d 0 b2
:4 0 252 :4 0 b5
:2 0 b6 :3 0 162a
2571 2573 :3 0 162d
256e 2575 :2 0 2577
1630 2578 256b 2577
0 2579 1632 0
2584 ce :3 0 11c
:3 0 257a 257b 0
c2 :3 0 d6 :3 0
257d 257e 0 49
:3 0 d0 :3 0 1634
257c 2582 :2 0 2584
1638 2585 2516 2584
0 2586 163c 0
25ad 76 :3 0 76
:3 0 b5 :2 0 246
:4 0 163e 2589 258b
:3 0 b5 :2 0 247
:4 0 1641 258d 258f
:3 0 b5 :2 0 248
:4 0 1644 2591 2593
:3 0 b5 :2 0 249
:4 0 1647 2595 2597
:3 0 b5 :2 0 3b
:3 0 164a 2599 259b
:3 0 b5 :2 0 24a
:4 0 164d 259d 259f
:3 0 b5 :2 0 253
:4 0 1650 25a1 25a3
:3 0 2587 25a4 0
25ad 85 :3 0 85
:3 0 bf :2 0 24
:2 0 1653 25a8 25aa
:3 0 25a6 25ab 0
25ad 1656 25af 1fa
:3 0 249d 25ad :4 0
25b0 165c 25b1 2488
25b0 0 25b2 1660
0 25ba 75 :3 0
75 :3 0 b5 :2 0
76 :3 0 1662 25b5
25b7 :3 0 25b3 25b8
0 25ba 1665 25bc
1bf4 1c6a 0 25bd
0 25ba 0 25bd
166d 0 368b 75
:3 0 75 :3 0 b5
:2 0 254 :4 0 1670
25c0 25c2 :3 0 25be
25c3 0 368b 255
:3 0 93 :3 0 75
:3 0 25c6 25c7 0
25c8 :2 0 368b 1fa
:3 0 93 :3 0 39
:4 0 25ce :2 0 2a84
25cb 25cc :3 0 93
:3 0 1bf :3 0 25cf
25d0 :3 0 21 :3 0
e8 :3 0 25d2 25d3
0 4e :2 0 25d4
25d5 0 25d7 1673
25de 21 :3 0 e8
:3 0 25d8 25d9 0
18a :2 0 25da 25db
0 25dd 1675 25df
25d1 25d7 0 25e0
0 25dd 0 25e0
1677 0 2a84 21
:3 0 e8 :3 0 25e1
25e2 0 21 :3 0
c3 :2 0 f4 :3 0
25e4 25e6 0 167c
25e5 25e8 :3 0 25e9
:2 0 1fe :8 0 25ed
167f 25ee 25ea 25ed
0 25ef 1681 0
2a84 a1 :3 0 50
:3 0 4e :2 0 1683
25f0 25f3 d2 :2 0
4e :2 0 1688 25f5
25f7 :3 0 a1 :3 0
5c :3 0 4e :2 0
168b 25f9 25fc c2
:3 0 c3 :2 0 c4
:3 0 25fe 2600 0
1690 25ff 2602 :3 0
25f8 2604 2603 :2 0
a1 :3 0 5c :3 0
4e :2 0 1693 2606
2609 c2 :3 0 c3
:2 0 d1 :3 0 260b
260d 0 1698 260c
260f :3 0 2605 2611
2610 :2 0 a1 :3 0
5c :3 0 4e :2 0
169b 2613 2616 c2
:3 0 c3 :2 0 d3
:3 0 2618 261a 0
16a0 2619 261c :3 0
14 :3 0 c5 :2 0
16a3 261f 2620 :3 0
2621 :2 0 261d 2623
2622 :2 0 2624 :2 0
2612 2626 2625 :2 0
255 :3 0 95 :4 0
262b :2 0 2710 2629
262c :3 0 95 :3 0
28 :4 0 2630 :2 0
2710 262d 262e :3 0
95 :3 0 1bf :3 0
2631 2632 :3 0 21
:3 0 e8 :3 0 2634
2635 0 4e :2 0
2636 2637 0 2639
16a5 2640 21 :3 0
e8 :3 0 263a 263b
0 18a :2 0 263c
263d 0 263f 16a7
2641 2633 2639 0
2642 0 263f 0
2642 16a9 0 2710
21 :3 0 e8 :3 0
2643 2644 0 21
:3 0 d2 :2 0 f4
:3 0 2646 2648 0
16ae 2647 264a :3 0
264b :2 0 256 :3 0
95 :4 0 2650 :2 0
2656 264e 0 21
:3 0 e8 :3 0 2651
2652 0 e9 :3 0
2653 2654 0 2656
16b1 26a9 ea :3 0
21 :3 0 e8 :3 0
2658 2659 0 e9
:3 0 265a 265b 0
265d 16b4 265f 16b6
265e 265d :2 0 26a7
eb :3 0 21 :3 0
e8 :3 0 2662 2663
0 e9 :3 0 2664
2665 0 269f ad
:3 0 ae :3 0 2667
2668 0 ad :3 0
bd :3 0 266a 266b
0 ec :2 0 2
:4 0 257 :2 0 bf
:2 0 47 :2 0 16b8
2670 2672 :3 0 16bb
266c 2674 2669 2676
2675 :2 0 b0 :3 0
c0 :3 0 2678 2679
0 b2 :4 0 258
:4 0 b5 :2 0 b6
:3 0 16bf 267d 267f
:3 0 b5 :2 0 c9
:4 0 16c2 2681 2683
:3 0 b5 :2 0 ef
:4 0 16c5 2685 2687
:3 0 b5 :2 0 e9
:3 0 16c8 2689 268b
:3 0 b5 :2 0 f0
:4 0 16cb 268d 268f
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 47
:2 0 f3 :2 0 16ce
2692 2696 16d2 2691
2698 :3 0 16d5 267a
269a :2 0 269c 16d8
269d 2677 269c 0
269e 16da 0 269f
16dc 26a2 :3 0 26a2
0 26a2 26a1 269f
26a0 :6 0 26a4 42
:3 0 16df 26a6 16e1
26a5 26a4 :2 0 26a7
16e3 :2 0 26a9 0
26a9 26a8 2656 26a7
:6 0 26ad 41 :3 0
259 :3 0 26ab :4 0
26ad 16e6 270d 256
:3 0 95 :4 0 26b1
:2 0 26b7 26af 0
21 :3 0 e8 :3 0
26b2 26b3 0 e9
:3 0 26b4 26b5 0
26b7 16e9 270a ea
:3 0 21 :3 0 e8
:3 0 26b9 26ba 0
e9 :3 0 26bb 26bc
0 26be 16ec 26c0
16ee 26bf 26be :2 0
2708 eb :3 0 21
:3 0 e8 :3 0 26c3
26c4 0 e9 :3 0
26c5 26c6 0 2700
ad :3 0 ae :3 0
26c8 26c9 0 ad
:3 0 bd :3 0 26cb
26cc 0 ec :2 0
2 :4 0 25a :2 0
bf :2 0 47 :2 0
16f0 26d1 26d3 :3 0
16f3 26cd 26d5 26ca
26d7 26d6 :2 0 b0
:3 0 c0 :3 0 26d9
26da 0 b2 :4 0
25b :4 0 b5 :2 0
b6 :3 0 16f7 26de
26e0 :3 0 b5 :2 0
c9 :4 0 16fa 26e2
26e4 :3 0 b5 :2 0
ef :4 0 16fd 26e6
26e8 :3 0 b5 :2 0
e9 :3 0 1700 26ea
26ec :3 0 b5 :2 0
f0 :4 0 1703 26ee
26f0 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
1706 26f3 26f7 170a
26f2 26f9 :3 0 170d
26db 26fb :2 0 26fd
1710 26fe 26d8 26fd
0 26ff 1712 0
2700 1714 2703 :3 0
2703 0 2703 2702
2700 2701 :6 0 2705
44 :3 0 1717 2707
1719 2706 2705 :2 0
2708 171b :2 0 270a
0 270a 2709 26b7
2708 :6 0 270c 41
:3 0 171e 270e 264c
26ad 0 270f 0
270c 0 270f 1720
0 2710 1723 2711
2627 2710 0 2712
1728 0 2a84 2e
:3 0 16 :3 0 2713
2714 0 2a84 30
:3 0 17 :3 0 2716
2717 0 2a84 a1
:3 0 50 :3 0 4e
:2 0 172a 2719 271c
108 :2 0 4e :2 0
172f 271e 2720 :3 0
f1 :3 0 46 :3 0
47 :2 0 47 :2 0
1732 2722 2726 d2
:2 0 47 :4 0 1738
2728 272a :3 0 48
:3 0 198 :4 0 272d
272e :3 0 272c 272f
0 2734 4f :3 0
4e :2 0 2731 2732
0 2734 173b 2880
132 :3 0 a1 :3 0
50 :3 0 4e :2 0
173e 2736 2739 1741
2735 273b c3 :2 0
4e :2 0 1745 273d
273f :3 0 25c :3 0
25d :3 0 82 :3 0
97 :3 0 98 :3 0
25 :3 0 9a :3 0
39 :3 0 1a0 :4 0
25e 1 :8 0 2750
21 :3 0 e8 :3 0
274b 274c 0 e9
:3 0 274d 274e 0
2750 1748 27a3 ea
:3 0 21 :3 0 e8
:3 0 2752 2753 0
e9 :3 0 2754 2755
0 2757 174b 2759
174d 2758 2757 :2 0
27a1 eb :3 0 21
:3 0 e8 :3 0 275c
275d 0 e9 :3 0
275e 275f 0 2799
ad :3 0 ae :3 0
2761 2762 0 ad
:3 0 bd :3 0 2764
2765 0 ec :2 0
2 :4 0 25f :2 0
bf :2 0 47 :2 0
174f 276a 276c :3 0
1752 2766 276e 2763
2770 276f :2 0 b0
:3 0 c0 :3 0 2772
2773 0 b2 :4 0
260 :4 0 b5 :2 0
b6 :3 0 1756 2777
2779 :3 0 b5 :2 0
c9 :4 0 1759 277b
277d :3 0 b5 :2 0
ef :4 0 175c 277f
2781 :3 0 b5 :2 0
e9 :3 0 175f 2783
2785 :3 0 b5 :2 0
f0 :4 0 1762 2787
2789 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
1765 278c 2790 1769
278b 2792 :3 0 176c
2774 2794 :2 0 2796
176f 2797 2771 2796
0 2798 1771 0
2799 1773 279c :3 0
279c 0 279c 279b
2799 279a :6 0 279e
46 :3 0 1776 27a0
1778 279f 279e :2 0
27a1 177a :2 0 27a3
0 27a3 27a2 2750
27a1 :6 0 287c 41
:3 0 a1 :3 0 82
:3 0 4e :2 0 177d
27a5 27a8 108 :2 0
4e :2 0 1782 27aa
27ac :3 0 256 :3 0
93 :4 0 27b1 :2 0
27b7 27af 0 21
:3 0 e8 :3 0 27b2
27b3 0 e9 :3 0
27b4 27b5 0 27b7
1785 280a ea :3 0
21 :3 0 e8 :3 0
27b9 27ba 0 e9
:3 0 27bb 27bc 0
27be 1788 27c0 178a
27bf 27be :2 0 2808
eb :3 0 21 :3 0
e8 :3 0 27c3 27c4
0 e9 :3 0 27c5
27c6 0 2800 ad
:3 0 ae :3 0 27c8
27c9 0 ad :3 0
bd :3 0 27cb 27cc
0 ec :2 0 2
:4 0 261 :2 0 bf
:2 0 47 :2 0 178c
27d1 27d3 :3 0 178f
27cd 27d5 27ca 27d7
27d6 :2 0 b0 :3 0
c0 :3 0 27d9 27da
0 b2 :4 0 262
:4 0 b5 :2 0 b6
:3 0 1793 27de 27e0
:3 0 b5 :2 0 c9
:4 0 1796 27e2 27e4
:3 0 b5 :2 0 ef
:4 0 1799 27e6 27e8
:3 0 b5 :2 0 e9
:3 0 179c 27ea 27ec
:3 0 b5 :2 0 f0
:4 0 179f 27ee 27f0
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 47
:2 0 f3 :2 0 17a2
27f3 27f7 17a6 27f2
27f9 :3 0 17a9 27db
27fb :2 0 27fd 17ac
27fe 27d8 27fd 0
27ff 17ae 0 2800
17b0 2803 :3 0 2803
0 2803 2802 2800
2801 :6 0 2805 48
:3 0 17b3 2807 17b5
2806 2805 :2 0 2808
17b7 :2 0 280a 0
280a 2809 27b7 2808
:6 0 2879 41 :3 0
ad :3 0 ae :3 0
280c 280d 0 ad
:3 0 bd :3 0 280f
2810 0 24 :2 0
2 :4 0 263 :2 0
bf :2 0 47 :2 0
17ba 2815 2817 :3 0
17bd 2811 2819 280e
281b 281a :2 0 b0
:3 0 c0 :3 0 281d
281e 0 b2 :4 0
264 :4 0 b5 :2 0
b6 :3 0 17c1 2822
2824 :3 0 b5 :2 0
c9 :4 0 17c4 2826
2828 :3 0 b5 :2 0
ca :4 0 17c7 282a
282c :3 0 b5 :2 0
a1 :3 0 ba :3 0
c2 :3 0 265 :3 0
2831 2832 0 17ca
2830 2834 bb :4 0
17cc 282f 2837 17cf
282e 2839 :3 0 b5
:2 0 119 :4 0 17d2
283b 283d :3 0 b5
:2 0 b8 :4 0 17d5
283f 2841 :3 0 b5
:2 0 39 :3 0 17d8
2843 2845 :3 0 b5
:2 0 b8 :4 0 17db
2847 2849 :3 0 17de
281f 284b :2 0 284d
17e1 284e 281c 284d
0 284f 17e3 0
2879 ad :3 0 ae
:3 0 2850 2851 0
ad :3 0 bd :3 0
2853 2854 0 47
:2 0 2 :4 0 266
:2 0 bf :2 0 47
:2 0 17e5 2859 285b
:3 0 17e8 2855 285d
2852 285f 285e :2 0
b0 :3 0 c0 :3 0
2861 2862 0 b2
:4 0 267 :4 0 b5
:2 0 b6 :3 0 17ec
2866 2868 :3 0 17ef
2863 286a :2 0 286c
17f2 286d 2860 286c
0 286e 17f4 0
2879 ce :3 0 11c
:3 0 286f 2870 0
c2 :3 0 265 :3 0
2872 2873 0 39
:3 0 d0 :3 0 17f6
2871 2877 :2 0 2879
17fa 287a 27ad 2879
0 287b 17ff 0
287c 1801 287d 2740
287c 0 287e 1804
0 287f 1806 2881
272b 2734 0 2882
0 287f 0 2882
1808 0 2a19 88
:3 0 268 :3 0 48
:3 0 25 :3 0 26
:3 0 39 :3 0 66
:3 0 50 :3 0 2e
:3 0 30 :3 0 31
:3 0 32 :3 0 41
:3 0 42 :3 0 61
:3 0 59 :3 0 57
:3 0 5a :3 0 5b
:3 0 55 :3 0 5c
:3 0 46 :3 0 53
:3 0 4d :3 0 5d
:3 0 58 :3 0 52
:3 0 5f :3 0 64
:3 0 29 :3 0 a1
:3 0 5f :3 0 4e
:2 0 180b 28a1 28a4
4e :2 0 68 :2 0
68 :2 0 4e :2 0
4e :2 0 180e 2884
28ab 2883 28ac 0
2a19 88 :3 0 c3
:2 0 4e :2 0 1833
28af 28b1 :3 0 256
:3 0 93 :4 0 28b6
:2 0 28bc 28b4 0
21 :3 0 e8 :3 0
28b7 28b8 0 e9
:3 0 28b9 28ba 0
28bc 1836 290f ea
:3 0 21 :3 0 e8
:3 0 28be 28bf 0
e9 :3 0 28c0 28c1
0 28c3 1839 28c5
183b 28c4 28c3 :2 0
290d eb :3 0 21
:3 0 e8 :3 0 28c8
28c9 0 e9 :3 0
28ca 28cb 0 2905
ad :3 0 ae :3 0
28cd 28ce 0 ad
:3 0 bd :3 0 28d0
28d1 0 ec :2 0
2 :4 0 269 :2 0
bf :2 0 47 :2 0
183d 28d6 28d8 :3 0
1840 28d2 28da 28cf
28dc 28db :2 0 b0
:3 0 c0 :3 0 28de
28df 0 b2 :4 0
26a :4 0 b5 :2 0
b6 :3 0 1844 28e3
28e5 :3 0 b5 :2 0
c9 :4 0 1847 28e7
28e9 :3 0 b5 :2 0
ef :4 0 184a 28eb
28ed :3 0 b5 :2 0
e9 :3 0 184d 28ef
28f1 :3 0 b5 :2 0
f0 :4 0 1850 28f3
28f5 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
1853 28f8 28fc 1857
28f7 28fe :3 0 185a
28e0 2900 :2 0 2902
185d 2903 28dd 2902
0 2904 185f 0
2905 1861 2908 :3 0
2908 0 2908 2907
2905 2906 :6 0 290a
4a :3 0 1864 290c
1866 290b 290a :2 0
290d 1868 :2 0 290f
0 290f 290e 28bc
290d :6 0 298a 41
:3 0 88 :3 0 c2
:3 0 f5 :2 0 26b
:3 0 2912 2914 0
186d 2913 2916 :3 0
88 :3 0 c2 :3 0
26c :3 0 2919 291a
0 2918 291b 0
291d 1870 291e 2917
291d 0 291f 1872
0 298a ad :3 0
ae :3 0 2920 2921
0 ad :3 0 bd
:3 0 2923 2924 0
24 :2 0 2 :4 0
26d :2 0 bf :2 0
47 :2 0 1874 2929
292b :3 0 1877 2925
292d 2922 292f 292e
:2 0 b0 :3 0 c0
:3 0 2931 2932 0
b2 :4 0 26e :4 0
b5 :2 0 b6 :3 0
187b 2936 2938 :3 0
b5 :2 0 c9 :4 0
187e 293a 293c :3 0
b5 :2 0 ca :4 0
1881 293e 2940 :3 0
b5 :2 0 a1 :3 0
ba :3 0 88 :3 0
1884 2944 2946 bb
:4 0 1886 2943 2949
1889 2942 294b :3 0
b5 :2 0 119 :4 0
188c 294d 294f :3 0
b5 :2 0 b8 :4 0
188f 2951 2953 :3 0
b5 :2 0 48 :3 0
1892 2955 2957 :3 0
b5 :2 0 b8 :4 0
1895 2959 295b :3 0
1898 2933 295d :2 0
295f 189b 2960 2930
295f 0 2961 189d
0 298a ad :3 0
ae :3 0 2962 2963
0 ad :3 0 bd
:3 0 2965 2966 0
47 :2 0 2 :4 0
26f :2 0 bf :2 0
47 :2 0 189f 296b
296d :3 0 18a2 2967
296f 2964 2971 2970
:2 0 b0 :3 0 c0
:3 0 2973 2974 0
b2 :4 0 270 :4 0
b5 :2 0 b6 :3 0
18a6 2978 297a :3 0
18a9 2975 297c :2 0
297e 18ac 297f 2972
297e 0 2980 18ae
0 298a ce :3 0
11c :3 0 2981 2982
0 88 :3 0 48
:3 0 d0 :3 0 18b0
2983 2987 :2 0 298a
d8 :3 0 18b4 2a15
f1 :3 0 46 :3 0
47 :2 0 47 :2 0
18ba 298b 298f d2
:2 0 47 :4 0 18c0
2991 2993 :3 0 2994
:2 0 f1 :3 0 4c
:3 0 47 :2 0 47
:2 0 18c3 2996 299a
d2 :2 0 1b9 :4 0
18c9 299c 299e :3 0
299f :2 0 2995 29a1
29a0 :2 0 199 :3 0
10e :3 0 19a :3 0
39 :3 0 10e :4 0
271 1 :8 0 29be
1bf :4 0 29a9 :3 0
d0 :3 0 d2 :2 0
18ce 29ac 29ad :3 0
21 :3 0 e8 :3 0
29af 29b0 0 4e
:2 0 29b1 29b2 0
29b4 18d1 29bb 21
:3 0 e8 :3 0 29b5
29b6 0 18a :2 0
29b7 29b8 0 29ba
18d3 29bc 29ae 29b4
0 29bd 0 29ba
0 29bd 18d5 0
29be 18d8 2a11 ea
:3 0 21 :3 0 e8
:3 0 29c0 29c1 0
e9 :3 0 29c2 29c3
0 29c5 18db 29c7
18dd 29c6 29c5 :2 0
2a0f eb :3 0 21
:3 0 e8 :3 0 29ca
29cb 0 e9 :3 0
29cc 29cd 0 2a07
ad :3 0 ae :3 0
29cf 29d0 0 ad
:3 0 bd :3 0 29d2
29d3 0 ec :2 0
2 :4 0 272 :2 0
bf :2 0 47 :2 0
18df 29d8 29da :3 0
18e2 29d4 29dc 29d1
29de 29dd :2 0 b0
:3 0 c0 :3 0 29e0
29e1 0 b2 :4 0
273 :4 0 b5 :2 0
b6 :3 0 18e6 29e5
29e7 :3 0 b5 :2 0
c9 :4 0 18e9 29e9
29eb :3 0 b5 :2 0
ef :4 0 18ec 29ed
29ef :3 0 b5 :2 0
e9 :3 0 18ef 29f1
29f3 :3 0 b5 :2 0
f0 :4 0 18f2 29f5
29f7 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
18f5 29fa 29fe 18f9
29f9 2a00 :3 0 18fc
29e2 2a02 :2 0 2a04
18ff 2a05 29df 2a04
0 2a06 1901 0
2a07 1903 2a0a :3 0
2a0a 0 2a0a 2a09
2a07 2a08 :6 0 2a0c
4c :3 0 1906 2a0e
1908 2a0d 2a0c :2 0
2a0f 190a :2 0 2a11
0 2a11 2a10 29be
2a0f :6 0 2a13 41
:3 0 190d 2a14 29a2
2a13 0 2a16 28b2
298a 0 2a16 190f
0 2a19 1fe :8 0
2a19 1912 2a7d a1
:3 0 4d :3 0 4e
:2 0 1917 2a1a 2a1d
c2 :3 0 c3 :2 0
c4 :3 0 2a1f 2a21
0 191c 2a20 2a23
:3 0 41 :3 0 5
:3 0 2a25 2a26 0
2a2b 42 :3 0 6
:3 0 2a28 2a29 0
2a2b 191f 2a2c 2a24
2a2b 0 2a2d 1922
0 2a7c 88 :3 0
268 :3 0 48 :3 0
25 :3 0 26 :3 0
39 :3 0 66 :3 0
50 :3 0 2e :3 0
30 :3 0 31 :3 0
32 :3 0 41 :3 0
42 :3 0 61 :3 0
59 :3 0 57 :3 0
5a :3 0 5b :3 0
55 :3 0 5c :3 0
46 :3 0 53 :3 0
4d :3 0 5d :3 0
58 :3 0 52 :3 0
5f :3 0 64 :3 0
29 :3 0 4e :2 0
4e :2 0 68 :2 0
68 :2 0 4e :2 0
4e :2 0 1924 2a2f
2a52 2a2e 2a53 0
2a7c 88 :3 0 d2
:2 0 4e :2 0 1949
2a56 2a58 :3 0 87
:3 0 87 :3 0 bf
:2 0 47 :2 0 194c
2a5c 2a5e :3 0 2a5a
2a5f 0 2a62 d8
:3 0 194f 2a6c 88
:3 0 f5 :2 0 4e
:2 0 1953 2a64 2a66
:3 0 1fe :8 0 2a6a
1956 2a6b 2a67 2a6a
0 2a6d 2a59 2a62
0 2a6d 1958 0
2a7c 87 :3 0 a1
:3 0 d2 :2 0 56
:3 0 4e :2 0 195b
2a6f 2a73 1960 2a70
2a75 :3 0 1fe :8 0
2a79 1963 2a7a 2a76
2a79 0 2a7b 1965
0 2a7c 1967 2a7e
2721 2a19 0 2a7f
0 2a7c 0 2a7f
196c 0 2a84 259
:5 0 2a82 4e 0
2a83 196f 2a82 2a81
2a84 1971 2a86 1fa
:4 0 2a84 :4 0 368b
256 :3 0 93 :4 0
2a8a :2 0 2a90 2a88
0 21 :3 0 e8
:3 0 2a8b 2a8c 0
e9 :3 0 2a8d 2a8e
0 2a90 197a 2ae3
ea :3 0 21 :3 0
e8 :3 0 2a92 2a93
0 e9 :3 0 2a94
2a95 0 2a97 197d
2a99 197f 2a98 2a97
:2 0 2ae1 eb :3 0
21 :3 0 e8 :3 0
2a9c 2a9d 0 e9
:3 0 2a9e 2a9f 0
2ad9 ad :3 0 ae
:3 0 2aa1 2aa2 0
ad :3 0 bd :3 0
2aa4 2aa5 0 ec
:2 0 2 :4 0 274
:2 0 bf :2 0 47
:2 0 1981 2aaa 2aac
:3 0 1984 2aa6 2aae
2aa3 2ab0 2aaf :2 0
b0 :3 0 c0 :3 0
2ab2 2ab3 0 b2
:4 0 275 :4 0 b5
:2 0 b6 :3 0 1988
2ab7 2ab9 :3 0 b5
:2 0 c9 :4 0 198b
2abb 2abd :3 0 b5
:2 0 ef :4 0 198e
2abf 2ac1 :3 0 b5
:2 0 e9 :3 0 1991
2ac3 2ac5 :3 0 b5
:2 0 f0 :4 0 1994
2ac7 2ac9 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 47 :2 0 f3
:2 0 1997 2acc 2ad0
199b 2acb 2ad2 :3 0
199e 2ab4 2ad4 :2 0
2ad6 19a1 2ad7 2ab1
2ad6 0 2ad8 19a3
0 2ad9 19a5 2adc
:3 0 2adc 0 2adc
2adb 2ad9 2ada :6 0
2ade 4e :3 0 19a8
2ae0 19aa 2adf 2ade
:2 0 2ae1 19ac :2 0
2ae3 0 2ae3 2ae2
2a90 2ae1 :6 0 368b
1 :3 0 88 :3 0
c2 :3 0 d2 :2 0
276 :3 0 2ae6 2ae8
0 19b1 2ae7 2aea
:3 0 2aeb :2 0 88
:3 0 f5 :2 0 4e
:2 0 19b6 2aee 2af0
:3 0 2af1 :2 0 2aec
2af3 2af2 :2 0 88
:3 0 c3 :2 0 4e
:2 0 19bb 2af6 2af8
:3 0 a1 :3 0 50
:3 0 4e :2 0 19be
2afa 2afd 108 :2 0
4e :2 0 19c3 2aff
2b01 :3 0 2af9 2b03
2b02 :2 0 2b04 :2 0
2af4 2b06 2b05 :2 0
ad :3 0 ae :3 0
2b08 2b09 0 ad
:3 0 bd :3 0 2b0b
2b0c 0 24 :2 0
2 :4 0 277 :2 0
bf :2 0 47 :2 0
19c6 2b11 2b13 :3 0
19c9 2b0d 2b15 2b0a
2b17 2b16 :2 0 b0
:3 0 c0 :3 0 2b19
2b1a 0 b2 :4 0
278 :4 0 b5 :2 0
b6 :3 0 19cd 2b1e
2b20 :3 0 b5 :2 0
c9 :4 0 19d0 2b22
2b24 :3 0 b5 :2 0
ca :4 0 19d3 2b26
2b28 :3 0 b5 :2 0
a1 :3 0 ba :3 0
88 :3 0 19d6 2b2c
2b2e bb :4 0 19d8
2b2b 2b31 19db 2b2a
2b33 :3 0 b5 :2 0
119 :4 0 19de 2b35
2b37 :3 0 b5 :2 0
b8 :4 0 19e1 2b39
2b3b :3 0 b5 :2 0
48 :3 0 19e4 2b3d
2b3f :3 0 b5 :2 0
b8 :4 0 19e7 2b41
2b43 :3 0 19ea 2b1b
2b45 :2 0 2b47 19ed
2b48 2b18 2b47 0
2b49 19ef 0 2b71
ad :3 0 ae :3 0
2b4a 2b4b 0 ad
:3 0 bd :3 0 2b4d
2b4e 0 47 :2 0
2 :4 0 279 :2 0
bf :2 0 47 :2 0
19f1 2b53 2b55 :3 0
19f4 2b4f 2b57 2b4c
2b59 2b58 :2 0 b0
:3 0 c0 :3 0 2b5b
2b5c 0 b2 :4 0
27a :4 0 b5 :2 0
b6 :3 0 19f8 2b60
2b62 :3 0 19fb 2b5d
2b64 :2 0 2b66 19fe
2b67 2b5a 2b66 0
2b68 1a00 0 2b71
ce :3 0 11c :3 0
2b69 2b6a 0 88
:3 0 48 :3 0 d0
:3 0 1a02 2b6b 2b6f
:2 0 2b71 1a06 2b72
2b07 2b71 0 2b73
1a0a 0 368b 8b
:3 0 c3 :2 0 47
:2 0 1a0e 2b75 2b77
:3 0 27 :3 0 27b
:4 0 2b79 2b7a 0
2ebe 28 :3 0 18c
:4 0 2b7c 2b7d 0
2ebe 3a :3 0 18c
:4 0 2b7f 2b80 0
2ebe 255 :3 0 9c
:4 0 2b85 :2 0 2ebe
2b83 2b86 :3 0 85
:3 0 4e :2 0 2b87
2b88 0 2ebe 1fa
:3 0 9c :3 0 26
:3 0 39 :3 0 49
:3 0 33 :3 0 4a
:3 0 34 :3 0 35
:3 0 36 :4 0 2b95
:2 0 2ddb 2b8b 2b96
:3 0 1a11 :3 0 9c
:3 0 1bf :3 0 2b97
2b98 :3 0 21 :3 0
e8 :3 0 2b9a 2b9b
0 4e :2 0 2b9c
2b9d 0 2b9f 1a1a
2ba6 21 :3 0 e8
:3 0 2ba0 2ba1 0
18a :2 0 2ba2 2ba3
0 2ba5 1a1c 2ba7
2b99 2b9f 0 2ba8
0 2ba5 0 2ba8
1a1e 0 2ddb 21
:3 0 e8 :3 0 2ba9
2baa 0 21 :3 0
c3 :2 0 f4 :3 0
2bac 2bae 0 1a23
2bad 2bb0 :3 0 2bb1
:2 0 1fe :8 0 2bb5
1a26 2bb6 2bb2 2bb5
0 2bb7 1a28 0
2ddb 49 :3 0 e3
:2 0 1a2a 2bb9 2bba
:3 0 2bbb :2 0 e4
:3 0 114 :3 0 2bbd
2bbe 0 49 :3 0
39 :3 0 1a2c 2bbf
2bc2 d2 :2 0 4e
:2 0 1a31 2bc4 2bc6
:3 0 2bbc 2bc8 2bc7
:2 0 a1 :3 0 1f1
:3 0 27 :3 0 1a34
2bcb 2bcd 4e :2 0
1a36 2bca 2bd0 d2
:2 0 4e :2 0 1a3b
2bd2 2bd4 :3 0 2bc9
2bd6 2bd5 :2 0 27
:3 0 26 :3 0 2bd8
2bd9 0 2bdb 1a3e
2bdc 2bd7 2bdb 0
2bdd 1a40 0 2ddb
e4 :3 0 114 :3 0
2bde 2bdf 0 28
:3 0 39 :3 0 1a42
2be0 2be3 c3 :2 0
4e :2 0 1a47 2be5
2be7 :3 0 85 :3 0
c3 :2 0 4e :2 0
1a4c 2bea 2bec :3 0
a7 :3 0 a0 :3 0
37 :3 0 a2 :3 0
2e :3 0 a3 :3 0
38 :3 0 a4 :3 0
30 :3 0 a5 :3 0
31 :3 0 a6 :3 0
32 :3 0 9d :3 0
3a :4 0 27c 1
:8 0 2c13 1bf :4 0
2bfe :3 0 d0 :3 0
d2 :2 0 1a51 2c01
2c02 :3 0 21 :3 0
e8 :3 0 2c04 2c05
0 4e :2 0 2c06
2c07 0 2c09 1a54
2c10 21 :3 0 e8
:3 0 2c0a 2c0b 0
18a :2 0 2c0c 2c0d
0 2c0f 1a56 2c11
2c03 2c09 0 2c12
0 2c0f 0 2c12
1a58 0 2c13 1a5b
2c66 ea :3 0 21
:3 0 e8 :3 0 2c15
2c16 0 e9 :3 0
2c17 2c18 0 2c1a
1a5e 2c1c 1a60 2c1b
2c1a :2 0 2c64 eb
:3 0 21 :3 0 e8
:3 0 2c1f 2c20 0
e9 :3 0 2c21 2c22
0 2c5c ad :3 0
ae :3 0 2c24 2c25
0 ad :3 0 bd
:3 0 2c27 2c28 0
ec :2 0 2 :4 0
27d :2 0 bf :2 0
47 :2 0 1a62 2c2d
2c2f :3 0 1a65 2c29
2c31 2c26 2c33 2c32
:2 0 b0 :3 0 c0
:3 0 2c35 2c36 0
b2 :4 0 27e :4 0
b5 :2 0 b6 :3 0
1a69 2c3a 2c3c :3 0
b5 :2 0 c9 :4 0
1a6c 2c3e 2c40 :3 0
b5 :2 0 ef :4 0
1a6f 2c42 2c44 :3 0
b5 :2 0 e9 :3 0
1a72 2c46 2c48 :3 0
b5 :2 0 f0 :4 0
1a75 2c4a 2c4c :3 0
b5 :2 0 f1 :3 0
f2 :3 0 47 :2 0
f3 :2 0 1a78 2c4f
2c53 1a7c 2c4e 2c55
:3 0 1a7f 2c37 2c57
:2 0 2c59 1a82 2c5a
2c34 2c59 0 2c5b
1a84 0 2c5c 1a86
2c5f :3 0 2c5f 0
2c5f 2c5e 2c5c 2c5d
:6 0 2c61 51 :3 0
1a89 2c63 1a8b 2c62
2c61 :2 0 2c64 1a8d
:2 0 2c66 0 2c66
2c65 2c13 2c64 :6 0
2c68 50 :3 0 1a90
2c69 2bed 2c68 0
2c6a 1a92 0 2c83
2e :3 0 18c :4 0
2c6b 2c6c 0 2c83
30 :3 0 18c :4 0
2c6e 2c6f 0 2c83
31 :3 0 18c :4 0
2c71 2c72 0 2c83
32 :3 0 18c :4 0
2c74 2c75 0 2c83
37 :3 0 18c :4 0
2c77 2c78 0 2c83
38 :3 0 18c :4 0
2c7a 2c7b 0 2c83
28 :3 0 39 :3 0
2c7d 2c7e 0 2c83
85 :3 0 4e :2 0
2c80 2c81 0 2c83
1a94 2c84 2be8 2c83
0 2c85 1a9e 0
2ddb 85 :3 0 c3
:2 0 4e :2 0 1aa2
2c87 2c89 :3 0 3a
:3 0 e3 :2 0 1aa5
2c8c 2c8d :3 0 2c8e
:2 0 2c8a 2c90 2c8f
:2 0 a7 :3 0 a0
:3 0 a2 :3 0 a3
:3 0 a4 :3 0 a5
:3 0 a6 :3 0 9d
:3 0 3a :4 0 27f
1 :8 0 2cb1 1bf
:4 0 2c9c :3 0 d0
:3 0 d2 :2 0 1aa9
2c9f 2ca0 :3 0 21
:3 0 e8 :3 0 2ca2
2ca3 0 4e :2 0
2ca4 2ca5 0 2ca7
1aac 2cae 21 :3 0
e8 :3 0 2ca8 2ca9
0 18a :2 0 2caa
2cab 0 2cad 1aae
2caf 2ca1 2ca7 0
2cb0 0 2cad 0
2cb0 1ab0 0 2cb1
1ab3 2d04 ea :3 0
21 :3 0 e8 :3 0
2cb3 2cb4 0 e9
:3 0 2cb5 2cb6 0
2cb8 1ab6 2cba 1ab8
2cb9 2cb8 :2 0 2d02
eb :3 0 21 :3 0
e8 :3 0 2cbd 2cbe
0 e9 :3 0 2cbf
2cc0 0 2cfa ad
:3 0 ae :3 0 2cc2
2cc3 0 ad :3 0
bd :3 0 2cc5 2cc6
0 ec :2 0 2
:4 0 280 :2 0 bf
:2 0 47 :2 0 1aba
2ccb 2ccd :3 0 1abd
2cc7 2ccf 2cc4 2cd1
2cd0 :2 0 b0 :3 0
c0 :3 0 2cd3 2cd4
0 b2 :4 0 281
:4 0 b5 :2 0 b6
:3 0 1ac1 2cd8 2cda
:3 0 b5 :2 0 c9
:4 0 1ac4 2cdc 2cde
:3 0 b5 :2 0 ef
:4 0 1ac7 2ce0 2ce2
:3 0 b5 :2 0 e9
:3 0 1aca 2ce4 2ce6
:3 0 b5 :2 0 f0
:4 0 1acd 2ce8 2cea
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 47
:2 0 f3 :2 0 1ad0
2ced 2cf1 1ad4 2cec
2cf3 :3 0 1ad7 2cd5
2cf5 :2 0 2cf7 1ada
2cf8 2cd2 2cf7 0
2cf9 1adc 0 2cfa
1ade 2cfd :3 0 2cfd
0 2cfd 2cfc 2cfa
2cfb :6 0 2cff 53
:3 0 1ae1 2d01 1ae3
2d00 2cff :2 0 2d02
1ae5 :2 0 2d04 0
2d04 2d03 2cb1 2d02
:6 0 2d06 50 :3 0
1ae8 2d07 2c91 2d06
0 2d08 1aea 0
2ddb 33 :3 0 e3
:2 0 1aec 2d0a 2d0b
:3 0 2d0c :2 0 2e
:3 0 e3 :2 0 1aee
2d0f 2d10 :3 0 2d11
:2 0 2e :3 0 f1
:3 0 2e :3 0 b5
:2 0 282 :4 0 1af0
2d16 2d18 :3 0 47
:2 0 2f :2 0 1af3
2d14 2d1c 2d13 2d1d
0 2d1f 1af7 2d20
2d12 2d1f 0 2d21
1af9 0 2d2e 2e
:3 0 f1 :3 0 2e
:3 0 b5 :2 0 33
:3 0 1afb 2d25 2d27
:3 0 47 :2 0 2f
:2 0 1afe 2d23 2d2b
2d22 2d2c 0 2d2e
1b02 2d2f 2d0d 2d2e
0 2d30 1b05 0
2ddb 49 :3 0 e3
:2 0 1b07 2d32 2d33
:3 0 2d34 :2 0 37
:3 0 f1 :3 0 37
:3 0 b5 :2 0 49
:3 0 1b09 2d39 2d3b
:3 0 47 :2 0 2f
:2 0 1b0c 2d37 2d3f
2d36 2d40 0 2d42
1b10 2d43 2d35 2d42
0 2d44 1b12 0
2ddb 34 :3 0 e3
:2 0 1b14 2d46 2d47
:3 0 2d48 :2 0 30
:3 0 e3 :2 0 1b16
2d4b 2d4c :3 0 2d4d
:2 0 30 :3 0 f1
:3 0 30 :3 0 b5
:2 0 282 :4 0 1b18
2d52 2d54 :3 0 47
:2 0 2f :2 0 1b1b
2d50 2d58 2d4f 2d59
0 2d5b 1b1f 2d5c
2d4e 2d5b 0 2d5d
1b21 0 2d6a 30
:3 0 f1 :3 0 30
:3 0 b5 :2 0 34
:3 0 1b23 2d61 2d63
:3 0 47 :2 0 2f
:2 0 1b26 2d5f 2d67
2d5e 2d68 0 2d6a
1b2a 2d6b 2d49 2d6a
0 2d6c 1b2d 0
2ddb 4a :3 0 e3
:2 0 1b2f 2d6e 2d6f
:3 0 2d70 :2 0 38
:3 0 f1 :3 0 38
:3 0 b5 :2 0 4a
:3 0 1b31 2d75 2d77
:3 0 47 :2 0 2f
:2 0 1b34 2d73 2d7b
2d72 2d7c 0 2d7e
1b38 2d7f 2d71 2d7e
0 2d80 1b3a 0
2ddb 35 :3 0 e3
:2 0 1b3c 2d82 2d83
:3 0 2d84 :2 0 31
:3 0 e3 :2 0 1b3e
2d87 2d88 :3 0 2d89
:2 0 31 :3 0 f1
:3 0 31 :3 0 b5
:2 0 282 :4 0 1b40
2d8e 2d90 :3 0 47
:2 0 2f :2 0 1b43
2d8c 2d94 2d8b 2d95
0 2d97 1b47 2d98
2d8a 2d97 0 2d99
1b49 0 2da6 31
:3 0 f1 :3 0 31
:3 0 b5 :2 0 35
:3 0 1b4b 2d9d 2d9f
:3 0 47 :2 0 2f
:2 0 1b4e 2d9b 2da3
2d9a 2da4 0 2da6
1b52 2da7 2d85 2da6
0 2da8 1b55 0
2ddb 36 :3 0 e3
:2 0 1b57 2daa 2dab
:3 0 2dac :2 0 32
:3 0 e3 :2 0 1b59
2daf 2db0 :3 0 2db1
:2 0 32 :3 0 f1
:3 0 32 :3 0 b5
:2 0 282 :4 0 1b5b
2db6 2db8 :3 0 47
:2 0 2f :2 0 1b5e
2db4 2dbc 2db3 2dbd
0 2dbf 1b62 2dc0
2db2 2dbf 0 2dc1
1b64 0 2dce 32
:3 0 f1 :3 0 32
:3 0 b5 :2 0 36
:3 0 1b66 2dc5 2dc7
:3 0 47 :2 0 2f
:2 0 1b69 2dc3 2dcb
2dc2 2dcc 0 2dce
1b6d 2dcf 2dad 2dce
0 2dd0 1b70 0
2ddb 85 :3 0 85
:3 0 bf :2 0 47
:2 0 1b72 2dd3 2dd5
:3 0 2dd1 2dd6 0
2ddb 3a :3 0 26
:3 0 2dd8 2dd9 0
2ddb 1b75 2ddd 1fa
:4 0 2ddb :4 0 2ebe
256 :3 0 9c :4 0
2de1 :2 0 2de7 2ddf
0 21 :3 0 e8
:3 0 2de2 2de3 0
e9 :3 0 2de4 2de5
0 2de7 1b84 2e3a
ea :3 0 21 :3 0
e8 :3 0 2de9 2dea
0 e9 :3 0 2deb
2dec 0 2dee 1b87
2df0 1b89 2def 2dee
:2 0 2e38 eb :3 0
21 :3 0 e8 :3 0
2df3 2df4 0 e9
:3 0 2df5 2df6 0
2e30 ad :3 0 ae
:3 0 2df8 2df9 0
ad :3 0 bd :3 0
2dfb 2dfc 0 ec
:2 0 2 :4 0 283
:2 0 bf :2 0 47
:2 0 1b8b 2e01 2e03
:3 0 1b8e 2dfd 2e05
2dfa 2e07 2e06 :2 0
b0 :3 0 c0 :3 0
2e09 2e0a 0 b2
:4 0 284 :4 0 b5
:2 0 b6 :3 0 1b92
2e0e 2e10 :3 0 b5
:2 0 c9 :4 0 1b95
2e12 2e14 :3 0 b5
:2 0 ef :4 0 1b98
2e16 2e18 :3 0 b5
:2 0 e9 :3 0 1b9b
2e1a 2e1c :3 0 b5
:2 0 f0 :4 0 1b9e
2e1e 2e20 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 47 :2 0 f3
:2 0 1ba1 2e23 2e27
1ba5 2e22 2e29 :3 0
1ba8 2e0b 2e2b :2 0
2e2d 1bab 2e2e 2e08
2e2d 0 2e2f 1bad
0 2e30 1baf 2e33
:3 0 2e33 0 2e33
2e32 2e30 2e31 :6 0
2e35 55 :3 0 1bb2
2e37 1bb4 2e36 2e35
:2 0 2e38 1bb6 :2 0
2e3a 0 2e3a 2e39
2de7 2e38 :6 0 2ebe
1 :3 0 85 :3 0
c3 :2 0 4e :2 0
1bbb 2e3d 2e3f :3 0
a7 :3 0 a0 :3 0
37 :3 0 a2 :3 0
2e :3 0 a3 :3 0
38 :3 0 a4 :3 0
30 :3 0 a5 :3 0
31 :3 0 a6 :3 0
32 :3 0 9d :3 0
3a :4 0 285 1
:8 0 2e66 1bf :4 0
2e51 :3 0 d0 :3 0
d2 :2 0 1bc0 2e54
2e55 :3 0 21 :3 0
e8 :3 0 2e57 2e58
0 4e :2 0 2e59
2e5a 0 2e5c 1bc3
2e63 21 :3 0 e8
:3 0 2e5d 2e5e 0
18a :2 0 2e5f 2e60
0 2e62 1bc5 2e64
2e56 2e5c 0 2e65
0 2e62 0 2e65
1bc7 0 2e66 1bca
2eb9 ea :3 0 21
:3 0 e8 :3 0 2e68
2e69 0 e9 :3 0
2e6a 2e6b 0 2e6d
1bcd 2e6f 1bcf 2e6e
2e6d :2 0 2eb7 eb
:3 0 21 :3 0 e8
:3 0 2e72 2e73 0
e9 :3 0 2e74 2e75
0 2eaf ad :3 0
ae :3 0 2e77 2e78
0 ad :3 0 bd
:3 0 2e7a 2e7b 0
ec :2 0 2 :4 0
286 :2 0 bf :2 0
47 :2 0 1bd1 2e80
2e82 :3 0 1bd4 2e7c
2e84 2e79 2e86 2e85
:2 0 b0 :3 0 c0
:3 0 2e88 2e89 0
b2 :4 0 287 :4 0
b5 :2 0 b6 :3 0
1bd8 2e8d 2e8f :3 0
b5 :2 0 c9 :4 0
1bdb 2e91 2e93 :3 0
b5 :2 0 ef :4 0
1bde 2e95 2e97 :3 0
b5 :2 0 e9 :3 0
1be1 2e99 2e9b :3 0
b5 :2 0 f0 :4 0
1be4 2e9d 2e9f :3 0
b5 :2 0 f1 :3 0
f2 :3 0 47 :2 0
f3 :2 0 1be7 2ea2
2ea6 1beb 2ea1 2ea8
:3 0 1bee 2e8a 2eaa
:2 0 2eac 1bf1 2ead
2e87 2eac 0 2eae
1bf3 0 2eaf 1bf5
2eb2 :3 0 2eb2 0
2eb2 2eb1 2eaf 2eb0
:6 0 2eb4 57 :3 0
1bf8 2eb6 1bfa 2eb5
2eb4 :2 0 2eb7 1bfc
:2 0 2eb9 0 2eb9
2eb8 2e66 2eb7 :6 0
2ebb 1 :3 0 1bff
2ebc 2e40 2ebb 0
2ebd 1c01 0 2ebe
1c03 2ebf 2b78 2ebe
0 2ec0 1c0c 0
368b 6 :3 0 e3
:2 0 1c0e 2ec2 2ec3
:3 0 2ec4 :2 0 a1
:3 0 57 :3 0 4e
:2 0 1c10 2ec6 2ec9
d2 :2 0 4e :2 0
1c15 2ecb 2ecd :3 0
a1 :3 0 288 :3 0
289 :3 0 59 :3 0
28a :3 0 110 :3 0
25 :3 0 28b :3 0
175 :3 0 f1 :3 0
41 :3 0 175 :3 0
f1 :3 0 42 :4 0
28c 1 :8 0 2ee3
21 :3 0 e8 :3 0
2ede 2edf 0 e9
:3 0 2ee0 2ee1 0
2ee3 1c18 2f36 ea
:3 0 21 :3 0 e8
:3 0 2ee5 2ee6 0
e9 :3 0 2ee7 2ee8
0 2eea 1c1b 2eec
1c1d 2eeb 2eea :2 0
2f34 eb :3 0 21
:3 0 e8 :3 0 2eef
2ef0 0 e9 :3 0
2ef1 2ef2 0 2f2c
ad :3 0 ae :3 0
2ef4 2ef5 0 ad
:3 0 bd :3 0 2ef7
2ef8 0 ec :2 0
2 :4 0 28d :2 0
bf :2 0 47 :2 0
1c1f 2efd 2eff :3 0
1c22 2ef9 2f01 2ef6
2f03 2f02 :2 0 b0
:3 0 c0 :3 0 2f05
2f06 0 b2 :4 0
28e :4 0 b5 :2 0
b6 :3 0 1c26 2f0a
2f0c :3 0 b5 :2 0
c9 :4 0 1c29 2f0e
2f10 :3 0 b5 :2 0
ef :4 0 1c2c 2f12
2f14 :3 0 b5 :2 0
e9 :3 0 1c2f 2f16
2f18 :3 0 b5 :2 0
f0 :4 0 1c32 2f1a
2f1c :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
1c35 2f1f 2f23 1c39
2f1e 2f25 :3 0 1c3c
2f07 2f27 :2 0 2f29
1c3f 2f2a 2f04 2f29
0 2f2b 1c41 0
2f2c 1c43 2f2f :3 0
2f2f 0 2f2f 2f2e
2f2c 2f2d :6 0 2f31
59 :3 0 1c46 2f33
1c48 2f32 2f31 :2 0
2f34 1c4a :2 0 2f36
0 2f36 2f35 2ee3
2f34 :6 0 2f38 1
:3 0 1c4d 2f3e 61
:3 0 4e :2 0 2f39
2f3a 0 2f3d 0
2f3d 1c4f 2f3f 2ece
2f38 0 2f40 0
2f3d 0 2f40 1c52
0 2f41 1c55 2f42
2ec5 2f41 0 2f43
1c57 0 368b 28f
:3 0 e4 :3 0 290
:3 0 291 :3 0 1ad
:3 0 6c :3 0 69
:3 0 10f :3 0 292
:3 0 1e9 :3 0 293
:3 0 291 :3 0 292
:3 0 28f :3 0 291
:3 0 110 :3 0 292
:3 0 110 :3 0 25
:4 0 294 1 :8 0
2f5d 21 :3 0 e8
:3 0 2f58 2f59 0
e9 :3 0 2f5a 2f5b
0 2f5d 1c59 2fb0
ea :3 0 21 :3 0
e8 :3 0 2f5f 2f60
0 e9 :3 0 2f61
2f62 0 2f64 1c5c
2f66 1c5e 2f65 2f64
:2 0 2fae eb :3 0
21 :3 0 e8 :3 0
2f69 2f6a 0 e9
:3 0 2f6b 2f6c 0
2fa6 ad :3 0 ae
:3 0 2f6e 2f6f 0
ad :3 0 bd :3 0
2f71 2f72 0 ec
:2 0 2 :4 0 295
:2 0 bf :2 0 47
:2 0 1c60 2f77 2f79
:3 0 1c63 2f73 2f7b
2f70 2f7d 2f7c :2 0
b0 :3 0 c0 :3 0
2f7f 2f80 0 b2
:4 0 296 :4 0 b5
:2 0 b6 :3 0 1c67
2f84 2f86 :3 0 b5
:2 0 c9 :4 0 1c6a
2f88 2f8a :3 0 b5
:2 0 ef :4 0 1c6d
2f8c 2f8e :3 0 b5
:2 0 e9 :3 0 1c70
2f90 2f92 :3 0 b5
:2 0 f0 :4 0 1c73
2f94 2f96 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 47 :2 0 f3
:2 0 1c76 2f99 2f9d
1c7a 2f98 2f9f :3 0
1c7d 2f81 2fa1 :2 0
2fa3 1c80 2fa4 2f7e
2fa3 0 2fa5 1c82
0 2fa6 1c84 2fa9
:3 0 2fa9 0 2fa9
2fa8 2fa6 2fa7 :6 0
2fab 5b :3 0 1c87
2fad 1c89 2fac 2fab
:2 0 2fae 1c8b :2 0
2fb0 0 2fb0 2faf
2f5d 2fae :6 0 368b
1 :3 0 a1 :3 0
5c :3 0 4e :2 0
1c8e 2fb2 2fb5 c2
:3 0 d2 :2 0 d3
:3 0 2fb7 2fb9 0
1c93 2fb8 2fbb :3 0
1e1 :3 0 1e2 :3 0
297 :4 0 2fbf :4 0
2fc0 :2 0 323b 21
:3 0 e8 :3 0 2fc2
2fc3 0 4e :2 0
2fc4 2fc5 0 323b
298 :3 0 9e :3 0
299 :3 0 29a :3 0
29b :3 0 29c :3 0
a7 :3 0 9d :3 0
27 :3 0 299 :3 0
29a :4 0 29d 1
:8 0 2fe8 1bf :4 0
2fd3 :3 0 d0 :3 0
d2 :2 0 1c98 2fd6
2fd7 :3 0 21 :3 0
e8 :3 0 2fd9 2fda
0 4e :2 0 2fdb
2fdc 0 2fde 1c9b
2fe5 21 :3 0 e8
:3 0 2fdf 2fe0 0
18a :2 0 2fe1 2fe2
0 2fe4 1c9d 2fe6
2fd8 2fde 0 2fe7
0 2fe4 0 2fe7
1c9f 0 2fe8 1ca2
303b ea :3 0 21
:3 0 e8 :3 0 2fea
2feb 0 e9 :3 0
2fec 2fed 0 2fef
1ca5 2ff1 1ca7 2ff0
2fef :2 0 3039 eb
:3 0 21 :3 0 e8
:3 0 2ff4 2ff5 0
e9 :3 0 2ff6 2ff7
0 3031 ad :3 0
ae :3 0 2ff9 2ffa
0 ad :3 0 bd
:3 0 2ffc 2ffd 0
ec :2 0 2 :4 0
29e :2 0 bf :2 0
47 :2 0 1ca9 3002
3004 :3 0 1cac 2ffe
3006 2ffb 3008 3007
:2 0 b0 :3 0 c0
:3 0 300a 300b 0
b2 :4 0 29f :4 0
b5 :2 0 b6 :3 0
1cb0 300f 3011 :3 0
b5 :2 0 c9 :4 0
1cb3 3013 3015 :3 0
b5 :2 0 ef :4 0
1cb6 3017 3019 :3 0
b5 :2 0 e9 :3 0
1cb9 301b 301d :3 0
b5 :2 0 f0 :4 0
1cbc 301f 3021 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 47 :2 0
f3 :2 0 1cbf 3024
3028 1cc3 3023 302a
:3 0 1cc6 300c 302c
:2 0 302e 1cc9 302f
3009 302e 0 3030
1ccb 0 3031 1ccd
3034 :3 0 3034 0
3034 3033 3031 3032
:6 0 3036 5d :3 0
1cd0 3038 1cd2 3037
3036 :2 0 3039 1cd4
:2 0 303b 0 303b
303a 2fe8 3039 :6 0
323b 1 :3 0 21
:3 0 e8 :3 0 303d
303e 0 21 :3 0
d2 :2 0 16a :3 0
3040 3042 0 1cd9
3041 3044 :3 0 3045
:2 0 298 :3 0 9e
:3 0 1a6 :3 0 299
:3 0 299 :3 0 1a6
:3 0 29a :3 0 29a
:3 0 1a6 :3 0 29b
:3 0 29b :3 0 1a6
:3 0 29c :3 0 29c
:3 0 a7 :3 0 9d
:3 0 27 :3 0 9e
:4 0 2a0 1 :8 0
306f 1bf :4 0 305a
:3 0 d0 :3 0 d2
:2 0 1cde 305d 305e
:3 0 21 :3 0 e8
:3 0 3060 3061 0
4e :2 0 3062 3063
0 3065 1ce1 306c
21 :3 0 e8 :3 0
3066 3067 0 18a
:2 0 3068 3069 0
306b 1ce3 306d 305f
3065 0 306e 0
306b 0 306e 1ce5
0 306f 1ce8 30c2
ea :3 0 21 :3 0
e8 :3 0 3071 3072
0 e9 :3 0 3073
3074 0 3076 1ceb
3078 1ced 3077 3076
:2 0 30c0 eb :3 0
21 :3 0 e8 :3 0
307b 307c 0 e9
:3 0 307d 307e 0
30b8 ad :3 0 ae
:3 0 3080 3081 0
ad :3 0 bd :3 0
3083 3084 0 ec
:2 0 2 :4 0 2a1
:2 0 bf :2 0 47
:2 0 1cef 3089 308b
:3 0 1cf2 3085 308d
3082 308f 308e :2 0
b0 :3 0 c0 :3 0
3091 3092 0 b2
:4 0 2a2 :4 0 b5
:2 0 b6 :3 0 1cf6
3096 3098 :3 0 b5
:2 0 c9 :4 0 1cf9
309a 309c :3 0 b5
:2 0 ef :4 0 1cfc
309e 30a0 :3 0 b5
:2 0 e9 :3 0 1cff
30a2 30a4 :3 0 b5
:2 0 f0 :4 0 1d02
30a6 30a8 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 47 :2 0 f3
:2 0 1d05 30ab 30af
1d09 30aa 30b1 :3 0
1d0c 3093 30b3 :2 0
30b5 1d0f 30b6 3090
30b5 0 30b7 1d11
0 30b8 1d13 30bb
:3 0 30bb 0 30bb
30ba 30b8 30b9 :6 0
30bd 5f :3 0 1d16
30bf 1d18 30be 30bd
:2 0 30c0 1d1a :2 0
30c2 0 30c2 30c1
306f 30c0 :6 0 3142
1 :3 0 21 :3 0
e8 :3 0 30c4 30c5
0 21 :3 0 d2
:2 0 16a :3 0 30c7
30c9 0 1d1f 30c8
30cb :3 0 30cc :2 0
298 :3 0 9e :3 0
a7 :3 0 9d :3 0
27 :3 0 9e :4 0
2a3 1 :8 0 30ea
1bf :4 0 30d5 :3 0
d0 :3 0 d2 :2 0
1d24 30d8 30d9 :3 0
21 :3 0 e8 :3 0
30db 30dc 0 4e
:2 0 30dd 30de 0
30e0 1d27 30e7 21
:3 0 e8 :3 0 30e1
30e2 0 18a :2 0
30e3 30e4 0 30e6
1d29 30e8 30da 30e0
0 30e9 0 30e6
0 30e9 1d2b 0
30ea 1d2e 313d ea
:3 0 21 :3 0 e8
:3 0 30ec 30ed 0
e9 :3 0 30ee 30ef
0 30f1 1d31 30f3
1d33 30f2 30f1 :2 0
313b eb :3 0 21
:3 0 e8 :3 0 30f6
30f7 0 e9 :3 0
30f8 30f9 0 3133
ad :3 0 ae :3 0
30fb 30fc 0 ad
:3 0 bd :3 0 30fe
30ff 0 ec :2 0
2 :4 0 2a4 :2 0
bf :2 0 47 :2 0
1d35 3104 3106 :3 0
1d38 3100 3108 30fd
310a 3109 :2 0 b0
:3 0 c0 :3 0 310c
310d 0 b2 :4 0
2a5 :4 0 b5 :2 0
b6 :3 0 1d3c 3111
3113 :3 0 b5 :2 0
c9 :4 0 1d3f 3115
3117 :3 0 b5 :2 0
ef :4 0 1d42 3119
311b :3 0 b5 :2 0
e9 :3 0 1d45 311d
311f :3 0 b5 :2 0
f0 :4 0 1d48 3121
3123 :3 0 b5 :2 0
f1 :3 0 f2 :3 0
47 :2 0 f3 :2 0
1d4b 3126 312a 1d4f
3125 312c :3 0 1d52
310e 312e :2 0 3130
1d55 3131 310b 3130
0 3132 1d57 0
3133 1d59 3136 :3 0
3136 0 3136 3135
3133 3134 :6 0 3138
61 :3 0 1d5c 313a
1d5e 3139 3138 :2 0
313b 1d60 :2 0 313d
0 313d 313c 30ea
313b :6 0 313f 1
:3 0 1d63 3140 30cd
313f 0 3141 1d65
0 3142 1d67 3143
3046 3142 0 3144
1d6a 0 323b 255
:3 0 a9 :3 0 39
:3 0 110 :3 0 149
:3 0 1e8 :3 0 1ba
:3 0 1ad :3 0 2a6
:3 0 a2 :3 0 2a6
:3 0 a4 :3 0 2a6
:3 0 a5 :3 0 2a6
:3 0 a6 :3 0 54
:3 0 2a7 :3 0 2a8
:3 0 1ad :3 0 2a9
:3 0 2aa :3 0 1ad
:3 0 2ab :3 0 2ac
:3 0 2ad :3 0 299
:3 0 2ad :3 0 299
:3 0 2a6 :3 0 2ae
:3 0 2af :3 0 299
:3 0 69 :3 0 13d
:3 0 299 :3 0 69
:3 0 299 :3 0 2ac
:3 0 2ad :3 0 2b0
:3 0 2ad :3 0 2b0
:3 0 2a6 :3 0 2ae
:3 0 2af :3 0 29a
:3 0 69 :3 0 13d
:3 0 29a :3 0 69
:3 0 29a :3 0 2ac
:3 0 2ad :3 0 29b
:3 0 2ad :3 0 29b
:3 0 2a6 :3 0 2ae
:3 0 2af :3 0 29b
:3 0 69 :3 0 13d
:3 0 29b :3 0 69
:3 0 29b :3 0 2ac
:3 0 2ad :3 0 2b1
:3 0 2ad :3 0 2b1
:3 0 2a6 :3 0 2ae
:3 0 2af :3 0 29c
:3 0 69 :3 0 13d
:3 0 29c :3 0 69
:3 0 29c :3 0 2a6
:3 0 2b2 :3 0 2a6
:3 0 2b3 :3 0 2a6
:3 0 2b4 :3 0 2a6
:3 0 2b5 :3 0 2a6
:3 0 2b6 :3 0 2a6
:3 0 2b7 :3 0 2a6
:3 0 2b7 :3 0 59
:3 0 2b8 :3 0 5a
:3 0 2b9 :3 0 2a6
:3 0 2b4 :3 0 2a6
:3 0 2b5 :3 0 2a6
:3 0 2b6 :3 0 2ba
:3 0 2bb :3 0 2bc
:3 0 2bd :3 0 2be
:3 0 1ad :3 0 2bf
:3 0 2c0 :3 0 2c1
:3 0 5f :3 0 133
:3 0 2a6 :3 0 2c2
:3 0 2c3 :3 0 2e
:3 0 a0 :3 0 30
:3 0 a3 :3 0 2c4
:3 0 2c5 :3 0 154
:3 0 2c6 :3 0 2c7
:3 0 2c8 :3 0 161
:3 0 2c9 :3 0 2ca
:3 0 298 :3 0 2af
:3 0 1e9 :3 0 a7
:3 0 2a6 :3 0 2a6
:3 0 9e :3 0 2af
:3 0 9e :3 0 2cb
:3 0 2cc :3 0 1e9
:3 0 2cd :3 0 2ad
:3 0 2ad :3 0 98
:3 0 25 :3 0 2ad
:3 0 9a :3 0 2a6
:3 0 9e :3 0 1e9
:3 0 199 :3 0 1e8
:3 0 1e8 :3 0 19a
:3 0 39 :3 0 1e9
:3 0 1af :3 0 2ce
:3 0 1e8 :3 0 a0
:3 0 2ce :3 0 110
:3 0 2cb :3 0 2cc
:3 0 1e9 :3 0 2cf
:3 0 13d :3 0 2ce
:3 0 2d0 :3 0 13d
:3 0 2d0 :3 0 2cb
:3 0 2cc :3 0 1e9
:3 0 226 :3 0 2a8
:3 0 1e8 :3 0 1bd
:3 0 2a8 :3 0 110
:3 0 2cb :3 0 2cc
:3 0 1e9 :3 0 231
:3 0 2aa :3 0 1e8
:3 0 1bc :3 0 2aa
:3 0 110 :3 0 2cb
:3 0 2cc :3 0 1e9
:3 0 182 :3 0 2be
:3 0 2be :3 0 110
:3 0 1e8 :3 0 1bb
:3 0 2a6 :3 0 a2
:3 0 2a6 :3 0 a4
:3 0 2a6 :3 0 a5
:3 0 2a6 :3 0 a6
:4 0 2d1 1 :a 0
3218 :2 0 323b 3146
3216 :2 0 ad :3 0
ae :3 0 3219 321a
0 ad :3 0 bd
:3 0 321c 321d 0
47 :2 0 2 :4 0
2d2 :2 0 bf :2 0
47 :2 0 1d6c 3222
3224 :3 0 1d6f 321e
3226 321b 3228 3227
:2 0 b0 :3 0 c0
:3 0 322a 322b 0
b2 :4 0 2d3 :4 0
b5 :2 0 b6 :3 0
1d73 322f 3231 :3 0
1d76 322c 3233 :2 0
3235 1d79 3236 3229
3235 0 3237 1d7b
0 323b 20 :3 0
a9 :3 0 3239 :2 0
323b 1d7d 3688 8b
:3 0 d2 :2 0 47
:2 0 1d87 323d 323f
:3 0 255 :3 0 aa
:3 0 2a6 :3 0 9e
:3 0 110 :3 0 149
:3 0 2ce :3 0 2bd
:3 0 1ad :3 0 2a6
:3 0 a2 :3 0 2a6
:3 0 a4 :3 0 2a6
:3 0 a5 :3 0 2a6
:3 0 a6 :3 0 2ce
:3 0 2a7 :3 0 2d4
:3 0 1ad :3 0 2a9
:3 0 2d5 :3 0 1ad
:3 0 2ab :3 0 2ac
:3 0 2a6 :3 0 2d6
:3 0 2a6 :3 0 299
:3 0 2ce :3 0 28f
:3 0 6c :3 0 2ce
:3 0 28f :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 2ce
:3 0 28f :3 0 2a6
:3 0 2d6 :3 0 2a6
:3 0 299 :3 0 2a6
:3 0 299 :3 0 69
:3 0 299 :3 0 2ac
:3 0 2a6 :3 0 2d6
:3 0 2a6 :3 0 29a
:3 0 2ce :3 0 28f
:3 0 6c :3 0 2ce
:3 0 28f :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 2ce
:3 0 28f :3 0 2a6
:3 0 2d6 :3 0 2a6
:3 0 29a :3 0 2a6
:3 0 29a :3 0 69
:3 0 29a :3 0 2ac
:3 0 2a6 :3 0 2d6
:3 0 2a6 :3 0 29b
:3 0 2ce :3 0 28f
:3 0 6c :3 0 2ce
:3 0 28f :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 2ce
:3 0 28f :3 0 2a6
:3 0 2d6 :3 0 2a6
:3 0 29b :3 0 2a6
:3 0 29b :3 0 69
:3 0 29b :3 0 2ac
:3 0 2a6 :3 0 2d6
:3 0 2a6 :3 0 29c
:3 0 2ce :3 0 28f
:3 0 6c :3 0 2ce
:3 0 28f :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 2ce
:3 0 28f :3 0 2a6
:3 0 2d6 :3 0 2a6
:3 0 29c :3 0 2a6
:3 0 29c :3 0 69
:3 0 29c :3 0 2a6
:3 0 2b2 :3 0 2a6
:3 0 2b3 :3 0 2a6
:3 0 2b4 :3 0 2a6
:3 0 2b5 :3 0 2a6
:3 0 2b6 :3 0 2a6
:3 0 2b7 :3 0 2a6
:3 0 2b7 :3 0 59
:3 0 2b8 :3 0 5a
:3 0 2b9 :3 0 2a6
:3 0 2b4 :3 0 2a6
:3 0 2b5 :3 0 2a6
:3 0 2b6 :3 0 2ba
:3 0 2d7 :3 0 2bd
:3 0 2bb :3 0 2ce
:3 0 2bc :3 0 2be
:3 0 1ad :3 0 2bf
:3 0 2d8 :3 0 2bd
:3 0 2d8 :3 0 2c0
:3 0 2c1 :3 0 5f
:3 0 133 :3 0 2a6
:3 0 2c2 :3 0 2c3
:3 0 2a6 :3 0 a0
:3 0 2a6 :3 0 a3
:3 0 a1 :3 0 2ad
:3 0 2d9 :3 0 2ad
:3 0 2da :3 0 2c4
:3 0 2ce :3 0 2c5
:3 0 2ce :3 0 2db
:3 0 2c6 :3 0 2ce
:3 0 2c7 :3 0 2ce
:3 0 2c8 :3 0 2ce
:3 0 161 :3 0 2ce
:3 0 2c0 :3 0 2c9
:3 0 2ce :3 0 2ca
:3 0 a7 :3 0 2a6
:3 0 1e9 :3 0 182
:3 0 1e8 :3 0 2a6
:3 0 9e :3 0 1e8
:3 0 110 :3 0 1e9
:3 0 182 :3 0 2be
:3 0 2be :3 0 110
:3 0 1e8 :3 0 1b0
:3 0 2cb :3 0 2cc
:3 0 1e9 :3 0 166
:3 0 2d8 :3 0 2be
:3 0 2dc :3 0 2d8
:3 0 9a :3 0 1e9
:3 0 166 :3 0 2ce
:3 0 2a6 :3 0 9e
:3 0 2ce :3 0 9a
:3 0 2cb :3 0 2cc
:3 0 1e9 :3 0 166
:3 0 2d7 :3 0 2d7
:3 0 9a :3 0 2ce
:3 0 2dd :3 0 2cb
:3 0 2cc :3 0 1e9
:3 0 2cd :3 0 2ad
:3 0 2ad :3 0 98
:3 0 25 :3 0 2ad
:3 0 9a :3 0 2a6
:3 0 9e :3 0 2cb
:3 0 2cc :3 0 1e9
:3 0 226 :3 0 2a8
:3 0 2ce :3 0 9a
:3 0 2a8 :3 0 110
:3 0 2cb :3 0 2cc
:3 0 1e9 :3 0 226
:3 0 2d4 :3 0 2a8
:3 0 1b0 :3 0 2d4
:3 0 110 :3 0 2cb
:3 0 2cc :3 0 1e9
:3 0 231 :3 0 2aa
:3 0 2ce :3 0 9a
:3 0 2aa :3 0 110
:3 0 2cb :3 0 2cc
:3 0 1e9 :3 0 231
:3 0 2d5 :3 0 2aa
:3 0 1b0 :3 0 2d5
:3 0 110 :3 0 110
:4 0 2de 1 :a 0
337b :2 0 339e 3242
3379 :2 0 ad :3 0
ae :3 0 337c 337d
0 ad :3 0 bd
:3 0 337f 3380 0
47 :2 0 2 :4 0
2df :2 0 bf :2 0
47 :2 0 1d8a 3385
3387 :3 0 1d8d 3381
3389 337e 338b 338a
:2 0 b0 :3 0 c0
:3 0 338d 338e 0
b2 :4 0 2e0 :4 0
b5 :2 0 b6 :3 0
1d91 3392 3394 :3 0
1d94 338f 3396 :2 0
3398 1d97 3399 338c
3398 0 339a 1d99
0 339e 20 :3 0
aa :3 0 339c :2 0
339e 1d9b 3684 1e1
:3 0 1e2 :3 0 2e1
:4 0 33a1 :4 0 33a2
:2 0 3683 21 :3 0
e8 :3 0 33a4 33a5
0 4e :2 0 33a6
33a7 0 3683 2e2
:3 0 9e :3 0 299
:3 0 29a :3 0 29b
:3 0 29c :3 0 a7
:3 0 2d6 :4 0 2e3
1 :8 0 33c7 1bf
:4 0 33b2 :3 0 d0
:3 0 d2 :2 0 1da1
33b5 33b6 :3 0 21
:3 0 e8 :3 0 33b8
33b9 0 4e :2 0
33ba 33bb 0 33bd
1da4 33c4 21 :3 0
e8 :3 0 33be 33bf
0 18a :2 0 33c0
33c1 0 33c3 1da6
33c5 33b7 33bd 0
33c6 0 33c3 0
33c6 1da8 0 33c7
1dab 341a ea :3 0
21 :3 0 e8 :3 0
33c9 33ca 0 e9
:3 0 33cb 33cc 0
33ce 1dae 33d0 1db0
33cf 33ce :2 0 3418
eb :3 0 21 :3 0
e8 :3 0 33d3 33d4
0 e9 :3 0 33d5
33d6 0 3410 ad
:3 0 ae :3 0 33d8
33d9 0 ad :3 0
bd :3 0 33db 33dc
0 ec :2 0 2
:4 0 2e4 :2 0 bf
:2 0 47 :2 0 1db2
33e1 33e3 :3 0 1db5
33dd 33e5 33da 33e7
33e6 :2 0 b0 :3 0
c0 :3 0 33e9 33ea
0 b2 :4 0 2e5
:4 0 b5 :2 0 b6
:3 0 1db9 33ee 33f0
:3 0 b5 :2 0 c9
:4 0 1dbc 33f2 33f4
:3 0 b5 :2 0 ef
:4 0 1dbf 33f6 33f8
:3 0 b5 :2 0 e9
:3 0 1dc2 33fa 33fc
:3 0 b5 :2 0 f0
:4 0 1dc5 33fe 3400
:3 0 b5 :2 0 f1
:3 0 f2 :3 0 47
:2 0 f3 :2 0 1dc8
3403 3407 1dcc 3402
3409 :3 0 1dcf 33eb
340b :2 0 340d 1dd2
340e 33e8 340d 0
340f 1dd4 0 3410
1dd6 3413 :3 0 3413
0 3413 3412 3410
3411 :6 0 3415 63
:3 0 1dd9 3417 1ddb
3416 3415 :2 0 3418
1ddd :2 0 341a 0
341a 3419 33c7 3418
:6 0 3683 1 :3 0
2e2 :3 0 9e :3 0
1a6 :3 0 299 :3 0
299 :3 0 1a6 :3 0
29a :3 0 29a :3 0
1a6 :3 0 29b :3 0
29b :3 0 1a6 :3 0
29c :3 0 29c :3 0
a7 :3 0 9e :3 0
9e :3 0 a7 :3 0
2d6 :3 0 9e :3 0
9e :4 0 2e6 1
:8 0 3447 1bf :4 0
3432 :3 0 d0 :3 0
d2 :2 0 1de2 3435
3436 :3 0 21 :3 0
e8 :3 0 3438 3439
0 4e :2 0 343a
343b 0 343d 1de5
3444 21 :3 0 e8
:3 0 343e 343f 0
18a :2 0 3440 3441
0 3443 1de7 3445
3437 343d 0 3446
0 3443 0 3446
1de9 0 3447 1dec
349a ea :3 0 21
:3 0 e8 :3 0 3449
344a 0 e9 :3 0
344b 344c 0 344e
1def 3450 1df1 344f
344e :2 0 3498 eb
:3 0 21 :3 0 e8
:3 0 3453 3454 0
e9 :3 0 3455 3456
0 3490 ad :3 0
ae :3 0 3458 3459
0 ad :3 0 bd
:3 0 345b 345c 0
ec :2 0 2 :4 0
2e7 :2 0 bf :2 0
47 :2 0 1df3 3461
3463 :3 0 1df6 345d
3465 345a 3467 3466
:2 0 b0 :3 0 c0
:3 0 3469 346a 0
b2 :4 0 2e8 :4 0
b5 :2 0 b6 :3 0
1dfa 346e 3470 :3 0
b5 :2 0 c9 :4 0
1dfd 3472 3474 :3 0
b5 :2 0 ef :4 0
1e00 3476 3478 :3 0
b5 :2 0 e9 :3 0
1e03 347a 347c :3 0
b5 :2 0 f0 :4 0
1e06 347e 3480 :3 0
b5 :2 0 f1 :3 0
f2 :3 0 47 :2 0
f3 :2 0 1e09 3483
3487 1e0d 3482 3489
:3 0 1e10 346b 348b
:2 0 348d 1e13 348e
3468 348d 0 348f
1e15 0 3490 1e17
3493 :3 0 3493 0
3493 3492 3490 3491
:6 0 3495 65 :3 0
1e1a 3497 1e1c 3496
3495 :2 0 3498 1e1e
:2 0 349a 0 349a
3499 3447 3498 :6 0
3683 1 :3 0 255
:3 0 ab :3 0 2a6
:3 0 9e :3 0 110
:3 0 149 :3 0 2ce
:3 0 2bd :3 0 1ad
:3 0 2a6 :3 0 a2
:3 0 2a6 :3 0 a4
:3 0 2a6 :3 0 a5
:3 0 2a6 :3 0 a6
:3 0 2ce :3 0 2a7
:3 0 2d4 :3 0 1ad
:3 0 2a9 :3 0 2d5
:3 0 1ad :3 0 2ab
:3 0 2ac :3 0 2ad
:3 0 299 :3 0 2ad
:3 0 299 :3 0 13d
:3 0 299 :3 0 13d
:3 0 299 :3 0 2ce
:3 0 28f :3 0 6c
:3 0 2ce :3 0 28f
:3 0 6c :3 0 e4
:3 0 290 :3 0 1ad
:3 0 293 :3 0 110
:3 0 6c :3 0 e4
:3 0 290 :3 0 1ad
:3 0 293 :3 0 110
:3 0 2ce :3 0 28f
:3 0 2e9 :3 0 299
:3 0 2e9 :3 0 299
:3 0 2ce :3 0 28f
:3 0 6c :3 0 2ce
:3 0 28f :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 2ce
:3 0 28f :3 0 2ea
:3 0 299 :3 0 69
:3 0 299 :3 0 2ac
:3 0 2ad :3 0 299
:3 0 2ad :3 0 2b0
:3 0 13d :3 0 299
:3 0 13d :3 0 29a
:3 0 2ce :3 0 28f
:3 0 6c :3 0 2ce
:3 0 28f :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 2ce
:3 0 28f :3 0 2e9
:3 0 299 :3 0 2e9
:3 0 29a :3 0 2ce
:3 0 28f :3 0 6c
:3 0 2ce :3 0 28f
:3 0 6c :3 0 e4
:3 0 290 :3 0 1ad
:3 0 293 :3 0 110
:3 0 6c :3 0 e4
:3 0 290 :3 0 1ad
:3 0 293 :3 0 110
:3 0 2ce :3 0 28f
:3 0 2ea :3 0 29a
:3 0 69 :3 0 29a
:3 0 2ac :3 0 2ad
:3 0 299 :3 0 2ad
:3 0 29b :3 0 13d
:3 0 299 :3 0 13d
:3 0 29b :3 0 2ce
:3 0 28f :3 0 6c
:3 0 2ce :3 0 28f
:3 0 6c :3 0 e4
:3 0 290 :3 0 1ad
:3 0 293 :3 0 110
:3 0 6c :3 0 e4
:3 0 290 :3 0 1ad
:3 0 293 :3 0 110
:3 0 2ce :3 0 28f
:3 0 2e9 :3 0 299
:3 0 2e9 :3 0 29b
:3 0 2ce :3 0 28f
:3 0 6c :3 0 2ce
:3 0 28f :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 2ce
:3 0 28f :3 0 2ea
:3 0 29b :3 0 69
:3 0 29b :3 0 2ac
:3 0 2ad :3 0 2b0
:3 0 2ad :3 0 2b1
:3 0 13d :3 0 29a
:3 0 13d :3 0 29c
:3 0 2ce :3 0 28f
:3 0 6c :3 0 2ce
:3 0 28f :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 6c
:3 0 e4 :3 0 290
:3 0 1ad :3 0 293
:3 0 110 :3 0 2ce
:3 0 28f :3 0 2e9
:3 0 299 :3 0 2e9
:3 0 29c :3 0 2ce
:3 0 28f :3 0 6c
:3 0 2ce :3 0 28f
:3 0 6c :3 0 e4
:3 0 290 :3 0 1ad
:3 0 293 :3 0 110
:3 0 6c :3 0 e4
:3 0 290 :3 0 1ad
:3 0 293 :3 0 110
:3 0 2ce :3 0 28f
:3 0 2ea :3 0 29c
:3 0 69 :3 0 29c
:3 0 2a6 :3 0 2b2
:3 0 2a6 :3 0 2b3
:3 0 2a6 :3 0 2b4
:3 0 2a6 :3 0 2b5
:3 0 2a6 :3 0 2b6
:3 0 2a6 :3 0 2b7
:3 0 2a6 :3 0 2b7
:3 0 59 :3 0 2b8
:3 0 5a :3 0 2b9
:3 0 2a6 :3 0 2b4
:3 0 2a6 :3 0 2b5
:3 0 2a6 :3 0 2b6
:3 0 2ba :3 0 2d7
:3 0 2bd :3 0 2bb
:3 0 2ce :3 0 2bc
:3 0 2be :3 0 1ad
:3 0 2bf :3 0 2d8
:3 0 2bd :3 0 2d8
:3 0 2c0 :3 0 2c1
:3 0 5f :3 0 133
:3 0 2a6 :3 0 2c2
:3 0 2c3 :3 0 2a6
:3 0 a0 :3 0 2a6
:3 0 a3 :3 0 a1
:3 0 2ad :3 0 2d9
:3 0 2ad :3 0 2da
:3 0 2c4 :3 0 2ce
:3 0 2c5 :3 0 2ce
:3 0 2db :3 0 2c6
:3 0 2ce :3 0 2c7
:3 0 2ce :3 0 2c8
:3 0 2ce :3 0 161
:3 0 2ce :3 0 2c0
:3 0 2c9 :3 0 2ce
:3 0 2ca :3 0 a7
:3 0 2a6 :3 0 2cb
:3 0 1e9 :3 0 2e2
:3 0 2e9 :3 0 2a6
:3 0 9e :3 0 2e9
:3 0 9e :3 0 2e9
:3 0 2d6 :3 0 2cb
:3 0 1e9 :3 0 2e2
:3 0 2ea :3 0 2a6
:3 0 9e :3 0 2ea
:3 0 9e :3 0 2ea
:3 0 2d6 :3 0 1e9
:3 0 182 :3 0 1e8
:3 0 2a6 :3 0 9e
:3 0 1e8 :3 0 110
:3 0 1e9 :3 0 182
:3 0 2be :3 0 2be
:3 0 110 :3 0 1e8
:3 0 1b0 :3 0 2cb
:3 0 2cc :3 0 1e9
:3 0 166 :3 0 2d8
:3 0 2be :3 0 2dc
:3 0 2d8 :3 0 9a
:3 0 1e9 :3 0 166
:3 0 2ce :3 0 2a6
:3 0 9e :3 0 2ce
:3 0 9a :3 0 2cb
:3 0 2cc :3 0 1e9
:3 0 166 :3 0 2d7
:3 0 2d7 :3 0 9a
:3 0 2ce :3 0 2dd
:3 0 2cb :3 0 2cc
:3 0 1e9 :3 0 2cd
:3 0 2ad :3 0 2ad
:3 0 98 :3 0 25
:3 0 2ad :3 0 9a
:3 0 2a6 :3 0 9e
:3 0 2cb :3 0 2cc
:3 0 1e9 :3 0 166
:3 0 2eb :3 0 2ce
:3 0 2dd :3 0 2eb
:3 0 9a :3 0 2cb
:3 0 2cc :3 0 1e9
:3 0 226 :3 0 2a8
:3 0 2ce :3 0 9a
:3 0 2a8 :3 0 110
:3 0 2cb :3 0 2cc
:3 0 1e9 :3 0 226
:3 0 2d4 :3 0 2a8
:3 0 1b0 :3 0 2d4
:3 0 110 :3 0 2cb
:3 0 2cc :3 0 1e9
:3 0 231 :3 0 2aa
:3 0 2ce :3 0 9a
:3 0 2aa :3 0 110
:3 0 2cb :3 0 2cc
:3 0 1e9 :3 0 231
:3 0 2d5 :3 0 2aa
:3 0 1b0 :3 0 2d5
:3 0 110 :3 0 2cb
:3 0 2cc :3 0 1e9
:3 0 2cf :3 0 13d
:3 0 2ce :3 0 2d0
:3 0 13d :3 0 2d0
:3 0 2a6 :3 0 a2
:3 0 2a6 :3 0 a4
:3 0 2a6 :3 0 a5
:3 0 2a6 :3 0 a6
:3 0 110 :4 0 2ec
1 :a 0 3660 :2 0
3683 349d 365e :2 0
ad :3 0 ae :3 0
3661 3662 0 ad
:3 0 bd :3 0 3664
3665 0 47 :2 0
2 :4 0 2ed :2 0
bf :2 0 47 :2 0
1e21 366a 366c :3 0
1e24 3666 366e 3663
3670 366f :2 0 b0
:3 0 c0 :3 0 3672
3673 0 b2 :4 0
2ee :4 0 b5 :2 0
b6 :3 0 1e28 3677
3679 :3 0 1e2b 3674
367b :2 0 367d 1e2e
367e 3671 367d 0
367f 1e30 0 3683
20 :3 0 ab :3 0
3681 :2 0 3683 1e32
3685 3240 339e 0
3686 0 3683 0
3686 1e3a 0 3687
1e3d 3689 2fbc 323b
0 368a 0 3687
0 368a 1e3f 0
368b 1e42 372c 21
:3 0 2ef :2 0 4
368c 368d 0 ad
:3 0 ae :3 0 368f
3690 0 ad :3 0
bd :3 0 3692 3693
0 ec :2 0 2
:4 0 2f0 :2 0 bf
:2 0 47 :2 0 1e7e
3698 369a :3 0 1e81
3694 369c 3691 369e
369d :2 0 b0 :3 0
c0 :3 0 36a0 36a1
0 b2 :4 0 2f1
:4 0 b5 :2 0 b6
:3 0 1e85 36a5 36a7
:3 0 1e88 36a2 36a9
:2 0 36c2 b0 :3 0
c0 :3 0 36ab 36ac
0 b2 :4 0 2f2
:4 0 b5 :2 0 21
:3 0 2f3 :3 0 36b1
36b2 0 1e8b 36b0
36b4 :3 0 b5 :2 0
119 :4 0 1e8e 36b6
36b8 :3 0 b5 :2 0
21 :3 0 2f4 :3 0
36bb 36bc 0 1e91
36ba 36be :3 0 1e94
36ad 36c0 :2 0 36c2
1e97 36c3 369f 36c2
0 36c4 1e9a 0
36d4 255 :3 0 ac
:3 0 21 :3 0 2f3
:3 0 2f5 :3 0 21
:3 0 2f4 :3 0 2f6
:3 0 e6 :4 0 2f7
1 :a 0 36d0 :2 0
36d4 36c6 36ce :2 0
20 :3 0 ac :3 0
36d2 :2 0 36d4 1e9c
36d6 1ea0 36d5 36d4
:2 0 372a eb :3 0
21 :3 0 e8 :3 0
36d9 36da 0 e9
:3 0 36db 36dc 0
3722 ad :3 0 ae
:3 0 36de 36df 0
ad :3 0 bd :3 0
36e1 36e2 0 ec
:2 0 2 :4 0 2f8
:2 0 bf :2 0 47
:2 0 1ea2 36e7 36e9
:3 0 1ea5 36e3 36eb
36e0 36ed 36ec :2 0
b0 :3 0 c0 :3 0
36ef 36f0 0 b2
:4 0 2f9 :4 0 b5
:2 0 b6 :3 0 1ea9
36f4 36f6 :3 0 1eac
36f1 36f8 :2 0 3712
b0 :3 0 c0 :3 0
36fa 36fb 0 b2
:4 0 ef :4 0 b5
:2 0 e9 :3 0 1eaf
36ff 3701 :3 0 b5
:2 0 f0 :4 0 1eb2
3703 3705 :3 0 b5
:2 0 f1 :3 0 f2
:3 0 47 :2 0 f3
:2 0 1eb5 3708 370c
1eb9 3707 370e :3 0
1ebc 36fc 3710 :2 0
3712 1ebf 3713 36ee
3712 0 3714 1ec2
0 3722 255 :3 0
ac :3 0 2f5 :3 0
21 :3 0 2f4 :3 0
2f6 :3 0 e6 :4 0
2fa 1 :a 0 371e
:2 0 3722 3716 371c
:2 0 20 :3 0 ac
:3 0 3720 :2 0 3722
1ec4 3725 :3 0 3725
0 3725 3724 3722
3723 :6 0 3727 1
:3 0 1ec9 3729 1ecb
3728 3727 :2 0 372a
1ecd :2 0 372c 1ed0
372c 372b 368b 372a
:6 0 372d :2 0 2
74 372c 3730 :3 0
372f 372d 3731 :8 0

1f3b
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 1
47 1 4b 1
4f 1 53 1
57 1 5b 1
5f 1 63 1
67 1 6b 1b
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 4a 4e 52
56 5a 5e 62
66 6a 6e 1
78 1 76 1
7f 1 7d 1
86 1 84 1
8d 1 8b 1
94 1 92 1
9b 1 99 1
a2 1 a0 1
a9 1 a7 1
b0 1 ae 1
b7 1 b5 1
be 1 bc 1
c5 1 c3 1
cc 1 ca 1
d3 1 d1 1
da 1 d8 1
e1 1 df 1
e8 1 e6 1
ef 1 ed 1
f6 1 f4 1
fd 1 fb 1
104 1 102 1
109 1 110 1
10e 1 117 1
115 1 11e 1
11c 1 125 1
123 1 12c 1
12a 1 131 1
138 1 136 1
13f 1 13d 1
146 1 144 1
14d 1 14b 1
154 1 152 1
15b 1 159 1
160 1 166 1
16c 1 172 1
178 1 17e 1
184 1 18a 1
190 1 196 1
19c 1 1a2 1
1a8 1 1ae 1
1b4 1 1ba 1
1c0 1 1c6 1
1cc 1 1d2 1
1d8 1 1de 1
1e4 1 1ea 1
1f0 1 1f6 1
1fc 1 202 1
208 1 20e 1
214 1 21a 1
220 1 228 1
226 1 22d 1
233 1 239 1
241 1 23f 1
248 1 246 1
24f 1 24d 1
254 1 25a 1
262 1 260 1
269 1 267 1
270 1 26e 1
277 1 275 1
27e 1 27c 1
285 1 283 1
28a 1 290 1
296 1 29c 1
2a2 1 2a8 1
2ae 1 2b4 1
2bc 1 2ba 1
2c1 1 2c7 1
2cc 1 2d1 1
2d6 1 2db 1
2e0 1 2e5 1
2ea 1 2fe 1
319 1 31f 1
326 1 32d 1
334 1 341 1
34d 2 350 352
2 355 357 2
359 35b 2 35d
35f 2 361 363
2 365 367 2
369 36b 2 36d
36f 2 371 373
2 375 377 2
379 37b 2 37d
37f 2 381 383
1 389 2 38b
38c 2 385 38e
2 390 392 1
398 2 39a 39b
2 394 39d 2
39f 3a1 1 3a7
2 3a9 3aa 2
3a3 3ac 2 3ae
3b0 1 3b6 2
3b8 3b9 2 3b2
3bb 2 3bd 3bf
1 3c5 2 3c7
3c8 2 3c1 3ca
2 3cc 3ce 1
3d4 2 3d6 3d7
2 3d0 3d9 2
3db 3dd 1 3e3
2 3e5 3e6 2
3df 3e8 2 3ea
3ec 1 3f2 2
3f4 3f5 2 3ee
3f7 2 3f9 3fb
2 3fd 3ff 2
401 403 2 405
407 2 409 40b
2 40d 40f 2
411 413 2 415
417 2 419 41b
2 41d 41f 2
421 423 2 425
427 2 429 42b
2 42d 42f 2
431 433 2 435
437 2 439 43b
2 43d 43f 2
441 443 2 445
447 2 449 44b
1 451 2 453
454 2 44d 456
2 458 45a 2
45c 45e 2 460
462 2 464 466
2 468 46a 2
46c 46e 2 470
472 2 474 476
2 478 47a 2
47c 47e 2 480
482 2 484 486
2 488 48a 2
48c 48e 2 490
492 2 494 496
2 498 49a 1
4a0 2 4a2 4a3
2 49c 4a5 2
4a7 4a9 1 4af
2 4b1 4b2 2
4ab 4b4 2 4b6
4b8 1 4be 2
4c0 4c1 2 4ba
4c3 2 4c5 4c7
1 4cd 2 4cf
4d0 2 4c9 4d2
2 4d4 4d6 2
4d8 4da 2 4dc
4de 2 4e0 4e2
2 4e4 4e6 2
4e8 4ea 2 4ec
4ee 2 4f0 4f2
2 4f4 4f6 4
349 34f 354 4f8
1 4fa 1 4fc
2 506 508 3
504 505 50a 2
513 515 2 512
517 1 519 1
51b 2 566 567
1 56d 2 569
56d 1 571 2
581 583 3 57f
580 585 2 58e
590 2 592 594
2 596 598 1
5a0 2 5a2 5a3
2 59a 5a5 2
58d 5a7 1 5a9
1 5ab 2 5b5
5b7 3 5b3 5b4
5b9 2 5c2 5c4
2 5c1 5c6 1
5c8 1 5ca 2
5d1 5d2 3 5ac
5cb 5d4 1 5d6
1 5d8 1 5de
1 5e6 1 5ee
2 5f7 5f8 1
5fe 2 5fa 5fe
1 604 2 60b
60c 1 612 2
60e 612 2 620
622 3 61e 61f
624 2 62d 62f
2 631 633 2
635 637 1 63f
2 641 642 2
639 644 2 62c
646 1 648 1
64a 2 654 656
3 652 653 658
2 661 663 2
660 665 1 667
1 669 2 670
671 3 64b 66a
673 1 676 1
67c 2 68c 68e
3 68a 68b 690
2 699 69b 2
69d 69f 2 6a1
6a3 1 6ab 2
6ad 6ae 2 6a5
6b0 2 698 6b2
1 6b4 1 6b6
2 6c0 6c2 3
6be 6bf 6c4 2
6cd 6cf 2 6cc
6d1 1 6d3 1
6d5 2 6dc 6dd
3 6b7 6d6 6df
2 6e2 6e1 1
6e3 1 6e5 2
6e8 6e9 1 6ed
2 6eb 6ed 2
6f1 6f2 1 6f6
2 6f4 6f6 2
6fc 6fd 1 701
2 6ff 701 2
70e 710 3 70c
70d 712 2 71b
71d 2 71f 721
2 723 725 1
72d 2 72f 730
2 727 732 2
71a 734 1 736
1 738 2 742
744 3 740 741
746 2 74f 751
2 74e 753 1
755 1 757 2
75e 75f 3 739
758 761 1 763
1 765 1 76d
1 771 2 773
774 2 777 778
1 77e 2 77a
77e 1 782 1
78a 2 79a 79f
1 7a6 1 7a1
2 7b9 7bb 3
7b7 7b8 7bd 2
7c6 7c8 2 7ca
7cc 2 7ce 7d0
2 7d2 7d4 2
7d6 7d8 3 7dd
7de 7df 2 7da
7e1 2 7c5 7e3
1 7e5 1 7e7
2 7b0 7e8 1
7ec 1 7ab 2
7a9 7f0 1 7fb
2 7f7 7fb 2
800 801 1 805
2 803 805 2
813 815 3 811
812 817 2 820
822 2 824 826
2 828 82a 1
832 2 834 835
2 82c 837 2
81f 839 1 83b
1 83d 2 847
849 3 845 846
84b 2 854 856
2 853 858 1
85a 1 85c 2
863 864 3 83e
85d 866 1 868
3 7f3 869 86c
1 86e 1 870
1 876 2 881
886 1 88d 1
888 2 8a0 8a2
3 89e 89f 8a4
2 8ad 8af 2
8b1 8b3 2 8b5
8b7 2 8b9 8bb
2 8bd 8bf 3
8c4 8c5 8c6 2
8c1 8c8 2 8ac
8ca 1 8cc 1
8ce 2 897 8cf
1 8d3 1 892
2 890 8d7 1
8da 1 8dd 2
8e8 8e9 2 8eb
8ee 2 8f1 8f2
2 8f9 8fa 2
8fc 8ff 2 909
90a 2 90c 90f
2 912 913 2
91a 91b 2 91d
920 2 925 926
1 92c 2 928
92c 1 931 2
935 936 1 93c
2 938 93c 1
941 2 945 946
1 94c 2 948
94c 1 951 1
955 2 957 958
1 959 3 95b
943 95c 2 95f
960 1 964 2
962 964 2 96f
974 1 97b 1
976 2 98e 990
3 98c 98d 992
2 99b 99d 2
99f 9a1 2 9a3
9a5 2 9a7 9a9
2 9ab 9ad 3
9b2 9b3 9b4 2
9af 9b6 2 99a
9b8 1 9ba 1
9bc 2 985 9bd
1 9c1 1 980
2 97e 9c5 2
9cb 9cc 1 9d0
2 9ce 9d0 2
9d8 9dd 1 9e4
1 9df 2 9f7
9f9 3 9f5 9f6
9fb 2 a04 a06
2 a08 a0a 2
a0c a0e 2 a10
a12 2 a14 a16
3 a1b a1c a1d
2 a18 a1f 2
a03 a21 1 a23
1 a25 2 9ee
a26 1 a2a 1
9e9 2 9e7 a2e
2 a36 a37 1
a3b 2 a39 a3b
2 a46 a48 3
a44 a45 a4a 2
a53 a55 2 a57
a59 2 a5b a5d
1 a65 2 a67
a68 2 a5f a6a
2 a6c a6e 2
a70 a72 2 a74
a76 2 a78 a7a
2 a52 a7c 1
a7e 1 a80 2
a8a a8c 3 a88
a89 a8e 2 a97
a99 2 a96 a9b
1 a9d 1 a9f
3 aa6 aa7 aa8
3 a81 aa0 aaa
1 aac 2 a31
aad 1 aaf 2
ab4 ab5 1 ab7
2 abc abd 1
ac1 2 abf ac1
2 ac7 ac8 1
aca 2 acf ad0
1 ad4 2 ad2
ad4 2 adf ae1
3 add ade ae3
2 aec aee 2
af0 af2 2 af4
af6 1 afe 2
b00 b01 2 af8
b03 2 aeb b05
1 b07 1 b09
2 b13 b15 3
b11 b12 b17 2
b20 b22 2 b1f
b24 1 b26 1
b28 2 b2f b30
3 b0a b29 b32
1 b34 3 acd
b35 b3a 1 b3c
2 b42 b43 1
b47 2 b45 b47
1 b4c 2 b56
b58 3 b54 b55
b5a 2 b63 b65
2 b67 b69 2
b6b b6d 1 b75
2 b77 b78 2
b6f b7a 2 b62
b7c 1 b7e 1
b80 2 b8a b8c
3 b88 b89 b8e
2 b97 b99 2
b96 b9b 1 b9d
1 b9f 2 ba6
ba7 3 b81 ba0
ba9 2 bab bac
6 bb0 bb1 bb2
bb3 bb4 bb5 2
bba bbb 1 bc1
2 bbd bc1 2
bc5 bc6 1 bca
2 bc8 bca 1
bd1 1 bd3 2
bdd bdf 3 bdb
bdc be1 2 bea
bec 2 bee bf0
2 bf2 bf4 1
bfa 2 bfc bfd
2 bf6 bff 2
c01 c03 2 c05
c07 2 c09 c0b
2 c0d c0f 2
be9 c11 1 c13
1 c15 2 c1f
c21 3 c1d c1e
c23 2 c2c c2e
2 c2b c30 1
c32 1 c34 2
c3a c3b 3 c3d
c3e c3f 4 bd4
c16 c35 c41 1
c43 2 c46 c47
1 c4b 2 c49
c4b 2 c4f c50
1 c54 2 c52
c54 2 c61 c63
3 c5f c60 c65
2 c6e c70 2
c72 c74 2 c76
c78 1 c7e 2
c80 c81 2 c7a
c83 2 c85 c87
2 c89 c8b 2
c8d c8f 2 c91
c93 2 c6d c95
1 c97 1 c99
2 ca3 ca5 3
ca1 ca2 ca7 2
cb0 cb2 2 caf
cb4 1 cb6 1
cb8 2 cbe cbf
3 cc1 cc2 cc3
3 c9a cb9 cc5
1 cc7 2 cca
ccb 1 cd1 2
ccd cd1 2 cd6
cd7 1 cd9 1
cdd 2 cdb cdd
2 ced cf2 1
cf9 1 cf4 2
d0c d0e 3 d0a
d0b d10 2 d19
d1b 2 d1d d1f
2 d21 d23 2
d25 d27 2 d29
d2b 3 d30 d31
d32 2 d2d d34
2 d18 d36 1
d38 1 d3a 2
d03 d3b 1 d3f
1 cfe 2 cfc
d43 1 d46 2
d70 d75 1 d7c
1 d77 2 d8f
d91 3 d8d d8e
d93 2 d9c d9e
2 da0 da2 2
da4 da6 2 da8
daa 2 dac dae
3 db3 db4 db5
2 db0 db7 2
d9b db9 1 dbb
1 dbd 2 d86
dbe 1 dc2 1
d81 2 d7f dc6
1 dc9 2 dcc
dcd 1 dd5 2
dd1 dd5 2 de1
de3 3 ddf de0
de5 2 dee df0
2 df2 df4 2
df6 df8 1 e00
2 e02 e03 2
dfa e05 2 e07
e09 2 e0b e0d
2 e0f e11 2
e13 e15 2 ded
e17 1 e19 1
e1b 2 e25 e27
3 e23 e24 e29
2 e32 e34 2
e31 e36 1 e38
1 e3a 3 e41
e42 e43 3 e1c
e3b e45 1 e47
2 dce e48 2
e4c e4d 1 e53
2 e4f e53 2
e5f e64 1 e6b
1 e66 2 e7e
e80 3 e7c e7d
e82 2 e8b e8d
2 e8f e91 2
e93 e95 2 e97
e99 2 e9b e9d
3 ea2 ea3 ea4
2 e9f ea6 2
e8a ea8 1 eaa
1 eac 2 e75
ead 1 eb1 1
e70 2 e6e eb5
1 ec0 2 ebc
ec0 2 ecc ece
3 eca ecb ed0
2 ed9 edb 2
edd edf 2 ee1
ee3 1 eeb 2
eed eee 2 ee5
ef0 2 ef2 ef4
2 ef6 ef8 2
efa efc 2 efe
f00 2 ed8 f02
1 f04 1 f06
2 f10 f12 3
f0e f0f f14 2
f1d f1f 2 f1c
f21 1 f23 1
f25 3 f2c f2d
f2e 3 f07 f26
f30 1 f32 2
f47 f4c 1 f53
1 f4e 2 f66
f68 3 f64 f65
f6a 2 f73 f75
2 f77 f79 2
f7b f7d 2 f7f
f81 2 f83 f85
3 f8a f8b f8c
2 f87 f8e 2
f72 f90 1 f92
1 f94 2 f5d
f95 1 f99 1
f58 2 f56 f9d
1 fa8 2 fa4
fa8 2 fb4 fb6
3 fb2 fb3 fb8
2 fc1 fc3 2
fc5 fc7 2 fc9
fcb 1 fd3 2
fd5 fd6 2 fcd
fd8 2 fda fdc
2 fde fe0 2
fe2 fe4 2 fe6
fe8 2 fc0 fea
1 fec 1 fee
2 ff8 ffa 3
ff6 ff7 ffc 2
1005 1007 2 1004
1009 1 100b 1
100d 3 1014 1015
1016 3 fef 100e
1018 1 101a 1
101c 1 1028 2
1025 102b 1 102d
5 eb8 f33 fa0
101b 102e 2 1039
103b 3 1037 1038
103d 2 1046 1048
2 104a 104c 2
104e 1050 1 1058
2 105a 105b 2
1052 105d 2 105f
1061 2 1063 1065
2 1067 1069 2
106b 106d 2 1045
106f 1 1071 1
1073 2 107d 107f
3 107b 107c 1081
2 108a 108c 2
1089 108e 1 1090
1 1092 3 1099
109a 109b 3 1074
1093 109d 3 109f
1030 10a0 2 10a3
10a4 1 10aa 2
10a6 10aa 2 10c4
10c9 1 10d0 1
10cb 2 10e3 10e5
3 10e1 10e2 10e7
2 10f0 10f2 2
10f4 10f6 2 10f8
10fa 2 10fc 10fe
2 1100 1102 3
1107 1108 1109 2
1104 110b 2 10ef
110d 1 110f 1
1111 2 10da 1112
1 1116 1 10d5
2 10d3 111a 1
1125 2 1121 1125
2 1131 1133 3
112f 1130 1135 2
113e 1140 2 1142
1144 2 1146 1148
1 1150 2 1152
1153 2 114a 1155
2 1157 1159 2
115b 115d 2 115f
1161 2 1163 1165
2 113d 1167 1
1169 1 116b 2
1175 1177 3 1173
1174 1179 2 1182
1184 2 1181 1186
1 1188 1 118a
3 1191 1192 1193
3 116c 118b 1195
1 119e 2 119a
119e 3 11a3 11a4
11a5 1 11a9 2
11a7 11a9 2 11ad
11ae 1 11b2 2
11b0 11b2 2 11b6
11b7 2 11bc 11bd
1 11bf 2 11b9
11bf 2 11cf 11d1
3 11cd 11ce 11d3
2 11dc 11de 2
11e0 11e2 2 11e4
11e6 1 11ee 2
11f0 11f1 2 11e8
11f3 2 11f5 11f7
2 11f9 11fb 2
11fd 11ff 2 1201
1203 2 11db 1205
1 1207 1 1209
2 1213 1215 3
1211 1212 1217 2
1220 1222 2 121f
1224 1 1226 1
1228 3 122f 1230
1231 3 120a 1229
1233 1 1235 2
1238 1239 2 123e
123f 1 1241 2
123b 1241 2 124d
1252 1 1259 1
1254 2 126c 126e
3 126a 126b 1270
2 1279 127b 2
127d 127f 2 1281
1283 2 1285 1287
2 1289 128b 3
1290 1291 1292 2
128d 1294 2 1278
1296 1 1298 1
129a 2 1263 129b
1 129f 1 125e
2 125c 12a3 1
12a6 1 12a9 2
1236 12aa 2 12ad
12ac 2 111d 12ae
1 12b0 c 969
9c8 ab0 aba b3d
b40 bad bb8 c44
cc8 10a1 12b1 1
12b3 2 12b6 12b7
1 12bb 2 12b9
12bb 2 12bf 12c0
1 12c6 2 12c2
12c6 1 12c9 2
12d1 12d2 1 12d6
2 12d4 12d6 2
12e3 12e5 3 12e1
12e2 12e7 2 12f0
12f2 2 12f4 12f6
2 12f8 12fa 1
1302 2 1304 1305
2 12fc 1307 2
1309 130b 2 130d
130f 2 1311 1313
2 1315 1317 2
12ef 1319 1 131b
1 131d 2 1327
1329 3 1325 1326
132b 2 1334 1336
2 1333 1338 1
133a 1 133c 3
1343 1344 1345 3
131e 133d 1347 1
1349 2 134c 134d
1 1353 2 134f
1353 2 1361 1366
1 136d 1 1368
2 1380 1382 3
137e 137f 1384 2
138d 138f 2 1391
1393 2 1395 1397
2 1399 139b 2
139d 139f 3 13a4
13a5 13a6 2 13a1
13a8 2 138c 13aa
1 13ac 1 13ae
2 1377 13af 1
13b3 1 1372 2
1370 13b7 1 13c2
2 13be 13c2 2
13cb 13d0 1 13d7
1 13d2 2 13ea
13ec 3 13e8 13e9
13ee 2 13f7 13f9
2 13fb 13fd 2
13ff 1401 2 1403
1405 2 1407 1409
3 140e 140f 1410
2 140b 1412 2
13f6 1414 1 1416
1 1418 2 13e1
1419 1 141d 1
13dc 2 13da 1421
1 142c 2 1428
142c 2 1438 143a
3 1436 1437 143c
2 1445 1447 2
1449 144b 2 144d
144f 1 1457 2
1459 145a 2 1451
145c 2 145e 1460
2 1462 1464 2
1466 1468 2 146a
146c 2 1444 146e
1 1470 1 1472
2 147c 147e 3
147a 147b 1480 2
1489 148b 2 1488
148d 1 148f 1
1491 3 1498 1499
149a 3 1473 1492
149c 1 149e 2
1424 149f 1 14a1
2 13ba 14a2 1
14a4 2 134a 14a5
1 14a7 2 14aa
14ab 1 14af 2
14ad 14af 2 14b3
14b4 1 14b8 2
14b6 14b8 1 14bf
1 14c1 2 14c4
14c5 1 14cb 2
14c7 14cb 1 14ce
2 14d5 14d8 2
14dc 14df 2 14e1
14e2 2 14e3 14e6
1 14ea 2 14e8
14ea 2 14f5 14f6
2 14fa 14fb 2
14ff 1500 2 1504
1505 2 1509 150a
2 150e 150f 2
1513 1514 2 1518
1519 d 14f2 14f3
14f8 14fd 1502 1507
150c 1511 1516 151b
151c 151d 151e 2
1523 1524 1 152a
2 1526 152a 2
1535 1537 3 1533
1534 1539 2 1542
1544 2 1546 1548
2 154a 154c 1
1554 2 1556 1557
2 154e 1559 2
1541 155b 1 155d
1 155f 2 1569
156b 3 1567 1568
156d 2 1576 1578
2 1575 157a 1
157c 1 157e 2
1585 1586 3 1560
157f 1588 2 158c
158d 1 1591 2
158f 1591 2 159c
159e 3 159a 159b
15a0 2 15a9 15ab
2 15ad 15af 2
15b1 15b3 1 15b9
2 15bb 15bc 2
15b5 15be 2 15c0
15c2 2 15c4 15c6
2 15c8 15ca 2
15cc 15ce 2 15a8
15d0 1 15d2 1
15d4 2 15de 15e0
3 15dc 15dd 15e2
2 15eb 15ed 2
15ea 15ef 1 15f1
1 15f3 2 15f9
15fa 3 15fc 15fd
15fe 3 15d5 15f4
1600 2 1603 1602
3 14ef 1521 1604
2 160a 160b 1
160f 2 160d 160f
2 1614 1615 2
161a 161b 2 1617
161d 1 1620 1
1622 2 1608 1623
2 1625 1626 2
1629 162a 1 162e
2 162c 162e 2
1633 1634 1 1638
2 1636 1638 2
163f 1640 1 1644
2 1642 1644 2
1649 164a 1 164e
2 164c 164e 1
1656 2 165a 165b
1 165f 2 165d
165f 1 1664 2
1669 166a 1 166e
2 166c 166e 2
1673 1674 1 1678
2 1676 1678 1
1680 2 1685 1686
1 168a 2 1688
168a 1 168f 4
1692 1667 1683 1691
1 1693 1 1695
2 1627 1696 2
1698 1699 2 169c
169d 1 16a3 2
169f 16a3 3 16b1
16b2 16b3 2 16bb
16bc 1 16c0 2
16be 16c0 2 16c7
16ca 2 16d1 16d6
1 16dd 1 16d8
2 16f0 16f2 3
16ee 16ef 16f4 2
16fd 16ff 2 1701
1703 2 1705 1707
2 1709 170b 2
170d 170f 3 1714
1715 1716 2 1711
1718 2 16fc 171a
1 171c 1 171e
2 16e7 171f 1
1723 1 16e2 2
16e0 1727 1 1732
2 172e 1732 2
1737 1738 1 173c
2 173a 173c 2
174a 174f 1 1756
1 1751 2 1769
176b 3 1767 1768
176d 2 1776 1778
2 177a 177c 2
177e 1780 2 1782
1784 2 1786 1788
3 178d 178e 178f
2 178a 1791 2
1775 1793 1 1795
1 1797 2 1760
1798 1 179c 1
175b 2 1759 17a0
1 17a3 1 17a6
1 17a7 1 17ab
2 17ad 17ae 2
172a 17af 2 17b1
17b2 1 17b6 2
17b4 17b6 2 17c2
17c7 1 17ce 1
17c9 2 17e1 17e3
3 17df 17e0 17e5
2 17ee 17f0 2
17f2 17f4 2 17f6
17f8 2 17fa 17fc
2 17fe 1800 3
1805 1806 1807 2
1802 1809 2 17ed
180b 1 180d 1
180f 2 17d8 1810
1 1814 1 17d3
2 17d1 1818 2
183c 1841 1 1848
1 1843 2 185b
185d 3 1859 185a
185f 2 1868 186a
2 186c 186e 2
1870 1872 2 1874
1876 2 1878 187a
3 187f 1880 1881
2 187c 1883 2
1867 1885 1 1887
1 1889 2 1852
188a 1 188e 1
184d 2 184b 1892
1 189d 2 1899
189d 2 18a9 18ab
3 18a7 18a8 18ad
2 18b6 18b8 2
18ba 18bc 2 18be
18c0 1 18c8 2
18ca 18cb 2 18c2
18cd 2 18cf 18d1
2 18d3 18d5 2
18d7 18d9 2 18db
18dd 2 18b5 18df
1 18e1 1 18e3
2 18ed 18ef 3
18eb 18ec 18f1 2
18fa 18fc 2 18f9
18fe 1 1900 1
1902 3 1909 190a
190b 3 18e4 1903
190d 1 190f 2
1912 1913 1 1917
2 1915 1917 1
191c 1 1920 2
1922 1923 1 193b
2 193a 193b 1
1943 1 1949 2
194b 194c 2 1938
194d 1 1954 1
194f 2 1967 1969
3 1965 1966 196b
2 1974 1976 2
1978 197a 2 197c
197e 2 1980 1982
2 1984 1986 3
198b 198c 198d 2
1988 198f 2 1973
1991 1 1993 1
1995 2 195e 1996
1 199a 1 1959
2 1957 199e 5
181b 1895 1910 1924
19a1 3 19a6 19a7
19a8 1 19ac 2
19aa 19ac 1 19b6
2 19b5 19b6 1
19be 1 19c4 2
19c6 19c7 2 19b3
19c8 1 19cf 1
19ca 2 19e2 19e4
3 19e0 19e1 19e6
2 19ef 19f1 2
19f3 19f5 2 19f7
19f9 2 19fb 19fd
2 19ff 1a01 3
1a06 1a07 1a08 2
1a03 1a0a 2 19ee
1a0c 1 1a0e 1
1a10 2 19d9 1a11
1 1a15 1 19d4
2 19d2 1a19 1
1a1c 2 1a20 1a1f
1 1a2e 2 1a2d
1a2e 1 1a36 1
1a3c 2 1a3e 1a3f
2 1a2b 1a40 1
1a47 1 1a42 2
1a5a 1a5c 3 1a58
1a59 1a5e 2 1a67
1a69 2 1a6b 1a6d
2 1a6f 1a71 2
1a73 1a75 2 1a77
1a79 3 1a7e 1a7f
1a80 2 1a7b 1a82
2 1a66 1a84 1
1a86 1 1a88 2
1a51 1a89 1 1a8d
1 1a4c 2 1a4a
1a91 1 1aa2 2
1aa1 1aa2 1 1aaa
1 1ab0 2 1ab2
1ab3 2 1a9f 1ab4
1 1abb 1 1ab6
2 1ace 1ad0 3
1acc 1acd 1ad2 2
1adb 1add 2 1adf
1ae1 2 1ae3 1ae5
2 1ae7 1ae9 2
1aeb 1aed 3 1af2
1af3 1af4 2 1aef
1af6 2 1ada 1af8
1 1afa 1 1afc
2 1ac5 1afd 1
1b01 1 1ac0 2
1abe 1b05 1 1b13
2 1b12 1b13 1
1b1b 1 1b21 2
1b23 1b24 2 1b10
1b25 1 1b2c 1
1b27 2 1b3f 1b41
3 1b3d 1b3e 1b43
2 1b4c 1b4e 2
1b50 1b52 2 1b54
1b56 2 1b58 1b5a
2 1b5c 1b5e 3
1b63 1b64 1b65 2
1b60 1b67 2 1b4b
1b69 1 1b6b 1
1b6d 2 1b36 1b6e
1 1b72 1 1b31
2 1b2f 1b76 a
16a8 16ab 16ae 16b6
16b9 17b3 1a21 1a94
1b08 1b79 1 1b7c
2 1b84 1b85 1
1b89 2 1b87 1b89
2 1b8d 1b8e 1
1b94 2 1b90 1b94
2 1b9a 1b9b 1
1ba1 2 1b9d 1ba1
1 1ba6 1 1bad
1 1baf 1 1bb0
1 1bb2 2 1bb5
1bb6 1 1bba 2
1bb8 1bba 1 1bc1
1 1bc3 1 1bc5
1 1bca 1 1bd1
1 1bd8 1 1be2
1 1be4 2 1bed
1bee 1 1bf2 2
1bf0 1bf2 2 1bf6
1bf7 1 1bfd 2
1bf9 1bfd 2 1c01
1c03 2 1c05 1c07
2 1c09 1c0b 2
1c0d 1c0f 2 1c11
1c13 2 1c15 1c17
2 1c19 1c1b 1
1c1e 2 1c22 1c23
1 1c27 2 1c25
1c27 2 1c2b 1c2d
2 1c2f 1c31 2
1c33 1c35 2 1c37
1c39 2 1c3b 1c3d
2 1c3f 1c41 2
1c43 1c45 2 1c47
1c49 1 1c4c 2
1c50 1c52 2 1c54
1c56 2 1c58 1c5a
2 1c5c 1c5e 2
1c60 1c62 1 1c65
3 1c67 1c4e 1c68
1 1c69 2 1c6c
1c6d 1 1c73 2
1c6f 1c73 2 1c77
1c78 1 1c7e 2
1c7a 1c7e 2 1c84
1c85 1 1c8b 2
1c87 1c8b 1 1c9a
1 1cc3 2 1cc2
1cc3 1 1ccb 1
1cd1 2 1cd3 1cd4
2 1cc0 1cd5 1
1cdc 1 1cd7 2
1cef 1cf1 3 1ced
1cee 1cf3 2 1cfc
1cfe 2 1d00 1d02
2 1d04 1d06 2
1d08 1d0a 2 1d0c
1d0e 3 1d13 1d14
1d15 2 1d10 1d17
2 1cfb 1d19 1
1d1b 1 1d1d 2
1ce6 1d1e 1 1d22
1 1ce1 2 1cdf
1d26 1 1d43 2
1d42 1d43 1 1d4b
1 1d51 2 1d53
1d54 2 1d40 1d55
1 1d5c 1 1d57
2 1d6f 1d71 3
1d6d 1d6e 1d73 2
1d7c 1d7e 2 1d80
1d82 2 1d84 1d86
2 1d88 1d8a 2
1d8c 1d8e 3 1d93
1d94 1d95 2 1d90
1d97 2 1d7b 1d99
1 1d9b 1 1d9d
2 1d66 1d9e 1
1da2 1 1d61 2
1d5f 1da6 4 1ca3
1ca8 1d29 1da9 1
1dae 2 1db0 1db1
3 1c94 1c99 1db2
1 1db4 1 1db6
1 1dbe 2 1dc0
1dc1 1 1dc5 2
1dc3 1dc5 1 1dcb
2 1dcd 1dce 2
1dd0 1dd1 2 1dd3
1dd5 1 1dc7 1
1ddd 2 1ddf 1de0
2 1de2 1de3 2
1dd9 1de6 1 1dee
2 1ded 1dee 2
1df8 1dfa 3 1df7
1dfc 1dfd 1 1dff
2 1e01 1e02 1
1e06 2 1e04 1e06
2 1e0d 1e0f 3
1e0c 1e11 1e12 1
1e14 2 1e16 1e17
1 1e1b 2 1e19
1e1b 1 1e21 1
1e23 2 1e26 1e28
2 1e24 1e2b 1
1e30 2 1e2f 1e30
2 1e3c 1e3e 3
1e3a 1e3b 1e40 2
1e49 1e4b 2 1e4d
1e4f 2 1e51 1e53
1 1e5b 2 1e5d
1e5e 2 1e55 1e60
2 1e48 1e62 1
1e64 1 1e66 2
1e70 1e72 3 1e6e
1e6f 1e74 2 1e7d
1e7f 2 1e7c 1e81
1 1e83 1 1e85
2 1e8c 1e8d 3
1e67 1e86 1e8f 1
1e91 2 1e97 1e9c
1 1ea3 1 1e9e
2 1eb6 1eb8 3
1eb4 1eb5 1eba 2
1ec3 1ec5 2 1ec7
1ec9 2 1ecb 1ecd
2 1ecf 1ed1 2
1ed3 1ed5 3 1eda
1edb 1edc 2 1ed7
1ede 2 1ec2 1ee0
1 1ee2 1 1ee4
2 1ead 1ee5 1
1ee9 1 1ea8 2
1ea6 1eed 5 1de8
1deb 1e2e 1e92 1ef0
1 1ef3 2 1ef6
1ef7 1 1efd 2
1ef9 1efd 2 1f07
1f09 2 1f0e 1f10
4 1f02 1f05 1f0c
1f13 2 1f17 1f18
1 1f1e 2 1f1a
1f1e 2 1f25 1f27
2 1f2c 1f2e 4
1f23 1f2a 1f31 1f34
2 1f38 1f39 1
1f3f 2 1f3b 1f3f
2 1f49 1f4b 1
1f4f 2 1f55 1f57
2 1f5c 1f5e 2
1f63 1f65 3 1f5a
1f61 1f68 1 1f6a
4 1f44 1f47 1f4e
1f6b 1 1f6d 2
1f73 1f75 2 1f78
1f7b 2 1f7e 1f80
2 1f82 1f84 2
1f8c 1f8e 2 1f90
1f92 2 1f94 1f96
2 1f98 1f9a 2
1f9c 1f9e 2 1fa0
1fa2 3 1f87 1f8a
1fa5 2 1fa7 1fa8
1 1faa 2 1fb0
1fb2 2 1fb4 1fb6
2 1fb8 1fba 1
1fbd 1 1fbf 2
1fa9 1fc0 2 1fc2
1fc3 1 1fc5 2
1fcb 1fcd 2 1fd2
1fd4 2 1fd9 1fdb
3 1fd0 1fd7 1fde
1 1fe0 2 1fc4
1fe1 3 1fe3 1f36
1fe4 2 1fe7 1fe8
1 1fee 2 1fea
1fee 1 1ff1 2
1ffb 2000 1 2007
1 2002 2 201a
201c 3 2018 2019
201e 2 2027 2029
2 202b 202d 2
202f 2031 2 2033
2035 2 2037 2039
3 203e 203f 2040
2 203b 2042 2
2026 2044 1 2046
1 2048 2 2011
2049 1 204d 1
200c 2 200a 2051
1 205c 2 2058
205c 1 2063 2
2065 2066 2 206b
206d 2 2072 2074
2 2076 2078 2
207a 207c 2 207e
2080 3 2069 2070
2083 2 208d 208f
3 208b 208c 2091
2 209a 209c 2
209e 20a0 2 20a2
20a4 1 20ac 2
20ae 20af 2 20a6
20b1 2 20b3 20b5
2 20b7 20b9 2
20bb 20bd 2 20bf
20c1 2 2099 20c3
1 20c5 1 20c7
2 20d1 20d3 3
20cf 20d0 20d5 2
20de 20e0 2 20dd
20e2 1 20e4 1
20e6 3 20ed 20ee
20ef 3 20c8 20e7
20f1 2 20f3 20f4
2 2054 20f5 1
20f7 1 20f9 2
2103 2108 1 210f
1 210a 2 2122
2124 3 2120 2121
2126 2 212f 2131
2 2133 2135 2
2137 2139 2 213b
213d 2 213f 2141
3 2146 2147 2148
2 2143 214a 2
212e 214c 1 214e
1 2150 2 2119
2151 1 2155 1
2114 2 2112 2159
1 2164 2 2160
2164 2 2169 216b
2 2170 2172 2
2174 2176 2 2178
217a 2 217c 217e
2 216e 2181 2
218b 218d 3 2189
218a 218f 2 2198
219a 2 219c 219e
2 21a0 21a2 1
21aa 2 21ac 21ad
2 21a4 21af 2
21b1 21b3 2 21b5
21b7 2 21b9 21bb
2 21bd 21bf 2
2197 21c1 1 21c3
1 21c5 2 21cf
21d1 3 21cd 21ce
21d3 2 21dc 21de
2 21db 21e0 1
21e2 1 21e4 3
21eb 21ec 21ed 3
21c6 21e5 21ef 2
21f1 21f2 2 215c
21f3 1 21f5 1
21f7 2 2201 2206
1 220d 1 2208
2 2220 2222 3
221e 221f 2224 2
222d 222f 2 2231
2233 2 2235 2237
2 2239 223b 2
223d 223f 3 2244
2245 2246 2 2241
2248 2 222c 224a
1 224c 1 224e
2 2217 224f 1
2253 1 2212 2
2210 2257 1 2262
2 225e 2262 2
2267 2269 2 226e
2270 2 2272 2274
2 2276 2278 2
227a 227c 2 226c
227f 2 2289 228b
3 2287 2288 228d
2 2296 2298 2
229a 229c 2 229e
22a0 1 22a8 2
22aa 22ab 2 22a2
22ad 2 22af 22b1
2 22b3 22b5 2
22b7 22b9 2 22bb
22bd 2 2295 22bf
1 22c1 1 22c3
2 22cd 22cf 3
22cb 22cc 22d1 2
22da 22dc 2 22d9
22de 1 22e0 1
22e2 3 22e9 22ea
22eb 3 22c4 22e3
22ed 2 22ef 22f0
2 225a 22f1 1
22f3 2 22f6 22f7
1 22fb 2 22f9
22fb 2 22ff 2300
1 2304 2 2302
2304 2 230a 230c
2 2312 2313 1
2315 2 230e 2317
2 2319 231b 1
231e 1 2320 4
20f8 21f6 22f4 2321
1 2323 1 2325
1 232d 2 232f
2330 1 2339 2
2338 2339 2 2345
2347 4 2343 2344
2349 234a 2 2353
2358 1 235f 1
235a 2 2372 2374
3 2370 2371 2376
2 237f 2381 2
2383 2385 2 2387
2389 2 238b 238d
2 238f 2391 3
2396 2397 2398 2
2393 239a 2 237e
239c 1 239e 1
23a0 2 2369 23a1
1 23a5 1 2364
2 2362 23a9 1
23b4 2 23b0 23b4
2 23c0 23c2 3
23be 23bf 23c4 2
23cd 23cf 2 23d1
23d3 2 23d5 23d7
1 23df 2 23e1
23e2 2 23d9 23e4
2 23e6 23e8 2
23ea 23ec 2 23ee
23f0 2 23f2 23f4
2 23cc 23f6 1
23f8 1 23fa 2
2404 2406 3 2402
2403 2408 2 2411
2413 2 2410 2415
1 2417 1 2419
3 2420 2421 2422
3 23fb 241a 2424
1 2426 2 2429
242b 2 242d 242f
2 2431 2433 2
2435 2437 2 2439
243b 2 243d 243f
2 2444 2445 1
244b 2 2447 244b
2 244f 2451 1
2454 2 2457 2459
1 245c 2 245e
245f 2 2462 2463
1 2469 2 2465
2469 1 246d 1
246f 2 2472 2474
7 234d 23ac 2427
2442 2460 2470 2477
3 2333 2336 247a
1 247c 2 247f
2480 1 2486 2
2482 2486 1 248c
2 248e 248f 1
2498 2 2497 2498
2 24a4 24a6 4
24a2 24a3 24a8 24a9
2 24b2 24b7 1
24be 1 24b9 2
24d1 24d3 3 24cf
24d0 24d5 2 24de
24e0 2 24e2 24e4
2 24e6 24e8 2
24ea 24ec 2 24ee
24f0 3 24f5 24f6
24f7 2 24f2 24f9
2 24dd 24fb 1
24fd 1 24ff 2
24c8 2500 1 2504
1 24c3 2 24c1
2508 1 2513 2
250f 2513 2 251f
2521 3 251d 251e
2523 2 252c 252e
2 2530 2532 2
2534 2536 1 253e
2 2540 2541 2
2538 2543 2 2545
2547 2 2549 254b
2 254d 254f 2
2551 2553 2 252b
2555 1 2557 1
2559 2 2563 2565
3 2561 2562 2567
2 2570 2572 2
256f 2574 1 2576
1 2578 3 257f
2580 2581 3 255a
2579 2583 1 2585
2 2588 258a 2
258c 258e 2 2590
2592 2 2594 2596
2 2598 259a 2
259c 259e 2 25a0
25a2 2 25a7 25a9
5 24ac 250b 2586
25a5 25ac 3 2492
2495 25af 1 25b1
2 25b4 25b6 7
1db5 1ef4 1fe5 2324
247d 25b2 25b9 2
25bb 25bc 2 25bf
25c1 1 25d6 1
25dc 2 25de 25df
1 25e7 2 25e3
25e7 1 25ec 1
25ee 2 25f1 25f2
1 25f6 2 25f4
25f6 2 25fa 25fb
1 2601 2 25fd
2601 2 2607 2608
1 260e 2 260a
260e 2 2614 2615
1 261b 2 2617
261b 1 261e 1
2638 1 263e 2
2640 2641 1 2649
2 2645 2649 2
264f 2655 1 265c
1 2657 2 266f
2671 3 266d 266e
2673 2 267c 267e
2 2680 2682 2
2684 2686 2 2688
268a 2 268c 268e
3 2693 2694 2695
2 2690 2697 2
267b 2699 1 269b
1 269d 2 2666
269e 1 26a2 1
2661 2 265f 26a6
2 26a9 26ac 2
26b0 26b6 1 26bd
1 26b8 2 26d0
26d2 3 26ce 26cf
26d4 2 26dd 26df
2 26e1 26e3 2
26e5 26e7 2 26e9
26eb 2 26ed 26ef
3 26f4 26f5 26f6
2 26f1 26f8 2
26dc 26fa 1 26fc
1 26fe 2 26c7
26ff 1 2703 1
26c2 2 26c0 2707
1 270a 2 270d
270e 4 262a 262f
2642 270f 1 2711
2 271a 271b 1
271f 2 271d 271f
3 2723 2724 2725
1 2729 2 2727
2729 2 2730 2733
2 2737 2738 1
273a 1 273e 2
273c 273e 2 274a
274f 1 2756 1
2751 2 2769 276b
3 2767 2768 276d
2 2776 2778 2
277a 277c 2 277e
2780 2 2782 2784
2 2786 2788 3
278d 278e 278f 2
278a 2791 2 2775
2793 1 2795 1
2797 2 2760 2798
1 279c 1 275b
2 2759 27a0 2
27a6 27a7 1 27ab
2 27a9 27ab 2
27b0 27b6 1 27bd
1 27b8 2 27d0
27d2 3 27ce 27cf
27d4 2 27dd 27df
2 27e1 27e3 2
27e5 27e7 2 27e9
27eb 2 27ed 27ef
3 27f4 27f5 27f6
2 27f1 27f8 2
27dc 27fa 1 27fc
1 27fe 2 27c7
27ff 1 2803 1
27c2 2 27c0 2807
2 2814 2816 3
2812 2813 2818 2
2821 2823 2 2825
2827 2 2829 282b
1 2833 2 2835
2836 2 282d 2838
2 283a 283c 2
283e 2840 2 2842
2844 2 2846 2848
2 2820 284a 1
284c 1 284e 2
2858 285a 3 2856
2857 285c 2 2865
2867 2 2864 2869
1 286b 1 286d
3 2874 2875 2876
4 280a 284f 286e
2878 1 287a 2
27a3 287b 1 287d
1 287e 2 2880
2881 2 28a2 28a3
22 2885 2886 2887
2888 2889 288a 288b
288c 288d 288e 288f
2890 2891 2892 2893
2894 2895 2896 2897
2898 2899 289a 289b
289c 289d 289e 289f
28a0 28a5 28a6 28a7
28a8 28a9 28aa 1
28b0 2 28ae 28b0
2 28b5 28bb 1
28c2 1 28bd 2
28d5 28d7 3 28d3
28d4 28d9 2 28e2
28e4 2 28e6 28e8
2 28ea 28ec 2
28ee 28f0 2 28f2
28f4 3 28f9 28fa
28fb 2 28f6 28fd
2 28e1 28ff 1
2901 1 2903 2
28cc 2904 1 2908
1 28c7 2 28c5
290c 1 2915 2
2911 2915 1 291c
1 291e 2 2928
292a 3 2926 2927
292c 2 2935 2937
2 2939 293b 2
293d 293f 1 2945
2 2947 2948 2
2941 294a 2 294c
294e 2 2950 2952
2 2954 2956 2
2958 295a 2 2934
295c 1 295e 1
2960 2 296a 296c
3 2968 2969 296e
2 2977 2979 2
2976 297b 1 297d
1 297f 3 2984
2985 2986 5 290f
291f 2961 2980 2988
3 298c 298d 298e
1 2992 2 2990
2992 3 2997 2998
2999 1 299d 2
299b 299d 1 29ab
2 29aa 29ab 1
29b3 1 29b9 2
29bb 29bc 2 29a8
29bd 1 29c4 1
29bf 2 29d7 29d9
3 29d5 29d6 29db
2 29e4 29e6 2
29e8 29ea 2 29ec
29ee 2 29f0 29f2
2 29f4 29f6 3
29fb 29fc 29fd 2
29f8 29ff 2 29e3
2a01 1 2a03 1
2a05 2 29ce 2a06
1 2a0a 1 29c9
2 29c7 2a0e 1
2a11 2 2a15 2a14
4 2882 28ad 2a16
2a18 2 2a1b 2a1c
1 2a22 2 2a1e
2a22 2 2a27 2a2a
1 2a2c 22 2a30
2a31 2a32 2a33 2a34
2a35 2a36 2a37 2a38
2a39 2a3a 2a3b 2a3c
2a3d 2a3e 2a3f 2a40
2a41 2a42 2a43 2a44
2a45 2a46 2a47 2a48
2a49 2a4a 2a4b 2a4c
2a4d 2a4e 2a4f 2a50
2a51 1 2a57 2
2a55 2a57 2 2a5b
2a5d 1 2a60 1
2a65 2 2a63 2a65
1 2a69 2 2a6c
2a6b 2 2a71 2a72
1 2a74 2 2a6e
2a74 1 2a78 1
2a7a 4 2a2d 2a54
2a6d 2a7b 2 2a7d
2a7e 1 2a80 8
25cd 25e0 25ef 2712
2715 2718 2a7f 2a83
2 2a89 2a8f 1
2a96 1 2a91 2
2aa9 2aab 3 2aa7
2aa8 2aad 2 2ab6
2ab8 2 2aba 2abc
2 2abe 2ac0 2
2ac2 2ac4 2 2ac6
2ac8 3 2acd 2ace
2acf 2 2aca 2ad1
2 2ab5 2ad3 1
2ad5 1 2ad7 2
2aa0 2ad8 1 2adc
1 2a9b 2 2a99
2ae0 1 2ae9 2
2ae5 2ae9 1 2aef
2 2aed 2aef 1
2af7 2 2af5 2af7
2 2afb 2afc 1
2b00 2 2afe 2b00
2 2b10 2b12 3
2b0e 2b0f 2b14 2
2b1d 2b1f 2 2b21
2b23 2 2b25 2b27
1 2b2d 2 2b2f
2b30 2 2b29 2b32
2 2b34 2b36 2
2b38 2b3a 2 2b3c
2b3e 2 2b40 2b42
2 2b1c 2b44 1
2b46 1 2b48 2
2b52 2b54 3 2b50
2b51 2b56 2 2b5f
2b61 2 2b5e 2b63
1 2b65 1 2b67
3 2b6c 2b6d 2b6e
3 2b49 2b68 2b70
1 2b72 1 2b76
2 2b74 2b76 8
2b8c 2b8d 2b8e 2b8f
2b90 2b91 2b92 2b93
1 2b9e 1 2ba4
2 2ba6 2ba7 1
2baf 2 2bab 2baf
1 2bb4 1 2bb6
1 2bb8 2 2bc0
2bc1 1 2bc5 2
2bc3 2bc5 1 2bcc
2 2bce 2bcf 1
2bd3 2 2bd1 2bd3
1 2bda 1 2bdc
2 2be1 2be2 1
2be6 2 2be4 2be6
1 2beb 2 2be9
2beb 1 2c00 2
2bff 2c00 1 2c08
1 2c0e 2 2c10
2c11 2 2bfd 2c12
1 2c19 1 2c14
2 2c2c 2c2e 3
2c2a 2c2b 2c30 2
2c39 2c3b 2 2c3d
2c3f 2 2c41 2c43
2 2c45 2c47 2
2c49 2c4b 3 2c50
2c51 2c52 2 2c4d
2c54 2 2c38 2c56
1 2c58 1 2c5a
2 2c23 2c5b 1
2c5f 1 2c1e 2
2c1c 2c63 1 2c66
1 2c69 9 2c6a
2c6d 2c70 2c73 2c76
2c79 2c7c 2c7f 2c82
1 2c84 1 2c88
2 2c86 2c88 1
2c8b 1 2c9e 2
2c9d 2c9e 1 2ca6
1 2cac 2 2cae
2caf 2 2c9b 2cb0
1 2cb7 1 2cb2
2 2cca 2ccc 3
2cc8 2cc9 2cce 2
2cd7 2cd9 2 2cdb
2cdd 2 2cdf 2ce1
2 2ce3 2ce5 2
2ce7 2ce9 3 2cee
2cef 2cf0 2 2ceb
2cf2 2 2cd6 2cf4
1 2cf6 1 2cf8
2 2cc1 2cf9 1
2cfd 1 2cbc 2
2cba 2d01 1 2d04
1 2d07 1 2d09
1 2d0e 2 2d15
2d17 3 2d19 2d1a
2d1b 1 2d1e 1
2d20 2 2d24 2d26
3 2d28 2d29 2d2a
2 2d21 2d2d 1
2d2f 1 2d31 2
2d38 2d3a 3 2d3c
2d3d 2d3e 1 2d41
1 2d43 1 2d45
1 2d4a 2 2d51
2d53 3 2d55 2d56
2d57 1 2d5a 1
2d5c 2 2d60 2d62
3 2d64 2d65 2d66
2 2d5d 2d69 1
2d6b 1 2d6d 2
2d74 2d76 3 2d78
2d79 2d7a 1 2d7d
1 2d7f 1 2d81
1 2d86 2 2d8d
2d8f 3 2d91 2d92
2d93 1 2d96 1
2d98 2 2d9c 2d9e
3 2da0 2da1 2da2
2 2d99 2da5 1
2da7 1 2da9 1
2dae 2 2db5 2db7
3 2db9 2dba 2dbb
1 2dbe 1 2dc0
2 2dc4 2dc6 3
2dc8 2dc9 2dca 2
2dc1 2dcd 1 2dcf
2 2dd2 2dd4 e
2b94 2ba8 2bb7 2bdd
2c85 2d08 2d30 2d44
2d6c 2d80 2da8 2dd0
2dd7 2dda 2 2de0
2de6 1 2ded 1
2de8 2 2e00 2e02
3 2dfe 2dff 2e04
2 2e0d 2e0f 2
2e11 2e13 2 2e15
2e17 2 2e19 2e1b
2 2e1d 2e1f 3
2e24 2e25 2e26 2
2e21 2e28 2 2e0c
2e2a 1 2e2c 1
2e2e 2 2df7 2e2f
1 2e33 1 2df2
2 2df0 2e37 1
2e3e 2 2e3c 2e3e
1 2e53 2 2e52
2e53 1 2e5b 1
2e61 2 2e63 2e64
2 2e50 2e65 1
2e6c 1 2e67 2
2e7f 2e81 3 2e7d
2e7e 2e83 2 2e8c
2e8e 2 2e90 2e92
2 2e94 2e96 2
2e98 2e9a 2 2e9c
2e9e 3 2ea3 2ea4
2ea5 2 2ea0 2ea7
2 2e8b 2ea9 1
2eab 1 2ead 2
2e76 2eae 1 2eb2
1 2e71 2 2e6f
2eb6 1 2eb9 1
2ebc 8 2b7b 2b7e
2b81 2b84 2b89 2ddd
2e3a 2ebd 1 2ebf
1 2ec1 2 2ec7
2ec8 1 2ecc 2
2eca 2ecc 2 2edd
2ee2 1 2ee9 1
2ee4 2 2efc 2efe
3 2efa 2efb 2f00
2 2f09 2f0b 2
2f0d 2f0f 2 2f11
2f13 2 2f15 2f17
2 2f19 2f1b 3
2f20 2f21 2f22 2
2f1d 2f24 2 2f08
2f26 1 2f28 1
2f2a 2 2ef3 2f2b
1 2f2f 1 2eee
2 2eec 2f33 1
2f36 2 2f3b 2f3c
2 2f3e 2f3f 1
2f40 1 2f42 2
2f57 2f5c 1 2f63
1 2f5e 2 2f76
2f78 3 2f74 2f75
2f7a 2 2f83 2f85
2 2f87 2f89 2
2f8b 2f8d 2 2f8f
2f91 2 2f93 2f95
3 2f9a 2f9b 2f9c
2 2f97 2f9e 2
2f82 2fa0 1 2fa2
1 2fa4 2 2f6d
2fa5 1 2fa9 1
2f68 2 2f66 2fad
2 2fb3 2fb4 1
2fba 2 2fb6 2fba
1 2fd5 2 2fd4
2fd5 1 2fdd 1
2fe3 2 2fe5 2fe6
2 2fd2 2fe7 1
2fee 1 2fe9 2
3001 3003 3 2fff
3000 3005 2 300e
3010 2 3012 3014
2 3016 3018 2
301a 301c 2 301e
3020 3 3025 3026
3027 2 3022 3029
2 300d 302b 1
302d 1 302f 2
2ff8 3030 1 3034
1 2ff3 2 2ff1
3038 1 3043 2
303f 3043 1 305c
2 305b 305c 1
3064 1 306a 2
306c 306d 2 3059
306e 1 3075 1
3070 2 3088 308a
3 3086 3087 308c
2 3095 3097 2
3099 309b 2 309d
309f 2 30a1 30a3
2 30a5 30a7 3
30ac 30ad 30ae 2
30a9 30b0 2 3094
30b2 1 30b4 1
30b6 2 307f 30b7
1 30bb 1 307a
2 3078 30bf 1
30ca 2 30c6 30ca
1 30d7 2 30d6
30d7 1 30df 1
30e5 2 30e7 30e8
2 30d4 30e9 1
30f0 1 30eb 2
3103 3105 3 3101
3102 3107 2 3110
3112 2 3114 3116
2 3118 311a 2
311c 311e 2 3120
3122 3 3127 3128
3129 2 3124 312b
2 310f 312d 1
312f 1 3131 2
30fa 3132 1 3136
1 30f5 2 30f3
313a 1 313d 1
3140 2 30c2 3141
1 3143 2 3221
3223 3 321f 3220
3225 2 322e 3230
2 322d 3232 1
3234 1 3236 7
2fc1 2fc6 303b 3144
3217 3237 323a 1
323e 2 323c 323e
2 3384 3386 3
3382 3383 3388 2
3391 3393 2 3390
3395 1 3397 1
3399 3 337a 339a
339d 1 33b4 2
33b3 33b4 1 33bc
1 33c2 2 33c4
33c5 2 33b1 33c6
1 33cd 1 33c8
2 33e0 33e2 3
33de 33df 33e4 2
33ed 33ef 2 33f1
33f3 2 33f5 33f7
2 33f9 33fb 2
33fd 33ff 3 3404
3405 3406 2 3401
3408 2 33ec 340a
1 340c 1 340e
2 33d7 340f 1
3413 1 33d2 2
33d0 3417 1 3434
2 3433 3434 1
343c 1 3442 2
3444 3445 2 3431
3446 1 344d 1
3448 2 3460 3462
3 345e 345f 3464
2 346d 346f 2
3471 3473 2 3475
3477 2 3479 347b
2 347d 347f 3
3484 3485 3486 2
3481 3488 2 346c
348a 1 348c 1
348e 2 3457 348f
1 3493 1 3452
2 3450 3497 2
3669 366b 3 3667
3668 366d 2 3676
3678 2 3675 367a
1 367c 1 367e
7 33a3 33a8 341a
349a 365f 367f 3682
2 3684 3685 1
3686 2 3688 3689
3b 4fd 51c 51f
522 525 528 52b
52e 531 534 537
53a 53d 540 543
546 549 54c 54f
552 555 558 55b
55e 561 564 5d7
6e6 764 775 86f
8de 8e1 8f5 902
916 923 95d 12b4
14a8 14c2 169a 1b7d
1b82 1bb3 1bc4 1be5
1be8 1beb 25bd 25c4
25c9 2a86 2ae3 2b73
2ec0 2f43 2fb0 368a
2 3697 3699 3
3695 3696 369b 2
36a4 36a6 2 36a3
36a8 2 36af 36b3
2 36b5 36b7 2
36b9 36bd 2 36ae
36bf 2 36aa 36c1
1 36c3 3 36c4
36cf 36d3 1 368e
2 36e6 36e8 3
36e4 36e5 36ea 2
36f3 36f5 2 36f2
36f7 2 36fe 3700
2 3702 3704 3
3709 370a 370b 2
3706 370d 2 36fd
370f 2 36f9 3711
1 3713 4 36dd
3714 371d 3721 1
3725 1 36d8 2
36d6 3729 6a 7b
82 89 90 97
9e a5 ac b3
ba c1 c8 cf
d6 dd e4 eb
f2 f9 100 107
10c 113 11a 121
128 12f 134 13b
142 149 150 157
15e 164 16a 170
176 17c 182 188
18e 194 19a 1a0
1a6 1ac 1b2 1b8
1be 1c4 1ca 1d0
1d6 1dc 1e2 1e8
1ee 1f4 1fa 200
206 20c 212 218
21e 224 22b 231
237 23d 244 24b
252 258 25e 265
26c 273 27a 281
288 28e 294 29a
2a0 2a6 2ac 2b2
2b8 2bf 2c5 2ca
2cf 2d4 2d9 2de
2e3 2e8 2ef 2ff
31a 324 32b 332
339 
1
4
0 
3730
0
1
a0
67
87
0 1 1 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 1 33 1 35 1 37
1 39 1 3b 3c 1 3e 3f
1 41 42 41 44 41 46 41
48 41 4a 41 4c 1 4e 1
50 51 50 53 1 55 1 57
1 59 1 5b 1 5d 1 5f
1 61 1 63 1 65 1 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

2a8 1 0
6b 1 0
2b 1 0
e6 1 0
25a 1 0
2ae 1 0
220 1 0
bc 1 0
5f 1 0
275 1 0
4b 1 0
28a 1 0
d8 1 0
2ea 1 0
2c1 1 0
1b4 1 0
21a 1 0
18a 1 0
8b 1 0
2a2 1 0
27 1 0
2d1 1 0
2f2 1 2
260 1 0
1f 1 0
53 1 0
202 1 0
a7 1 0
1b 1 0
1f6 1 0
2f 1 0
2b4 1 0
136 1 0
305 1 3
144 1 0
fb 1 0
2a80 41 4e
172 1 0
d1 1 0
13d 1 0
178 1 0
63 1 0
43 1 0
23f 1 0
67 1 0
239 1 0
109 1 0
2c7 1 0
296 1 0
4f 1 0
2db 1 0
1d8 1 0
13 1 0
1ae 1 0
ed 1 0
b5 1 0
1a2 1 0
123 1 0
115 1 0
159 1 0
3f 1 0
24d 1 0
1de 1 0
226 1 0
10e 1 0
ae 1 0
3b 1 0
37 1 0
33 1 0
f 1 0
19c 1 0
31f 1 0
92 1 0
3 1 0
c3 1 0
283 1 0
160 1 0
5b 1 0
32d 1 0
14b 1 0
326 1 0
233 1 0
20e 1 0
12a 1 0
11c 1 0
290 1 0
190 1 0
1fc 1 0
2 0 1
1cc 1 0
1c0 1 0
23 1 0
84 1 0
102 1 0
29c 1 0
214 1 0
7 1 0
1f0 1 0
1a8 1 0
2d6 1 0
196 1 0
a0 1 0
246 1 0
1e4 1 0
17e 1 0
27c 1 0
26e 1 0
208 1 0
166 1 0
254 1 0
22d 1 0
16c 1 0
57 1 0
131 1 0
f4 1 0
7d 1 0
1c6 1 0
ca 1 0
47 1 0
184 1 0
df 1 0
2e0 1 0
1ea 1 0
17 1 0
2e5 1 0
152 1 0
2ba 1 0
1d2 1 0
99 1 0
2cc 1 0
76 1 0
1ba 1 0
b 1 0
334 1 0
267 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_2;
ALTER FUNCTION SP_SEARCH_2 COMPILE DEBUG;
/*#################################################################################################*/
/*#################################################################################################*/
/*
#Stored Procedure  :SP_SEARCH_1
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_SEARCH_1 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_1 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
2b2
2 :e:
1FUNCTION:
1SP_SEARCH_1:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1TYPE001:
1AND_ROLES:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PROJECT_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_TASK_ID:
1H_UNIQUEID:
1H_REC_USER:
1H_RES_ID:
1H_SECURITY_ID:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_FINISH_D:
1H_RES_TYPE:
11:
1H_ASSIGN_ID:
1H_AND_ROLES:
18000:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_FULL_NAME:
1255:
1H_COUNT:
10:
1H_BITFLAG:
1H_TYPE:
1H_WORK_TYPE:
1H_CRI:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_UPDATE:
1H_DAYS:
1H_DURATION:
1H_PARTICIPANT:
1H_PRIORITY:
1H_TOTAL:
1H_TOTPR:
1H_FROM_PRJ:
1H_SCHED_WORK:
1H_JULIAN_DAY:
1H_J_EFECTIVE_DATE:
1H_J_DISCONTI_DATE:
1H_WEEK:
1H_ACTIVE:
1H_REC_STATUS:
1H_RES_COST:
1NUMBER:
1STMT:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_CRI_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TABLE_TYPE:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_TASK_TYPE:
1H_TEMP_VAR:
1ID001:
1I:
1II:
1I_RETURN:
1ISF:
1NUMITEMS:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_1(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1109:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_1(110) :: cplan.sql(2668) :: :
1:
1GETTABLE:
10.00:
1IS NULL:
18:
1150:
1      RETURN_INVALID:: SP_SEARCH_1(151) :: cplan.sql(2709) :: :
1 :
1STATE:: :
1PMO_CNST:
1ELEMENT_ID_REQUIRED:
1153:
1                EXIT:: SP_SEARCH_1(154) :: cplan.sql(2712) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1160:
1      RETURN_INVALID:: SP_SEARCH_1(161) :: cplan.sql(2719) :: :
1163:
1                EXIT:: SP_SEARCH_1(164) :: cplan.sql(2722) :: :
1=:
15:
1170:
1      RETURN_INVALID:: SP_SEARCH_1(171) :: cplan.sql(2729) :: :
1INVALID_PARAMS:
1173:
1                EXIT:: SP_SEARCH_1(174) :: cplan.sql(2732) :: :
1IS NOT NULL:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1191:
1           EXCEPTION:: SP_SEARCH_1(192) :: cplan.sql(2750) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1<:
1198:
1      RETURN_INVALID:: SP_SEARCH_1(199) :: cplan.sql(2757) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1201:
1                EXIT:: SP_SEARCH_1(202) :: cplan.sql(2760) :: :
1ELSIF:
1SELECT SYSTIMESTAMP INTO h_start_date:n         FROM DUAL:
1219:
1           EXCEPTION:: SP_SEARCH_1(220) :: cplan.sql(2778) :: :
1>:
1PMO_STPU:
1STRNPCPY:
133:
1ISPROJECTTYPE:
1!=:
1PROJECT_ID:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2+
1400), PRIORITY:n            INTO h_project_id, h_per_day, h_per_week, h_prior+
1ity:n            FROM TMT_WBS WHERE ELEMENT_ID = h_task_id:
1252:
1           EXCEPTION:: SP_SEARCH_1(253) :: cplan.sql(2811) :: :
1B:
1TYPE_ID:
1TASK_TYPE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1A:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1SELECT B.TYPE_ID, B.TASK_TYPE, B.UNRESOLVED_START, B.UNRESOLVED_FINISH, B.PRO+
1JECT_ID,:n            COALESCE(A.MINUTE_PER_DAY, 480), COALESCE(A.MINUTE_PER_+
1WEEK, 2400), A.PRIORITY:n            INTO h_type, h_task_type, h_task_start_D+
1T, h_task_finish_DT, h_project_id,:n            h_per_day, h_per_week, h_prio+
1rity FROM TMT_WBS A, TMT_WBS B:n            WHERE B.ELEMENT_ID = h_task_id AN+
1D B.TYPE_ID IN (pmo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,pmo_cnst.SC_TASK_TYPE+
12,pmo_cnst.SC_TASK_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.SC_PERSONAL_TASK,pmo_+
1cnst.SC_ACTIVE_ADM_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pmo_cnst.SC_WBS_CHANGE_+
1REQUEST_TASK,pmo_cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.SC_WBS_RISK_TASK,pmo_c+
1nst.SC_WBS_ISSUE_TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,pmo_cnst.SC_WBS_DEFECT+
1_TASK,pmo_cnst.SC_WBS_SERVICE_REQUEST_TASK) AND A.ELEMENT_ID = B.PROJECT_ID:
1271:
1           EXCEPTION:: SP_SEARCH_1(272) :: cplan.sql(2830) :: :
1SC_SQL_NO_DATA:
1WBS_ID:
1TMT_CRI:
1SELECT PROJECT_ID, WBS_ID INTO h_project_id, id001:n            FROM TMT_CRI +
1WHERE ELEMENT_ID = h_task_id:
1289:
1           EXCEPTION:: SP_SEARCH_1(290) :: cplan.sql(2848) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n               INTO h_per_day, h_per_week, h_priority:n               FRO+
1M TMT_WBS WHERE ELEMENT_ID = h_project_id:
1310:
1           EXCEPTION:: SP_SEARCH_1(311) :: cplan.sql(2869) :: :
1316:
1        RETURN_ERROR:: SP_SEARCH_1(317) :: cplan.sql(2875) :: :
1RECORD_NOT_FOUND:
1 ID:: :
1319:
1                EXIT:: SP_SEARCH_1(320) :: cplan.sql(2878) :: :
1PMO_RETURN_ERROR_SP:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1340:
1           EXCEPTION:: SP_SEARCH_1(341) :: cplan.sql(2899) :: :
1REC_STATUS:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1358:
1           EXCEPTION:: SP_SEARCH_1(359) :: cplan.sql(2917) :: :
1STRCMP:
1L:
1365:
1        RETURN_ERROR:: SP_SEARCH_1(366) :: cplan.sql(2924) :: :
1LEV_LOCKED_BY_COPY:
1368:
1                EXIT:: SP_SEARCH_1(369) :: cplan.sql(2927) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n         INTO h_per_day, h_per_week, h_priority:n         FROM TMT_WBS WH+
1ERE ELEMENT_ID = h_project_id:
1386:
1           EXCEPTION:: SP_SEARCH_1(387) :: cplan.sql(2945) :: :
1TMT_POOLS:
1SELECT 480, 2400 INTO h_per_day, h_per_week FROM TMT_POOLS WHERE ELEMENT_ID =+
1 h_project_id:
1401:
1           EXCEPTION:: SP_SEARCH_1(402) :: cplan.sql(2960) :: :
1407:
1        RETURN_ERROR:: SP_SEARCH_1(408) :: cplan.sql(2966) :: :
1410:
1                EXIT:: SP_SEARCH_1(411) :: cplan.sql(2969) :: :
1SC_FD_EFFORT_DRIVEN:
1COUNT:
1TSK_ASSIGNMENT_ID:
1TASK_ASSIGNMENTS:
1TASK_ID:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_temp_var :n         FROM TASK_ASSIGNME+
1NTS:n         WHERE PROJECT_ID = h_project_id:n         AND TASK_ID = h_task_+
1id:
1432:
1           EXCEPTION:: SP_SEARCH_1(433) :: cplan.sql(2991) :: :
1SC_SRCH_PROFILE:
1SC_SRCH_FROM_PROJECT:
17:
1FC_CALC_DURATION:
1457:
1      RETURN_INVALID:: SP_SEARCH_1(458) :: cplan.sql(3016) :: :
1460:
1                EXIT:: SP_SEARCH_1(461) :: cplan.sql(3019) :: :
1465:
1        RETURN_ERROR:: SP_SEARCH_1(466) :: cplan.sql(3024) :: :
1468:
1                EXIT:: SP_SEARCH_1(469) :: cplan.sql(3027) :: :
1*:
1100:
12:
13:
14:
1FC_DECLARE_PMO_TMP_SEARCH:
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1ASSIGNRESOURCE:
1SC_SRCH_PARTICIPANT:
1RECORD_ALREADY_ASSIGNED:
1516:
1        RETURN_ERROR:: SP_SEARCH_1(517) :: cplan.sql(3075) :: :
1519:
1                EXIT:: SP_SEARCH_1(520) :: cplan.sql(3078) :: :
1526:
1        RETURN_ERROR:: SP_SEARCH_1(527) :: cplan.sql(3085) :: :
1529:
1                EXIT:: SP_SEARCH_1(530) :: cplan.sql(3088) :: :
1MIN:
1BAK_START_DT:
1RESOURCE_ID:
1RESOURCE_TYPE:
1SELECT MIN(BAK_START_DT), PMO_ORASTD.DAYS(h_start_date) - PMO_ORASTD.DAYS(MIN+
1(BAK_START_DT)):n         INTO h_start_DT, h_total :n         FROM TASK_ASSIG+
1NMENTS:n         WHERE PROJECT_ID = h_project_id :n         AND TASK_ID = h_p+
1roject_id :n         AND RESOURCE_ID = h_res_id :n         AND RESOURCE_TYPE +
1= h_res_type:
1552:
1           EXCEPTION:: SP_SEARCH_1(553) :: cplan.sql(3111) :: :
1PROJECT_ASSIGNMENT_ID:
1SCHED_START:
1TO_DATE:
1SCHED_FINISH:
1SCHED_WORK:
1BIT_FLAG:
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START, :n               CASE WHEN (TO_DAT+
1E(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AN+
1D TO_DATE(SubStr(SCHED_FINISH, 1, 10)) OR :n               TO_DATE(SubStr(h_f+
1inish_DT, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AND TO_DATE(Sub+
1Str(SCHED_FINISH, 1, 10))) AND :n               SCHED_WORK >= h_effort THEN 0+
1 ELSE 1 END,SCHED_WORK:n               INTO h_prj_assign_id, h_start_DT, h_to+
1tal, h_sched_work:n               FROM TASK_ASSIGNMENTS:n               WHERE+
1 TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_+
1FLAG = '2':
1584:
1           EXCEPTION:: SP_SEARCH_1(585) :: cplan.sql(3143) :: :
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_WORK:
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, :n                     CASE WHEN+
1 (TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, +
11, 10)) AND TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) OR :n                     +
1TO_DATE(SubStr(h_finish_DT, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, +
110)) AND TO_DATE(SubStr(PLANNED_FINISH, 1, 10))) AND :n                     P+
1LANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                     INTO h_prj_as+
1sign_id, h_start_DT, h_total:n                     FROM TASK_ASSIGNMENTS:n   +
1                  WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RES+
1OURCE_TYPE='0' AND BIT_FLAG = '0':
1608:
1           EXCEPTION:: SP_SEARCH_1(609) :: cplan.sql(3167) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, :n                  CASE WHEN (T+
1O_DATE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, +
110)) AND TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) OR :n                  TO_DAT+
1E(SubStr(h_finish_DT, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) A+
1ND TO_DATE(SubStr(PLANNED_FINISH, 1, 10))) AND :n                  PLANNED_WO+
1RK >= h_effort THEN 0 ELSE 1 END:n                  INTO h_prj_assign_id, h_s+
1tart_DT, h_total:n                  FROM TASK_ASSIGNMENTS:n                  +
1WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND+
1 BIT_FLAG = '0':
1632:
1           EXCEPTION:: SP_SEARCH_1(633) :: cplan.sql(3191) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, :n               CASE WHEN(TO_DA+
1TE(SubStr(h_start_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10))+
1 AND TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) OR :n               TO_DATE(SubSt+
1r(h_finish_DT, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_D+
1ATE(SubStr(PLANNED_FINISH, 1, 10))) AND :n               PLANNED_WORK >= h_ef+
1fort THEN 0 ELSE 1 END:n               INTO h_prj_assign_id, h_start_DT, h_to+
1tal:n               FROM TASK_ASSIGNMENTS:n               WHERE TASK_ID=h_pro+
1ject_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1' AND BIT_FLAG = '0':
1654:
1           EXCEPTION:: SP_SEARCH_1(655) :: cplan.sql(3213) :: :
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START,CASE WHEN TO_DATE(SubStr(h_start_da+
1te, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AND TO_DATE(SubStr(SC+
1HED_FINISH, 1, 10)) AND h_effort <= SCHED_WORK THEN 0 ELSE 1 END, SCHED_WORK+
1:n               INTO h_prj_assign_id, h_start_DT,h_total, h_sched_work :n   +
1            FROM TASK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_id +
1AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
1674:
1           EXCEPTION:: SP_SEARCH_1(675) :: cplan.sql(3233) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLAN+
1NED_WORK THEN 0 ELSE 1 END:n                     INTO h_prj_assign_id, h_star+
1t_DT,h_total :n                     FROM TASK_ASSIGNMENTS:n                  +
1   WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' +
1AND BIT_FLAG = '0':
1695:
1           EXCEPTION:: SP_SEARCH_1(696) :: cplan.sql(3254) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1               INTO h_prj_assign_id, h_start_DT,h_total :n                  F+
1ROM TASK_ASSIGNMENTS:n                  WHERE TASK_ID=h_project_id AND RESOUR+
1CE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
1717:
1           EXCEPTION:: SP_SEARCH_1(718) :: cplan.sql(3276) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1            INTO h_prj_assign_id, h_start_DT,h_total :n               FROM TA+
1SK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_r+
1es_id AND RESOURCE_TYPE='1' AND BIT_FLAG = '0':
1736:
1           EXCEPTION:: SP_SEARCH_1(737) :: cplan.sql(3295) :: :
1746:
1        RETURN_ERROR:: SP_SEARCH_1(747) :: cplan.sql(3305) :: :
1TASK_ASSIGNMENT_ERROR:
1749:
1                EXIT:: SP_SEARCH_1(750) :: cplan.sql(3308) :: :
1SUM:
1SCHED_MIN:
1TASK_DAY_OF_YEAR:
1DAY_YEAR:
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                  FROM TASK_DAY_OF_+
1YEAR:n                  WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID+
1 = h_prj_assign_id :n                  AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_+
1start_date, 1, 10)) AND TO_DATE(SubStr(h_finish_DT, 1, 10)):
1768:
1           EXCEPTION:: SP_SEARCH_1(769) :: cplan.sql(3327) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                  FROM TASK_DAY_OF_+
1YEAR:n                  WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID+
1 = h_prj_assign_id :n                  AND DAY_YEAR >= TO_DATE(SubStr(h_start+
1_date, 1, 10)):
1787:
1           EXCEPTION:: SP_SEARCH_1(788) :: cplan.sql(3346) :: :
1795:
1        RETURN_ERROR:: SP_SEARCH_1(796) :: cplan.sql(3354) :: :
1798:
1                EXIT:: SP_SEARCH_1(799) :: cplan.sql(3357) :: :
1ISNOTPROJECTTYPE:
1806:
1        RETURN_ERROR:: SP_SEARCH_1(807) :: cplan.sql(3365) :: :
1809:
1                EXIT:: SP_SEARCH_1(810) :: cplan.sql(3368) :: :
1NICK_NAME:
1JULIAN_DAY:
1ACTIVE:
1EFFECTIVE_DATE:
1DISCONTINUE_DATE:
1RESOURCES:
1SELECT NICK_NAME, PMO_ORASTD.JULIAN_DAY(h_start_DT), ACTIVE, COALESCE(PMO_ORA+
1STD.JULIAN_DAY(EFFECTIVE_DATE),0),COALESCE(PMO_ORASTD.JULIAN_DAY(DISCONTINUE_+
1DATE),0):n            INTO h_full_name, h_julian_day, h_active, h_j_efective_+
1date, h_j_disconti_date:n            FROM RESOURCES :n            WHERE RESOU+
1RCE_ID = h_res_id:
1830:
1           EXCEPTION:: SP_SEARCH_1(831) :: cplan.sql(3389) :: :
1837:
1        RETURN_ERROR:: SP_SEARCH_1(838) :: cplan.sql(3396) :: :
1840:
1                EXIT:: SP_SEARCH_1(841) :: cplan.sql(3399) :: :
1848:
1        RETURN_ERROR:: SP_SEARCH_1(849) :: cplan.sql(3407) :: :
1RESOURCE_NOT_ACTIVE:
1851:
1                EXIT:: SP_SEARCH_1(852) :: cplan.sql(3410) :: :
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_assign_id, h_partic+
1ipant, h_security_id:n            FROM RESOURCE_ASSIGNMENTS:n            WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_TYPE = '0' AND RESOURCE_ID = h_res_id:
1868:
1           EXCEPTION:: SP_SEARCH_1(869) :: cplan.sql(3427) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME INTO h_full_name FROM PROFILES WHERE PROFILE_ID = h_res_i+
1d:
1885:
1           EXCEPTION:: SP_SEARCH_1(886) :: cplan.sql(3444) :: :
1892:
1        RETURN_ERROR:: SP_SEARCH_1(893) :: cplan.sql(3451) :: :
1895:
1                EXIT:: SP_SEARCH_1(896) :: cplan.sql(3454) :: :
1BAK_FINISH_DT:
1BAK_WORK:
1SELECT BAK_START_DT, CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) BETWEEN T+
1O_DATE(SubStr(BAK_START_DT, 1, 10)) AND TO_DATE(SubStr(BAK_FINISH_DT, 1, 10))+
1 AND BAK_WORK >= h_effort THEN 0 ELSE 1 END:n            INTO h_start_DT, h_t+
1otal :n            FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project+
1_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1':
1913:
1           EXCEPTION:: SP_SEARCH_1(914) :: cplan.sql(3472) :: :
1920:
1        RETURN_ERROR:: SP_SEARCH_1(921) :: cplan.sql(3479) :: :
1923:
1                EXIT:: SP_SEARCH_1(924) :: cplan.sql(3482) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_assign_id, h_partic+
1ipant, h_security_id:n            FROM RESOURCE_ASSIGNMENTS:n            WHER+
1E ELEMENT_ID = h_task_id AND RESOURCE_TYPE = '1' AND RESOURCE_ID = h_res_id:
1940:
1           EXCEPTION:: SP_SEARCH_1(941) :: cplan.sql(3499) :: :
1DB2TIMESTAMP:
1TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_DT, 1, 10)), PMO_ORASTD+
1.TIME(h_start_date)) INTO h_start_DT:n            FROM DUAL:
1960:
1           EXCEPTION:: SP_SEARCH_1(961) :: cplan.sql(3519) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) > TO_DATE(SubStr(h_star+
1t_DT, 1, 10)) THEN h_start_date:n            ELSE h_start_DT END:n           +
1 INTO h_start_DT:n            FROM DUAL:
1978:
1           EXCEPTION:: SP_SEARCH_1(979) :: cplan.sql(3537) :: :
110:
1FC_SEARCH_2:
1PMO_TMP_SEARCH:
1PLANNED_SCHED_FLAG:
1RES_ID:
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='0' WHERE RES_ID=h_res_id:
1FOUND:
11011:
1           EXCEPTION:: SP_SEARCH_1(1012) :: cplan.sql(3570) :: :
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='1' WHERE RES_ID=h_res_id:
11030:
1           EXCEPTION:: SP_SEARCH_1(1031) :: cplan.sql(3589) :: :
11068:
1           EXCEPTION:: SP_SEARCH_1(1069) :: cplan.sql(3627) :: :
1LENGTH:
1TRUNC:
1/:
1WHILE:
1LOOP:
1PROPOSED_START:
1SELECT COUNT(*), MIN(PROPOSED_START) INTO h_total, h_start_DT :n             +
1  FROM TASK_ASSIGNMENTS:n               WHERE PROJECT_ID = h_project_id AND T+
1ASK_ID = h_project_id:n               AND RESOURCE_ID = h_res_id AND RESOURCE+
1_TYPE = h_res_type:
11110:
1           EXCEPTION:: SP_SEARCH_1(1111) :: cplan.sql(3669) :: :
1',':
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START, CASE WHEN TO_DATE(SubStr(h_start_d+
1ate, 1, 10)) >= TO_DATE(SubStr(SCHED_START, 1, 10)) AND:n                    +
1    TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(SCHED_FINISH, 1, 10+
1)) AND SCHED_WORK >= h_effort THEN 0 ELSE 1 END,SCHED_WORK:n                 +
1       INTO h_prj_assign_id, h_start_DT, h_total, h_sched_work:n             +
1           FROM TASK_ASSIGNMENTS:n                        WHERE TASK_ID=h_pro+
1ject_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '2':
11159:
1           EXCEPTION:: SP_SEARCH_1(1160) :: cplan.sql(3718) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1              TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_F+
1INISH, 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n              +
1                INTO h_prj_assign_id, h_start_DT, h_total :n                 +
1             FROM TASK_ASSIGNMENTS:n                              WHERE TASK_+
1ID=h_project_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG =+
1 '0':
11181:
1           EXCEPTION:: SP_SEARCH_1(1182) :: cplan.sql(3740) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1           TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINI+
1SH, 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                 +
1          INTO h_prj_assign_id, h_start_DT, h_total :n                       +
1    FROM TASK_ASSIGNMENTS:n                           WHERE TASK_ID=h_project+
1_id AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
11203:
1           EXCEPTION:: SP_SEARCH_1(1204) :: cplan.sql(3762) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) >= TO_DATE(SubStr(PLANNED_START, 1, 10)) AND:n                +
1        TO_DATE(SubStr(h_finish_DT, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH,+
1 1, 10)) AND PLANNED_WORK >= h_effort THEN 0 ELSE 1 END:n                    +
1    INTO h_prj_assign_id, h_start_DT, h_total FROM TASK_ASSIGNMENTS:n        +
1                WHERE PROJECT_ID = h_project_id AND TASK_ID=h_project_id:n   +
1                     AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='1' AND BIT_F+
1LAG = '0':
11223:
1           EXCEPTION:: SP_SEARCH_1(1224) :: cplan.sql(3782) :: :
1SELECT PROJECT_ASSIGNMENT_ID, SCHED_START,CASE WHEN TO_DATE(SubStr(h_start_da+
1te, 1, 10)) BETWEEN TO_DATE(SubStr(SCHED_START, 1, 10)) AND TO_DATE(SubStr(SC+
1HED_FINISH, 1, 10)) AND h_effort <= SCHED_WORK THEN 0 ELSE 1 END, SCHED_WORK+
1:n                        INTO h_prj_assign_id, h_start_DT,h_total, h_sched_w+
1ork FROM TASK_ASSIGNMENTS:n                        WHERE PROJECT_ID = h_proje+
1ct_id AND TASK_ID=h_project_id:n                        AND RESOURCE_ID=h_res+
1_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
11243:
1           EXCEPTION:: SP_SEARCH_1(1244) :: cplan.sql(3802) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) <= TO_DATE(SubStr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLAN+
1NED_WORK THEN 0 ELSE 1 END:n                              INTO h_prj_assign_i+
1d, h_start_DT,h_total FROM TASK_ASSIGNMENTS:n                              WH+
1ERE PROJECT_ID = h_project_id AND TASK_ID=h_project_id:n                     +
1         AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG = '0':
11263:
1           EXCEPTION:: SP_SEARCH_1(1264) :: cplan.sql(3822) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START, CASE WHEN TO_DATE(SubStr(h_start+
1_date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubS+
1tr(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n  +
1                         INTO h_prj_assign_id, h_start_DT,h_total FROM TASK_A+
1SSIGNMENTS:n                           WHERE PROJECT_ID = h_project_id AND TA+
1SK_ID=h_project_id:n                           AND RESOURCE_ID=h_res_id AND R+
1ESOURCE_TYPE='0' AND BIT_FLAG = '0':
11285:
1           EXCEPTION:: SP_SEARCH_1(1286) :: cplan.sql(3844) :: :
1SELECT PROJECT_ASSIGNMENT_ID, PLANNED_START,CASE WHEN TO_DATE(SubStr(h_start_+
1date, 1, 10)) BETWEEN TO_DATE(SubStr(PLANNED_START, 1, 10)) AND TO_DATE(SubSt+
1r(PLANNED_FINISH, 1, 10)) AND h_effort <= PLANNED_WORK THEN 0 ELSE 1 END:n   +
1                     INTO h_prj_assign_id, h_start_DT,h_total FROM TASK_ASSIG+
1NMENTS:n                        WHERE PROJECT_ID = h_project_id AND TASK_ID=h+
1_project_id:n                        AND RESOURCE_ID=h_res_id AND RESOURCE_TY+
1PE='1' AND BIT_FLAG = '0':
11304:
1           EXCEPTION:: SP_SEARCH_1(1305) :: cplan.sql(3863) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                              FROM +
1TASK_DAY_OF_YEAR:n                              WHERE PROJECT_ID = h_project_+
1id AND TSK_ASSIGNMENT_ID = h_prj_assign_id :n                              AN+
1D DAY_YEAR BETWEEN TO_DATE(SubStr(h_start_date, 1, 10)) AND TO_DATE(SubStr(h_+
1finish_DT, 1, 10)):
11331:
1           EXCEPTION:: SP_SEARCH_1(1332) :: cplan.sql(3890) :: :
1SELECT SUM(SCHED_MIN) INTO h_sched_work :n                              FROM +
1TASK_DAY_OF_YEAR:n                              WHERE PROJECT_ID = h_project_+
1id AND TSK_ASSIGNMENT_ID = h_prj_assign_id :n                              AN+
1D DAY_YEAR >= TO_DATE(SubStr(h_start_date, 1, 10)):
11350:
1           EXCEPTION:: SP_SEARCH_1(1351) :: cplan.sql(3909) :: :
1CONTINUE0000:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_DT, 1, 10)), PMO_ORASTD+
1.TIME(h_start_date)):n                  INTO h_start_DT:n                  FR+
1OM DUAL:
11382:
1           EXCEPTION:: SP_SEARCH_1(1383) :: cplan.sql(3941) :: :
1SELECT CASE WHEN TO_DATE(SubStr(h_start_date, 1, 10)) > TO_DATE(SubStr(h_star+
1t_DT, 1, 10)) THEN h_start_date ELSE h_start_DT END:n                  INTO h+
1_start_DT:n                  FROM DUAL:
11399:
1           EXCEPTION:: SP_SEARCH_1(1400) :: cplan.sql(3958) :: :
11432:
1           EXCEPTION:: SP_SEARCH_1(1433) :: cplan.sql(3991) :: :
11451:
1           EXCEPTION:: SP_SEARCH_1(1452) :: cplan.sql(4010) :: :
11487:
1           EXCEPTION:: SP_SEARCH_1(1488) :: cplan.sql(4046) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
11517:
1           EXCEPTION:: SP_SEARCH_1(1518) :: cplan.sql(4076) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET SECURITY_ID = h_security_id, PARTICIPANT = h_+
1participant:n            WHERE RES_ASSIGNMENT_ID = h_assign_id:
11537:
1           EXCEPTION:: SP_SEARCH_1(1538) :: cplan.sql(4096) :: :
11545:
1        RETURN_ERROR:: SP_SEARCH_1(1546) :: cplan.sql(4104) :: :
11548:
1                EXIT:: SP_SEARCH_1(1549) :: cplan.sql(4107) :: :
1CANNOT_ASSIGN_TO_DEFAULT_CRI:
11553:
1        RETURN_ERROR:: SP_SEARCH_1(1554) :: cplan.sql(4112) :: :
11556:
1                EXIT:: SP_SEARCH_1(1557) :: cplan.sql(4115) :: :
1CANNOT_CHANGE_OBJECT_TYPE:
11562:
1        RETURN_ERROR:: SP_SEARCH_1(1563) :: cplan.sql(4121) :: :
11565:
1                EXIT:: SP_SEARCH_1(1566) :: cplan.sql(4124) :: :
11571:
1        RETURN_ERROR:: SP_SEARCH_1(1572) :: cplan.sql(4130) :: :
11574:
1                EXIT:: SP_SEARCH_1(1575) :: cplan.sql(4133) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN_0003:
1INSERT INTO PMO_TMP_CPLN_0003 SELECT RESOURCE_ID, RESOURCE_TYPE, :
1 MIN(PLANNED_START) AS PLANNED_START,  MAX(PLANNED_FINISH) AS PLANNED_FINISH,+
1 :
1 SUM(PLANNED_WORK) AS PLANNED_EFFORT,  MIN(SCHED_START) AS START_DATE,  :
1 MAX(SCHED_FINISH) AS FINISH_DATE,     SUM(SCHED_WORK) AS WORK,  :
1 SUM(ETC) AS REMAINING :
1 FROM TASK_ASSIGNMENTS WHERE PROJECT_ID=':
1' AND :
1      (RESOURCE_ID IN (':
1') OR RESOURCE_ID IN (':
1')) GROUP BY RESOURCE_ID, RESOURCE_TYPE :
11608:
1           EXCEPTION:: SP_SEARCH_1(1609) :: cplan.sql(4167) :: :
1SQL :: :
1DELETE FROM PMO_TMP_CPLN_0002:
1INSERT INTO PMO_TMP_CPLN_0002 SELECT RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,MIN+
1(PLANNED_START) AS PRJ_PLANNED_START, :
1 MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH,  SUM(PLANNED_WORK) AS PLANNED_REM+
1AINING, :
1 MIN(SCHED_START) AS PRJ_SCHED_START,        MAX(SCHED_FINISH) AS PRJ_SCHED_F+
1INISH, :
1 SUM(SCHED_WORK) AS SCHED_REMAINING  :
1 FROM TASK_ASSIGNMENTS :
1 WHERE TASK_ID=':
1 (RESOURCE_ID IN (':
1')) GROUP BY RESOURCE_ID :
11642:
1           EXCEPTION:: SP_SEARCH_1(1643) :: cplan.sql(4201) :: :
1FC_U_CREATETMPTABLE:
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME,RESOURCE_TYPE,TYPE_ID+
1,E_MAIL_ADDRESS,PLANNED_START,:
1PLANNED_FINISH,PLANNED_EFFORT,START_DATE,FINISH_DATE,WORK,REMAINING,BEST_STAR+
1T,BEST_FINISH,:
1ASSIGNABLE,PLANNED,SCHED,WORK_EFFORT,PERIOD_AVAILABILITY,PROJECT_ASSIGNMENT_I+
1D,PRJ_PLANNED_START,:
1PRJ_PLANNED_FINISH,PLANNED_REMAINING,PRJ_SCHED_START,PRJ_SCHED_FINISH,SCHED_R+
1EMAINING,REGULAR_COST,:
1REGULAR_RATE,SPECIAL_COST,SPECIAL_RATE, EXTERNAL_ID) :
1SELECT DISTINCT r.RESOURCE_ID,r.FULL_NAME AS ELEMENT_NAME,'0',:
1CASE WHEN ta.TSK_ASSIGNMENT_ID IS NuLL THEN 185 ELSE 13 END AS TYPE_ID,:
1r.E_MAIL_ADDRESS, a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.STAR+
1T_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,:
1rs.START_DATE, rs.FINISH_DATE, rs.ASSIGNABLE, rs.PLANNED, rs.SCHED, rs.PROPOS+
1ED, (rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) ,:
1tb.PROJECT_ASSIGNMENT_ID,tb.PRJ_PLANNED_START, tb.PRJ_PLANNED_FINISH, tb.PLAN+
1NED_REMAINING,:
1tb.PRJ_SCHED_START, tb.PRJ_SCHED_FINISH, tb.SCHED_REMAINING, pa.REGULAR_COST,+
1 pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE, r.EXTERNAL_ID :
1FROM RESOURCES r LEFT OUTER JOIN PMO_TMP_CPLN_0003 a ON a.RESOURCE_TYPE='0' A+
1ND a.RESOURCE_ID=r.RESOURCE_ID :
1LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID=':
1' AND r.RESOURCE_ID = pa.RESOURCE_ID :
1LEFT OUTER JOIN TASK_ASSIGNMENTS ta ON ta.PROJECT_ID=':
1' AND r.RESOURCE_ID = ta.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_CPLN_0002 tb ON r.RESOURCE_ID = tb.PROJECT_ASSIGNMENT+
1_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON r.RESOURCE_ID=rs.RES_ID WHERE r.RESOURCE+
1_ID IN (':
1') :
1UNION ALL :
1SELECT DISTINCT p.PROFILE_ID , p.PROFILE_NAME AS ELEMENT_NAME, '1', 41 AS TYP+
1E_ID,:
1'', a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.START_DATE, a.FINI+
1SH_DATE, a.WORK, a.REMAINING,:
1rs.START_DATE , rs.FINISH_DATE, rs.ASSIGNABLE ,rs.PLANNED,rs.SCHED, rs.PROPOS+
1ED,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) ,:
1tb.PRJ_SCHED_START, tb.PRJ_SCHED_FINISH, tb.SCHED_REMAINING, pa.REGULAR_COST,+
1 pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE, '' AS EXTERNAL_ID :
1FROM PROFILES p LEFT OUTER JOIN PMO_TMP_CPLN_0003 a ON a.RESOURCE_TYPE='1' AN+
1D p.PROFILE_ID=a.RESOURCE_ID :
1LEFT OUTER JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID= ':
1' AND p.PROFILE_ID = pa.RESOURCE_ID :
1JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=p.ROLE_ID :
1JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID LEFT OUTER JOIN PMO_TMP_S+
1EARCH rs ON a.RESOURCE_ID=rs.RES_ID :
1LEFT OUTER JOIN PMO_TMP_CPLN_0002 tb ON p.PROFILE_ID = tb.PROJECT_ASSIGNMENT_+
1ID :
1WHERE p.PROFILE_ID IN (':
1ORDER BY TYPE_ID,ELEMENT_NAME:
11699:
1           EXCEPTION:: SP_SEARCH_1(1700) :: cplan.sql(4258) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME AS ELEMENT_NAME,+
1 T.TYPE_ID AS TYPE_ID, :
1 T.E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T.STA+
1RT_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1 T.BEST_START, T.BEST_FINISH, T.ASSIGNABLE AS CALENDAR,T.PLANNED AS PLANNED_W+
1ORK,:
1 T.SCHED AS SCHED_WORK, T.WORK_EFFORT, :
1 AS UNIT_EFFORT,T.PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED_+
1REMAINING, :
1T.PRJ_SCHED_START, T.PRJ_SCHED_FINISH, T.SCHED_REMAINING, T.REGULAR_COST, T.R+
1EGULAR_RATE, T.SPECIAL_COST, T.SPECIAL_RATE, T.EXTERNAL_ID, :
1 r.LOGON_NAME, r.NICK_NAME, r.E_MAIL_ADDRESS AS RESOURCE_E_MAIL,r.WORK_LOCATI+
1ON, r.WORK_PHONE :
1 FROM PMO_TMP_CPLN01_TEMP T:
1 LEFT JOIN RESOURCES r ON r.RESOURCE_ID = T.ELEMENT_ID :
1 LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=rs.RES_ID WHERE T.RESOURCE+
1_TYPE IN ('0') :
1 UNION ALL :
1 SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME, T.TYPE_ID, :
1 '' AS E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T+
1.START_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1 T.BEST_START, T.BEST_FINISH, T.ASSIGNABLE AS CALENDAR, :
1 T.PLANNED AS PLANNED_WORK,T.SCHED AS SCHED_WORK, T.WORK_EFFORT, :
1 AS UNIT_EFFORT, :
1 T.PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING,'' AS OBJECTIVES,'' AS RANK, :
1 T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED+
1_REMAINING, :
1  T.PRJ_SCHED_START, T.PRJ_SCHED_FINISH, T.SCHED_REMAINING, T.REGULAR_COST, T+
1.REGULAR_RATE, T.SPECIAL_COST, T.SPECIAL_RATE, T.EXTERNAL_ID, :
1 '' AS LOGON_NAME, '' AS NICK_NAME, '' AS RESOURCE_E_MAIL, 0 AS WORK_LOCATION+
1, '' AS WORK_PHONE :
1 FROM PMO_TMP_CPLN01_TEMP T LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID+
1=rs.RES_ID :
1 WHERE T.RESOURCE_TYPE = '1' ORDER BY TYPE_ID,ELEMENT_NAME:
1DELETE FROM PMO_TMP_CPLN_0001:
1INSERT INTO PMO_TMP_CPLN_0001 :
1SELECT  RESOURCE_ID, MIN(PLANNED_START) AS PLANNED_START, :
1 MAX(PLANNED_FINISH) AS PLANNED_FINISH,   SUM(PLANNED_WORK) AS PLANNED_EFFORT+
1, :
1 MIN(SCHED_START) AS START_DATE,          MAX(SCHED_FINISH) AS FINISH_DATE, :
1 SUM(SCHED_WORK) AS WORK,                 SUM(ETC) AS REMAINING :
1 RESOURCE_ID IN (':
1') AND PROJECT_ID<>TASK_ID GROUP BY RESOURCE_ID:
11763:
1           EXCEPTION:: SP_SEARCH_1(1764) :: cplan.sql(4322) :: :
1INSERT INTO PMO_TMP_CPLN_0002 :
1SELECT RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,      MIN(PLANNED_START) AS PRJ_P+
1LANNED_START, :
1 MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH, SUM(PLANNED_WORK) AS PLANNED_REMA+
1INING, :
1 MIN(SCHED_START) AS PRJ_SCHED_START,       MAX(SCHED_FINISH) AS PRJ_SCHED_FI+
1NISH, :
1 SUM(SCHED_WORK) AS SCHED_REMAINING :
1 FROM TASK_ASSIGNMENTS WHERE TASK_ID=':
1' AND RESOURCE_ID IN (':
1') GROUP BY RESOURCE_ID:
11795:
1           EXCEPTION:: SP_SEARCH_1(1796) :: cplan.sql(4354) :: :
1PLANNED_FINISH,PLANNED_EFFORT,START_DATE,FINISH_DATE,WORK,REMAINING,PROJECT_A+
1SSIGNMENT_ID,PRJ_PLANNED_START,:
1REGULAR_RATE,SPECIAL_COST,SPECIAL_RATE, EXTERNAL_ID):
1SELECT DISTINCT r.RESOURCE_ID, r.FULL_NAME,'0',CASE WHEN ta.TSK_ASSIGNMENT_ID+
1 IS NuLL THEN 185 ELSE 13 END ,:
1tb.PROJECT_ASSIGNMENT_ID, tb.PRJ_PLANNED_START, tb.PRJ_PLANNED_FINISH, tb.PLA+
1NNED_REMAINING,:
1FROM RESOURCES r LEFT OUTER JOIN PMO_TMP_CPLN_0001 a ON a.RESOURCE_ID=r.RESOU+
1RCE_ID :
1WHERE r.RESOURCE_ID IN (':
1'):
11833:
1           EXCEPTION:: SP_SEARCH_1(1834) :: cplan.sql(4392) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME AS ELEMENT_NAME,+
1 T.TYPE_ID, :
1T.E_MAIL_ADDRESS, T.PLANNED_START, T.PLANNED_FINISH, T.PLANNED_EFFORT, T.STAR+
1T_DATE, T.FINISH_DATE, T.WORK, T.REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR,rs.PLANNED AS PLANNED_WORK, :
1rs.SCHED AS SCHED_WORK, rs.PROPOSED AS WORK_EFFORT, :
1 AS UNIT_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILIT+
1Y, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1T.PROJECT_ASSIGNMENT_ID, T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED+
1_REMAINING, :
1r.LOGON_NAME, r.NICK_NAME, r.E_MAIL_ADDRESS AS RESOURCE_E_MAIL,r.WORK_LOCATIO+
1N, r.WORK_PHONE :
1 FROM PMO_TMP_CPLN01_TEMP T :
1 LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=rs.RES_ID :
1 ORDER BY ELEMENT_NAME:
1SELECT RESOURCE_ID, MIN(PLANNED_START) AS PLANNED_START, :
1       MAX(PLANNED_FINISH) AS PLANNED_FINISH,    SUM(PLANNED_WORK) AS PLANNED+
1_EFFORT, :
1       MIN(SCHED_START) AS START_DATE,           MAX(SCHED_FINISH) AS FINISH_+
1DATE, :
1       SUM(SCHED_WORK) AS WORK,                  SUM(ETC) AS REMAINING :
1 WHERE PROJECT_ID=':
1'        AND :
1       RESOURCE_ID IN (':
1')   AND :
1       PROJECT_ID<>TASK_ID GROUP BY RESOURCE_ID :
11883:
1           EXCEPTION:: SP_SEARCH_1(1884) :: cplan.sql(4442) :: :
1SELECT    RESOURCE_ID AS PROJECT_ASSIGNMENT_ID,          MIN(PLANNED_START) A+
1S PRJ_PLANNED_START, :
1          MAX(PLANNED_FINISH) AS PRJ_PLANNED_FINISH,     SUM(PLANNED_WORK) AS+
1 PLANNED_REMAINING, :
1          MIN(SCHED_START) AS PRJ_SCHED_START,           MAX(SCHED_FINISH) AS+
1 PRJ_SCHED_FINISH, :
1          SUM(SCHED_WORK) AS SCHED_REMAINING  :
1') GROUP BY RESOURCE_ID :
11915:
1           EXCEPTION:: SP_SEARCH_1(1916) :: cplan.sql(4474) :: :
1REGULAR_RATE,SPECIAL_COST,SPECIAL_RATE) :
1SELECT DISTINCT p.PROFILE_ID , p.PROFILE_NAME ,'1', 41 ,:
1'' , a.PLANNED_START, a.PLANNED_FINISH, a.PLANNED_EFFORT, a.START_DATE, a.FIN+
1ISH_DATE, a.WORK, a.REMAINING,:
1tb.PRJ_SCHED_START, tb.PRJ_SCHED_FINISH, tb.SCHED_REMAINING, pa.REGULAR_COST,+
1 pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RATE :
1FROM PROFILES p LEFT OUTER JOIN PMO_TMP_CPLN_0001 a ON p.PROFILE_ID=a.RESOURC+
1E_ID JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=p.ROLE_ID :
1JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID :
11953:
1           EXCEPTION:: SP_SEARCH_1(1954) :: cplan.sql(4512) :: :
1SELECT T.ELEMENT_ID, '' AS RES_ASSIGNMENT_ID, T.ELEMENT_NAME, T.TYPE_ID, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR, :
1rs.PLANNED AS PLANNED_WORK,rs.SCHED AS SCHED_WORK, rs.PROPOSED AS WORK_EFFORT+
1, :
1(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,+
1  :
1T.PROJECT_ASSIGNMENT_ID,T.PRJ_PLANNED_START, T.PRJ_PLANNED_FINISH, T.PLANNED_+
1REMAINING, :
1FROM PMO_TMP_CPLN01_TEMP T :
1LEFT JOIN RESOURCES r ON r.RESOURCE_ID = T.ELEMENT_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON T.ELEMENT_ID=rs.RES_ID :
1ORDER BY ELEMENT_NAME:
11982:
1                EXIT:: SP_SEARCH_1(1983) :: cplan.sql(4541) :: :
11985:
1                EXIT:: SP_SEARCH_1(1986) :: cplan.sql(4544) :: :
1PMO_SELECT_READ:
1RETURN_ERROR_EXCEPTION:
11993:
1           EXCEPTION:: SP_SEARCH_1(1994) :: cplan.sql(4552) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
12005:
1           EXCEPTION:: SP_SEARCH_1(2006) :: cplan.sql(4564) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
3392
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 81 b0 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d a0 6e d a0 4d d :4 a0
51 a5 b a5 b d a0 51
d a0 51 d a0 51 d a0
7e b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 b7 19 3c a0 7e
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e a 10 :2 a0
51 a5 b 7e 51 b4 2e a
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a a 10 :8 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 b7 19 3c a0
51 d a0 b7 a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a a 10
:3 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 d a0
7e b4 2e 5a a0 6e d b7
19 3c :3 a0 :2 51 a5 b d :3 a0
:2 51 a5 b d :2 a0 d :2 a0 51
a5 b 7e 51 b4 2e :4 a0 :2 51
a5 b :2 51 a5 b d :3 a0 6b
:3 51 a0 a5 b d :3 a0 51 a5
b a5 b 7e 51 b4 2e :d a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :45 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
:7 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 7e b4 2e 5a
a0 51 d b7 19 3c :b a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c b7 a0 51 d b7
:2 19 3c a0 51 d :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 6e a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 19 3c
b7 :b a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 19 3c b7 :2 19 3c :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :8 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 51 a5 b a0 7e a0 6b
b4 2e a 10 a0 51 d b7
19 3c a0 51 d a0 51 d
b7 19 3c b7 a0 7e 51 b4
2e :2 a0 d :2 a0 d :6 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :2 a0 51 a5
b :2 a0 51 a5 b :3 a0 a5 b
d :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 :2 19 3c :2 a0
d a0 7e b4 2e 5a a0 6e
d b7 19 3c b7 :2 a0 d :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d b7 19 3c b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 a0 51 d a0 b7 :2 a0 51
a5 b 7e 51 b4 2e a0 51
d a0 b7 19 :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a 52 10
a0 51 d a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e a0 51
d b7 :2 19 3c b7 19 3c b7
:2 19 3c :2 a0 b4 2e d a0 6e
d a0 6e d :3 a0 6b :3 a0 51
a5 b :2 a0 6b a5 b 5a 51
a5 b d :4 a0 51 a5 b :2 a0
6b a5 b d :2 a0 51 a5 b
7e 51 b4 2e :8 a0 a5 b d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :3 a0 6b d b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 51 a5 b :2 a0 a5 57
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 51
a5 b :2 a0 a5 57 b7 19 3c
a0 4d d :14 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a a0 7e
b4 2e :2 5a a 10 a0 51 d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 d b7 19 3c b7 19 3c
a0 51 d a0 51 d a0 7e
51 b4 2e :2 a0 :2 51 a5 b 7e
6e b4 2e :22 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a a0 51
d :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 :20 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
a0 51 d b7 :2 19 3c a0 b7
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 :20 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :20 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:2 a0 :2 51 a5 b 7e 6e b4 2e
:19 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 51 d :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
52 10 :14 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a0 51 d
4f b7 :2 19 3c a0 b7 :2 a0 6b
a0 7e a0 6b b4 2e 5a :17 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :17 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 a0 b7 a0
7e b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e a 10 a0 7e
51 b4 2e a0 51 d :f a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 51 d :c a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c b7
:2 19 3c a0 51 d a0 b7 :2 a0
51 a5 b 7e 51 b4 2e 5a
:3 a0 51 a5 b a5 b 5a 7e
51 b4 2e a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 19 3c :2 a0
:2 51 a5 b 7e 6e b4 2e :3 a0
7e a0 b4 2e :2 51 a5 b d
:15 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 :2 51 a5
b 7e 6e b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e 5a a 10 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :c a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :3 a0 7e
a0 b4 2e :2 51 a5 b d :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :14 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :c a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 d :2 a0 51 a5 b 7e
51 b4 2e :a a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :a a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
51 d :2 a0 d :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 3c :1e a0 :6 51 a5 b d a0
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e :4 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 19 3c b7 :2 a0 d :2 a0 d
:2 a0 :2 51 a5 b 7e 6e b4 2e
:3 a0 6b d b7 :4 a0 51 a5 b
:2 a0 6b a5 b d b7 :2 19 3c
:1e a0 :6 51 a5 b d a0 7e 51
b4 2e :4 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 :2 19 3c
b7 :3 a0 a5 b 51 a5 b 7e
51 b4 2e a0 51 d b7 :5 a0
a5 b 51 a5 b 7e 51 b4
2e 5a 7e 51 b4 2e a5 b
d b7 :2 19 3c a0 7e 51 b4
2e a0 51 d :3 a0 51 a5 b
a0 7e a0 b4 2e 82 a0 51
d :3 a0 6b :2 51 :2 a0 51 a5 b
7e 51 b4 2e 7e 51 b4 2e
a0 a5 b d :3 a0 6b :2 51 :2 a0
51 a5 b 7e 51 b4 2e 7e
51 b4 2e 7e 51 b4 2e a0
a5 b d :2 a0 d a0 51 d
a0 51 d :2 a0 d :e a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
a0 7e b4 2e :2 5a a 10 a0
51 d :2 a0 6b :2 a0 a5 b 7e
51 b4 2e :2 a0 d b7 19 3c
b7 19 3c :2 a0 :2 51 a5 b 7e
6e b4 2e :3 a0 6b d :3 a0 a5
b 51 a5 b 7e 51 b4 2e
:2 a0 d b7 :3 a0 7e 6e b4 2e
:2 51 a5 b d :3 a0 7e a0 b4
2e :2 51 a5 b d b7 :2 19 3c
b7 :3 a0 a5 b 51 a5 b 7e
51 b4 2e :2 a0 d b7 :3 a0 7e
6e b4 2e :2 51 a5 b d :3 a0
7e a0 b4 2e :2 51 a5 b d
b7 :2 19 3c b7 :2 19 3c a0 51
d a0 51 d :2 a0 51 a5 b
7e 51 b4 2e a0 7e 51 b4
2e :2 a0 :2 51 a5 b 7e 6e b4
2e :1c a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a a0 51 d :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a 52 10 :1a a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 a0 51
d b7 :2 19 3c a0 b7 :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
52 10 :1a a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:1c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 :2 a0 :2 51
a5 b 7e 6e b4 2e :1b a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 :16 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
a0 51 d 4f b7 :2 19 3c a0
b7 :2 a0 6b a0 7e a0 6b b4
2e 5a :19 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:19 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 a0 7e b4
2e 5a a0 7e 51 b4 2e a0
51 d :f a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a0 51 d
:c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :3 a0 51 a5 b 7e 51 b4
2e d a0 3b b7 19 3c b7
19 3c a0 51 d b7 :2 19 3c
b7 :3 a0 51 a5 b 7e 51 b4
2e d a0 3b b7 :2 19 3c :2 a0
d a0 51 d :a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :a a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 51 d :2 a0 d :2 a0 51 a5
b 7e 51 b4 2e a0 51 d
b7 19 3c :1e a0 :6 51 a5 b d
a0 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :4 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 19 3c a0 b7 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 d
:2 a0 d :2 a0 :2 51 a5 b 7e 6e
b4 2e :3 a0 6b d b7 :3 a0 51
a5 b d b7 :2 19 3c :1e a0 :6 51
a5 b d a0 7e 51 b4 2e
:4 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 :2 19 3c :3 a0 51
a5 b 7e 51 b4 2e d 93
4f b0 46 b7 a0 47 b7 19
3c b7 :2 19 3c a0 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b 7e 51 b4 2e :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :7 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c a0 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 a0 b7 :2 a0
7e a0 6b b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 a0 b7 19 :2 a0
7e a0 6b b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 19 3c
b7 19 3c :3 a0 a5 b 51 a5
b 7e 51 b4 2e 5a :3 a0 a5
b 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 6e 11e 11d :2 a0
6b 51 d a0 6e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e d :3 a0 11e
11d a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6e 11e 11d :2 a0 6b 51 d
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d :3 a0 11e 11d a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
b4 2e d a0 6e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e d :3 a0 11e
11d a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e d a0
b7 :3 a0 a5 b 51 a5 b 7e
51 b4 2e :2 a0 6e 11e 11d :2 a0
6b 51 d a0 6e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e d :3 a0 11e
11d a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6e 11e 11d :2 a0 6b 51 d
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e d :3 a0
11e 11d a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 b4 2e d a0
6e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e d :3 a0 11e 11d a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 51 a5 b a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e d b7 19 :2 a0
6e 11e 11d :2 a0 6b 51 d a0
6e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e d :3 a0 11e 11d a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6e 11e 11d
:2 a0 6b 51 d a0 6e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e d :3 a0 11e 11d a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
b4 2e d a0 6e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e d :3 a0 11e
11d a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 6e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
d b7 :2 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b a0 a5 b 65
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
3392
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 16a 155
159 15c 15d 165 154 187 175 151
179 17a 182 174 1a4 192 171 196
197 19f 191 1c1 1af 18e 1b3 1b4
1bc 1ae 1de 1cc 1ab 1d0 1d1 1d9
1cb 1fb 1e9 1c8 1ed 1ee 1f6 1e8
218 206 1e5 20a 20b 213 205 235
223 202 227 228 230 222 252 240
21f 244 245 24d 23f 26f 25d 23c
261 262 26a 25c 28b 27a 27e 286
259 2a3 292 296 29e 279 2c0 2ae
276 2b2 2b3 2bb 2ad 2dd 2cb 2aa
2cf 2d0 2d8 2ca 2fa 2e8 2c7 2ec
2ed 2f5 2e7 317 305 2e4 309 30a
312 304 334 322 301 326 327 32f
321 351 33f 31e 343 344 34c 33e
36d 35c 360 33b 368 35b 389 378
37c 358 384 377 3a5 394 398 374
3a0 393 3c1 3b0 3b4 390 3bc 3af
3dd 3cc 3d0 3ac 3d8 3cb 3f9 3e8
3ec 3c8 3f4 3e7 415 404 408 3e4
410 403 431 420 424 400 42c 41f
44d 43c 440 41c 448 43b 469 458
45c 438 464 457 485 474 478 454
480 473 4a1 490 494 470 49c 48f
4bd 4ac 4b0 48c 4b8 4ab 4d9 4c8
4cc 4a8 4d4 4c7 4f5 4e4 4e8 4c4
4f0 4e3 511 500 504 4e0 50c 4ff
52d 51c 520 4fc 528 51b 549 538
53c 518 544 537 565 554 558 534
560 553 581 570 574 550 57c 56f
59d 58c 590 56c 598 58b 5b9 5a8
5ac 588 5b4 5a7 5d5 5c4 5c8 5a4
5d0 5c3 5f1 5e0 5e4 5c0 5ec 5df
60d 5fc 600 5dc 608 5fb 629 618
61c 5f8 624 617 645 634 638 614
640 633 661 650 654 630 65c 64f
67e 66c 64c 670 671 679 66b 69b
689 668 68d 68e 696 688 6b7 6a6
6aa 685 6b2 6a5 6d4 6c2 6a2 6c6
6c7 6cf 6c1 6f0 6df 6e3 6be 6eb
6de 70d 6fb 6db 6ff 700 708 6fa
72a 718 6f7 71c 71d 725 717 747
735 714 739 73a 742 734 763 752
756 731 75e 751 77f 76e 772 74e
77a 76d 79b 78a 78e 76a 796 789
7b8 7a6 786 7aa 7ab 7b3 7a5 7d5
7c3 7a2 7c7 7c8 7d0 7c2 7f1 7e0
7e4 7bf 7ec 7df 80d 7fc 800 7dc
808 7fb 82a 818 7f8 81c 81d 825
817 846 835 839 814 841 834 862
851 855 831 85d 850 87e 86d 871
84d 879 86c 89a 889 88d 869 895
888 8b6 8a5 8a9 8b1 885 8d5 8bd
8c1 8c5 8c8 8d0 8a4 8dc 8e0 8a1
8e4 8e8 8ec 8ef 8f4 8f5 1 8f7
8fc 900 904 907 90c 910 914 917
91c 91d 91f 924 927 92b 92c 931
936 939 93e 93f 944 947 94b 94c
951 954 959 95a 95f 962 967 968
96d 970 975 976 97b 97e 982 983
988 98b 990 991 996 999 99e 99f
9a4 9a7 9ac 9ad 9b2 9b5 9b9 9ba
9bf 9c2 9c7 9c8 9cd 9d0 9d5 9d6
9db 9de 9e2 9e6 9ea 9eb 9ed 9f2
9f3 9f5 9f6 9fb 9fe a03 a04 a09
a0c a10 a14 a18 a19 a1b a20 a21
a23 a24 a29 a2c a31 a32 a37 a3a
a3e a42 a46 a47 a49 a4e a4f a51
a52 a57 a5a a5f a60 a65 a68 a6c
a70 a74 a75 a77 a7c a7d a7f a80
a85 a88 a8d a8e a93 a96 a9a a9e
aa2 aa3 aa5 aaa aab aad aae ab3
ab6 abb abc ac1 ac4 ac8 acc ad0
ad1 ad3 ad8 ad9 adb adc ae1 ae4
ae9 aea aef af2 af6 afa afe aff
b01 b06 b07 b09 b0a b0f b12 b17
b18 b1d b20 b24 b28 b2c b2d b2f
b34 b35 b37 b38 b3d b40 b45 b46
b4b b4e b52 b56 b5a b5b b5d b62
b63 b65 b66 b6b b6e b73 b74 b79
b7c b80 b84 b88 b89 b8b b90 b91
b93 b94 b99 b9c ba1 ba2 ba7 baa
baf bb0 bb5 bb8 bbc bbd bc2 bc5
bca bcb bd0 bd3 bd8 bd9 bde be1
be6 be7 bec bef bf3 bf4 bf9 bfc
c01 c02 c07 c0a c0f c10 c15 c16
c1b c1d c21 c24 c28 c2c c2f c33
c37 c3a c3d c42 c45 c48 c4b c4c
c51 c52 1 c54 c59 c5d c61 c64
c69 c6e c71 c75 c76 c7b c7c c81
c83 c87 c8a c8e c92 c96 c9a c9e
ca2 ca6 caa cae cb2 cb6 cba cbe
cc2 cc6 cca cce cd2 cd6 cda cde
ce2 ce6 cea cee cf2 cf6 cfa cfe
d02 d06 d0a d0e d12 d16 d1a d1e
d22 d26 d2a d2e d32 d36 d3a d3e
d42 d47 d4b d4f d50 d54 d58 d5c
d60 d64 d67 d68 d6a d6b d6d d71
d75 d78 d7c d80 d83 d87 d8b d8e
d92 d96 d99 d9a d9f da2 da6 daa
dad db1 db5 db8 dbb dc0 dc3 dc6
dc9 dca dcf dd0 1 dd2 dd7 ddb
ddf de2 de7 dec def df3 df4 df9
dfc e01 e02 e07 e0a e0f e10 e15
e18 e1c e20 e24 e28 e2b e2c e2e
e33 e34 e36 e37 e3c e3d e42 e44
e48 e4b e4f e53 e56 e5a e5e e61
e64 e69 e6c e6f e72 e73 e78 e79
1 e7b e80 e84 e88 e8b e90 e95
e98 e9c e9d ea2 ea3 ea8 eaa eae
eb1 eb5 eb9 ebc ec0 ec4 ec7 ecb
ecc ed1 ed3 ed7 eda ede ee1 ee2
ee7 eea eee ef2 ef5 ef9 efd f00
f03 f08 f0b f0e f11 f12 f17 f18
1 f1a f1f f23 f27 f2a f2f f34
f37 f3b f3c f41 f44 f49 f4a f4f
f52 f57 f58 f5d f60 f64 f68 f6c
f70 f73 f74 f76 f7b f7c f7e f7f
f84 f85 f8a f8c f90 f93 f97 f9b
f9e fa2 fa6 fa9 fac fb1 fb4 fb7
fba fbb fc0 fc1 1 fc3 fc8 fcc
fd0 fd3 fd8 fdd fe0 fe4 fe5 fea
feb ff0 ff2 ff6 ff9 ffd 1001 1004
1008 100c 100f 1013 1014 1019 101b 101f
1022 1026 102a 102d 102e 1030 1033 1036
1037 103c 1040 1044 1047 1048 104a 104d
1050 1051 1 1056 105b 105f 1063 1066
1067 1069 106c 106f 1070 1 1075 107a
107e 1082 1085 1089 108d 1090 1093 1098
109b 109e 10a1 10a2 10a7 10a8 1 10aa
10af 10b3 10b7 10ba 10bf 10c4 10c7 10cb
10cc 10d1 10d4 10d9 10da 10df 10e2 10e7
10e8 10ed 10f0 10f4 10f8 10fc 1100 1103
1104 1106 110b 110c 110e 110f 1114 1115
111a 111c 1120 1123 1127 112b 112e 1132
1136 1139 113c 1141 1144 1147 114a 114b
1150 1151 1 1153 1158 115c 1160 1163
1168 116d 1170 1174 1175 117a 117b 1180
1182 1186 1189 118d 1191 1194 1198 119c
119f 11a3 11a4 11a9 11ab 11af 11b2 11b6
11b9 11ba 11bf 11c2 11c5 11c9 11cc 11cd
11d2 11d5 1 11d8 11dd 11e1 11e5 11e9
11ed 11f1 11f5 11f9 11fd 1209 120d 1211
1214 1218 121c 121e 1222 1226 122a 122d
1231 1235 1237 1238 123d 1 1241 1245
1249 124c 1250 1254 1258 125c 125f 1263
1267 126a 126d 1272 1275 1278 127b 127c
1281 1282 1 1284 1289 128d 1291 1294
1299 129e 12a1 12a5 12a6 12ab 12ae 12b3
12b4 12b9 12bc 12c1 12c2 12c7 12ca 12ce
12cf 12d4 12d7 12dc 12dd 12e2 12e5 12e9
12ed 12f0 12f3 12f4 12f6 12f7 12fc 12fd
1302 1304 1308 130b 130d 1311 1313 131f
1321 1323 1324 1329 132d 132f 133b 133d
1341 1345 1348 134c 134f 1353 1356 1357
135c 135f 1363 1367 136a 136b 136d 1370
1373 1374 1379 1 137c 1381 1385 1389
138c 1390 1394 1397 139a 139f 13a2 13a5
13a8 13a9 13ae 13af 1 13b1 13b6 13ba
13be 13c1 13c6 13cb 13ce 13d2 13d3 13d8
13db 13e0 13e1 13e6 13e9 13ee 13ef 13f4
13f7 13fb 13ff 1403 1407 140a 140b 140d
1412 1413 1415 1416 141b 141c 1421 1423
1427 142a 142e 1432 1435 1439 143d 1440
1443 1448 144b 144e 1451 1452 1457 1458
1 145a 145f 1463 1467 146a 146f 1474
1477 147b 147c 1481 1482 1487 1489 148d
1490 1494 1498 149b 149f 14a3 14a6 14aa
14ab 14b0 14b2 14b6 14b9 14bd 14c0 14c4
14c8 14ca 14ce 14d1 14d2 14d7 14da 14dd
14e1 14e4 14e5 14ea 14ed 1 14f0 14f5
14f9 14fd 1501 150d 1511 1515 1518 151c
1520 1522 1526 152a 152e 1531 1535 1539
153b 153c 1541 1 1545 1549 154d 1550
1554 1558 155c 1560 1563 1567 156b 156e
1571 1576 1579 157c 157f 1580 1585 1586
1 1588 158d 1591 1595 1598 159d 15a2
15a5 15a9 15aa 15af 15b2 15b7 15b8 15bd
15c0 15c5 15c6 15cb 15ce 15d2 15d3 15d8
15db 15e0 15e1 15e6 15e9 15ed 15f1 15f4
15f7 15f8 15fa 15fb 1600 1601 1606 1608
160c 160f 1611 1615 1617 1623 1625 1627
1628 162d 1631 1633 163f 1641 1643 1647
164b 164e 1652 1656 165a 165e 1661 1662
1667 166a 166e 1673 1677 1679 167d 1680
1684 1688 168c 168f 1692 1693 1695 1699
169d 16a1 16a5 16a8 16ab 16ac 16ae 16b2
16b6 16ba 16be 16c2 16c6 16c9 16ca 16cc
16cf 16d2 16d3 16d8 16dc 16e0 16e4 16e8
16eb 16ee 16ef 16f1 16f4 16f7 16f8 16fa
16fe 1702 1706 170a 170d 1710 1713 1716
171a 171b 171d 1721 1725 1729 172d 1730
1731 1733 1734 1736 1739 173c 173d 1742
1746 174a 174e 1752 1756 175a 175e 1762
1766 176a 176e 1772 1776 1782 1786 178a
178d 1791 1795 1797 179b 179f 17a3 17a6
17aa 17ae 17b0 17b1 17b6 1 17ba 17be
17c2 17c5 17c9 17cd 17d1 17d5 17d8 17dc
17e0 17e3 17e6 17eb 17ee 17f1 17f4 17f5
17fa 17fb 1 17fd 1802 1806 180a 180d
1812 1817 181a 181e 181f 1824 1827 182c
182d 1832 1835 183a 183b 1840 1843 1847
1848 184d 1850 1855 1856 185b 185e 1862
1866 1869 186c 186d 186f 1870 1875 1876
187b 187d 1881 1884 1886 188a 188c 1898
189a 189c 189d 18a2 18a6 18a8 18b4 18b6
18b8 18bc 18c0 18c4 18c8 18cc 18d0 18d4
18d8 18dc 18e0 18e4 18e8 18ec 18f0 18f4
18f8 18fc 1900 1904 1908 190c 1910 1914
1918 191c 1920 1924 1928 192c 1930 1934
1938 193c 1940 1944 1948 194c 1950 1954
1958 195c 1960 1964 1968 196c 1970 1974
1978 197c 1980 1984 1988 198c 1990 1994
1998 199c 19a0 19a4 19a8 19ac 19b0 19b4
19b8 19bc 19c0 19c4 19c8 19cc 19d8 19dc
19e0 19e3 19e7 19eb 19ed 19f1 19f5 19f9
19fc 1a00 1a04 1a06 1a07 1a0c 1 1a10
1a14 1a18 1a1b 1a1f 1a23 1a27 1a2b 1a2e
1a32 1a36 1a39 1a3c 1a41 1a44 1a47 1a4a
1a4b 1a50 1a51 1 1a53 1a58 1a5c 1a60
1a63 1a68 1a6d 1a70 1a74 1a75 1a7a 1a7d
1a82 1a83 1a88 1a8b 1a90 1a91 1a96 1a99
1a9d 1a9e 1aa3 1aa6 1aab 1aac 1ab1 1ab4
1ab8 1abc 1abf 1ac2 1ac3 1ac5 1ac6 1acb
1acc 1ad1 1ad3 1ad7 1ada 1adc 1ae0 1ae2
1aee 1af0 1af2 1af3 1af8 1afc 1afe 1b0a
1b0c 1b0e 1b12 1b16 1b19 1b1d 1b21 1b24
1b28 1b2b 1b2f 1b32 1b33 1b38 1b3b 1b3f
1b43 1b47 1b4b 1b4f 1b53 1b57 1b63 1b67
1b6b 1b6e 1b72 1b76 1b78 1b7c 1b80 1b84
1b87 1b8b 1b8f 1b91 1b92 1b97 1 1b9b
1b9f 1ba3 1ba6 1baa 1bae 1bb2 1bb6 1bb9
1bbd 1bc1 1bc4 1bc7 1bcc 1bcf 1bd2 1bd5
1bd6 1bdb 1bdc 1 1bde 1be3 1be7 1beb
1bee 1bf3 1bf8 1bfb 1bff 1c00 1c05 1c08
1c0d 1c0e 1c13 1c16 1c1b 1c1c 1c21 1c24
1c28 1c29 1c2e 1c31 1c36 1c37 1c3c 1c3f
1c43 1c47 1c4a 1c4d 1c4e 1c50 1c51 1c56
1c57 1c5c 1c5e 1c62 1c65 1c67 1c6b 1c6d
1c79 1c7b 1c7d 1c7e 1c83 1c87 1c89 1c95
1c97 1c9b 1c9f 1ca2 1ca6 1ca9 1cad 1cb0
1cb1 1cb6 1cb9 1cbd 1cc0 1cc1 1cc6 1cc9
1ccd 1cd0 1cd4 1cd6 1cda 1cdd 1ce1 1ce5
1ce9 1ced 1cf1 1cf5 1cf9 1cfd 1d01 1d05
1d09 1d15 1d19 1d1d 1d20 1d24 1d28 1d2a
1d2e 1d32 1d36 1d39 1d3d 1d41 1d43 1d44
1d49 1 1d4d 1d51 1d55 1d58 1d5c 1d60
1d64 1d68 1d6b 1d6f 1d73 1d76 1d79 1d7e
1d81 1d84 1d87 1d88 1d8d 1d8e 1 1d90
1d95 1d99 1d9d 1da0 1da5 1daa 1dad 1db1
1db2 1db7 1dba 1dbf 1dc0 1dc5 1dc8 1dcd
1dce 1dd3 1dd6 1dda 1ddb 1de0 1de3 1de8
1de9 1dee 1df1 1df5 1df9 1dfc 1dff 1e00
1e02 1e03 1e08 1e09 1e0e 1e10 1e14 1e17
1e19 1e1d 1e1f 1e2b 1e2d 1e2f 1e30 1e35
1e39 1e3b 1e47 1e49 1e4b 1e4f 1e53 1e56
1e5a 1e5e 1e61 1e64 1e69 1e6c 1e6f 1e72
1e73 1e78 1e79 1 1e7b 1e80 1e84 1e88
1e8b 1e90 1e95 1e98 1e9c 1e9d 1ea2 1ea5
1eaa 1eab 1eb0 1eb3 1eb8 1eb9 1ebe 1ec1
1ec5 1ec9 1ecd 1ed1 1ed4 1ed5 1ed7 1edc
1edd 1edf 1ee0 1ee5 1ee8 1eed 1eee 1ef3
1ef6 1efb 1efc 1f01 1f04 1f08 1f09 1f0e
1f11 1f16 1f17 1f1c 1f1d 1f22 1f24 1f28
1f2b 1f2f 1f33 1f36 1f3a 1f3e 1f41 1f44
1f49 1f4c 1f4f 1f52 1f53 1f58 1f59 1
1f5b 1f60 1f64 1f68 1f6b 1f70 1f75 1f78
1f7c 1f7d 1f82 1f83 1f88 1f8a 1f8e 1f91
1f95 1f99 1f9c 1fa0 1fa4 1fa7 1fab 1faf
1fb0 1fb5 1fb7 1fbb 1fbf 1fc2 1fc4 1fc8
1fcb 1fcf 1fd1 1fd5 1fd9 1fdc 1fe0 1fe3
1fe7 1feb 1fef 1ff3 1ff7 1ffb 2007 200b
200f 2012 2016 201a 201c 2020 2024 2028
202b 202f 2033 2035 2036 203b 1 203f
2043 2047 204a 204e 2052 2056 205a 205d
2061 2065 2068 206b 2070 2073 2076 2079
207a 207f 2080 1 2082 2087 208b 208f
2092 2097 209c 209f 20a3 20a4 20a9 20ac
20b1 20b2 20b7 20ba 20bf 20c0 20c5 20c8
20cc 20cd 20d2 20d5 20da 20db 20e0 20e3
20e7 20eb 20ee 20f1 20f2 20f4 20f5 20fa
20fb 2100 2102 2106 2109 210b 210f 2111
211d 211f 2121 2122 2127 212b 212d 2139
213b 213f 2143 2146 2147 2149 214c 214f
2150 2155 2159 215d 2161 2165 2169 2175
2179 217d 2180 2184 2188 218a 218e 2192
2196 2199 219d 21a1 21a3 21a4 21a9 1
21ad 21b1 21b5 21b8 21bc 21c0 21c4 21c8
21cb 21cf 21d3 21d6 21d9 21de 21e1 21e4
21e7 21e8 21ed 21ee 1 21f0 21f5 21f9
21fd 2200 2205 220a 220d 2211 2212 2217
221a 221f 2220 2225 2228 222d 222e 2233
2236 223a 223b 2240 2243 2248 2249 224e
2251 2255 2259 225c 225f 2260 2262 2263
2268 2269 226e 2270 2274 2277 2279 227d
227f 228b 228d 228f 2290 2295 2299 229b
22a7 22a9 22ad 22b1 22b4 22b8 22bd 22be
22c0 22c3 22c6 22c7 22cc 22d0 22d4 22d7
22db 22df 22e2 22e5 22ea 22ed 22f0 22f3
22f4 22f9 22fa 1 22fc 2301 2305 2309
230c 2311 2316 2319 231d 231e 2323 2326
232b 232c 2331 2334 2339 233a 233f 2342
2346 234a 234e 2352 2355 2356 2358 235d
235e 2360 2361 2366 2369 236e 236f 2374
2377 237c 237d 2382 2385 2389 238a 238f
2392 2397 2398 239d 239e 23a3 23a5 23a9
23ac 23b0 23b4 23b7 23bb 23bf 23c2 23c5
23ca 23cd 23d0 23d3 23d4 23d9 23da 1
23dc 23e1 23e5 23e9 23ec 23f1 23f6 23f9
23fd 23fe 2403 2404 2409 240b 240f 2412
2416 241a 241d 2421 2425 2428 242c 2430
2431 2436 2438 243c 243f 2441 2445 2448
244a 244e 2452 2456 245a 245e 2462 2466
246a 246e 2472 2476 2482 2486 248a 248d
2491 2495 2497 249b 249f 24a3 24a6 24aa
24ae 24b0 24b1 24b6 1 24ba 24be 24c2
24c5 24c9 24cd 24d1 24d5 24d8 24dc 24e0
24e3 24e6 24eb 24ee 24f1 24f4 24f5 24fa
24fb 1 24fd 2502 2506 250a 250d 2512
2517 251a 251e 251f 2524 2527 252c 252d
2532 2535 253a 253b 2540 2543 2547 2548
254d 2550 2555 2556 255b 255e 2562 2566
2569 256c 256d 256f 2570 2575 2576 257b
257d 2581 2584 2586 258a 258c 2598 259a
259c 259d 25a2 25a6 25a8 25b4 25b6 25ba
25be 25c1 25c5 25c8 25cc 25cf 25d0 25d5
25d8 25dc 25e0 25e4 25e8 25ec 25f8 25fc
2600 2603 2607 260b 260d 2611 2615 2619
261c 2620 2624 2626 2627 262c 1 2630
2634 2638 263b 263f 2643 2647 264b 264e
2652 2656 2659 265c 2661 2664 2667 266a
266b 2670 2671 1 2673 2678 267c 2680
2683 2688 268d 2690 2694 2695 269a 269d
26a2 26a3 26a8 26ab 26b0 26b1 26b6 26b9
26bd 26be 26c3 26c6 26cb 26cc 26d1 26d4
26d8 26dc 26df 26e2 26e3 26e5 26e6 26eb
26ec 26f1 26f3 26f7 26fa 26fc 2700 2702
270e 2710 2712 2713 2718 271c 271e 272a
272c 2730 2734 2737 273b 273e 2742 2745
2746 274b 274e 2752 2756 2759 275d 2761
2764 2767 276c 276f 2772 2775 2776 277b
277c 1 277e 2783 2787 278b 278e 2793
2798 279b 279f 27a0 27a5 27a8 27ad 27ae
27b3 27b6 27bb 27bc 27c1 27c4 27c8 27cc
27d0 27d4 27d7 27d8 27da 27df 27e0 27e2
27e3 27e8 27eb 27f0 27f1 27f6 27f9 27fe
27ff 2804 2807 280b 280c 2811 2814 2819
281a 281f 2820 2825 2827 282b 282e 2832
2836 2839 283d 2841 2844 2847 284c 284f
2852 2855 2856 285b 285c 1 285e 2863
2867 286b 286e 2873 2878 287b 287f 2880
2885 2886 288b 288d 2891 2894 2898 289c
289f 28a3 28a7 28aa 28ae 28b2 28b3 28b8
28ba 28be 28c1 28c3 28c7 28ca 28cc 28d0
28d4 28d7 28db 28df 28e2 28e3 28e5 28e9
28ec 28f0 28f3 28f4 28f9 28fd 2901 2904
2905 2907 290a 290d 290e 2913 1 2916
291b 291f 2923 2927 292b 292f 2933 2937
293b 2947 294b 294f 2952 2956 295a 295c
2960 2964 2968 296b 296f 2973 2975 2976
297b 1 297f 2983 2987 298a 298e 2992
2996 299a 299d 29a1 29a5 29a8 29ab 29b0
29b3 29b6 29b9 29ba 29bf 29c0 1 29c2
29c7 29cb 29cf 29d2 29d7 29dc 29df 29e3
29e4 29e9 29ec 29f1 29f2 29f7 29fa 29ff
2a00 2a05 2a08 2a0c 2a0d 2a12 2a15 2a1a
2a1b 2a20 2a23 2a27 2a2b 2a2e 2a31 2a32
2a34 2a35 2a3a 2a3b 2a40 2a42 2a46 2a49
2a4b 2a4f 2a51 2a5d 2a5f 2a61 2a62 2a67
2a6b 2a6d 2a79 2a7b 2a7f 2a83 2a86 2a87
2a89 2a8c 2a8f 2a90 2a95 2a99 2a9d 2aa0
2aa1 2aa3 2aa7 2aaa 2aae 2ab1 2ab2 2ab7
2abb 2abf 2ac2 2ac3 2ac5 2ac9 2acc 2ad0
2ad3 2ad4 1 2ad9 2ade 2ae2 2ae5 2ae9
2aeb 2aef 2af2 2af6 2af9 2afd 2b01 2b04
2b08 2b0a 2b0e 2b11 2b13 2b17 2b1a 2b1d
2b1e 2b23 2b27 2b2b 2b2f 2b33 2b37 2b3b
2b3f 2b43 2b47 2b4b 2b4f 2b53 2b56 2b57
2b59 2b5d 2b61 2b64 2b65 2b67 2b6b 2b6f
2b72 2b73 2b75 2b79 2b7d 2b80 2b81 2b83
2b87 2b8b 2b8e 2b8f 2b91 2b95 2b99 2b9c
2b9d 2b9f 2ba3 2ba7 2baa 2bab 2bad 2bb1
2bb5 2bb8 2bb9 2bbb 2bbf 2bc3 2bc7 2bc8
2bca 2bce 2bd2 2bd6 2bd9 2bda 2bdc 2be0
2be3 2be7 2bea 2beb 2bf0 2bf4 2bf8 2bfb
2bff 2c03 2c06 2c09 2c0e 2c11 2c14 2c17
2c18 2c1d 2c1e 1 2c20 2c25 2c29 2c2d
2c30 2c35 2c3a 2c3d 2c41 2c42 2c47 2c4a
2c4f 2c50 2c55 2c58 2c5d 2c5e 2c63 2c66
2c6a 2c6e 2c72 2c76 2c79 2c7a 2c7c 2c81
2c82 2c84 2c85 2c8a 2c8b 2c90 2c92 2c96
2c99 2c9d 2ca1 2ca4 2ca8 2cac 2caf 2cb2
2cb7 2cba 2cbd 2cc0 2cc1 2cc6 2cc7 1
2cc9 2cce 2cd2 2cd6 2cd9 2cde 2ce3 2ce6
2cea 2ceb 2cf0 2cf1 2cf6 2cf8 2cfc 2cff
2d03 2d07 2d0a 2d0e 2d12 2d15 2d19 2d1a
2d1f 2d23 2d25 2d29 2d2d 2d30 2d31 2d33
2d36 2d39 2d3a 2d3f 2d43 2d47 2d4a 2d4e
2d52 2d55 2d58 2d5d 2d60 2d63 2d66 2d67
2d6c 2d6d 1 2d6f 2d74 2d78 2d7c 2d7f
2d84 2d89 2d8c 2d90 2d91 2d96 2d99 2d9e
2d9f 2da4 2da7 2dac 2dad 2db2 2db5 2db9
2dbd 2dc1 2dc2 2dc4 2dc9 2dca 2dcc 2dcd
2dd2 2dd5 2dda 2ddb 2de0 2de3 2de8 2de9
2dee 2df1 2df5 2df6 2dfb 2dfe 2e03 2e04
2e09 2e0a 2e0f 2e11 2e15 2e18 2e1c 2e20
2e23 2e27 2e2b 2e2e 2e31 2e36 2e39 2e3c
2e3f 2e40 2e45 2e46 1 2e48 2e4d 2e51
2e55 2e58 2e5d 2e62 2e65 2e69 2e6a 2e6f
2e70 2e75 2e77 2e7b 2e7e 2e82 2e86 2e89
2e8d 2e91 2e94 2e95 2e97 2e9b 2e9f 2ea0
2ea5 2ea7 2eab 2eaf 2eb2 2eb6 2eba 2ebe
2ec2 2ec5 2ec6 2ecb 2ece 2ed2 2ed7 2edb
2edd 2ee1 2ee4 2ee6 2eea 2eee 2ef2 2ef6
2efa 2efd 2efe 2f00 2f03 2f06 2f07 2f0c
2f10 2f14 2f18 2f1b 2f1c 2f1e 2f21 2f25
2f29 2f2c 2f2d 2f2f 2f30 2f35 2f39 2f3b
2f3f 2f42 2f44 2f48 2f4c 2f4f 2f53 2f57
2f5a 2f5b 2f5d 2f60 2f63 2f64 2f69 2f6c
2f70 2f74 2f77 2f78 2f7a 2f7d 2f80 2f81
2f86 1 2f89 2f8e 2f92 2f96 2f99 2f9a
2f9c 2f9f 2fa2 2fa3 2fa8 2fab 2faf 2fb3
2fb6 2fb7 2fb9 2fbc 2fbf 2fc0 2fc5 1
2fc8 2fcd 2fd1 2fd4 2fd8 2fdc 2fde 2fe2
2fe6 2fe9 2fea 2fec 2fef 2ff2 2ff3 2ff8
2ffc 2fff 3003 3007 3009 300d 3011 3015
3018 3019 301b 301e 3021 3022 3027 302a
302e 3032 3035 3036 3038 303b 303e 303f
3044 1 3047 304c 3050 3053 3057 305b
305d 3061 3065 3069 306c 306d 306f 3072
3075 3076 307b 307f 3082 3086 3088 308c
3090 3093 3095 3099 309c 309e 30a2 30a6
30a9 30ad 30b1 30b2 30b7 30bb 30bf 30c4
30c8 30cc 30d1 30d5 30d9 30dd 30e1 30e4
30e8 30ec 30f0 30f3 30f4 30f6 30fa 30fe
3101 3102 3104 3107 310a 310b 310d 3111
3115 3119 311d 3121 3124 3125 3127 312b
312f 3132 3133 3135 3139 313d 3141 3144
3145 3147 314a 314d 314e 3153 3157 315b
315f 3163 3167 316b 316f 3173 3174 3176
317a 317e 3182 3185 3186 3188 318c 318f
3193 3196 3197 319c 31a0 31a4 31a7 31a8
31aa 31ad 31b0 31b1 31b6 31ba 31be 31c2
31c5 31c9 31cb 31cf 31d2 31d6 31da 31dd
31e1 31e5 31e8 31eb 31f0 31f3 31f6 31f9
31fa 31ff 3200 1 3202 3207 320b 320f
3212 3217 321c 321f 3223 3224 3229 322c
3231 3232 3237 323a 323f 3240 3245 3248
324c 3250 3254 3255 3257 325c 325d 325f
3260 3265 3268 326d 326e 3273 3276 327b
327c 3281 3284 3288 3289 328e 3291 3296
3297 329c 329d 32a2 32a4 32a8 32ab 32af
32b3 32b6 32ba 32be 32c1 32c4 32c9 32cc
32cf 32d2 32d3 32d8 32d9 1 32db 32e0
32e4 32e8 32eb 32f0 32f5 32f8 32fc 32fd
3302 3303 3308 330a 330e 3311 3315 3319
331c 3320 3324 3327 3328 332a 332e 3332
3333 3338 333a 333e 3341 3345 3349 334c
334d 334f 3352 3355 3356 335b 335f 3363
3366 3367 3369 336c 336f 3370 1 3375
337a 337e 3382 3385 3389 338d 3390 3393
3398 339b 339e 33a1 33a2 33a7 33a8 1
33aa 33af 33b3 33b7 33ba 33bf 33c4 33c7
33cb 33cc 33d1 33d4 33d9 33da 33df 33e2
33e7 33e8 33ed 33f0 33f4 33f8 33fc 33fd
33ff 3404 3405 3407 3408 340d 3410 3415
3416 341b 341e 3423 3424 3429 342c 3430
3431 3436 3439 343e 343f 3444 3445 344a
344c 3450 3453 3457 345b 345e 3462 3466
3469 346c 3471 3474 3477 347a 347b 3480
3481 1 3483 3488 348c 3490 3493 3498
349d 34a0 34a4 34a5 34aa 34ab 34b0 34b2
34b6 34b9 34bd 34c1 34c4 34c8 34cc 34cf
34d0 34d2 34d6 34da 34db 34e0 34e2 34e6
34e9 34ed 34ee 34f2 34f6 34fa 34fe 3502
3506 350a 350e 3512 3516 351a 351e 3522
3526 352a 352e 3532 3536 353a 353e 3542
354e 3552 3556 3559 355d 3561 3563 3567
356b 356f 3572 3576 357a 357c 357d 3582
1 3586 358a 358e 3591 3595 3599 359d
35a1 35a4 35a8 35ac 35af 35b2 35b7 35ba
35bd 35c0 35c1 35c6 35c7 1 35c9 35ce
35d2 35d6 35d9 35de 35e3 35e6 35ea 35eb
35f0 35f3 35f8 35f9 35fe 3601 3606 3607
360c 360f 3613 3614 3619 361c 3621 3622
3627 362a 362e 3632 3635 3638 3639 363b
363c 3641 3642 3647 3649 364d 3650 3652
3656 3658 3664 3666 3668 3669 366e 3672
3674 3680 3682 3686 368a 368d 3691 3694
3698 369b 369c 36a1 36a4 36a8 36ab 36ac
36b1 36b4 1 36b7 36bc 36c0 36c3 36c7
36cb 36cf 36d2 36d3 36d5 36d8 36db 36dc
36e1 36e5 36e9 36ed 36ef 36f3 36f6 36f8
36fc 36ff 3703 3706 370a 370e 3711 3715
3719 371c 371f 3720 3725 3729 372d 3730
3733 3734 3736 3739 373e 373f 3744 3748
374c 3750 3754 3758 375c 3760 3764 3768
376c 3770 3774 3778 377c 3780 3784 3788
378c 3790 3794 3798 379c 37a0 37a4 37a8
37ac 37b0 37b4 37b8 37bc 37c0 37c4 37c8
37cc 37d8 37dc 37e0 37e3 37e7 37eb 37ed
37f1 37f5 37f9 37fc 3800 3804 3806 3807
380c 1 3810 3814 3818 381b 381f 3823
3827 382b 382e 3832 3836 3839 383c 3841
3844 3847 384a 384b 3850 3851 1 3853
3858 385c 3860 3863 3868 386d 3870 3874
3875 387a 387d 3882 3883 3888 388b 3890
3891 3896 3899 389d 389e 38a3 38a6 38ab
38ac 38b1 38b4 38b8 38bc 38bf 38c2 38c3
38c5 38c6 38cb 38cc 38d1 38d3 38d7 38da
38dc 38e0 38e2 38ee 38f0 38f2 38f3 38f8
38fc 38fe 390a 390c 3910 3914 3917 391b
391e 3922 3925 3926 392b 392e 3932 3935
3939 393d 3941 3944 3945 3947 394a 394d
394e 3953 3956 395a 395e 3961 3962 3964
3967 396a 396b 3970 1 3973 3978 397c
3980 3984 3988 398c 3990 3994 3998 399c
39a0 39a4 39a8 39ac 39b0 39b4 39b8 39bc
39c0 39c4 39c8 39cc 39d0 39d4 39d8 39dc
39e0 39e4 39e8 39ec 39f0 39f4 39f8 3a04
3a08 3a0c 3a0f 3a13 3a17 3a19 3a1d 3a21
3a25 3a28 3a2c 3a30 3a32 3a33 3a38 1
3a3c 3a40 3a44 3a47 3a4b 3a4f 3a53 3a57
3a5a 3a5e 3a62 3a65 3a68 3a6d 3a70 3a73
3a76 3a77 3a7c 3a7d 1 3a7f 3a84 3a88
3a8c 3a8f 3a94 3a99 3a9c 3aa0 3aa1 3aa6
3aa9 3aae 3aaf 3ab4 3ab7 3abc 3abd 3ac2
3ac5 3ac9 3aca 3acf 3ad2 3ad7 3ad8 3add
3ae0 3ae4 3ae8 3aeb 3aee 3aef 3af1 3af2
3af7 3af8 3afd 3aff 3b03 3b06 3b08 3b0c
3b0e 3b1a 3b1c 3b1e 3b1f 3b24 3b28 3b2a
3b36 3b38 3b3a 3b3e 3b41 3b45 3b47 3b4b
3b4f 3b52 3b56 3b58 3b5c 3b60 3b63 3b67
3b6a 3b6e 3b71 3b72 3b77 3b7a 3b7e 3b82
3b85 3b86 3b88 3b8b 3b8e 3b8f 3b94 1
3b97 3b9c 3ba0 3ba4 3ba8 3bac 3bb0 3bb4
3bb8 3bbc 3bc0 3bc4 3bc8 3bcc 3bd0 3bd4
3bd8 3bdc 3be0 3be4 3be8 3bec 3bf0 3bf4
3bf8 3bfc 3c00 3c04 3c08 3c0c 3c10 3c14
3c18 3c1c 3c28 3c2c 3c30 3c33 3c37 3c3b
3c3d 3c41 3c45 3c49 3c4c 3c50 3c54 3c56
3c57 3c5c 1 3c60 3c64 3c68 3c6b 3c6f
3c73 3c77 3c7b 3c7e 3c82 3c86 3c89 3c8c
3c91 3c94 3c97 3c9a 3c9b 3ca0 3ca1 1
3ca3 3ca8 3cac 3cb0 3cb3 3cb8 3cbd 3cc0
3cc4 3cc5 3cca 3ccd 3cd2 3cd3 3cd8 3cdb
3ce0 3ce1 3ce6 3ce9 3ced 3cee 3cf3 3cf6
3cfb 3cfc 3d01 3d04 3d08 3d0c 3d0f 3d12
3d13 3d15 3d16 3d1b 3d1c 3d21 3d23 3d27
3d2a 3d2c 3d30 3d32 3d3e 3d40 3d42 3d43
3d48 3d4c 3d4e 3d5a 3d5c 3d5e 3d62 3d66
3d69 3d6b 3d6f 3d73 3d77 3d7b 3d7f 3d83
3d87 3d8b 3d8f 3d93 3d97 3d9b 3d9f 3da3
3da7 3dab 3daf 3db3 3db7 3dbb 3dbf 3dc3
3dc7 3dcb 3dcf 3dd3 3dd7 3ddb 3ddf 3de3
3de7 3deb 3df7 3dfb 3dff 3e02 3e06 3e0a
3e0c 3e10 3e14 3e18 3e1b 3e1f 3e23 3e25
3e26 3e2b 1 3e2f 3e33 3e37 3e3a 3e3e
3e42 3e46 3e4a 3e4d 3e51 3e55 3e58 3e5b
3e60 3e63 3e66 3e69 3e6a 3e6f 3e70 1
3e72 3e77 3e7b 3e7f 3e82 3e87 3e8c 3e8f
3e93 3e94 3e99 3e9c 3ea1 3ea2 3ea7 3eaa
3eaf 3eb0 3eb5 3eb8 3ebc 3ebd 3ec2 3ec5
3eca 3ecb 3ed0 3ed3 3ed7 3edb 3ede 3ee1
3ee2 3ee4 3ee5 3eea 3eeb 3ef0 3ef2 3ef6
3ef9 3efb 3eff 3f01 3f0d 3f0f 3f11 3f12
3f17 3f1b 3f1d 3f29 3f2b 3f2d 3f31 3f35
3f38 3f3a 3f3e 3f42 3f45 3f48 3f49 3f4b
3f4e 3f53 3f54 3f59 3f5d 3f61 3f65 3f69
3f6d 3f71 3f75 3f79 3f7d 3f81 3f85 3f89
3f8d 3f91 3f95 3f99 3f9d 3fa1 3fa5 3fa9
3fad 3fb1 3fb5 3fb9 3fbd 3fc9 3fcd 3fd1
3fd4 3fd8 3fdc 3fde 3fe2 3fe6 3fea 3fed
3ff1 3ff5 3ff7 3ff8 3ffd 1 4001 4005
4009 400c 4010 4014 4018 401c 401f 4023
4027 402a 402d 4032 4035 4038 403b 403c
4041 4042 1 4044 4049 404d 4051 4054
4059 405e 4061 4065 4066 406b 406e 4073
4074 4079 407c 4081 4082 4087 408a 408e
408f 4094 4097 409c 409d 40a2 40a5 40a9
40ad 40b0 40b3 40b4 40b6 40b7 40bc 40bd
40c2 40c4 40c8 40cb 40cd 40d1 40d3 40df
40e1 40e3 40e4 40e9 40ed 40ef 40fb 40fd
4101 4105 4108 410c 410f 4113 4116 4117
411c 411f 4123 4126 412a 412e 4132 4135
4136 4138 413b 413e 413f 4144 4147 414b
414f 4152 4153 4155 4158 415b 415c 4161
1 4164 4169 416d 4171 4175 4179 417d
4181 4185 4189 418d 4191 4195 4199 419d
41a1 41a5 41a9 41ad 41b1 41b5 41b9 41c5
41c9 41cd 41d0 41d4 41d8 41da 41de 41e2
41e6 41e9 41ed 41f1 41f3 41f4 41f9 1
41fd 4201 4205 4208 420c 4210 4214 4218
421b 421f 4223 4226 4229 422e 4231 4234
4237 4238 423d 423e 1 4240 4245 4249
424d 4250 4255 425a 425d 4261 4262 4267
426a 426f 4270 4275 4278 427d 427e 4283
4286 428a 428b 4290 4293 4298 4299 429e
42a1 42a5 42a9 42ac 42af 42b0 42b2 42b3
42b8 42b9 42be 42c0 42c4 42c7 42c9 42cd
42cf 42db 42dd 42df 42e0 42e5 42e9 42eb
42f7 42f9 42fb 42ff 4302 4306 4308 430a
430e 4312 4315 4319 431b 431f 4323 4326
432a 432d 4331 4334 4335 433a 433d 4341
4345 4349 434d 4351 4355 4359 435d 4361
4365 4369 436d 4371 4375 4379 437d 4381
4385 4389 438d 4391 4395 4399 43a5 43a9
43ad 43b0 43b4 43b8 43ba 43be 43c2 43c6
43c9 43cd 43d1 43d3 43d4 43d9 1 43dd
43e1 43e5 43e8 43ec 43f0 43f4 43f8 43fb
43ff 4403 4406 4409 440e 4411 4414 4417
4418 441d 441e 1 4420 4425 4429 442d
4430 4435 443a 443d 4441 4442 4447 444a
444f 4450 4455 4458 445d 445e 4463 4466
446a 446b 4470 4473 4478 4479 447e 4481
4485 4489 448c 448f 4490 4492 4493 4498
4499 449e 44a0 44a4 44a7 44a9 44ad 44af
44bb 44bd 44bf 44c0 44c5 44c9 44cb 44d7
44d9 44db 44df 44e3 44e6 44e8 44ec 44f0
44f4 44f8 44fc 4500 4504 4508 450c 4510
4514 4518 451c 4520 4524 4528 452c 4530
4534 4538 453c 4540 4544 4550 4554 4558
455b 455f 4563 4565 4569 456d 4571 4574
4578 457c 457e 457f 4584 1 4588 458c
4590 4593 4597 459b 459f 45a3 45a6 45aa
45ae 45b1 45b4 45b9 45bc 45bf 45c2 45c3
45c8 45c9 1 45cb 45d0 45d4 45d8 45db
45e0 45e5 45e8 45ec 45ed 45f2 45f5 45fa
45fb 4600 4603 4608 4609 460e 4611 4615
4616 461b 461e 4623 4624 4629 462c 4630
4634 4637 463a 463b 463d 463e 4643 4644
4649 464b 464f 4652 4654 4658 465a 4666
4668 466a 466b 4670 4674 4676 4682 4684
4686 468a 468e 4691 4693 4697 469b 469e
46a2 46a6 46a9 46ad 46b0 46b4 46b7 46b8
46bd 46c0 46c4 46c8 46cb 46cc 46ce 46d1
46d4 46d5 46da 46de 46e2 46e5 46e9 46ed
46f0 46f3 46f8 46fb 46fe 4701 4702 4707
4708 1 470a 470f 4713 4717 471a 471f
4724 4727 472b 472c 4731 4734 4739 473a
473f 4742 4747 4748 474d 4750 4754 4758
475c 4760 4763 4764 4766 476b 476c 476e
476f 4774 4777 477c 477d 4782 4785 478a
478b 4790 4793 4797 4798 479d 47a0 47a5
47a6 47ab 47ac 47b1 47b3 47b7 47ba 47be
47c2 47c5 47c9 47cd 47d0 47d3 47d8 47db
47de 47e1 47e2 47e7 47e8 1 47ea 47ef
47f3 47f7 47fa 47ff 4804 4807 480b 480c
4811 4812 4817 4819 481d 4820 4824 4828
482b 482f 4833 4836 483a 483e 483f 4844
4848 484a 484e 4851 4852 4857 485a 485e
4862 4865 4866 4868 486b 486e 486f 1
4874 4879 487d 4880 4883 4884 4889 488d
4890 4894 4898 489c 48a0 48a4 48a8 48ac
48b0 48b4 48b8 48bc 48c0 48c4 48c8 48cc
48d0 48dc 48e0 48e4 48e7 48eb 48ef 48f1
48f5 48f9 48fd 4900 4904 4908 490a 490b
4910 1 4914 4918 491c 491f 4923 4927
492b 492f 4932 4936 493a 493d 4940 4945
4948 494b 494e 494f 4954 4955 1 4957
495c 4960 4964 4967 496c 4971 4974 4978
4979 497e 4981 4986 4987 498c 498f 4994
4995 499a 499d 49a1 49a2 49a7 49aa 49af
49b0 49b5 49b8 49bc 49c0 49c3 49c6 49c7
49c9 49ca 49cf 49d0 49d5 49d7 49db 49de
49e0 49e4 49e6 49f2 49f4 49f6 49f7 49fc
4a00 4a02 4a0e 4a10 4a12 4a16 4a19 4a1d
4a21 4a25 4a29 4a2d 4a31 4a35 4a39 4a3d
4a41 4a45 4a49 4a4d 4a59 4a5d 4a61 4a64
4a68 4a6c 4a6e 4a72 4a76 4a7a 4a7d 4a81
4a85 4a87 4a88 4a8d 1 4a91 4a95 4a99
4a9c 4aa0 4aa4 4aa8 4aac 4aaf 4ab3 4ab7
4aba 4abd 4ac2 4ac5 4ac8 4acb 4acc 4ad1
4ad2 1 4ad4 4ad9 4add 4ae1 4ae4 4ae9
4aee 4af1 4af5 4af6 4afb 4afe 4b03 4b04
4b09 4b0c 4b11 4b12 4b17 4b1a 4b1e 4b1f
4b24 4b27 4b2c 4b2d 4b32 4b35 4b39 4b3d
4b40 4b43 4b44 4b46 4b47 4b4c 4b4d 4b52
4b54 4b58 4b5b 4b5d 4b61 4b63 4b6f 4b71
4b73 4b74 4b79 4b7d 4b7f 4b8b 4b8d 4b8f
4b93 4b97 4b9a 4b9e 4ba2 4ba5 4ba6 4ba8
4bac 4baf 4bb3 4bb6 4bb7 4bb9 4bba 4bbf
4bc3 4bc7 4bca 4bce 4bd2 4bd5 4bd8 4bdd
4be0 4be3 4be6 4be7 4bec 4bed 1 4bef
4bf4 4bf8 4bfc 4bff 4c04 4c09 4c0c 4c10
4c11 4c16 4c19 4c1e 4c1f 4c24 4c27 4c2c
4c2d 4c32 4c35 4c39 4c3d 4c41 4c45 4c48
4c49 4c4b 4c50 4c51 4c53 4c54 4c59 4c5c
4c61 4c62 4c67 4c6a 4c6f 4c70 4c75 4c78
4c7c 4c7d 4c82 4c85 4c8a 4c8b 4c90 4c91
4c96 4c98 4c9c 4c9f 4ca3 4ca7 4caa 4cae
4cb2 4cb5 4cb8 4cbd 4cc0 4cc3 4cc6 4cc7
4ccc 4ccd 1 4ccf 4cd4 4cd8 4cdc 4cdf
4ce4 4ce9 4cec 4cf0 4cf1 4cf6 4cf7 4cfc
4cfe 4d02 4d05 4d09 4d0d 4d10 4d14 4d18
4d1b 4d1f 4d23 4d24 4d29 4d2b 4d2f 4d32
4d34 4d38 4d3c 4d3f 4d43 4d46 4d4a 4d4e
4d50 4d54 4d58 4d5b 4d5c 4d5e 4d61 4d64
4d65 4d6a 4d6d 4d71 4d75 4d79 4d7c 4d7d
4d7f 4d80 4d82 4d85 4d88 4d8b 4d8c 1
4d91 4d96 4d9a 4d9e 4da1 4da5 4da9 4dac
4daf 4db4 4db7 4dba 4dbd 4dbe 4dc3 4dc4
1 4dc6 4dcb 4dcf 4dd3 4dd6 4ddb 4de0
4de3 4de7 4de8 4ded 4df0 4df5 4df6 4dfb
4dfe 4e03 4e04 4e09 4e0c 4e10 4e14 4e18
4e1c 4e1f 4e20 4e22 4e27 4e28 4e2a 4e2b
4e30 4e33 4e38 4e39 4e3e 4e41 4e46 4e47
4e4c 4e4f 4e53 4e54 4e59 4e5c 4e61 4e62
4e67 4e68 4e6d 4e6f 4e73 4e76 4e7a 4e7e
4e81 4e85 4e89 4e8c 4e8f 4e94 4e97 4e9a
4e9d 4e9e 4ea3 4ea4 1 4ea6 4eab 4eaf
4eb3 4eb6 4ebb 4ec0 4ec3 4ec7 4ec8 4ecd
4ece 4ed3 4ed5 4ed9 4edc 4ee0 4ee4 4ee7
4eeb 4eef 4ef2 4ef6 4efa 4efb 4f00 4f02
4f06 4f0a 4f0d 4f11 4f15 4f18 4f1b 4f1c
4f1e 4f21 4f26 4f27 4f2c 4f30 4f34 4f38
4f3b 4f3f 4f40 4f45 4f48 4f4b 4f4c 4f4e
4f52 4f56 4f5a 4f5e 4f62 4f66 4f6a 4f6e
4f72 4f76 4f7a 4f7e 4f82 4f86 4f8a 4f8e
4f92 4f96 4f9a 4f9e 4fa2 4fa6 4fb2 4fb6
4fba 4fbd 4fc1 4fc5 4fc7 4fcb 4fcf 4fd3
4fd6 4fda 4fde 4fe0 4fe1 4fe6 1 4fea
4fee 4ff2 4ff5 4ff9 4ffd 5001 5005 5008
500c 5010 5013 5016 501b 501e 5021 5024
5025 502a 502b 1 502d 5032 5036 503a
503d 5042 5047 504a 504e 504f 5054 5057
505c 505d 5062 5065 506a 506b 5070 5073
5077 5078 507d 5080 5085 5086 508b 508e
5092 5096 5099 509c 509d 509f 50a0 50a5
50a6 50ab 50ad 50b1 50b4 50b6 50ba 50bc
50c8 50ca 50cc 50cd 50d2 50d6 50d8 50e4
50e6 50ea 50ee 50f1 50f5 50f8 50fc 50ff
5100 5105 5108 510c 5110 5113 5117 511b
511e 5121 5126 5129 512c 512f 5130 5135
5136 1 5138 513d 5141 5145 5148 514d
5152 5155 5159 515a 515f 5162 5167 5168
516d 5170 5175 5176 517b 517e 5182 5186
518a 518e 5191 5192 5194 5199 519a 519c
519d 51a2 51a5 51aa 51ab 51b0 51b3 51b8
51b9 51be 51c1 51c5 51c6 51cb 51ce 51d3
51d4 51d9 51da 51df 51e1 51e5 51e8 51ec
51f0 51f3 51f7 51fb 51fe 5201 5206 5209
520c 520f 5210 5215 5216 1 5218 521d
5221 5225 5228 522d 5232 5235 5239 523a
523f 5240 5245 5247 524b 524e 5252 5256
5259 525d 5261 5264 5268 526c 526d 5272
5274 5278 527b 527f 5283 5286 5289 528a
528c 528f 5294 5295 529a 529d 52a1 52a5
52a8 52a9 52ab 52ae 52b1 52b2 52b7 52ba
52be 52c2 52c5 52c6 52c8 52cc 52cf 52d3
52d6 52d7 52d9 52da 52df 1 52e2 52e7
1 52ea 52ef 52f3 52f7 52fa 52fe 5302
5305 5308 530d 5310 5313 5316 5317 531c
531d 1 531f 5324 5328 532c 532f 5334
5339 533c 5340 5341 5346 5349 534e 534f
5354 5357 535c 535d 5362 5365 5369 536d
5371 5375 5378 5379 537b 5380 5381 5383
5384 5389 538c 5391 5392 5397 539a 539f
53a0 53a5 53a8 53ac 53ad 53b2 53b5 53ba
53bb 53c0 53c1 53c6 53c8 53cc 53cf 53d3
53d7 53da 53de 53e2 53e5 53e8 53ed 53f0
53f3 53f6 53f7 53fc 53fd 1 53ff 5404
5408 540c 540f 5414 5419 541c 5420 5421
5426 5427 542c 542e 5432 5435 5439 543d
5440 5444 5448 544b 544f 5453 5454 5459
545b 545f 5462 5466 546a 546e 5472 5476
547a 547e 5482 5486 548a 548e 5492 549e
54a2 54a6 54a9 54ad 54b1 54b3 54b7 54bb
54bf 54c2 54c6 54ca 54cc 54cd 54d2 1
54d6 54da 54de 54e1 54e5 54e9 54ed 54f1
54f4 54f8 54fc 54ff 5502 5507 550a 550d
5510 5511 5516 5517 1 5519 551e 5522
5526 5529 552e 5533 5536 553a 553b 5540
5543 5548 5549 554e 5551 5556 5557 555c
555f 5563 5564 5569 556c 5571 5572 5577
557a 557e 5582 5585 5588 5589 558b 558c
5591 5592 5597 5599 559d 55a0 55a2 55a6
55a8 55b4 55b6 55b8 55b9 55be 55c2 55c4
55d0 55d2 55d4 55d8 55dc 55e0 55e3 55e7
55e8 55ed 55f0 55f3 55f4 55f6 55fa 55fe
5602 5606 560a 560e 561a 561e 5622 5625
5629 562d 562f 5633 5637 563b 563e 5642
5646 5648 5649 564e 1 5652 5656 565a
565d 5661 5665 5669 566d 5670 5674 5678
567b 567e 5683 5686 5689 568c 568d 5692
5693 1 5695 569a 569e 56a2 56a5 56aa
56af 56b2 56b6 56b7 56bc 56bf 56c4 56c5
56ca 56cd 56d2 56d3 56d8 56db 56df 56e0
56e5 56e8 56ed 56ee 56f3 56f6 56fa 56fe
5701 5704 5705 5707 5708 570d 570e 5713
5715 5719 571c 571e 5722 5724 5730 5732
5734 5735 573a 573e 5740 574c 574e 5752
5756 5759 575d 5760 5764 5767 5768 576d
5770 5774 5778 577b 577f 5783 5786 5789
578e 5791 5794 5797 5798 579d 579e 1
57a0 57a5 57a9 57ad 57b0 57b5 57ba 57bd
57c1 57c2 57c7 57ca 57cf 57d0 57d5 57d8
57dd 57de 57e3 57e6 57ea 57ee 57f2 57f6
57f9 57fa 57fc 5801 5802 5804 5805 580a
580d 5812 5813 5818 581b 5820 5821 5826
5829 582d 582e 5833 5836 583b 583c 5841
5842 5847 5849 584d 5850 5854 5858 585b
585f 5863 5866 5869 586e 5871 5874 5877
5878 587d 587e 1 5880 5885 5889 588d
5890 5895 589a 589d 58a1 58a2 58a7 58a8
58ad 58af 58b3 58b6 58ba 58be 58c1 58c5
58c9 58cc 58d0 58d4 58d5 58da 58dc 58e0
58e3 58e7 58eb 58ef 58f3 58f7 58fb 58ff
5903 5907 590b 590f 5913 5917 591b 591f
5923 5927 592b 592f 5933 593f 5943 5947
594a 594e 5952 5954 5958 595c 5960 5963
5967 596b 596d 596e 5973 1 5977 597b
597f 5982 5986 598a 598e 5992 5995 5999
599d 59a0 59a3 59a8 59ab 59ae 59b1 59b2
59b7 59b8 1 59ba 59bf 59c3 59c7 59ca
59cf 59d4 59d7 59db 59dc 59e1 59e4 59e9
59ea 59ef 59f2 59f7 59f8 59fd 5a00 5a04
5a05 5a0a 5a0d 5a12 5a13 5a18 5a1b 5a1f
5a23 5a26 5a29 5a2a 5a2c 5a2d 5a32 5a33
5a38 5a3a 5a3e 5a41 5a43 5a47 5a49 5a55
5a57 5a59 5a5a 5a5f 5a63 5a65 5a71 5a73
5a77 5a7b 5a7e 5a82 5a85 5a89 5a8c 5a8d
5a92 5a95 5a99 5a9d 5aa0 5aa1 5aa3 5aa6
5aa9 5aaa 5aaf 1 5ab2 5ab7 5abb 5abf
5ac2 5ac6 5aca 5acd 5ad0 5ad5 5ad8 5adb
5ade 5adf 5ae4 5ae5 1 5ae7 5aec 5af0
5af4 5af7 5afc 5b01 5b04 5b08 5b09 5b0e
5b11 5b16 5b17 5b1c 5b1f 5b24 5b25 5b2a
5b2d 5b31 5b35 5b39 5b3d 5b40 5b41 5b43
5b48 5b49 5b4b 5b4c 5b51 5b54 5b59 5b5a
5b5f 5b62 5b67 5b68 5b6d 5b70 5b74 5b75
5b7a 5b7d 5b82 5b83 5b88 5b89 5b8e 5b90
5b94 5b97 5b9b 5b9f 5ba2 5ba6 5baa 5bad
5bb0 5bb5 5bb8 5bbb 5bbe 5bbf 5bc4 5bc5
1 5bc7 5bcc 5bd0 5bd4 5bd7 5bdc 5be1
5be4 5be8 5be9 5bee 5bef 5bf4 5bf6 5bfa
5bfd 5c01 5c05 5c08 5c0c 5c10 5c13 5c17
5c1b 5c1c 5c21 5c23 5c27 5c2a 5c2e 5c32
5c36 5c3a 5c3e 5c42 5c46 5c4a 5c4e 5c52
5c56 5c5a 5c66 5c6a 5c6e 5c71 5c75 5c79
5c7b 5c7f 5c83 5c87 5c8a 5c8e 5c92 5c94
5c95 5c9a 1 5c9e 5ca2 5ca6 5ca9 5cad
5cb1 5cb5 5cb9 5cbc 5cc0 5cc4 5cc7 5cca
5ccf 5cd2 5cd5 5cd8 5cd9 5cde 5cdf 1
5ce1 5ce6 5cea 5cee 5cf1 5cf6 5cfb 5cfe
5d02 5d03 5d08 5d0b 5d10 5d11 5d16 5d19
5d1e 5d1f 5d24 5d27 5d2b 5d2c 5d31 5d34
5d39 5d3a 5d3f 5d42 5d46 5d4a 5d4d 5d50
5d51 5d53 5d54 5d59 5d5a 5d5f 5d61 5d65
5d68 5d6a 5d6e 5d70 5d7c 5d7e 5d80 5d81
5d86 5d8a 5d8c 5d98 5d9a 5d9c 5da0 5da4
5da7 5dab 5daf 5db3 5db7 5dbb 5dbe 5dbf
5dc1 5dc4 5dc7 5dc8 5dcd 5dd1 5dd5 5dd9
5ddd 5de1 5de5 5de9 5ded 5df1 5df5 5e01
5e05 5e09 5e0c 5e10 5e14 5e16 5e1a 5e1e
5e22 5e25 5e29 5e2d 5e2f 5e30 5e35 1
5e39 5e3d 5e41 5e44 5e48 5e4c 5e50 5e54
5e57 5e5b 5e5f 5e62 5e65 5e6a 5e6d 5e70
5e73 5e74 5e79 5e7a 1 5e7c 5e81 5e85
5e89 5e8c 5e91 5e96 5e99 5e9d 5e9e 5ea3
5ea6 5eab 5eac 5eb1 5eb4 5eb9 5eba 5ebf
5ec2 5ec6 5ec7 5ecc 5ecf 5ed4 5ed5 5eda
5edd 5ee1 5ee5 5ee8 5eeb 5eec 5eee 5eef
5ef4 5ef5 5efa 5efc 5f00 5f03 5f05 5f09
5f0b 5f17 5f19 5f1b 5f1c 5f21 5f25 5f27
5f33 5f35 5f39 5f3d 5f41 5f45 5f49 5f4d
5f51 5f55 5f59 5f5d 5f69 5f6d 5f71 5f74
5f78 5f7c 5f7e 5f82 5f86 5f8a 5f8d 5f91
5f95 5f97 5f98 5f9d 1 5fa1 5fa5 5fa9
5fac 5fb0 5fb4 5fb8 5fbc 5fbf 5fc3 5fc7
5fca 5fcd 5fd2 5fd5 5fd8 5fdb 5fdc 5fe1
5fe2 1 5fe4 5fe9 5fed 5ff1 5ff4 5ff9
5ffe 6001 6005 6006 600b 600e 6013 6014
6019 601c 6021 6022 6027 602a 602e 602f
6034 6037 603c 603d 6042 6045 6049 604d
6050 6053 6054 6056 6057 605c 605d 6062
6064 6068 606b 606d 6071 6073 607f 6081
6083 6084 6089 608d 608f 609b 609d 60a1
60a4 60a8 60ac 60b0 60b4 60b8 60bc 60bf
60c0 60c2 60c5 60c8 60c9 60ce 60d2 60d5
60d9 60db 60df 60e2 60e6 60ea 60ee 60f2
60f6 60fa 60fe 6102 6106 610a 610e 6112
6116 611a 611e 6122 6126 612a 612e 6132
6136 613a 613e 6142 6146 614a 614e 6152
6156 615a 615d 6160 6163 6166 6169 616c
616d 616f 6173 6177 617a 617d 617e 6183
6187 618b 618e 618f 6191 6194 6197 6198
619d 61a1 61a5 61a9 61ad 61b9 61bd 61c2
61c6 61c9 61ca 61cf 61d3 61d7 61da 61dd
61e1 61e3 61e7 61eb 61ee 61f1 61f5 61f7
61fb 61ff 6202 6204 6208 620c 6210 6213
6217 621b 621d 621e 6223 1 6227 622b
622f 6232 6236 623a 623e 6242 6245 6249
624d 6250 6253 6258 625b 625e 6261 6262
6267 6268 1 626a 626f 6273 6277 627a
627f 6284 6287 628b 628c 6291 6294 6299
629a 629f 62a2 62a7 62a8 62ad 62b0 62b4
62b5 62ba 62bd 62c2 62c3 62c8 62cb 62cf
62d3 62d6 62d9 62da 62dc 62dd 62e2 62e3
62e8 62ea 62ee 62f1 62f3 62f7 62f9 6305
6307 6309 630a 630f 6313 6315 6321 6323
6325 6329 632d 6331 6335 6341 6345 634a
634e 6351 6352 6357 635b 635f 6362 6365
6369 636b 636f 6373 6376 6379 637d 637f
6383 6387 638a 638c 6390 6394 6398 639b
639f 63a3 63a5 63a6 63ab 1 63af 63b3
63b7 63ba 63be 63c2 63c6 63ca 63cd 63d1
63d5 63d8 63db 63e0 63e3 63e6 63e9 63ea
63ef 63f0 1 63f2 63f7 63fb 63ff 6402
6407 640c 640f 6413 6414 6419 641c 6421
6422 6427 642a 642f 6430 6435 6438 643c
643d 6442 6445 644a 644b 6450 6453 6457
645b 645e 6461 6462 6464 6465 646a 646b
6470 6472 6476 6479 647b 647f 6481 648d
648f 6491 6492 6497 649b 649d 64a9 64ab
64ad 64b1 64b5 64b8 64ba 64be 64c1 64c3
64c7 64cb 64cf 64d3 64d7 64db 64df 64e3
64e6 64e9 64ea 64ec 64ef 64f4 64f5 64fa
64fe 6502 6506 6509 650d 650f 6513 6517
651b 651f 6522 6523 6525 6529 652d 6530
6531 6533 6537 6539 653d 6541 6544 6548
654c 6550 6554 6558 655c 6560 6564 6568
656c 6570 6574 6578 657c 6580 6584 6588
658c 6590 6594 6598 659c 65a0 65a4 65a8
65ac 65b0 65b4 65b8 65bc 65bf 65c2 65c5
65c8 65cb 65ce 65cf 65d1 65d5 65d9 65dc
65df 65e0 65e5 65e9 65ed 65f1 65f5 6601
6605 660a 660e 6611 6612 6617 661b 661f
6622 6625 6629 662b 662f 6633 6636 6639
663d 663f 6643 6647 664a 664c 6650 6654
6658 665b 665f 6663 6665 6666 666b 1
666f 6673 6677 667a 667e 6682 6686 668a
668d 6691 6695 6698 669b 66a0 66a3 66a6
66a9 66aa 66af 66b0 1 66b2 66b7 66bb
66bf 66c2 66c7 66cc 66cf 66d3 66d4 66d9
66dc 66e1 66e2 66e7 66ea 66ef 66f0 66f5
66f8 66fc 66fd 6702 6705 670a 670b 6710
6713 6717 671b 671e 6721 6722 6724 6725
672a 672b 6730 6732 6736 6739 673b 673f
6741 674d 674f 6751 6752 6757 675b 675d
6769 676b 676d 6771 6774 6776 677a 677e
6781 6783 6787 678b 678f 6790 6792 6795
6796 6798 679b 679e 679f 67a4 67a8 67ab
67af 67b1 67b5 67b9 67bd 67c1 67c5 67c6
67c8 67cb 67cc 67ce 67d1 67d4 67d5 67da
67dd 67e0 67e3 67e4 67e9 67ea 67ec 67f0
67f2 67f6 67fa 67fd 6801 6804 6807 6808
680d 6811 6814 6818 681c 6820 6824 6827
6828 682a 682e 6831 6835 6836 683b 683d
6841 6844 6848 684c 6850 6854 6857 685a
685d 6861 6865 6868 6869 686b 686e 6871
6872 6877 687a 687d 687e 6883 6887 6888
688a 688e 6892 6896 689a 689d 68a0 68a3
68a7 68ab 68ae 68af 68b1 68b4 68b7 68b8
68bd 68c0 68c3 68c4 68c9 68cc 68cf 68d0
68d5 68d9 68da 68dc 68e0 68e4 68e8 68ec
68f0 68f3 68f7 68fb 68fe 6902 6906 690a
690e 6912 6916 691a 691e 6922 6926 692a
692e 6932 6936 693a 693e 6942 6946 6952
6956 695a 695d 6961 6965 6967 696b 696f
6973 6976 697a 697e 6980 6981 6986 1
698a 698e 6992 6995 6999 699d 69a1 69a5
69a8 69ac 69b0 69b3 69b6 69bb 69be 69c1
69c4 69c5 69ca 69cb 1 69cd 69d2 69d6
69da 69dd 69e2 69e7 69ea 69ee 69ef 69f4
69f7 69fc 69fd 6a02 6a05 6a0a 6a0b 6a10
6a13 6a17 6a18 6a1d 6a20 6a25 6a26 6a2b
6a2e 6a32 6a36 6a39 6a3c 6a3d 6a3f 6a40
6a45 6a46 6a4b 6a4d 6a51 6a54 6a56 6a5a
6a5c 6a68 6a6a 6a6c 6a6d 6a72 6a76 6a78
6a84 6a86 6a8a 6a8e 6a91 6a92 6a94 6a97
6a9a 6a9b 6aa0 6aa3 6aa7 6aaa 6aab 6ab0
6ab3 1 6ab6 6abb 6abf 6ac2 6ac6 6aca
6ace 6ad1 6ad5 6ad9 6ada 6adc 6adf 6ae2
6ae3 6ae8 6aec 6af0 6af4 6af6 6afa 6afd
6aff 6b03 6b06 6b0a 6b0e 6b11 6b14 6b15
6b17 6b1a 6b1f 6b20 6b25 6b29 6b2d 6b31
6b34 6b38 6b3c 6b40 6b44 6b45 6b47 6b4a
6b4b 6b4d 6b50 6b53 6b54 6b59 6b5d 6b61
6b65 6b67 6b6b 6b6f 6b73 6b76 6b7b 6b7c
6b81 6b84 6b87 6b88 6b8a 6b8e 6b92 6b96
6b9a 6b9d 6ba1 6ba2 6ba7 6baa 6bad 6bae
6bb0 6bb4 6bb6 6bba 6bbe 6bc1 6bc3 6bc7
6bcb 6bcf 6bd0 6bd2 6bd5 6bd6 6bd8 6bdb
6bde 6bdf 6be4 6be8 6bec 6bf0 6bf2 6bf6
6bfa 6bfe 6c01 6c06 6c07 6c0c 6c0f 6c12
6c13 6c15 6c19 6c1d 6c21 6c25 6c28 6c2c
6c2d 6c32 6c35 6c38 6c39 6c3b 6c3f 6c41
6c45 6c49 6c4c 6c4e 6c52 6c56 6c59 6c5d
6c60 6c64 6c68 6c6b 6c6f 6c73 6c77 6c7a
6c7b 6c7d 6c80 6c83 6c84 6c89 6c8d 6c90
6c93 6c94 6c99 6c9d 6ca1 6ca4 6ca7 6ca8
6caa 6cad 6cb2 6cb3 6cb8 6cbc 6cc0 6cc4
6cc8 6ccc 6cd0 6cd4 6cd8 6cdc 6ce0 6ce4
6ce8 6cec 6cf0 6cf4 6cf8 6cfc 6d00 6d04
6d08 6d0c 6d10 6d14 6d18 6d1c 6d20 6d24
6d28 6d34 6d38 6d3c 6d3f 6d43 6d47 6d49
6d4d 6d51 6d55 6d58 6d5c 6d60 6d62 6d63
6d68 1 6d6c 6d70 6d74 6d77 6d7b 6d7f
6d83 6d87 6d8a 6d8e 6d92 6d95 6d98 6d9d
6da0 6da3 6da6 6da7 6dac 6dad 1 6daf
6db4 6db8 6dbc 6dbf 6dc4 6dc9 6dcc 6dd0
6dd1 6dd6 6dd9 6dde 6ddf 6de4 6de7 6dec
6ded 6df2 6df5 6df9 6dfa 6dff 6e02 6e07
6e08 6e0d 6e10 6e14 6e18 6e1b 6e1e 6e1f
6e21 6e22 6e27 6e28 6e2d 6e2f 6e33 6e36
6e38 6e3c 6e3e 6e4a 6e4c 6e4e 6e4f 6e54
6e58 6e5a 6e66 6e68 6e6c 6e70 6e73 6e77
6e7a 6e7e 6e81 6e82 6e87 6e8a 6e8e 6e91
6e95 6e99 6e9d 6ea0 6ea1 6ea3 6ea6 6ea9
6eaa 6eaf 6eb2 6eb6 6eba 6ebd 6ebe 6ec0
6ec3 6ec6 6ec7 6ecc 1 6ecf 6ed4 6ed8
6edc 6ee0 6ee4 6ee8 6eec 6ef0 6ef4 6ef8
6efc 6f00 6f04 6f08 6f0c 6f10 6f14 6f18
6f1c 6f20 6f24 6f28 6f2c 6f30 6f34 6f38
6f3c 6f48 6f4c 6f50 6f53 6f57 6f5b 6f5d
6f61 6f65 6f69 6f6c 6f70 6f74 6f76 6f77
6f7c 1 6f80 6f84 6f88 6f8b 6f8f 6f93
6f97 6f9b 6f9e 6fa2 6fa6 6fa9 6fac 6fb1
6fb4 6fb7 6fba 6fbb 6fc0 6fc1 1 6fc3
6fc8 6fcc 6fd0 6fd3 6fd8 6fdd 6fe0 6fe4
6fe5 6fea 6fed 6ff2 6ff3 6ff8 6ffb 7000
7001 7006 7009 700d 700e 7013 7016 701b
701c 7021 7024 7028 702c 702f 7032 7033
7035 7036 703b 703c 7041 7043 7047 704a
704c 7050 7052 705e 7060 7062 7063 7068
706c 706e 707a 707c 707e 7082 7085 7089
708b 708f 7093 7096 709a 709c 70a0 70a4
70a7 70ab 70ae 70b2 70b5 70b6 70bb 70be
70c2 70c6 70c9 70ca 70cc 70cf 70d2 70d3
70d8 1 70db 70e0 70e4 70e8 70ec 70f0
70f4 70f8 70fc 7100 7104 7108 710c 7110
7114 7118 711c 7120 7124 7128 712c 7130
7134 7138 713c 7140 7144 7148 7154 7158
715c 715f 7163 7167 7169 716d 7171 7175
7178 717c 7180 7182 7183 7188 1 718c
7190 7194 7197 719b 719f 71a3 71a7 71aa
71ae 71b2 71b5 71b8 71bd 71c0 71c3 71c6
71c7 71cc 71cd 1 71cf 71d4 71d8 71dc
71df 71e4 71e9 71ec 71f0 71f1 71f6 71f9
71fe 71ff 7204 7207 720c 720d 7212 7215
7219 721a 721f 7222 7227 7228 722d 7230
7234 7238 723b 723e 723f 7241 7242 7247
7248 724d 724f 7253 7256 7258 725c 725e
726a 726c 726e 726f 7274 7278 727a 7286
7288 728a 728e 7292 7295 7297 729b 729f
72a3 72a7 72ab 72af 72b3 72b7 72bb 72bf
72c3 72c7 72cb 72cf 72d3 72d7 72db 72df
72e3 72e7 72eb 72ef 72f3 72f7 72fb 72ff
7303 7307 7313 7317 731b 731e 7322 7326
7328 732c 7330 7334 7337 733b 733f 7341
7342 7347 1 734b 734f 7353 7356 735a
735e 7362 7366 7369 736d 7371 7374 7377
737c 737f 7382 7385 7386 738b 738c 1
738e 7393 7397 739b 739e 73a3 73a8 73ab
73af 73b0 73b5 73b8 73bd 73be 73c3 73c6
73cb 73cc 73d1 73d4 73d8 73d9 73de 73e1
73e6 73e7 73ec 73ef 73f3 73f7 73fa 73fd
73fe 7400 7401 7406 7407 740c 740e 7412
7415 7417 741b 741d 7429 742b 742d 742e
7433 7437 7439 7445 7447 7449 744d 7451
7454 7456 745a 745e 7461 7464 7465 7467
746a 746f 7470 7475 7479 747d 7481 7485
7489 748d 7491 7495 7499 749d 74a1 74a5
74a9 74ad 74b1 74b5 74b9 74bd 74c1 74c5
74c9 74cd 74d1 74d5 74d9 74dd 74e1 74ed
74f1 74f5 74f8 74fc 7500 7502 7506 750a
750e 7511 7515 7519 751b 751c 7521 1
7525 7529 752d 7530 7534 7538 753c 7540
7543 7547 754b 754e 7551 7556 7559 755c
755f 7560 7565 7566 1 7568 756d 7571
7575 7578 757d 7582 7585 7589 758a 758f
7592 7597 7598 759d 75a0 75a5 75a6 75ab
75ae 75b2 75b3 75b8 75bb 75c0 75c1 75c6
75c9 75cd 75d1 75d4 75d7 75d8 75da 75db
75e0 75e1 75e6 75e8 75ec 75ef 75f1 75f5
75f7 7603 7605 7607 7608 760d 7611 7613
761f 7621 7625 7629 762c 7630 7633 7637
763a 763b 7640 7643 7647 764b 764e 764f
7651 7654 7657 7658 765d 7660 7664 7668
766b 766c 766e 7671 7674 7675 767a 1
767d 7682 7686 768a 768e 7692 7696 769a
769e 76a2 76a6 76aa 76ae 76b2 76b6 76ba
76be 76c2 76c6 76ca 76ce 76d2 76d6 76da
76e6 76ea 76ee 76f1 76f5 76f9 76fb 76ff
7703 7707 770a 770e 7712 7714 7715 771a
1 771e 7722 7726 7729 772d 7731 7735
7739 773c 7740 7744 7747 774a 774f 7752
7755 7758 7759 775e 775f 1 7761 7766
776a 776e 7771 7776 777b 777e 7782 7783
7788 778b 7790 7791 7796 7799 779e 779f
77a4 77a7 77ab 77ac 77b1 77b4 77b9 77ba
77bf 77c2 77c6 77ca 77cd 77d0 77d1 77d3
77d4 77d9 77da 77df 77e1 77e5 77e8 77ea
77ee 77f0 77fc 77fe 7800 7801 7806 780a
780c 7818 781a 781c 7820 7823 7827 7829
782b 782f 7833 7836 783a 783c 7840 7844
7847 784b 784e 7852 7855 7856 785b 785e
7862 7866 786a 786e 7872 7876 787a 787e
7882 7886 788a 788e 7892 7896 789a 789e
78a2 78a6 78aa 78ae 78b2 78b6 78ba 78be
78c2 78ce 78d2 78d6 78d9 78dd 78e1 78e3
78e7 78eb 78ef 78f2 78f6 78fa 78fc 78fd
7902 1 7906 790a 790e 7911 7915 7919
791d 7921 7924 7928 792c 792f 7932 7937
793a 793d 7940 7941 7946 7947 1 7949
794e 7952 7956 7959 795e 7963 7966 796a
796b 7970 7973 7978 7979 797e 7981 7986
7987 798c 798f 7993 7994 7999 799c 79a1
79a2 79a7 79aa 79ae 79b2 79b5 79b8 79b9
79bb 79bc 79c1 79c2 79c7 79c9 79cd 79d0
79d2 79d6 79d8 79e4 79e6 79e8 79e9 79ee
79f2 79f4 7a00 7a02 7a04 7a08 7a0c 7a0f
7a11 7a15 7a19 7a1d 7a21 7a25 7a29 7a2d
7a31 7a35 7a39 7a3d 7a41 7a45 7a49 7a4d
7a51 7a55 7a59 7a5d 7a61 7a65 7a69 7a6d
7a71 7a75 7a81 7a85 7a89 7a8c 7a90 7a94
7a96 7a9a 7a9e 7aa2 7aa5 7aa9 7aad 7aaf
7ab0 7ab5 1 7ab9 7abd 7ac1 7ac4 7ac8
7acc 7ad0 7ad4 7ad7 7adb 7adf 7ae2 7ae5
7aea 7aed 7af0 7af3 7af4 7af9 7afa 1
7afc 7b01 7b05 7b09 7b0c 7b11 7b16 7b19
7b1d 7b1e 7b23 7b26 7b2b 7b2c 7b31 7b34
7b39 7b3a 7b3f 7b42 7b46 7b47 7b4c 7b4f
7b54 7b55 7b5a 7b5d 7b61 7b65 7b68 7b6b
7b6c 7b6e 7b6f 7b74 7b75 7b7a 7b7c 7b80
7b83 7b85 7b89 7b8b 7b97 7b99 7b9b 7b9c
7ba1 7ba5 7ba7 7bb3 7bb5 7bb7 7bbb 7bbf
7bc2 7bc4 7bc8 7bcc 7bcf 7bd3 7bd7 7bda
7bde 7be1 7be5 7be8 7be9 7bee 7bf1 7bf5
7bf9 7bfc 7bfd 7bff 7c02 7c05 7c06 7c0b
7c0f 7c12 7c16 7c18 7c1c 7c1f 7c20 7c25
7c28 7c2c 7c2f 7c32 7c33 7c38 7c3c 7c3f
7c43 7c47 7c4b 7c4f 7c53 7c57 7c5b 7c5f
7c63 7c67 7c6b 7c6f 7c73 7c77 7c7b 7c7f
7c8b 7c8f 7c93 7c96 7c9a 7c9e 7ca0 7ca4
7ca8 7cac 7caf 7cb3 7cb7 7cb9 7cba 7cbf
1 7cc3 7cc7 7ccb 7cce 7cd2 7cd6 7cda
7cde 7ce1 7ce5 7ce9 7cec 7cef 7cf4 7cf7
7cfa 7cfd 7cfe 7d03 7d04 1 7d06 7d0b
7d0f 7d13 7d16 7d1b 7d20 7d23 7d27 7d28
7d2d 7d30 7d35 7d36 7d3b 7d3e 7d43 7d44
7d49 7d4c 7d50 7d51 7d56 7d59 7d5e 7d5f
7d64 7d67 7d6b 7d6f 7d72 7d75 7d76 7d78
7d79 7d7e 7d7f 7d84 7d86 7d8a 7d8d 7d8f
7d93 7d95 7da1 7da3 7da5 7da6 7dab 7daf
7db1 7dbd 7dbf 7dc1 7dc5 7dc8 7dcc 7dd0
7dd4 7dd8 7ddc 7de0 7de4 7de8 7dec 7df0
7df4 7df8 7dfc 7e08 7e0c 7e10 7e13 7e17
7e1b 7e1d 7e21 7e25 7e29 7e2c 7e30 7e34
7e36 7e37 7e3c 1 7e40 7e44 7e48 7e4b
7e4f 7e53 7e57 7e5b 7e5e 7e62 7e66 7e69
7e6c 7e71 7e74 7e77 7e7a 7e7b 7e80 7e81
1 7e83 7e88 7e8c 7e90 7e93 7e98 7e9d
7ea0 7ea4 7ea5 7eaa 7ead 7eb2 7eb3 7eb8
7ebb 7ec0 7ec1 7ec6 7ec9 7ecd 7ece 7ed3
7ed6 7edb 7edc 7ee1 7ee4 7ee8 7eec 7eef
7ef2 7ef3 7ef5 7ef6 7efb 7efc 7f01 7f03
7f07 7f0a 7f0c 7f10 7f12 7f1e 7f20 7f22
7f23 7f28 7f2c 7f2e 7f3a 7f3c 7f3e 7f42
7f46 7f49 7f4d 7f51 7f54 7f55 7f57 7f5b
7f5e 7f62 7f65 7f66 7f68 7f69 7f6e 7f72
7f76 7f7a 7f7d 7f7e 7f80 7f83 7f86 7f87
7f8c 7f90 7f94 7f9a 7f9c 7fa0 7fa3 7fa5
7fa9 7fac 7fb0 7fb3 7fb7 7fb9 7fbd 7fc1
7fc4 7fc6 7fca 7fce 7fd2 7fd5 7fd6 7fd8
7fdb 7fde 7fdf 7fe4 7fe8 7fec 7ff2 7ff4
7ff8 7ffc 7fff 8003 8007 800b 800f 8012
8016 801a 801e 8022 8026 802a 802e 8032
8036 803a 803e 804a 804e 8052 8055 8059
805d 805f 8063 8067 806b 806e 8072 8076
8078 8079 807e 1 8082 8086 808a 808d
8091 8095 8099 809d 80a0 80a4 80a8 80ab
80ae 80b3 80b6 80b9 80bc 80bd 80c2 80c3
1 80c5 80ca 80ce 80d2 80d5 80da 80df
80e2 80e6 80e7 80ec 80ef 80f4 80f5 80fa
80fd 8102 8103 8108 810b 810f 8110 8115
8118 811d 811e 8123 8126 812a 812e 8131
8134 8135 8137 8138 813d 813e 8143 8145
8149 814c 814e 8152 8154 8160 8162 8164
8165 816a 816e 8170 817c 817e 8182 8186
818a 818e 8192 8196 819a 819e 81a2 81a6
81b2 81b6 81ba 81bd 81c1 81c5 81c7 81cb
81cf 81d3 81d6 81da 81de 81e0 81e1 81e6
1 81ea 81ee 81f2 81f5 81f9 81fd 8201
8205 8208 820c 8210 8213 8216 821b 821e
8221 8224 8225 822a 822b 1 822d 8232
8236 823a 823d 8242 8247 824a 824e 824f
8254 8257 825c 825d 8262 8265 826a 826b
8270 8273 8277 8278 827d 8280 8285 8286
828b 828e 8292 8296 8299 829c 829d 829f
82a0 82a5 82a6 82ab 82ad 82b1 82b4 82b6
82ba 82bc 82c8 82ca 82cc 82cd 82d2 82d6
82d8 82e4 82e6 82ea 82ed 82f1 82f5 82f9
82fd 8301 8305 8308 8309 830b 830e 8311
8312 8317 831b 831e 8322 8324 8328 832b
832f 8333 8337 833b 833f 8343 8347 834b
834f 8353 8357 835b 835f 8363 8367 836b
836f 8373 8377 837b 837f 8383 8387 838b
838f 8393 8397 839b 839f 83a3 83a6 83a9
83ac 83af 83b2 83b5 83b6 83b8 83bc 83c0
83c3 83c6 83c7 83cc 83d0 83d4 83d7 83d8
83da 83dd 83e0 83e1 83e6 83ea 83ee 83f2
83f6 8402 8406 840b 840f 8412 8413 8418
841c 8420 8423 8426 842a 842c 8430 8434
8437 843a 843e 8440 8444 8448 844b 844d
8451 8455 8459 845c 8460 8464 8466 8467
846c 1 8470 8474 8478 847b 847f 8483
8487 848b 848e 8492 8496 8499 849c 84a1
84a4 84a7 84aa 84ab 84b0 84b1 1 84b3
84b8 84bc 84c0 84c3 84c8 84cd 84d0 84d4
84d5 84da 84dd 84e2 84e3 84e8 84eb 84f0
84f1 84f6 84f9 84fd 84fe 8503 8506 850b
850c 8511 8514 8518 851c 851f 8522 8523
8525 8526 852b 852c 8531 8533 8537 853a
853c 8540 8542 854e 8550 8552 8553 8558
855c 855e 856a 856c 856e 8572 8576 857a
857e 858a 858e 8593 8597 859a 859b 85a0
85a4 85a8 85ab 85ae 85b2 85b4 85b8 85bc
85bf 85c2 85c6 85c8 85cc 85d0 85d3 85d5
85d9 85dd 85e1 85e4 85e8 85ec 85ee 85ef
85f4 1 85f8 85fc 8600 8603 8607 860b
860f 8613 8616 861a 861e 8621 8624 8629
862c 862f 8632 8633 8638 8639 1 863b
8640 8644 8648 864b 8650 8655 8658 865c
865d 8662 8665 866a 866b 8670 8673 8678
8679 867e 8681 8685 8686 868b 868e 8693
8694 8699 869c 86a0 86a4 86a7 86aa 86ab
86ad 86ae 86b3 86b4 86b9 86bb 86bf 86c2
86c4 86c8 86ca 86d6 86d8 86da 86db 86e0
86e4 86e6 86f2 86f4 86f6 86fa 86fe 8701
8703 8707 870a 870e 8710 8714 8718 871b
871c 871e 8721 8724 8725 872a 872e 8732
8736 873a 873e 8742 8746 874a 874d 8750
8751 8753 8756 875b 875c 8761 8765 8769
876d 8770 8774 8776 877a 877e 8782 8785
8786 8788 878c 878e 8792 8796 8799 879d
87a1 87a5 87a9 87ad 87b1 87b5 87b9 87bd
87c1 87c5 87c9 87cd 87d1 87d5 87d9 87dd
87e1 87e5 87e9 87ed 87f1 87f5 87f9 87fd
8801 8805 8809 880d 8811 8814 8817 881a
881d 8820 8823 8824 8826 882a 882e 8831
8834 8835 883a 883e 8842 8846 884a 8856
885a 885f 8863 8866 8867 886c 8870 8874
8877 887a 887e 8880 8884 8888 888b 888e
8892 8894 8898 889c 889f 88a1 88a5 88a9
88ad 88b0 88b4 88b8 88ba 88bb 88c0 1
88c4 88c8 88cc 88cf 88d3 88d7 88db 88df
88e2 88e6 88ea 88ed 88f0 88f5 88f8 88fb
88fe 88ff 8904 8905 1 8907 890c 8910
8914 8917 891c 8921 8924 8928 8929 892e
8931 8936 8937 893c 893f 8944 8945 894a
894d 8951 8952 8957 895a 895f 8960 8965
8968 896c 8970 8973 8976 8977 8979 897a
897f 8980 8985 8987 898b 898e 8990 8994
8996 89a2 89a4 89a6 89a7 89ac 89b0 89b2
89be 89c0 89c2 89c6 89c9 89cb 89cf 89d3
89d6 89da 89de 89e2 89e5 89e6 89e8 89eb
89ee 89ef 89f4 89f8 8a00 8a02 8a03 8a06
8a08 8a0c 8a13 8a15 8a19 8a1c 8a1e 8a22
8a26 8a29 8a2d 8a30 8a33 8a34 8a39 8a3c
8a40 8a44 8a47 8a48 8a4a 8a4d 8a50 8a51
8a56 1 8a59 8a5e 8a62 8a66 8a69 8a6a
8a6c 8a6f 8a72 8a73 8a78 8a7c 8a80 8a84
8a90 8a94 8a99 8a9d 8aa0 8aa1 8aa6 8aaa
8aae 8ab1 8ab4 8ab8 8aba 8abe 8ac2 8ac5
8ac8 8acc 8ace 8ad2 8ad6 8ad9 8adb 8adf
8ae3 8ae7 8aea 8aee 8af2 8af4 8af5 8afa
1 8afe 8b02 8b06 8b09 8b0d 8b11 8b15
8b19 8b1c 8b20 8b24 8b27 8b2a 8b2f 8b32
8b35 8b38 8b39 8b3e 8b3f 1 8b41 8b46
8b4a 8b4e 8b51 8b56 8b5b 8b5e 8b62 8b63
8b68 8b6b 8b70 8b71 8b76 8b79 8b7e 8b7f
8b84 8b87 8b8b 8b8c 8b91 8b94 8b99 8b9a
8b9f 8ba2 8ba6 8baa 8bad 8bb0 8bb1 8bb3
8bb4 8bb9 8bba 8bbf 8bc1 8bc5 8bc8 8bca
8bce 8bd0 8bdc 8bde 8be0 8be1 8be6 8bea
8bec 8bf8 8bfa 8bfc 8c00 8c04 8c08 8c0c
8c10 8c14 8c18 8c24 8c28 8c2d 8c31 8c34
8c35 8c3a 8c3e 8c42 8c45 8c48 8c4c 8c4e
8c52 8c56 8c59 8c5c 8c60 8c62 8c66 8c6a
8c6d 8c6f 8c73 8c77 8c7b 8c7e 8c82 8c86
8c88 8c89 8c8e 1 8c92 8c96 8c9a 8c9d
8ca1 8ca5 8ca9 8cad 8cb0 8cb4 8cb8 8cbb
8cbe 8cc3 8cc6 8cc9 8ccc 8ccd 8cd2 8cd3
1 8cd5 8cda 8cde 8ce2 8ce5 8cea 8cef
8cf2 8cf6 8cf7 8cfc 8cff 8d04 8d05 8d0a
8d0d 8d12 8d13 8d18 8d1b 8d1f 8d20 8d25
8d28 8d2d 8d2e 8d33 8d36 8d3a 8d3e 8d41
8d44 8d45 8d47 8d48 8d4d 8d4e 8d53 8d55
8d59 8d5c 8d5e 8d62 8d64 8d70 8d72 8d74
8d75 8d7a 8d7e 8d80 8d8c 8d8e 8d90 8d94
8d98 8d9b 8d9f 8da2 8da5 8da6 8dab 8daf
8db3 8db6 8dba 8dbe 8dc1 8dc4 8dc9 8dcc
8dcf 8dd2 8dd3 8dd8 8dd9 1 8ddb 8de0
8de4 8de8 8deb 8df0 8df5 8df8 8dfc 8dfd
8e02 8e05 8e0a 8e0b 8e10 8e13 8e18 8e19
8e1e 8e21 8e25 8e29 8e2d 8e31 8e34 8e35
8e37 8e3c 8e3d 8e3f 8e40 8e45 8e48 8e4d
8e4e 8e53 8e56 8e5b 8e5c 8e61 8e64 8e68
8e69 8e6e 8e71 8e76 8e77 8e7c 8e7d 8e82
8e84 8e88 8e8b 8e8f 8e93 8e96 8e9a 8e9e
8ea1 8ea4 8ea9 8eac 8eaf 8eb2 8eb3 8eb8
8eb9 1 8ebb 8ec0 8ec4 8ec8 8ecb 8ed0
8ed5 8ed8 8edc 8edd 8ee2 8ee3 8ee8 8eea
8eee 8ef1 8ef5 8ef9 8efc 8f00 8f04 8f07
8f0b 8f0f 8f10 8f15 8f19 8f1b 8f1f 8f23
8f26 8f2a 8f2d 8f2e 8f33 8f37 8f3b 8f3e
8f42 8f46 8f49 8f4c 8f51 8f54 8f57 8f5a
8f5b 8f60 8f61 1 8f63 8f68 8f6c 8f70
8f73 8f78 8f7d 8f80 8f84 8f85 8f8a 8f8d
8f92 8f93 8f98 8f9b 8fa0 8fa1 8fa6 8fa9
8fad 8fb1 8fb5 8fb9 8fbc 8fbd 8fbf 8fc4
8fc5 8fc7 8fc8 8fcd 8fd0 8fd5 8fd6 8fdb
8fde 8fe3 8fe4 8fe9 8fec 8ff0 8ff1 8ff6
8ff9 8ffe 8fff 9004 9005 900a 900c 9010
9013 9017 901b 901e 9022 9026 9029 902c
9031 9034 9037 903a 903b 9040 9041 1
9043 9048 904c 9050 9053 9058 905d 9060
9064 9065 906a 906b 9070 9072 9076 9079
907d 9081 9084 9088 908c 908f 9093 9097
9098 909d 90a1 90a3 90a7 90ab 90af 90b2
90b6 90b9 90ba 90bf 90c3 90c7 90ca 90ce
90d2 90d5 90d8 90dd 90e0 90e3 90e6 90e7
90ec 90ed 1 90ef 90f4 90f8 90fc 90ff
9104 9109 910c 9110 9111 9116 9119 911e
911f 9124 9127 912c 912d 9132 9135 9139
913d 9141 9145 9148 9149 914b 9150 9151
9153 9154 9159 915c 9161 9162 9167 916a
916f 9170 9175 9178 917c 917d 9182 9185
918a 918b 9190 9191 9196 9198 919c 919f
91a3 91a7 91aa 91ae 91b2 91b5 91b8 91bd
91c0 91c3 91c6 91c7 91cc 91cd 1 91cf
91d4 91d8 91dc 91df 91e4 91e9 91ec 91f0
91f1 91f6 91f7 91fc 91fe 9202 9205 9209
920d 9210 9214 9218 921b 921f 9223 9224
9229 922b 922f 9233 9237 923a 923e 9242
9245 9248 924d 9250 9253 9256 9257 925c
925d 1 925f 9264 9268 926c 926f 9274
9279 927c 9280 9281 9286 9289 928e 928f
9294 9297 929c 929d 92a2 92a5 92a9 92ad
92b1 92b5 92b8 92b9 92bb 92c0 92c1 92c3
92c4 92c9 92cc 92d1 92d2 92d7 92da 92df
92e0 92e5 92e8 92ec 92ed 92f2 92f5 92fa
92fb 9300 9301 9306 9308 930c 930f 9313
9317 931a 931e 9322 9325 9328 932d 9330
9333 9336 9337 933c 933d 1 933f 9344
9348 934c 934f 9354 9359 935c 9360 9361
9366 9367 936c 936e 9372 9375 9379 937d
9380 9384 9388 938b 938f 9393 9394 9399
939b 939f 93a3 93a6 93a8 93ac 93af 93b3
93b7 93bb 93bc 93be 93c1 93c2 93c4 93c7
93ca 93cb 93d0 93d3 93d7 93db 93df 93e0
93e2 93e5 93e6 93e8 93eb 93ee 93ef 93f4
1 93f7 93fc 9400 9404 9409 940e 9412
9416 941a 941d 9420 9424 9428 942d 9430
9435 9436 943b 943e 9443 9444 9449 944c
9451 9452 9457 945a 945f 9460 9465 9468
946d 946e 9473 9476 947a 947b 9480 9483
9488 9489 948e 9491 9496 9497 949c 949f
94a3 94a4 94a9 94ac 94b1 94b2 94b7 94ba
94be 94bf 94c4 94c7 94cc 94cd 94d2 94d6
94da 94de 94e2 94e7 94eb 94ef 94f4 94f8
94fb 94fc 9501 9505 9509 950c 950f 9513
9515 9519 951d 9520 9523 9527 9529 952d
9531 9534 9536 953a 953e 9542 9545 9549
954d 954f 9550 9555 1 9559 955d 9561
9564 9568 956c 9570 9574 9577 957b 957f
9582 9585 958a 958d 9590 9593 9594 9599
959a 1 959c 95a1 95a5 95a9 95ac 95b1
95b6 95b9 95bd 95be 95c3 95c6 95cb 95cc
95d1 95d4 95d9 95da 95df 95e2 95e6 95e7
95ec 95ef 95f4 95f5 95fa 95fd 9601 9605
9608 960b 960c 960e 960f 9614 9615 961a
961e 9622 9625 962a 962f 9632 9636 9637
963c 963d 9642 9644 9648 964b 964d 9651
9653 965f 9661 9663 9664 9669 966d 966f
967b 967d 9681 9685 968a 968f 9693 9697
969b 969e 96a1 96a5 96a9 96ae 96b1 96b6
96b7 96bc 96bf 96c4 96c5 96ca 96cd 96d2
96d3 96d8 96db 96e0 96e1 96e6 96e9 96ee
96ef 96f4 96f7 96fb 96fc 9701 9704 9709
970a 970f 9712 9717 9718 971d 9720 9724
9725 972a 972d 9732 9733 9738 973b 973f
9740 9745 9748 974d 974e 9753 9757 975b
975f 9763 9768 976c 9770 9775 9779 977c
977d 9782 9786 978a 978d 9790 9794 9796
979a 979e 97a1 97a4 97a8 97aa 97ae 97b2
97b5 97b7 97bb 97bf 97c3 97c6 97ca 97ce
97d0 97d1 97d6 1 97da 97de 97e2 97e5
97e9 97ed 97f1 97f5 97f8 97fc 9800 9803
9806 980b 980e 9811 9814 9815 981a 981b
1 981d 9822 9826 982a 982d 9832 9837
983a 983e 983f 9844 9847 984c 984d 9852
9855 985a 985b 9860 9863 9867 9868 986d
9870 9875 9876 987b 987e 9882 9886 9889
988c 988d 988f 9890 9895 9896 989b 989f
98a3 98a6 98ab 98b0 98b3 98b7 98b8 98bd
98be 98c3 98c5 98c9 98cc 98ce 98d2 98d4
98e0 98e2 98e4 98e5 98ea 98ee 98f0 98fc
98fe 9902 9906 9909 990d 990e 9913 9917
991b 9920 9923 9928 9929 992e 9931 9936
9937 993c 993f 9944 9945 994a 994d 9952
9953 9958 995b 9960 9961 9966 9969 996e
996f 9974 9977 997c 997d 9982 9985 998a
998b 9990 9993 9998 9999 999e 99a1 99a6
99a7 99ac 99af 99b4 99b5 99ba 99bd 99c2
99c3 99c8 99cb 99cf 99d0 99d5 99d8 99dd
99de 99e3 99e6 99eb 99ec 99f1 99f4 99f8
99f9 99fe 9a01 9a06 9a07 9a0c 9a0f 9a14
9a15 9a1a 9a1d 9a22 9a23 9a28 9a2b 9a2f
9a30 9a35 9a38 9a3d 9a3e 9a43 9a46 9a4b
9a4c 9a51 9a54 9a59 9a5a 9a5f 9a62 9a67
9a68 9a6d 9a70 9a75 9a76 9a7b 9a7e 9a83
9a84 9a89 9a8c 9a91 9a92 9a97 9a9a 9a9f
9aa0 9aa5 9aa8 9aad 9aae 9ab3 9ab6 9aba
9abb 9ac0 9ac3 9ac8 9ac9 9ace 9ad1 9ad6
9ad7 9adc 9adf 9ae4 9ae5 9aea 9aed 9af2
9af3 9af8 9afb 9b00 9b01 9b06 9b09 9b0d
9b0e 9b13 9b16 9b1b 9b1c 9b21 9b24 9b29
9b2a 9b2f 9b33 9b37 9b3b 9b3f 9b44 9b48
9b4c 9b51 9b55 9b58 9b59 9b5e 9b62 9b66
9b69 9b6c 9b70 9b72 9b76 9b7a 9b7d 9b80
9b84 9b86 9b8a 9b8e 9b91 9b93 9b97 9b9b
9b9f 9ba2 9ba6 9baa 9bac 9bad 9bb2 1
9bb6 9bba 9bbe 9bc1 9bc5 9bc9 9bcd 9bd1
9bd4 9bd8 9bdc 9bdf 9be2 9be7 9bea 9bed
9bf0 9bf1 9bf6 9bf7 1 9bf9 9bfe 9c02
9c06 9c09 9c0e 9c13 9c16 9c1a 9c1b 9c20
9c23 9c28 9c29 9c2e 9c31 9c36 9c37 9c3c
9c3f 9c43 9c44 9c49 9c4c 9c51 9c52 9c57
9c5a 9c5e 9c62 9c65 9c68 9c69 9c6b 9c6c
9c71 9c72 9c77 9c7b 9c7f 9c82 9c87 9c8c
9c8f 9c93 9c94 9c99 9c9a 9c9f 9ca1 9ca5
9ca8 9caa 9cae 9cb0 9cbc 9cbe 9cc0 9cc1
9cc6 9cca 9ccc 9cd8 9cda 9cde 9ce3 9ce6
9ceb 9cec 9cf1 9cf4 9cf9 9cfa 9cff 9d02
9d07 9d08 9d0d 9d10 9d14 9d18 9d1c 9d1f
9d20 9d22 9d23 9d25 9d26 9d2b 9d2e 9d33
9d34 9d39 9d3c 9d41 9d42 9d47 9d4a 9d4e
9d52 9d56 9d59 9d5a 9d5c 9d5d 9d5f 9d60
9d65 9d68 9d6d 9d6e 9d73 9d76 9d7b 9d7c
9d81 9d84 9d89 9d8a 9d8f 9d92 9d97 9d98
9d9d 9da0 9da5 9da6 9dab 9dae 9db3 9db4
9db9 9dbc 9dc1 9dc2 9dc7 9dca 9dcf 9dd0
9dd5 9dd8 9ddd 9dde 9de3 9de6 9deb 9dec
9df1 9df4 9df9 9dfa 9dff 9e02 9e06 9e0a
9e0e 9e11 9e12 9e14 9e15 9e17 9e18 9e1d
9e20 9e25 9e26 9e2b 9e2e 9e33 9e34 9e39
9e3c 9e40 9e44 9e48 9e4b 9e4c 9e4e 9e4f
9e51 9e52 9e57 9e5a 9e5f 9e60 9e65 9e68
9e6d 9e6e 9e73 9e76 9e7b 9e7c 9e81 9e84
9e89 9e8a 9e8f 9e92 9e97 9e98 9e9d 9ea0
9ea5 9ea6 9eab 9eaf 9eb3 9eb5 9eb9 9ebd
9ec1 9ec2 9ec4 9ec7 9ec8 9eca 9ecd 9ed0
9ed1 9ed6 9eda 9ede 9ee3 9ee8 9eec 9ef0
9ef4 9ef7 9efa 9efe 9f02 9f07 9f0a 9f0f
9f10 9f15 9f18 9f1d 9f1e 9f23 9f26 9f2b
9f2c 9f31 9f34 9f39 9f3a 9f3f 9f42 9f47
9f48 9f4d 9f50 9f54 9f55 9f5a 9f5d 9f62
9f63 9f68 9f6b 9f70 9f71 9f76 9f79 9f7d
9f7e 9f83 9f86 9f8b 9f8c 9f91 9f95 9f99
9f9d 9fa1 9fa6 9faa 9fae 9fb3 9fb7 9fba
9fbb 9fc0 9fc4 9fc8 9fcb 9fce 9fd2 9fd4
9fd8 9fdc 9fdf 9fe2 9fe6 9fe8 9fec 9ff0
9ff3 9ff5 9ff9 9ffd a001 a004 a008 a00c
a00e a00f a014 1 a018 a01c a020 a023
a027 a02b a02f a033 a036 a03a a03e a041
a044 a049 a04c a04f a052 a053 a058 a059
1 a05b a060 a064 a068 a06b a070 a075
a078 a07c a07d a082 a085 a08a a08b a090
a093 a098 a099 a09e a0a1 a0a5 a0a6 a0ab
a0ae a0b3 a0b4 a0b9 a0bc a0c0 a0c4 a0c7
a0ca a0cb a0cd a0ce a0d3 a0d4 a0d9 a0dd
a0e1 a0e4 a0e9 a0ee a0f1 a0f5 a0f6 a0fb
a0fc a101 a103 a107 a10a a10c a110 a112
a11e a120 a122 a123 a128 a12c a12e a13a
a13c a140 a144 a149 a14e a152 a156 a15a
a15d a160 a164 a168 a16d a170 a175 a176
a17b a17e a183 a184 a189 a18c a191 a192
a197 a19a a19f a1a0 a1a5 a1a8 a1ad a1ae
a1b3 a1b6 a1ba a1bb a1c0 a1c3 a1c8 a1c9
a1ce a1d1 a1d5 a1d6 a1db a1de a1e3 a1e4
a1e9 a1ed a1f1 a1f5 a1f9 a1fe a202 a206
a20b a20f a212 a213 a218 a21c a220 a223
a226 a22a a22c a230 a234 a237 a23a a23e
a240 a244 a248 a24b a24d a251 a255 a259
a25c a260 a264 a266 a267 a26c 1 a270
a274 a278 a27b a27f a283 a287 a28b a28e
a292 a296 a299 a29c a2a1 a2a4 a2a7 a2aa
a2ab a2b0 a2b1 1 a2b3 a2b8 a2bc a2c0
a2c3 a2c8 a2cd a2d0 a2d4 a2d5 a2da a2dd
a2e2 a2e3 a2e8 a2eb a2f0 a2f1 a2f6 a2f9
a2fd a2fe a303 a306 a30b a30c a311 a314
a318 a31c a31f a322 a323 a325 a326 a32b
a32c a331 a335 a339 a33c a341 a346 a349
a34d a34e a353 a354 a359 a35b a35f a362
a364 a368 a36a a376 a378 a37a a37b a380
a384 a386 a392 a394 a398 a39c a39f a3a3
a3a4 a3a9 a3ad a3b1 a3b6 a3b9 a3be a3bf
a3c4 a3c7 a3cc a3cd a3d2 a3d5 a3da a3db
a3e0 a3e3 a3e8 a3e9 a3ee a3f1 a3f6 a3f7
a3fc a3ff a404 a405 a40a a40d a412 a413
a418 a41b a420 a421 a426 a429 a42e a42f
a434 a437 a43b a43c a441 a444 a449 a44a
a44f a452 a457 a458 a45d a460 a464 a465
a46a a46d a472 a473 a478 a47b a480 a481
a486 a489 a48e a48f a494 a497 a49b a49c
a4a1 a4a4 a4a9 a4aa a4af a4b3 a4b7 a4bb
a4bf a4c4 a4c8 a4cc a4d1 a4d5 a4d8 a4d9
a4de a4e2 a4e6 a4e9 a4ec a4f0 a4f2 a4f6
a4fa a4fd a500 a504 a506 a50a a50e a511
a513 a517 a51b a51f a522 a526 a52a a52c
a52d a532 1 a536 a53a a53e a541 a545
a549 a54d a551 a554 a558 a55c a55f a562
a567 a56a a56d a570 a571 a576 a577 1
a579 a57e a582 a586 a589 a58e a593 a596
a59a a59b a5a0 a5a3 a5a8 a5a9 a5ae a5b1
a5b6 a5b7 a5bc a5bf a5c3 a5c4 a5c9 a5cc
a5d1 a5d2 a5d7 a5da a5de a5e2 a5e5 a5e8
a5e9 a5eb a5ec a5f1 a5f2 a5f7 a5fb a5ff
a602 a607 a60c a60f a613 a614 a619 a61a
a61f a621 a625 a628 a62a a62e a630 a63c
a63e a640 a641 a646 a64a a64c a658 a65a
a65e a663 a666 a66b a66c a671 a674 a679
a67a a67f a682 a687 a688 a68d a690 a694
a698 a69c a69f a6a0 a6a2 a6a3 a6a5 a6a6
a6ab a6ae a6b3 a6b4 a6b9 a6bc a6c0 a6c4
a6c8 a6cb a6cc a6ce a6cf a6d1 a6d2 a6d7
a6da a6df a6e0 a6e5 a6e8 a6ed a6ee a6f3
a6f6 a6fb a6fc a701 a704 a709 a70a a70f
a712 a717 a718 a71d a720 a725 a726 a72b
a72e a733 a734 a739 a73d a73f a743 a747
a74b a750 a755 a759 a75d a761 a764 a767
a76b a76f a774 a777 a77c a77d a782 a785
a78a a78b a790 a793 a798 a799 a79e a7a1
a7a6 a7a7 a7ac a7af a7b4 a7b5 a7ba a7bd
a7c2 a7c3 a7c8 a7cb a7cf a7d0 a7d5 a7d8
a7dd a7de a7e3 a7e6 a7eb a7ec a7f1 a7f4
a7f8 a7f9 a7fe a801 a806 a807 a80c a80f
a814 a815 a81a a81e a822 a826 a82a a82f
a833 a837 a83c a840 a843 a844 a849 a84d
a851 a854 a857 a85b a85d a861 a865 a868
a86b a86f a871 a875 a879 a87c a87e a882
a886 a88a a88d a891 a895 a897 a898 a89d
1 a8a1 a8a5 a8a9 a8ac a8b0 a8b4 a8b8
a8bc a8bf a8c3 a8c7 a8ca a8cd a8d2 a8d5
a8d8 a8db a8dc a8e1 a8e2 1 a8e4 a8e9
a8ed a8f1 a8f4 a8f9 a8fe a901 a905 a906
a90b a90e a913 a914 a919 a91c a921 a922
a927 a92a a92e a92f a934 a937 a93c a93d
a942 a945 a949 a94d a950 a953 a954 a956
a957 a95c a95d a962 a966 a96a a96d a972
a977 a97a a97e a97f a984 a985 a98a a98c
a990 a993 a995 a999 a99b a9a7 a9a9 a9ab
a9ac a9b1 a9b5 a9b7 a9c3 a9c5 a9c9 a9cd
a9d2 a9d7 a9db a9df a9e3 a9e6 a9e9 a9ed
a9f1 a9f6 a9f9 a9fe a9ff aa04 aa07 aa0c
aa0d aa12 aa15 aa1a aa1b aa20 aa23 aa28
aa29 aa2e aa31 aa36 aa37 aa3c aa3f aa43
aa44 aa49 aa4c aa51 aa52 aa57 aa5a aa5e
aa5f aa64 aa67 aa6c aa6d aa72 aa76 aa7a
aa7e aa82 aa87 aa8b aa8f aa94 aa98 aa9b
aa9c aaa1 aaa5 aaa9 aaac aaaf aab3 aab5
aab9 aabd aac0 aac3 aac7 aac9 aacd aad1
aad4 aad6 aada aade aae2 aae5 aae9 aaed
aaef aaf0 aaf5 1 aaf9 aafd ab01 ab04
ab08 ab0c ab10 ab14 ab17 ab1b ab1f ab22
ab25 ab2a ab2d ab30 ab33 ab34 ab39 ab3a
1 ab3c ab41 ab45 ab49 ab4c ab51 ab56
ab59 ab5d ab5e ab63 ab66 ab6b ab6c ab71
ab74 ab79 ab7a ab7f ab82 ab86 ab87 ab8c
ab8f ab94 ab95 ab9a ab9d aba1 aba5 aba8
abab abac abae abaf abb4 abb5 abba abbe
abc2 abc5 abca abcf abd2 abd6 abd7 abdc
abdd abe2 abe4 abe8 abeb abed abf1 abf3
abff ac01 ac03 ac04 ac09 ac0d ac0f ac1b
ac1d ac21 ac25 ac28 ac2c ac2d ac32 ac36
ac3a ac3f ac42 ac47 ac48 ac4d ac50 ac55
ac56 ac5b ac5e ac63 ac64 ac69 ac6c ac71
ac72 ac77 ac7a ac7f ac80 ac85 ac88 ac8d
ac8e ac93 ac96 ac9b ac9c aca1 aca4 aca9
acaa acaf acb2 acb7 acb8 acbd acc0 acc4
acc5 acca accd acd2 acd3 acd8 acdb ace0
ace1 ace6 ace9 acee acef acf4 acf7 acfc
acfd ad02 ad05 ad09 ad0a ad0f ad12 ad17
ad18 ad1d ad21 ad25 ad29 ad2d ad32 ad36
ad3a ad3f ad43 ad46 ad47 ad4c ad50 ad54
ad57 ad5a ad5e ad60 ad64 ad68 ad6b ad6e
ad72 ad74 ad78 ad7c ad7f ad81 ad85 ad89
ad8d ad90 ad94 ad98 ad9a ad9b ada0 1
ada4 ada8 adac adaf adb3 adb7 adbb adbf
adc2 adc6 adca adcd add0 add5 add8 addb
adde addf ade4 ade5 1 ade7 adec adf0
adf4 adf7 adfc ae01 ae04 ae08 ae09 ae0e
ae11 ae16 ae17 ae1c ae1f ae24 ae25 ae2a
ae2d ae31 ae32 ae37 ae3a ae3f ae40 ae45
ae48 ae4c ae50 ae53 ae56 ae57 ae59 ae5a
ae5f ae60 ae65 ae69 ae6d ae70 ae75 ae7a
ae7d ae81 ae82 ae87 ae88 ae8d ae8f ae93
ae96 ae98 ae9c ae9e aeaa aeac aeae aeaf
aeb4 aeb8 aeba aec6 aec8 aecc aed1 aed4
aed9 aeda aedf aee2 aee7 aee8 aeed aef0
aef5 aef6 aefb aefe af02 af06 af0a af0d
af0e af10 af11 af13 af14 af19 af1c af21
af22 af27 af2a af2f af30 af35 af38 af3c
af40 af44 af47 af48 af4a af4b af4d af4e
af53 af56 af5b af5c af61 af64 af69 af6a
af6f af72 af77 af78 af7d af80 af85 af86
af8b af8e af93 af94 af99 af9c afa1 afa2
afa7 afaa afaf afb0 afb5 afb8 afbd afbe
afc3 afc7 afc9 afcd afd1 afd4 afd8 afdc
afdf afe3 afe7 afea afed aff2 aff5 aff8
affb affc b001 b002 1 b004 b009 b00d
b011 b014 b019 b01e b021 b025 b026 b02b
b02c b031 b033 b037 b03a b03e b042 b045
b049 b04d b050 b053 b058 b05b b05e b061
b062 b067 b068 1 b06a b06f b073 b077
b07a b07f b084 b087 b08b b08c b091 b092
b097 b099 b09d b0a0 b0a4 b0a8 b0ac b0af
b0b3 b0b4 b0b6 b0ba b0bc b0c0 b0c4 b0c7
b0cb b0cf b0d2 b0d6 b0da b0dd b0e0 b0e5
b0e8 b0eb b0ee b0ef b0f4 b0f5 1 b0f7
b0fc b100 b104 b107 b10c b111 b114 b118
b119 b11e b11f b124 b128 b12c b12f b134
b139 b13c b140 b144 b147 b148 b14d b150
b155 b156 b15b b15e b162 b166 b169 b16a
b16f b170 b175 b177 b17b b17e b182 b186
b18a b18e b192 b196 b19a b19e b1a2 b1ae
b1b3 b1b7 b1bb b1bf b1c3 b1c5 b1c6 b1cb
1 b1cf b1d3 b1d7 b1da b1de b1e2 b1e6
b1ea b1ed b1f1 b1f5 b1f8 b1fb b200 b203
b206 b209 b20a b20f b210 1 b212 b217
b21b b21f b222 b227 b22c b22f b233 b234
b239 b23a b23f b243 b247 b24a b24f b254
b257 b25b b25c b261 b264 b269 b26a b26f
b272 b276 b27a b27d b280 b281 b283 b284
b289 b28a b28f b291 b295 b298 b29c b2a0
b2a4 b2a8 b2ac b2b0 b2b4 b2c0 b2c5 b2c9
b2cd b2d1 b2d5 b2d7 b2db b2dd b2e9 b2eb
b2ed b2ee b2f3 b2f7 b2f9 b305 b309 b30b
b30c b315 
3392
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 10 :3 6 e :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 14 1d
1c :2 14 :2 4 e 17 16 :2 e :2 4
f 18 17 :2 f :2 4 f 18 17
:2 f :2 4 d 16 15 :2 d :2 4 12
1b 1a :2 12 :2 4 11 1a 19 :2 11
:2 4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 :3 10 :2 4 :3 f :2 4 f
18 17 :2 f :2 4 10 19 18 :2 10
:2 4 10 19 18 :2 10 :2 4 f 18
17 :2 f :2 4 10 19 18 :2 10 :2 4
10 19 18 :2 10 :2 4 :2 c 1b c
:2 4 :2 e 1d e :2 4 :2 b 1a b
:2 4 :2 10 1f 10 :2 4 :2 a 19 a
:2 4 :2 b 1a b :2 4 :2 11 20 11
:2 4 :2 d 1c d :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 c 1b c
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 12 21 12
:2 4 :2 f 1e f :2 4 :2 c 1b c
:2 4 :2 c 1b c :2 4 :2 f 1e f
:2 4 :2 11 20 11 :2 4 :2 11 20 11
:2 4 :2 16 25 16 :2 4 :2 16 25 16
:2 4 :2 b 1a b :2 4 d 16 15
:2 d :2 4 11 1a 19 :2 11 :2 4 :2 f
19 f :2 4 9 12 11 :2 9 :2 4
:2 17 26 17 :2 4 17 1c 1b :2 17
:2 4 18 1d 1c :2 18 :2 4 16 1f
1e :2 16 :2 4 :2 13 22 13 :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 14
1d 1c :2 14 :2 4 15 1e 1d :2 15
:2 4 :2 10 1f 10 :2 4 :2 f 1e f
:2 4 a 13 12 :2 a :2 4 :2 6 1e
6 :2 4 :2 7 1f 7 :2 4 :2 d 25
d :2 4 :2 8 20 8 :2 4 :3 d :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 53 59 5c :2 53 6a 7f 8
:2 6a d 10 :2 6a 17 1a :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
2c 2f :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 2d 30 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 34 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
2f :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 2e :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 34 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 34 :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 40 :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4e 4f :2 4b :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e :2 7 52 :3 4
14 :2 4 14 :2 4 13 :2 4 12 :2 4
10 :2 4 e :2 4 14 :2 4 f :2 4
12 :2 4 e :2 4 e :2 4 11 :2 4
11 :2 4 13 :2 4 11 :2 4 13 :2 4
17 :2 4 14 1d 26 2e :2 1d :2 14
:2 4 13 :2 4 12 :2 4 10 4 :4 8
7 a :2 14 26 :2 30 3c 3f 4e
51 52 :2 4e :2 26 :3 a :2 10 15 21
5f 62 :2 21 6f 72 :2 21 76 79
:2 21 83 86 8f 97 :2 a0 :2 8f b6
:2 86 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4e 51 52 :2 4e :2 26
:3 a :2 10 15 21 5f 62 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 46 :2 7 18
:2 4 :4 8 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b6 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 46
:2 7 1b :2 4 7 10 1b :2 7 1e
20 :2 1e 26 2f 37 :2 26 3a 3c
:2 3a :2 7 42 4b 53 :2 42 56 58
:2 56 :2 7 a :2 14 26 :2 30 3c 3f
4e 51 52 :2 4e :2 26 :3 a :2 10 15
21 5f 62 :2 21 6f 72 :2 21 76
79 :2 21 83 86 8f 97 :2 a0 :2 8f
b1 :2 86 :2 21 :2 a 55 :2 7 a :2 14
26 :2 30 3c 3f 4e 51 52 :2 4e
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:2 a 55 :3 7 :2 12 28 :2 31 41 :2 7
5a :2 4 :4 9 8 7 :4 2b 2a 29
:2 7 11 1c 21 33 3e 43 :2 f
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 8b 8e :2 27 96 99 :2 27 a5
a8 af b8 bb :2 a8 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 48 b :2 14
1f 1d :2 28 :2 1d a 3d 46 4f
:2 3d 52 54 :2 52 3c :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 62 65 :2 24
72 75 :2 24 79 7c :2 24 86 89
92 9a :2 a3 :2 92 c0 :2 89 :2 24 :2 d
58 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 62 65 :2 24 :2 d 58 :3 a :2 15
2b :2 34 50 :2 a 57 :3 7 e 7
4 48 :4 c b a :4 2a 29 28
:2 a 11 23 f :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 8b 8e :2 27
96 99 :2 27 a5 a8 af b8 bb
:2 a8 :2 27 :2 10 5c :2 d :2 a :4 16 :2 a
7 :4 43 48 :3 4 12 4 :4 8 :2 7
16 7 20 :3 4 10 17 21 24
:2 10 :2 4 12 19 25 28 :2 12 :2 4
13 4 7 10 18 :2 7 1b 1d
:2 1b 7 13 1a 21 2e 31 :2 1a
36 39 :2 13 :2 7 15 :2 1e 27 2a
2d 31 :2 15 7 a 18 21 29
:2 18 :2 a 2d 30 :2 2d 14 20 29
3f 48 60 12 20 2b 37 12
20 2d :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :4 32
14 16 1f 21 2c 2e 40 42
55 57 d 16 18 2e 37 39
51 53 12 1a 27 38 4a d
18 24 34 3c 3f 47 13 15
22 30 32 3e 47 4f 58 66
6f 7d 86 94 9d aa b3 c4
cd e0 e9 fe 107 122 12b 143
14c 15d 166 178 181 199 1a2 1b5
1be 1df 1e1 1ee 1f0 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :7 7 b :2 14 1f 1d :2 28
:2 1d a 14 20 2c 3a 12 20
2d :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :3 38 e
:2 17 22 20 :2 2b :2 20 d :4 11 :2 10
20 10 24 :2 d 17 20 36 3f
57 15 20 2c 15 23 30 :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5e
5f :2 5b :2 32 :3 16 :2 1c 21 2d 6b
6e :2 2d 7b 7e :2 2d 82 85 :2 2d
91 94 :2 2d 9c 9f :2 2d ab ae
b5 be c1 :2 ae :2 2d :2 16 62 :2 13
:2 10 :4 1c :2 10 d :4 3b 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 b9 :2 8c :2 27 c1 c4
:2 27 cc cf :2 27 d4 d7 :2 27 e1
e4 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 47 52 :2 d
:4 a 38 a 1a a :5 7 15 7
11 21 f 10 1d :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 1f a 13 1f :2 a 22
24 :2 22 14 24 12 13 20 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 26 d :2 18 1f
2d :2 d 32 34 :2 32 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 bb :2 8c :2 27 c3 c6
:2 27 ce d1 :2 27 d6 d9 :2 27 e6
e9 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 49 57 :2 d
36 :2 a 26 :2 7 1f 11 1a 30
39 51 f 1a 26 f 1d 2a
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 8b 8e :2 27 96 99 :2 27 a5
a8 af b8 bb :2 a8 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 4 b :2 14
1f 1d :2 28 :2 1d a 23 2e 3e
4e 5b :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 38
e :2 17 22 20 :2 2b :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 89
8c 95 9d :2 a6 :2 95 b7 :2 8c :2 27
bf c2 :2 27 ca cd :2 27 d2 d5
:2 27 e2 e5 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 :2 10 5b :3 d :2 18 2c :2 35 45
53 :2 d 3b :2 a 38 :2 7 :4 4 7
10 1d :2 7 22 20 :2 2b :2 20 44
4d 55 :2 44 58 5a :2 58 43 :2 7
11 17 2f f 10 1d e 18
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 8b 8e :2 27 96 99 :2 27 a5
a8 af b8 bb :2 a8 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 5d a 13
1f :2 a 22 24 :2 22 d 16 22
:2 d 28 25 :2 31 :2 25 45 10 1c
:2 45 22 1f :2 2b :2 1f :3 d 1b d
40 :3 a 11 :2 a 14 a 26 :2 7
5d a e 10 :2 e a 18 :2 a
19 :2 a 18 29 35 42 4b 54
:2 42 58 61 69 :2 58 22 2b 37
:2 22 3b 44 4f :2 3b 53 20 2b
:2 53 2f 38 46 :2 2f 4a 53 5e
:2 4a 22 2b 37 :2 22 3b 43 4d
:2 18 a d 16 22 :2 d 27 25
:2 30 :2 25 10 :2 1a 2c :2 36 42 45
54 57 58 :2 54 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 89 8c 95 9d :2 a6 :2 95
b7 :2 8c :2 27 :2 10 5b :2 d 10 :2 1a
2c :2 36 42 45 54 57 58 :2 54
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
:2 10 5b :3 d :2 18 2e :2 37 47 :2 d
a 3f 10 19 25 :2 10 28 2b
:2 28 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 89 8c 95 9d :2 95 aa :2 8c
:2 27 b2 b5 :2 27 bd c0 :2 27 c5
c8 :2 27 d5 d8 :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 :2 10 5b :3 d :2 18 2c 35
41 :2 2c 45 53 :2 d 2d 3f :3 a
19 a :4 e :2 d 1c d 23 :2 a
12 a 19 a d 16 1e :2 d
21 23 :2 21 d 17 20 28 :2 17
2b 2d 36 42 :2 2d :2 17 d 25
:2 a :4 7 b 14 1c :2 b 1f 21
:2 1f a 29 32 3a :2 29 3d 40
:2 3d 28 :2 a e 17 1f :2 e 22
24 :2 22 d 2b 34 3c :2 2b 3f
41 :2 3f 2a :3 d 18 d a 44
10 19 21 :2 10 24 26 :2 24 d
18 d a 28 44 11 1a 22
:2 11 25 27 :2 25 10 2e 37 3f
:2 2e 42 44 :2 42 2d :2 10 d 18
d a 47 44 10 19 21 :2 10
24 26 :2 24 d 18 d 28 44
:2 a 45 :2 7 :5 4 :3 17 :2 4 12 :2 4
13 :2 4 d :2 16 22 29 32 3e
:2 29 42 :2 4b :2 22 21 5a :2 d :2 4
12 19 22 2e :2 19 32 :2 3b :2 12
4 7 10 18 :2 7 1b 1d :2 1b
7 1a 29 37 3f 4a 54 25
:2 1a 7 a 13 1e :2 a 23 21
:2 2c :2 21 d 16 27 :2 d 2a 2c
:2 2a d 20 :2 29 d 2e :2 a d
:2 17 29 :2 33 3f 43 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 62 65
:2 24 72 75 :2 24 79 7c :2 24 86
89 92 9a :2 92 ac :2 89 :2 24 b4
b7 :2 24 bf c2 :2 24 c7 ca :2 24
d6 d9 :2 24 :2 d 59 :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 62 65 :2 24
:2 d 58 :3 a :2 15 29 32 43 :2 29
47 54 :2 a 40 :2 7 a 13 24
:2 a 27 2a :2 27 30 39 4a :2 30
4d 50 :2 4d :2 a d :2 17 29 :2 33
3f 43 52 55 56 :2 52 :2 29 :3 d
:2 13 18 24 62 65 :2 24 72 75
:2 24 79 7c :2 24 86 89 92 9a
:2 92 ac :2 89 :2 24 b4 b7 :2 24 bf
c2 :2 24 c7 ca :2 24 d6 d9 :2 24
:2 d 59 :2 a d :2 17 29 :2 33 3f
42 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 62 65 :2 24 :2 d 58 :3 a
:2 15 29 32 43 :2 29 47 54 :2 a
52 :3 7 15 7 11 15 24 2f
34 44 4f 54 58 f 1b f
10 1d e 18 e 1c e 1e
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
65 68 :2 27 75 78 :2 27 7c 7f
:2 27 8b 8e :2 27 96 99 :2 27 a5
a8 af b8 bb :2 a8 :2 27 :2 10 5c
:2 d :2 a :4 16 :2 a 7 :3 1f b :2 14
1f 1d :2 28 :2 1d a :4 3e 3d 3c
:3 a 18 a d 16 1f :2 d 22
24 :2 22 d 1d d 26 :2 a 57
:3 7 16 :2 7 12 7 a e 10
:2 e d 14 20 23 :2 d 26 28
:2 26 17 2e 1b 23 2a 48 50
57 70 78 7f 10 18 1f 3c
44 4b 64 6c 73 10 1e 39
15 26 32 3b 15 16 1e 2f
3b 48 5e :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5e 5f :2 5b :2 32 :3 16
:2 1c 21 2d 6b 6e :2 2d 7b 7e
:2 2d 82 85 :2 2d 91 94 :2 2d 9c
9f :2 2d ab ae b5 be c1 :2 ae
:2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10 d
:3 2c 11 :2 1a 25 23 :2 2e :2 23 :2 10
1e 10 14 1d 2b :2 14 2e 30
:2 2e 13 37 40 49 :2 37 4c 4e
:2 4c 36 :2 13 1d 34 21 29 30
4e 56 5d 78 80 87 16 1e
25 42 4a 51 6c 74 7b 16
26 1b 2c 38 1b 1c 24 35
41 4e 64 :2 16 :2 1f 2b 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 61 64 65 :2 61 :2 38 :3 1c
:2 22 27 33 71 74 :2 33 81 84
:2 33 88 8b :2 33 97 9a :2 33 a2
a5 :2 33 b1 b4 bb c4 c7 :2 b4
:2 33 :2 1c 68 :2 19 :2 16 :4 22 :2 16 13
:4 51 13 22 13 :4 10 d 3e 14
:2 1d 28 26 :2 31 :2 26 13 45 4e
57 :2 45 5a 5c :2 5a 44 :2 13 1a
31 1e 26 2d 4b 53 5a 75
7d 84 13 1b 22 3f 47 4e
69 71 78 13 23 18 29 35
18 19 21 32 3e 4b 61 :2 13
:2 1c 28 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5e 61
62 :2 5e :2 35 :3 19 :2 1f 24 30 6e
71 :2 30 7e 81 :2 30 85 88 :2 30
94 97 :2 30 9f a2 :2 30 ae b1
b8 c1 c4 :2 b1 :2 30 :2 19 65 :2 16
:2 13 :4 1f :2 13 10 :4 5f 3e :2 d 2c
17 2e 1a 22 29 47 4f 56
71 79 80 10 18 1f 3c 44
4b 66 6e 75 10 20 15 26
32 15 16 1e 2f 3b 48 5e
:2 10 :2 19 25 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5b
5e 5f :2 5b :2 32 :3 16 :2 1c 21 2d
6b 6e :2 2d 7b 7e :2 2d 82 85
:2 2d 91 94 :2 2d 9c 9f :2 2d ab
ae b5 be c1 :2 ae :2 2d :2 16 62
:2 13 :2 10 :4 1c :2 10 d :7 a 12 d
14 20 23 :2 d 26 28 :2 26 17
2e 44 4c 53 71 79 80 99
a1 a8 c2 ce ec 15 26 31
3a 15 16 1e 2f 3b 48 5e
:2 10 :2 19 25 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5b
5e 5f :2 5b :2 32 :3 16 :2 1c 21 2d
6b 6e :2 2d 7b 7e :2 2d 82 85
:2 2d 91 94 :2 2d 9c 9f :2 2d ab
ae b5 be c1 :2 ae :2 2d :2 16 62
:2 13 :2 10 :4 1c :2 10 d :3 2c 11 :2 1a
25 23 :2 2e :2 23 :2 10 1e 10 14
1d 2b :2 14 2e 30 :2 2e 13 37
40 49 :2 37 4c 4e :2 4c 36 :2 13
1d 34 4d 55 5c 75 7d 84
a0 ac 1b 2c 37 1b 1c 24
35 41 4e 64 :2 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 61 64 65 :2 61 :2 38
:3 1c :2 22 27 33 71 74 :2 33 81
84 :2 33 88 8b :2 33 97 9a :2 33
a2 a5 :2 33 b1 b4 bb c4 c7
:2 b4 :2 33 :2 1c 68 :2 19 :2 16 :4 22 :2 16
13 :4 51 13 22 :2 13 :4 10 d 3e
14 :2 1d 28 26 :2 31 :2 26 13 1a
31 49 51 58 76 7e 85 a0
a8 af cb d7 18 29 34 18
19 21 32 3e 4b 61 :2 13 :2 1c
28 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 5e 61 62
:2 5e :2 35 :3 19 :2 1f 24 30 6e 71
:2 30 7e 81 :2 30 85 88 :2 30 94
97 :2 30 9f a2 :2 30 ae b1 b8
c1 c4 :2 b1 :2 30 :2 19 65 :2 16 :2 13
:4 1f :2 13 10 :4 41 3e :2 d 2c 17
2e 46 4e 55 73 7b 82 9d
a5 ac c8 d4 15 26 31 15
16 1e 2f 3b 48 5e :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5e 5f
:2 5b :2 32 :3 16 :2 1c 21 2d 6b 6e
:2 2d 7b 7e :2 2d 82 85 :2 2d 91
94 :2 2d 9c 9f :2 2d ab ae b5
be c1 :2 ae :2 2d :2 16 62 :2 13 :2 10
:4 1c :2 10 d :7 a :4 7 b :2 14 1f
1d :2 28 :2 1d a d 16 1f :2 d
22 24 :2 22 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 89 8c 95 9d :2 a6
:2 95 be :2 8c :2 27 c6 c9 :2 27 d1
d4 :2 27 d9 dc :2 27 e5 e8 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 4c 56 :2 d a 26
:4 11 10 32 3b 45 :2 32 48 4a
:2 48 :3 10 14 16 :2 14 10 20 10
1a 1e 2e 18 19 26 37 4b
17 28 30 37 51 59 60 :2 13
:2 1c 28 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 5e 61
62 :2 5e :2 35 :3 19 :2 1f 24 30 6e
71 :2 30 7e 81 :2 30 85 88 :2 30
94 97 :2 30 9f a2 :2 30 ae b1
b8 c1 c4 :2 b1 :2 30 :2 19 65 :2 16
:2 13 :4 1f :2 13 10 :4 18 10 20 10
1a 1e 2e 18 19 26 37 4b
17 23 2b 32 :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 5e 61 62 :2 5e :2 35
:3 19 :2 1f 24 30 6e 71 :2 30 7e
81 :2 30 85 88 :2 30 94 97 :2 30
9f a2 :2 30 ae b1 b8 c1 c4
:2 b1 :2 30 :2 19 65 :2 16 :2 13 :4 1f :2 13
10 :7 d 10 19 27 :2 10 2c 2a
35 3f :2 2c :2 2a 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8c 8f 98 a0
:2 a9 :2 98 c1 :2 8f :2 2a c9 cc :2 2a
d4 d7 :2 2a dc df :2 2a e8 eb
:2 2a :2 13 5f :2 10 13 :2 1d 2f :2 39
45 48 57 5a 5b :2 57 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a :2 13 5e
:3 10 :2 1b 2f :2 38 4f 59 :2 10 42
:2 d 4c 26 :3 a 18 a 7 38
e 17 23 :2 e 26 28 :2 26 d
30 41 4a 52 :2 41 :2 30 2f 57
5a :2 57 :3 d :2 17 29 :2 33 3f 43
52 55 56 :2 52 :2 29 :3 d :2 13 18
24 62 65 :2 24 72 75 :2 24 79
7c :2 24 86 89 92 9a :2 a3 :2 92
bb :2 89 :2 24 c3 c6 :2 24 ce d1
:2 24 d6 d9 :2 24 e2 e5 :2 24 :2 d
59 :2 a d :2 17 29 :2 33 3f 42
51 54 55 :2 51 :2 29 :3 d :2 13 18
24 62 65 :2 24 :2 d 58 :3 a :2 15
29 :2 32 49 53 :2 a 5c 38 :2 7
a 11 1d 20 :2 a 23 25 :2 23
a 18 1f 2a 2d :2 1f 37 3a
:2 18 a 14 1f 2a 35 42 4a
53 5e 69 7c 85 90 9b 12
1f 2d 37 4a 12 13 21 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 29 e :2 17 22
20 :2 2b :2 20 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 89 8c 95 9d
:2 a6 :2 95 b9 :2 8c :2 27 c1 c4 :2 27
cc cf :2 27 d4 d7 :2 27 e0 e3
:2 27 :2 10 5c :2 d 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 :2 10 5b
:3 d :2 18 2c :2 35 47 51 :2 d 3b
:2 a e 15 1f 22 :2 e 25 27
:2 25 d 31 3a 4d :2 31 50 52
:2 50 30 5a 10 1e :2 5a 23 21
2c 3f :2 23 :2 21 59 :2 30 2f :2 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 75 78 :2 27 7c 7f :2 27
89 8c 95 9d :2 a6 :2 95 bc :2 8c
:2 27 c4 c7 :2 27 cf d2 :2 27 d7
da :2 27 e3 e6 :2 27 :2 10 5c :2 d
10 :2 1a 2c :2 36 42 45 54 57
58 :2 54 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 :2 10 5b :3 d :2 18 2c :2 35
4a 54 :2 d 44 :2 a 14 27 34
45 52 61 12 13 20 2e 46
54 :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :4 29 a
19 20 2c 2f :2 20 39 3c :2 19
a 14 26 37 46 53 :2 d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :3 7 e :2 17 22 20
:2 2b :2 20 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 89 8c 95 9d :2 a6
:2 95 b9 :2 8c :2 27 c1 c4 :2 27 cc
cf :2 27 d4 d7 :2 27 e0 e3 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 47 51 :2 d 3b :2 a
14 2c 34 3b 59 61 68 82
8a 91 ac b8 12 1e 12 13
1b 2c 38 45 :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 7 e :2 17 22 20 :2 2b :2 20
d 40 49 52 :2 40 55 57 :2 55
3f :2 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 89 8c 95 9d :2 a6 :2 95
be :2 8c :2 27 c6 c9 :2 27 d1 d4
:2 27 d9 dc :2 27 e5 e8 :2 27 :2 10
5c :2 d 10 :2 1a 2c :2 36 42 45
54 57 58 :2 54 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 :2 10 5b :3 d :2 18
2c :2 35 4c 56 :2 d 5a :2 a 14
27 34 45 52 61 12 13 20
2e 46 54 :2 d :2 16 22 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5b 5c :2 58 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:8 7 15 7 a 13 1f :2 a 22
24 :2 22 14 1f 2c 34 3b 50
5b 60 74 12 :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 26 1e 26 2d 45 4d 54
6d :3 12 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 26
a 15 :2 a 19 a d 16 23
:2 d 26 28 :2 26 d 19 d 2a
:3 a 16 22 2f 3d 48 52 5e
1b 28 35 42 4f 1b 28 34
3e 46 4f 57 5e 1b 27 34
3f 4a 58 1b 26 32 3e 41
44 4a 50 53 :2 16 a d 16
18 :2 16 10 19 26 :2 10 29 2b
:2 29 1a 2d 4a 51 13 1a 16
22 :3 20 16 :2 1f 2b 16 27 16
:2 1f 2b 16 :4 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 5e
62 63 :2 5e :2 35 :3 19 :2 1f 24 30
6f 72 :2 30 7f 82 :2 30 86 89
:2 30 95 98 :2 30 a0 a3 :2 30 af
b2 b9 c2 c5 :2 b2 :2 30 :2 19 66
:2 16 :2 13 :4 1f :2 13 10 :4 2d 1a 2d
4a 51 13 1a 16 22 :3 20 16
:2 1f 2b 16 27 16 :2 1f 2b 16
:4 13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 5e 62 63 :2 5e
:2 35 :3 19 :2 1f 24 30 6f 72 :2 30
7f 82 :2 30 86 89 :2 30 95 98
:2 30 a0 a3 :2 30 af b2 b9 c2
c5 :2 b2 :2 30 :2 19 66 :2 16 :2 13 :4 1f
:2 13 10 :7 d 1a :2 a 26 a 18
:2 a 19 a d 14 20 23 :2 d
26 28 :2 26 d 18 :2 21 d 2c
d 18 1f 28 34 :2 1f 38 :2 41
:2 18 d :5 a 16 22 2f 3d 48
52 5e 1b 28 35 42 4f 1b
28 34 3e 46 4f 57 5e 1b
27 34 3f 4a 58 1b 26 32
3e 41 44 4a 50 53 :2 16 a
d 16 18 :2 16 17 2a 47 4e
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5b 5f 60 :2 5b :2 32 :3 16
:2 1c 21 2d 6c 6f :2 2d 7c 7f
:2 2d 83 86 :2 2d 92 95 :2 2d 9d
a0 :2 2d ac af b6 bf c2 :2 af
:2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10 d
:4 1a :2 a :4 7 1f a 13 1a :2 13
28 :2 a 2b 2d :2 2b a 16 a
30 a 16 1d 26 2d :2 26 3b
:2 1d 3e 40 :2 1d 1c 43 45 :2 1c
:2 16 a :4 7 a 13 15 :2 13 a
15 :2 a 10 19 22 :2 10 27 25
30 :2 25 a d 1b :2 d 19 :2 22
2b 2f 33 3c 45 :2 33 48 4a
:2 33 4c 4d :2 33 50 :2 19 :2 d 1b
:2 24 2d 30 33 3c 45 :2 33 48
4a :2 33 4d 4f :2 33 51 52 :2 33
55 :2 1b :2 d 1d :2 d 1b :2 d 18
:2 d 1b d 17 21 25 3a 43
15 16 23 34 3e 14 22 2f
3f :2 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5b 5f 60 :2 5b :2 32 :3 16 :2 1c 21
2d 6c 6f :2 2d 7c 7f :2 2d 83
86 :2 2d 92 95 :2 2d 9d a0 :2 2d
ac af b6 bf c2 :2 af :2 2d :2 16
63 :2 13 :2 10 :4 1c :2 10 d :3 30 11
1a 23 :2 11 26 28 :2 26 10 :4 31
30 2f :3 10 1e 10 13 :2 1e 25
33 :2 13 3f 41 :2 3f 13 23 13
43 :2 10 4a :2 d 10 17 23 26
:2 10 29 2b :2 29 10 1e :2 27 10
13 1c 23 :2 1c 31 :2 13 34 36
:2 34 13 22 13 38 13 22 29
35 38 :2 29 41 44 :2 22 :2 13 22
29 35 38 :2 29 42 45 :2 22 13
:4 10 2f 13 1c 23 :2 1c 30 :2 13
33 35 :2 33 13 21 13 37 13
21 28 33 36 :2 28 3f 42 :2 21
:2 13 21 28 33 36 :2 28 40 43
:2 21 13 :4 10 :5 d 1c :2 d 18 d
10 19 25 :2 10 28 2a :2 28 13
17 19 :2 17 16 1d 29 2c :2 16
2f 31 :2 2f 20 37 4e 56 5d
76 7e 85 19 21 28 40 48
4f 69 77 92 1e 2f 3b 44
1e 1f 27 38 44 51 67 :2 19
:2 22 2e 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 64 68
69 :2 64 :2 3b :3 1f :2 25 2a 36 75
78 :2 36 85 88 :2 36 8c 8f :2 36
9b 9e :2 36 a6 a9 :2 36 b5 b8
bf c8 cb :2 b8 :2 36 :2 1f 6c :2 1c
:2 19 :4 25 :2 19 16 :3 35 1a :2 23 2e
2c :2 37 :2 2c :2 19 27 19 1d 26
34 :2 1d 37 39 :2 37 1c 40 49
52 :2 40 55 57 :2 55 3f :2 1c 26
3d 56 5e 65 7e 86 8d 1f
27 2e 46 4e 55 71 81 24
35 41 24 25 2d 3e 4a 57
6d :2 1f :2 28 34 1f 1c 24 22
:2 2b 37 22 32 :2 1f :2 24 22 :2 2b
37 22 25 :2 2f 41 :2 4b 57 5b
6a 6e 6f :2 6a :2 41 :3 25 :2 2b 30
3c 7b 7e :2 3c 8b 8e :2 3c 92
95 :2 3c a1 a4 :2 3c ac af :2 3c
bb be c5 ce d1 :2 be :2 3c :2 25
72 :2 22 :2 1f :4 2b :2 1f 1c :4 5a 1c
2b 1c :4 19 16 47 1d :2 26 31
2f :2 3a :2 2f 1c 4e 57 60 :2 4e
63 65 :2 63 4d :2 1c 23 3a 53
5b 62 7b 83 8a 1c 24 2b
43 4b 52 6e 7e 21 32 3e
21 22 2a 3b 47 54 6a :2 1c
:2 25 31 1c 19 21 1f :2 28 34
1f 2f :2 1c :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 67 6b
6c :2 67 :2 3e :3 22 :2 28 2d 39 78
7b :2 39 88 8b :2 39 8f 92 :2 39
9e a1 :2 39 a9 ac :2 39 b8 bb
c2 cb ce :2 bb :2 39 :2 22 6f :2 1f
:2 1c :4 28 :2 1c 19 :4 68 47 :2 16 35
20 37 50 58 5f 78 80 87
19 21 28 40 48 4f 6b 7b
1e 2f 3b 48 1f 2c 3d 45
1d 29 36 4c :2 19 :2 22 2e 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 64 68 69 :2 64 :2 3b
:3 1f :2 25 2a 36 75 78 :2 36 85
88 :2 36 8c 8f :2 36 9b 9e :2 36
a6 a9 :2 36 b5 b8 bf c8 cb
:2 b8 :2 36 :2 1f 6c :2 1c :2 19 :4 25 :2 19
16 :7 13 1b 16 1d 29 2c :2 16
2f 31 :2 2f 20 37 4d 55 5c
7a 82 89 a2 aa b1 cb d7
f5 1e 2f 3a 43 55 1f 2c
3d 45 1d 29 36 4c :2 19 :2 22
2e 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 64 68 69
:2 64 :2 3b :3 1f :2 25 2a 36 75 78
:2 36 85 88 :2 36 8c 8f :2 36 9b
9e :2 36 a6 a9 :2 36 b5 b8 bf
c8 cb :2 b8 :2 36 :2 1f 6c :2 1c :2 19
:4 25 :2 19 16 :3 35 1a :2 23 2e 2c
:2 37 :2 2c 19 1d 26 34 :2 1d 37
39 :2 37 1c 40 49 52 :2 40 55
57 :2 55 3f :2 1c 26 3d 56 5e
65 7e 86 8d a9 b5 24 35
40 4d 25 32 43 4b 23 2f
3c 52 :2 1f :2 28 34 1f 1c 24
22 :2 2b 37 22 32 :2 1f :2 24 22
:2 2b 37 22 25 :2 2f 41 :2 4b 57
5b 6a 6e 6f :2 6a :2 41 :3 25 :2 2b
30 3c 7b 7e :2 3c 8b 8e :2 3c
92 95 :2 3c a1 a4 :2 3c ac af
:2 3c bb be c5 ce d1 :2 be :2 3c
:2 25 72 :2 22 :2 1f :4 2b :2 1f 1c :4 5a
1c 2b :2 1c :4 19 16 47 1d :2 26
31 2f :2 3a :2 2f 1c 23 3a 53
5b 62 80 88 8f aa b2 b9
d5 e1 21 32 3d 4a 22 2f
40 48 20 2c 39 4f :2 1c :2 25
31 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 67 6b 6c
:2 67 :2 3e :3 22 :2 28 2d 39 78 7b
:2 39 88 8b :2 39 8f 92 :2 39 9e
a1 :2 39 a9 ac :2 39 b8 bb c2
cb ce :2 bb :2 39 :2 22 6f :2 1f :2 1c
:4 28 :2 1c 19 :4 4a 47 :2 16 35 20
37 4f 57 5e 7c 84 8b a6
ae b5 d1 dd 1e 2f 3a 47
1f 2c 3d 45 1d 29 36 4c
:2 19 :2 22 2e 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 64
68 69 :2 64 :2 3b :3 1f :2 25 2a 36
75 78 :2 36 85 88 :2 36 8c 8f
:2 36 9b 9e :2 36 a6 a9 :2 36 b5
b8 bf c8 cb :2 b8 :2 36 :2 1f 6c
:2 1c :2 19 :4 25 :2 19 16 :7 13 :4 10 14
:2 1d 28 26 :2 31 :2 26 13 16 1f
28 :2 16 2b 2d :2 2b 16 24 16
2f :4 1a 19 1c 20 22 :2 20 1c
2c 1c 26 2a 3a 24 25 32
43 57 23 34 3c 43 5d 65
6c :2 1f :2 28 34 1f 1c 24 22
:2 2b 37 22 32 :2 1f :2 24 22 :2 2b
37 22 25 :2 2f 41 :2 4b 57 5b
6a 6e 6f :2 6a :2 41 :3 25 :2 2b 30
3c 7b 7e :2 3c 8b 8e :2 3c 92
95 :2 3c a1 a4 :2 3c ac af :2 3c
bb be c5 ce d1 :2 be :2 3c :2 25
72 :2 22 :2 1f :4 2b :2 1f 1c :4 24 1c
2c 1c 26 2a 3a 24 25 32
43 57 23 2f 37 3e :2 1f :2 28
34 1f 1c 24 22 :2 2b 37 22
32 :2 1f :2 24 22 :2 2b 37 22 25
:2 2f 41 :2 4b 57 5b 6a 6e 6f
:2 6a :2 41 :3 25 :2 2b 30 3c 7b 7e
:2 3c 8b 8e :2 3c 92 95 :2 3c a1
a4 :2 3c ac af :2 3c bb be c5
ce d1 :2 be :2 3c :2 25 72 :2 22 :2 1f
:4 2b :2 1f 1c :7 19 1c 25 33 :2 1c
38 36 41 4b :2 38 :2 36 1c 27
30 39 :2 27 3c 3e :2 27 1c 21
1c 4e :2 19 37 :3 16 24 16 :4 13
41 13 1e 27 30 :2 1e 33 35
:2 1e 13 18 13 :5 10 1e :2 10 1c
10 1a 25 32 3a 41 56 61
66 :2 18 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 5e 62 63 :2 5e :2 35 :3 19 :2 1f
24 30 6f 72 :2 30 7f 82 :2 30
86 89 :2 30 95 98 :2 30 a0 a3
:2 30 af b2 b9 c2 c5 :2 b2 :2 30
:2 19 66 :2 16 :2 13 :4 1f :2 13 10 :3 2c
24 2c 33 4b 53 5a 73 85
:2 18 :2 13 :2 1c 28 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
5e 62 63 :2 5e :2 35 :3 19 :2 1f 24
30 6f 72 :2 30 7f 82 :2 30 86
89 :2 30 95 98 :2 30 a0 a3 :2 30
af b2 b9 c2 c5 :2 b2 :2 30 :2 19
66 :2 16 :2 13 :4 1f :2 13 10 :3 2c 10
1b :2 10 1f 10 13 1c 29 :2 13
2c 2e :2 2c 13 1f 13 30 :3 10
1c 28 39 47 52 5c 68 1b
28 35 42 4f 1b 28 34 3e
46 4f 57 5e 1b 27 34 3f
4a 58 1b 26 32 3e 41 44
4a 50 53 :2 1c 10 13 1c 1e
:2 1c 16 1f 2c :2 16 2f 31 :2 2f
20 33 50 57 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 64 68
69 :2 64 :2 3b :3 1f :2 25 2a 36 75
78 :2 36 85 88 :2 36 8c 8f :2 36
9b 9e :2 36 a6 a9 :2 36 b5 b8
bf c8 cb :2 b8 :2 36 :2 1f 6c :2 1c
:2 19 :4 25 :2 19 16 :4 33 20 33 50
57 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 64 68 69 :2 64 :2 3b
:3 1f :2 25 2a 36 75 78 :2 36 85
88 :2 36 8c 8f :2 36 9b 9e :2 36
a6 a9 :2 36 b5 b8 bf c8 cb
:2 b8 :2 36 :2 1f 6c :2 1c :2 19 :4 25 :2 19
16 :7 13 20 :2 10 d 2c 13 1c
28 :2 13 2b 2d :2 2b 10 1e :2 10
1f 10 13 1a 26 29 :2 13 2c
2e :2 2c 13 1e :2 27 13 32 13
1e 27 33 :2 1e 13 :5 10 1c 28
35 43 4e 58 64 1b 28 35
42 4f 1b 28 34 3e 46 4f
57 5e 1b 27 34 3f 4a 58
1b 26 32 3e 41 44 4a 50
53 :2 1c 10 13 1c 1e :2 1c 1d
30 4d 54 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 61 65 66
:2 61 :2 38 :3 1c :2 22 27 33 72 75
:2 33 82 85 :2 33 89 8c :2 33 98
9b :2 33 a3 a6 :2 33 b2 b5 bc
c5 c8 :2 b5 :2 33 :2 1c 69 :2 19 :2 16
:4 22 :2 16 13 :4 20 :2 10 2f 2c :3 d
18 21 2a :2 18 2d 2f :2 18 d
f d :3 30 e a 17 :2 7 :4 4
8 11 14 :2 11 7 1c 25 2d
:2 1c 30 32 :2 30 1b :2 7 a 13
22 :2 a 25 27 :2 25 19 34 48
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5c 5d :2 58 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8f 92 :2 2a 9a
9d :2 2a a9 ac b3 bc bf :2 ac
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:4 29 14 2d 3b 4a 58 13 27
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 58 5c 5d :2 58 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8f 92 :2 2a 9a
9d :2 2a a9 ac b3 bc bf :2 ac
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:7 7 a 13 15 :2 13 d :2 17 29
:2 33 3f 43 52 56 57 :2 52 :2 29
:3 d :2 13 18 24 63 66 :2 24 73
76 :2 24 7a 7d :2 24 87 8a 93
9b :2 a4 :2 93 ba :2 8a :2 24 c2 c5
:2 24 cd d0 :2 24 d5 d8 :2 24 e1
e4 :2 24 :2 d 5a :2 a d :2 17 29
:2 33 3f 42 51 55 56 :2 51 :2 29
:3 d :2 13 18 24 63 66 :2 24 :2 d
59 :3 a :2 15 29 :2 32 47 51 :2 a
7 19 d 18 16 :2 21 :2 16 d
:2 17 29 :2 33 3f 43 52 56 57
:2 52 :2 29 :3 d :2 13 18 24 63 66
:2 24 73 76 :2 24 7a 7d :2 24 87
8a 93 9b :2 a4 :2 93 c3 :2 8a :2 24
cb ce :2 24 d6 d9 :2 24 de e1
:2 24 ea ed :2 24 :2 d 5a :2 a d
:2 17 29 :2 33 3f 42 51 55 56
:2 51 :2 29 :3 d :2 13 18 24 63 66
:2 24 :2 d 59 :3 a :2 15 29 :2 32 50
12 :2 a 7 3e 19 d 18 16
:2 21 :2 16 d :2 17 29 :2 33 3f 43
52 56 57 :2 52 :2 29 :3 d :2 13 18
24 63 66 :2 24 73 76 :2 24 7a
7d :2 24 87 8a 93 9b :2 a4 :2 93
c0 :2 8a :2 24 c8 cb :2 24 d3 d6
:2 24 db de :2 24 e7 ea :2 24 :2 d
5a :2 a d :2 17 29 :2 33 3f 42
51 55 56 :2 51 :2 29 :3 d :2 13 18
24 63 66 :2 24 :2 d 59 :3 a :2 15
29 :2 32 4d 12 :2 a 3b 19 d
:2 17 29 :2 33 3f 43 52 56 57
:2 52 :2 29 :3 d :2 13 18 24 63 66
:2 24 73 76 :2 24 7a 7d :2 24 87
8a 93 9b :2 a4 :2 93 bc :2 8a :2 24
c4 c7 :2 24 cf d2 :2 24 d7 da
:2 24 e6 e9 :2 24 :2 d 5a :2 a d
:2 17 29 :2 33 3f 42 51 55 56
:2 51 :2 29 :3 d :2 13 18 24 63 66
:2 24 :2 d 59 :3 a :2 15 29 :2 32 49
56 :2 a :4 7 35 :2 4 8 11 18
:2 11 25 :2 8 28 2a :2 28 7 32
3b 42 :2 3b 50 :2 32 53 55 :2 53
31 :3 7 f 19 :3 7 :2 10 1c :2 7
f e 11 :2 f e 11 :2 f e
11 :2 f e 11 :2 f e 11 :2 f
3e 41 :2 f 4e 51 :2 f e 11
:2 f 2d 30 :2 f 3b 3e :2 f 5a
5d :2 f 13 16 :2 f 7 a 12
1c :2 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 59 5a :2 55 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :3 10 :2 16 1b 3f 48 4b
:2 3f :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 58 7 f 19 :3 7 :2 10 1c :2 7
d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
25 28 :2 d 35 38 :2 d e 11
:2 d 28 2b :2 d 36 39 :2 d 55
58 :2 d 13 16 :2 d 7 a 12
1c :2 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 55 59 5a :2 55 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :3 10 :2 16 1b 3f 48 4b
:2 3f :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 58 7 :2 10 :3 1c :2 7 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d 4e 51 :2 d 13 16 :2 d
e 11 :2 d 4b 4e :2 d 13 16
:2 d e 11 :2 d e 11 :2 d 13
16 :2 d 21 24 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d 4f 52 :2 d
13 16 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d 2d
30 :2 d 3c 3f :2 d e 11 :2 d
7 a 12 1c :2 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 59
5a :2 55 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :3 10 :2 16 1b
3f 48 4b :2 3f :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 58 7 d e 11
:2 d e 11 :2 d e 11 :2 d 3b
3e 46 4f 58 :2 46 :2 3e :2 d 13
16 :2 d e 11 :2 d 15 18 20
29 34 :2 20 :2 18 :2 d 13 16 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d 55 58
60 13 1c :2 60 :2 58 :2 d 20 23
:2 d e 11 :2 d 2c 2f 37 40
4b :2 37 :2 2f :2 d 13 16 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d 7 4
58 a 13 1a :2 13 28 :2 a 2b
2d :2 2b 7 f 19 :3 7 :2 10 1c
:2 7 f e 11 :2 f e 11 :2 f
e 11 :2 f e 11 :2 f e 11
:2 f 3e 41 :2 f 4e 51 :2 f e
11 :2 f 27 2a :2 f 35 38 :2 f
7 a 12 1c :2 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 59
5a :2 55 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :3 10 :2 16 1b
3f 48 4b :2 3f :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 2f 7 f 19 :3 7
:2 10 1c :2 7 f e 11 :2 f e
11 :2 f e 11 :2 f e 11 :2 f
e 11 :2 f 3b 3e :2 f 4b 4e
:2 f 13 16 :2 f 21 24 :2 f 7
a 12 1c :2 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 59 5a
:2 55 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :3 10 :2 16 1b 3f
48 4b :2 3f :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 2f 7 :2 10 :3 1c :2 7 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d 4e 51 :2 d 13 16
:2 d e 11 :2 d 4b 4e :2 d 13
16 :2 d e 11 :2 d e 11 :2 d
2e 31 :2 d 3c 3f :2 d 7 a
12 1c :2 a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 59 5a :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8c 8f
:2 27 97 9a :2 27 a6 a9 b0 b9
bc :2 a9 :2 27 :3 10 :2 16 1b 3f 48
4b :2 3f :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 2f 7 d e 11 :2 d e
11 :2 d e 11 :2 d 48 4b 53
5c 65 :2 53 :2 4b :2 d 13 16 :2 d
e 11 19 22 2d :2 19 :2 11 :2 d
13 16 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d 7 2f 58
7 f 19 :3 7 :2 10 1c :2 7 f
e 11 :2 f e 11 :2 f e 11
:2 f e 11 :2 f e 11 :2 f e
11 :2 f 28 2b :2 f 38 3b :2 f
e 11 :2 f 2d 30 :2 f 3c 3f
:2 f e 11 :2 f 7 a 12 1c
:2 a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 59 5a :2 55 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :3 10 :2 16 1b 3f 48 4b :2 3f
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 4
7 f 19 :3 7 :2 10 1c :2 7 f
e 11 :2 f e 11 :2 f e 11
:2 f e 11 :2 f e 11 :2 f 3b
3e :2 f 4b 4e :2 f 13 16 :2 f
22 25 :2 f 7 a 12 1c :2 a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 59 5a :2 55 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8c 8f :2 27 97 9a
:2 27 a6 a9 b0 b9 bc :2 a9 :2 27
:3 10 :2 16 1b 3f 48 4b :2 3f :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 4 7
:2 10 :3 1c :2 7 d e 11 :2 d e
11 :2 d e 11 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d 4e
51 :2 d 13 16 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d 2d 30
:2 d 3c 3f :2 d 7 a 12 1c
:2 a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 59 5a :2 55 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :3 10 :2 16 1b 3f 48 4b :2 3f
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 4
7 f e 11 :2 f e 11 :2 f
e 11 :2 f 13 16 1e 27 30
:2 1e :2 16 :2 f 34 37 :2 f e 11
:2 f 54 57 5f 13 1e :2 5f :2 57
:2 f 13 16 :2 f e 11 :2 f e
11 :2 f e 11 :2 f e 11 :2 f
e 11 :2 f e 11 :2 f e 11
:2 f 7 :4 4 7 :2 11 23 :2 2d 39
3c 4b 4f 50 :2 4b :2 23 :3 7 :2 d
12 1e 5d 60 :2 1e :2 7 53 :2 4
7 :2 11 23 :2 2d 39 3c 4b 4f
50 :2 4b :2 23 :3 7 :2 d 12 1e 5d
60 :2 1e :2 7 53 :3 4 b :2 16 26
:2 b 4 1 9 12 9 a :2 14
26 :2 30 3c 40 4f 53 54 :2 4f
:2 26 :3 a :2 10 15 21 60 63 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
57 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4c 50 51 :2 4c
:2 23 :3 7 :2 d 12 1e 5d 60 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 54 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
3392
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :7 1b
:7 1c :7 1d :5 1e :5 1f
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :7 42 :7 43
:6 44 :7 45 :6 46 :7 47
:7 48 :7 49 :6 4a :6 4b
:6 4c :7 4d :7 4e :6 4f
:6 50 :7 51 :6 52 :6 53
:6 54 :6 55 :5 56 :7 58
:b 5a :11 5b 5c :2 5b
:2 5c :2 5b :2 5c :2 5b
:2 5d :2 5b :2 5d :2 5b
:2 5d :2 5b :2 5d :2 5b
:2 5e :2 5b :2 5e :2 5b
:2 5e :2 5b :2 5e :2 5b
:2 5f :2 5b :9 5f :2 5b
:2 60 :2 5b :9 60 :2 5b
:2 61 :2 5b :9 61 :2 5b
:2 62 :2 5b :9 62 :2 5b
:2 63 :2 5b :9 63 :2 5b
:2 64 :2 5b :9 64 :2 5b
:2 65 :2 5b :9 65 :2 5b
:2 66 :2 5b :9 66 :2 5b
:2 67 :2 5b :9 67 :2 5b
:2 68 :2 5b :9 68 :2 5b
:2 69 :2 5b :2 69 :2 5b
:2 69 :2 5b :2 69 :2 5b
:2 6a :2 5b :2 6a :2 5b
:2 6a :2 5b :2 6a :2 5b
:2 6a :4 5b :3 5a :11 6d
:b 6e :3 6d :3 76 :3 77
:3 78 :3 79 :3 7b :3 7d
:3 7f :3 81 :3 82 :3 83
:3 84 :3 85 :3 86 :3 87
:3 89 :3 8a :3 8b :a 8c
:3 8d :3 92 :3 93 :5 95
:11 96 :20 97 :3 96 :11 99
:b 9a :3 99 :9 9c :3 95
:5 9f :11 a0 :20 a1 :3 a0
:11 a3 :b a4 :3 a3 :9 a6
:3 9f :1f a9 :11 aa :20 ab
:3 aa :11 ad :b ae :3 ad
:9 b0 :3 a9 :e b3 :6 b5
b6 b7 b5 :5 b8
b4 ba :5 bb :3 ba
:2 bc :5 be :11 bf :24 c0
:3 bf :2 bd :6 bc b9
:3 b3 :16 c5 :11 c6 :20 c7
:3 c6 :11 c9 :b ca :3 c9
:9 cc :3 c5 :3 cf d0
b3 :e d0 :2 d2 d3
d2 :5 d4 d1 d6
:5 d7 :3 d6 :2 d8 :5 da
:11 db :24 dc :3 db :2 d9
:6 d8 d5 :4 d0 :3 b3
:3 e2 :5 e3 :3 e4 :3 e3
:8 e7 :8 e8 :3 e9 :9 eb
:d ed :b ee :c f0 :6 f2
:4 f3 :3 f4 f2 :5 f5
f1 f7 :5 f8 :3 f7
:2 f9 :5 fb :11 fc :24 fd
:3 fc :2 fa :6 f9 f6
:4 f0 :a 103 :8 104 :5 105
:7 106 :27 107 103 :5 108
102 10a :5 10b :3 10a
:2 10c :5 10e :11 10f :24 110
:3 10f :2 10d :6 10c 109
:4 101 :3 f0 :a 116 :4 118
:3 119 118 :5 11a 117
11c :5 11d :3 11c :2 11e
:5 120 :11 121 :24 122 :3 121
:2 11f :6 11e 11b :3 116
:a 127 :5 128 :3 129 :3 128
:5 12c :3 12d :3 12e 12c
:5 12f 12b 131 :5 132
:3 131 :2 133 :5 135 :11 136
:24 137 :3 136 :2 134 :6 133
130 :4 127 :11 13c :30 13d
:3 13c :11 13f :b 140 :3 13f
:a 142 13b :3 127 116
:3 145 144 :3 116 :3 148
:2 14a 14b :2 14c 14a
:5 14d 149 14f :5 150
:3 14f :2 151 :5 153 :11 154
:24 155 :3 154 :2 152 :6 151
14e :3 eb :9 15a :2 15c
15d :2 15e 15c :5 15f
15b 161 :5 162 :3 161
:2 163 :5 165 :11 166 :24 167
:3 166 :2 164 :6 163 160
:3 15a :b 16c :11 16d :30 16e
:3 16d :11 170 :b 171 :3 170
:a 173 :3 16c :3 15a eb
:5 178 :3 179 :3 17a 178
:5 17b 177 17d :5 17e
:3 17d :2 17f :5 181 :11 182
:24 183 :3 182 :2 180 :6 17f
17c :3 176 :a 187 :6 189
:5 18a 188 18c :5 18d
:3 18c :2 18e :5 190 :11 191
:24 192 :3 191 :2 18f :6 18e
18b :3 187 :a 196 :11 197
:30 198 :3 197 :11 19a :b 19b
:3 19a :a 19d :3 196 :3 187
176 :3 eb :17 1a2 :3 1a5
1a6 :2 1a7 :2 1a8 1a5
:5 1a9 1a4 1ab :5 1ac
:3 1ab :2 1ad :5 1af :11 1b0
:24 1b1 :3 1b0 :2 1ae :6 1ad
1aa :3 1a2 :9 1b6 :c 1b7
:2 1b8 :2 1b7 :6 1b8 :2 1b7
:3 1b9 1b8 :2 1b7 :3 1bc
:3 1bd :3 1b6 1a2 :5 1c0
:3 1c1 :3 1c2 :e 1c3 :b 1c4
:2 1c5 :2 1c4 :a 1c5 :8 1c6
:3 1c3 :b 1c8 :11 1c9 :20 1ca
:3 1c9 :11 1cc :b 1cd :3 1cc
:9 1cf 1d0 1c8 :9 1d0
:11 1d1 :2e 1d2 :3 1d1 :11 1d4
:b 1d5 :3 1d4 :c 1d7 1d0
:3 1c8 :3 1da :5 1db :3 1dc
:3 1db 1c0 :3 1df :9 1e1
:f 1e2 :3 1e1 1de :3 1c0
:16 1e5 :16 1e6 :3 1e7 1e8
1e6 :9 1e8 :3 1e9 1ea
1e8 1e6 :16 1ea :3 1eb
1ec 1ea 1e6 :9 1ec
:3 1ed 1ec :3 1e6 :3 1e5
1bf :3 1a2 :5 1f2 :3 1f4
:3 1f5 :14 1f7 :d 1f9 :9 1fb
:7 1fc 1fd :3 1fc :b 1ff
:9 200 :5 201 :3 200 :11 204
:2e 205 :3 204 :11 207 :b 208
:3 207 :c 20a :3 1ff :14 20d
:11 20e :2e 20f :3 20e :11 211
:b 212 :3 211 :c 214 :3 20d
:3 217 :9 21a :2 21b 21c
:2 21d :2 21e :2 21f :2 220
21a :5 221 219 223
:5 224 :3 223 :2 225 :5 227
:11 228 :24 229 :3 228 :2 226
:6 225 222 :3 1fb :12 22e
:3 22f :9 230 :3 231 :3 230
:3 22e :3 235 :3 236 :5 237
:a 238 :2 23a :9 23b :9 23c
:3 23d :4 23e 23f :6 240
23a :5 241 239 243
:5 244 :3 243 :2 245 :5 247
:11 248 :24 249 :3 248 :2 246
:6 245 242 :3 238 :a 24e
:3 24f :16 250 :2 252 :9 253
:9 254 :2 255 :3 256 257
:6 258 252 :5 259 251
25b :5 25c :3 25b :2 25d
:5 25f :11 260 :24 261 :3 260
:2 25e :6 25d 25a :4 250
:3 266 265 :3 250 268
24e :16 268 :2 26a :9 26b
:9 26c :2 26d :3 26e 26f
:6 270 26a :5 271 269
273 :5 274 :3 273 :2 275
:5 277 :11 278 :24 279 :3 278
:2 276 :6 275 272 :4 268
:3 24e 238 :2 280 :9 281
:9 282 :2 283 :3 284 285
:6 286 280 :5 287 27f
289 :5 28a :3 289 :2 28b
:5 28d :11 28e :24 28f :3 28e
:2 28c :6 28b 288 :4 27e
:3 238 237 :a 295 :e 297
:4 298 299 :6 29a 297
:5 29b 296 29d :5 29e
:3 29d :2 29f :5 2a1 :11 2a2
:24 2a3 :3 2a2 :2 2a0 :6 29f
29c :3 295 :a 2a8 :3 2a9
:16 2aa :a 2ac :3 2ad 2ae
:6 2af 2ac :5 2b0 2ab
2b2 :5 2b3 :3 2b2 :2 2b4
:5 2b6 :11 2b7 :24 2b8 :3 2b7
:2 2b5 :6 2b4 2b1 :4 2aa
:3 2bd 2be 2bc :3 2aa
2c0 2a8 :a 2c0 :d 2c2
:3 2c3 2c4 :6 2c5 2c2
:5 2c6 2c1 2c8 :5 2c9
:3 2c8 :2 2ca :5 2cc :11 2cd
:24 2ce :3 2cd :2 2cb :6 2ca
2c7 :4 2c0 :3 2a8 295
:d 2d5 :3 2d6 2d7 :6 2d8
2d5 :5 2d9 2d4 2db
:5 2dc :3 2db :2 2dd :5 2df
:11 2e0 :24 2e1 :3 2e0 :2 2de
:6 2dd 2da :4 2d3 :3 295
294 :3 237 :a 2e8 :9 2e9
:11 2ea :30 2eb :3 2ea :11 2ed
:b 2ee :3 2ed :a 2f0 2f1
2e9 :10 2f1 :5 2f2 :3 2f3
:3 2f5 2f6 :4 2f7 :7 2f8
2f5 :5 2f9 2f4 2fb
:5 2fc :3 2fb :2 2fd :5 2ff
:11 300 :24 301 :3 300 :2 2fe
:6 2fd 2fa :4 2f2 :3 306
:3 308 309 :4 30a :4 30b
308 :5 30c 307 30e
:5 30f :3 30e :2 310 :5 312
:11 313 :24 314 :3 313 :2 311
:6 310 30d :4 305 :3 2f2
:d 31a :11 31b :30 31c :3 31b
:11 31e :b 31f :3 31e :a 321
:3 31a 2f1 :3 2e9 :3 324
325 2e8 :19 325 :11 326
:30 327 :3 326 :11 329 :b 32a
:3 329 :a 32c 325 :3 2e8
:a 32f :c 330 :d 333 :5 334
335 :2 336 333 :5 337
332 339 :5 33a :3 339
:2 33b :5 33d :11 33e :24 33f
:3 33e :2 33c :6 33b 338
:3 32f :a 344 :11 345 :30 346
:3 345 :11 348 :b 349 :3 348
:a 34b :3 344 :16 34e :2 34f
:2 34e :8 34f :6 34e :11 350
:30 351 :3 350 :11 353 :b 354
:3 353 :a 356 34f :2 34e
:6 35a 35b :5 35c 35a
:5 35d 359 35f :5 360
:3 35f :2 361 :5 363 :11 364
:24 365 :3 364 :2 362 :6 361
35e :4 32f :c 36a :6 36d
:5 36e 36c 370 :5 371
:3 370 :2 372 :5 374 :11 375
:24 376 :3 375 :2 373 :6 372
36f :3 369 :a 37b :11 37c
:30 37d :3 37c :11 37f :b 380
:3 37f :a 382 :3 37b :c 386
:2 387 388 :5 389 386
:5 38a 385 38c :5 38d
:3 38c :2 38e :5 390 :11 391
:24 392 :3 391 :2 38f :6 38e
38b :3 369 :16 397 :11 398
:30 399 :3 398 :11 39b :b 39c
:3 39b :a 39e :3 397 :6 3a2
3a3 :5 3a4 3a2 :5 3a5
3a1 3a7 :5 3a8 :3 3a7
:2 3a9 :5 3ab :11 3ac :24 3ad
:3 3ac :2 3aa :6 3a9 3a6
:4 369 :3 32f :3 3b3 :9 3b5
:9 3b7 3b8 3b7 :5 3b9
3b6 3bb :5 3bc :3 3bb
:2 3bd :5 3bf :11 3c0 :24 3c1
:3 3c0 :2 3be :6 3bd 3ba
:3 3b5 :7 3c7 3c8 3c9
3ca 3c7 :5 3cb 3c6
3cd :5 3ce :3 3cd :2 3cf
:5 3d1 :11 3d2 :24 3d3 :3 3d2
:2 3d0 :6 3cf 3cc :3 3b5
:3 3d8 :3 3d9 :9 3da :3 3db
:3 3da :8 3de :5 3df :8 3e0
:6 3e1 :9 3e2 :3 3de :5 3e4
:9 3e5 :5 3e7 :6 3e8 :5 3e9
3e8 :5 3eb 3ea :3 3e8
3e6 3ee :5 3ef :3 3ee
:2 3f0 :5 3f2 :11 3f3 :24 3f4
:3 3f3 :2 3f1 :6 3f0 3ed
:4 3e5 :5 3fa :6 3fb :5 3fc
3fb :5 3fe 3fd :3 3fb
3f9 401 :5 402 :3 401
:2 403 :5 405 :11 406 :24 407
:3 406 :2 404 :6 403 400
:4 3f8 :3 3e5 :3 3e4 3b5
:3 40f :3 410 :a 412 :5 413
412 :d 415 414 :3 412
:8 418 :5 419 :8 41a :6 41b
:9 41c :3 418 :5 41e :5 420
:6 421 :5 422 421 :5 424
423 :3 421 41f 427
:5 428 :3 427 :2 429 :5 42b
:11 42c :24 42d :3 42c :2 42a
:6 429 426 :6 41e 40d
:3 3b5 1fb :c 436 :3 437
436 :16 439 438 :3 436
:5 43b :3 43c :c 43d :3 43e
:17 441 :1b 443 :3 445 :3 446
:3 447 :3 448 :5 44b 44c
:4 44d :4 44e 44b :5 44f
44a 451 :5 452 :3 451
:2 453 :5 455 :11 456 :24 457
:3 456 :2 454 :6 453 450
:3 43d :12 45c :3 45d :b 45e
:3 45f :3 45e :3 45c :a 463
:5 464 :c 465 :3 466 465
:c 468 :c 469 467 :3 465
463 :c 46c :3 46d 46c
:c 46f :c 470 46e :3 46c
46b :3 463 :3 474 :3 475
:9 477 :5 478 :a 479 :8 47b
:9 47c :4 47d 47e :6 47f
47b :5 480 47a 482
:5 483 :3 482 :2 484 :5 486
:11 487 :24 488 :3 487 :2 485
:6 484 481 :3 479 :a 48d
:3 48e :16 48f :8 491 :8 492
:3 493 494 :6 495 491
:5 496 490 498 :5 499
:3 498 :2 49a :5 49c :11 49d
:24 49e :3 49d :2 49b :6 49a
497 :4 48f :3 4a3 4a2
:3 48f 4a5 48d :16 4a5
:8 4a7 :8 4a8 :3 4a9 4aa
:6 4ab 4a7 :5 4ac 4a6
4ae :5 4af :3 4ae :2 4b0
:5 4b2 :11 4b3 :24 4b4 :3 4b3
:2 4b1 :6 4b0 4ad :4 4a5
:3 48d 479 :8 4bb :8 4bc
:4 4bd :4 4be :4 4bf 4bb
:5 4c0 4ba 4c2 :5 4c3
:3 4c2 :2 4c4 :5 4c6 :11 4c7
:24 4c8 :3 4c7 :2 4c5 :6 4c4
4c1 :4 4b9 :3 479 478
:a 4ce :e 4d0 :5 4d1 :4 4d2
:4 4d3 4d0 :5 4d4 4cf
4d6 :5 4d7 :3 4d6 :2 4d8
:5 4da :11 4db :24 4dc :3 4db
:2 4d9 :6 4d8 4d5 :3 4ce
:a 4e1 :16 4e2 :a 4e4 :4 4e5
:4 4e6 :4 4e7 4e4 :5 4e8
4e3 4ea :5 4eb :3 4ea
:2 4ec :5 4ee :11 4ef :24 4f0
:3 4ef :2 4ed :6 4ec 4e9
:4 4e2 :3 4f5 4f6 4f4
:3 4e2 4f8 4e1 :a 4f8
:d 4fa :4 4fb :4 4fc :4 4fd
4fa :5 4fe 4f9 500
:5 501 :3 500 :2 502 :5 504
:11 505 :24 506 :3 505 :2 503
:6 502 4ff :4 4f8 :3 4e1
4ce :d 50d :4 50e :4 50f
:4 510 50d :5 511 50c
513 :5 514 :3 513 :2 515
:5 517 :11 518 :24 519 :3 518
:2 516 :6 515 512 :4 50b
:3 4ce 4cd :3 478 :a 520
:9 521 :3 522 521 :5 524
:5 525 :3 526 :3 528 529
:4 52a :7 52b 528 :5 52c
527 52e :5 52f :3 52e
:2 530 :5 532 :11 533 :24 534
:3 533 :2 531 :6 530 52d
:4 525 :3 539 :3 53b 53c
:4 53d :4 53e 53b :5 53f
53a 541 :5 542 :3 541
:2 543 :5 545 :11 546 :24 547
:3 546 :2 544 :6 543 540
:4 538 :3 525 :d 54c :b 54d
:2 54e :3 54c :3 524 :3 551
523 :3 521 520 :b 554
:2 555 553 :3 520 :3 558
:3 559 :8 55c 55d 55e
55c :5 55f 55b 561
:5 562 :3 561 :2 563 :5 565
:11 566 :24 567 :3 566 :2 564
:6 563 560 :3 477 :8 56d
56e 56f 56d :5 570
56c 572 :5 573 :3 572
:2 574 :5 576 :11 577 :24 578
:3 577 :2 575 :6 574 571
:3 477 :3 57d :3 57e :9 57f
:3 580 :3 57f :8 583 :5 584
:8 585 :6 586 :9 587 :3 583
:5 589 :9 58a :5 58c :6 58d
:5 58e 58d :5 590 58f
:3 58d 58b 593 :5 594
:3 593 :2 595 :5 597 :11 598
:24 599 :3 598 :2 596 :6 595
592 :4 58a :5 59f :6 5a0
:5 5a1 5a0 :5 5a3 5a2
:3 5a0 59e 5a6 :5 5a7
:3 5a6 :2 5a8 :5 5aa :11 5ab
:24 5ac :3 5ab :2 5a9 :6 5a8
5a5 :4 59d :3 58a :3 589
5b2 477 :9 5b2 :3 5b3
:3 5b4 :a 5b6 :5 5b7 5b6
:7 5b9 5b8 :3 5b6 :8 5bc
:5 5bd :8 5be :6 5bf :9 5c0
:3 5bc :5 5c1 :5 5c3 :6 5c4
:5 5c5 5c4 :5 5c7 5c6
:3 5c4 5c2 5ca :5 5cb
:3 5ca :2 5cc :5 5ce :11 5cf
:24 5d0 :3 5cf :2 5cd :6 5cc
5c9 :6 5c1 5b2 :3 477
:b 5d6 5d7 5d8 :3 43d
5d9 43d :3 43b 433
:3 1fb :12 5de :9 5df :4 5e1
:6 5e2 :5 5e3 5e2 :5 5e5
5e4 :3 5e2 5e0 5e8
:5 5e9 :3 5e8 :2 5ea :5 5ec
:11 5ed :24 5ee :3 5ed :2 5eb
:6 5ea 5e7 :4 5df :5 5f4
:2 5f5 5f4 :6 5f6 :5 5f7
5f6 :5 5f9 5f8 :3 5f6
5f3 5fc :5 5fd :3 5fc
:2 5fe :5 600 :11 601 :24 602
:3 601 :2 5ff :6 5fe 5fb
:4 5f2 :3 5df :5 608 :11 609
:30 60a :3 609 :11 60c :b 60d
:3 60c :a 60f 610 608
:7 610 :11 611 :30 612 :3 611
:11 614 :b 615 :3 614 :7 617
618 :2 617 619 610
608 :7 619 :11 61a :30 61b
:3 61a :11 61d :b 61e :3 61d
:7 620 621 :2 620 619
608 :11 623 :30 624 :3 623
:11 626 :b 627 :3 626 :a 629
622 :3 608 :3 5de :1c 62d
:5 62f :5 630 :2 632 :2 633
:2 632 :2 634 :2 632 :2 635
:2 632 :2 636 :2 632 :2 637
:2 632 :2 637 :2 632 :2 637
:2 632 :2 638 :2 632 :2 638
:2 632 :2 638 :2 632 :2 638
:2 632 :2 639 :3 632 :5 63c
:6 63d :5 63e 63d :5 640
63f :3 63d 63b 643
:5 644 :3 643 :2 645 :5 647
:11 648 :24 649 :b 64a :3 648
:2 646 :6 645 642 :3 62d
:5 650 :5 651 653 654
:2 655 :2 654 :2 656 :2 654
:2 657 :2 654 :2 658 :2 654
:2 659 :2 654 :2 659 :2 654
:2 659 :2 654 :2 65a :2 654
:2 65a :2 654 :2 65a :2 654
:2 65a :2 654 :2 65b :2 654
653 :5 65e :6 65f :5 660
65f :5 662 661 :3 65f
65d 665 :5 666 :3 665
:2 667 :5 669 :11 66a :24 66b
:b 66c :3 66a :2 668 :6 667
664 :3 62d :7 671 673
674 :2 675 :2 674 :2 676
:2 674 :2 677 :2 674 :2 678
:2 674 :2 679 :2 674 :2 67a
:2 674 :2 67b :2 674 :2 67c
:2 674 :2 67d :2 674 :2 67e
:2 674 :2 67f :2 674 :2 680
:2 674 :2 680 :2 674 :2 681
:2 674 :2 682 :2 674 :2 682
:2 674 :2 683 :2 674 :2 684
:2 674 :2 685 :2 674 :2 686
:2 674 :2 686 :2 674 :2 687
:2 674 :2 688 :2 674 :2 689
:2 674 :2 68a :2 674 :2 68b
:2 674 :2 68c :2 674 :2 68d
:2 674 :2 68e :2 674 :2 68e
:2 674 :2 68f :2 674 :2 690
:2 674 :2 691 :2 674 :2 692
:2 674 :2 693 :2 674 :2 693
:2 674 :2 693 :2 674 :2 694
:2 674 673 :5 697 :6 698
:5 699 698 :5 69b 69a
:3 698 696 69e :5 69f
:3 69e :2 6a0 :5 6a2 :11 6a3
:24 6a4 :b 6a5 :3 6a3 :2 6a1
:6 6a0 69d :3 62d 6aa
6ab :2 6ac :2 6ab :2 6ad
:2 6ab :2 6ae :2 6ab :9 6ae
:2 6ab :2 6af :2 6ab :2 6b0
:2 6ab :9 6b0 :2 6ab :2 6b1
:2 6ab :2 6b2 :2 6ab :2 6b3
:2 6ab :2 6b4 :2 6ab :2 6b5
:2 6ab :2 6b6 :2 6ab :2 6b7
:2 6ab :2 6b8 :2 6ab :2 6b9
:2 6ab :2 6ba :2 6ab :2 6bb
:2 6ab :3 6bb :2 6bc :4 6bb
:2 6ab :2 6bc :2 6ab :2 6bd
:2 6ab :9 6bd :2 6ab :2 6be
:2 6ab :2 6bf :2 6ab :2 6c0
:2 6ab :2 6c1 :2 6ab :2 6c2
:2 6ab :2 6c3 :2 6ab 6aa
6c9 62d :c 6c9 :5 6cb
:5 6cc :2 6ce :2 6cf :2 6ce
:2 6d0 :2 6ce :2 6d1 :2 6ce
:2 6d2 :2 6ce :2 6d3 :2 6ce
:2 6d3 :2 6ce :2 6d3 :2 6ce
:2 6d4 :2 6ce :2 6d4 :2 6ce
:2 6d4 :3 6ce :5 6d7 :6 6d8
:5 6d9 6d8 :5 6db 6da
:3 6d8 6d6 6de :5 6df
:3 6de :2 6e0 :5 6e2 :11 6e3
:24 6e4 :b 6e5 :3 6e3 :2 6e1
:6 6e0 6dd :3 6c9 :5 6eb
:5 6ec :2 6ee :2 6ef :2 6ee
:2 6f0 :2 6ee :2 6f1 :2 6ee
:2 6f2 :2 6ee :2 6f3 :2 6ee
:2 6f3 :2 6ee :2 6f3 :2 6ee
:2 6f4 :2 6ee :2 6f4 :3 6ee
:5 6f7 :6 6f8 :5 6f9 6f8
:5 6fb 6fa :3 6f8 6f6
6fe :5 6ff :3 6fe :2 700
:5 702 :11 703 :24 704 :b 705
:3 703 :2 701 :6 700 6fd
:3 6c9 :7 70a 70b 70c
:2 70d :2 70c :2 70e :2 70c
:2 70f :2 70c :2 710 :2 70c
:2 711 :2 70c :2 712 :2 70c
:2 713 :2 70c :2 714 :2 70c
:2 715 :2 70c :2 715 :2 70c
:2 716 :2 70c :2 717 :2 70c
:2 717 :2 70c :2 718 :2 70c
:2 719 :2 70c :2 71a :2 70c
:2 71a :2 70c :2 71a :2 70c
70b :5 71d :6 71e :5 71f
71e :5 721 720 :3 71e
71c 724 :5 725 :3 724
:2 726 :5 728 :11 729 :24 72a
:b 72b :3 729 :2 727 :6 726
723 :3 6c9 730 731
:2 732 :2 731 :2 733 :2 731
:2 734 :2 731 :9 734 :2 731
:2 735 :2 731 :9 736 :2 731
:2 737 :2 731 :2 738 :2 731
:2 739 :2 731 :2 73a :2 731
:2 73b :2 731 :2 73c :2 731
:2 73d :2 731 730 6c9
62d :5 741 :5 742 :2 744
:2 745 :2 744 :2 746 :2 744
:2 747 :2 744 :2 748 :2 744
:2 749 :2 744 :2 74a :2 744
:2 74a :2 744 :2 74a :2 744
:2 74b :2 744 :2 74b :2 744
:2 74b :2 744 :2 74c :3 744
:5 74f :6 750 :5 751 750
:5 753 752 :3 750 74e
756 :5 757 :3 756 :2 758
:5 75a :11 75b :24 75c :b 75d
:3 75b :2 759 :6 758 755
:3 73f :5 763 :5 764 :2 766
:2 767 :2 766 :2 768 :2 766
:2 769 :2 766 :2 76a :2 766
:2 76b :2 766 :2 76b :2 766
:2 76b :2 766 :2 76c :2 766
:2 76c :3 766 :5 76f :6 770
:5 771 770 :5 773 772
:3 770 76e 776 :5 777
:3 776 :2 778 :5 77a :11 77b
:24 77c :b 77d :3 77b :2 779
:6 778 775 :3 73f :7 782
784 785 :2 786 :2 785
:2 787 :2 785 :2 788 :2 785
:2 789 :2 785 :2 78a :2 785
:2 78b :2 785 :2 78c :2 785
:2 78d :2 785 :2 78e :2 785
:2 78e :2 785 :2 78f :2 785
:2 790 :2 785 :2 791 :2 785
:2 792 :2 785 :2 792 :2 785
:2 792 :2 785 784 :5 795
:6 796 :5 797 796 :5 799
798 :3 796 794 79c
:5 79d :3 79c :2 79e :5 7a0
:11 7a1 :24 7a2 :b 7a3 :3 7a1
:2 79f :6 79e 79b :3 73f
:2 7a8 :2 7a9 :2 7a8 :2 7aa
:2 7a8 :2 7ab :2 7a8 :9 7ac
:2 7a8 :2 7ac :2 7a8 :2 7ad
:2 7a8 :3 7ad :2 7ae :4 7ad
:2 7a8 :2 7af :2 7a8 :2 7b0
:2 7a8 :2 7b1 :2 7a8 :2 7b2
:2 7a8 :2 7b3 :2 7a8 :2 7b4
:2 7a8 :2 7b5 :2 7a8 :2 7b6
:3 7a8 73f :3 62d :11 7be
:b 7bf :3 7be :11 7c1 :b 7c2
:3 7c1 :8 7c4 59 :3 7c8
:11 7c9 :b 7ca :17 7cb :3 7c9
:2 7cd :3 7ce :3 7cf 7d0
7ce 7cd 7ce :3 7d1
:3 7c8 :2 7d2 :5 7d4 :11 7d5
:b 7d6 :18 7d7 :3 7d5 :2 7d9
7da :3 7db 7dc 7da
7d9 7da :3 7dd :2 7d3
:6 7d2 7c7 :7 1 
b317
4
:3 0 1 :3 0 2
:a 0 338d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f 4 :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 338d 2 44
:2 0 18 :2 0 33
4 :3 0 18 :2 0
31 47 49 :6 0
4c 4a 0 338b
0 17 :6 0 18
:2 0 37 4 :3 0
35 4e 50 :6 0
53 51 0 338b
0 19 :6 0 18
:2 0 3b 4 :3 0
39 55 57 :6 0
5a 58 0 338b
0 1a :6 0 18
:2 0 3f 4 :3 0
3d 5c 5e :6 0
61 5f 0 338b
0 1b :6 0 18
:2 0 43 4 :3 0
41 63 65 :6 0
68 66 0 338b
0 1c :6 0 18
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 338b
0 1d :6 0 20
:2 0 4b 4 :3 0
49 71 73 :6 0
76 74 0 338b
0 1e :6 0 20
:2 0 4f 4 :3 0
4d 78 7a :6 0
7d 7b 0 338b
0 1f :6 0 20
:2 0 53 4 :3 0
51 7f 81 :6 0
84 82 0 338b
0 21 :6 0 59
276 0 57 4
:3 0 55 86 88
:6 0 8b 89 0
338b 0 22 :6 0
27 :2 0 5b 24
:3 0 8d :7 0 90
8e 0 338b 0
23 :6 0 24 :3 0
92 :7 0 95 93
0 338b 0 25
:6 0 18 :2 0 5f
4 :3 0 5d 97
99 :6 0 9c 9a
0 338b 0 26
:6 0 2a :2 0 63
4 :3 0 61 9e
a0 :6 0 a3 a1
0 338b 0 28
:6 0 2a :2 0 67
4 :3 0 65 a5
a7 :6 0 aa a8
0 338b 0 29
:6 0 2a :2 0 6b
4 :3 0 69 ac
ae :6 0 b1 af
0 338b 0 2b
:6 0 2e :2 0 6f
4 :3 0 6d b3
b5 :6 0 b8 b6
0 338b 0 2c
:6 0 30 :2 0 73
4 :3 0 71 ba
bc :6 0 bf bd
0 338b 0 2d
:6 0 30 :2 0 75
8 :3 0 c1 :7 0
c5 c2 c3 338b
0 2f :6 0 30
:2 0 77 8 :3 0
c7 :7 0 cb c8
c9 338b 0 31
:6 0 30 :2 0 79
8 :3 0 cd :7 0
d1 ce cf 338b
0 32 :6 0 30
:2 0 7b 8 :3 0
d3 :7 0 d7 d4
d5 338b 0 33
:6 0 30 :2 0 7d
8 :3 0 d9 :7 0
dd da db 338b
0 34 :6 0 30
:2 0 7f 8 :3 0
df :7 0 e3 e0
e1 338b 0 35
:6 0 30 :2 0 81
8 :3 0 e5 :7 0
e9 e6 e7 338b
0 36 :6 0 30
:2 0 83 8 :3 0
eb :7 0 ef ec
ed 338b 0 37
:6 0 30 :2 0 85
8 :3 0 f1 :7 0
f5 f2 f3 338b
0 38 :6 0 30
:2 0 87 8 :3 0
f7 :7 0 fb f8
f9 338b 0 39
:6 0 30 :2 0 89
8 :3 0 fd :7 0
101 fe ff 338b
0 3a :6 0 30
:2 0 8b 8 :3 0
103 :7 0 107 104
105 338b 0 3b
:6 0 30 :2 0 8d
8 :3 0 109 :7 0
10d 10a 10b 338b
0 3c :6 0 30
:2 0 8f 8 :3 0
10f :7 0 113 110
111 338b 0 3d
:6 0 30 :2 0 91
8 :3 0 115 :7 0
119 116 117 338b
0 3e :6 0 30
:2 0 93 8 :3 0
11b :7 0 11f 11c
11d 338b 0 3f
:6 0 30 :2 0 95
8 :3 0 121 :7 0
125 122 123 338b
0 40 :6 0 30
:2 0 97 8 :3 0
127 :7 0 12b 128
129 338b 0 41
:6 0 30 :2 0 99
8 :3 0 12d :7 0
131 12e 12f 338b
0 42 :6 0 30
:2 0 9b 8 :3 0
133 :7 0 137 134
135 338b 0 43
:6 0 30 :2 0 9d
8 :3 0 139 :7 0
13d 13a 13b 338b
0 44 :6 0 30
:2 0 9f 8 :3 0
13f :7 0 143 140
141 338b 0 45
:6 0 30 :2 0 a1
8 :3 0 145 :7 0
149 146 147 338b
0 46 :6 0 30
:2 0 a3 8 :3 0
14b :7 0 14f 14c
14d 338b 0 47
:6 0 30 :2 0 a5
8 :3 0 151 :7 0
155 152 153 338b
0 48 :6 0 30
:2 0 a7 8 :3 0
157 :7 0 15b 158
159 338b 0 49
:6 0 30 :2 0 a9
8 :3 0 15d :7 0
161 15e 15f 338b
0 4a :6 0 27
:2 0 ab 8 :3 0
163 :7 0 167 164
165 338b 0 4b
:6 0 27 :2 0 af
4 :3 0 ad 169
16b :6 0 16e 16c
0 338b 0 4c
:6 0 30 :2 0 b3
4 :3 0 b1 170
172 :6 0 175 173
0 338b 0 4d
:6 0 2a :2 0 b5
4f :3 0 177 :7 0
17b 178 179 338b
0 4e :6 0 30
:2 0 b9 4 :3 0
b7 17d 17f :6 0
182 180 0 338b
0 50 :6 0 18
:2 0 bb 8 :3 0
184 :7 0 188 185
186 338b 0 51
:6 0 18 :2 0 bf
53 :3 0 bd 18a
18c :6 0 18f 18d
0 338b 0 52
:6 0 18 :2 0 c3
53 :3 0 c1 191
193 :6 0 196 194
0 338b 0 54
:6 0 30 :2 0 c7
4 :3 0 c5 198
19a :6 0 19d 19b
0 338b 0 55
:6 0 30 :2 0 c9
8 :3 0 19f :7 0
1a3 1a0 1a1 338b
0 56 :6 0 30
:2 0 cb 8 :3 0
1a5 :7 0 1a9 1a6
1a7 338b 0 57
:6 0 20 :2 0 cd
8 :3 0 1ab :7 0
1af 1ac 1ad 338b
0 58 :6 0 20
:2 0 d1 4 :3 0
cf 1b1 1b3 :6 0
1b6 1b4 0 338b
0 59 :6 0 30
:2 0 d5 4 :3 0
d3 1b8 1ba :6 0
1bd 1bb 0 338b
0 5a :6 0 30
:2 0 d7 8 :3 0
1bf :7 0 1c3 1c0
1c1 338b 0 5b
:6 0 18 :2 0 d9
8 :3 0 1c5 :7 0
1c9 1c6 1c7 338b
0 5c :6 0 27
:2 0 dd 4 :3 0
db 1cb 1cd :6 0
1d0 1ce 0 338b
0 5d :6 0 27
:2 0 df 8 :3 0
1d2 0 2 :5 0
1d6 1d3 1d4 338b
0 5e :6 0 30
:2 0 e1 8 :3 0
1d8 0 2 :5 0
1dc 1d9 1da 338b
0 5f :6 0 30
:2 0 e3 8 :3 0
1de 0 2 :5 0
1e2 1df 1e0 338b
0 60 :6 0 e7
8a1 0 e5 8
:3 0 1e4 0 2
:5 0 1e8 1e5 1e6
338b 0 61 :6 0
1f5 1f6 0 e9
8 :3 0 1ea :7 0
1ed 1eb 0 338b
0 62 :6 0 15
:3 0 16 :2 0 4
1ef 1f0 0 1f1
:7 0 1f4 1f2 0
338b 0 63 :6 0
64 :3 0 65 :3 0
64 :3 0 66 :3 0
1f8 1f9 0 2
:4 0 eb 1fa 1fc
1f7 1fe 1fd :2 0
67 :3 0 68 :3 0
200 201 0 69
:4 0 64 :3 0 6a
:3 0 204 205 0
2 :4 0 ed 206
208 6b :4 0 6c
:2 0 6d :3 0 ef
20b 20d :3 0 6e
:4 0 6c :2 0 6f
:4 0 f2 210 212
:3 0 6c :2 0 3
:3 0 f5 214 216
:3 0 6c :2 0 6f
:4 0 f8 218 21a
:3 0 6c :2 0 70
:4 0 fb 21c 21e
:3 0 6c :2 0 6f
:4 0 fe 220 222
:3 0 6c :2 0 5
:3 0 101 224 226
:3 0 6c :2 0 6f
:4 0 104 228 22a
:3 0 6c :2 0 70
:4 0 107 22c 22e
:3 0 6c :2 0 6f
:4 0 10a 230 232
:3 0 6c :2 0 6
:3 0 10d 234 236
:3 0 6c :2 0 6f
:4 0 110 238 23a
:3 0 6c :2 0 70
:4 0 113 23c 23e
:3 0 6c :2 0 71
:3 0 72 :3 0 7
:3 0 116 242 244
73 :4 0 118 241
247 11b 240 249
:3 0 6c :2 0 70
:4 0 11e 24b 24d
:3 0 6c :2 0 71
:3 0 72 :3 0 9
:3 0 121 251 253
73 :4 0 123 250
256 126 24f 258
:3 0 6c :2 0 70
:4 0 129 25a 25c
:3 0 6c :2 0 71
:3 0 72 :3 0 a
:3 0 12c 260 262
73 :4 0 12e 25f
265 131 25e 267
:3 0 6c :2 0 70
:4 0 134 269 26b
:3 0 6c :2 0 71
:3 0 72 :3 0 b
:3 0 137 26f 271
73 :4 0 139 26e
274 13c 26d 276
:3 0 6c :2 0 70
:4 0 13f 278 27a
:3 0 6c :2 0 71
:3 0 72 :3 0 c
:3 0 142 27e 280
73 :4 0 144 27d
283 147 27c 285
:3 0 6c :2 0 70
:4 0 14a 287 289
:3 0 6c :2 0 71
:3 0 72 :3 0 d
:3 0 14d 28d 28f
73 :4 0 14f 28c
292 152 28b 294
:3 0 6c :2 0 70
:4 0 155 296 298
:3 0 6c :2 0 71
:3 0 72 :3 0 e
:3 0 158 29c 29e
73 :4 0 15a 29b
2a1 15d 29a 2a3
:3 0 6c :2 0 70
:4 0 160 2a5 2a7
:3 0 6c :2 0 71
:3 0 72 :3 0 f
:3 0 163 2ab 2ad
73 :4 0 165 2aa
2b0 168 2a9 2b2
:3 0 6c :2 0 70
:4 0 16b 2b4 2b6
:3 0 6c :2 0 71
:3 0 72 :3 0 10
:3 0 16e 2ba 2bc
73 :4 0 170 2b9
2bf 173 2b8 2c1
:3 0 6c :2 0 70
:4 0 176 2c3 2c5
:3 0 6c :2 0 71
:3 0 72 :3 0 11
:3 0 179 2c9 2cb
73 :4 0 17b 2c8
2ce 17e 2c7 2d0
:3 0 6c :2 0 70
:4 0 181 2d2 2d4
:3 0 6c :2 0 6f
:4 0 184 2d6 2d8
:3 0 6c :2 0 12
:3 0 187 2da 2dc
:3 0 6c :2 0 6f
:4 0 18a 2de 2e0
:3 0 6c :2 0 70
:4 0 18d 2e2 2e4
:3 0 6c :2 0 6f
:4 0 190 2e6 2e8
:3 0 6c :2 0 13
:3 0 193 2ea 2ec
:3 0 6c :2 0 6f
:4 0 196 2ee 2f0
:3 0 6c :2 0 74
:4 0 199 2f2 2f4
:3 0 19c 202 2f6
:2 0 2f8 1a1 2f9
1ff 2f8 0 2fa
1a3 0 32eb 64
:3 0 65 :3 0 2fb
2fc 0 64 :3 0
75 :3 0 2fe 2ff
0 27 :2 0 2
:4 0 76 :2 0 77
:2 0 27 :2 0 1a5
304 306 :3 0 1a8
300 308 2fd 30a
309 :2 0 67 :3 0
78 :3 0 30c 30d
0 69 :4 0 79
:4 0 6c :2 0 6d
:3 0 1ac 311 313
:3 0 1af 30e 315
:2 0 317 1b2 318
30b 317 0 319
1b4 0 32eb 17
:3 0 3 :3 0 31a
31b 0 32eb 1f
:3 0 5 :3 0 31d
31e 0 32eb 22
:3 0 6 :3 0 320
321 0 32eb 1c
:3 0 13 :3 0 323
324 0 32eb 37
:3 0 7 :3 0 326
327 0 32eb 35
:3 0 9 :3 0 329
32a 0 32eb 36
:3 0 e :3 0 32c
32d 0 32eb 38
:3 0 b :3 0 32f
330 0 32eb 3a
:3 0 f :3 0 332
333 0 32eb 39
:3 0 c :3 0 335
336 0 32eb 32
:3 0 11 :3 0 338
339 0 32eb 31
:3 0 a :3 0 33b
33c 0 32eb 3b
:3 0 d :3 0 33e
33f 0 32eb 33
:3 0 10 :3 0 341
342 0 32eb 1a
:3 0 17 :3 0 344
345 0 32eb 23
:3 0 7a :4 0 347
348 0 32eb 19
:4 0 34a 34b 0
32eb 58 :3 0 7b
:3 0 71 :3 0 32
:3 0 30 :2 0 1b6
34f 352 1b9 34e
354 34d 355 0
32eb 5b :3 0 30
:2 0 357 358 0
32eb 4e :3 0 7c
:2 0 35a 35b 0
32eb 3f :3 0 30
:2 0 35d 35e 0
32eb 3 :3 0 7d
:2 0 1bb 361 362
:3 0 363 :2 0 64
:3 0 65 :3 0 365
366 0 64 :3 0
75 :3 0 368 369
0 7e :2 0 2
:4 0 7f :2 0 77
:2 0 27 :2 0 1bd
36e 370 :3 0 1c0
36a 372 367 374
373 :2 0 67 :3 0
78 :3 0 376 377
0 69 :4 0 80
:4 0 6c :2 0 6d
:3 0 1c4 37b 37d
:3 0 6c :2 0 81
:4 0 1c7 37f 381
:3 0 6c :2 0 82
:4 0 1ca 383 385
:3 0 6c :2 0 71
:3 0 72 :3 0 83
:3 0 84 :3 0 38a
38b 0 1cd 389
38d 73 :4 0 1cf
388 390 1d2 387
392 :3 0 1d5 378
394 :2 0 396 1d8
397 375 396 0
398 1da 0 3c1
64 :3 0 65 :3 0
399 39a 0 64
:3 0 75 :3 0 39c
39d 0 27 :2 0
2 :4 0 85 :2 0
77 :2 0 27 :2 0
1dc 3a2 3a4 :3 0
1df 39e 3a6 39b
3a8 3a7 :2 0 67
:3 0 78 :3 0 3aa
3ab 0 69 :4 0
86 :4 0 6c :2 0
6d :3 0 1e3 3af
3b1 :3 0 1e6 3ac
3b3 :2 0 3b5 1e9
3b6 3a9 3b5 0
3b7 1eb 0 3c1
87 :3 0 88 :3 0
3b8 3b9 0 83
:3 0 84 :3 0 3bb
3bc 0 89 :3 0
1ed 3ba 3bf :2 0
3c1 1f0 3c2 364
3c1 0 3c3 1f4
0 32eb 12 :3 0
7d :2 0 1f6 3c5
3c6 :3 0 3c7 :2 0
64 :3 0 65 :3 0
3c9 3ca 0 64
:3 0 75 :3 0 3cc
3cd 0 7e :2 0
2 :4 0 8a :2 0
77 :2 0 27 :2 0
1f8 3d2 3d4 :3 0
1fb 3ce 3d6 3cb
3d8 3d7 :2 0 67
:3 0 78 :3 0 3da
3db 0 69 :4 0
8b :4 0 6c :2 0
6d :3 0 1ff 3df
3e1 :3 0 6c :2 0
81 :4 0 202 3e3
3e5 :3 0 6c :2 0
82 :4 0 205 3e7
3e9 :3 0 6c :2 0
71 :3 0 72 :3 0
83 :3 0 84 :3 0
3ee 3ef 0 208
3ed 3f1 73 :4 0
20a 3ec 3f4 20d
3eb 3f6 :3 0 210
3dc 3f8 :2 0 3fa
213 3fb 3d9 3fa
0 3fc 215 0
425 64 :3 0 65
:3 0 3fd 3fe 0
64 :3 0 75 :3 0
400 401 0 27
:2 0 2 :4 0 8c
:2 0 77 :2 0 27
:2 0 217 406 408
:3 0 21a 402 40a
3ff 40c 40b :2 0
67 :3 0 78 :3 0
40e 40f 0 69
:4 0 8d :4 0 6c
:2 0 6d :3 0 21e
413 415 :3 0 221
410 417 :2 0 419
224 41a 40d 419
0 41b 226 0
425 87 :3 0 88
:3 0 41c 41d 0
83 :3 0 84 :3 0
41f 420 0 89
:3 0 228 41e 423
:2 0 425 22b 426
3c8 425 0 427
22f 0 32eb 71
:3 0 31 :3 0 30
:2 0 231 428 42b
8e :2 0 8f :2 0
236 42d 42f :3 0
71 :3 0 39 :3 0
30 :2 0 239 431
434 8e :2 0 8f
:2 0 23e 436 438
:3 0 430 43a 439
:2 0 71 :3 0 35
:3 0 30 :2 0 241
43c 43f 8e :2 0
8f :2 0 246 441
443 :3 0 43b 445
444 :2 0 64 :3 0
65 :3 0 447 448
0 64 :3 0 75
:3 0 44a 44b 0
7e :2 0 2 :4 0
90 :2 0 77 :2 0
27 :2 0 249 450
452 :3 0 24c 44c
454 449 456 455
:2 0 67 :3 0 78
:3 0 458 459 0
69 :4 0 91 :4 0
6c :2 0 6d :3 0
250 45d 45f :3 0
6c :2 0 81 :4 0
253 461 463 :3 0
6c :2 0 82 :4 0
256 465 467 :3 0
6c :2 0 71 :3 0
72 :3 0 83 :3 0
92 :3 0 46c 46d
0 259 46b 46f
73 :4 0 25b 46a
472 25e 469 474
:3 0 261 45a 476
:2 0 478 264 479
457 478 0 47a
266 0 4a3 64
:3 0 65 :3 0 47b
47c 0 64 :3 0
75 :3 0 47e 47f
0 27 :2 0 2
:4 0 93 :2 0 77
:2 0 27 :2 0 268
484 486 :3 0 26b
480 488 47d 48a
489 :2 0 67 :3 0
78 :3 0 48c 48d
0 69 :4 0 94
:4 0 6c :2 0 6d
:3 0 26f 491 493
:3 0 272 48e 495
:2 0 497 275 498
48b 497 0 499
277 0 4a3 87
:3 0 88 :3 0 49a
49b 0 83 :3 0
92 :3 0 49d 49e
0 89 :3 0 279
49c 4a1 :2 0 4a3
27c 4a4 446 4a3
0 4a5 280 0
32eb 5 :3 0 95
:2 0 282 4a7 4a8
:3 0 4a9 :2 0 4aa
:2 0 6 :3 0 95
:2 0 284 4ad 4ae
:3 0 4af :2 0 4b0
:2 0 4ab 4b2 4b1
:2 0 96 :3 0 97
:3 0 6 :3 0 96
:3 0 97 :3 0 5
:3 0 44 :3 0 98
:4 0 99 1 :8 0
4c2 15 :3 0 9a
:3 0 4bd 4be 0
9b :3 0 4bf 4c0
0 4c2 286 515
9c :3 0 15 :3 0
9a :3 0 4c4 4c5
0 9b :3 0 4c6
4c7 0 4c9 289
4cb 28b 4ca 4c9
:2 0 513 9d :3 0
15 :3 0 9a :3 0
4ce 4cf 0 9b
:3 0 4d0 4d1 0
50b 64 :3 0 65
:3 0 4d3 4d4 0
64 :3 0 75 :3 0
4d6 4d7 0 9e
:2 0 2 :4 0 9f
:2 0 77 :2 0 27
:2 0 28d 4dc 4de
:3 0 290 4d8 4e0
4d5 4e2 4e1 :2 0
67 :3 0 78 :3 0
4e4 4e5 0 69
:4 0 a0 :4 0 6c
:2 0 6d :3 0 294
4e9 4eb :3 0 6c
:2 0 81 :4 0 297
4ed 4ef :3 0 6c
:2 0 a1 :4 0 29a
4f1 4f3 :3 0 6c
:2 0 9b :3 0 29d
4f5 4f7 :3 0 6c
:2 0 a2 :4 0 2a0
4f9 4fb :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 2a3 4fe 502
2a7 4fd 504 :3 0
2aa 4e6 506 :2 0
508 2ad 509 4e3
508 0 50a 2af
0 50b 2b1 50e
:3 0 50e 0 50e
50d 50b 50c :6 0
510 2 :3 0 2b4
512 2b6 511 510
:2 0 513 2b8 :2 0
515 0 515 514
4c2 513 :6 0 590
1 :3 0 15 :3 0
9a :3 0 517 518
0 15 :3 0 8e
:2 0 a6 :3 0 51a
51c 0 2bd 51b
51e :3 0 51f :2 0
71 :3 0 44 :3 0
30 :2 0 2c0 521
524 a7 :2 0 30
:2 0 2c5 526 528
:3 0 529 :2 0 520
52b 52a :2 0 64
:3 0 65 :3 0 52d
52e 0 64 :3 0
75 :3 0 530 531
0 7e :2 0 2
:4 0 a8 :2 0 77
:2 0 27 :2 0 2c8
536 538 :3 0 2cb
532 53a 52f 53c
53b :2 0 67 :3 0
78 :3 0 53e 53f
0 69 :4 0 a9
:4 0 6c :2 0 6d
:3 0 2cf 543 545
:3 0 6c :2 0 81
:4 0 2d2 547 549
:3 0 6c :2 0 82
:4 0 2d5 54b 54d
:3 0 6c :2 0 71
:3 0 72 :3 0 83
:3 0 aa :3 0 552
553 0 2d8 551
555 73 :4 0 2da
550 558 2dd 54f
55a :3 0 2e0 540
55c :2 0 55e 2e3
55f 53d 55e 0
560 2e5 0 589
64 :3 0 65 :3 0
561 562 0 64
:3 0 75 :3 0 564
565 0 27 :2 0
2 :4 0 ab :2 0
77 :2 0 27 :2 0
2e7 56a 56c :3 0
2ea 566 56e 563
570 56f :2 0 67
:3 0 78 :3 0 572
573 0 69 :4 0
ac :4 0 6c :2 0
6d :3 0 2ee 577
579 :3 0 2f1 574
57b :2 0 57d 2f4
57e 571 57d 0
57f 2f6 0 589
87 :3 0 88 :3 0
580 581 0 83
:3 0 aa :3 0 583
584 0 89 :3 0
2f8 582 587 :2 0
589 2fb 58a 52c
589 0 58b 2ff
0 590 61 :3 0
27 :2 0 58c 58d
0 590 ad :3 0
301 5ff 5 :3 0
7d :2 0 305 592
593 :3 0 594 :2 0
595 :2 0 6 :3 0
7d :2 0 307 598
599 :3 0 59a :2 0
59b :2 0 596 59d
59c :2 0 6d :3 0
1f :3 0 98 :4 0
ae 1 :8 0 5a8
15 :3 0 9a :3 0
5a3 5a4 0 9b
:3 0 5a5 5a6 0
5a8 309 5fb 9c
:3 0 15 :3 0 9a
:3 0 5aa 5ab 0
9b :3 0 5ac 5ad
0 5af 30c 5b1
30e 5b0 5af :2 0
5f9 9d :3 0 15
:3 0 9a :3 0 5b4
5b5 0 9b :3 0
5b6 5b7 0 5f1
64 :3 0 65 :3 0
5b9 5ba 0 64
:3 0 75 :3 0 5bc
5bd 0 9e :2 0
2 :4 0 af :2 0
77 :2 0 27 :2 0
310 5c2 5c4 :3 0
313 5be 5c6 5bb
5c8 5c7 :2 0 67
:3 0 78 :3 0 5ca
5cb 0 69 :4 0
b0 :4 0 6c :2 0
6d :3 0 317 5cf
5d1 :3 0 6c :2 0
81 :4 0 31a 5d3
5d5 :3 0 6c :2 0
a1 :4 0 31d 5d7
5d9 :3 0 6c :2 0
9b :3 0 320 5db
5dd :3 0 6c :2 0
a2 :4 0 323 5df
5e1 :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
326 5e4 5e8 32a
5e3 5ea :3 0 32d
5cc 5ec :2 0 5ee
330 5ef 5c9 5ee
0 5f0 332 0
5f1 334 5f4 :3 0
5f4 0 5f4 5f3
5f1 5f2 :6 0 5f6
4 :3 0 337 5f8
339 5f7 5f6 :2 0
5f9 33b :2 0 5fb
0 5fb 5fa 5a8
5f9 :6 0 5fd 1
:3 0 33e 5fe 59e
5fd 0 600 4b3
590 0 600 340
0 32eb 21 :3 0
1f :3 0 601 602
0 32eb 6 :3 0
7d :2 0 343 605
606 :3 0 607 :2 0
22 :3 0 7a :4 0
609 60a 0 60c
345 60d 608 60c
0 60e 347 0
32eb 1d :3 0 a3
:3 0 1d :3 0 27
:2 0 18 :2 0 349
610 614 60f 615
0 32eb 26 :3 0
a3 :3 0 26 :3 0
27 :2 0 27 :2 0
34d 618 61c 617
61d 0 32eb 29
:3 0 12 :3 0 61f
620 0 32eb 71
:3 0 32 :3 0 30
:2 0 351 622 625
b1 :2 0 30 :2 0
356 627 629 :3 0
1d :3 0 a3 :3 0
a3 :3 0 29 :3 0
27 :2 0 18 :2 0
359 62d 631 27
:2 0 18 :2 0 35d
62c 635 62b 636
0 a07 26 :3 0
b2 :3 0 b3 :3 0
639 63a 0 27
:2 0 27 :2 0 b4
:2 0 29 :3 0 361
63b 640 638 641
0 a07 b5 :3 0
71 :3 0 32 :3 0
30 :2 0 366 644
647 369 643 649
b6 :2 0 30 :2 0
36d 64b 64d :3 0
b7 :3 0 71 :3 0
b8 :3 0 71 :3 0
b9 :3 0 ba :3 0
17 :3 0 3d :3 0
3e :3 0 43 :3 0
bb :3 0 bc :3 0
1a :4 0 bd 1
:8 0 662 15 :3 0
9a :3 0 65d 65e
0 9b :3 0 65f
660 0 662 370
6b5 9c :3 0 15
:3 0 9a :3 0 664
665 0 9b :3 0
666 667 0 669
373 66b 375 66a
669 :2 0 6b3 9d
:3 0 15 :3 0 9a
:3 0 66e 66f 0
9b :3 0 670 671
0 6ab 64 :3 0
65 :3 0 673 674
0 64 :3 0 75
:3 0 676 677 0
9e :2 0 2 :4 0
be :2 0 77 :2 0
27 :2 0 377 67c
67e :3 0 37a 678
680 675 682 681
:2 0 67 :3 0 78
:3 0 684 685 0
69 :4 0 bf :4 0
6c :2 0 6d :3 0
37e 689 68b :3 0
6c :2 0 81 :4 0
381 68d 68f :3 0
6c :2 0 a1 :4 0
384 691 693 :3 0
6c :2 0 9b :3 0
387 695 697 :3 0
6c :2 0 a2 :4 0
38a 699 69b :3 0
6c :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 38d 69e
6a2 391 69d 6a4
:3 0 394 686 6a6
:2 0 6a8 397 6a9
683 6a8 0 6aa
399 0 6ab 39b
6ae :3 0 6ae 0
6ae 6ad 6ab 6ac
:6 0 6b0 6 :3 0
39e 6b2 3a0 6b1
6b0 :2 0 6b3 3a2
:2 0 6b5 0 6b5
6b4 662 6b3 :6 0
6b7 1 :3 0 3a5
759 c0 :3 0 c1
:3 0 c0 :3 0 c2
:3 0 c0 :3 0 c3
:3 0 c0 :3 0 c4
:3 0 c0 :3 0 b7
:3 0 71 :3 0 c5
:3 0 b8 :3 0 71
:3 0 c5 :3 0 b9
:3 0 c5 :3 0 ba
:3 0 32 :3 0 5b
:3 0 59 :3 0 5a
:3 0 17 :3 0 3d
:3 0 3e :3 0 43
:3 0 bb :3 0 c5
:3 0 bb :3 0 c0
:3 0 c0 :3 0 bc
:3 0 1a :3 0 c0
:3 0 c1 :3 0 83
:3 0 c6 :3 0 83
:3 0 c7 :3 0 83
:3 0 c8 :3 0 83
:3 0 c9 :3 0 83
:3 0 ca :3 0 83
:3 0 cb :3 0 83
:3 0 cc :3 0 83
:3 0 cd :3 0 83
:3 0 ce :3 0 83
:3 0 cf :3 0 83
:3 0 d0 :3 0 83
:3 0 d1 :3 0 83
:3 0 d2 :3 0 83
:3 0 d3 :3 0 83
:3 0 d4 :3 0 c5
:3 0 bc :3 0 c0
:3 0 b7 :4 0 d5
1 :8 0 703 15
:3 0 9a :3 0 6fe
6ff 0 9b :3 0
700 701 0 703
3a7 756 9c :3 0
15 :3 0 9a :3 0
705 706 0 9b
:3 0 707 708 0
70a 3aa 70c 3ac
70b 70a :2 0 754
9d :3 0 15 :3 0
9a :3 0 70f 710
0 9b :3 0 711
712 0 74c 64
:3 0 65 :3 0 714
715 0 64 :3 0
75 :3 0 717 718
0 9e :2 0 2
:4 0 d6 :2 0 77
:2 0 27 :2 0 3ae
71d 71f :3 0 3b1
719 721 716 723
722 :2 0 67 :3 0
78 :3 0 725 726
0 69 :4 0 d7
:4 0 6c :2 0 6d
:3 0 3b5 72a 72c
:3 0 6c :2 0 81
:4 0 3b8 72e 730
:3 0 6c :2 0 a1
:4 0 3bb 732 734
:3 0 6c :2 0 9b
:3 0 3be 736 738
:3 0 6c :2 0 a2
:4 0 3c1 73a 73c
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 3c4
73f 743 3c8 73e
745 :3 0 3cb 727
747 :2 0 749 3ce
74a 724 749 0
74b 3d0 0 74c
3d2 74f :3 0 74f
0 74f 74e 74c
74d :6 0 751 8
:3 0 3d5 753 3d7
752 751 :2 0 754
3d9 :2 0 756 0
756 755 703 754
:6 0 758 1 :3 0
3dc 75a 64e 6b7
0 75b 0 758
0 75b 3de 0
a07 15 :3 0 9a
:3 0 75c 75d 0
15 :3 0 8e :2 0
d8 :3 0 75f 761
0 3e3 760 763
:3 0 764 :2 0 b7
:3 0 d9 :3 0 17
:3 0 5d :3 0 da
:3 0 bc :3 0 1a
:4 0 db 1 :8 0
773 15 :3 0 9a
:3 0 76e 76f 0
9b :3 0 770 771
0 773 3e6 7c6
9c :3 0 15 :3 0
9a :3 0 775 776
0 9b :3 0 777
778 0 77a 3e9
77c 3eb 77b 77a
:2 0 7c4 9d :3 0
15 :3 0 9a :3 0
77f 780 0 9b
:3 0 781 782 0
7bc 64 :3 0 65
:3 0 784 785 0
64 :3 0 75 :3 0
787 788 0 9e
:2 0 2 :4 0 dc
:2 0 77 :2 0 27
:2 0 3ed 78d 78f
:3 0 3f0 789 791
786 793 792 :2 0
67 :3 0 78 :3 0
795 796 0 69
:4 0 dd :4 0 6c
:2 0 6d :3 0 3f4
79a 79c :3 0 6c
:2 0 81 :4 0 3f7
79e 7a0 :3 0 6c
:2 0 a1 :4 0 3fa
7a2 7a4 :3 0 6c
:2 0 9b :3 0 3fd
7a6 7a8 :3 0 6c
:2 0 a2 :4 0 400
7aa 7ac :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 403 7af 7b3
407 7ae 7b5 :3 0
40a 797 7b7 :2 0
7b9 40d 7ba 794
7b9 0 7bb 40f
0 7bc 411 7bf
:3 0 7bf 0 7bf
7be 7bc 7bd :6 0
7c1 a :3 0 414
7c3 416 7c2 7c1
:2 0 7c4 418 :2 0
7c6 0 7c6 7c5
773 7c4 :6 0 8b5
1 :3 0 15 :3 0
9a :3 0 7c8 7c9
0 15 :3 0 8e
:2 0 a6 :3 0 7cb
7cd 0 41d 7cc
7cf :3 0 7d0 :2 0
5d :3 0 95 :2 0
420 7d3 7d4 :3 0
7d5 :2 0 58 :3 0
27 :2 0 7d7 7d8
0 7da 422 7db
7d6 7da 0 7dc
424 0 843 71
:3 0 b8 :3 0 71
:3 0 b9 :3 0 ba
:3 0 3d :3 0 3e
:3 0 43 :3 0 bb
:3 0 bc :3 0 17
:4 0 de 1 :8 0
7ee 15 :3 0 9a
:3 0 7e9 7ea 0
9b :3 0 7eb 7ec
0 7ee 426 841
9c :3 0 15 :3 0
9a :3 0 7f0 7f1
0 9b :3 0 7f2
7f3 0 7f5 429
7f7 42b 7f6 7f5
:2 0 83f 9d :3 0
15 :3 0 9a :3 0
7fa 7fb 0 9b
:3 0 7fc 7fd 0
837 64 :3 0 65
:3 0 7ff 800 0
64 :3 0 75 :3 0
802 803 0 9e
:2 0 2 :4 0 df
:2 0 77 :2 0 27
:2 0 42d 808 80a
:3 0 430 804 80c
801 80e 80d :2 0
67 :3 0 78 :3 0
810 811 0 69
:4 0 e0 :4 0 6c
:2 0 6d :3 0 434
815 817 :3 0 6c
:2 0 81 :4 0 437
819 81b :3 0 6c
:2 0 a1 :4 0 43a
81d 81f :3 0 6c
:2 0 9b :3 0 43d
821 823 :3 0 6c
:2 0 a2 :4 0 440
825 827 :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 443 82a 82e
447 829 830 :3 0
44a 812 832 :2 0
834 44d 835 80f
834 0 836 44f
0 837 451 83a
:3 0 83a 0 83a
839 837 838 :6 0
83c c :3 0 454
83e 456 83d 83c
:2 0 83f 458 :2 0
841 0 841 840
7ee 83f :6 0 843
1 :3 0 45b 8b2
64 :3 0 65 :3 0
844 845 0 64
:3 0 75 :3 0 847
848 0 18 :2 0
2 :4 0 e1 :2 0
77 :2 0 27 :2 0
45e 84d 84f :3 0
461 849 851 846
853 852 :2 0 67
:3 0 78 :3 0 855
856 0 69 :4 0
e2 :4 0 6c :2 0
6d :3 0 465 85a
85c :3 0 6c :2 0
81 :4 0 468 85e
860 :3 0 6c :2 0
82 :4 0 46b 862
864 :3 0 6c :2 0
71 :3 0 72 :3 0
83 :3 0 e3 :3 0
869 86a 0 46e
868 86c 73 :4 0
470 867 86f 473
866 871 :3 0 6c
:2 0 e4 :4 0 476
873 875 :3 0 6c
:2 0 6f :4 0 479
877 879 :3 0 6c
:2 0 1a :3 0 47c
87b 87d :3 0 6c
:2 0 6f :4 0 47f
87f 881 :3 0 482
857 883 :2 0 885
485 886 854 885
0 887 487 0
8b1 64 :3 0 65
:3 0 888 889 0
64 :3 0 75 :3 0
88b 88c 0 27
:2 0 2 :4 0 e5
:2 0 77 :2 0 27
:2 0 489 891 893
:3 0 48c 88d 895
88a 897 896 :2 0
67 :3 0 78 :3 0
899 89a 0 69
:4 0 e6 :4 0 6c
:2 0 6d :3 0 490
89e 8a0 :3 0 493
89b 8a2 :2 0 8a4
496 8a5 898 8a4
0 8a6 498 0
8b1 87 :3 0 e7
:3 0 8a7 8a8 0
83 :3 0 e3 :3 0
8aa 8ab 0 1a
:3 0 89 :3 0 49a
8a9 8af :2 0 8b1
49e 8b3 7d1 843
0 8b4 0 8b1
0 8b4 4a2 0
8b5 4a5 8ba 58
:3 0 27 :2 0 8b6
8b7 0 8b9 4a8
8bb 765 8b5 0
8bc 0 8b9 0
8bc 4aa 0 a07
5c :3 0 30 :2 0
8bd 8be 0 a07
e8 :3 0 5c :3 0
e9 :3 0 b7 :3 0
17 :4 0 ea 1
:8 0 8cb 15 :3 0
9a :3 0 8c6 8c7
0 9b :3 0 8c8
8c9 0 8cb 4ad
91e 9c :3 0 15
:3 0 9a :3 0 8cd
8ce 0 9b :3 0
8cf 8d0 0 8d2
4b0 8d4 4b2 8d3
8d2 :2 0 91c 9d
:3 0 15 :3 0 9a
:3 0 8d7 8d8 0
9b :3 0 8d9 8da
0 914 64 :3 0
65 :3 0 8dc 8dd
0 64 :3 0 75
:3 0 8df 8e0 0
9e :2 0 2 :4 0
eb :2 0 77 :2 0
27 :2 0 4b4 8e5
8e7 :3 0 4b7 8e1
8e9 8de 8eb 8ea
:2 0 67 :3 0 78
:3 0 8ed 8ee 0
69 :4 0 ec :4 0
6c :2 0 6d :3 0
4bb 8f2 8f4 :3 0
6c :2 0 81 :4 0
4be 8f6 8f8 :3 0
6c :2 0 a1 :4 0
4c1 8fa 8fc :3 0
6c :2 0 9b :3 0
4c4 8fe 900 :3 0
6c :2 0 a2 :4 0
4c7 902 904 :3 0
6c :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 4ca 907
90b 4ce 906 90d
:3 0 4d1 8ef 90f
:2 0 911 4d4 912
8ec 911 0 913
4d6 0 914 4d8
917 :3 0 917 0
917 916 914 915
:6 0 919 e :3 0
4db 91b 4dd 91a
919 :2 0 91c 4df
:2 0 91e 0 91e
91d 8cb 91c :6 0
a07 1 :3 0 71
:3 0 5c :3 0 30
:2 0 4e2 920 923
b1 :2 0 30 :2 0
4e7 925 927 :3 0
ed :3 0 4d :3 0
bb :3 0 bc :3 0
17 :4 0 ee 1
:8 0 934 15 :3 0
9a :3 0 92f 930
0 9b :3 0 931
932 0 934 4ea
987 9c :3 0 15
:3 0 9a :3 0 936
937 0 9b :3 0
938 939 0 93b
4ed 93d 4ef 93c
93b :2 0 985 9d
:3 0 15 :3 0 9a
:3 0 940 941 0
9b :3 0 942 943
0 97d 64 :3 0
65 :3 0 945 946
0 64 :3 0 75
:3 0 948 949 0
9e :2 0 2 :4 0
ef :2 0 77 :2 0
27 :2 0 4f1 94e
950 :3 0 4f4 94a
952 947 954 953
:2 0 67 :3 0 78
:3 0 956 957 0
69 :4 0 f0 :4 0
6c :2 0 6d :3 0
4f8 95b 95d :3 0
6c :2 0 81 :4 0
4fb 95f 961 :3 0
6c :2 0 a1 :4 0
4fe 963 965 :3 0
6c :2 0 9b :3 0
501 967 969 :3 0
6c :2 0 a2 :4 0
504 96b 96d :3 0
6c :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 507 970
974 50b 96f 976
:3 0 50e 958 978
:2 0 97a 511 97b
955 97a 0 97c
513 0 97d 515
980 :3 0 980 0
980 97f 97d 97e
:6 0 982 10 :3 0
518 984 51a 983
982 :2 0 985 51c
:2 0 987 0 987
986 934 985 :6 0
a04 1 :3 0 96
:3 0 f1 :3 0 989
98a 0 4d :3 0
f2 :4 0 51f 98b
98e 8e :2 0 30
:2 0 524 990 992
:3 0 64 :3 0 65
:3 0 994 995 0
64 :3 0 75 :3 0
997 998 0 18
:2 0 2 :4 0 f3
:2 0 77 :2 0 27
:2 0 527 99d 99f
:3 0 52a 999 9a1
996 9a3 9a2 :2 0
67 :3 0 78 :3 0
9a5 9a6 0 69
:4 0 f4 :4 0 6c
:2 0 6d :3 0 52e
9aa 9ac :3 0 6c
:2 0 81 :4 0 531
9ae 9b0 :3 0 6c
:2 0 82 :4 0 534
9b2 9b4 :3 0 6c
:2 0 71 :3 0 72
:3 0 83 :3 0 f5
:3 0 9b9 9ba 0
537 9b8 9bc 73
:4 0 539 9b7 9bf
53c 9b6 9c1 :3 0
6c :2 0 e4 :4 0
53f 9c3 9c5 :3 0
6c :2 0 6f :4 0
542 9c7 9c9 :3 0
6c :2 0 17 :3 0
545 9cb 9cd :3 0
6c :2 0 6f :4 0
548 9cf 9d1 :3 0
54b 9a7 9d3 :2 0
9d5 54e 9d6 9a4
9d5 0 9d7 550
0 a01 64 :3 0
65 :3 0 9d8 9d9
0 64 :3 0 75
:3 0 9db 9dc 0
27 :2 0 2 :4 0
f6 :2 0 77 :2 0
27 :2 0 552 9e1
9e3 :3 0 555 9dd
9e5 9da 9e7 9e6
:2 0 67 :3 0 78
:3 0 9e9 9ea 0
69 :4 0 f7 :4 0
6c :2 0 6d :3 0
559 9ee 9f0 :3 0
55c 9eb 9f2 :2 0
9f4 55f 9f5 9e8
9f4 0 9f6 561
0 a01 87 :3 0
e7 :3 0 9f7 9f8
0 83 :3 0 f5
:3 0 9fa 9fb 0
17 :3 0 89 :3 0
563 9f9 9ff :2 0
a01 567 a02 993
a01 0 a03 56b
0 a04 56d a05
928 a04 0 a06
570 0 a07 572
b56 71 :3 0 b8
:3 0 71 :3 0 b9
:3 0 ba :3 0 3d
:3 0 3e :3 0 43
:3 0 bb :3 0 bc
:3 0 17 :4 0 f8
1 :8 0 a19 15
:3 0 9a :3 0 a14
a15 0 9b :3 0
a16 a17 0 a19
57a a6c 9c :3 0
15 :3 0 9a :3 0
a1b a1c 0 9b
:3 0 a1d a1e 0
a20 57d a22 57f
a21 a20 :2 0 a6a
9d :3 0 15 :3 0
9a :3 0 a25 a26
0 9b :3 0 a27
a28 0 a62 64
:3 0 65 :3 0 a2a
a2b 0 64 :3 0
75 :3 0 a2d a2e
0 9e :2 0 2
:4 0 f9 :2 0 77
:2 0 27 :2 0 581
a33 a35 :3 0 584
a2f a37 a2c a39
a38 :2 0 67 :3 0
78 :3 0 a3b a3c
0 69 :4 0 fa
:4 0 6c :2 0 6d
:3 0 588 a40 a42
:3 0 6c :2 0 81
:4 0 58b a44 a46
:3 0 6c :2 0 a1
:4 0 58e a48 a4a
:3 0 6c :2 0 9b
:3 0 591 a4c a4e
:3 0 6c :2 0 a2
:4 0 594 a50 a52
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 597
a55 a59 59b a54
a5b :3 0 59e a3d
a5d :2 0 a5f 5a1
a60 a3a a5f 0
a61 5a3 0 a62
5a5 a65 :3 0 a65
0 a65 a64 a62
a63 :6 0 a67 12
:3 0 5a8 a69 5aa
a68 a67 :2 0 a6a
5ac :2 0 a6c 0
a6c a6b a19 a6a
:6 0 b55 1 :3 0
15 :3 0 9a :3 0
a6e a6f 0 15
:3 0 8e :2 0 d8
:3 0 a71 a73 0
5b1 a72 a75 :3 0
a76 :2 0 3d :3 0
3e :3 0 fb :3 0
bc :3 0 17 :4 0
fc 1 :8 0 a83
15 :3 0 9a :3 0
a7e a7f 0 9b
:3 0 a80 a81 0
a83 5b4 ad6 9c
:3 0 15 :3 0 9a
:3 0 a85 a86 0
9b :3 0 a87 a88
0 a8a 5b7 a8c
5b9 a8b a8a :2 0
ad4 9d :3 0 15
:3 0 9a :3 0 a8f
a90 0 9b :3 0
a91 a92 0 acc
64 :3 0 65 :3 0
a94 a95 0 64
:3 0 75 :3 0 a97
a98 0 9e :2 0
2 :4 0 fd :2 0
77 :2 0 27 :2 0
5bb a9d a9f :3 0
5be a99 aa1 a96
aa3 aa2 :2 0 67
:3 0 78 :3 0 aa5
aa6 0 69 :4 0
fe :4 0 6c :2 0
6d :3 0 5c2 aaa
aac :3 0 6c :2 0
81 :4 0 5c5 aae
ab0 :3 0 6c :2 0
a1 :4 0 5c8 ab2
ab4 :3 0 6c :2 0
9b :3 0 5cb ab6
ab8 :3 0 6c :2 0
a2 :4 0 5ce aba
abc :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
5d1 abf ac3 5d5
abe ac5 :3 0 5d8
aa7 ac7 :2 0 ac9
5db aca aa4 ac9
0 acb 5dd 0
acc 5df acf :3 0
acf 0 acf ace
acc acd :6 0 ad1
14 :3 0 5e2 ad3
5e4 ad2 ad1 :2 0
ad4 5e6 :2 0 ad6
0 ad6 ad5 a83
ad4 :6 0 b52 1
:3 0 15 :3 0 9a
:3 0 ad8 ad9 0
15 :3 0 8e :2 0
d8 :3 0 adb add
0 5eb adc adf
:3 0 ae0 :2 0 64
:3 0 65 :3 0 ae2
ae3 0 64 :3 0
75 :3 0 ae5 ae6
0 18 :2 0 2
:4 0 ff :2 0 77
:2 0 27 :2 0 5ee
aeb aed :3 0 5f1
ae7 aef ae4 af1
af0 :2 0 67 :3 0
78 :3 0 af3 af4
0 69 :4 0 100
:4 0 6c :2 0 6d
:3 0 5f5 af8 afa
:3 0 6c :2 0 81
:4 0 5f8 afc afe
:3 0 6c :2 0 82
:4 0 5fb b00 b02
:3 0 6c :2 0 71
:3 0 72 :3 0 83
:3 0 92 :3 0 b07
b08 0 5fe b06
b0a 73 :4 0 600
b05 b0d 603 b04
b0f :3 0 6c :2 0
e4 :4 0 606 b11
b13 :3 0 6c :2 0
6f :4 0 609 b15
b17 :3 0 6c :2 0
17 :3 0 60c b19
b1b :3 0 6c :2 0
6f :4 0 60f b1d
b1f :3 0 612 af5
b21 :2 0 b23 615
b24 af2 b23 0
b25 617 0 b4f
64 :3 0 65 :3 0
b26 b27 0 64
:3 0 75 :3 0 b29
b2a 0 27 :2 0
2 :4 0 101 :2 0
77 :2 0 27 :2 0
619 b2f b31 :3 0
61c b2b b33 b28
b35 b34 :2 0 67
:3 0 78 :3 0 b37
b38 0 69 :4 0
102 :4 0 6c :2 0
6d :3 0 620 b3c
b3e :3 0 623 b39
b40 :2 0 b42 626
b43 b36 b42 0
b44 628 0 b4f
87 :3 0 e7 :3 0
b45 b46 0 83
:3 0 92 :3 0 b48
b49 0 17 :3 0
89 :3 0 62a b47
b4d :2 0 b4f 62e
b50 ae1 b4f 0
b51 632 0 b52
634 b53 a77 b52
0 b54 637 0
b55 639 b57 62a
a07 0 b58 0
b55 0 b58 63c
0 32eb 71 :3 0
5b :3 0 30 :2 0
63f b59 b5c 83
:3 0 8e :2 0 103
:3 0 b5e b60 0
644 b5f b62 :3 0
71 :3 0 32 :3 0
30 :2 0 647 b64
b67 b1 :2 0 30
:2 0 64c b69 b6b
:3 0 b6c :2 0 b63
b6e b6d :2 0 104
:3 0 105 :3 0 5c
:3 0 106 :3 0 b7
:3 0 17 :3 0 107
:3 0 1a :4 0 108
1 :8 0 b7e 15
:3 0 9a :3 0 b79
b7a 0 9b :3 0
b7b b7c 0 b7e
64f bd1 9c :3 0
15 :3 0 9a :3 0
b80 b81 0 9b
:3 0 b82 b83 0
b85 652 b87 654
b86 b85 :2 0 bcf
9d :3 0 15 :3 0
9a :3 0 b8a b8b
0 9b :3 0 b8c
b8d 0 bc7 64
:3 0 65 :3 0 b8f
b90 0 64 :3 0
75 :3 0 b92 b93
0 9e :2 0 2
:4 0 109 :2 0 77
:2 0 27 :2 0 656
b98 b9a :3 0 659
b94 b9c b91 b9e
b9d :2 0 67 :3 0
78 :3 0 ba0 ba1
0 69 :4 0 10a
:4 0 6c :2 0 6d
:3 0 65d ba5 ba7
:3 0 6c :2 0 81
:4 0 660 ba9 bab
:3 0 6c :2 0 a1
:4 0 663 bad baf
:3 0 6c :2 0 9b
:3 0 666 bb1 bb3
:3 0 6c :2 0 a2
:4 0 669 bb5 bb7
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 66c
bba bbe 670 bb9
bc0 :3 0 673 ba2
bc2 :2 0 bc4 676
bc5 b9f bc4 0
bc6 678 0 bc7
67a bca :3 0 bca
0 bca bc9 bc7
bc8 :6 0 bcc 16
:3 0 67d bce 67f
bcd bcc :2 0 bcf
681 :2 0 bd1 0
bd1 bd0 b7e bcf
:6 0 c03 1 :3 0
71 :3 0 5c :3 0
30 :2 0 684 bd3
bd6 b1 :2 0 30
:2 0 689 bd8 bda
:3 0 71 :3 0 3a
:3 0 30 :2 0 68c
bdc bdf 83 :3 0
b6 :2 0 10b :3 0
be1 be3 0 691
be2 be5 :3 0 71
:3 0 3a :3 0 30
:2 0 694 be7 bea
83 :3 0 b6 :2 0
10c :3 0 bec bee
0 699 bed bf0
:3 0 be6 bf2 bf1
:2 0 3a :3 0 10d
:2 0 bf4 bf5 0
bf7 69c bf8 bf3
bf7 0 bf9 69e
0 c00 61 :3 0
27 :2 0 bfa bfb
0 c00 35 :3 0
30 :2 0 bfd bfe
0 c00 6a0 c01
bdb c00 0 c02
6a4 0 c03 6a6
dc5 61 :3 0 8e
:2 0 30 :2 0 6ab
c05 c07 :3 0 21
:3 0 5 :3 0 c09
c0a 0 d32 22
:3 0 6 :3 0 c0c
c0d 0 d32 5c
:3 0 10e :3 0 21
:3 0 22 :3 0 71
:3 0 38 :3 0 30
:2 0 6ae c13 c16
71 :3 0 39 :3 0
30 :2 0 6b1 c18
c1b 71 :3 0 3a
:3 0 30 :2 0 6b4
c1d c20 71 :3 0
31 :3 0 30 :2 0
6b7 c22 c25 71
:3 0 3b :3 0 30
:2 0 6ba c27 c2a
71 :3 0 36 :3 0
30 :2 0 6bd c2c
c2f 71 :3 0 3d
:3 0 30 :2 0 6c0
c31 c34 71 :3 0
3e :3 0 30 :2 0
6c3 c36 c39 35
:3 0 37 :3 0 41
:3 0 6c6 c10 c3e
c0f c3f 0 d32
71 :3 0 5c :3 0
30 :2 0 6d4 c41
c44 83 :3 0 8e
:2 0 92 :3 0 c46
c48 0 6d9 c47
c4a :3 0 64 :3 0
65 :3 0 c4c c4d
0 64 :3 0 75
:3 0 c4f c50 0
7e :2 0 2 :4 0
10f :2 0 77 :2 0
27 :2 0 6dc c55
c57 :3 0 6df c51
c59 c4e c5b c5a
:2 0 67 :3 0 78
:3 0 c5d c5e 0
69 :4 0 110 :4 0
6c :2 0 6d :3 0
6e3 c62 c64 :3 0
6c :2 0 81 :4 0
6e6 c66 c68 :3 0
6c :2 0 82 :4 0
6e9 c6a c6c :3 0
6c :2 0 71 :3 0
72 :3 0 83 :3 0
92 :3 0 c71 c72
0 6ec c70 c74
73 :4 0 6ee c6f
c77 6f1 c6e c79
:3 0 6f4 c5f c7b
:2 0 c7d 6f7 c7e
c5c c7d 0 c7f
6f9 0 ca9 64
:3 0 65 :3 0 c80
c81 0 64 :3 0
75 :3 0 c83 c84
0 27 :2 0 2
:4 0 111 :2 0 77
:2 0 27 :2 0 6fb
c89 c8b :3 0 6fe
c85 c8d c82 c8f
c8e :2 0 67 :3 0
78 :3 0 c91 c92
0 69 :4 0 112
:4 0 6c :2 0 6d
:3 0 702 c96 c98
:3 0 705 c93 c9a
:2 0 c9c 708 c9d
c90 c9c 0 c9e
70a 0 ca9 87
:3 0 88 :3 0 c9f
ca0 0 83 :3 0
92 :3 0 ca2 ca3
0 89 :3 0 70c
ca1 ca6 :2 0 ca9
ad :3 0 70f d22
71 :3 0 5c :3 0
30 :2 0 713 caa
cad b6 :2 0 30
:2 0 718 caf cb1
:3 0 64 :3 0 65
:3 0 cb3 cb4 0
64 :3 0 75 :3 0
cb6 cb7 0 18
:2 0 2 :4 0 113
:2 0 77 :2 0 27
:2 0 71b cbc cbe
:3 0 71e cb8 cc0
cb5 cc2 cc1 :2 0
67 :3 0 78 :3 0
cc4 cc5 0 69
:4 0 114 :4 0 6c
:2 0 6d :3 0 722
cc9 ccb :3 0 6c
:2 0 81 :4 0 725
ccd ccf :3 0 6c
:2 0 82 :4 0 728
cd1 cd3 :3 0 6c
:2 0 71 :3 0 72
:3 0 5c :3 0 72b
cd7 cd9 73 :4 0
72d cd6 cdc 730
cd5 cde :3 0 6c
:2 0 e4 :4 0 733
ce0 ce2 :3 0 6c
:2 0 6f :4 0 736
ce4 ce6 :3 0 6c
:2 0 17 :3 0 739
ce8 cea :3 0 6c
:2 0 6f :4 0 73c
cec cee :3 0 73f
cc6 cf0 :2 0 cf2
742 cf3 cc3 cf2
0 cf4 744 0
d20 64 :3 0 65
:3 0 cf5 cf6 0
64 :3 0 75 :3 0
cf8 cf9 0 27
:2 0 2 :4 0 115
:2 0 77 :2 0 27
:2 0 746 cfe d00
:3 0 749 cfa d02
cf7 d04 d03 :2 0
67 :3 0 78 :3 0
d06 d07 0 69
:4 0 116 :4 0 6c
:2 0 6d :3 0 74d
d0b d0d :3 0 750
d08 d0f :2 0 d11
753 d12 d05 d11
0 d13 755 0
d20 87 :3 0 e7
:3 0 d14 d15 0
71 :3 0 5c :3 0
30 :2 0 757 d17
d1a 17 :3 0 89
:3 0 75a d16 d1e
:2 0 d20 75e d21
cb2 d20 0 d23
c4b ca9 0 d23
762 0 d32 22
:3 0 22 :3 0 d24
d25 0 d32 22
:3 0 7d :2 0 765
d28 d29 :3 0 d2a
:2 0 22 :3 0 7a
:4 0 d2c d2d 0
d2f 767 d30 d2b
d2f 0 d31 769
0 d32 76b d52
22 :3 0 6 :3 0
d33 d34 0 d51
71 :3 0 39 :3 0
30 :2 0 772 d36
d39 8e :2 0 8f
:2 0 777 d3b d3d
:3 0 35 :3 0 71
:3 0 35 :3 0 30
:2 0 77a d40 d43
117 :2 0 71 :3 0
3e :3 0 30 :2 0
77d d46 d49 780
d45 d4b :3 0 d3f
d4c 0 d4e 783
d4f d3e d4e 0
d50 785 0 d51
787 d53 c08 d32
0 d54 0 d51
0 d54 78a 0
dc4 71 :3 0 35
:3 0 30 :2 0 78d
d55 d58 b1 :2 0
30 :2 0 792 d5a
d5c :3 0 d5d :2 0
71 :3 0 39 :3 0
30 :2 0 795 d5f
d62 b6 :2 0 118
:2 0 79a d64 d66
:3 0 d67 :2 0 d5e
d69 d68 :2 0 71
:3 0 39 :3 0 30
:2 0 79d d6b d6e
8e :2 0 27 :2 0
7a2 d70 d72 :3 0
d73 :2 0 71 :3 0
39 :3 0 30 :2 0
7a5 d75 d78 8e
:2 0 119 :2 0 7aa
d7a d7c :3 0 d7d
:2 0 d74 d7f d7e
:2 0 38 :3 0 119
:2 0 d81 d82 0
d85 ad :3 0 7ad
dbf 71 :3 0 39
:3 0 30 :2 0 7af
d86 d89 8e :2 0
30 :2 0 7b4 d8b
d8d :3 0 38 :3 0
27 :2 0 d8f d90
0 d93 ad :3 0
7b7 d94 d8e d93
0 dc0 71 :3 0
39 :3 0 30 :2 0
7b9 d95 d98 8e
:2 0 11a :2 0 7be
d9a d9c :3 0 d9d
:2 0 71 :3 0 39
:3 0 30 :2 0 7c1
d9f da2 8e :2 0
11b :2 0 7c6 da4
da6 :3 0 da7 :2 0
d9e da9 da8 :2 0
38 :3 0 27 :2 0
dab dac 0 daf
ad :3 0 7c9 db0
daa daf 0 dc0
71 :3 0 39 :3 0
30 :2 0 7cb db1
db4 8e :2 0 8f
:2 0 7d0 db6 db8
:3 0 38 :3 0 11a
:2 0 dba dbb 0
dbd 7d3 dbe db9
dbd 0 dc0 d80
d85 0 dc0 7d5
0 dc1 7da dc2
d6a dc1 0 dc3
7dc 0 dc4 7de
dc6 b6f c03 0
dc7 0 dc4 0
dc7 7e1 0 32eb
57 :3 0 11c :4 0
dc9 dca :3 0 dc8
dcb 0 32eb 2b
:3 0 7a :4 0 dcd
dce 0 32eb 2c
:3 0 7a :4 0 dd0
dd1 0 32eb 34
:3 0 11d :3 0 11e
:3 0 dd4 dd5 0
11f :3 0 71 :3 0
3a :3 0 30 :2 0
7e4 dd8 ddb 83
:3 0 120 :3 0 ddd
dde 0 7e7 dd7
de0 de1 :2 0 121
:2 0 7ea dd6 de4
dd3 de5 0 32eb
3a :3 0 11f :3 0
71 :3 0 3a :3 0
30 :2 0 7ed de9
dec 83 :3 0 122
:3 0 dee def 0
7f0 de8 df1 de7
df2 0 32eb 71
:3 0 32 :3 0 30
:2 0 7f3 df4 df7
b1 :2 0 30 :2 0
7f8 df9 dfb :3 0
57 :3 0 123 :3 0
58 :3 0 32 :3 0
1a :3 0 1d :3 0
1c :3 0 28 :3 0
7fb dfe e05 dfd
e06 0 1db0 71
:3 0 31 :3 0 30
:2 0 802 e08 e0b
83 :3 0 8e :2 0
124 :3 0 e0d e0f
0 807 e0e e11
:3 0 71 :3 0 57
:3 0 30 :2 0 80a
e13 e16 8e :2 0
27 :2 0 80f e18
e1a :3 0 57 :3 0
83 :3 0 125 :3 0
e1d e1e 0 e1c
e1f 0 e21 812
e22 e1b e21 0
e23 814 0 e91
64 :3 0 65 :3 0
e24 e25 0 64
:3 0 75 :3 0 e27
e28 0 18 :2 0
2 :4 0 126 :2 0
77 :2 0 27 :2 0
816 e2d e2f :3 0
819 e29 e31 e26
e33 e32 :2 0 67
:3 0 78 :3 0 e35
e36 0 69 :4 0
127 :4 0 6c :2 0
6d :3 0 81d e3a
e3c :3 0 6c :2 0
81 :4 0 820 e3e
e40 :3 0 6c :2 0
82 :4 0 823 e42
e44 :3 0 6c :2 0
71 :3 0 72 :3 0
57 :3 0 826 e48
e4a 73 :4 0 828
e47 e4d 82b e46
e4f :3 0 6c :2 0
e4 :4 0 82e e51
e53 :3 0 6c :2 0
6f :4 0 831 e55
e57 :3 0 6c :2 0
28 :3 0 834 e59
e5b :3 0 6c :2 0
6f :4 0 837 e5d
e5f :3 0 83a e37
e61 :2 0 e63 83d
e64 e34 e63 0
e65 83f 0 e91
64 :3 0 65 :3 0
e66 e67 0 64
:3 0 75 :3 0 e69
e6a 0 27 :2 0
2 :4 0 128 :2 0
77 :2 0 27 :2 0
841 e6f e71 :3 0
844 e6b e73 e68
e75 e74 :2 0 67
:3 0 78 :3 0 e77
e78 0 69 :4 0
129 :4 0 6c :2 0
6d :3 0 848 e7c
e7e :3 0 84b e79
e80 :2 0 e82 84e
e83 e76 e82 0
e84 850 0 e91
87 :3 0 e7 :3 0
e85 e86 0 71
:3 0 57 :3 0 30
:2 0 852 e88 e8b
28 :3 0 89 :3 0
855 e87 e8f :2 0
e91 859 e92 e12
e91 0 e93 85e
0 1db0 71 :3 0
57 :3 0 30 :2 0
860 e94 e97 b6
:2 0 30 :2 0 865
e99 e9b :3 0 71
:3 0 57 :3 0 30
:2 0 868 e9d ea0
b6 :2 0 27 :2 0
86d ea2 ea4 :3 0
e9c ea6 ea5 :2 0
64 :3 0 65 :3 0
ea8 ea9 0 64
:3 0 75 :3 0 eab
eac 0 18 :2 0
2 :4 0 12a :2 0
77 :2 0 27 :2 0
870 eb1 eb3 :3 0
873 ead eb5 eaa
eb7 eb6 :2 0 67
:3 0 78 :3 0 eb9
eba 0 69 :4 0
12b :4 0 6c :2 0
6d :3 0 877 ebe
ec0 :3 0 6c :2 0
81 :4 0 87a ec2
ec4 :3 0 6c :2 0
82 :4 0 87d ec6
ec8 :3 0 6c :2 0
71 :3 0 72 :3 0
57 :3 0 880 ecc
ece 73 :4 0 882
ecb ed1 885 eca
ed3 :3 0 6c :2 0
e4 :4 0 888 ed5
ed7 :3 0 6c :2 0
6f :4 0 88b ed9
edb :3 0 6c :2 0
28 :3 0 88e edd
edf :3 0 6c :2 0
6f :4 0 891 ee1
ee3 :3 0 894 ebb
ee5 :2 0 ee7 897
ee8 eb8 ee7 0
ee9 899 0 f15
64 :3 0 65 :3 0
eea eeb 0 64
:3 0 75 :3 0 eed
eee 0 27 :2 0
2 :4 0 12c :2 0
77 :2 0 27 :2 0
89b ef3 ef5 :3 0
89e eef ef7 eec
ef9 ef8 :2 0 67
:3 0 78 :3 0 efb
efc 0 69 :4 0
12d :4 0 6c :2 0
6d :3 0 8a2 f00
f02 :3 0 8a5 efd
f04 :2 0 f06 8a8
f07 efa f06 0
f08 8aa 0 f15
87 :3 0 e7 :3 0
f09 f0a 0 71
:3 0 57 :3 0 30
:2 0 8ac f0c f0f
28 :3 0 89 :3 0
8af f0b f13 :2 0
f15 8b3 f16 ea7
f15 0 f17 8b7
0 1db0 21 :4 0
f18 f19 0 1db0
12e :3 0 12f :3 0
96 :3 0 97 :3 0
1f :3 0 96 :3 0
97 :3 0 12e :3 0
12f :3 0 21 :3 0
44 :3 0 106 :3 0
b7 :3 0 17 :3 0
107 :3 0 17 :3 0
130 :3 0 1d :3 0
131 :3 0 26 :4 0
132 1 :8 0 f35
15 :3 0 9a :3 0
f30 f31 0 9b
:3 0 f32 f33 0
f35 8b9 f88 9c
:3 0 15 :3 0 9a
:3 0 f37 f38 0
9b :3 0 f39 f3a
0 f3c 8bc f3e
8be f3d f3c :2 0
f86 9d :3 0 15
:3 0 9a :3 0 f41
f42 0 9b :3 0
f43 f44 0 f7e
64 :3 0 65 :3 0
f46 f47 0 64
:3 0 75 :3 0 f49
f4a 0 9e :2 0
2 :4 0 133 :2 0
77 :2 0 27 :2 0
8c0 f4f f51 :3 0
8c3 f4b f53 f48
f55 f54 :2 0 67
:3 0 78 :3 0 f57
f58 0 69 :4 0
134 :4 0 6c :2 0
6d :3 0 8c7 f5c
f5e :3 0 6c :2 0
81 :4 0 8ca f60
f62 :3 0 6c :2 0
a1 :4 0 8cd f64
f66 :3 0 6c :2 0
9b :3 0 8d0 f68
f6a :3 0 6c :2 0
a2 :4 0 8d3 f6c
f6e :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
8d6 f71 f75 8da
f70 f77 :3 0 8dd
f59 f79 :2 0 f7b
8e0 f7c f56 f7b
0 f7d 8e2 0
f7e 8e4 f81 :3 0
f81 0 f81 f80
f7e f7f :6 0 f83
18 :3 0 8e7 f85
8e9 f84 f83 :2 0
f86 8eb :2 0 f88
0 f88 f87 f35
f86 :6 0 1db0 1
:3 0 15 :3 0 9a
:3 0 f8a f8b 0
15 :3 0 8e :2 0
a6 :3 0 f8d f8f
0 8f0 f8e f91
:3 0 f92 :2 0 21
:3 0 95 :2 0 8f3
f95 f96 :3 0 f97
:2 0 f98 :2 0 f93
f9a f99 :2 0 46
:3 0 27 :2 0 f9c
f9d 0 fae 71
:3 0 44 :3 0 30
:2 0 8f5 f9f fa2
a7 :2 0 30 :2 0
8fa fa4 fa6 :3 0
1f :3 0 21 :3 0
fa8 fa9 0 fab
8fd fac fa7 fab
0 fad 8ff 0
fae 901 faf f9b
fae 0 fb0 904
0 1db0 33 :3 0
30 :2 0 fb1 fb2
0 1db0 44 :3 0
30 :2 0 fb4 fb5
0 1db0 61 :3 0
8e :2 0 27 :2 0
908 fb8 fba :3 0
a3 :3 0 26 :3 0
27 :2 0 27 :2 0
90b fbc fc0 8e
:2 0 30 :4 0 911
fc2 fc4 :3 0 135
:3 0 136 :3 0 137
:3 0 a3 :3 0 1f
:3 0 137 :3 0 a3
:3 0 136 :3 0 137
:3 0 a3 :3 0 138
:3 0 137 :3 0 a3
:3 0 22 :3 0 137
:3 0 a3 :3 0 136
:3 0 137 :3 0 a3
:3 0 138 :3 0 139
:3 0 37 :3 0 139
:3 0 19 :3 0 21
:3 0 44 :3 0 47
:3 0 106 :3 0 107
:3 0 17 :3 0 130
:3 0 1d :3 0 131
:3 0 13a :4 0 13b
1 :8 0 fee 15
:3 0 9a :3 0 fe9
fea 0 9b :3 0
feb fec 0 fee
914 1041 9c :3 0
15 :3 0 9a :3 0
ff0 ff1 0 9b
:3 0 ff2 ff3 0
ff5 917 ff7 919
ff6 ff5 :2 0 103f
9d :3 0 15 :3 0
9a :3 0 ffa ffb
0 9b :3 0 ffc
ffd 0 1037 64
:3 0 65 :3 0 fff
1000 0 64 :3 0
75 :3 0 1002 1003
0 9e :2 0 2
:4 0 13c :2 0 77
:2 0 27 :2 0 91b
1008 100a :3 0 91e
1004 100c 1001 100e
100d :2 0 67 :3 0
78 :3 0 1010 1011
0 69 :4 0 13d
:4 0 6c :2 0 6d
:3 0 922 1015 1017
:3 0 6c :2 0 81
:4 0 925 1019 101b
:3 0 6c :2 0 a1
:4 0 928 101d 101f
:3 0 6c :2 0 9b
:3 0 92b 1021 1023
:3 0 6c :2 0 a2
:4 0 92e 1025 1027
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 931
102a 102e 935 1029
1030 :3 0 938 1012
1032 :2 0 1034 93b
1035 100f 1034 0
1036 93d 0 1037
93f 103a :3 0 103a
0 103a 1039 1037
1038 :6 0 103c 1a
:3 0 942 103e 944
103d 103c :2 0 103f
946 :2 0 1041 0
1041 1040 fee 103f
:6 0 1180 1 :3 0
15 :3 0 9a :3 0
1043 1044 0 15
:3 0 8e :2 0 a6
:3 0 1046 1048 0
94b 1047 104a :3 0
104b :2 0 46 :3 0
27 :2 0 104d 104e
0 10ea 71 :3 0
47 :3 0 30 :2 0
94e 1050 1053 8e
:2 0 30 :2 0 953
1055 1057 :3 0 1058
:2 0 71 :3 0 44
:3 0 30 :2 0 956
105a 105d 8e :2 0
27 :2 0 95b 105f
1061 :3 0 1062 :2 0
1059 1064 1063 :2 0
135 :3 0 13e :3 0
137 :3 0 a3 :3 0
1f :3 0 137 :3 0
a3 :3 0 13e :3 0
137 :3 0 a3 :3 0
13f :3 0 137 :3 0
a3 :3 0 22 :3 0
137 :3 0 a3 :3 0
13e :3 0 137 :3 0
a3 :3 0 13f :3 0
140 :3 0 37 :3 0
19 :3 0 21 :3 0
44 :3 0 106 :3 0
107 :3 0 17 :3 0
130 :3 0 1d :3 0
131 :3 0 13a :4 0
141 1 :8 0 108c
15 :3 0 9a :3 0
1087 1088 0 9b
:3 0 1089 108a 0
108c 95e 10df 9c
:3 0 15 :3 0 9a
:3 0 108e 108f 0
9b :3 0 1090 1091
0 1093 961 1095
963 1094 1093 :2 0
10dd 9d :3 0 15
:3 0 9a :3 0 1098
1099 0 9b :3 0
109a 109b 0 10d5
64 :3 0 65 :3 0
109d 109e 0 64
:3 0 75 :3 0 10a0
10a1 0 9e :2 0
2 :4 0 142 :2 0
77 :2 0 27 :2 0
965 10a6 10a8 :3 0
968 10a2 10aa 109f
10ac 10ab :2 0 67
:3 0 78 :3 0 10ae
10af 0 69 :4 0
143 :4 0 6c :2 0
6d :3 0 96c 10b3
10b5 :3 0 6c :2 0
81 :4 0 96f 10b7
10b9 :3 0 6c :2 0
a1 :4 0 972 10bb
10bd :3 0 6c :2 0
9b :3 0 975 10bf
10c1 :3 0 6c :2 0
a2 :4 0 978 10c3
10c5 :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
97b 10c8 10cc 97f
10c7 10ce :3 0 982
10b0 10d0 :2 0 10d2
985 10d3 10ad 10d2
0 10d4 987 0
10d5 989 10d8 :3 0
10d8 0 10d8 10d7
10d5 10d6 :6 0 10da
1c :3 0 98c 10dc
98e 10db 10da :2 0
10dd 990 :2 0 10df
0 10df 10de 108c
10dd :6 0 10e1 1
:3 0 993 10e6 33
:3 0 119 :2 0 10e2
10e3 0 10e5 995
10e7 1065 10e1 0
10e8 0 10e5 0
10e8 997 0 10ea
ad :3 0 99a 117e
15 :3 0 9a :3 0
10eb 10ec 0 15
:3 0 8e :2 0 d8
:3 0 10ee 10f0 0
99f 10ef 10f2 :3 0
10f3 :2 0 71 :3 0
44 :3 0 30 :2 0
9a2 10f5 10f8 8e
:2 0 27 :2 0 9a7
10fa 10fc :3 0 10fd
:2 0 10f4 10ff 10fe
:2 0 135 :3 0 13e
:3 0 137 :3 0 a3
:3 0 1f :3 0 137
:3 0 a3 :3 0 13e
:3 0 137 :3 0 a3
:3 0 13f :3 0 137
:3 0 a3 :3 0 22
:3 0 137 :3 0 a3
:3 0 13e :3 0 137
:3 0 a3 :3 0 13f
:3 0 140 :3 0 37
:3 0 19 :3 0 21
:3 0 44 :3 0 106
:3 0 107 :3 0 17
:3 0 130 :3 0 1d
:3 0 131 :3 0 13a
:4 0 144 1 :8 0
1127 15 :3 0 9a
:3 0 1122 1123 0
9b :3 0 1124 1125
0 1127 9aa 117a
9c :3 0 15 :3 0
9a :3 0 1129 112a
0 9b :3 0 112b
112c 0 112e 9ad
1130 9af 112f 112e
:2 0 1178 9d :3 0
15 :3 0 9a :3 0
1133 1134 0 9b
:3 0 1135 1136 0
1170 64 :3 0 65
:3 0 1138 1139 0
64 :3 0 75 :3 0
113b 113c 0 9e
:2 0 2 :4 0 145
:2 0 77 :2 0 27
:2 0 9b1 1141 1143
:3 0 9b4 113d 1145
113a 1147 1146 :2 0
67 :3 0 78 :3 0
1149 114a 0 69
:4 0 146 :4 0 6c
:2 0 6d :3 0 9b8
114e 1150 :3 0 6c
:2 0 81 :4 0 9bb
1152 1154 :3 0 6c
:2 0 a1 :4 0 9be
1156 1158 :3 0 6c
:2 0 9b :3 0 9c1
115a 115c :3 0 6c
:2 0 a2 :4 0 9c4
115e 1160 :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 9c7 1163 1167
9cb 1162 1169 :3 0
9ce 114b 116b :2 0
116d 9d1 116e 1148
116d 0 116f 9d3
0 1170 9d5 1173
:3 0 1173 0 1173
1172 1170 1171 :6 0
1175 1e :3 0 9d8
1177 9da 1176 1175
:2 0 1178 9dc :2 0
117a 0 117a 1179
1127 1178 :6 0 117c
1 :3 0 9df 117d
1100 117c 0 117f
104c 10ea 0 117f
9e1 0 1180 9e4
11fd 135 :3 0 13e
:3 0 137 :3 0 a3
:3 0 1f :3 0 137
:3 0 a3 :3 0 13e
:3 0 137 :3 0 a3
:3 0 13f :3 0 137
:3 0 a3 :3 0 22
:3 0 137 :3 0 a3
:3 0 13e :3 0 137
:3 0 a3 :3 0 13f
:3 0 140 :3 0 37
:3 0 19 :3 0 21
:3 0 44 :3 0 106
:3 0 107 :3 0 17
:3 0 130 :3 0 1d
:3 0 131 :3 0 13a
:4 0 147 1 :8 0
11a7 15 :3 0 9a
:3 0 11a2 11a3 0
9b :3 0 11a4 11a5
0 11a7 9e7 11fa
9c :3 0 15 :3 0
9a :3 0 11a9 11aa
0 9b :3 0 11ab
11ac 0 11ae 9ea
11b0 9ec 11af 11ae
:2 0 11f8 9d :3 0
15 :3 0 9a :3 0
11b3 11b4 0 9b
:3 0 11b5 11b6 0
11f0 64 :3 0 65
:3 0 11b8 11b9 0
64 :3 0 75 :3 0
11bb 11bc 0 9e
:2 0 2 :4 0 148
:2 0 77 :2 0 27
:2 0 9ee 11c1 11c3
:3 0 9f1 11bd 11c5
11ba 11c7 11c6 :2 0
67 :3 0 78 :3 0
11c9 11ca 0 69
:4 0 149 :4 0 6c
:2 0 6d :3 0 9f5
11ce 11d0 :3 0 6c
:2 0 81 :4 0 9f8
11d2 11d4 :3 0 6c
:2 0 a1 :4 0 9fb
11d6 11d8 :3 0 6c
:2 0 9b :3 0 9fe
11da 11dc :3 0 6c
:2 0 a2 :4 0 a01
11de 11e0 :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 a04 11e3 11e7
a08 11e2 11e9 :3 0
a0b 11cb 11eb :2 0
11ed a0e 11ee 11c8
11ed 0 11ef a10
0 11f0 a12 11f3
:3 0 11f3 0 11f3
11f2 11f0 11f1 :6 0
11f5 20 :3 0 a15
11f7 a17 11f6 11f5
:2 0 11f8 a19 :2 0
11fa 0 11fa 11f9
11a7 11f8 :6 0 11fc
1 :3 0 a1c 11fe
fc5 1180 0 11ff
0 11fc 0 11ff
a1e 0 1200 a21
1414 a3 :3 0 26
:3 0 27 :2 0 27
:2 0 a23 1201 1205
8e :2 0 30 :4 0
a29 1207 1209 :3 0
135 :3 0 136 :3 0
137 :3 0 a3 :3 0
1f :3 0 137 :3 0
a3 :3 0 136 :3 0
137 :3 0 a3 :3 0
138 :3 0 37 :3 0
139 :3 0 139 :3 0
19 :3 0 21 :3 0
44 :3 0 47 :3 0
106 :3 0 107 :3 0
17 :3 0 130 :3 0
1d :3 0 131 :3 0
13a :4 0 14a 1
:8 0 122a 15 :3 0
9a :3 0 1225 1226
0 9b :3 0 1227
1228 0 122a a2c
127d 9c :3 0 15
:3 0 9a :3 0 122c
122d 0 9b :3 0
122e 122f 0 1231
a2f 1233 a31 1232
1231 :2 0 127b 9d
:3 0 15 :3 0 9a
:3 0 1236 1237 0
9b :3 0 1238 1239
0 1273 64 :3 0
65 :3 0 123b 123c
0 64 :3 0 75
:3 0 123e 123f 0
9e :2 0 2 :4 0
14b :2 0 77 :2 0
27 :2 0 a33 1244
1246 :3 0 a36 1240
1248 123d 124a 1249
:2 0 67 :3 0 78
:3 0 124c 124d 0
69 :4 0 14c :4 0
6c :2 0 6d :3 0
a3a 1251 1253 :3 0
6c :2 0 81 :4 0
a3d 1255 1257 :3 0
6c :2 0 a1 :4 0
a40 1259 125b :3 0
6c :2 0 9b :3 0
a43 125d 125f :3 0
6c :2 0 a2 :4 0
a46 1261 1263 :3 0
6c :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 a49 1266
126a a4d 1265 126c
:3 0 a50 124e 126e
:2 0 1270 a53 1271
124b 1270 0 1272
a55 0 1273 a57
1276 :3 0 1276 0
1276 1275 1273 1274
:6 0 1278 22 :3 0
a5a 127a a5c 1279
1278 :2 0 127b a5e
:2 0 127d 0 127d
127c 122a 127b :6 0
139c 1 :3 0 15
:3 0 9a :3 0 127f
1280 0 15 :3 0
8e :2 0 a6 :3 0
1282 1284 0 a63
1283 1286 :3 0 1287
:2 0 46 :3 0 27
:2 0 1289 128a 0
131b 71 :3 0 47
:3 0 30 :2 0 a66
128c 128f 8e :2 0
30 :2 0 a6b 1291
1293 :3 0 1294 :2 0
71 :3 0 44 :3 0
30 :2 0 a6e 1296
1299 8e :2 0 27
:2 0 a73 129b 129d
:3 0 129e :2 0 1295
12a0 129f :2 0 135
:3 0 13e :3 0 137
:3 0 a3 :3 0 1f
:3 0 137 :3 0 a3
:3 0 13f :3 0 37
:3 0 140 :3 0 19
:3 0 21 :3 0 44
:3 0 106 :3 0 107
:3 0 17 :3 0 130
:3 0 1d :3 0 131
:3 0 13a :4 0 14d
1 :8 0 12bc 15
:3 0 9a :3 0 12b7
12b8 0 9b :3 0
12b9 12ba 0 12bc
a76 130f 9c :3 0
15 :3 0 9a :3 0
12be 12bf 0 9b
:3 0 12c0 12c1 0
12c3 a79 12c5 a7b
12c4 12c3 :2 0 130d
9d :3 0 15 :3 0
9a :3 0 12c8 12c9
0 9b :3 0 12ca
12cb 0 1305 64
:3 0 65 :3 0 12cd
12ce 0 64 :3 0
75 :3 0 12d0 12d1
0 9e :2 0 2
:4 0 14e :2 0 77
:2 0 27 :2 0 a7d
12d6 12d8 :3 0 a80
12d2 12da 12cf 12dc
12db :2 0 67 :3 0
78 :3 0 12de 12df
0 69 :4 0 14f
:4 0 6c :2 0 6d
:3 0 a84 12e3 12e5
:3 0 6c :2 0 81
:4 0 a87 12e7 12e9
:3 0 6c :2 0 a1
:4 0 a8a 12eb 12ed
:3 0 6c :2 0 9b
:3 0 a8d 12ef 12f1
:3 0 6c :2 0 a2
:4 0 a90 12f3 12f5
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 a93
12f8 12fc a97 12f7
12fe :3 0 a9a 12e0
1300 :2 0 1302 a9d
1303 12dd 1302 0
1304 a9f 0 1305
aa1 1308 :3 0 1308
0 1308 1307 1305
1306 :6 0 130a 24
:3 0 aa4 130c aa6
130b 130a :2 0 130d
aa8 :2 0 130f 0
130f 130e 12bc 130d
:6 0 1311 1 :3 0
aab 1317 33 :3 0
119 :2 0 1312 1313
0 1316 0 1316
aad 1318 12a1 1311
0 1319 0 1316
0 1319 ab0 0
131b ad :3 0 ab3
139a 15 :3 0 9a
:3 0 131c 131d 0
15 :3 0 8e :2 0
d8 :3 0 131f 1321
0 ab8 1320 1323
:3 0 1324 :2 0 135
:3 0 13e :3 0 137
:3 0 a3 :3 0 1f
:3 0 137 :3 0 a3
:3 0 13e :3 0 137
:3 0 a3 :3 0 13f
:3 0 37 :3 0 140
:3 0 19 :3 0 21
:3 0 44 :3 0 106
:3 0 107 :3 0 17
:3 0 130 :3 0 1d
:3 0 131 :3 0 13a
:4 0 150 1 :8 0
1343 15 :3 0 9a
:3 0 133e 133f 0
9b :3 0 1340 1341
0 1343 abb 1396
9c :3 0 15 :3 0
9a :3 0 1345 1346
0 9b :3 0 1347
1348 0 134a abe
134c ac0 134b 134a
:2 0 1394 9d :3 0
15 :3 0 9a :3 0
134f 1350 0 9b
:3 0 1351 1352 0
138c 64 :3 0 65
:3 0 1354 1355 0
64 :3 0 75 :3 0
1357 1358 0 9e
:2 0 2 :4 0 151
:2 0 77 :2 0 27
:2 0 ac2 135d 135f
:3 0 ac5 1359 1361
1356 1363 1362 :2 0
67 :3 0 78 :3 0
1365 1366 0 69
:4 0 152 :4 0 6c
:2 0 6d :3 0 ac9
136a 136c :3 0 6c
:2 0 81 :4 0 acc
136e 1370 :3 0 6c
:2 0 a1 :4 0 acf
1372 1374 :3 0 6c
:2 0 9b :3 0 ad2
1376 1378 :3 0 6c
:2 0 a2 :4 0 ad5
137a 137c :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 ad8 137f 1383
adc 137e 1385 :3 0
adf 1367 1387 :2 0
1389 ae2 138a 1364
1389 0 138b ae4
0 138c ae6 138f
:3 0 138f 0 138f
138e 138c 138d :6 0
1391 26 :3 0 ae9
1393 aeb 1392 1391
:2 0 1394 aed :2 0
1396 0 1396 1395
1343 1394 :6 0 1398
1 :3 0 af0 1399
1325 1398 0 139b
1288 131b 0 139b
af2 0 139c af5
1410 135 :3 0 13e
:3 0 137 :3 0 a3
:3 0 1f :3 0 137
:3 0 a3 :3 0 13e
:3 0 137 :3 0 a3
:3 0 13f :3 0 37
:3 0 140 :3 0 19
:3 0 21 :3 0 44
:3 0 106 :3 0 107
:3 0 17 :3 0 130
:3 0 1d :3 0 131
:3 0 13a :4 0 153
1 :8 0 13ba 15
:3 0 9a :3 0 13b5
13b6 0 9b :3 0
13b7 13b8 0 13ba
af8 140d 9c :3 0
15 :3 0 9a :3 0
13bc 13bd 0 9b
:3 0 13be 13bf 0
13c1 afb 13c3 afd
13c2 13c1 :2 0 140b
9d :3 0 15 :3 0
9a :3 0 13c6 13c7
0 9b :3 0 13c8
13c9 0 1403 64
:3 0 65 :3 0 13cb
13cc 0 64 :3 0
75 :3 0 13ce 13cf
0 9e :2 0 2
:4 0 154 :2 0 77
:2 0 27 :2 0 aff
13d4 13d6 :3 0 b02
13d0 13d8 13cd 13da
13d9 :2 0 67 :3 0
78 :3 0 13dc 13dd
0 69 :4 0 155
:4 0 6c :2 0 6d
:3 0 b06 13e1 13e3
:3 0 6c :2 0 81
:4 0 b09 13e5 13e7
:3 0 6c :2 0 a1
:4 0 b0c 13e9 13eb
:3 0 6c :2 0 9b
:3 0 b0f 13ed 13ef
:3 0 6c :2 0 a2
:4 0 b12 13f1 13f3
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 b15
13f6 13fa b19 13f5
13fc :3 0 b1c 13de
13fe :2 0 1400 b1f
1401 13db 1400 0
1402 b21 0 1403
b23 1406 :3 0 1406
0 1406 1405 1403
1404 :6 0 1408 28
:3 0 b26 140a b28
1409 1408 :2 0 140b
b2a :2 0 140d 0
140d 140c 13ba 140b
:6 0 140f 1 :3 0
b2d 1411 120a 139c
0 1412 0 140f
0 1412 b2f 0
1413 b32 1415 fbb
1200 0 1416 0
1413 0 1416 b34
0 1db0 15 :3 0
9a :3 0 1417 1418
0 15 :3 0 8e
:2 0 a6 :3 0 141a
141c 0 b39 141b
141e :3 0 141f :2 0
71 :3 0 44 :3 0
30 :2 0 b3c 1421
1424 8e :2 0 27
:2 0 b41 1426 1428
:3 0 64 :3 0 65
:3 0 142a 142b 0
64 :3 0 75 :3 0
142d 142e 0 18
:2 0 2 :4 0 156
:2 0 77 :2 0 27
:2 0 b44 1433 1435
:3 0 b47 142f 1437
142c 1439 1438 :2 0
67 :3 0 78 :3 0
143b 143c 0 69
:4 0 157 :4 0 6c
:2 0 6d :3 0 b4b
1440 1442 :3 0 6c
:2 0 81 :4 0 b4e
1444 1446 :3 0 6c
:2 0 82 :4 0 b51
1448 144a :3 0 6c
:2 0 71 :3 0 72
:3 0 83 :3 0 158
:3 0 144f 1450 0
b54 144e 1452 73
:4 0 b56 144d 1455
b59 144c 1457 :3 0
6c :2 0 e4 :4 0
b5c 1459 145b :3 0
6c :2 0 6f :4 0
b5f 145d 145f :3 0
6c :2 0 1d :3 0
b62 1461 1463 :3 0
6c :2 0 6f :4 0
b65 1465 1467 :3 0
b68 143d 1469 :2 0
146b b6b 146c 143a
146b 0 146d b6d
0 1498 64 :3 0
65 :3 0 146e 146f
0 64 :3 0 75
:3 0 1471 1472 0
27 :2 0 2 :4 0
159 :2 0 77 :2 0
27 :2 0 b6f 1477
1479 :3 0 b72 1473
147b 1470 147d 147c
:2 0 67 :3 0 78
:3 0 147f 1480 0
69 :4 0 15a :4 0
6c :2 0 6d :3 0
b76 1484 1486 :3 0
b79 1481 1488 :2 0
148a b7c 148b 147e
148a 0 148c b7e
0 1498 87 :3 0
e7 :3 0 148d 148e
0 83 :3 0 158
:3 0 1490 1491 0
1d :3 0 89 :3 0
b80 148f 1495 :2 0
1498 ad :3 0 b84
1609 19 :3 0 95
:2 0 b88 149a 149b
:3 0 149c :2 0 71
:3 0 37 :3 0 30
:2 0 b8a 149e 14a1
b1 :2 0 30 :2 0
b8f 14a3 14a5 :3 0
149d 14a7 14a6 :2 0
61 :3 0 8e :2 0
27 :2 0 b94 14aa
14ac :3 0 47 :3 0
30 :2 0 14ae 14af
0 151b 15b :3 0
15c :3 0 47 :3 0
15d :3 0 b7 :3 0
17 :3 0 105 :3 0
19 :3 0 15e :3 0
137 :3 0 a3 :3 0
1f :3 0 137 :3 0
a3 :3 0 22 :4 0
15f 1 :8 0 14c6
15 :3 0 9a :3 0
14c1 14c2 0 9b
:3 0 14c3 14c4 0
14c6 b97 1519 9c
:3 0 15 :3 0 9a
:3 0 14c8 14c9 0
9b :3 0 14ca 14cb
0 14cd b9a 14cf
b9c 14ce 14cd :2 0
1517 9d :3 0 15
:3 0 9a :3 0 14d2
14d3 0 9b :3 0
14d4 14d5 0 150f
64 :3 0 65 :3 0
14d7 14d8 0 64
:3 0 75 :3 0 14da
14db 0 9e :2 0
2 :4 0 160 :2 0
77 :2 0 27 :2 0
b9e 14e0 14e2 :3 0
ba1 14dc 14e4 14d9
14e6 14e5 :2 0 67
:3 0 78 :3 0 14e8
14e9 0 69 :4 0
161 :4 0 6c :2 0
6d :3 0 ba5 14ed
14ef :3 0 6c :2 0
81 :4 0 ba8 14f1
14f3 :3 0 6c :2 0
a1 :4 0 bab 14f5
14f7 :3 0 6c :2 0
9b :3 0 bae 14f9
14fb :3 0 6c :2 0
a2 :4 0 bb1 14fd
14ff :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
bb4 1502 1506 bb8
1501 1508 :3 0 bbb
14ea 150a :2 0 150c
bbe 150d 14e7 150c
0 150e bc0 0
150f bc2 1512 :3 0
1512 0 1512 1511
150f 1510 :6 0 1514
2a :3 0 bc5 1516
bc7 1515 1514 :2 0
1517 bc9 :2 0 1519
0 1519 1518 14c6
1517 :6 0 151b 1
:3 0 bcc 1587 47
:3 0 30 :2 0 151c
151d 0 1586 15b
:3 0 15c :3 0 47
:3 0 15d :3 0 b7
:3 0 17 :3 0 105
:3 0 19 :3 0 15e
:3 0 137 :3 0 a3
:3 0 1f :4 0 162
1 :8 0 1531 15
:3 0 9a :3 0 152c
152d 0 9b :3 0
152e 152f 0 1531
bcf 1584 9c :3 0
15 :3 0 9a :3 0
1533 1534 0 9b
:3 0 1535 1536 0
1538 bd2 153a bd4
1539 1538 :2 0 1582
9d :3 0 15 :3 0
9a :3 0 153d 153e
0 9b :3 0 153f
1540 0 157a 64
:3 0 65 :3 0 1542
1543 0 64 :3 0
75 :3 0 1545 1546
0 9e :2 0 2
:4 0 163 :2 0 77
:2 0 27 :2 0 bd6
154b 154d :3 0 bd9
1547 154f 1544 1551
1550 :2 0 67 :3 0
78 :3 0 1553 1554
0 69 :4 0 164
:4 0 6c :2 0 6d
:3 0 bdd 1558 155a
:3 0 6c :2 0 81
:4 0 be0 155c 155e
:3 0 6c :2 0 a1
:4 0 be3 1560 1562
:3 0 6c :2 0 9b
:3 0 be6 1564 1566
:3 0 6c :2 0 a2
:4 0 be9 1568 156a
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 bec
156d 1571 bf0 156c
1573 :3 0 bf3 1555
1575 :2 0 1577 bf6
1578 1552 1577 0
1579 bf8 0 157a
bfa 157d :3 0 157d
0 157d 157c 157a
157b :6 0 157f 2c
:3 0 bfd 1581 bff
1580 157f :2 0 1582
c01 :2 0 1584 0
1584 1583 1531 1582
:6 0 1586 1 :3 0
c04 1588 14ad 151b
0 1589 0 1586
0 1589 c07 0
1607 71 :3 0 47
:3 0 30 :2 0 c0a
158a 158d 71 :3 0
a7 :2 0 37 :3 0
30 :2 0 c0d 158f
1593 c12 1590 1595
:3 0 64 :3 0 65
:3 0 1597 1598 0
64 :3 0 75 :3 0
159a 159b 0 18
:2 0 2 :4 0 165
:2 0 77 :2 0 27
:2 0 c15 15a0 15a2
:3 0 c18 159c 15a4
1599 15a6 15a5 :2 0
67 :3 0 78 :3 0
15a8 15a9 0 69
:4 0 166 :4 0 6c
:2 0 6d :3 0 c1c
15ad 15af :3 0 6c
:2 0 81 :4 0 c1f
15b1 15b3 :3 0 6c
:2 0 82 :4 0 c22
15b5 15b7 :3 0 6c
:2 0 71 :3 0 72
:3 0 83 :3 0 158
:3 0 15bc 15bd 0
c25 15bb 15bf 73
:4 0 c27 15ba 15c2
c2a 15b9 15c4 :3 0
6c :2 0 e4 :4 0
c2d 15c6 15c8 :3 0
6c :2 0 6f :4 0
c30 15ca 15cc :3 0
6c :2 0 1d :3 0
c33 15ce 15d0 :3 0
6c :2 0 6f :4 0
c36 15d2 15d4 :3 0
c39 15aa 15d6 :2 0
15d8 c3c 15d9 15a7
15d8 0 15da c3e
0 1604 64 :3 0
65 :3 0 15db 15dc
0 64 :3 0 75
:3 0 15de 15df 0
27 :2 0 2 :4 0
167 :2 0 77 :2 0
27 :2 0 c40 15e4
15e6 :3 0 c43 15e0
15e8 15dd 15ea 15e9
:2 0 67 :3 0 78
:3 0 15ec 15ed 0
69 :4 0 168 :4 0
6c :2 0 6d :3 0
c47 15f1 15f3 :3 0
c4a 15ee 15f5 :2 0
15f7 c4d 15f8 15eb
15f7 0 15f9 c4f
0 1604 87 :3 0
e7 :3 0 15fa 15fb
0 83 :3 0 158
:3 0 15fd 15fe 0
1d :3 0 89 :3 0
c51 15fc 1602 :2 0
1604 c55 1605 1596
1604 0 1606 c59
0 1607 c5b 1608
14a8 1607 0 160a
1429 1498 0 160a
c5e 0 160f 46
:3 0 27 :2 0 160b
160c 0 160f ad
:3 0 c61 1698 71
:3 0 46 :3 0 30
:2 0 c64 1610 1613
8e :2 0 27 :2 0
c69 1615 1617 :3 0
1618 :2 0 169 :3 0
71 :3 0 32 :3 0
30 :2 0 c6c 161b
161e c6f 161a 1620
1621 :2 0 b6 :2 0
30 :2 0 c73 1623
1625 :3 0 1619 1627
1626 :2 0 64 :3 0
65 :3 0 1629 162a
0 64 :3 0 75
:3 0 162c 162d 0
18 :2 0 2 :4 0
16a :2 0 77 :2 0
27 :2 0 c76 1632
1634 :3 0 c79 162e
1636 162b 1638 1637
:2 0 67 :3 0 78
:3 0 163a 163b 0
69 :4 0 16b :4 0
6c :2 0 6d :3 0
c7d 163f 1641 :3 0
6c :2 0 81 :4 0
c80 1643 1645 :3 0
6c :2 0 82 :4 0
c83 1647 1649 :3 0
6c :2 0 71 :3 0
72 :3 0 83 :3 0
158 :3 0 164e 164f
0 c86 164d 1651
73 :4 0 c88 164c
1654 c8b 164b 1656
:3 0 6c :2 0 e4
:4 0 c8e 1658 165a
:3 0 6c :2 0 6f
:4 0 c91 165c 165e
:3 0 6c :2 0 1d
:3 0 c94 1660 1662
:3 0 6c :2 0 6f
:4 0 c97 1664 1666
:3 0 c9a 163c 1668
:2 0 166a c9d 166b
1639 166a 0 166c
c9f 0 1696 64
:3 0 65 :3 0 166d
166e 0 64 :3 0
75 :3 0 1670 1671
0 27 :2 0 2
:4 0 16c :2 0 77
:2 0 27 :2 0 ca1
1676 1678 :3 0 ca4
1672 167a 166f 167c
167b :2 0 67 :3 0
78 :3 0 167e 167f
0 69 :4 0 16d
:4 0 6c :2 0 6d
:3 0 ca8 1683 1685
:3 0 cab 1680 1687
:2 0 1689 cae 168a
167d 1689 0 168b
cb0 0 1696 87
:3 0 e7 :3 0 168c
168d 0 83 :3 0
158 :3 0 168f 1690
0 1d :3 0 89
:3 0 cb2 168e 1694
:2 0 1696 cb6 1697
1628 1696 0 1699
1420 160f 0 1699
cba 0 1db0 a3
:3 0 26 :3 0 27
:2 0 27 :2 0 cbd
169a 169e 8e :2 0
30 :4 0 cc3 16a0
16a2 :3 0 2b :3 0
a3 :3 0 2b :3 0
6c :2 0 1d :3 0
cc6 16a7 16a9 :3 0
27 :2 0 2a :2 0
cc9 16a5 16ad 16a4
16ae 0 1899 16e
:3 0 96 :3 0 16f
:3 0 21 :3 0 170
:3 0 71 :3 0 96
:3 0 16f :3 0 171
:3 0 71 :3 0 96
:3 0 16f :3 0 172
:3 0 2d :3 0 48
:3 0 4c :3 0 49
:3 0 4a :3 0 173
:3 0 130 :3 0 1d
:4 0 174 1 :8 0
16cb 15 :3 0 9a
:3 0 16c6 16c7 0
9b :3 0 16c8 16c9
0 16cb ccd 171e
9c :3 0 15 :3 0
9a :3 0 16cd 16ce
0 9b :3 0 16cf
16d0 0 16d2 cd0
16d4 cd2 16d3 16d2
:2 0 171c 9d :3 0
15 :3 0 9a :3 0
16d7 16d8 0 9b
:3 0 16d9 16da 0
1714 64 :3 0 65
:3 0 16dc 16dd 0
64 :3 0 75 :3 0
16df 16e0 0 9e
:2 0 2 :4 0 175
:2 0 77 :2 0 27
:2 0 cd4 16e5 16e7
:3 0 cd7 16e1 16e9
16de 16eb 16ea :2 0
67 :3 0 78 :3 0
16ed 16ee 0 69
:4 0 176 :4 0 6c
:2 0 6d :3 0 cdb
16f2 16f4 :3 0 6c
:2 0 81 :4 0 cde
16f6 16f8 :3 0 6c
:2 0 a1 :4 0 ce1
16fa 16fc :3 0 6c
:2 0 9b :3 0 ce4
16fe 1700 :3 0 6c
:2 0 a2 :4 0 ce7
1702 1704 :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 cea 1707 170b
cee 1706 170d :3 0
cf1 16ef 170f :2 0
1711 cf4 1712 16ec
1711 0 1713 cf6
0 1714 cf8 1717
:3 0 1717 0 1717
1716 1714 1715 :6 0
1719 2e :3 0 cfb
171b cfd 171a 1719
:2 0 171c cff :2 0
171e 0 171e 171d
16cb 171c :6 0 1899
1 :3 0 15 :3 0
9a :3 0 1720 1721
0 15 :3 0 8e
:2 0 d8 :3 0 1723
1725 0 d04 1724
1727 :3 0 1728 :2 0
64 :3 0 65 :3 0
172a 172b 0 64
:3 0 75 :3 0 172d
172e 0 18 :2 0
2 :4 0 177 :2 0
77 :2 0 27 :2 0
d07 1733 1735 :3 0
d0a 172f 1737 172c
1739 1738 :2 0 67
:3 0 78 :3 0 173b
173c 0 69 :4 0
178 :4 0 6c :2 0
6d :3 0 d0e 1740
1742 :3 0 6c :2 0
81 :4 0 d11 1744
1746 :3 0 6c :2 0
82 :4 0 d14 1748
174a :3 0 6c :2 0
71 :3 0 72 :3 0
83 :3 0 e3 :3 0
174f 1750 0 d17
174e 1752 73 :4 0
d19 174d 1755 d1c
174c 1757 :3 0 6c
:2 0 e4 :4 0 d1f
1759 175b :3 0 6c
:2 0 6f :4 0 d22
175d 175f :3 0 6c
:2 0 1d :3 0 d25
1761 1763 :3 0 6c
:2 0 6f :4 0 d28
1765 1767 :3 0 d2b
173d 1769 :2 0 176b
d2e 176c 173a 176b
0 176d d30 0
1797 64 :3 0 65
:3 0 176e 176f 0
64 :3 0 75 :3 0
1771 1772 0 27
:2 0 2 :4 0 179
:2 0 77 :2 0 27
:2 0 d32 1777 1779
:3 0 d35 1773 177b
1770 177d 177c :2 0
67 :3 0 78 :3 0
177f 1780 0 69
:4 0 17a :4 0 6c
:2 0 6d :3 0 d39
1784 1786 :3 0 d3c
1781 1788 :2 0 178a
d3f 178b 177e 178a
0 178c d41 0
1797 87 :3 0 e7
:3 0 178d 178e 0
83 :3 0 e3 :3 0
1790 1791 0 1d
:3 0 89 :3 0 d43
178f 1795 :2 0 1797
d47 1798 1729 1797
0 1799 d4b 0
1899 a3 :3 0 4c
:3 0 27 :2 0 27
:2 0 d4d 179a 179e
8e :2 0 30 :4 0
d53 17a0 17a2 :3 0
17a3 :2 0 71 :3 0
4a :3 0 30 :2 0
d56 17a5 17a8 b1
:2 0 30 :2 0 d5b
17aa 17ac :3 0 17ad
:2 0 71 :3 0 48
:3 0 30 :2 0 d5e
17af 17b2 71 :3 0
b1 :2 0 4a :3 0
30 :2 0 d61 17b4
17b8 d66 17b5 17ba
:3 0 17bb :2 0 17ae
17bd 17bc :2 0 17be
:2 0 17a4 17c0 17bf
:2 0 64 :3 0 65
:3 0 17c2 17c3 0
64 :3 0 75 :3 0
17c5 17c6 0 18
:2 0 2 :4 0 17b
:2 0 77 :2 0 27
:2 0 d69 17cb 17cd
:3 0 d6c 17c7 17cf
17c4 17d1 17d0 :2 0
67 :3 0 78 :3 0
17d3 17d4 0 69
:4 0 17c :4 0 6c
:2 0 6d :3 0 d70
17d8 17da :3 0 6c
:2 0 81 :4 0 d73
17dc 17de :3 0 6c
:2 0 82 :4 0 d76
17e0 17e2 :3 0 6c
:2 0 71 :3 0 72
:3 0 83 :3 0 17d
:3 0 17e7 17e8 0
d79 17e6 17ea 73
:4 0 d7b 17e5 17ed
d7e 17e4 17ef :3 0
6c :2 0 e4 :4 0
d81 17f1 17f3 :3 0
6c :2 0 6f :4 0
d84 17f5 17f7 :3 0
6c :2 0 1d :3 0
d87 17f9 17fb :3 0
6c :2 0 6f :4 0
d8a 17fd 17ff :3 0
d8d 17d5 1801 :2 0
1803 d90 1804 17d2
1803 0 1805 d92
0 182f 64 :3 0
65 :3 0 1806 1807
0 64 :3 0 75
:3 0 1809 180a 0
27 :2 0 2 :4 0
17e :2 0 77 :2 0
27 :2 0 d94 180f
1811 :3 0 d97 180b
1813 1808 1815 1814
:2 0 67 :3 0 78
:3 0 1817 1818 0
69 :4 0 17f :4 0
6c :2 0 6d :3 0
d9b 181c 181e :3 0
d9e 1819 1820 :2 0
1822 da1 1823 1816
1822 0 1824 da3
0 182f 87 :3 0
e7 :3 0 1825 1826
0 83 :3 0 17d
:3 0 1828 1829 0
1d :3 0 89 :3 0
da5 1827 182d :2 0
182f da9 1830 17c1
182f 0 1831 dad
0 1899 180 :3 0
181 :3 0 182 :3 0
28 :3 0 42 :3 0
1e :3 0 183 :3 0
bc :3 0 1a :3 0
131 :3 0 130 :3 0
1d :4 0 184 1
:8 0 1844 15 :3 0
9a :3 0 183f 1840
0 9b :3 0 1841
1842 0 1844 daf
1897 9c :3 0 15
:3 0 9a :3 0 1846
1847 0 9b :3 0
1848 1849 0 184b
db2 184d db4 184c
184b :2 0 1895 9d
:3 0 15 :3 0 9a
:3 0 1850 1851 0
9b :3 0 1852 1853
0 188d 64 :3 0
65 :3 0 1855 1856
0 64 :3 0 75
:3 0 1858 1859 0
9e :2 0 2 :4 0
185 :2 0 77 :2 0
27 :2 0 db6 185e
1860 :3 0 db9 185a
1862 1857 1864 1863
:2 0 67 :3 0 78
:3 0 1866 1867 0
69 :4 0 186 :4 0
6c :2 0 6d :3 0
dbd 186b 186d :3 0
6c :2 0 81 :4 0
dc0 186f 1871 :3 0
6c :2 0 a1 :4 0
dc3 1873 1875 :3 0
6c :2 0 9b :3 0
dc6 1877 1879 :3 0
6c :2 0 a2 :4 0
dc9 187b 187d :3 0
6c :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 dcc 1880
1884 dd0 187f 1886
:3 0 dd3 1868 1888
:2 0 188a dd6 188b
1865 188a 0 188c
dd8 0 188d dda
1890 :3 0 1890 0
1890 188f 188d 188e
:6 0 1892 30 :3 0
ddd 1894 ddf 1893
1892 :2 0 1895 de1
:2 0 1897 0 1897
1896 1844 1895 :6 0
1899 1 :3 0 de4
1add 2c :3 0 a3
:3 0 2c :3 0 6c
:2 0 1d :3 0 dea
189d 189f :3 0 27
:2 0 2a :2 0 ded
189b 18a3 189a 18a4
0 1adc 187 :3 0
2d :3 0 188 :3 0
189 :3 0 1d :4 0
18a 1 :8 0 18b1
15 :3 0 9a :3 0
18ac 18ad 0 9b
:3 0 18ae 18af 0
18b1 df1 1904 9c
:3 0 15 :3 0 9a
:3 0 18b3 18b4 0
9b :3 0 18b5 18b6
0 18b8 df4 18ba
df6 18b9 18b8 :2 0
1902 9d :3 0 15
:3 0 9a :3 0 18bd
18be 0 9b :3 0
18bf 18c0 0 18fa
64 :3 0 65 :3 0
18c2 18c3 0 64
:3 0 75 :3 0 18c5
18c6 0 9e :2 0
2 :4 0 18b :2 0
77 :2 0 27 :2 0
df8 18cb 18cd :3 0
dfb 18c7 18cf 18c4
18d1 18d0 :2 0 67
:3 0 78 :3 0 18d3
18d4 0 69 :4 0
18c :4 0 6c :2 0
6d :3 0 dff 18d8
18da :3 0 6c :2 0
81 :4 0 e02 18dc
18de :3 0 6c :2 0
a1 :4 0 e05 18e0
18e2 :3 0 6c :2 0
9b :3 0 e08 18e4
18e6 :3 0 6c :2 0
a2 :4 0 e0b 18e8
18ea :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
e0e 18ed 18f1 e12
18ec 18f3 :3 0 e15
18d5 18f5 :2 0 18f7
e18 18f8 18d2 18f7
0 18f9 e1a 0
18fa e1c 18fd :3 0
18fd 0 18fd 18fc
18fa 18fb :6 0 18ff
32 :3 0 e1f 1901
e21 1900 18ff :2 0
1902 e23 :2 0 1904
0 1904 1903 18b1
1902 :6 0 1adc 1
:3 0 15 :3 0 9a
:3 0 1906 1907 0
15 :3 0 8e :2 0
d8 :3 0 1909 190b
0 e28 190a 190d
:3 0 190e :2 0 64
:3 0 65 :3 0 1910
1911 0 64 :3 0
75 :3 0 1913 1914
0 18 :2 0 2
:4 0 18d :2 0 77
:2 0 27 :2 0 e2b
1919 191b :3 0 e2e
1915 191d 1912 191f
191e :2 0 67 :3 0
78 :3 0 1921 1922
0 69 :4 0 18e
:4 0 6c :2 0 6d
:3 0 e32 1926 1928
:3 0 6c :2 0 81
:4 0 e35 192a 192c
:3 0 6c :2 0 82
:4 0 e38 192e 1930
:3 0 6c :2 0 71
:3 0 72 :3 0 83
:3 0 e3 :3 0 1935
1936 0 e3b 1934
1938 73 :4 0 e3d
1933 193b e40 1932
193d :3 0 6c :2 0
e4 :4 0 e43 193f
1941 :3 0 6c :2 0
6f :4 0 e46 1943
1945 :3 0 6c :2 0
1d :3 0 e49 1947
1949 :3 0 6c :2 0
6f :4 0 e4c 194b
194d :3 0 e4f 1923
194f :2 0 1951 e52
1952 1920 1951 0
1953 e54 0 197d
64 :3 0 65 :3 0
1954 1955 0 64
:3 0 75 :3 0 1957
1958 0 27 :2 0
2 :4 0 18f :2 0
77 :2 0 27 :2 0
e56 195d 195f :3 0
e59 1959 1961 1956
1963 1962 :2 0 67
:3 0 78 :3 0 1965
1966 0 69 :4 0
190 :4 0 6c :2 0
6d :3 0 e5d 196a
196c :3 0 e60 1967
196e :2 0 1970 e63
1971 1964 1970 0
1972 e65 0 197d
87 :3 0 e7 :3 0
1973 1974 0 83
:3 0 e3 :3 0 1976
1977 0 1d :3 0
89 :3 0 e67 1975
197b :2 0 197d e6b
197e 190f 197d 0
197f e6f 0 1adc
12f :3 0 137 :3 0
a3 :3 0 1f :3 0
137 :3 0 a3 :3 0
12f :3 0 137 :3 0
a3 :3 0 191 :3 0
192 :3 0 37 :3 0
21 :3 0 44 :3 0
106 :3 0 107 :3 0
17 :3 0 130 :3 0
1d :3 0 131 :4 0
193 1 :8 0 199a
15 :3 0 9a :3 0
1995 1996 0 9b
:3 0 1997 1998 0
199a e71 19ed 9c
:3 0 15 :3 0 9a
:3 0 199c 199d 0
9b :3 0 199e 199f
0 19a1 e74 19a3
e76 19a2 19a1 :2 0
19eb 9d :3 0 15
:3 0 9a :3 0 19a6
19a7 0 9b :3 0
19a8 19a9 0 19e3
64 :3 0 65 :3 0
19ab 19ac 0 64
:3 0 75 :3 0 19ae
19af 0 9e :2 0
2 :4 0 194 :2 0
77 :2 0 27 :2 0
e78 19b4 19b6 :3 0
e7b 19b0 19b8 19ad
19ba 19b9 :2 0 67
:3 0 78 :3 0 19bc
19bd 0 69 :4 0
195 :4 0 6c :2 0
6d :3 0 e7f 19c1
19c3 :3 0 6c :2 0
81 :4 0 e82 19c5
19c7 :3 0 6c :2 0
a1 :4 0 e85 19c9
19cb :3 0 6c :2 0
9b :3 0 e88 19cd
19cf :3 0 6c :2 0
a2 :4 0 e8b 19d1
19d3 :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
e8e 19d6 19da e92
19d5 19dc :3 0 e95
19be 19de :2 0 19e0
e98 19e1 19bb 19e0
0 19e2 e9a 0
19e3 e9c 19e6 :3 0
19e6 0 19e6 19e5
19e3 19e4 :6 0 19e8
34 :3 0 e9f 19ea
ea1 19e9 19e8 :2 0
19eb ea3 :2 0 19ed
0 19ed 19ec 199a
19eb :6 0 1adc 1
:3 0 15 :3 0 9a
:3 0 19ef 19f0 0
15 :3 0 8e :2 0
a6 :3 0 19f2 19f4
0 ea8 19f3 19f6
:3 0 19f7 :2 0 71
:3 0 44 :3 0 30
:2 0 eab 19f9 19fc
8e :2 0 27 :2 0
eb0 19fe 1a00 :3 0
1a01 :2 0 19f8 1a03
1a02 :2 0 64 :3 0
65 :3 0 1a05 1a06
0 64 :3 0 75
:3 0 1a08 1a09 0
18 :2 0 2 :4 0
196 :2 0 77 :2 0
27 :2 0 eb3 1a0e
1a10 :3 0 eb6 1a0a
1a12 1a07 1a14 1a13
:2 0 67 :3 0 78
:3 0 1a16 1a17 0
69 :4 0 197 :4 0
6c :2 0 6d :3 0
eba 1a1b 1a1d :3 0
6c :2 0 81 :4 0
ebd 1a1f 1a21 :3 0
6c :2 0 82 :4 0
ec0 1a23 1a25 :3 0
6c :2 0 71 :3 0
72 :3 0 83 :3 0
158 :3 0 1a2a 1a2b
0 ec3 1a29 1a2d
73 :4 0 ec5 1a28
1a30 ec8 1a27 1a32
:3 0 6c :2 0 e4
:4 0 ecb 1a34 1a36
:3 0 6c :2 0 6f
:4 0 ece 1a38 1a3a
:3 0 6c :2 0 1d
:3 0 ed1 1a3c 1a3e
:3 0 6c :2 0 6f
:4 0 ed4 1a40 1a42
:3 0 ed7 1a18 1a44
:2 0 1a46 eda 1a47
1a15 1a46 0 1a48
edc 0 1a72 64
:3 0 65 :3 0 1a49
1a4a 0 64 :3 0
75 :3 0 1a4c 1a4d
0 27 :2 0 2
:4 0 198 :2 0 77
:2 0 27 :2 0 ede
1a52 1a54 :3 0 ee1
1a4e 1a56 1a4b 1a58
1a57 :2 0 67 :3 0
78 :3 0 1a5a 1a5b
0 69 :4 0 199
:4 0 6c :2 0 6d
:3 0 ee5 1a5f 1a61
:3 0 ee8 1a5c 1a63
:2 0 1a65 eeb 1a66
1a59 1a65 0 1a67
eed 0 1a72 87
:3 0 e7 :3 0 1a68
1a69 0 83 :3 0
158 :3 0 1a6b 1a6c
0 1d :3 0 89
:3 0 eef 1a6a 1a70
:2 0 1a72 ef3 1a73
1a04 1a72 0 1a74
ef7 0 1adc 180
:3 0 181 :3 0 182
:3 0 28 :3 0 42
:3 0 1e :3 0 183
:3 0 bc :3 0 1a
:3 0 131 :3 0 130
:3 0 1d :4 0 19a
1 :8 0 1a87 15
:3 0 9a :3 0 1a82
1a83 0 9b :3 0
1a84 1a85 0 1a87
ef9 1ada 9c :3 0
15 :3 0 9a :3 0
1a89 1a8a 0 9b
:3 0 1a8b 1a8c 0
1a8e efc 1a90 efe
1a8f 1a8e :2 0 1ad8
9d :3 0 15 :3 0
9a :3 0 1a93 1a94
0 9b :3 0 1a95
1a96 0 1ad0 64
:3 0 65 :3 0 1a98
1a99 0 64 :3 0
75 :3 0 1a9b 1a9c
0 9e :2 0 2
:4 0 19b :2 0 77
:2 0 27 :2 0 f00
1aa1 1aa3 :3 0 f03
1a9d 1aa5 1a9a 1aa7
1aa6 :2 0 67 :3 0
78 :3 0 1aa9 1aaa
0 69 :4 0 19c
:4 0 6c :2 0 6d
:3 0 f07 1aae 1ab0
:3 0 6c :2 0 81
:4 0 f0a 1ab2 1ab4
:3 0 6c :2 0 a1
:4 0 f0d 1ab6 1ab8
:3 0 6c :2 0 9b
:3 0 f10 1aba 1abc
:3 0 6c :2 0 a2
:4 0 f13 1abe 1ac0
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 f16
1ac3 1ac7 f1a 1ac2
1ac9 :3 0 f1d 1aab
1acb :2 0 1acd f20
1ace 1aa8 1acd 0
1acf f22 0 1ad0
f24 1ad3 :3 0 1ad3
0 1ad3 1ad2 1ad0
1ad1 :6 0 1ad5 36
:3 0 f27 1ad7 f29
1ad6 1ad5 :2 0 1ad8
f2b :2 0 1ada 0
1ada 1ad9 1a87 1ad8
:6 0 1adc 1 :3 0
f2e 1ade 16a3 1899
0 1adf 0 1adc
0 1adf f35 0
1db0 21 :3 0 21
:3 0 1ae0 1ae1 0
1db0 71 :3 0 46
:3 0 30 :2 0 f38
1ae3 1ae6 8e :2 0
27 :2 0 f3d 1ae8
1aea :3 0 96 :3 0
19d :3 0 137 :3 0
a3 :3 0 21 :3 0
96 :3 0 19e :3 0
1f :3 0 21 :3 0
98 :4 0 19f 1
:8 0 1afc 15 :3 0
9a :3 0 1af7 1af8
0 9b :3 0 1af9
1afa 0 1afc f40
1b4f 9c :3 0 15
:3 0 9a :3 0 1afe
1aff 0 9b :3 0
1b00 1b01 0 1b03
f43 1b05 f45 1b04
1b03 :2 0 1b4d 9d
:3 0 15 :3 0 9a
:3 0 1b08 1b09 0
9b :3 0 1b0a 1b0b
0 1b45 64 :3 0
65 :3 0 1b0d 1b0e
0 64 :3 0 75
:3 0 1b10 1b11 0
9e :2 0 2 :4 0
1a0 :2 0 77 :2 0
27 :2 0 f47 1b16
1b18 :3 0 f4a 1b12
1b1a 1b0f 1b1c 1b1b
:2 0 67 :3 0 78
:3 0 1b1e 1b1f 0
69 :4 0 1a1 :4 0
6c :2 0 6d :3 0
f4e 1b23 1b25 :3 0
6c :2 0 81 :4 0
f51 1b27 1b29 :3 0
6c :2 0 a1 :4 0
f54 1b2b 1b2d :3 0
6c :2 0 9b :3 0
f57 1b2f 1b31 :3 0
6c :2 0 a2 :4 0
f5a 1b33 1b35 :3 0
6c :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 f5d 1b38
1b3c f61 1b37 1b3e
:3 0 f64 1b20 1b40
:2 0 1b42 f67 1b43
1b1d 1b42 0 1b44
f69 0 1b45 f6b
1b48 :3 0 1b48 0
1b48 1b47 1b45 1b46
:6 0 1b4a 38 :3 0
f6e 1b4c f70 1b4b
1b4a :2 0 1b4d f72
:2 0 1b4f 0 1b4f
1b4e 1afc 1b4d :6 0
1ce6 1 :3 0 137
:3 0 a3 :3 0 1f
:3 0 137 :3 0 a3
:3 0 21 :3 0 1f
:3 0 21 :3 0 21
:3 0 98 :4 0 1a2
1 :8 0 1b61 15
:3 0 9a :3 0 1b5c
1b5d 0 9b :3 0
1b5e 1b5f 0 1b61
f75 1bb4 9c :3 0
15 :3 0 9a :3 0
1b63 1b64 0 9b
:3 0 1b65 1b66 0
1b68 f78 1b6a f7a
1b69 1b68 :2 0 1bb2
9d :3 0 15 :3 0
9a :3 0 1b6d 1b6e
0 9b :3 0 1b6f
1b70 0 1baa 64
:3 0 65 :3 0 1b72
1b73 0 64 :3 0
75 :3 0 1b75 1b76
0 9e :2 0 2
:4 0 1a3 :2 0 77
:2 0 27 :2 0 f7c
1b7b 1b7d :3 0 f7f
1b77 1b7f 1b74 1b81
1b80 :2 0 67 :3 0
78 :3 0 1b83 1b84
0 69 :4 0 1a4
:4 0 6c :2 0 6d
:3 0 f83 1b88 1b8a
:3 0 6c :2 0 81
:4 0 f86 1b8c 1b8e
:3 0 6c :2 0 a1
:4 0 f89 1b90 1b92
:3 0 6c :2 0 9b
:3 0 f8c 1b94 1b96
:3 0 6c :2 0 a2
:4 0 f8f 1b98 1b9a
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 f92
1b9d 1ba1 f96 1b9c
1ba3 :3 0 f99 1b85
1ba5 :2 0 1ba7 f9c
1ba8 1b82 1ba7 0
1ba9 f9e 0 1baa
fa0 1bad :3 0 1bad
0 1bad 1bac 1baa
1bab :6 0 1baf 3a
:3 0 fa3 1bb1 fa5
1bb0 1baf :2 0 1bb2
fa7 :2 0 1bb4 0
1bb4 1bb3 1b61 1bb2
:6 0 1ce6 1 :3 0
45 :3 0 1a5 :2 0
1bb6 1bb7 0 1ce6
22 :3 0 6 :3 0
1bb9 1bba 0 1ce6
71 :3 0 33 :3 0
30 :2 0 faa 1bbc
1bbf 8e :2 0 30
:2 0 faf 1bc1 1bc3
:3 0 3f :3 0 11a
:2 0 1bc5 1bc6 0
1bc8 fb2 1bc9 1bc4
1bc8 0 1bca fb4
0 1ce6 60 :3 0
1a6 :3 0 28 :3 0
17 :3 0 1a :3 0
1d :3 0 4e :3 0
32 :3 0 23 :3 0
23 :3 0 23 :3 0
23 :3 0 21 :3 0
22 :3 0 41 :3 0
37 :3 0 35 :3 0
38 :3 0 39 :3 0
34 :3 0 45 :3 0
26 :3 0 33 :3 0
31 :3 0 3b :3 0
36 :3 0 3f :3 0
3d :3 0 43 :3 0
1c :3 0 30 :2 0
30 :2 0 7c :2 0
7c :2 0 30 :2 0
30 :2 0 fb6 1bcc
1bef 1bcb 1bf0 0
1ce6 60 :3 0 8e
:2 0 30 :2 0 fdb
1bf3 1bf5 :3 0 71
:3 0 33 :3 0 30
:2 0 fde 1bf7 1bfa
8e :2 0 30 :2 0
fe3 1bfc 1bfe :3 0
1a7 :3 0 1a8 :3 0
1a9 :3 0 1d :4 0
1aa 1 :8 0 1c1a
1ab :4 0 1c05 :3 0
89 :3 0 8e :2 0
fe8 1c08 1c09 :3 0
15 :3 0 9a :3 0
1c0b 1c0c 0 30
:2 0 1c0d 1c0e 0
1c10 feb 1c17 15
:3 0 9a :3 0 1c11
1c12 0 118 :2 0
1c13 1c14 0 1c16
fed 1c18 1c0a 1c10
0 1c19 0 1c16
0 1c19 fef 0
1c1a ff2 1c6d 9c
:3 0 15 :3 0 9a
:3 0 1c1c 1c1d 0
9b :3 0 1c1e 1c1f
0 1c21 ff5 1c23
ff7 1c22 1c21 :2 0
1c6b 9d :3 0 15
:3 0 9a :3 0 1c26
1c27 0 9b :3 0
1c28 1c29 0 1c63
64 :3 0 65 :3 0
1c2b 1c2c 0 64
:3 0 75 :3 0 1c2e
1c2f 0 9e :2 0
2 :4 0 1ac :2 0
77 :2 0 27 :2 0
ff9 1c34 1c36 :3 0
ffc 1c30 1c38 1c2d
1c3a 1c39 :2 0 67
:3 0 78 :3 0 1c3c
1c3d 0 69 :4 0
1ad :4 0 6c :2 0
6d :3 0 1000 1c41
1c43 :3 0 6c :2 0
81 :4 0 1003 1c45
1c47 :3 0 6c :2 0
a1 :4 0 1006 1c49
1c4b :3 0 6c :2 0
9b :3 0 1009 1c4d
1c4f :3 0 6c :2 0
a2 :4 0 100c 1c51
1c53 :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
100f 1c56 1c5a 1013
1c55 1c5c :3 0 1016
1c3e 1c5e :2 0 1c60
1019 1c61 1c3b 1c60
0 1c62 101b 0
1c63 101d 1c66 :3 0
1c66 0 1c66 1c65
1c63 1c64 :6 0 1c68
3c :3 0 1020 1c6a
1022 1c69 1c68 :2 0
1c6b 1024 :2 0 1c6d
0 1c6d 1c6c 1c1a
1c6b :6 0 1c6f 1
:3 0 1027 1ce0 1a7
:3 0 1a8 :3 0 1a9
:3 0 1d :4 0 1ae
1 :8 0 1c8a 1ab
:4 0 1c75 :3 0 89
:3 0 8e :2 0 102b
1c78 1c79 :3 0 15
:3 0 9a :3 0 1c7b
1c7c 0 30 :2 0
1c7d 1c7e 0 1c80
102e 1c87 15 :3 0
9a :3 0 1c81 1c82
0 118 :2 0 1c83
1c84 0 1c86 1030
1c88 1c7a 1c80 0
1c89 0 1c86 0
1c89 1032 0 1c8a
1035 1cdd 9c :3 0
15 :3 0 9a :3 0
1c8c 1c8d 0 9b
:3 0 1c8e 1c8f 0
1c91 1038 1c93 103a
1c92 1c91 :2 0 1cdb
9d :3 0 15 :3 0
9a :3 0 1c96 1c97
0 9b :3 0 1c98
1c99 0 1cd3 64
:3 0 65 :3 0 1c9b
1c9c 0 64 :3 0
75 :3 0 1c9e 1c9f
0 9e :2 0 2
:4 0 1af :2 0 77
:2 0 27 :2 0 103c
1ca4 1ca6 :3 0 103f
1ca0 1ca8 1c9d 1caa
1ca9 :2 0 67 :3 0
78 :3 0 1cac 1cad
0 69 :4 0 1b0
:4 0 6c :2 0 6d
:3 0 1043 1cb1 1cb3
:3 0 6c :2 0 81
:4 0 1046 1cb5 1cb7
:3 0 6c :2 0 a1
:4 0 1049 1cb9 1cbb
:3 0 6c :2 0 9b
:3 0 104c 1cbd 1cbf
:3 0 6c :2 0 a2
:4 0 104f 1cc1 1cc3
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 1052
1cc6 1cca 1056 1cc5
1ccc :3 0 1059 1cae
1cce :2 0 1cd0 105c
1cd1 1cab 1cd0 0
1cd2 105e 0 1cd3
1060 1cd6 :3 0 1cd6
0 1cd6 1cd5 1cd3
1cd4 :6 0 1cd8 3e
:3 0 1063 1cda 1065
1cd9 1cd8 :2 0 1cdb
1067 :2 0 1cdd 0
1cdd 1cdc 1c8a 1cdb
:6 0 1cdf 1 :3 0
106a 1ce1 1bff 1c6f
0 1ce2 0 1cdf
0 1ce2 106c 0
1ce3 106f 1ce4 1bf6
1ce3 0 1ce5 1071
0 1ce6 1073 1dad
21 :3 0 1f :3 0
1ce7 1ce8 0 1dac
22 :3 0 6 :3 0
1cea 1ceb 0 1dac
a3 :3 0 26 :3 0
27 :2 0 27 :2 0
107b 1ced 1cf1 8e
:2 0 27 :4 0 1081
1cf3 1cf5 :3 0 45
:3 0 83 :3 0 10b
:3 0 1cf8 1cf9 0
1cf7 1cfa 0 1cfc
1084 1d0b 45 :3 0
11f :3 0 71 :3 0
3a :3 0 30 :2 0
1086 1cff 1d02 83
:3 0 122 :3 0 1d04
1d05 0 1089 1cfe
1d07 1cfd 1d08 0
1d0a 108c 1d0c 1cf6
1cfc 0 1d0d 0
1d0a 0 1d0d 108e
0 1dac 60 :3 0
1a6 :3 0 28 :3 0
17 :3 0 1a :3 0
1d :3 0 4e :3 0
32 :3 0 23 :3 0
23 :3 0 23 :3 0
23 :3 0 21 :3 0
22 :3 0 41 :3 0
37 :3 0 35 :3 0
38 :3 0 39 :3 0
34 :3 0 45 :3 0
26 :3 0 33 :3 0
31 :3 0 3b :3 0
36 :3 0 3f :3 0
3d :3 0 43 :3 0
1c :3 0 30 :2 0
30 :2 0 7c :2 0
7c :2 0 30 :2 0
30 :2 0 1091 1d0f
1d32 1d0e 1d33 0
1dac 60 :3 0 8e
:2 0 30 :2 0 10b6
1d36 1d38 :3 0 1a7
:3 0 1a8 :3 0 1a9
:3 0 1d :4 0 1aa
1 :8 0 1d54 1ab
:4 0 1d3f :3 0 89
:3 0 8e :2 0 10bb
1d42 1d43 :3 0 15
:3 0 9a :3 0 1d45
1d46 0 30 :2 0
1d47 1d48 0 1d4a
10be 1d51 15 :3 0
9a :3 0 1d4b 1d4c
0 118 :2 0 1d4d
1d4e 0 1d50 10c0
1d52 1d44 1d4a 0
1d53 0 1d50 0
1d53 10c2 0 1d54
10c5 1da7 9c :3 0
15 :3 0 9a :3 0
1d56 1d57 0 9b
:3 0 1d58 1d59 0
1d5b 10c8 1d5d 10ca
1d5c 1d5b :2 0 1da5
9d :3 0 15 :3 0
9a :3 0 1d60 1d61
0 9b :3 0 1d62
1d63 0 1d9d 64
:3 0 65 :3 0 1d65
1d66 0 64 :3 0
75 :3 0 1d68 1d69
0 9e :2 0 2
:4 0 1b1 :2 0 77
:2 0 27 :2 0 10cc
1d6e 1d70 :3 0 10cf
1d6a 1d72 1d67 1d74
1d73 :2 0 67 :3 0
78 :3 0 1d76 1d77
0 69 :4 0 1b2
:4 0 6c :2 0 6d
:3 0 10d3 1d7b 1d7d
:3 0 6c :2 0 81
:4 0 10d6 1d7f 1d81
:3 0 6c :2 0 a1
:4 0 10d9 1d83 1d85
:3 0 6c :2 0 9b
:3 0 10dc 1d87 1d89
:3 0 6c :2 0 a2
:4 0 10df 1d8b 1d8d
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 10e2
1d90 1d94 10e6 1d8f
1d96 :3 0 10e9 1d78
1d98 :2 0 1d9a 10ec
1d9b 1d75 1d9a 0
1d9c 10ee 0 1d9d
10f0 1da0 :3 0 1da0
0 1da0 1d9f 1d9d
1d9e :6 0 1da2 40
:3 0 10f3 1da4 10f5
1da3 1da2 :2 0 1da5
10f7 :2 0 1da7 0
1da7 1da6 1d54 1da5
:6 0 1da9 1 :3 0
10fa 1daa 1d39 1da9
0 1dab 10fc 0
1dac 10fe 1dae 1aeb
1ce6 0 1daf 0
1dac 0 1daf 1104
0 1db0 1107 27a6
71 :3 0 1b3 :3 0
29 :3 0 1115 1db2
1db4 30 :2 0 1117
1db1 1db7 a7 :2 0
18 :2 0 111c 1db9
1dbb :3 0 62 :3 0
30 :2 0 1dbd 1dbe
0 1dc0 111f 1dd8
62 :3 0 1b4 :3 0
71 :3 0 1b3 :3 0
29 :3 0 1121 1dc4
1dc6 30 :2 0 1123
1dc3 1dc9 77 :2 0
27 :2 0 1126 1dcb
1dcd :3 0 1dce :2 0
1b5 :2 0 b4 :2 0
1129 1dd0 1dd2 :3 0
112c 1dc2 1dd4 1dc1
1dd5 0 1dd7 112e
1dd9 1dbc 1dc0 0
1dda 0 1dd7 0
1dda 1130 0 27a5
62 :3 0 b1 :2 0
30 :2 0 1135 1ddc
1dde :3 0 2f :3 0
30 :2 0 1de0 1de1
0 27a2 1b6 :3 0
71 :3 0 2f :3 0
30 :2 0 1138 1de4
1de7 62 :3 0 a7
:2 0 1b7 :3 0 113d
1dea 1dec :3 0 1ded
27a1 46 :3 0 30
:2 0 1def 1df0 0
279f 1d :3 0 b2
:3 0 b3 :3 0 1df3
1df4 0 18 :2 0
18 :2 0 71 :3 0
2f :3 0 30 :2 0
1140 1df8 1dfb 117
:2 0 b4 :2 0 1143
1dfd 1dff :3 0 77
:2 0 27 :2 0 1146
1e01 1e03 :3 0 29
:3 0 1149 1df5 1e06
1df2 1e07 0 279f
26 :3 0 b2 :3 0
b3 :3 0 1e0a 1e0b
0 27 :2 0 27
:2 0 71 :3 0 2f
:3 0 30 :2 0 114e
1e0f 1e12 117 :2 0
b4 :2 0 1151 1e14
1e16 :3 0 77 :2 0
18 :2 0 1154 1e18
1e1a :3 0 77 :2 0
27 :2 0 1157 1e1c
1e1e :3 0 29 :3 0
115a 1e0c 1e21 1e09
1e22 0 279f 1f
:3 0 5 :3 0 1e24
1e25 0 279f 46
:3 0 30 :2 0 1e27
1e28 0 279f 44
:3 0 30 :2 0 1e2a
1e2b 0 279f 21
:3 0 1f :3 0 1e2d
1e2e 0 279f 104
:3 0 12e :3 0 1b8
:3 0 44 :3 0 21
:3 0 106 :3 0 b7
:3 0 17 :3 0 107
:3 0 17 :3 0 130
:3 0 1d :3 0 131
:3 0 26 :4 0 1b9
1 :8 0 1e44 15
:3 0 9a :3 0 1e3f
1e40 0 9b :3 0
1e41 1e42 0 1e44
115f 1e97 9c :3 0
15 :3 0 9a :3 0
1e46 1e47 0 9b
:3 0 1e48 1e49 0
1e4b 1162 1e4d 1164
1e4c 1e4b :2 0 1e95
9d :3 0 15 :3 0
9a :3 0 1e50 1e51
0 9b :3 0 1e52
1e53 0 1e8d 64
:3 0 65 :3 0 1e55
1e56 0 64 :3 0
75 :3 0 1e58 1e59
0 9e :2 0 2
:4 0 1ba :2 0 77
:2 0 27 :2 0 1166
1e5e 1e60 :3 0 1169
1e5a 1e62 1e57 1e64
1e63 :2 0 67 :3 0
78 :3 0 1e66 1e67
0 69 :4 0 1bb
:4 0 6c :2 0 6d
:3 0 116d 1e6b 1e6d
:3 0 6c :2 0 81
:4 0 1170 1e6f 1e71
:3 0 6c :2 0 a1
:4 0 1173 1e73 1e75
:3 0 6c :2 0 9b
:3 0 1176 1e77 1e79
:3 0 6c :2 0 a2
:4 0 1179 1e7b 1e7d
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 117c
1e80 1e84 1180 1e7f
1e86 :3 0 1183 1e68
1e88 :2 0 1e8a 1186
1e8b 1e65 1e8a 0
1e8c 1188 0 1e8d
118a 1e90 :3 0 1e90
0 1e90 1e8f 1e8d
1e8e :6 0 1e92 43
:3 0 118d 1e94 118f
1e93 1e92 :2 0 1e95
1191 :2 0 1e97 0
1e97 1e96 1e44 1e95
:6 0 279f 42 :3 0
71 :3 0 44 :3 0
30 :2 0 1194 1e99
1e9c b1 :2 0 30
:2 0 1199 1e9e 1ea0
:3 0 1ea1 :2 0 21
:3 0 95 :2 0 119c
1ea4 1ea5 :3 0 1ea6
:2 0 1ea7 :2 0 1ea2
1ea9 1ea8 :2 0 46
:3 0 27 :2 0 1eab
1eac 0 1ebf 96
:3 0 f1 :3 0 1eae
1eaf 0 1f :3 0
21 :3 0 119e 1eb0
1eb3 a7 :2 0 30
:2 0 11a3 1eb5 1eb7
:3 0 1f :3 0 21
:3 0 1eb9 1eba 0
1ebc 11a6 1ebd 1eb8
1ebc 0 1ebe 11a8
0 1ebf 11aa 1ec0
1eaa 1ebf 0 1ec1
11ad 0 279f a3
:3 0 26 :3 0 27
:2 0 27 :2 0 11af
1ec2 1ec6 8e :2 0
27 :4 0 11b5 1ec8
1eca :3 0 3a :3 0
83 :3 0 10b :3 0
1ecd 1ece 0 1ecc
1ecf 0 1efd 71
:3 0 1b3 :3 0 2c
:3 0 11b8 1ed2 1ed4
30 :2 0 11ba 1ed1
1ed7 8e :2 0 30
:2 0 11bf 1ed9 1edb
:3 0 2c :3 0 1d
:3 0 1edd 1ede 0
1ee0 11c2 1efa 2c
:3 0 a3 :3 0 2c
:3 0 6c :2 0 1bc
:4 0 11c4 1ee4 1ee6
:3 0 27 :2 0 2a
:2 0 11c7 1ee2 1eea
1ee1 1eeb 0 1ef9
2c :3 0 a3 :3 0
2c :3 0 6c :2 0
1d :3 0 11cb 1ef0
1ef2 :3 0 27 :2 0
2a :2 0 11ce 1eee
1ef6 1eed 1ef7 0
1ef9 11d2 1efb 1edc
1ee0 0 1efc 0
1ef9 0 1efc 11d5
0 1efd 11d8 1f2b
71 :3 0 1b3 :3 0
2b :3 0 11db 1eff
1f01 30 :2 0 11dd
1efe 1f04 8e :2 0
30 :2 0 11e2 1f06
1f08 :3 0 2b :3 0
1d :3 0 1f0a 1f0b
0 1f0d 11e5 1f27
2b :3 0 a3 :3 0
2b :3 0 6c :2 0
1bc :4 0 11e7 1f11
1f13 :3 0 27 :2 0
2a :2 0 11ea 1f0f
1f17 1f0e 1f18 0
1f26 2b :3 0 a3
:3 0 2b :3 0 6c
:2 0 1d :3 0 11ee
1f1d 1f1f :3 0 27
:2 0 2a :2 0 11f1
1f1b 1f23 1f1a 1f24
0 1f26 11f5 1f28
1f09 1f0d 0 1f29
0 1f26 0 1f29
11f8 0 1f2a 11fb
1f2c 1ecb 1efd 0
1f2d 0 1f2a 0
1f2d 11fd 0 279f
33 :3 0 30 :2 0
1f2e 1f2f 0 279f
44 :3 0 30 :2 0
1f31 1f32 0 279f
71 :3 0 46 :3 0
30 :2 0 1200 1f34
1f37 8e :2 0 27
:2 0 1205 1f39 1f3b
:3 0 61 :3 0 8e
:2 0 27 :2 0 120a
1f3e 1f40 :3 0 a3
:3 0 26 :3 0 27
:2 0 27 :2 0 120d
1f42 1f46 8e :2 0
30 :4 0 1213 1f48
1f4a :3 0 135 :3 0
136 :3 0 137 :3 0
a3 :3 0 1f :3 0
137 :3 0 a3 :3 0
136 :3 0 137 :3 0
a3 :3 0 22 :3 0
137 :3 0 a3 :3 0
138 :3 0 139 :3 0
37 :3 0 139 :3 0
19 :3 0 21 :3 0
44 :3 0 47 :3 0
106 :3 0 107 :3 0
17 :3 0 130 :3 0
1d :3 0 131 :3 0
13a :4 0 1bd 1
:8 0 1f6e 15 :3 0
9a :3 0 1f69 1f6a
0 9b :3 0 1f6b
1f6c 0 1f6e 1216
1fc1 9c :3 0 15
:3 0 9a :3 0 1f70
1f71 0 9b :3 0
1f72 1f73 0 1f75
1219 1f77 121b 1f76
1f75 :2 0 1fbf 9d
:3 0 15 :3 0 9a
:3 0 1f7a 1f7b 0
9b :3 0 1f7c 1f7d
0 1fb7 64 :3 0
65 :3 0 1f7f 1f80
0 64 :3 0 75
:3 0 1f82 1f83 0
9e :2 0 2 :4 0
1be :2 0 77 :2 0
27 :2 0 121d 1f88
1f8a :3 0 1220 1f84
1f8c 1f81 1f8e 1f8d
:2 0 67 :3 0 78
:3 0 1f90 1f91 0
69 :4 0 1bf :4 0
6c :2 0 6d :3 0
1224 1f95 1f97 :3 0
6c :2 0 81 :4 0
1227 1f99 1f9b :3 0
6c :2 0 a1 :4 0
122a 1f9d 1f9f :3 0
6c :2 0 9b :3 0
122d 1fa1 1fa3 :3 0
6c :2 0 a2 :4 0
1230 1fa5 1fa7 :3 0
6c :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 1233 1faa
1fae 1237 1fa9 1fb0
:3 0 123a 1f92 1fb2
:2 0 1fb4 123d 1fb5
1f8f 1fb4 0 1fb6
123f 0 1fb7 1241
1fba :3 0 1fba 0
1fba 1fb9 1fb7 1fb8
:6 0 1fbc 45 :3 0
1244 1fbe 1246 1fbd
1fbc :2 0 1fbf 1248
:2 0 1fc1 0 1fc1
1fc0 1f6e 1fbf :6 0
20f4 42 :3 0 15
:3 0 9a :3 0 1fc3
1fc4 0 15 :3 0
8e :2 0 a6 :3 0
1fc6 1fc8 0 124d
1fc7 1fca :3 0 1fcb
:2 0 46 :3 0 27
:2 0 1fcd 1fce 0
2064 71 :3 0 47
:3 0 30 :2 0 1250
1fd0 1fd3 8e :2 0
30 :2 0 1255 1fd5
1fd7 :3 0 1fd8 :2 0
71 :3 0 44 :3 0
30 :2 0 1258 1fda
1fdd 8e :2 0 27
:2 0 125d 1fdf 1fe1
:3 0 1fe2 :2 0 1fd9
1fe4 1fe3 :2 0 135
:3 0 13e :3 0 137
:3 0 a3 :3 0 1f
:3 0 137 :3 0 a3
:3 0 13e :3 0 137
:3 0 a3 :3 0 22
:3 0 137 :3 0 a3
:3 0 13f :3 0 140
:3 0 37 :3 0 19
:3 0 21 :3 0 44
:3 0 106 :3 0 107
:3 0 17 :3 0 130
:3 0 1d :3 0 131
:3 0 13a :4 0 1c0
1 :8 0 2006 15
:3 0 9a :3 0 2001
2002 0 9b :3 0
2003 2004 0 2006
1260 2059 9c :3 0
15 :3 0 9a :3 0
2008 2009 0 9b
:3 0 200a 200b 0
200d 1263 200f 1265
200e 200d :2 0 2057
9d :3 0 15 :3 0
9a :3 0 2012 2013
0 9b :3 0 2014
2015 0 204f 64
:3 0 65 :3 0 2017
2018 0 64 :3 0
75 :3 0 201a 201b
0 9e :2 0 2
:4 0 1c1 :2 0 77
:2 0 27 :2 0 1267
2020 2022 :3 0 126a
201c 2024 2019 2026
2025 :2 0 67 :3 0
78 :3 0 2028 2029
0 69 :4 0 1c2
:4 0 6c :2 0 6d
:3 0 126e 202d 202f
:3 0 6c :2 0 81
:4 0 1271 2031 2033
:3 0 6c :2 0 a1
:4 0 1274 2035 2037
:3 0 6c :2 0 9b
:3 0 1277 2039 203b
:3 0 6c :2 0 a2
:4 0 127a 203d 203f
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 127d
2042 2046 1281 2041
2048 :3 0 1284 202a
204a :2 0 204c 1287
204d 2027 204c 0
204e 1289 0 204f
128b 2052 :3 0 2052
0 2052 2051 204f
2050 :6 0 2054 47
:3 0 128e 2056 1290
2055 2054 :2 0 2057
1292 :2 0 2059 0
2059 2058 2006 2057
:6 0 205b 42 :3 0
1295 2060 33 :3 0
119 :2 0 205c 205d
0 205f 1297 2061
1fe5 205b 0 2062
0 205f 0 2062
1299 0 2064 ad
:3 0 129c 20f2 15
:3 0 9a :3 0 2065
2066 0 15 :3 0
8e :2 0 d8 :3 0
2068 206a 0 12a1
2069 206c :3 0 206d
:2 0 71 :3 0 44
:3 0 30 :2 0 12a4
206f 2072 8e :2 0
27 :2 0 12a9 2074
2076 :3 0 2077 :2 0
206e 2079 2078 :2 0
135 :3 0 13e :3 0
137 :3 0 a3 :3 0
1f :3 0 137 :3 0
a3 :3 0 13e :3 0
137 :3 0 a3 :3 0
22 :3 0 137 :3 0
a3 :3 0 13f :3 0
140 :3 0 37 :3 0
19 :3 0 21 :3 0
44 :3 0 106 :3 0
107 :3 0 17 :3 0
130 :3 0 1d :3 0
131 :3 0 13a :4 0
1c3 1 :8 0 209b
15 :3 0 9a :3 0
2096 2097 0 9b
:3 0 2098 2099 0
209b 12ac 20ee 9c
:3 0 15 :3 0 9a
:3 0 209d 209e 0
9b :3 0 209f 20a0
0 20a2 12af 20a4
12b1 20a3 20a2 :2 0
20ec 9d :3 0 15
:3 0 9a :3 0 20a7
20a8 0 9b :3 0
20a9 20aa 0 20e4
64 :3 0 65 :3 0
20ac 20ad 0 64
:3 0 75 :3 0 20af
20b0 0 9e :2 0
2 :4 0 1c4 :2 0
77 :2 0 27 :2 0
12b3 20b5 20b7 :3 0
12b6 20b1 20b9 20ae
20bb 20ba :2 0 67
:3 0 78 :3 0 20bd
20be 0 69 :4 0
1c5 :4 0 6c :2 0
6d :3 0 12ba 20c2
20c4 :3 0 6c :2 0
81 :4 0 12bd 20c6
20c8 :3 0 6c :2 0
a1 :4 0 12c0 20ca
20cc :3 0 6c :2 0
9b :3 0 12c3 20ce
20d0 :3 0 6c :2 0
a2 :4 0 12c6 20d2
20d4 :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
12c9 20d7 20db 12cd
20d6 20dd :3 0 12d0
20bf 20df :2 0 20e1
12d3 20e2 20bc 20e1
0 20e3 12d5 0
20e4 12d7 20e7 :3 0
20e7 0 20e7 20e6
20e4 20e5 :6 0 20e9
49 :3 0 12da 20eb
12dc 20ea 20e9 :2 0
20ec 12de :2 0 20ee
0 20ee 20ed 209b
20ec :6 0 20f0 42
:3 0 12e1 20f1 207a
20f0 0 20f3 1fcc
2064 0 20f3 12e3
0 20f4 12e6 216d
135 :3 0 13e :3 0
137 :3 0 a3 :3 0
1f :3 0 137 :3 0
a3 :3 0 13e :3 0
137 :3 0 a3 :3 0
22 :3 0 137 :3 0
a3 :3 0 13f :3 0
140 :3 0 37 :3 0
19 :3 0 21 :3 0
44 :3 0 106 :3 0
b7 :3 0 17 :3 0
107 :3 0 17 :3 0
130 :3 0 1d :3 0
131 :3 0 13a :4 0
1c6 1 :8 0 2117
15 :3 0 9a :3 0
2112 2113 0 9b
:3 0 2114 2115 0
2117 12e9 216a 9c
:3 0 15 :3 0 9a
:3 0 2119 211a 0
9b :3 0 211b 211c
0 211e 12ec 2120
12ee 211f 211e :2 0
2168 9d :3 0 15
:3 0 9a :3 0 2123
2124 0 9b :3 0
2125 2126 0 2160
64 :3 0 65 :3 0
2128 2129 0 64
:3 0 75 :3 0 212b
212c 0 9e :2 0
2 :4 0 1c7 :2 0
77 :2 0 27 :2 0
12f0 2131 2133 :3 0
12f3 212d 2135 212a
2137 2136 :2 0 67
:3 0 78 :3 0 2139
213a 0 69 :4 0
1c8 :4 0 6c :2 0
6d :3 0 12f7 213e
2140 :3 0 6c :2 0
81 :4 0 12fa 2142
2144 :3 0 6c :2 0
a1 :4 0 12fd 2146
2148 :3 0 6c :2 0
9b :3 0 1300 214a
214c :3 0 6c :2 0
a2 :4 0 1303 214e
2150 :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
1306 2153 2157 130a
2152 2159 :3 0 130d
213b 215b :2 0 215d
1310 215e 2138 215d
0 215f 1312 0
2160 1314 2163 :3 0
2163 0 2163 2162
2160 2161 :6 0 2165
4b :3 0 1317 2167
1319 2166 2165 :2 0
2168 131b :2 0 216a
0 216a 2169 2117
2168 :6 0 216c 42
:3 0 131e 216e 1f4b
20f4 0 216f 0
216c 0 216f 1320
0 2170 1323 2389
a3 :3 0 26 :3 0
27 :2 0 27 :2 0
1325 2171 2175 8e
:2 0 30 :4 0 132b
2177 2179 :3 0 135
:3 0 136 :3 0 137
:3 0 a3 :3 0 1f
:3 0 137 :3 0 a3
:3 0 136 :3 0 137
:3 0 a3 :3 0 138
:3 0 37 :3 0 139
:3 0 139 :3 0 19
:3 0 21 :3 0 44
:3 0 47 :3 0 106
:3 0 b7 :3 0 17
:3 0 107 :3 0 17
:3 0 130 :3 0 1d
:3 0 131 :3 0 13a
:4 0 1c9 1 :8 0
219c 15 :3 0 9a
:3 0 2197 2198 0
9b :3 0 2199 219a
0 219c 132e 21ef
9c :3 0 15 :3 0
9a :3 0 219e 219f
0 9b :3 0 21a0
21a1 0 21a3 1331
21a5 1333 21a4 21a3
:2 0 21ed 9d :3 0
15 :3 0 9a :3 0
21a8 21a9 0 9b
:3 0 21aa 21ab 0
21e5 64 :3 0 65
:3 0 21ad 21ae 0
64 :3 0 75 :3 0
21b0 21b1 0 9e
:2 0 2 :4 0 1ca
:2 0 77 :2 0 27
:2 0 1335 21b6 21b8
:3 0 1338 21b2 21ba
21af 21bc 21bb :2 0
67 :3 0 78 :3 0
21be 21bf 0 69
:4 0 1cb :4 0 6c
:2 0 6d :3 0 133c
21c3 21c5 :3 0 6c
:2 0 81 :4 0 133f
21c7 21c9 :3 0 6c
:2 0 a1 :4 0 1342
21cb 21cd :3 0 6c
:2 0 9b :3 0 1345
21cf 21d1 :3 0 6c
:2 0 a2 :4 0 1348
21d3 21d5 :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 134b 21d8 21dc
134f 21d7 21de :3 0
1352 21c0 21e0 :2 0
21e2 1355 21e3 21bd
21e2 0 21e4 1357
0 21e5 1359 21e8
:3 0 21e8 0 21e8
21e7 21e5 21e6 :6 0
21ea 4d :3 0 135c
21ec 135e 21eb 21ea
:2 0 21ed 1360 :2 0
21ef 0 21ef 21ee
219c 21ed :6 0 230f
42 :3 0 15 :3 0
9a :3 0 21f1 21f2
0 15 :3 0 8e
:2 0 a6 :3 0 21f4
21f6 0 1365 21f5
21f8 :3 0 21f9 :2 0
71 :3 0 47 :3 0
30 :2 0 1368 21fb
21fe 8e :2 0 30
:2 0 136d 2200 2202
:3 0 2203 :2 0 71
:3 0 44 :3 0 30
:2 0 1370 2205 2208
8e :2 0 27 :2 0
1375 220a 220c :3 0
220d :2 0 2204 220f
220e :2 0 135 :3 0
13e :3 0 137 :3 0
a3 :3 0 1f :3 0
137 :3 0 a3 :3 0
13f :3 0 37 :3 0
140 :3 0 19 :3 0
21 :3 0 44 :3 0
106 :3 0 b7 :3 0
17 :3 0 107 :3 0
17 :3 0 130 :3 0
1d :3 0 131 :3 0
13a :4 0 1cc 1
:8 0 222d 15 :3 0
9a :3 0 2228 2229
0 9b :3 0 222a
222b 0 222d 1378
2280 9c :3 0 15
:3 0 9a :3 0 222f
2230 0 9b :3 0
2231 2232 0 2234
137b 2236 137d 2235
2234 :2 0 227e 9d
:3 0 15 :3 0 9a
:3 0 2239 223a 0
9b :3 0 223b 223c
0 2276 64 :3 0
65 :3 0 223e 223f
0 64 :3 0 75
:3 0 2241 2242 0
9e :2 0 2 :4 0
1cd :2 0 77 :2 0
27 :2 0 137f 2247
2249 :3 0 1382 2243
224b 2240 224d 224c
:2 0 67 :3 0 78
:3 0 224f 2250 0
69 :4 0 1ce :4 0
6c :2 0 6d :3 0
1386 2254 2256 :3 0
6c :2 0 81 :4 0
1389 2258 225a :3 0
6c :2 0 a1 :4 0
138c 225c 225e :3 0
6c :2 0 9b :3 0
138f 2260 2262 :3 0
6c :2 0 a2 :4 0
1392 2264 2266 :3 0
6c :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 1395 2269
226d 1399 2268 226f
:3 0 139c 2251 2271
:2 0 2273 139f 2274
224e 2273 0 2275
13a1 0 2276 13a3
2279 :3 0 2279 0
2279 2278 2276 2277
:6 0 227b 4f :3 0
13a6 227d 13a8 227c
227b :2 0 227e 13aa
:2 0 2280 0 2280
227f 222d 227e :6 0
2282 42 :3 0 13ad
2288 33 :3 0 119
:2 0 2283 2284 0
2287 0 2287 13af
2289 2210 2282 0
228a 0 2287 0
228a 13b2 0 228c
ad :3 0 13b5 230d
15 :3 0 9a :3 0
228d 228e 0 15
:3 0 8e :2 0 d8
:3 0 2290 2292 0
13b9 2291 2294 :3 0
2295 :2 0 135 :3 0
13e :3 0 137 :3 0
a3 :3 0 1f :3 0
137 :3 0 a3 :3 0
13e :3 0 137 :3 0
a3 :3 0 13f :3 0
37 :3 0 140 :3 0
19 :3 0 21 :3 0
44 :3 0 106 :3 0
b7 :3 0 17 :3 0
107 :3 0 17 :3 0
130 :3 0 1d :3 0
131 :3 0 13a :4 0
1cf 1 :8 0 22b6
15 :3 0 9a :3 0
22b1 22b2 0 9b
:3 0 22b3 22b4 0
22b6 13bc 2309 9c
:3 0 15 :3 0 9a
:3 0 22b8 22b9 0
9b :3 0 22ba 22bb
0 22bd 13bf 22bf
13c1 22be 22bd :2 0
2307 9d :3 0 15
:3 0 9a :3 0 22c2
22c3 0 9b :3 0
22c4 22c5 0 22ff
64 :3 0 65 :3 0
22c7 22c8 0 64
:3 0 75 :3 0 22ca
22cb 0 9e :2 0
2 :4 0 1d0 :2 0
77 :2 0 27 :2 0
13c3 22d0 22d2 :3 0
13c6 22cc 22d4 22c9
22d6 22d5 :2 0 67
:3 0 78 :3 0 22d8
22d9 0 69 :4 0
1d1 :4 0 6c :2 0
6d :3 0 13ca 22dd
22df :3 0 6c :2 0
81 :4 0 13cd 22e1
22e3 :3 0 6c :2 0
a1 :4 0 13d0 22e5
22e7 :3 0 6c :2 0
9b :3 0 13d3 22e9
22eb :3 0 6c :2 0
a2 :4 0 13d6 22ed
22ef :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
13d9 22f2 22f6 13dd
22f1 22f8 :3 0 13e0
22da 22fa :2 0 22fc
13e3 22fd 22d7 22fc
0 22fe 13e5 0
22ff 13e7 2302 :3 0
2302 0 2302 2301
22ff 2300 :6 0 2304
51 :3 0 13ea 2306
13ec 2305 2304 :2 0
2307 13ee :2 0 2309
0 2309 2308 22b6
2307 :6 0 230b 42
:3 0 13f1 230c 2296
230b 0 230e 21fa
228c 0 230e 13f3
0 230f 13f6 2385
135 :3 0 13e :3 0
137 :3 0 a3 :3 0
1f :3 0 137 :3 0
a3 :3 0 13e :3 0
137 :3 0 a3 :3 0
13f :3 0 37 :3 0
140 :3 0 19 :3 0
21 :3 0 44 :3 0
106 :3 0 b7 :3 0
17 :3 0 107 :3 0
17 :3 0 130 :3 0
1d :3 0 131 :3 0
13a :4 0 1d2 1
:8 0 232f 15 :3 0
9a :3 0 232a 232b
0 9b :3 0 232c
232d 0 232f 13f9
2382 9c :3 0 15
:3 0 9a :3 0 2331
2332 0 9b :3 0
2333 2334 0 2336
13fc 2338 13fe 2337
2336 :2 0 2380 9d
:3 0 15 :3 0 9a
:3 0 233b 233c 0
9b :3 0 233d 233e
0 2378 64 :3 0
65 :3 0 2340 2341
0 64 :3 0 75
:3 0 2343 2344 0
9e :2 0 2 :4 0
1d3 :2 0 77 :2 0
27 :2 0 1400 2349
234b :3 0 1403 2345
234d 2342 234f 234e
:2 0 67 :3 0 78
:3 0 2351 2352 0
69 :4 0 1d4 :4 0
6c :2 0 6d :3 0
1407 2356 2358 :3 0
6c :2 0 81 :4 0
140a 235a 235c :3 0
6c :2 0 a1 :4 0
140d 235e 2360 :3 0
6c :2 0 9b :3 0
1410 2362 2364 :3 0
6c :2 0 a2 :4 0
1413 2366 2368 :3 0
6c :2 0 a3 :3 0
a4 :3 0 27 :2 0
a5 :2 0 1416 236b
236f 141a 236a 2371
:3 0 141d 2353 2373
:2 0 2375 1420 2376
2350 2375 0 2377
1422 0 2378 1424
237b :3 0 237b 0
237b 237a 2378 2379
:6 0 237d 53 :3 0
1427 237f 1429 237e
237d :2 0 2380 142b
:2 0 2382 0 2382
2381 232f 2380 :6 0
2384 42 :3 0 142e
2386 217a 230f 0
2387 0 2384 0
2387 1430 0 2388
1433 238a 1f41 2170
0 238b 0 2388
0 238b 1435 0
26c3 15 :3 0 9a
:3 0 238c 238d 0
15 :3 0 8e :2 0
a6 :3 0 238f 2391
0 143a 2390 2393
:3 0 2394 :2 0 71
:3 0 44 :3 0 30
:2 0 143d 2396 2399
8e :2 0 27 :2 0
1442 239b 239d :3 0
46 :3 0 119 :2 0
239f 23a0 0 23a2
1445 24ad 19 :3 0
95 :2 0 1447 23a4
23a5 :3 0 23a6 :2 0
61 :3 0 8e :2 0
27 :2 0 144b 23a9
23ab :3 0 47 :3 0
30 :2 0 23ad 23ae
0 241a 15b :3 0
15c :3 0 47 :3 0
15d :3 0 b7 :3 0
17 :3 0 105 :3 0
19 :3 0 15e :3 0
137 :3 0 a3 :3 0
1f :3 0 137 :3 0
a3 :3 0 22 :4 0
1d5 1 :8 0 23c5
15 :3 0 9a :3 0
23c0 23c1 0 9b
:3 0 23c2 23c3 0
23c5 144e 2418 9c
:3 0 15 :3 0 9a
:3 0 23c7 23c8 0
9b :3 0 23c9 23ca
0 23cc 1451 23ce
1453 23cd 23cc :2 0
2416 9d :3 0 15
:3 0 9a :3 0 23d1
23d2 0 9b :3 0
23d3 23d4 0 240e
64 :3 0 65 :3 0
23d6 23d7 0 64
:3 0 75 :3 0 23d9
23da 0 9e :2 0
2 :4 0 1d6 :2 0
77 :2 0 27 :2 0
1455 23df 23e1 :3 0
1458 23db 23e3 23d8
23e5 23e4 :2 0 67
:3 0 78 :3 0 23e7
23e8 0 69 :4 0
1d7 :4 0 6c :2 0
6d :3 0 145c 23ec
23ee :3 0 6c :2 0
81 :4 0 145f 23f0
23f2 :3 0 6c :2 0
a1 :4 0 1462 23f4
23f6 :3 0 6c :2 0
9b :3 0 1465 23f8
23fa :3 0 6c :2 0
a2 :4 0 1468 23fc
23fe :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
146b 2401 2405 146f
2400 2407 :3 0 1472
23e9 2409 :2 0 240b
1475 240c 23e6 240b
0 240d 1477 0
240e 1479 2411 :3 0
2411 0 2411 2410
240e 240f :6 0 2413
55 :3 0 147c 2415
147e 2414 2413 :2 0
2416 1480 :2 0 2418
0 2418 2417 23c5
2416 :6 0 241a 42
:3 0 1483 2486 47
:3 0 30 :2 0 241b
241c 0 2485 15b
:3 0 15c :3 0 47
:3 0 15d :3 0 b7
:3 0 17 :3 0 105
:3 0 19 :3 0 15e
:3 0 137 :3 0 a3
:3 0 1f :4 0 1d8
1 :8 0 2430 15
:3 0 9a :3 0 242b
242c 0 9b :3 0
242d 242e 0 2430
1486 2483 9c :3 0
15 :3 0 9a :3 0
2432 2433 0 9b
:3 0 2434 2435 0
2437 1489 2439 148b
2438 2437 :2 0 2481
9d :3 0 15 :3 0
9a :3 0 243c 243d
0 9b :3 0 243e
243f 0 2479 64
:3 0 65 :3 0 2441
2442 0 64 :3 0
75 :3 0 2444 2445
0 9e :2 0 2
:4 0 1d9 :2 0 77
:2 0 27 :2 0 148d
244a 244c :3 0 1490
2446 244e 2443 2450
244f :2 0 67 :3 0
78 :3 0 2452 2453
0 69 :4 0 1da
:4 0 6c :2 0 6d
:3 0 1494 2457 2459
:3 0 6c :2 0 81
:4 0 1497 245b 245d
:3 0 6c :2 0 a1
:4 0 149a 245f 2461
:3 0 6c :2 0 9b
:3 0 149d 2463 2465
:3 0 6c :2 0 a2
:4 0 14a0 2467 2469
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 14a3
246c 2470 14a7 246b
2472 :3 0 14aa 2454
2474 :2 0 2476 14ad
2477 2451 2476 0
2478 14af 0 2479
14b1 247c :3 0 247c
0 247c 247b 2479
247a :6 0 247e 57
:3 0 14b4 2480 14b6
247f 247e :2 0 2481
14b8 :2 0 2483 0
2483 2482 2430 2481
:6 0 2485 42 :3 0
14bb 2487 23ac 241a
0 2488 0 2485
0 2488 14be 0
24a6 71 :3 0 47
:3 0 30 :2 0 14c1
2489 248c 71 :3 0
a7 :2 0 37 :3 0
30 :2 0 14c4 248e
2492 14c9 248f 2494
:3 0 2f :3 0 71
:3 0 2f :3 0 30
:2 0 14cc 2497 249a
77 :2 0 27 :2 0
14cf 249c 249e :3 0
2496 249f 0 24a3
1db :3 0 24a1 :4 0
24a3 14d2 24a4 2495
24a3 0 24a5 14d5
0 24a6 14d7 24a7
23a7 24a6 0 24a8
14da 0 24ac 46
:3 0 27 :2 0 24a9
24aa 0 24ac 14dc
24ae 239e 23a2 0
24af 0 24ac 0
24af 14df 0 24b0
14e2 24bf 2f :3 0
71 :3 0 2f :3 0
30 :2 0 14e4 24b2
24b5 77 :2 0 27
:2 0 14e7 24b7 24b9
:3 0 24b1 24ba 0
24be 1db :3 0 24bc
:4 0 24be 14ea 24c0
2395 24b0 0 24c1
0 24be 0 24c1
14ed 0 26c3 21
:3 0 21 :3 0 24c2
24c3 0 26c3 3f
:3 0 30 :2 0 24c5
24c6 0 26c3 96
:3 0 19d :3 0 137
:3 0 a3 :3 0 21
:3 0 96 :3 0 19e
:3 0 1f :3 0 21
:3 0 98 :4 0 1dc
1 :8 0 24d8 15
:3 0 9a :3 0 24d3
24d4 0 9b :3 0
24d5 24d6 0 24d8
14f0 252b 9c :3 0
15 :3 0 9a :3 0
24da 24db 0 9b
:3 0 24dc 24dd 0
24df 14f3 24e1 14f5
24e0 24df :2 0 2529
9d :3 0 15 :3 0
9a :3 0 24e4 24e5
0 9b :3 0 24e6
24e7 0 2521 64
:3 0 65 :3 0 24e9
24ea 0 64 :3 0
75 :3 0 24ec 24ed
0 9e :2 0 2
:4 0 1dd :2 0 77
:2 0 27 :2 0 14f7
24f2 24f4 :3 0 14fa
24ee 24f6 24eb 24f8
24f7 :2 0 67 :3 0
78 :3 0 24fa 24fb
0 69 :4 0 1de
:4 0 6c :2 0 6d
:3 0 14fe 24ff 2501
:3 0 6c :2 0 81
:4 0 1501 2503 2505
:3 0 6c :2 0 a1
:4 0 1504 2507 2509
:3 0 6c :2 0 9b
:3 0 1507 250b 250d
:3 0 6c :2 0 a2
:4 0 150a 250f 2511
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 150d
2514 2518 1511 2513
251a :3 0 1514 24fc
251c :2 0 251e 1517
251f 24f9 251e 0
2520 1519 0 2521
151b 2524 :3 0 2524
0 2524 2523 2521
2522 :6 0 2526 59
:3 0 151e 2528 1520
2527 2526 :2 0 2529
1522 :2 0 252b 0
252b 252a 24d8 2529
:6 0 26c3 42 :3 0
137 :3 0 a3 :3 0
1f :3 0 137 :3 0
a3 :3 0 21 :3 0
1f :3 0 21 :3 0
21 :3 0 98 :4 0
1df 1 :8 0 253d
15 :3 0 9a :3 0
2538 2539 0 9b
:3 0 253a 253b 0
253d 1525 2590 9c
:3 0 15 :3 0 9a
:3 0 253f 2540 0
9b :3 0 2541 2542
0 2544 1528 2546
152a 2545 2544 :2 0
258e 9d :3 0 15
:3 0 9a :3 0 2549
254a 0 9b :3 0
254b 254c 0 2586
64 :3 0 65 :3 0
254e 254f 0 64
:3 0 75 :3 0 2551
2552 0 9e :2 0
2 :4 0 1e0 :2 0
77 :2 0 27 :2 0
152c 2557 2559 :3 0
152f 2553 255b 2550
255d 255c :2 0 67
:3 0 78 :3 0 255f
2560 0 69 :4 0
1e1 :4 0 6c :2 0
6d :3 0 1533 2564
2566 :3 0 6c :2 0
81 :4 0 1536 2568
256a :3 0 6c :2 0
a1 :4 0 1539 256c
256e :3 0 6c :2 0
9b :3 0 153c 2570
2572 :3 0 6c :2 0
a2 :4 0 153f 2574
2576 :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
1542 2579 257d 1546
2578 257f :3 0 1549
2561 2581 :2 0 2583
154c 2584 255e 2583
0 2585 154e 0
2586 1550 2589 :3 0
2589 0 2589 2588
2586 2587 :6 0 258b
5b :3 0 1553 258d
1555 258c 258b :2 0
258e 1557 :2 0 2590
0 2590 258f 253d
258e :6 0 26c3 42
:3 0 45 :3 0 1a5
:2 0 2592 2593 0
26c3 22 :3 0 6
:3 0 2595 2596 0
26c3 71 :3 0 33
:3 0 30 :2 0 155a
2598 259b 8e :2 0
30 :2 0 155f 259d
259f :3 0 3f :3 0
11a :2 0 25a1 25a2
0 25a4 1562 25a5
25a0 25a4 0 25a6
1564 0 26c3 60
:3 0 1a6 :3 0 19
:3 0 17 :3 0 1a
:3 0 1d :3 0 4e
:3 0 32 :3 0 23
:3 0 23 :3 0 23
:3 0 23 :3 0 21
:3 0 22 :3 0 41
:3 0 37 :3 0 35
:3 0 38 :3 0 39
:3 0 34 :3 0 45
:3 0 26 :3 0 33
:3 0 31 :3 0 3b
:3 0 36 :3 0 3f
:3 0 3d :3 0 43
:3 0 1c :3 0 30
:2 0 30 :2 0 7c
:2 0 7c :2 0 30
:2 0 30 :2 0 1566
25a8 25cb 25a7 25cc
0 26c3 60 :3 0
8e :2 0 30 :2 0
158b 25cf 25d1 :3 0
71 :3 0 33 :3 0
30 :2 0 158e 25d3
25d6 8e :2 0 30
:2 0 1593 25d8 25da
:3 0 1a7 :3 0 1a8
:3 0 1a9 :3 0 1d
:4 0 1aa 1 :8 0
25f6 1ab :4 0 25e1
:3 0 89 :3 0 8e
:2 0 1598 25e4 25e5
:3 0 15 :3 0 9a
:3 0 25e7 25e8 0
30 :2 0 25e9 25ea
0 25ec 159b 25f3
15 :3 0 9a :3 0
25ed 25ee 0 118
:2 0 25ef 25f0 0
25f2 159d 25f4 25e6
25ec 0 25f5 0
25f2 0 25f5 159f
0 25f6 15a2 2649
9c :3 0 15 :3 0
9a :3 0 25f8 25f9
0 9b :3 0 25fa
25fb 0 25fd 15a5
25ff 15a7 25fe 25fd
:2 0 2647 9d :3 0
15 :3 0 9a :3 0
2602 2603 0 9b
:3 0 2604 2605 0
263f 64 :3 0 65
:3 0 2607 2608 0
64 :3 0 75 :3 0
260a 260b 0 9e
:2 0 2 :4 0 1e2
:2 0 77 :2 0 27
:2 0 15a9 2610 2612
:3 0 15ac 260c 2614
2609 2616 2615 :2 0
67 :3 0 78 :3 0
2618 2619 0 69
:4 0 1e3 :4 0 6c
:2 0 6d :3 0 15b0
261d 261f :3 0 6c
:2 0 81 :4 0 15b3
2621 2623 :3 0 6c
:2 0 a1 :4 0 15b6
2625 2627 :3 0 6c
:2 0 9b :3 0 15b9
2629 262b :3 0 6c
:2 0 a2 :4 0 15bc
262d 262f :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 15bf 2632 2636
15c3 2631 2638 :3 0
15c6 261a 263a :2 0
263c 15c9 263d 2617
263c 0 263e 15cb
0 263f 15cd 2642
:3 0 2642 0 2642
2641 263f 2640 :6 0
2644 5d :3 0 15d0
2646 15d2 2645 2644
:2 0 2647 15d4 :2 0
2649 0 2649 2648
25f6 2647 :6 0 264b
42 :3 0 15d7 26bc
1a7 :3 0 1a8 :3 0
1a9 :3 0 1d :4 0
1ae 1 :8 0 2666
1ab :4 0 2651 :3 0
89 :3 0 8e :2 0
15db 2654 2655 :3 0
15 :3 0 9a :3 0
2657 2658 0 30
:2 0 2659 265a 0
265c 15de 2663 15
:3 0 9a :3 0 265d
265e 0 118 :2 0
265f 2660 0 2662
15e0 2664 2656 265c
0 2665 0 2662
0 2665 15e2 0
2666 15e5 26b9 9c
:3 0 15 :3 0 9a
:3 0 2668 2669 0
9b :3 0 266a 266b
0 266d 15e8 266f
15ea 266e 266d :2 0
26b7 9d :3 0 15
:3 0 9a :3 0 2672
2673 0 9b :3 0
2674 2675 0 26af
64 :3 0 65 :3 0
2677 2678 0 64
:3 0 75 :3 0 267a
267b 0 9e :2 0
2 :4 0 1e4 :2 0
77 :2 0 27 :2 0
15ec 2680 2682 :3 0
15ef 267c 2684 2679
2686 2685 :2 0 67
:3 0 78 :3 0 2688
2689 0 69 :4 0
1e5 :4 0 6c :2 0
6d :3 0 15f3 268d
268f :3 0 6c :2 0
81 :4 0 15f6 2691
2693 :3 0 6c :2 0
a1 :4 0 15f9 2695
2697 :3 0 6c :2 0
9b :3 0 15fc 2699
269b :3 0 6c :2 0
a2 :4 0 15ff 269d
269f :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
1602 26a2 26a6 1606
26a1 26a8 :3 0 1609
268a 26aa :2 0 26ac
160c 26ad 2687 26ac
0 26ae 160e 0
26af 1610 26b2 :3 0
26b2 0 26b2 26b1
26af 26b0 :6 0 26b4
5f :3 0 1613 26b6
1615 26b5 26b4 :2 0
26b7 1617 :2 0 26b9
0 26b9 26b8 2666
26b7 :6 0 26bb 42
:3 0 161a 26bd 25db
264b 0 26be 0
26bb 0 26be 161c
0 26bf 161f 26c0
25d2 26bf 0 26c1
1621 0 26c3 ad
:3 0 1623 278e 71
:3 0 46 :3 0 30
:2 0 162f 26c4 26c7
8e :2 0 30 :2 0
1634 26c9 26cb :3 0
21 :3 0 1f :3 0
26cd 26ce 0 278c
22 :3 0 6 :3 0
26d0 26d1 0 278c
a3 :3 0 26 :3 0
27 :2 0 27 :2 0
1637 26d3 26d7 8e
:2 0 27 :4 0 163d
26d9 26db :3 0 45
:3 0 83 :3 0 10b
:3 0 26de 26df 0
26dd 26e0 0 26e2
1640 26eb 45 :3 0
71 :3 0 3a :3 0
30 :2 0 1642 26e4
26e7 26e3 26e8 0
26ea 1645 26ec 26dc
26e2 0 26ed 0
26ea 0 26ed 1647
0 278c 60 :3 0
1a6 :3 0 28 :3 0
17 :3 0 1a :3 0
1d :3 0 4e :3 0
32 :3 0 23 :3 0
23 :3 0 23 :3 0
23 :3 0 21 :3 0
22 :3 0 41 :3 0
37 :3 0 35 :3 0
38 :3 0 39 :3 0
34 :3 0 45 :3 0
26 :3 0 33 :3 0
31 :3 0 3b :3 0
36 :3 0 3f :3 0
3d :3 0 43 :3 0
1c :3 0 30 :2 0
30 :2 0 7c :2 0
7c :2 0 30 :2 0
30 :2 0 164a 26ef
2712 26ee 2713 0
278c 60 :3 0 8e
:2 0 30 :2 0 166f
2716 2718 :3 0 1a7
:3 0 1a8 :3 0 1a9
:3 0 1d :4 0 1aa
1 :8 0 2734 1ab
:4 0 271f :3 0 89
:3 0 8e :2 0 1674
2722 2723 :3 0 15
:3 0 9a :3 0 2725
2726 0 30 :2 0
2727 2728 0 272a
1677 2731 15 :3 0
9a :3 0 272b 272c
0 118 :2 0 272d
272e 0 2730 1679
2732 2724 272a 0
2733 0 2730 0
2733 167b 0 2734
167e 2787 9c :3 0
15 :3 0 9a :3 0
2736 2737 0 9b
:3 0 2738 2739 0
273b 1681 273d 1683
273c 273b :2 0 2785
9d :3 0 15 :3 0
9a :3 0 2740 2741
0 9b :3 0 2742
2743 0 277d 64
:3 0 65 :3 0 2745
2746 0 64 :3 0
75 :3 0 2748 2749
0 9e :2 0 2
:4 0 1e6 :2 0 77
:2 0 27 :2 0 1685
274e 2750 :3 0 1688
274a 2752 2747 2754
2753 :2 0 67 :3 0
78 :3 0 2756 2757
0 69 :4 0 1e7
:4 0 6c :2 0 6d
:3 0 168c 275b 275d
:3 0 6c :2 0 81
:4 0 168f 275f 2761
:3 0 6c :2 0 a1
:4 0 1692 2763 2765
:3 0 6c :2 0 9b
:3 0 1695 2767 2769
:3 0 6c :2 0 a2
:4 0 1698 276b 276d
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 169b
2770 2774 169f 276f
2776 :3 0 16a2 2758
2778 :2 0 277a 16a5
277b 2755 277a 0
277c 16a7 0 277d
16a9 2780 :3 0 2780
0 2780 277f 277d
277e :6 0 2782 61
:3 0 16ac 2784 16ae
2783 2782 :2 0 2785
16b0 :2 0 2787 0
2787 2786 2734 2785
:6 0 2789 42 :3 0
16b3 278a 2719 2789
0 278b 16b5 0
278c 16b7 278d 26cc
278c 0 278f 1f3c
26c3 0 278f 16bd
0 279f 2f :3 0
71 :3 0 2f :3 0
30 :2 0 16c0 2791
2794 77 :2 0 27
:2 0 16c3 2796 2798
:3 0 2790 2799 0
279f 1db :5 0 279d
63 0 279e 16c6
279d 279c 279f 16c8
27a1 1b7 :3 0 1dee
279f :4 0 27a2 16d8
27a3 1ddf 27a2 0
27a4 16db 0 27a5
16dd 27a7 dfc 1db0
0 27a8 0 27a5
0 27a8 16e0 0
32eb 60 :3 0 b6
:2 0 30 :2 0 16e5
27aa 27ac :3 0 27ad
:2 0 71 :3 0 32
:3 0 30 :2 0 16e8
27af 27b2 b1 :2 0
30 :2 0 16ed 27b4
27b6 :3 0 27b7 :2 0
27ae 27b9 27b8 :2 0
71 :3 0 42 :3 0
30 :2 0 16f0 27bb
27be 8e :2 0 30
:2 0 16f5 27c0 27c2
:3 0 183 :3 0 180
:3 0 28 :4 0 1e8
1 :8 0 27dd 1ab
:4 0 27c8 :3 0 89
:3 0 8e :2 0 16fa
27cb 27cc :3 0 15
:3 0 9a :3 0 27ce
27cf 0 30 :2 0
27d0 27d1 0 27d3
16fd 27da 15 :3 0
9a :3 0 27d4 27d5
0 118 :2 0 27d6
27d7 0 27d9 16ff
27db 27cd 27d3 0
27dc 0 27d9 0
27dc 1701 0 27dd
1704 2830 9c :3 0
15 :3 0 9a :3 0
27df 27e0 0 9b
:3 0 27e1 27e2 0
27e4 1707 27e6 1709
27e5 27e4 :2 0 282e
9d :3 0 15 :3 0
9a :3 0 27e9 27ea
0 9b :3 0 27eb
27ec 0 2826 64
:3 0 65 :3 0 27ee
27ef 0 64 :3 0
75 :3 0 27f1 27f2
0 9e :2 0 2
:4 0 1e9 :2 0 77
:2 0 27 :2 0 170b
27f7 27f9 :3 0 170e
27f3 27fb 27f0 27fd
27fc :2 0 67 :3 0
78 :3 0 27ff 2800
0 69 :4 0 1ea
:4 0 6c :2 0 6d
:3 0 1712 2804 2806
:3 0 6c :2 0 81
:4 0 1715 2808 280a
:3 0 6c :2 0 a1
:4 0 1718 280c 280e
:3 0 6c :2 0 9b
:3 0 171b 2810 2812
:3 0 6c :2 0 a2
:4 0 171e 2814 2816
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 1721
2819 281d 1725 2818
281f :3 0 1728 2801
2821 :2 0 2823 172b
2824 27fe 2823 0
2825 172d 0 2826
172f 2829 :3 0 2829
0 2829 2828 2826
2827 :6 0 282b 63
:3 0 1732 282d 1734
282c 282b :2 0 282e
1736 :2 0 2830 0
2830 282f 27dd 282e
:6 0 2832 1 :3 0
1739 28a6 183 :3 0
182 :3 0 1e :3 0
181 :3 0 42 :3 0
180 :3 0 28 :4 0
1eb 1 :8 0 2850
1ab :4 0 283b :3 0
89 :3 0 8e :2 0
173d 283e 283f :3 0
15 :3 0 9a :3 0
2841 2842 0 30
:2 0 2843 2844 0
2846 1740 284d 15
:3 0 9a :3 0 2847
2848 0 118 :2 0
2849 284a 0 284c
1742 284e 2840 2846
0 284f 0 284c
0 284f 1744 0
2850 1747 28a3 9c
:3 0 15 :3 0 9a
:3 0 2852 2853 0
9b :3 0 2854 2855
0 2857 174a 2859
174c 2858 2857 :2 0
28a1 9d :3 0 15
:3 0 9a :3 0 285c
285d 0 9b :3 0
285e 285f 0 2899
64 :3 0 65 :3 0
2861 2862 0 64
:3 0 75 :3 0 2864
2865 0 9e :2 0
2 :4 0 1ec :2 0
77 :2 0 27 :2 0
174e 286a 286c :3 0
1751 2866 286e 2863
2870 286f :2 0 67
:3 0 78 :3 0 2872
2873 0 69 :4 0
1ed :4 0 6c :2 0
6d :3 0 1755 2877
2879 :3 0 6c :2 0
81 :4 0 1758 287b
287d :3 0 6c :2 0
a1 :4 0 175b 287f
2881 :3 0 6c :2 0
9b :3 0 175e 2883
2885 :3 0 6c :2 0
a2 :4 0 1761 2887
2889 :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
1764 288c 2890 1768
288b 2892 :3 0 176b
2874 2894 :2 0 2896
176e 2897 2871 2896
0 2898 1770 0
2899 1772 289c :3 0
289c 0 289c 289b
2899 289a :6 0 289e
65 :3 0 1775 28a0
1777 289f 289e :2 0
28a1 1779 :2 0 28a3
0 28a3 28a2 2850
28a1 :6 0 28a5 1
:3 0 177c 28a7 27c3
2832 0 28a8 0
28a5 0 28a8 177e
0 2a7b 60 :3 0
8e :2 0 118 :2 0
1783 28aa 28ac :3 0
64 :3 0 65 :3 0
28ae 28af 0 64
:3 0 75 :3 0 28b1
28b2 0 18 :2 0
2 :4 0 1ee :2 0
77 :2 0 27 :2 0
1786 28b7 28b9 :3 0
1789 28b3 28bb 28b0
28bd 28bc :2 0 67
:3 0 78 :3 0 28bf
28c0 0 69 :4 0
1ef :4 0 6c :2 0
6d :3 0 178d 28c4
28c6 :3 0 6c :2 0
81 :4 0 1790 28c8
28ca :3 0 6c :2 0
82 :4 0 1793 28cc
28ce :3 0 6c :2 0
71 :3 0 72 :3 0
83 :3 0 17d :3 0
28d3 28d4 0 1796
28d2 28d6 73 :4 0
1798 28d1 28d9 179b
28d0 28db :3 0 6c
:2 0 e4 :4 0 179e
28dd 28df :3 0 6c
:2 0 6f :4 0 17a1
28e1 28e3 :3 0 6c
:2 0 1d :3 0 17a4
28e5 28e7 :3 0 6c
:2 0 6f :4 0 17a7
28e9 28eb :3 0 17aa
28c1 28ed :2 0 28ef
17ad 28f0 28be 28ef
0 28f1 17af 0
291c 64 :3 0 65
:3 0 28f2 28f3 0
64 :3 0 75 :3 0
28f5 28f6 0 27
:2 0 2 :4 0 1f0
:2 0 77 :2 0 27
:2 0 17b1 28fb 28fd
:3 0 17b4 28f7 28ff
28f4 2901 2900 :2 0
67 :3 0 78 :3 0
2903 2904 0 69
:4 0 1f1 :4 0 6c
:2 0 6d :3 0 17b8
2908 290a :3 0 17bb
2905 290c :2 0 290e
17be 290f 2902 290e
0 2910 17c0 0
291c 87 :3 0 e7
:3 0 2911 2912 0
83 :3 0 17d :3 0
2914 2915 0 1d
:3 0 89 :3 0 17c2
2913 2919 :2 0 291c
ad :3 0 17c6 2a78
60 :3 0 83 :3 0
8e :2 0 1f2 :3 0
291e 2920 0 17cc
291f 2922 :3 0 64
:3 0 65 :3 0 2924
2925 0 64 :3 0
75 :3 0 2927 2928
0 18 :2 0 2
:4 0 1f3 :2 0 77
:2 0 27 :2 0 17cf
292d 292f :3 0 17d2
2929 2931 2926 2933
2932 :2 0 67 :3 0
78 :3 0 2935 2936
0 69 :4 0 1f4
:4 0 6c :2 0 6d
:3 0 17d6 293a 293c
:3 0 6c :2 0 81
:4 0 17d9 293e 2940
:3 0 6c :2 0 82
:4 0 17dc 2942 2944
:3 0 6c :2 0 71
:3 0 72 :3 0 83
:3 0 1f2 :3 0 2949
294a 0 17df 2948
294c 73 :4 0 17e1
2947 294f 17e4 2946
2951 :3 0 6c :2 0
e4 :4 0 17e7 2953
2955 :3 0 6c :2 0
6f :4 0 17ea 2957
2959 :3 0 6c :2 0
1d :3 0 17ed 295b
295d :3 0 6c :2 0
6f :4 0 17f0 295f
2961 :3 0 17f3 2937
2963 :2 0 2965 17f6
2966 2934 2965 0
2967 17f8 0 2992
64 :3 0 65 :3 0
2968 2969 0 64
:3 0 75 :3 0 296b
296c 0 27 :2 0
2 :4 0 1f5 :2 0
77 :2 0 27 :2 0
17fa 2971 2973 :3 0
17fd 296d 2975 296a
2977 2976 :2 0 67
:3 0 78 :3 0 2979
297a 0 69 :4 0
1f6 :4 0 6c :2 0
6d :3 0 1801 297e
2980 :3 0 1804 297b
2982 :2 0 2984 1807
2985 2978 2984 0
2986 1809 0 2992
87 :3 0 e7 :3 0
2987 2988 0 83
:3 0 1f2 :3 0 298a
298b 0 1d :3 0
89 :3 0 180b 2989
298f :2 0 2992 ad
:3 0 180f 2993 2923
2992 0 2a7a 60
:3 0 83 :3 0 8e
:2 0 1f7 :3 0 2995
2997 0 1815 2996
2999 :3 0 64 :3 0
65 :3 0 299b 299c
0 64 :3 0 75
:3 0 299e 299f 0
18 :2 0 2 :4 0
1f8 :2 0 77 :2 0
27 :2 0 1818 29a4
29a6 :3 0 181b 29a0
29a8 299d 29aa 29a9
:2 0 67 :3 0 78
:3 0 29ac 29ad 0
69 :4 0 1f9 :4 0
6c :2 0 6d :3 0
181f 29b1 29b3 :3 0
6c :2 0 81 :4 0
1822 29b5 29b7 :3 0
6c :2 0 82 :4 0
1825 29b9 29bb :3 0
6c :2 0 71 :3 0
72 :3 0 83 :3 0
1f7 :3 0 29c0 29c1
0 1828 29bf 29c3
73 :4 0 182a 29be
29c6 182d 29bd 29c8
:3 0 6c :2 0 e4
:4 0 1830 29ca 29cc
:3 0 6c :2 0 6f
:4 0 1833 29ce 29d0
:3 0 6c :2 0 1d
:3 0 1836 29d2 29d4
:3 0 6c :2 0 6f
:4 0 1839 29d6 29d8
:3 0 183c 29ae 29da
:2 0 29dc 183f 29dd
29ab 29dc 0 29de
1841 0 2a08 64
:3 0 65 :3 0 29df
29e0 0 64 :3 0
75 :3 0 29e2 29e3
0 27 :2 0 2
:4 0 1fa :2 0 77
:2 0 27 :2 0 1843
29e8 29ea :3 0 1846
29e4 29ec 29e1 29ee
29ed :2 0 67 :3 0
78 :3 0 29f0 29f1
0 69 :4 0 1fb
:4 0 6c :2 0 6d
:3 0 184a 29f5 29f7
:3 0 184d 29f2 29f9
:2 0 29fb 1850 29fc
29ef 29fb 0 29fd
1852 0 2a08 87
:3 0 e7 :3 0 29fe
29ff 0 83 :3 0
1f7 :3 0 2a01 2a02
0 1d :3 0 89
:3 0 1854 2a00 2a06
:2 0 2a08 1858 2a09
299a 2a08 0 2a7a
64 :3 0 65 :3 0
2a0a 2a0b 0 64
:3 0 75 :3 0 2a0d
2a0e 0 18 :2 0
2 :4 0 1fc :2 0
77 :2 0 27 :2 0
185c 2a13 2a15 :3 0
185f 2a0f 2a17 2a0c
2a19 2a18 :2 0 67
:3 0 78 :3 0 2a1b
2a1c 0 69 :4 0
1fd :4 0 6c :2 0
6d :3 0 1863 2a20
2a22 :3 0 6c :2 0
81 :4 0 1866 2a24
2a26 :3 0 6c :2 0
82 :4 0 1869 2a28
2a2a :3 0 6c :2 0
71 :3 0 72 :3 0
83 :3 0 158 :3 0
2a2f 2a30 0 186c
2a2e 2a32 73 :4 0
186e 2a2d 2a35 1871
2a2c 2a37 :3 0 6c
:2 0 e4 :4 0 1874
2a39 2a3b :3 0 6c
:2 0 6f :4 0 1877
2a3d 2a3f :3 0 6c
:2 0 28 :3 0 187a
2a41 2a43 :3 0 6c
:2 0 6f :4 0 187d
2a45 2a47 :3 0 1880
2a1d 2a49 :2 0 2a4b
1883 2a4c 2a1a 2a4b
0 2a4d 1885 0
2a77 64 :3 0 65
:3 0 2a4e 2a4f 0
64 :3 0 75 :3 0
2a51 2a52 0 27
:2 0 2 :4 0 1fe
:2 0 77 :2 0 27
:2 0 1887 2a57 2a59
:3 0 188a 2a53 2a5b
2a50 2a5d 2a5c :2 0
67 :3 0 78 :3 0
2a5f 2a60 0 69
:4 0 1ff :4 0 6c
:2 0 6d :3 0 188e
2a64 2a66 :3 0 1891
2a61 2a68 :2 0 2a6a
1894 2a6b 2a5e 2a6a
0 2a6c 1896 0
2a77 87 :3 0 e7
:3 0 2a6d 2a6e 0
83 :3 0 158 :3 0
2a70 2a71 0 28
:3 0 89 :3 0 1898
2a6f 2a75 :2 0 2a77
189c 2a79 28ad 291c
0 2a7a 0 2a77
0 2a7a 18a0 0
2a7b 18a5 2a7c 27ba
2a7b 0 2a7d 18a8
0 32eb 71 :3 0
1b3 :3 0 2b :3 0
18aa 2a7f 2a81 30
:2 0 18ac 2a7e 2a84
b1 :2 0 30 :2 0
18b1 2a86 2a88 :3 0
2a89 :2 0 71 :3 0
1b3 :3 0 2c :3 0
18b4 2a8c 2a8e 30
:2 0 18b6 2a8b 2a91
b1 :2 0 30 :2 0
18bb 2a93 2a95 :3 0
2a96 :2 0 2a8a 2a98
2a97 :2 0 200 :3 0
201 :3 0 202 :4 0
2a9c :4 0 2a9d :2 0
2db4 15 :3 0 9a
:3 0 2a9f 2aa0 0
30 :2 0 2aa1 2aa2
0 2db4 50 :3 0
203 :4 0 6c :2 0
204 :4 0 18be 2aa6
2aa8 :3 0 6c :2 0
205 :4 0 18c1 2aaa
2aac :3 0 6c :2 0
206 :4 0 18c4 2aae
2ab0 :3 0 6c :2 0
207 :4 0 18c7 2ab2
2ab4 :3 0 6c :2 0
208 :4 0 18ca 2ab6
2ab8 :3 0 6c :2 0
17 :3 0 18cd 2aba
2abc :3 0 6c :2 0
209 :4 0 18d0 2abe
2ac0 :3 0 6c :2 0
20a :4 0 18d3 2ac2
2ac4 :3 0 6c :2 0
2b :3 0 18d6 2ac6
2ac8 :3 0 6c :2 0
20b :4 0 18d9 2aca
2acc :3 0 6c :2 0
2c :3 0 18dc 2ace
2ad0 :3 0 6c :2 0
20c :4 0 18df 2ad2
2ad4 :3 0 2aa4 2ad5
0 2db4 200 :3 0
201 :3 0 50 :3 0
2ad9 :4 0 2ada :2 0
2af1 1ab :4 0 2adc
:3 0 89 :3 0 8e
:2 0 18e4 2adf 2ae0
:3 0 15 :3 0 9a
:3 0 2ae2 2ae3 0
30 :2 0 2ae4 2ae5
0 2ae7 18e7 2aee
15 :3 0 9a :3 0
2ae8 2ae9 0 118
:2 0 2aea 2aeb 0
2aed 18e9 2aef 2ae1
2ae7 0 2af0 0
2aed 0 2af0 18eb
0 2af1 18ee 2b4f
9c :3 0 15 :3 0
9a :3 0 2af3 2af4
0 9b :3 0 2af5
2af6 0 2af8 18f1
2afa 18f3 2af9 2af8
:2 0 2b4d 9d :3 0
15 :3 0 9a :3 0
2afd 2afe 0 9b
:3 0 2aff 2b00 0
2b45 64 :3 0 65
:3 0 2b02 2b03 0
64 :3 0 75 :3 0
2b05 2b06 0 9e
:2 0 2 :4 0 20d
:2 0 77 :2 0 27
:2 0 18f5 2b0b 2b0d
:3 0 18f8 2b07 2b0f
2b04 2b11 2b10 :2 0
67 :3 0 78 :3 0
2b13 2b14 0 69
:4 0 20e :4 0 6c
:2 0 6d :3 0 18fc
2b18 2b1a :3 0 6c
:2 0 81 :4 0 18ff
2b1c 2b1e :3 0 6c
:2 0 a1 :4 0 1902
2b20 2b22 :3 0 6c
:2 0 9b :3 0 1905
2b24 2b26 :3 0 6c
:2 0 a2 :4 0 1908
2b28 2b2a :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 190b 2b2d 2b31
190f 2b2c 2b33 :3 0
1912 2b15 2b35 :2 0
2b42 67 :3 0 78
:3 0 2b37 2b38 0
69 :4 0 20f :4 0
6c :2 0 50 :3 0
1915 2b3c 2b3e :3 0
1918 2b39 2b40 :2 0
2b42 191b 2b43 2b12
2b42 0 2b44 191e
0 2b45 1920 2b48
:3 0 2b48 0 2b48
2b47 2b45 2b46 :6 0
2b4a 67 :3 0 1923
2b4c 1925 2b4b 2b4a
:2 0 2b4d 1927 :2 0
2b4f 0 2b4f 2b4e
2af1 2b4d :6 0 2db4
1 :3 0 200 :3 0
201 :3 0 210 :4 0
2b53 :4 0 2b54 :2 0
2db4 15 :3 0 9a
:3 0 2b56 2b57 0
30 :2 0 2b58 2b59
0 2db4 50 :3 0
211 :4 0 6c :2 0
212 :4 0 192a 2b5d
2b5f :3 0 6c :2 0
213 :4 0 192d 2b61
2b63 :3 0 6c :2 0
214 :4 0 1930 2b65
2b67 :3 0 6c :2 0
215 :4 0 1933 2b69
2b6b :3 0 6c :2 0
216 :4 0 1936 2b6d
2b6f :3 0 6c :2 0
17 :3 0 1939 2b71
2b73 :3 0 6c :2 0
209 :4 0 193c 2b75
2b77 :3 0 6c :2 0
217 :4 0 193f 2b79
2b7b :3 0 6c :2 0
2b :3 0 1942 2b7d
2b7f :3 0 6c :2 0
20b :4 0 1945 2b81
2b83 :3 0 6c :2 0
2c :3 0 1948 2b85
2b87 :3 0 6c :2 0
218 :4 0 194b 2b89
2b8b :3 0 2b5b 2b8c
0 2db4 200 :3 0
201 :3 0 50 :3 0
2b90 :4 0 2b91 :2 0
2ba8 1ab :4 0 2b93
:3 0 89 :3 0 8e
:2 0 1950 2b96 2b97
:3 0 15 :3 0 9a
:3 0 2b99 2b9a 0
30 :2 0 2b9b 2b9c
0 2b9e 1953 2ba5
15 :3 0 9a :3 0
2b9f 2ba0 0 118
:2 0 2ba1 2ba2 0
2ba4 1955 2ba6 2b98
2b9e 0 2ba7 0
2ba4 0 2ba7 1957
0 2ba8 195a 2c06
9c :3 0 15 :3 0
9a :3 0 2baa 2bab
0 9b :3 0 2bac
2bad 0 2baf 195d
2bb1 195f 2bb0 2baf
:2 0 2c04 9d :3 0
15 :3 0 9a :3 0
2bb4 2bb5 0 9b
:3 0 2bb6 2bb7 0
2bfc 64 :3 0 65
:3 0 2bb9 2bba 0
64 :3 0 75 :3 0
2bbc 2bbd 0 9e
:2 0 2 :4 0 219
:2 0 77 :2 0 27
:2 0 1961 2bc2 2bc4
:3 0 1964 2bbe 2bc6
2bbb 2bc8 2bc7 :2 0
67 :3 0 78 :3 0
2bca 2bcb 0 69
:4 0 21a :4 0 6c
:2 0 6d :3 0 1968
2bcf 2bd1 :3 0 6c
:2 0 81 :4 0 196b
2bd3 2bd5 :3 0 6c
:2 0 a1 :4 0 196e
2bd7 2bd9 :3 0 6c
:2 0 9b :3 0 1971
2bdb 2bdd :3 0 6c
:2 0 a2 :4 0 1974
2bdf 2be1 :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 1977 2be4 2be8
197b 2be3 2bea :3 0
197e 2bcc 2bec :2 0
2bf9 67 :3 0 78
:3 0 2bee 2bef 0
69 :4 0 20f :4 0
6c :2 0 50 :3 0
1981 2bf3 2bf5 :3 0
1984 2bf0 2bf7 :2 0
2bf9 1987 2bfa 2bc9
2bf9 0 2bfb 198a
0 2bfc 198c 2bff
:3 0 2bff 0 2bff
2bfe 2bfc 2bfd :6 0
2c01 69 :3 0 198f
2c03 1991 2c02 2c01
:2 0 2c04 1993 :2 0
2c06 0 2c06 2c05
2ba8 2c04 :6 0 2db4
1 :3 0 15 :3 0
9a :3 0 2c08 2c09
0 21b :4 0 2c0b
2c0c :3 0 2c0a 2c0d
0 2db4 50 :3 0
21c :4 0 6c :2 0
21d :4 0 1996 2c11
2c13 :3 0 6c :2 0
21e :4 0 1999 2c15
2c17 :3 0 6c :2 0
21f :4 0 199c 2c19
2c1b :3 0 6c :2 0
220 :4 0 199f 2c1d
2c1f :3 0 6c :2 0
221 :4 0 19a2 2c21
2c23 :3 0 6c :2 0
222 :4 0 19a5 2c25
2c27 :3 0 6c :2 0
223 :4 0 19a8 2c29
2c2b :3 0 6c :2 0
224 :4 0 19ab 2c2d
2c2f :3 0 6c :2 0
225 :4 0 19ae 2c31
2c33 :3 0 6c :2 0
226 :4 0 19b1 2c35
2c37 :3 0 6c :2 0
227 :4 0 19b4 2c39
2c3b :3 0 6c :2 0
228 :4 0 19b7 2c3d
2c3f :3 0 6c :2 0
17 :3 0 19ba 2c41
2c43 :3 0 6c :2 0
229 :4 0 19bd 2c45
2c47 :3 0 6c :2 0
22a :4 0 19c0 2c49
2c4b :3 0 6c :2 0
17 :3 0 19c3 2c4d
2c4f :3 0 6c :2 0
22b :4 0 19c6 2c51
2c53 :3 0 6c :2 0
22c :4 0 19c9 2c55
2c57 :3 0 6c :2 0
22d :4 0 19cc 2c59
2c5b :3 0 6c :2 0
2b :3 0 19cf 2c5d
2c5f :3 0 6c :2 0
22e :4 0 19d2 2c61
2c63 :3 0 6c :2 0
22f :4 0 19d5 2c65
2c67 :3 0 6c :2 0
230 :4 0 19d8 2c69
2c6b :3 0 6c :2 0
231 :4 0 19db 2c6d
2c6f :3 0 6c :2 0
232 :4 0 19de 2c71
2c73 :3 0 6c :2 0
225 :4 0 19e1 2c75
2c77 :3 0 6c :2 0
233 :4 0 19e4 2c79
2c7b :3 0 6c :2 0
234 :4 0 19e7 2c7d
2c7f :3 0 6c :2 0
235 :4 0 19ea 2c81
2c83 :3 0 6c :2 0
17 :3 0 19ed 2c85
2c87 :3 0 6c :2 0
236 :4 0 19f0 2c89
2c8b :3 0 6c :2 0
237 :4 0 19f3 2c8d
2c8f :3 0 6c :2 0
238 :4 0 19f6 2c91
2c93 :3 0 6c :2 0
239 :4 0 19f9 2c95
2c97 :3 0 6c :2 0
23a :4 0 19fc 2c99
2c9b :3 0 6c :2 0
2c :3 0 19ff 2c9d
2c9f :3 0 6c :2 0
22e :4 0 1a02 2ca1
2ca3 :3 0 6c :2 0
23b :4 0 1a05 2ca5
2ca7 :3 0 2c0f 2ca8
0 2db4 200 :3 0
201 :3 0 50 :3 0
2cac :4 0 2cad :2 0
2cc4 1ab :4 0 2caf
:3 0 89 :3 0 8e
:2 0 1a0a 2cb2 2cb3
:3 0 15 :3 0 9a
:3 0 2cb5 2cb6 0
30 :2 0 2cb7 2cb8
0 2cba 1a0d 2cc1
15 :3 0 9a :3 0
2cbb 2cbc 0 118
:2 0 2cbd 2cbe 0
2cc0 1a0f 2cc2 2cb4
2cba 0 2cc3 0
2cc0 0 2cc3 1a11
0 2cc4 1a14 2d22
9c :3 0 15 :3 0
9a :3 0 2cc6 2cc7
0 9b :3 0 2cc8
2cc9 0 2ccb 1a17
2ccd 1a19 2ccc 2ccb
:2 0 2d20 9d :3 0
15 :3 0 9a :3 0
2cd0 2cd1 0 9b
:3 0 2cd2 2cd3 0
2d18 64 :3 0 65
:3 0 2cd5 2cd6 0
64 :3 0 75 :3 0
2cd8 2cd9 0 9e
:2 0 2 :4 0 23c
:2 0 77 :2 0 27
:2 0 1a1b 2cde 2ce0
:3 0 1a1e 2cda 2ce2
2cd7 2ce4 2ce3 :2 0
67 :3 0 78 :3 0
2ce6 2ce7 0 69
:4 0 23d :4 0 6c
:2 0 6d :3 0 1a22
2ceb 2ced :3 0 6c
:2 0 81 :4 0 1a25
2cef 2cf1 :3 0 6c
:2 0 a1 :4 0 1a28
2cf3 2cf5 :3 0 6c
:2 0 9b :3 0 1a2b
2cf7 2cf9 :3 0 6c
:2 0 a2 :4 0 1a2e
2cfb 2cfd :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 1a31 2d00 2d04
1a35 2cff 2d06 :3 0
1a38 2ce8 2d08 :2 0
2d15 67 :3 0 78
:3 0 2d0a 2d0b 0
69 :4 0 20f :4 0
6c :2 0 50 :3 0
1a3b 2d0f 2d11 :3 0
1a3e 2d0c 2d13 :2 0
2d15 1a41 2d16 2ce5
2d15 0 2d17 1a44
0 2d18 1a46 2d1b
:3 0 2d1b 0 2d1b
2d1a 2d18 2d19 :6 0
2d1d 6b :3 0 1a49
2d1f 1a4b 2d1e 2d1d
:2 0 2d20 1a4d :2 0
2d22 0 2d22 2d21
2cc4 2d20 :6 0 2db4
1 :3 0 50 :3 0
23e :4 0 6c :2 0
23f :4 0 1a50 2d26
2d28 :3 0 6c :2 0
240 :4 0 1a53 2d2a
2d2c :3 0 6c :2 0
241 :4 0 1a56 2d2e
2d30 :3 0 6c :2 0
72 :3 0 71 :3 0
38 :3 0 30 :2 0
1a59 2d34 2d37 1a5c
2d33 2d39 1a5e 2d32
2d3b :3 0 6c :2 0
242 :4 0 1a61 2d3d
2d3f :3 0 6c :2 0
81 :4 0 1a64 2d41
2d43 :3 0 6c :2 0
72 :3 0 71 :3 0
3d :3 0 30 :2 0
1a67 2d47 2d4a 1a6a
2d46 2d4c 1a6c 2d45
2d4e :3 0 6c :2 0
243 :4 0 1a6f 2d50
2d52 :3 0 6c :2 0
244 :4 0 1a72 2d54
2d56 :3 0 6c :2 0
245 :4 0 1a75 2d58
2d5a :3 0 6c :2 0
246 :4 0 1a78 2d5c
2d5e :3 0 6c :2 0
247 :4 0 1a7b 2d60
2d62 :3 0 6c :2 0
248 :4 0 1a7e 2d64
2d66 :3 0 6c :2 0
249 :4 0 1a81 2d68
2d6a :3 0 6c :2 0
24a :4 0 1a84 2d6c
2d6e :3 0 6c :2 0
24b :4 0 1a87 2d70
2d72 :3 0 6c :2 0
24c :4 0 1a8a 2d74
2d76 :3 0 6c :2 0
24d :4 0 1a8d 2d78
2d7a :3 0 6c :2 0
72 :3 0 71 :3 0
38 :3 0 30 :2 0
1a90 2d7e 2d81 1a93
2d7d 2d83 1a95 2d7c
2d85 :3 0 6c :2 0
24e :4 0 1a98 2d87
2d89 :3 0 6c :2 0
24f :4 0 1a9b 2d8b
2d8d :3 0 6c :2 0
72 :3 0 71 :3 0
3d :3 0 30 :2 0
1a9e 2d91 2d94 1aa1
2d90 2d96 1aa3 2d8f
2d98 :3 0 6c :2 0
250 :4 0 1aa6 2d9a
2d9c :3 0 6c :2 0
251 :4 0 1aa9 2d9e
2da0 :3 0 6c :2 0
252 :4 0 1aac 2da2
2da4 :3 0 6c :2 0
253 :4 0 1aaf 2da6
2da8 :3 0 6c :2 0
254 :4 0 1ab2 2daa
2dac :3 0 6c :2 0
255 :4 0 1ab5 2dae
2db0 :3 0 2d24 2db1
0 2db4 ad :3 0
1ab8 32a2 71 :3 0
1b3 :3 0 2c :3 0
1ac5 2db6 2db8 30
:2 0 1ac7 2db5 2dbb
8e :2 0 30 :2 0
1acc 2dbd 2dbf :3 0
200 :3 0 201 :3 0
256 :4 0 2dc3 :4 0
2dc4 :2 0 302c 15
:3 0 9a :3 0 2dc6
2dc7 0 30 :2 0
2dc8 2dc9 0 302c
50 :3 0 257 :4 0
6c :2 0 258 :4 0
1acf 2dcd 2dcf :3 0
6c :2 0 259 :4 0
1ad2 2dd1 2dd3 :3 0
6c :2 0 25a :4 0
1ad5 2dd5 2dd7 :3 0
6c :2 0 25b :4 0
1ad8 2dd9 2ddb :3 0
6c :2 0 208 :4 0
1adb 2ddd 2ddf :3 0
6c :2 0 17 :3 0
1ade 2de1 2de3 :3 0
6c :2 0 209 :4 0
1ae1 2de5 2de7 :3 0
6c :2 0 25c :4 0
1ae4 2de9 2deb :3 0
6c :2 0 2b :3 0
1ae7 2ded 2def :3 0
6c :2 0 25d :4 0
1aea 2df1 2df3 :3 0
2dcb 2df4 0 302c
200 :3 0 201 :3 0
50 :3 0 2df8 :4 0
2df9 :2 0 2e10 1ab
:4 0 2dfb :3 0 89
:3 0 8e :2 0 1aef
2dfe 2dff :3 0 15
:3 0 9a :3 0 2e01
2e02 0 30 :2 0
2e03 2e04 0 2e06
1af2 2e0d 15 :3 0
9a :3 0 2e07 2e08
0 118 :2 0 2e09
2e0a 0 2e0c 1af4
2e0e 2e00 2e06 0
2e0f 0 2e0c 0
2e0f 1af6 0 2e10
1af9 2e6e 9c :3 0
15 :3 0 9a :3 0
2e12 2e13 0 9b
:3 0 2e14 2e15 0
2e17 1afc 2e19 1afe
2e18 2e17 :2 0 2e6c
9d :3 0 15 :3 0
9a :3 0 2e1c 2e1d
0 9b :3 0 2e1e
2e1f 0 2e64 64
:3 0 65 :3 0 2e21
2e22 0 64 :3 0
75 :3 0 2e24 2e25
0 9e :2 0 2
:4 0 25e :2 0 77
:2 0 27 :2 0 1b00
2e2a 2e2c :3 0 1b03
2e26 2e2e 2e23 2e30
2e2f :2 0 67 :3 0
78 :3 0 2e32 2e33
0 69 :4 0 25f
:4 0 6c :2 0 6d
:3 0 1b07 2e37 2e39
:3 0 6c :2 0 81
:4 0 1b0a 2e3b 2e3d
:3 0 6c :2 0 a1
:4 0 1b0d 2e3f 2e41
:3 0 6c :2 0 9b
:3 0 1b10 2e43 2e45
:3 0 6c :2 0 a2
:4 0 1b13 2e47 2e49
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 1b16
2e4c 2e50 1b1a 2e4b
2e52 :3 0 1b1d 2e34
2e54 :2 0 2e61 67
:3 0 78 :3 0 2e56
2e57 0 69 :4 0
20f :4 0 6c :2 0
50 :3 0 1b20 2e5b
2e5d :3 0 1b23 2e58
2e5f :2 0 2e61 1b26
2e62 2e31 2e61 0
2e63 1b29 0 2e64
1b2b 2e67 :3 0 2e67
0 2e67 2e66 2e64
2e65 :6 0 2e69 6d
:3 0 1b2e 2e6b 1b30
2e6a 2e69 :2 0 2e6c
1b32 :2 0 2e6e 0
2e6e 2e6d 2e10 2e6c
:6 0 302c 1 :3 0
200 :3 0 201 :3 0
210 :4 0 2e72 :4 0
2e73 :2 0 302c 15
:3 0 9a :3 0 2e75
2e76 0 30 :2 0
2e77 2e78 0 302c
50 :3 0 260 :4 0
6c :2 0 261 :4 0
1b35 2e7c 2e7e :3 0
6c :2 0 262 :4 0
1b38 2e80 2e82 :3 0
6c :2 0 263 :4 0
1b3b 2e84 2e86 :3 0
6c :2 0 264 :4 0
1b3e 2e88 2e8a :3 0
6c :2 0 265 :4 0
1b41 2e8c 2e8e :3 0
6c :2 0 17 :3 0
1b44 2e90 2e92 :3 0
6c :2 0 266 :4 0
1b47 2e94 2e96 :3 0
6c :2 0 2b :3 0
1b4a 2e98 2e9a :3 0
6c :2 0 267 :4 0
1b4d 2e9c 2e9e :3 0
2e7a 2e9f 0 302c
200 :3 0 201 :3 0
50 :3 0 2ea3 :4 0
2ea4 :2 0 2ebb 1ab
:4 0 2ea6 :3 0 89
:3 0 8e :2 0 1b52
2ea9 2eaa :3 0 15
:3 0 9a :3 0 2eac
2ead 0 30 :2 0
2eae 2eaf 0 2eb1
1b55 2eb8 15 :3 0
9a :3 0 2eb2 2eb3
0 118 :2 0 2eb4
2eb5 0 2eb7 1b57
2eb9 2eab 2eb1 0
2eba 0 2eb7 0
2eba 1b59 0 2ebb
1b5c 2f19 9c :3 0
15 :3 0 9a :3 0
2ebd 2ebe 0 9b
:3 0 2ebf 2ec0 0
2ec2 1b5f 2ec4 1b61
2ec3 2ec2 :2 0 2f17
9d :3 0 15 :3 0
9a :3 0 2ec7 2ec8
0 9b :3 0 2ec9
2eca 0 2f0f 64
:3 0 65 :3 0 2ecc
2ecd 0 64 :3 0
75 :3 0 2ecf 2ed0
0 9e :2 0 2
:4 0 268 :2 0 77
:2 0 27 :2 0 1b63
2ed5 2ed7 :3 0 1b66
2ed1 2ed9 2ece 2edb
2eda :2 0 67 :3 0
78 :3 0 2edd 2ede
0 69 :4 0 269
:4 0 6c :2 0 6d
:3 0 1b6a 2ee2 2ee4
:3 0 6c :2 0 81
:4 0 1b6d 2ee6 2ee8
:3 0 6c :2 0 a1
:4 0 1b70 2eea 2eec
:3 0 6c :2 0 9b
:3 0 1b73 2eee 2ef0
:3 0 6c :2 0 a2
:4 0 1b76 2ef2 2ef4
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 1b79
2ef7 2efb 1b7d 2ef6
2efd :3 0 1b80 2edf
2eff :2 0 2f0c 67
:3 0 78 :3 0 2f01
2f02 0 69 :4 0
20f :4 0 6c :2 0
50 :3 0 1b83 2f06
2f08 :3 0 1b86 2f03
2f0a :2 0 2f0c 1b89
2f0d 2edc 2f0c 0
2f0e 1b8c 0 2f0f
1b8e 2f12 :3 0 2f12
0 2f12 2f11 2f0f
2f10 :6 0 2f14 6f
:3 0 1b91 2f16 1b93
2f15 2f14 :2 0 2f17
1b95 :2 0 2f19 0
2f19 2f18 2ebb 2f17
:6 0 302c 1 :3 0
15 :3 0 9a :3 0
2f1b 2f1c 0 21b
:4 0 2f1e 2f1f :3 0
2f1d 2f20 0 302c
50 :3 0 21c :4 0
6c :2 0 26a :4 0
1b98 2f24 2f26 :3 0
6c :2 0 21f :4 0
1b9b 2f28 2f2a :3 0
6c :2 0 26b :4 0
1b9e 2f2c 2f2e :3 0
6c :2 0 26c :4 0
1ba1 2f30 2f32 :3 0
6c :2 0 223 :4 0
1ba4 2f34 2f36 :3 0
6c :2 0 26d :4 0
1ba7 2f38 2f3a :3 0
6c :2 0 226 :4 0
1baa 2f3c 2f3e :3 0
6c :2 0 26e :4 0
1bad 2f40 2f42 :3 0
6c :2 0 228 :4 0
1bb0 2f44 2f46 :3 0
6c :2 0 17 :3 0
1bb3 2f48 2f4a :3 0
6c :2 0 229 :4 0
1bb6 2f4c 2f4e :3 0
6c :2 0 22a :4 0
1bb9 2f50 2f52 :3 0
6c :2 0 17 :3 0
1bbc 2f54 2f56 :3 0
6c :2 0 22b :4 0
1bbf 2f58 2f5a :3 0
6c :2 0 22c :4 0
1bc2 2f5c 2f5e :3 0
6c :2 0 26f :4 0
1bc5 2f60 2f62 :3 0
6c :2 0 2b :3 0
1bc8 2f64 2f66 :3 0
6c :2 0 270 :4 0
1bcb 2f68 2f6a :3 0
2f22 2f6b 0 302c
200 :3 0 201 :3 0
50 :3 0 2f6f :4 0
2f70 :2 0 2f87 1ab
:4 0 2f72 :3 0 89
:3 0 8e :2 0 1bd0
2f75 2f76 :3 0 15
:3 0 9a :3 0 2f78
2f79 0 30 :2 0
2f7a 2f7b 0 2f7d
1bd3 2f84 15 :3 0
9a :3 0 2f7e 2f7f
0 118 :2 0 2f80
2f81 0 2f83 1bd5
2f85 2f77 2f7d 0
2f86 0 2f83 0
2f86 1bd7 0 2f87
1bda 2fe5 9c :3 0
15 :3 0 9a :3 0
2f89 2f8a 0 9b
:3 0 2f8b 2f8c 0
2f8e 1bdd 2f90 1bdf
2f8f 2f8e :2 0 2fe3
9d :3 0 15 :3 0
9a :3 0 2f93 2f94
0 9b :3 0 2f95
2f96 0 2fdb 64
:3 0 65 :3 0 2f98
2f99 0 64 :3 0
75 :3 0 2f9b 2f9c
0 9e :2 0 2
:4 0 271 :2 0 77
:2 0 27 :2 0 1be1
2fa1 2fa3 :3 0 1be4
2f9d 2fa5 2f9a 2fa7
2fa6 :2 0 67 :3 0
78 :3 0 2fa9 2faa
0 69 :4 0 272
:4 0 6c :2 0 6d
:3 0 1be8 2fae 2fb0
:3 0 6c :2 0 81
:4 0 1beb 2fb2 2fb4
:3 0 6c :2 0 a1
:4 0 1bee 2fb6 2fb8
:3 0 6c :2 0 9b
:3 0 1bf1 2fba 2fbc
:3 0 6c :2 0 a2
:4 0 1bf4 2fbe 2fc0
:3 0 6c :2 0 a3
:3 0 a4 :3 0 27
:2 0 a5 :2 0 1bf7
2fc3 2fc7 1bfb 2fc2
2fc9 :3 0 1bfe 2fab
2fcb :2 0 2fd8 67
:3 0 78 :3 0 2fcd
2fce 0 69 :4 0
20f :4 0 6c :2 0
50 :3 0 1c01 2fd2
2fd4 :3 0 1c04 2fcf
2fd6 :2 0 2fd8 1c07
2fd9 2fa8 2fd8 0
2fda 1c0a 0 2fdb
1c0c 2fde :3 0 2fde
0 2fde 2fdd 2fdb
2fdc :6 0 2fe0 71
:3 0 1c0f 2fe2 1c11
2fe1 2fe0 :2 0 2fe3
1c13 :2 0 2fe5 0
2fe5 2fe4 2f87 2fe3
:6 0 302c 1 :3 0
50 :3 0 273 :4 0
6c :2 0 274 :4 0
1c16 2fe9 2feb :3 0
6c :2 0 275 :4 0
1c19 2fed 2fef :3 0
6c :2 0 276 :4 0
1c1c 2ff1 2ff3 :3 0
6c :2 0 72 :3 0
71 :3 0 38 :3 0
30 :2 0 1c1f 2ff7
2ffa 1c22 2ff6 2ffc
1c24 2ff5 2ffe :3 0
6c :2 0 277 :4 0
1c27 3000 3002 :3 0
6c :2 0 72 :3 0
71 :3 0 3d :3 0
30 :2 0 1c2a 3006
3009 1c2d 3005 300b
1c2f 3004 300d :3 0
6c :2 0 278 :4 0
1c32 300f 3011 :3 0
6c :2 0 244 :4 0
1c35 3013 3015 :3 0
6c :2 0 279 :4 0
1c38 3017 3019 :3 0
6c :2 0 27a :4 0
1c3b 301b 301d :3 0
6c :2 0 247 :4 0
1c3e 301f 3021 :3 0
6c :2 0 27b :4 0
1c41 3023 3025 :3 0
6c :2 0 27c :4 0
1c44 3027 3029 :3 0
2fe7 302a 0 302c
1c47 302d 2dc0 302c
0 32a4 200 :3 0
201 :3 0 256 :4 0
3030 :4 0 3031 :2 0
32a1 15 :3 0 9a
:3 0 3033 3034 0
30 :2 0 3035 3036
0 32a1 50 :3 0
257 :4 0 6c :2 0
27d :4 0 1c54 303a
303c :3 0 6c :2 0
27e :4 0 1c57 303e
3040 :3 0 6c :2 0
27f :4 0 1c5a 3042
3044 :3 0 6c :2 0
280 :4 0 1c5d 3046
3048 :3 0 6c :2 0
215 :4 0 1c60 304a
304c :3 0 6c :2 0
281 :4 0 1c63 304e
3050 :3 0 6c :2 0
17 :3 0 1c66 3052
3054 :3 0 6c :2 0
282 :4 0 1c69 3056
3058 :3 0 6c :2 0
283 :4 0 1c6c 305a
305c :3 0 6c :2 0
2c :3 0 1c6f 305e
3060 :3 0 6c :2 0
284 :4 0 1c72 3062
3064 :3 0 6c :2 0
285 :4 0 1c75 3066
3068 :3 0 3038 3069
0 32a1 200 :3 0
201 :3 0 50 :3 0
306d :4 0 306e :2 0
3085 1ab :4 0 3070
:3 0 89 :3 0 8e
:2 0 1c7a 3073 3074
:3 0 15 :3 0 9a
:3 0 3076 3077 0
30 :2 0 3078 3079
0 307b 1c7d 3082
15 :3 0 9a :3 0
307c 307d 0 118
:2 0 307e 307f 0
3081 1c7f 3083 3075
307b 0 3084 0
3081 0 3084 1c81
0 3085 1c84 30e3
9c :3 0 15 :3 0
9a :3 0 3087 3088
0 9b :3 0 3089
308a 0 308c 1c87
308e 1c89 308d 308c
:2 0 30e1 9d :3 0
15 :3 0 9a :3 0
3091 3092 0 9b
:3 0 3093 3094 0
30d9 64 :3 0 65
:3 0 3096 3097 0
64 :3 0 75 :3 0
3099 309a 0 9e
:2 0 2 :4 0 286
:2 0 77 :2 0 27
:2 0 1c8b 309f 30a1
:3 0 1c8e 309b 30a3
3098 30a5 30a4 :2 0
67 :3 0 78 :3 0
30a7 30a8 0 69
:4 0 287 :4 0 6c
:2 0 6d :3 0 1c92
30ac 30ae :3 0 6c
:2 0 81 :4 0 1c95
30b0 30b2 :3 0 6c
:2 0 a1 :4 0 1c98
30b4 30b6 :3 0 6c
:2 0 9b :3 0 1c9b
30b8 30ba :3 0 6c
:2 0 a2 :4 0 1c9e
30bc 30be :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 1ca1 30c1 30c5
1ca5 30c0 30c7 :3 0
1ca8 30a9 30c9 :2 0
30d6 67 :3 0 78
:3 0 30cb 30cc 0
69 :4 0 20f :4 0
6c :2 0 50 :3 0
1cab 30d0 30d2 :3 0
1cae 30cd 30d4 :2 0
30d6 1cb1 30d7 30a6
30d6 0 30d8 1cb4
0 30d9 1cb6 30dc
:3 0 30dc 0 30dc
30db 30d9 30da :6 0
30de 73 :3 0 1cb9
30e0 1cbb 30df 30de
:2 0 30e1 1cbd :2 0
30e3 0 30e3 30e2
3085 30e1 :6 0 32a1
1 :3 0 200 :3 0
201 :3 0 210 :4 0
30e7 :4 0 30e8 :2 0
32a1 15 :3 0 9a
:3 0 30ea 30eb 0
30 :2 0 30ec 30ed
0 32a1 50 :3 0
260 :4 0 6c :2 0
288 :4 0 1cc0 30f1
30f3 :3 0 6c :2 0
289 :4 0 1cc3 30f5
30f7 :3 0 6c :2 0
28a :4 0 1cc6 30f9
30fb :3 0 6c :2 0
28b :4 0 1cc9 30fd
30ff :3 0 6c :2 0
265 :4 0 1ccc 3101
3103 :3 0 6c :2 0
17 :3 0 1ccf 3105
3107 :3 0 6c :2 0
266 :4 0 1cd2 3109
310b :3 0 6c :2 0
2c :3 0 1cd5 310d
310f :3 0 6c :2 0
28c :4 0 1cd8 3111
3113 :3 0 30ef 3114
0 32a1 200 :3 0
201 :3 0 50 :3 0
3118 :4 0 3119 :2 0
3130 1ab :4 0 311b
:3 0 89 :3 0 8e
:2 0 1cdd 311e 311f
:3 0 15 :3 0 9a
:3 0 3121 3122 0
30 :2 0 3123 3124
0 3126 1ce0 312d
15 :3 0 9a :3 0
3127 3128 0 118
:2 0 3129 312a 0
312c 1ce2 312e 3120
3126 0 312f 0
312c 0 312f 1ce4
0 3130 1ce7 318e
9c :3 0 15 :3 0
9a :3 0 3132 3133
0 9b :3 0 3134
3135 0 3137 1cea
3139 1cec 3138 3137
:2 0 318c 9d :3 0
15 :3 0 9a :3 0
313c 313d 0 9b
:3 0 313e 313f 0
3184 64 :3 0 65
:3 0 3141 3142 0
64 :3 0 75 :3 0
3144 3145 0 9e
:2 0 2 :4 0 28d
:2 0 77 :2 0 27
:2 0 1cee 314a 314c
:3 0 1cf1 3146 314e
3143 3150 314f :2 0
67 :3 0 78 :3 0
3152 3153 0 69
:4 0 28e :4 0 6c
:2 0 6d :3 0 1cf5
3157 3159 :3 0 6c
:2 0 81 :4 0 1cf8
315b 315d :3 0 6c
:2 0 a1 :4 0 1cfb
315f 3161 :3 0 6c
:2 0 9b :3 0 1cfe
3163 3165 :3 0 6c
:2 0 a2 :4 0 1d01
3167 3169 :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 1d04 316c 3170
1d08 316b 3172 :3 0
1d0b 3154 3174 :2 0
3181 67 :3 0 78
:3 0 3176 3177 0
69 :4 0 20f :4 0
6c :2 0 50 :3 0
1d0e 317b 317d :3 0
1d11 3178 317f :2 0
3181 1d14 3182 3151
3181 0 3183 1d17
0 3184 1d19 3187
:3 0 3187 0 3187
3186 3184 3185 :6 0
3189 75 :3 0 1d1c
318b 1d1e 318a 3189
:2 0 318c 1d20 :2 0
318e 0 318e 318d
3130 318c :6 0 32a1
1 :3 0 15 :3 0
9a :3 0 3190 3191
0 21b :4 0 3193
3194 :3 0 3192 3195
0 32a1 50 :3 0
21c :4 0 6c :2 0
26a :4 0 1d23 3199
319b :3 0 6c :2 0
21f :4 0 1d26 319d
319f :3 0 6c :2 0
28f :4 0 1d29 31a1
31a3 :3 0 6c :2 0
290 :4 0 1d2c 31a5
31a7 :3 0 6c :2 0
291 :4 0 1d2f 31a9
31ab :3 0 6c :2 0
225 :4 0 1d32 31ad
31af :3 0 6c :2 0
292 :4 0 1d35 31b1
31b3 :3 0 6c :2 0
293 :4 0 1d38 31b5
31b7 :3 0 6c :2 0
228 :4 0 1d3b 31b9
31bb :3 0 6c :2 0
17 :3 0 1d3e 31bd
31bf :3 0 6c :2 0
236 :4 0 1d41 31c1
31c3 :3 0 6c :2 0
294 :4 0 1d44 31c5
31c7 :3 0 6c :2 0
239 :4 0 1d47 31c9
31cb :3 0 6c :2 0
23a :4 0 1d4a 31cd
31cf :3 0 6c :2 0
2c :3 0 1d4d 31d1
31d3 :3 0 6c :2 0
270 :4 0 1d50 31d5
31d7 :3 0 3197 31d8
0 32a1 200 :3 0
201 :3 0 50 :3 0
31dc :4 0 31dd :2 0
31f4 1ab :4 0 31df
:3 0 89 :3 0 8e
:2 0 1d55 31e2 31e3
:3 0 15 :3 0 9a
:3 0 31e5 31e6 0
30 :2 0 31e7 31e8
0 31ea 1d58 31f1
15 :3 0 9a :3 0
31eb 31ec 0 118
:2 0 31ed 31ee 0
31f0 1d5a 31f2 31e4
31ea 0 31f3 0
31f0 0 31f3 1d5c
0 31f4 1d5f 3252
9c :3 0 15 :3 0
9a :3 0 31f6 31f7
0 9b :3 0 31f8
31f9 0 31fb 1d62
31fd 1d64 31fc 31fb
:2 0 3250 9d :3 0
15 :3 0 9a :3 0
3200 3201 0 9b
:3 0 3202 3203 0
3248 64 :3 0 65
:3 0 3205 3206 0
64 :3 0 75 :3 0
3208 3209 0 9e
:2 0 2 :4 0 295
:2 0 77 :2 0 27
:2 0 1d66 320e 3210
:3 0 1d69 320a 3212
3207 3214 3213 :2 0
67 :3 0 78 :3 0
3216 3217 0 69
:4 0 296 :4 0 6c
:2 0 6d :3 0 1d6d
321b 321d :3 0 6c
:2 0 81 :4 0 1d70
321f 3221 :3 0 6c
:2 0 a1 :4 0 1d73
3223 3225 :3 0 6c
:2 0 9b :3 0 1d76
3227 3229 :3 0 6c
:2 0 a2 :4 0 1d79
322b 322d :3 0 6c
:2 0 a3 :3 0 a4
:3 0 27 :2 0 a5
:2 0 1d7c 3230 3234
1d80 322f 3236 :3 0
1d83 3218 3238 :2 0
3245 67 :3 0 78
:3 0 323a 323b 0
69 :4 0 20f :4 0
6c :2 0 50 :3 0
1d86 323f 3241 :3 0
1d89 323c 3243 :2 0
3245 1d8c 3246 3215
3245 0 3247 1d8f
0 3248 1d91 324b
:3 0 324b 0 324b
324a 3248 3249 :6 0
324d 77 :3 0 1d94
324f 1d96 324e 324d
:2 0 3250 1d98 :2 0
3252 0 3252 3251
31f4 3250 :6 0 32a1
1 :3 0 50 :3 0
297 :4 0 6c :2 0
274 :4 0 1d9b 3256
3258 :3 0 6c :2 0
298 :4 0 1d9e 325a
325c :3 0 6c :2 0
299 :4 0 1da1 325e
3260 :3 0 6c :2 0
72 :3 0 71 :3 0
38 :3 0 30 :2 0
1da4 3264 3267 1da7
3263 3269 1da9 3262
326b :3 0 6c :2 0
24e :4 0 1dac 326d
326f :3 0 6c :2 0
29a :4 0 1daf 3271
3273 :3 0 6c :2 0
72 :3 0 71 :3 0
3d :3 0 30 :2 0
1db2 3277 327a 1db5
3276 327c 1db7 3275
327e :3 0 6c :2 0
29b :4 0 1dba 3280
3282 :3 0 6c :2 0
29c :4 0 1dbd 3284
3286 :3 0 6c :2 0
244 :4 0 1dc0 3288
328a :3 0 6c :2 0
279 :4 0 1dc3 328c
328e :3 0 6c :2 0
29d :4 0 1dc6 3290
3292 :3 0 6c :2 0
29e :4 0 1dc9 3294
3296 :3 0 6c :2 0
29f :4 0 1dcc 3298
329a :3 0 6c :2 0
2a0 :4 0 1dcf 329c
329e :3 0 3254 329f
0 32a1 1dd2 32a3
2a99 2db4 0 32a4
0 32a1 0 32a4
1ddf 0 32eb 64
:3 0 65 :3 0 32a5
32a6 0 64 :3 0
75 :3 0 32a8 32a9
0 27 :2 0 2
:4 0 2a1 :2 0 77
:2 0 27 :2 0 1de3
32ae 32b0 :3 0 1de6
32aa 32b2 32a7 32b4
32b3 :2 0 67 :3 0
78 :3 0 32b6 32b7
0 69 :4 0 2a2
:4 0 6c :2 0 6d
:3 0 1dea 32bb 32bd
:3 0 1ded 32b8 32bf
:2 0 32c1 1df0 32c2
32b5 32c1 0 32c3
1df2 0 32eb 64
:3 0 65 :3 0 32c4
32c5 0 64 :3 0
75 :3 0 32c7 32c8
0 27 :2 0 2
:4 0 2a3 :2 0 77
:2 0 27 :2 0 1df4
32cd 32cf :3 0 1df7
32c9 32d1 32c6 32d3
32d2 :2 0 67 :3 0
78 :3 0 32d5 32d6
0 69 :4 0 2a4
:4 0 6c :2 0 6d
:3 0 1dfb 32da 32dc
:3 0 1dfe 32d7 32de
:2 0 32e0 1e01 32e1
32d4 32e0 0 32e2
1e03 0 32eb 14
:3 0 87 :3 0 2a5
:3 0 32e4 32e5 0
50 :3 0 1e05 32e6
32e8 32e9 :2 0 32eb
1e07 338c 15 :3 0
2a6 :2 0 4 32ec
32ed 0 64 :3 0
65 :3 0 32ef 32f0
0 64 :3 0 75
:3 0 32f2 32f3 0
9e :2 0 2 :4 0
2a7 :2 0 77 :2 0
27 :2 0 1e35 32f8
32fa :3 0 1e38 32f4
32fc 32f1 32fe 32fd
:2 0 67 :3 0 78
:3 0 3300 3301 0
69 :4 0 2a8 :4 0
6c :2 0 6d :3 0
1e3c 3305 3307 :3 0
1e3f 3302 3309 :2 0
3322 67 :3 0 78
:3 0 330b 330c 0
69 :4 0 2a9 :4 0
6c :2 0 15 :3 0
2aa :3 0 3311 3312
0 1e42 3310 3314
:3 0 6c :2 0 e4
:4 0 1e45 3316 3318
:3 0 6c :2 0 15
:3 0 2ab :3 0 331b
331c 0 1e48 331a
331e :3 0 1e4b 330d
3320 :2 0 3322 1e4e
3323 32ff 3322 0
3324 1e51 0 3334
2ac :3 0 63 :3 0
15 :3 0 2aa :3 0
2ad :3 0 15 :3 0
2ab :3 0 2ae :3 0
98 :4 0 2af 1
:a 0 3330 :2 0 3334
3326 332e :2 0 14
:3 0 63 :3 0 3332
:2 0 3334 1e53 3336
1e57 3335 3334 :2 0
338a 9d :3 0 15
:3 0 9a :3 0 3339
333a 0 9b :3 0
333b 333c 0 3382
64 :3 0 65 :3 0
333e 333f 0 64
:3 0 75 :3 0 3341
3342 0 9e :2 0
2 :4 0 2b0 :2 0
77 :2 0 27 :2 0
1e59 3347 3349 :3 0
1e5c 3343 334b 3340
334d 334c :2 0 67
:3 0 78 :3 0 334f
3350 0 69 :4 0
2b1 :4 0 6c :2 0
6d :3 0 1e60 3354
3356 :3 0 1e63 3351
3358 :2 0 3372 67
:3 0 78 :3 0 335a
335b 0 69 :4 0
a1 :4 0 6c :2 0
9b :3 0 1e66 335f
3361 :3 0 6c :2 0
a2 :4 0 1e69 3363
3365 :3 0 6c :2 0
a3 :3 0 a4 :3 0
27 :2 0 a5 :2 0
1e6c 3368 336c 1e70
3367 336e :3 0 1e73
335c 3370 :2 0 3372
1e76 3373 334e 3372
0 3374 1e79 0
3382 2ac :3 0 63
:3 0 2ad :3 0 15
:3 0 2ab :3 0 2ae
:3 0 98 :4 0 2b2
1 :a 0 337e :2 0
3382 3376 337c :2 0
14 :3 0 63 :3 0
3380 :2 0 3382 1e7b
3385 :3 0 3385 0
3385 3384 3382 3383
:6 0 3387 1 :3 0
1e80 3389 1e82 3388
3387 :2 0 338a 1e84
:2 0 338c 1e87 338c
338b 32eb 338a :6 0
338d :2 0 2 44
338c 3390 :3 0 338f
338d 3391 :8 0 
1ecc
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
4f 1 4d 1
56 1 54 1
5d 1 5b 1
64 1 62 1
6b 1 69 1
72 1 70 1
79 1 77 1
80 1 7e 1
87 1 85 1
8c 1 91 1
98 1 96 1
9f 1 9d 1
a6 1 a4 1
ad 1 ab 1
b4 1 b2 1
bb 1 b9 1
c0 1 c6 1
cc 1 d2 1
d8 1 de 1
e4 1 ea 1
f0 1 f6 1
fc 1 102 1
108 1 10e 1
114 1 11a 1
120 1 126 1
12c 1 132 1
138 1 13e 1
144 1 14a 1
150 1 156 1
15c 1 162 1
16a 1 168 1
171 1 16f 1
176 1 17e 1
17c 1 183 1
18b 1 189 1
192 1 190 1
199 1 197 1
19e 1 1a4 1
1aa 1 1b2 1
1b0 1 1b9 1
1b7 1 1be 1
1c4 1 1cc 1
1ca 1 1d1 1
1d7 1 1dd 1
1e3 1 1e9 1
1ee 1 1fb 1
207 2 20a 20c
2 20f 211 2
213 215 2 217
219 2 21b 21d
2 21f 221 2
223 225 2 227
229 2 22b 22d
2 22f 231 2
233 235 2 237
239 2 23b 23d
1 243 2 245
246 2 23f 248
2 24a 24c 1
252 2 254 255
2 24e 257 2
259 25b 1 261
2 263 264 2
25d 266 2 268
26a 1 270 2
272 273 2 26c
275 2 277 279
1 27f 2 281
282 2 27b 284
2 286 288 1
28e 2 290 291
2 28a 293 2
295 297 1 29d
2 29f 2a0 2
299 2a2 2 2a4
2a6 1 2ac 2
2ae 2af 2 2a8
2b1 2 2b3 2b5
1 2bb 2 2bd
2be 2 2b7 2c0
2 2c2 2c4 1
2ca 2 2cc 2cd
2 2c6 2cf 2
2d1 2d3 2 2d5
2d7 2 2d9 2db
2 2dd 2df 2
2e1 2e3 2 2e5
2e7 2 2e9 2eb
2 2ed 2ef 2
2f1 2f3 4 203
209 20e 2f5 1
2f7 1 2f9 2
303 305 3 301
302 307 2 310
312 2 30f 314
1 316 1 318
2 350 351 1
353 1 360 2
36d 36f 3 36b
36c 371 2 37a
37c 2 37e 380
2 382 384 1
38c 2 38e 38f
2 386 391 2
379 393 1 395
1 397 2 3a1
3a3 3 39f 3a0
3a5 2 3ae 3b0
2 3ad 3b2 1
3b4 1 3b6 2
3bd 3be 3 398
3b7 3c0 1 3c2
1 3c4 2 3d1
3d3 3 3cf 3d0
3d5 2 3de 3e0
2 3e2 3e4 2
3e6 3e8 1 3f0
2 3f2 3f3 2
3ea 3f5 2 3dd
3f7 1 3f9 1
3fb 2 405 407
3 403 404 409
2 412 414 2
411 416 1 418
1 41a 2 421
422 3 3fc 41b
424 1 426 2
429 42a 1 42e
2 42c 42e 2
432 433 1 437
2 435 437 2
43d 43e 1 442
2 440 442 2
44f 451 3 44d
44e 453 2 45c
45e 2 460 462
2 464 466 1
46e 2 470 471
2 468 473 2
45b 475 1 477
1 479 2 483
485 3 481 482
487 2 490 492
2 48f 494 1
496 1 498 2
49f 4a0 3 47a
499 4a2 1 4a4
1 4a6 1 4ac
2 4bc 4c1 1
4c8 1 4c3 2
4db 4dd 3 4d9
4da 4df 2 4e8
4ea 2 4ec 4ee
2 4f0 4f2 2
4f4 4f6 2 4f8
4fa 3 4ff 500
501 2 4fc 503
2 4e7 505 1
507 1 509 2
4d2 50a 1 50e
1 4cd 2 4cb
512 1 51d 2
519 51d 2 522
523 1 527 2
525 527 2 535
537 3 533 534
539 2 542 544
2 546 548 2
54a 54c 1 554
2 556 557 2
54e 559 2 541
55b 1 55d 1
55f 2 569 56b
3 567 568 56d
2 576 578 2
575 57a 1 57c
1 57e 2 585
586 3 560 57f
588 1 58a 3
515 58b 58e 1
591 1 597 2
5a2 5a7 1 5ae
1 5a9 2 5c1
5c3 3 5bf 5c0
5c5 2 5ce 5d0
2 5d2 5d4 2
5d6 5d8 2 5da
5dc 2 5de 5e0
3 5e5 5e6 5e7
2 5e2 5e9 2
5cd 5eb 1 5ed
1 5ef 2 5b8
5f0 1 5f4 1
5b3 2 5b1 5f8
1 5fb 2 5ff
5fe 1 604 1
60b 1 60d 3
611 612 613 3
619 61a 61b 2
623 624 1 628
2 626 628 3
62e 62f 630 3
632 633 634 4
63c 63d 63e 63f
2 645 646 1
648 1 64c 2
64a 64c 2 65c
661 1 668 1
663 2 67b 67d
3 679 67a 67f
2 688 68a 2
68c 68e 2 690
692 2 694 696
2 698 69a 3
69f 6a0 6a1 2
69c 6a3 2 687
6a5 1 6a7 1
6a9 2 672 6aa
1 6ae 1 66d
2 66b 6b2 1
6b5 2 6fd 702
1 709 1 704
2 71c 71e 3
71a 71b 720 2
729 72b 2 72d
72f 2 731 733
2 735 737 2
739 73b 3 740
741 742 2 73d
744 2 728 746
1 748 1 74a
2 713 74b 1
74f 1 70e 2
70c 753 1 756
2 759 75a 1
762 2 75e 762
2 76d 772 1
779 1 774 2
78c 78e 3 78a
78b 790 2 799
79b 2 79d 79f
2 7a1 7a3 2
7a5 7a7 2 7a9
7ab 3 7b0 7b1
7b2 2 7ad 7b4
2 798 7b6 1
7b8 1 7ba 2
783 7bb 1 7bf
1 77e 2 77c
7c3 1 7ce 2
7ca 7ce 1 7d2
1 7d9 1 7db
2 7e8 7ed 1
7f4 1 7ef 2
807 809 3 805
806 80b 2 814
816 2 818 81a
2 81c 81e 2
820 822 2 824
826 3 82b 82c
82d 2 828 82f
2 813 831 1
833 1 835 2
7fe 836 1 83a
1 7f9 2 7f7
83e 2 7dc 841
2 84c 84e 3
84a 84b 850 2
859 85b 2 85d
85f 2 861 863
1 86b 2 86d
86e 2 865 870
2 872 874 2
876 878 2 87a
87c 2 87e 880
2 858 882 1
884 1 886 2
890 892 3 88e
88f 894 2 89d
89f 2 89c 8a1
1 8a3 1 8a5
3 8ac 8ad 8ae
3 887 8a6 8b0
2 8b2 8b3 2
7c6 8b4 1 8b8
2 8ba 8bb 2
8c5 8ca 1 8d1
1 8cc 2 8e4
8e6 3 8e2 8e3
8e8 2 8f1 8f3
2 8f5 8f7 2
8f9 8fb 2 8fd
8ff 2 901 903
3 908 909 90a
2 905 90c 2
8f0 90e 1 910
1 912 2 8db
913 1 917 1
8d6 2 8d4 91b
2 921 922 1
926 2 924 926
2 92e 933 1
93a 1 935 2
94d 94f 3 94b
94c 951 2 95a
95c 2 95e 960
2 962 964 2
966 968 2 96a
96c 3 971 972
973 2 96e 975
2 959 977 1
979 1 97b 2
944 97c 1 980
1 93f 2 93d
984 2 98c 98d
1 991 2 98f
991 2 99c 99e
3 99a 99b 9a0
2 9a9 9ab 2
9ad 9af 2 9b1
9b3 1 9bb 2
9bd 9be 2 9b5
9c0 2 9c2 9c4
2 9c6 9c8 2
9ca 9cc 2 9ce
9d0 2 9a8 9d2
1 9d4 1 9d6
2 9e0 9e2 3
9de 9df 9e4 2
9ed 9ef 2 9ec
9f1 1 9f3 1
9f5 3 9fc 9fd
9fe 3 9d7 9f6
a00 1 a02 2
987 a03 1 a05
7 637 642 75b
8bc 8bf 91e a06
2 a13 a18 1
a1f 1 a1a 2
a32 a34 3 a30
a31 a36 2 a3f
a41 2 a43 a45
2 a47 a49 2
a4b a4d 2 a4f
a51 3 a56 a57
a58 2 a53 a5a
2 a3e a5c 1
a5e 1 a60 2
a29 a61 1 a65
1 a24 2 a22
a69 1 a74 2
a70 a74 2 a7d
a82 1 a89 1
a84 2 a9c a9e
3 a9a a9b aa0
2 aa9 aab 2
aad aaf 2 ab1
ab3 2 ab5 ab7
2 ab9 abb 3
ac0 ac1 ac2 2
abd ac4 2 aa8
ac6 1 ac8 1
aca 2 a93 acb
1 acf 1 a8e
2 a8c ad3 1
ade 2 ada ade
2 aea aec 3
ae8 ae9 aee 2
af7 af9 2 afb
afd 2 aff b01
1 b09 2 b0b
b0c 2 b03 b0e
2 b10 b12 2
b14 b16 2 b18
b1a 2 b1c b1e
2 af6 b20 1
b22 1 b24 2
b2e b30 3 b2c
b2d b32 2 b3b
b3d 2 b3a b3f
1 b41 1 b43
3 b4a b4b b4c
3 b25 b44 b4e
1 b50 2 ad6
b51 1 b53 2
a6c b54 2 b56
b57 2 b5a b5b
1 b61 2 b5d
b61 2 b65 b66
1 b6a 2 b68
b6a 2 b78 b7d
1 b84 1 b7f
2 b97 b99 3
b95 b96 b9b 2
ba4 ba6 2 ba8
baa 2 bac bae
2 bb0 bb2 2
bb4 bb6 3 bbb
bbc bbd 2 bb8
bbf 2 ba3 bc1
1 bc3 1 bc5
2 b8e bc6 1
bca 1 b89 2
b87 bce 2 bd4
bd5 1 bd9 2
bd7 bd9 2 bdd
bde 1 be4 2
be0 be4 2 be8
be9 1 bef 2
beb bef 1 bf6
1 bf8 3 bf9
bfc bff 1 c01
2 bd1 c02 1
c06 2 c04 c06
2 c14 c15 2
c19 c1a 2 c1e
c1f 2 c23 c24
2 c28 c29 2
c2d c2e 2 c32
c33 2 c37 c38
d c11 c12 c17
c1c c21 c26 c2b
c30 c35 c3a c3b
c3c c3d 2 c42
c43 1 c49 2
c45 c49 2 c54
c56 3 c52 c53
c58 2 c61 c63
2 c65 c67 2
c69 c6b 1 c73
2 c75 c76 2
c6d c78 2 c60
c7a 1 c7c 1
c7e 2 c88 c8a
3 c86 c87 c8c
2 c95 c97 2
c94 c99 1 c9b
1 c9d 2 ca4
ca5 3 c7f c9e
ca7 2 cab cac
1 cb0 2 cae
cb0 2 cbb cbd
3 cb9 cba cbf
2 cc8 cca 2
ccc cce 2 cd0
cd2 1 cd8 2
cda cdb 2 cd4
cdd 2 cdf ce1
2 ce3 ce5 2
ce7 ce9 2 ceb
ced 2 cc7 cef
1 cf1 1 cf3
2 cfd cff 3
cfb cfc d01 2
d0a d0c 2 d09
d0e 1 d10 1
d12 2 d18 d19
3 d1b d1c d1d
3 cf4 d13 d1f
2 d22 d21 1
d27 1 d2e 1
d30 6 c0b c0e
c40 d23 d26 d31
2 d37 d38 1
d3c 2 d3a d3c
2 d41 d42 2
d47 d48 2 d44
d4a 1 d4d 1
d4f 2 d35 d50
2 d52 d53 2
d56 d57 1 d5b
2 d59 d5b 2
d60 d61 1 d65
2 d63 d65 2
d6c d6d 1 d71
2 d6f d71 2
d76 d77 1 d7b
2 d79 d7b 1
d83 2 d87 d88
1 d8c 2 d8a
d8c 1 d91 2
d96 d97 1 d9b
2 d99 d9b 2
da0 da1 1 da5
2 da3 da5 1
dad 2 db2 db3
1 db7 2 db5
db7 1 dbc 4
dbf d94 db0 dbe
1 dc0 1 dc2
2 d54 dc3 2
dc5 dc6 2 dd9
dda 2 ddc ddf
2 de2 de3 2
dea deb 2 ded
df0 2 df5 df6
1 dfa 2 df8
dfa 6 dff e00
e01 e02 e03 e04
2 e09 e0a 1
e10 2 e0c e10
2 e14 e15 1
e19 2 e17 e19
1 e20 1 e22
2 e2c e2e 3
e2a e2b e30 2
e39 e3b 2 e3d
e3f 2 e41 e43
1 e49 2 e4b
e4c 2 e45 e4e
2 e50 e52 2
e54 e56 2 e58
e5a 2 e5c e5e
2 e38 e60 1
e62 1 e64 2
e6e e70 3 e6c
e6d e72 2 e7b
e7d 2 e7a e7f
1 e81 1 e83
2 e89 e8a 3
e8c e8d e8e 4
e23 e65 e84 e90
1 e92 2 e95
e96 1 e9a 2
e98 e9a 2 e9e
e9f 1 ea3 2
ea1 ea3 2 eb0
eb2 3 eae eaf
eb4 2 ebd ebf
2 ec1 ec3 2
ec5 ec7 1 ecd
2 ecf ed0 2
ec9 ed2 2 ed4
ed6 2 ed8 eda
2 edc ede 2
ee0 ee2 2 ebc
ee4 1 ee6 1
ee8 2 ef2 ef4
3 ef0 ef1 ef6
2 eff f01 2
efe f03 1 f05
1 f07 2 f0d
f0e 3 f10 f11
f12 3 ee9 f08
f14 1 f16 2
f2f f34 1 f3b
1 f36 2 f4e
f50 3 f4c f4d
f52 2 f5b f5d
2 f5f f61 2
f63 f65 2 f67
f69 2 f6b f6d
3 f72 f73 f74
2 f6f f76 2
f5a f78 1 f7a
1 f7c 2 f45
f7d 1 f81 1
f40 2 f3e f85
1 f90 2 f8c
f90 1 f94 2
fa0 fa1 1 fa5
2 fa3 fa5 1
faa 1 fac 2
f9e fad 1 faf
1 fb9 2 fb7
fb9 3 fbd fbe
fbf 1 fc3 2
fc1 fc3 2 fe8
fed 1 ff4 1
fef 2 1007 1009
3 1005 1006 100b
2 1014 1016 2
1018 101a 2 101c
101e 2 1020 1022
2 1024 1026 3
102b 102c 102d 2
1028 102f 2 1013
1031 1 1033 1
1035 2 ffe 1036
1 103a 1 ff9
2 ff7 103e 1
1049 2 1045 1049
2 1051 1052 1
1056 2 1054 1056
2 105b 105c 1
1060 2 105e 1060
2 1086 108b 1
1092 1 108d 2
10a5 10a7 3 10a3
10a4 10a9 2 10b2
10b4 2 10b6 10b8
2 10ba 10bc 2
10be 10c0 2 10c2
10c4 3 10c9 10ca
10cb 2 10c6 10cd
2 10b1 10cf 1
10d1 1 10d3 2
109c 10d4 1 10d8
1 1097 2 1095
10dc 1 10df 1
10e4 2 10e6 10e7
2 104f 10e8 1
10f1 2 10ed 10f1
2 10f6 10f7 1
10fb 2 10f9 10fb
2 1121 1126 1
112d 1 1128 2
1140 1142 3 113e
113f 1144 2 114d
114f 2 1151 1153
2 1155 1157 2
1159 115b 2 115d
115f 3 1164 1165
1166 2 1161 1168
2 114c 116a 1
116c 1 116e 2
1137 116f 1 1173
1 1132 2 1130
1177 1 117a 2
117e 117d 2 1041
117f 2 11a1 11a6
1 11ad 1 11a8
2 11c0 11c2 3
11be 11bf 11c4 2
11cd 11cf 2 11d1
11d3 2 11d5 11d7
2 11d9 11db 2
11dd 11df 3 11e4
11e5 11e6 2 11e1
11e8 2 11cc 11ea
1 11ec 1 11ee
2 11b7 11ef 1
11f3 1 11b2 2
11b0 11f7 1 11fa
2 11fd 11fe 1
11ff 3 1202 1203
1204 1 1208 2
1206 1208 2 1224
1229 1 1230 1
122b 2 1243 1245
3 1241 1242 1247
2 1250 1252 2
1254 1256 2 1258
125a 2 125c 125e
2 1260 1262 3
1267 1268 1269 2
1264 126b 2 124f
126d 1 126f 1
1271 2 123a 1272
1 1276 1 1235
2 1233 127a 1
1285 2 1281 1285
2 128d 128e 1
1292 2 1290 1292
2 1297 1298 1
129c 2 129a 129c
2 12b6 12bb 1
12c2 1 12bd 2
12d5 12d7 3 12d3
12d4 12d9 2 12e2
12e4 2 12e6 12e8
2 12ea 12ec 2
12ee 12f0 2 12f2
12f4 3 12f9 12fa
12fb 2 12f6 12fd
2 12e1 12ff 1
1301 1 1303 2
12cc 1304 1 1308
1 12c7 2 12c5
130c 1 130f 2
1314 1315 2 1317
1318 2 128b 1319
1 1322 2 131e
1322 2 133d 1342
1 1349 1 1344
2 135c 135e 3
135a 135b 1360 2
1369 136b 2 136d
136f 2 1371 1373
2 1375 1377 2
1379 137b 3 1380
1381 1382 2 137d
1384 2 1368 1386
1 1388 1 138a
2 1353 138b 1
138f 1 134e 2
134c 1393 1 1396
2 139a 1399 2
127d 139b 2 13b4
13b9 1 13c0 1
13bb 2 13d3 13d5
3 13d1 13d2 13d7
2 13e0 13e2 2
13e4 13e6 2 13e8
13ea 2 13ec 13ee
2 13f0 13f2 3
13f7 13f8 13f9 2
13f4 13fb 2 13df
13fd 1 13ff 1
1401 2 13ca 1402
1 1406 1 13c5
2 13c3 140a 1
140d 2 1410 1411
1 1412 2 1414
1415 1 141d 2
1419 141d 2 1422
1423 1 1427 2
1425 1427 2 1432
1434 3 1430 1431
1436 2 143f 1441
2 1443 1445 2
1447 1449 1 1451
2 1453 1454 2
144b 1456 2 1458
145a 2 145c 145e
2 1460 1462 2
1464 1466 2 143e
1468 1 146a 1
146c 2 1476 1478
3 1474 1475 147a
2 1483 1485 2
1482 1487 1 1489
1 148b 3 1492
1493 1494 3 146d
148c 1496 1 1499
2 149f 14a0 1
14a4 2 14a2 14a4
1 14ab 2 14a9
14ab 2 14c0 14c5
1 14cc 1 14c7
2 14df 14e1 3
14dd 14de 14e3 2
14ec 14ee 2 14f0
14f2 2 14f4 14f6
2 14f8 14fa 2
14fc 14fe 3 1503
1504 1505 2 1500
1507 2 14eb 1509
1 150b 1 150d
2 14d6 150e 1
1512 1 14d1 2
14cf 1516 2 14b0
1519 2 152b 1530
1 1537 1 1532
2 154a 154c 3
1548 1549 154e 2
1557 1559 2 155b
155d 2 155f 1561
2 1563 1565 2
1567 1569 3 156e
156f 1570 2 156b
1572 2 1556 1574
1 1576 1 1578
2 1541 1579 1
157d 1 153c 2
153a 1581 2 151e
1584 2 1587 1588
2 158b 158c 2
1591 1592 1 1594
2 158e 1594 2
159f 15a1 3 159d
159e 15a3 2 15ac
15ae 2 15b0 15b2
2 15b4 15b6 1
15be 2 15c0 15c1
2 15b8 15c3 2
15c5 15c7 2 15c9
15cb 2 15cd 15cf
2 15d1 15d3 2
15ab 15d5 1 15d7
1 15d9 2 15e3
15e5 3 15e1 15e2
15e7 2 15f0 15f2
2 15ef 15f4 1
15f6 1 15f8 3
15ff 1600 1601 3
15da 15f9 1603 1
1605 2 1589 1606
2 1609 1608 2
160a 160d 2 1611
1612 1 1616 2
1614 1616 2 161c
161d 1 161f 1
1624 2 1622 1624
2 1631 1633 3
162f 1630 1635 2
163e 1640 2 1642
1644 2 1646 1648
1 1650 2 1652
1653 2 164a 1655
2 1657 1659 2
165b 165d 2 165f
1661 2 1663 1665
2 163d 1667 1
1669 1 166b 2
1675 1677 3 1673
1674 1679 2 1682
1684 2 1681 1686
1 1688 1 168a
3 1691 1692 1693
3 166c 168b 1695
2 1698 1697 3
169b 169c 169d 1
16a1 2 169f 16a1
2 16a6 16a8 3
16aa 16ab 16ac 2
16c5 16ca 1 16d1
1 16cc 2 16e4
16e6 3 16e2 16e3
16e8 2 16f1 16f3
2 16f5 16f7 2
16f9 16fb 2 16fd
16ff 2 1701 1703
3 1708 1709 170a
2 1705 170c 2
16f0 170e 1 1710
1 1712 2 16db
1713 1 1717 1
16d6 2 16d4 171b
1 1726 2 1722
1726 2 1732 1734
3 1730 1731 1736
2 173f 1741 2
1743 1745 2 1747
1749 1 1751 2
1753 1754 2 174b
1756 2 1758 175a
2 175c 175e 2
1760 1762 2 1764
1766 2 173e 1768
1 176a 1 176c
2 1776 1778 3
1774 1775 177a 2
1783 1785 2 1782
1787 1 1789 1
178b 3 1792 1793
1794 3 176d 178c
1796 1 1798 3
179b 179c 179d 1
17a1 2 179f 17a1
2 17a6 17a7 1
17ab 2 17a9 17ab
2 17b0 17b1 2
17b6 17b7 1 17b9
2 17b3 17b9 2
17ca 17cc 3 17c8
17c9 17ce 2 17d7
17d9 2 17db 17dd
2 17df 17e1 1
17e9 2 17eb 17ec
2 17e3 17ee 2
17f0 17f2 2 17f4
17f6 2 17f8 17fa
2 17fc 17fe 2
17d6 1800 1 1802
1 1804 2 180e
1810 3 180c 180d
1812 2 181b 181d
2 181a 181f 1
1821 1 1823 3
182a 182b 182c 3
1805 1824 182e 1
1830 2 183e 1843
1 184a 1 1845
2 185d 185f 3
185b 185c 1861 2
186a 186c 2 186e
1870 2 1872 1874
2 1876 1878 2
187a 187c 3 1881
1882 1883 2 187e
1885 2 1869 1887
1 1889 1 188b
2 1854 188c 1
1890 1 184f 2
184d 1894 5 16af
171e 1799 1831 1897
2 189c 189e 3
18a0 18a1 18a2 2
18ab 18b0 1 18b7
1 18b2 2 18ca
18cc 3 18c8 18c9
18ce 2 18d7 18d9
2 18db 18dd 2
18df 18e1 2 18e3
18e5 2 18e7 18e9
3 18ee 18ef 18f0
2 18eb 18f2 2
18d6 18f4 1 18f6
1 18f8 2 18c1
18f9 1 18fd 1
18bc 2 18ba 1901
1 190c 2 1908
190c 2 1918 191a
3 1916 1917 191c
2 1925 1927 2
1929 192b 2 192d
192f 1 1937 2
1939 193a 2 1931
193c 2 193e 1940
2 1942 1944 2
1946 1948 2 194a
194c 2 1924 194e
1 1950 1 1952
2 195c 195e 3
195a 195b 1960 2
1969 196b 2 1968
196d 1 196f 1
1971 3 1978 1979
197a 3 1953 1972
197c 1 197e 2
1994 1999 1 19a0
1 199b 2 19b3
19b5 3 19b1 19b2
19b7 2 19c0 19c2
2 19c4 19c6 2
19c8 19ca 2 19cc
19ce 2 19d0 19d2
3 19d7 19d8 19d9
2 19d4 19db 2
19bf 19dd 1 19df
1 19e1 2 19aa
19e2 1 19e6 1
19a5 2 19a3 19ea
1 19f5 2 19f1
19f5 2 19fa 19fb
1 19ff 2 19fd
19ff 2 1a0d 1a0f
3 1a0b 1a0c 1a11
2 1a1a 1a1c 2
1a1e 1a20 2 1a22
1a24 1 1a2c 2
1a2e 1a2f 2 1a26
1a31 2 1a33 1a35
2 1a37 1a39 2
1a3b 1a3d 2 1a3f
1a41 2 1a19 1a43
1 1a45 1 1a47
2 1a51 1a53 3
1a4f 1a50 1a55 2
1a5e 1a60 2 1a5d
1a62 1 1a64 1
1a66 3 1a6d 1a6e
1a6f 3 1a48 1a67
1a71 1 1a73 2
1a81 1a86 1 1a8d
1 1a88 2 1aa0
1aa2 3 1a9e 1a9f
1aa4 2 1aad 1aaf
2 1ab1 1ab3 2
1ab5 1ab7 2 1ab9
1abb 2 1abd 1abf
3 1ac4 1ac5 1ac6
2 1ac1 1ac8 2
1aac 1aca 1 1acc
1 1ace 2 1a97
1acf 1 1ad3 1
1a92 2 1a90 1ad7
6 18a5 1904 197f
19ed 1a74 1ada 2
1add 1ade 2 1ae4
1ae5 1 1ae9 2
1ae7 1ae9 2 1af6
1afb 1 1b02 1
1afd 2 1b15 1b17
3 1b13 1b14 1b19
2 1b22 1b24 2
1b26 1b28 2 1b2a
1b2c 2 1b2e 1b30
2 1b32 1b34 3
1b39 1b3a 1b3b 2
1b36 1b3d 2 1b21
1b3f 1 1b41 1
1b43 2 1b0c 1b44
1 1b48 1 1b07
2 1b05 1b4c 2
1b5b 1b60 1 1b67
1 1b62 2 1b7a
1b7c 3 1b78 1b79
1b7e 2 1b87 1b89
2 1b8b 1b8d 2
1b8f 1b91 2 1b93
1b95 2 1b97 1b99
3 1b9e 1b9f 1ba0
2 1b9b 1ba2 2
1b86 1ba4 1 1ba6
1 1ba8 2 1b71
1ba9 1 1bad 1
1b6c 2 1b6a 1bb1
2 1bbd 1bbe 1
1bc2 2 1bc0 1bc2
1 1bc7 1 1bc9
22 1bcd 1bce 1bcf
1bd0 1bd1 1bd2 1bd3
1bd4 1bd5 1bd6 1bd7
1bd8 1bd9 1bda 1bdb
1bdc 1bdd 1bde 1bdf
1be0 1be1 1be2 1be3
1be4 1be5 1be6 1be7
1be8 1be9 1bea 1beb
1bec 1bed 1bee 1
1bf4 2 1bf2 1bf4
2 1bf8 1bf9 1
1bfd 2 1bfb 1bfd
1 1c07 2 1c06
1c07 1 1c0f 1
1c15 2 1c17 1c18
2 1c04 1c19 1
1c20 1 1c1b 2
1c33 1c35 3 1c31
1c32 1c37 2 1c40
1c42 2 1c44 1c46
2 1c48 1c4a 2
1c4c 1c4e 2 1c50
1c52 3 1c57 1c58
1c59 2 1c54 1c5b
2 1c3f 1c5d 1
1c5f 1 1c61 2
1c2a 1c62 1 1c66
1 1c25 2 1c23
1c6a 1 1c6d 1
1c77 2 1c76 1c77
1 1c7f 1 1c85
2 1c87 1c88 2
1c74 1c89 1 1c90
1 1c8b 2 1ca3
1ca5 3 1ca1 1ca2
1ca7 2 1cb0 1cb2
2 1cb4 1cb6 2
1cb8 1cba 2 1cbc
1cbe 2 1cc0 1cc2
3 1cc7 1cc8 1cc9
2 1cc4 1ccb 2
1caf 1ccd 1 1ccf
1 1cd1 2 1c9a
1cd2 1 1cd6 1
1c95 2 1c93 1cda
1 1cdd 2 1ce0
1ce1 1 1ce2 1
1ce4 7 1b4f 1bb4
1bb8 1bbb 1bca 1bf1
1ce5 3 1cee 1cef
1cf0 1 1cf4 2
1cf2 1cf4 1 1cfb
2 1d00 1d01 2
1d03 1d06 1 1d09
2 1d0b 1d0c 22
1d10 1d11 1d12 1d13
1d14 1d15 1d16 1d17
1d18 1d19 1d1a 1d1b
1d1c 1d1d 1d1e 1d1f
1d20 1d21 1d22 1d23
1d24 1d25 1d26 1d27
1d28 1d29 1d2a 1d2b
1d2c 1d2d 1d2e 1d2f
1d30 1d31 1 1d37
2 1d35 1d37 1
1d41 2 1d40 1d41
1 1d49 1 1d4f
2 1d51 1d52 2
1d3e 1d53 1 1d5a
1 1d55 2 1d6d
1d6f 3 1d6b 1d6c
1d71 2 1d7a 1d7c
2 1d7e 1d80 2
1d82 1d84 2 1d86
1d88 2 1d8a 1d8c
3 1d91 1d92 1d93
2 1d8e 1d95 2
1d79 1d97 1 1d99
1 1d9b 2 1d64
1d9c 1 1da0 1
1d5f 2 1d5d 1da4
1 1da7 1 1daa
5 1ce9 1cec 1d0d
1d34 1dab 2 1dad
1dae d e07 e93
f17 f1a f88 fb0
fb3 fb6 1416 1699
1adf 1ae2 1daf 1
1db3 2 1db5 1db6
1 1dba 2 1db8
1dba 1 1dbf 1
1dc5 2 1dc7 1dc8
2 1dca 1dcc 2
1dcf 1dd1 1 1dd3
1 1dd6 2 1dd8
1dd9 1 1ddd 2
1ddb 1ddd 2 1de5
1de6 1 1de9 2
1de8 1de9 2 1df9
1dfa 2 1dfc 1dfe
2 1e00 1e02 4
1df6 1df7 1e04 1e05
2 1e10 1e11 2
1e13 1e15 2 1e17
1e19 2 1e1b 1e1d
4 1e0d 1e0e 1e1f
1e20 2 1e3e 1e43
1 1e4a 1 1e45
2 1e5d 1e5f 3
1e5b 1e5c 1e61 2
1e6a 1e6c 2 1e6e
1e70 2 1e72 1e74
2 1e76 1e78 2
1e7a 1e7c 3 1e81
1e82 1e83 2 1e7e
1e85 2 1e69 1e87
1 1e89 1 1e8b
2 1e54 1e8c 1
1e90 1 1e4f 2
1e4d 1e94 2 1e9a
1e9b 1 1e9f 2
1e9d 1e9f 1 1ea3
2 1eb1 1eb2 1
1eb6 2 1eb4 1eb6
1 1ebb 1 1ebd
2 1ead 1ebe 1
1ec0 3 1ec3 1ec4
1ec5 1 1ec9 2
1ec7 1ec9 1 1ed3
2 1ed5 1ed6 1
1eda 2 1ed8 1eda
1 1edf 2 1ee3
1ee5 3 1ee7 1ee8
1ee9 2 1eef 1ef1
3 1ef3 1ef4 1ef5
2 1eec 1ef8 2
1efa 1efb 2 1ed0
1efc 1 1f00 2
1f02 1f03 1 1f07
2 1f05 1f07 1
1f0c 2 1f10 1f12
3 1f14 1f15 1f16
2 1f1c 1f1e 3
1f20 1f21 1f22 2
1f19 1f25 2 1f27
1f28 1 1f29 2
1f2b 1f2c 2 1f35
1f36 1 1f3a 2
1f38 1f3a 1 1f3f
2 1f3d 1f3f 3
1f43 1f44 1f45 1
1f49 2 1f47 1f49
2 1f68 1f6d 1
1f74 1 1f6f 2
1f87 1f89 3 1f85
1f86 1f8b 2 1f94
1f96 2 1f98 1f9a
2 1f9c 1f9e 2
1fa0 1fa2 2 1fa4
1fa6 3 1fab 1fac
1fad 2 1fa8 1faf
2 1f93 1fb1 1
1fb3 1 1fb5 2
1f7e 1fb6 1 1fba
1 1f79 2 1f77
1fbe 1 1fc9 2
1fc5 1fc9 2 1fd1
1fd2 1 1fd6 2
1fd4 1fd6 2 1fdb
1fdc 1 1fe0 2
1fde 1fe0 2 2000
2005 1 200c 1
2007 2 201f 2021
3 201d 201e 2023
2 202c 202e 2
2030 2032 2 2034
2036 2 2038 203a
2 203c 203e 3
2043 2044 2045 2
2040 2047 2 202b
2049 1 204b 1
204d 2 2016 204e
1 2052 1 2011
2 200f 2056 1
2059 1 205e 2
2060 2061 2 1fcf
2062 1 206b 2
2067 206b 2 2070
2071 1 2075 2
2073 2075 2 2095
209a 1 20a1 1
209c 2 20b4 20b6
3 20b2 20b3 20b8
2 20c1 20c3 2
20c5 20c7 2 20c9
20cb 2 20cd 20cf
2 20d1 20d3 3
20d8 20d9 20da 2
20d5 20dc 2 20c0
20de 1 20e0 1
20e2 2 20ab 20e3
1 20e7 1 20a6
2 20a4 20eb 1
20ee 2 20f2 20f1
2 1fc1 20f3 2
2111 2116 1 211d
1 2118 2 2130
2132 3 212e 212f
2134 2 213d 213f
2 2141 2143 2
2145 2147 2 2149
214b 2 214d 214f
3 2154 2155 2156
2 2151 2158 2
213c 215a 1 215c
1 215e 2 2127
215f 1 2163 1
2122 2 2120 2167
1 216a 2 216d
216e 1 216f 3
2172 2173 2174 1
2178 2 2176 2178
2 2196 219b 1
21a2 1 219d 2
21b5 21b7 3 21b3
21b4 21b9 2 21c2
21c4 2 21c6 21c8
2 21ca 21cc 2
21ce 21d0 2 21d2
21d4 3 21d9 21da
21db 2 21d6 21dd
2 21c1 21df 1
21e1 1 21e3 2
21ac 21e4 1 21e8
1 21a7 2 21a5
21ec 1 21f7 2
21f3 21f7 2 21fc
21fd 1 2201 2
21ff 2201 2 2206
2207 1 220b 2
2209 220b 2 2227
222c 1 2233 1
222e 2 2246 2248
3 2244 2245 224a
2 2253 2255 2
2257 2259 2 225b
225d 2 225f 2261
2 2263 2265 3
226a 226b 226c 2
2267 226e 2 2252
2270 1 2272 1
2274 2 223d 2275
1 2279 1 2238
2 2236 227d 1
2280 2 2285 2286
2 2288 2289 1
228a 1 2293 2
228f 2293 2 22b0
22b5 1 22bc 1
22b7 2 22cf 22d1
3 22cd 22ce 22d3
2 22dc 22de 2
22e0 22e2 2 22e4
22e6 2 22e8 22ea
2 22ec 22ee 3
22f3 22f4 22f5 2
22f0 22f7 2 22db
22f9 1 22fb 1
22fd 2 22c6 22fe
1 2302 1 22c1
2 22bf 2306 1
2309 2 230d 230c
2 21ef 230e 2
2329 232e 1 2335
1 2330 2 2348
234a 3 2346 2347
234c 2 2355 2357
2 2359 235b 2
235d 235f 2 2361
2363 2 2365 2367
3 236c 236d 236e
2 2369 2370 2
2354 2372 1 2374
1 2376 2 233f
2377 1 237b 1
233a 2 2338 237f
1 2382 2 2385
2386 1 2387 2
2389 238a 1 2392
2 238e 2392 2
2397 2398 1 239c
2 239a 239c 1
23a1 1 23a3 1
23aa 2 23a8 23aa
2 23bf 23c4 1
23cb 1 23c6 2
23de 23e0 3 23dc
23dd 23e2 2 23eb
23ed 2 23ef 23f1
2 23f3 23f5 2
23f7 23f9 2 23fb
23fd 3 2402 2403
2404 2 23ff 2406
2 23ea 2408 1
240a 1 240c 2
23d5 240d 1 2411
1 23d0 2 23ce
2415 2 23af 2418
2 242a 242f 1
2436 1 2431 2
2449 244b 3 2447
2448 244d 2 2456
2458 2 245a 245c
2 245e 2460 2
2462 2464 2 2466
2468 3 246d 246e
246f 2 246a 2471
2 2455 2473 1
2475 1 2477 2
2440 2478 1 247c
1 243b 2 2439
2480 2 241d 2483
2 2486 2487 2
248a 248b 2 2490
2491 1 2493 2
248d 2493 2 2498
2499 2 249b 249d
2 24a0 24a2 1
24a4 2 2488 24a5
1 24a7 2 24a8
24ab 2 24ad 24ae
1 24af 2 24b3
24b4 2 24b6 24b8
2 24bb 24bd 2
24bf 24c0 2 24d2
24d7 1 24de 1
24d9 2 24f1 24f3
3 24ef 24f0 24f5
2 24fe 2500 2
2502 2504 2 2506
2508 2 250a 250c
2 250e 2510 3
2515 2516 2517 2
2512 2519 2 24fd
251b 1 251d 1
251f 2 24e8 2520
1 2524 1 24e3
2 24e1 2528 2
2537 253c 1 2543
1 253e 2 2556
2558 3 2554 2555
255a 2 2563 2565
2 2567 2569 2
256b 256d 2 256f
2571 2 2573 2575
3 257a 257b 257c
2 2577 257e 2
2562 2580 1 2582
1 2584 2 254d
2585 1 2589 1
2548 2 2546 258d
2 2599 259a 1
259e 2 259c 259e
1 25a3 1 25a5
22 25a9 25aa 25ab
25ac 25ad 25ae 25af
25b0 25b1 25b2 25b3
25b4 25b5 25b6 25b7
25b8 25b9 25ba 25bb
25bc 25bd 25be 25bf
25c0 25c1 25c2 25c3
25c4 25c5 25c6 25c7
25c8 25c9 25ca 1
25d0 2 25ce 25d0
2 25d4 25d5 1
25d9 2 25d7 25d9
1 25e3 2 25e2
25e3 1 25eb 1
25f1 2 25f3 25f4
2 25e0 25f5 1
25fc 1 25f7 2
260f 2611 3 260d
260e 2613 2 261c
261e 2 2620 2622
2 2624 2626 2
2628 262a 2 262c
262e 3 2633 2634
2635 2 2630 2637
2 261b 2639 1
263b 1 263d 2
2606 263e 1 2642
1 2601 2 25ff
2646 1 2649 1
2653 2 2652 2653
1 265b 1 2661
2 2663 2664 2
2650 2665 1 266c
1 2667 2 267f
2681 3 267d 267e
2683 2 268c 268e
2 2690 2692 2
2694 2696 2 2698
269a 2 269c 269e
3 26a3 26a4 26a5
2 26a0 26a7 2
268b 26a9 1 26ab
1 26ad 2 2676
26ae 1 26b2 1
2671 2 266f 26b6
1 26b9 2 26bc
26bd 1 26be 1
26c0 b 238b 24c1
24c4 24c7 252b 2590
2594 2597 25a6 25cd
26c1 2 26c5 26c6
1 26ca 2 26c8
26ca 3 26d4 26d5
26d6 1 26da 2
26d8 26da 1 26e1
2 26e5 26e6 1
26e9 2 26eb 26ec
22 26f0 26f1 26f2
26f3 26f4 26f5 26f6
26f7 26f8 26f9 26fa
26fb 26fc 26fd 26fe
26ff 2700 2701 2702
2703 2704 2705 2706
2707 2708 2709 270a
270b 270c 270d 270e
270f 2710 2711 1
2717 2 2715 2717
1 2721 2 2720
2721 1 2729 1
272f 2 2731 2732
2 271e 2733 1
273a 1 2735 2
274d 274f 3 274b
274c 2751 2 275a
275c 2 275e 2760
2 2762 2764 2
2766 2768 2 276a
276c 3 2771 2772
2773 2 276e 2775
2 2759 2777 1
2779 1 277b 2
2744 277c 1 2780
1 273f 2 273d
2784 1 2787 1
278a 5 26cf 26d2
26ed 2714 278b 2
278e 278d 2 2792
2793 2 2795 2797
1 279b f 1df1
1e08 1e23 1e26 1e29
1e2c 1e2f 1e97 1ec1
1f2d 1f30 1f33 278f
279a 279e 2 1de2
27a1 1 27a3 2
1dda 27a4 2 27a6
27a7 1 27ab 2
27a9 27ab 2 27b0
27b1 1 27b5 2
27b3 27b5 2 27bc
27bd 1 27c1 2
27bf 27c1 1 27ca
2 27c9 27ca 1
27d2 1 27d8 2
27da 27db 2 27c7
27dc 1 27e3 1
27de 2 27f6 27f8
3 27f4 27f5 27fa
2 2803 2805 2
2807 2809 2 280b
280d 2 280f 2811
2 2813 2815 3
281a 281b 281c 2
2817 281e 2 2802
2820 1 2822 1
2824 2 27ed 2825
1 2829 1 27e8
2 27e6 282d 1
2830 1 283d 2
283c 283d 1 2845
1 284b 2 284d
284e 2 283a 284f
1 2856 1 2851
2 2869 286b 3
2867 2868 286d 2
2876 2878 2 287a
287c 2 287e 2880
2 2882 2884 2
2886 2888 3 288d
288e 288f 2 288a
2891 2 2875 2893
1 2895 1 2897
2 2860 2898 1
289c 1 285b 2
2859 28a0 1 28a3
2 28a6 28a7 1
28ab 2 28a9 28ab
2 28b6 28b8 3
28b4 28b5 28ba 2
28c3 28c5 2 28c7
28c9 2 28cb 28cd
1 28d5 2 28d7
28d8 2 28cf 28da
2 28dc 28de 2
28e0 28e2 2 28e4
28e6 2 28e8 28ea
2 28c2 28ec 1
28ee 1 28f0 2
28fa 28fc 3 28f8
28f9 28fe 2 2907
2909 2 2906 290b
1 290d 1 290f
3 2916 2917 2918
3 28f1 2910 291a
1 2921 2 291d
2921 2 292c 292e
3 292a 292b 2930
2 2939 293b 2
293d 293f 2 2941
2943 1 294b 2
294d 294e 2 2945
2950 2 2952 2954
2 2956 2958 2
295a 295c 2 295e
2960 2 2938 2962
1 2964 1 2966
2 2970 2972 3
296e 296f 2974 2
297d 297f 2 297c
2981 1 2983 1
2985 3 298c 298d
298e 3 2967 2986
2990 1 2998 2
2994 2998 2 29a3
29a5 3 29a1 29a2
29a7 2 29b0 29b2
2 29b4 29b6 2
29b8 29ba 1 29c2
2 29c4 29c5 2
29bc 29c7 2 29c9
29cb 2 29cd 29cf
2 29d1 29d3 2
29d5 29d7 2 29af
29d9 1 29db 1
29dd 2 29e7 29e9
3 29e5 29e6 29eb
2 29f4 29f6 2
29f3 29f8 1 29fa
1 29fc 3 2a03
2a04 2a05 3 29de
29fd 2a07 2 2a12
2a14 3 2a10 2a11
2a16 2 2a1f 2a21
2 2a23 2a25 2
2a27 2a29 1 2a31
2 2a33 2a34 2
2a2b 2a36 2 2a38
2a3a 2 2a3c 2a3e
2 2a40 2a42 2
2a44 2a46 2 2a1e
2a48 1 2a4a 1
2a4c 2 2a56 2a58
3 2a54 2a55 2a5a
2 2a63 2a65 2
2a62 2a67 1 2a69
1 2a6b 3 2a72
2a73 2a74 3 2a4d
2a6c 2a76 4 2a78
2993 2a09 2a79 2
28a8 2a7a 1 2a7c
1 2a80 2 2a82
2a83 1 2a87 2
2a85 2a87 1 2a8d
2 2a8f 2a90 1
2a94 2 2a92 2a94
2 2aa5 2aa7 2
2aa9 2aab 2 2aad
2aaf 2 2ab1 2ab3
2 2ab5 2ab7 2
2ab9 2abb 2 2abd
2abf 2 2ac1 2ac3
2 2ac5 2ac7 2
2ac9 2acb 2 2acd
2acf 2 2ad1 2ad3
1 2ade 2 2add
2ade 1 2ae6 1
2aec 2 2aee 2aef
2 2adb 2af0 1
2af7 1 2af2 2
2b0a 2b0c 3 2b08
2b09 2b0e 2 2b17
2b19 2 2b1b 2b1d
2 2b1f 2b21 2
2b23 2b25 2 2b27
2b29 3 2b2e 2b2f
2b30 2 2b2b 2b32
2 2b16 2b34 2
2b3b 2b3d 2 2b3a
2b3f 2 2b36 2b41
1 2b43 2 2b01
2b44 1 2b48 1
2afc 2 2afa 2b4c
2 2b5c 2b5e 2
2b60 2b62 2 2b64
2b66 2 2b68 2b6a
2 2b6c 2b6e 2
2b70 2b72 2 2b74
2b76 2 2b78 2b7a
2 2b7c 2b7e 2
2b80 2b82 2 2b84
2b86 2 2b88 2b8a
1 2b95 2 2b94
2b95 1 2b9d 1
2ba3 2 2ba5 2ba6
2 2b92 2ba7 1
2bae 1 2ba9 2
2bc1 2bc3 3 2bbf
2bc0 2bc5 2 2bce
2bd0 2 2bd2 2bd4
2 2bd6 2bd8 2
2bda 2bdc 2 2bde
2be0 3 2be5 2be6
2be7 2 2be2 2be9
2 2bcd 2beb 2
2bf2 2bf4 2 2bf1
2bf6 2 2bed 2bf8
1 2bfa 2 2bb8
2bfb 1 2bff 1
2bb3 2 2bb1 2c03
2 2c10 2c12 2
2c14 2c16 2 2c18
2c1a 2 2c1c 2c1e
2 2c20 2c22 2
2c24 2c26 2 2c28
2c2a 2 2c2c 2c2e
2 2c30 2c32 2
2c34 2c36 2 2c38
2c3a 2 2c3c 2c3e
2 2c40 2c42 2
2c44 2c46 2 2c48
2c4a 2 2c4c 2c4e
2 2c50 2c52 2
2c54 2c56 2 2c58
2c5a 2 2c5c 2c5e
2 2c60 2c62 2
2c64 2c66 2 2c68
2c6a 2 2c6c 2c6e
2 2c70 2c72 2
2c74 2c76 2 2c78
2c7a 2 2c7c 2c7e
2 2c80 2c82 2
2c84 2c86 2 2c88
2c8a 2 2c8c 2c8e
2 2c90 2c92 2
2c94 2c96 2 2c98
2c9a 2 2c9c 2c9e
2 2ca0 2ca2 2
2ca4 2ca6 1 2cb1
2 2cb0 2cb1 1
2cb9 1 2cbf 2
2cc1 2cc2 2 2cae
2cc3 1 2cca 1
2cc5 2 2cdd 2cdf
3 2cdb 2cdc 2ce1
2 2cea 2cec 2
2cee 2cf0 2 2cf2
2cf4 2 2cf6 2cf8
2 2cfa 2cfc 3
2d01 2d02 2d03 2
2cfe 2d05 2 2ce9
2d07 2 2d0e 2d10
2 2d0d 2d12 2
2d09 2d14 1 2d16
2 2cd4 2d17 1
2d1b 1 2ccf 2
2ccd 2d1f 2 2d25
2d27 2 2d29 2d2b
2 2d2d 2d2f 2
2d35 2d36 1 2d38
2 2d31 2d3a 2
2d3c 2d3e 2 2d40
2d42 2 2d48 2d49
1 2d4b 2 2d44
2d4d 2 2d4f 2d51
2 2d53 2d55 2
2d57 2d59 2 2d5b
2d5d 2 2d5f 2d61
2 2d63 2d65 2
2d67 2d69 2 2d6b
2d6d 2 2d6f 2d71
2 2d73 2d75 2
2d77 2d79 2 2d7f
2d80 1 2d82 2
2d7b 2d84 2 2d86
2d88 2 2d8a 2d8c
2 2d92 2d93 1
2d95 2 2d8e 2d97
2 2d99 2d9b 2
2d9d 2d9f 2 2da1
2da3 2 2da5 2da7
2 2da9 2dab 2
2dad 2daf c 2a9e
2aa3 2ad6 2b4f 2b55
2b5a 2b8d 2c06 2c0e
2ca9 2d22 2db2 1
2db7 2 2db9 2dba
1 2dbe 2 2dbc
2dbe 2 2dcc 2dce
2 2dd0 2dd2 2
2dd4 2dd6 2 2dd8
2dda 2 2ddc 2dde
2 2de0 2de2 2
2de4 2de6 2 2de8
2dea 2 2dec 2dee
2 2df0 2df2 1
2dfd 2 2dfc 2dfd
1 2e05 1 2e0b
2 2e0d 2e0e 2
2dfa 2e0f 1 2e16
1 2e11 2 2e29
2e2b 3 2e27 2e28
2e2d 2 2e36 2e38
2 2e3a 2e3c 2
2e3e 2e40 2 2e42
2e44 2 2e46 2e48
3 2e4d 2e4e 2e4f
2 2e4a 2e51 2
2e35 2e53 2 2e5a
2e5c 2 2e59 2e5e
2 2e55 2e60 1
2e62 2 2e20 2e63
1 2e67 1 2e1b
2 2e19 2e6b 2
2e7b 2e7d 2 2e7f
2e81 2 2e83 2e85
2 2e87 2e89 2
2e8b 2e8d 2 2e8f
2e91 2 2e93 2e95
2 2e97 2e99 2
2e9b 2e9d 1 2ea8
2 2ea7 2ea8 1
2eb0 1 2eb6 2
2eb8 2eb9 2 2ea5
2eba 1 2ec1 1
2ebc 2 2ed4 2ed6
3 2ed2 2ed3 2ed8
2 2ee1 2ee3 2
2ee5 2ee7 2 2ee9
2eeb 2 2eed 2eef
2 2ef1 2ef3 3
2ef8 2ef9 2efa 2
2ef5 2efc 2 2ee0
2efe 2 2f05 2f07
2 2f04 2f09 2
2f00 2f0b 1 2f0d
2 2ecb 2f0e 1
2f12 1 2ec6 2
2ec4 2f16 2 2f23
2f25 2 2f27 2f29
2 2f2b 2f2d 2
2f2f 2f31 2 2f33
2f35 2 2f37 2f39
2 2f3b 2f3d 2
2f3f 2f41 2 2f43
2f45 2 2f47 2f49
2 2f4b 2f4d 2
2f4f 2f51 2 2f53
2f55 2 2f57 2f59
2 2f5b 2f5d 2
2f5f 2f61 2 2f63
2f65 2 2f67 2f69
1 2f74 2 2f73
2f74 1 2f7c 1
2f82 2 2f84 2f85
2 2f71 2f86 1
2f8d 1 2f88 2
2fa0 2fa2 3 2f9e
2f9f 2fa4 2 2fad
2faf 2 2fb1 2fb3
2 2fb5 2fb7 2
2fb9 2fbb 2 2fbd
2fbf 3 2fc4 2fc5
2fc6 2 2fc1 2fc8
2 2fac 2fca 2
2fd1 2fd3 2 2fd0
2fd5 2 2fcc 2fd7
1 2fd9 2 2f97
2fda 1 2fde 1
2f92 2 2f90 2fe2
2 2fe8 2fea 2
2fec 2fee 2 2ff0
2ff2 2 2ff8 2ff9
1 2ffb 2 2ff4
2ffd 2 2fff 3001
2 3007 3008 1
300a 2 3003 300c
2 300e 3010 2
3012 3014 2 3016
3018 2 301a 301c
2 301e 3020 2
3022 3024 2 3026
3028 c 2dc5 2dca
2df5 2e6e 2e74 2e79
2ea0 2f19 2f21 2f6c
2fe5 302b 2 3039
303b 2 303d 303f
2 3041 3043 2
3045 3047 2 3049
304b 2 304d 304f
2 3051 3053 2
3055 3057 2 3059
305b 2 305d 305f
2 3061 3063 2
3065 3067 1 3072
2 3071 3072 1
307a 1 3080 2
3082 3083 2 306f
3084 1 308b 1
3086 2 309e 30a0
3 309c 309d 30a2
2 30ab 30ad 2
30af 30b1 2 30b3
30b5 2 30b7 30b9
2 30bb 30bd 3
30c2 30c3 30c4 2
30bf 30c6 2 30aa
30c8 2 30cf 30d1
2 30ce 30d3 2
30ca 30d5 1 30d7
2 3095 30d8 1
30dc 1 3090 2
308e 30e0 2 30f0
30f2 2 30f4 30f6
2 30f8 30fa 2
30fc 30fe 2 3100
3102 2 3104 3106
2 3108 310a 2
310c 310e 2 3110
3112 1 311d 2
311c 311d 1 3125
1 312b 2 312d
312e 2 311a 312f
1 3136 1 3131
2 3149 314b 3
3147 3148 314d 2
3156 3158 2 315a
315c 2 315e 3160
2 3162 3164 2
3166 3168 3 316d
316e 316f 2 316a
3171 2 3155 3173
2 317a 317c 2
3179 317e 2 3175
3180 1 3182 2
3140 3183 1 3187
1 313b 2 3139
318b 2 3198 319a
2 319c 319e 2
31a0 31a2 2 31a4
31a6 2 31a8 31aa
2 31ac 31ae 2
31b0 31b2 2 31b4
31b6 2 31b8 31ba
2 31bc 31be 2
31c0 31c2 2 31c4
31c6 2 31c8 31ca
2 31cc 31ce 2
31d0 31d2 2 31d4
31d6 1 31e1 2
31e0 31e1 1 31e9
1 31ef 2 31f1
31f2 2 31de 31f3
1 31fa 1 31f5
2 320d 320f 3
320b 320c 3211 2
321a 321c 2 321e
3220 2 3222 3224
2 3226 3228 2
322a 322c 3 3231
3232 3233 2 322e
3235 2 3219 3237
2 323e 3240 2
323d 3242 2 3239
3244 1 3246 2
3204 3247 1 324b
1 31ff 2 31fd
324f 2 3255 3257
2 3259 325b 2
325d 325f 2 3265
3266 1 3268 2
3261 326a 2 326c
326e 2 3270 3272
2 3278 3279 1
327b 2 3274 327d
2 327f 3281 2
3283 3285 2 3287
3289 2 328b 328d
2 328f 3291 2
3293 3295 2 3297
3299 2 329b 329d
c 3032 3037 306a
30e3 30e9 30ee 3115
318e 3196 31d9 3252
32a0 3 32a2 302d
32a3 2 32ad 32af
3 32ab 32ac 32b1
2 32ba 32bc 2
32b9 32be 1 32c0
1 32c2 2 32cc
32ce 3 32ca 32cb
32d0 2 32d9 32db
2 32d8 32dd 1
32df 1 32e1 1
32e7 2d 2fa 319
31c 31f 322 325
328 32b 32e 331
334 337 33a 33d
340 343 346 349
34c 356 359 35c
35f 3c3 427 4a5
600 603 60e 616
61e 621 b58 dc7
dcc dcf dd2 de6
df3 27a8 2a7d 32a4
32c3 32e2 32ea 2
32f7 32f9 3 32f5
32f6 32fb 2 3304
3306 2 3303 3308
2 330f 3313 2
3315 3317 2 3319
331d 2 330e 331f
2 330a 3321 1
3323 3 3324 332f
3333 1 32ee 2
3346 3348 3 3344
3345 334a 2 3353
3355 2 3352 3357
2 335e 3360 2
3362 3364 3 3369
336a 336b 2 3366
336d 2 335d 336f
2 3359 3371 1
3373 4 333d 3374
337d 3381 1 3385
1 3338 2 3336
3389 44 4b 52
59 60 67 6e
75 7c 83 8a
8f 94 9b a2
a9 b0 b7 be
c4 ca d0 d6
dc e2 e8 ee
f4 fa 100 106
10c 112 118 11e
124 12a 130 136
13c 142 148 14e
154 15a 160 166
16d 174 17a 181
187 18e 195 19c
1a2 1a8 1ae 1b5
1bc 1c2 1c8 1cf
1d5 1db 1e1 1e7
1ec 1f3 
1
4
0 
3390
0
1
a0
79
55
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 1 36 1
38 1 3a 1 3c 1 3e 1
40 1 42 43 42 45 42 47
42 49 42 4b 42 4d 42 4f
42 51 42 53 42 55 42 57
42 59 42 5b 42 5d 42 5f
42 61 1 63 1 65 1 67
1 69 1 6b 1 6d 1 6f
1 71 1 73 1 75 1 77
1 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3b 1 0
13e 1 0
2b 1 0
183 1 0
1dd 1 0
162 1 0
2f 1 0
1c4 1 0
ab 1 0
fc 1 0
15c 1 0
d8 1 0
1d7 1 0
27 1 0
189 1 0
1f 1 0
1b 1 0
1e3 1 0
96 1 0
279b 42 63
c0 1 0
9d 1 0
11a 1 0
17c 1 0
12c 1 0
8c 1 0
1e9 1 0
1a4 1 0
13 1 0
f6 1 0
1b0 1 0
ea 1 0
7e 1 0
1ca 1 0
16f 1 0
168 1 0
a4 1 0
77 1 0
f 1 0
e4 1 0
70 1 0
5b 1 0
3 1 0
c6 1 0
150 1 0
14a 1 0
1b7 1 0
85 1 0
19e 1 0
138 1 0
2 0 1
114 1 0
108 1 0
23 1 0
144 1 0
54 1 0
1d1 1 0
156 1 0
7 1 0
176 1 0
f0 1 0
de 1 0
132 1 0
d2 1 0
197 1 0
1be 1 0
1aa 1 0
cc 1 0
69 1 0
46 1 0
10e 1 0
37 1 0
4d 1 0
b2 1 0
120 1 0
17 1 0
91 1 0
b9 1 0
126 1 0
62 1 0
33 1 0
102 1 0
b 1 0
1ee 1 0
190 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_1;
ALTER FUNCTION SP_SEARCH_1 COMPILE DEBUG;
/*######################################################################################*/
/*######################################################################################*/
/*
#Stored Procedure  :SP_SEARCH_3
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_SEARCH_3 ==
CREATE OR REPLACE FUNCTION SP_SEARCH_3 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1dc
2 :e:
1FUNCTION:
1SP_SEARCH_3:
1PRJ_ID:
1VARCHAR2:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1TYPE001:
1AND_ROLES:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PROJECT_ID:
132:
1H_TASK_ID:
1H_REC_USER:
1H_RES_ID:
1H_START_DATE:
126:
1H_START_DT:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_REC_STATUS:
11:
1H_RES_TYPE:
1H_PA_TIMEPHASE:
1H_ASSIGN_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_AND_ROLES:
18000:
1H_SHW_ROLE:
1H_SHW_SKILL:
1H_SD:
1H_FD:
1H_FULL_NAME:
1255:
1H_COUNT:
10:
1H_BITFLAG:
1H_TYPE:
1H_UPDATE:
1H_WORK_TYPE:
1H_CRI:
1H_WORK:
1H_OCCURRENCE:
1H_EFFORT:
1H_EUNIT:
1H_UNIT:
1H_CONSIDER:
1H_CONTOUR:
1H_EVERY:
1H_PER_DAY:
1H_PER_WEEK:
1H_FROM_PRJ:
1H_DAYS:
1H_DURATION:
1H_NUMBER:
1H_TOTAL:
1H_TOTPR:
1H_PRIORITY:
1H_WEEK:
1H_RES_COST:
1NUMBER:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_AVAILABLE:
1H_ASSIGNED_WORK:
1H_REG_COST:
10.00:
1H_REG_SALE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1CHAR:
1H_TEMP2_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1STMT:
1H_TABLE_TYPE:
1H_TEMP_VAR:
1I:
1II:
1I_PA_SCHED:
1I_RETURN:
1ISF:
1NUMITEMS:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_SEARCH_3(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1107:
1+:
1FPUT:
1               ENTER:: SP_SEARCH_3(108) :: cplan.sql(4702) :: :
1GETTABLE:
1IS NULL:
18:
1143:
1      RETURN_INVALID:: SP_SEARCH_3(144) :: cplan.sql(4738) :: :
1 :
1STATE:: :
1PMO_CNST:
1ELEMENT_ID_REQUIRED:
1146:
1                EXIT:: SP_SEARCH_3(147) :: cplan.sql(4741) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1=:
15:
1153:
1      RETURN_INVALID:: SP_SEARCH_3(154) :: cplan.sql(4748) :: :
1INVALID_PARAMS:
1156:
1                EXIT:: SP_SEARCH_3(157) :: cplan.sql(4751) :: :
1!=:
1SC_SRCH_PARTICIPANT:
1IS NOT NULL:
1PMO_ORASTD:
1DAYS:
1DUAL:
1SELECT PMO_ORASTD.DAYS(finish_date001) - PMO_ORASTD.DAYS(start_date001):n    +
1     INTO h_total:n         FROM DUAL:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1175:
1           EXCEPTION:: SP_SEARCH_3(176) :: cplan.sql(4770) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_SUCCESS:
1<:
1182:
1      RETURN_INVALID:: SP_SEARCH_3(183) :: cplan.sql(4777) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1185:
1                EXIT:: SP_SEARCH_3(186) :: cplan.sql(4780) :: :
1ELSIF:
1SELECT SYSTIMESTAMP INTO h_start_date:n         FROM DUAL:
1203:
1           EXCEPTION:: SP_SEARCH_3(204) :: cplan.sql(4798) :: :
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1SC_SRCH_OVERALLOCATE:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), PRIORI+
1TY:n         INTO h_per_day, h_per_week, h_priority:n         FROM TMT_WBS WH+
1ERE ELEMENT_ID = h_project_id:
1233:
1           EXCEPTION:: SP_SEARCH_3(234) :: cplan.sql(4828) :: :
1SC_SQL_NO_DATA:
1TMT_POOLS:
1SELECT 480, 2400, 0 INTO h_per_day, h_per_week, h_priority FROM TMT_POOLS WHE+
1RE ELEMENT_ID = h_project_id:
1249:
1           EXCEPTION:: SP_SEARCH_3(250) :: cplan.sql(4844) :: :
1        RETURN_ERROR:: SP_SEARCH_3(256) :: cplan.sql(4850) :: :
1 ID:: :
1258:
1                EXIT:: SP_SEARCH_3(259) :: cplan.sql(4853) :: :
1PMO_RETURN_ERROR_SP:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1PROJECT_ID:
1SELECT LEVEL_LOCK INTO h_temp_var:n         FROM PROJECT_DETAILS:n         WH+
1ERE PROJECT_ID = h_project_id:
1277:
1           EXCEPTION:: SP_SEARCH_3(278) :: cplan.sql(4872) :: :
1>:
1REC_STATUS:
1SELECT REC_STATUS INTO h_rec_status:n            FROM TMT_WBS:n            WH+
1ERE ELEMENT_ID = h_project_id:
1295:
1           EXCEPTION:: SP_SEARCH_3(296) :: cplan.sql(4890) :: :
1STRCMP:
1L:
1302:
1        RETURN_ERROR:: SP_SEARCH_3(303) :: cplan.sql(4897) :: :
1LEV_LOCKED_BY_COPY:
1305:
1                EXIT:: SP_SEARCH_3(306) :: cplan.sql(4900) :: :
1313:
1      RETURN_INVALID:: SP_SEARCH_3(314) :: cplan.sql(4908) :: :
1316:
1                EXIT:: SP_SEARCH_3(317) :: cplan.sql(4911) :: :
1PMO_STPU:
1STRNPCPY:
133:
1ISPROJECTTYPE:
1TYPE_ID:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1SELECT PROJECT_ID, COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2+
1400), PRIORITY:n            INTO h_project_id, h_per_day, h_per_week, h_prior+
1ity:n            FROM TMT_WBS WHERE ELEMENT_ID = h_task_id AND TYPE_ID IN (pm+
1o_cnst.SC_PROJECT,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PRO+
1J_TYPE2,pmo_cnst.SC_PROJ_TYPE3):
1344:
1           EXCEPTION:: SP_SEARCH_3(345) :: cplan.sql(4939) :: :
1351:
1        RETURN_ERROR:: SP_SEARCH_3(352) :: cplan.sql(4946) :: :
1RECORD_NOT_FOUND:
1354:
1                EXIT:: SP_SEARCH_3(355) :: cplan.sql(4949) :: :
1360:
1        RETURN_ERROR:: SP_SEARCH_3(361) :: cplan.sql(4955) :: :
1363:
1                EXIT:: SP_SEARCH_3(364) :: cplan.sql(4958) :: :
1100:
1:
1FC_CALC_DURATION:
1386:
1      RETURN_INVALID:: SP_SEARCH_3(387) :: cplan.sql(4981) :: :
1389:
1                EXIT:: SP_SEARCH_3(390) :: cplan.sql(4984) :: :
1394:
1        RETURN_ERROR:: SP_SEARCH_3(395) :: cplan.sql(4989) :: :
1397:
1                EXIT:: SP_SEARCH_3(398) :: cplan.sql(4992) :: :
1*:
12:
13:
14:
1FC_DECLARE_PMO_TMP_SEARCH:
1TSK_ASSIGNMENT_ID:
1TO_DATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n            REG+
1ULAR_COST, REGULAR_RATE:n            INTO h_prj_assignment_id, h_SD, h_FD, h_+
1billable, h_capital_expense,:n            h_reg_cost, h_reg_sale:n           +
1 FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project_id AND RESOURCE_I+
1D=h_res_id AND RESOURCE_TYPE='1' AND BIT_FLAG='0':
1454:
1           EXCEPTION:: SP_SEARCH_3(455) :: cplan.sql(5049) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME INTO h_full_name FROM PROFILES WHERE PROFILE_ID = h_res_i+
1d:
1469:
1           EXCEPTION:: SP_SEARCH_3(470) :: cplan.sql(5064) :: :
1476:
1        RETURN_ERROR:: SP_SEARCH_3(477) :: cplan.sql(5071) :: :
1479:
1                EXIT:: SP_SEARCH_3(480) :: cplan.sql(5074) :: :
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1RESOURCE_ASSIGNMENTS:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_assign_id, h_number:n           +
1 FROM RESOURCE_ASSIGNMENTS:n            WHERE ELEMENT_ID = h_task_id AND RESO+
1URCE_TYPE = '1' AND RESOURCE_ID = h_res_id:
1498:
1           EXCEPTION:: SP_SEARCH_3(499) :: cplan.sql(5093) :: :
1NICK_NAME:
1RESOURCES:
1SELECT NICK_NAME INTO h_full_name FROM RESOURCES WHERE RESOURCE_ID = h_res_id:
1513:
1           EXCEPTION:: SP_SEARCH_3(514) :: cplan.sql(5108) :: :
1520:
1        RETURN_ERROR:: SP_SEARCH_3(521) :: cplan.sql(5115) :: :
1523:
1                EXIT:: SP_SEARCH_3(524) :: cplan.sql(5118) :: :
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n            REG+
1ULAR_COST, REGULAR_RATE:n            INTO h_prj_assignment_id, h_SD, h_FD, h_+
1billable, h_capital_expense,:n            h_reg_cost, h_reg_sale:n           +
1 FROM TASK_ASSIGNMENTS:n            WHERE TASK_ID=h_project_id AND RESOURCE_I+
1D=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='0':
1545:
1           EXCEPTION:: SP_SEARCH_3(546) :: cplan.sql(5140) :: :
1SELECT TSK_ASSIGNMENT_ID, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n               +
1REGULAR_COST, REGULAR_RATE :n               INTO h_prj_assignment_id, h_SD, h+
1_FD, h_billable, h_capital_expense,:n               h_reg_cost, h_reg_sale:n +
1              FROM TASK_ASSIGNMENTS:n               WHERE TASK_ID=h_project_i+
1d AND RESOURCE_ID=h_res_id AND RESOURCE_TYPE='0' AND BIT_FLAG='2':
1568:
1           EXCEPTION:: SP_SEARCH_3(569) :: cplan.sql(5163) :: :
1-:
1COUNT:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (SELECT 'X' FROM TAS+
1K_ASSIGNMENTS  :n                     WHERE PROJECT_ID = h_project_id AND TAS+
1K_ID <> PROJECT_ID AND RESOURCE_ID = h_res_id):
1589:
1           EXCEPTION:: SP_SEARCH_3(590) :: cplan.sql(5184) :: :
1595:
1        RETURN_ERROR:: SP_SEARCH_3(596) :: cplan.sql(5190) :: :
1CHILD_TASK_ASSIGNMENT_ALREADY_:
1598:
1                EXIT:: SP_SEARCH_3(599) :: cplan.sql(5193) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_assign_id, h_number:n           +
1 FROM RESOURCE_ASSIGNMENTS:n            WHERE ELEMENT_ID = h_task_id AND RESO+
1URCE_TYPE = '0' AND RESOURCE_ID = h_res_id:
1619:
1           EXCEPTION:: SP_SEARCH_3(620) :: cplan.sql(5214) :: :
1625:
1      RETURN_INVALID:: SP_SEARCH_3(626) :: cplan.sql(5220) :: :
1628:
1                EXIT:: SP_SEARCH_3(629) :: cplan.sql(5223) :: :
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1SC_PARTICIPANT_GROUP:
1SECURITY_ID:
1ELEMENT_TYPE:
1SC_AFFECTED:
1SC_TEAMMEMBER:
1BIT_OR:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT =:n            CASE:n            +
1WHEN SECURITY_ID = h_temp2_security_id AND ELEMENT_TYPE IN (pmo_cnst.SC_PROJE+
1CT,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PROJ_TYPE2,pmo_cns+
1t.SC_PROJ_TYPE3) THEN pmo_cnst.SC_AFFECTED:n            WHEN SECURITY_ID = h_+
1temp2_security_id THEN pmo_cnst.SC_TEAMMEMBER:n            WHEN SECURITY_ID =+
1 h_temp_security_id THEN pmo_cnst.SC_AFFECTED:n            ELSE PMO_STPU.BIT_+
1OR( PARTICIPANT, pmo_cnst.SC_TEAMMEMBER):n            END, SECURITY_ID =:n   +
1         CASE:n            WHEN SECURITY_ID = h_temp2_security_id THEN  h_tem+
1p_security_id:n            ELSE SECURITY_ID:n            END:n            WHE+
1RE RES_ASSIGNMENT_ID = h_assign_id:
1FOUND:
1665:
1           EXCEPTION:: SP_SEARCH_3(666) :: cplan.sql(5260) :: :
1FC_AFTER_U_RES_ASSIGN:
1SYS_GUID:
1FC_BEFORE_I_RES_ASSIGN:
1TABLE_TYPE:
1REC_USER:
1REC_DATETIME:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE, TABLE_TYPE,:n            RESOURCE_TYPE, RESOURCE_ID, PARTICIPANT+
1, SECURITY_ID, REC_USER, REC_DATETIME):n            VALUES (h_assign_id, h_pr+
1oject_id, h_task_id, h_type, h_table_type,:n            h_res_type, h_res_id,+
1 pmo_cnst.SC_AFFECTED, h_temp_security_id, rec_user001, SYSTIMESTAMP):
1701:
1           EXCEPTION:: SP_SEARCH_3(702) :: cplan.sql(5296) :: :
1TRUNC:
1TO_NUMBER:
1/:
110000.0:
10.5:
1NOT:
1STRNCMP:
110:
1>=:
1<=:
1MIN:
1TDY:
1DAY_YEAR:
1CALENDAR_DAY_OF_YEAR:
1CDY:
1TASK_DAY_OF_YEAR:
1ACTUAL_FLAG:
1AVAILABLE_MIN:
1SCHED_MIN:
1SELECT MIN(tdy.DAY_YEAR) INTO h_SD :n                  FROM CALENDAR_DAY_OF_Y+
1EAR cdy, TASK_DAY_OF_YEAR tdy :n                  WHERE tdy.PROJECT_ID = h_pr+
1oject_id :n                  AND tdy.TSK_ASSIGNMENT_ID = h_prj_assignment_id+
1:n                  AND tdy.DAY_YEAR >= TO_DATE(SubStr(h_start_DT, 1, 10)) :n+
1                  AND tdy.ACTUAL_FLAG = 0:n                  AND cdy.ELEMENT_+
1ID = h_res_id :n                  AND cdy.DAY_YEAR = tdy.DAY_YEAR:n          +
1        AND (cdy.AVAILABLE_MIN - tdy.SCHED_MIN) > 0:
1770:
1           EXCEPTION:: SP_SEARCH_3(771) :: cplan.sql(5365) :: :
1DB2TIMESTAMP:
1TIME:
1SELECT  PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_FD, 1, 10)) + 1     , PMO_OR+
1ASTD.TIME('00::00'))  INTO  h_start_DT FROM DUAL:
1787:
1           EXCEPTION:: SP_SEARCH_3(788) :: cplan.sql(5382) :: :
1LAST_AVAIL_TIME:
1BIT_SCHED:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_STPU.LAST_AVAIL_TIME(BIT_SCHED))+
1 INTO h_start_DT:n                     FROM TASK_DAY_OF_YEAR :n              +
1       WHERE PROJECT_ID = h_project_id :n                     AND TSK_ASSIGNM+
1ENT_ID = h_prj_assignment_id :n                     AND DAY_YEAR = h_SD:
1811:
1           EXCEPTION:: SP_SEARCH_3(812) :: cplan.sql(5406) :: :
1824:
1        RETURN_ERROR:: SP_SEARCH_3(825) :: cplan.sql(5419) :: :
1TASK_ASSIGNMENT_ERROR:
1827:
1                EXIT:: SP_SEARCH_3(828) :: cplan.sql(5422) :: :
1SUM:
1SELECT SUM(SCHED_MIN) INTO h_assigned_work:n               FROM TASK_DAY_OF_Y+
1EAR:n               WHERE PROJECT_ID = h_project_id :n               AND TSK_+
1ASSIGNMENT_ID = h_prj_assignment_id :n               AND DAY_YEAR BETWEEN TO_+
1DATE(SubStr(h_start_DT, 1, 10)) AND TO_DATE(SubStr(h_finish_DT, 1, 10)):
1847:
1           EXCEPTION:: SP_SEARCH_3(848) :: cplan.sql(5442) :: :
1SELECT SUM(AVAILABLE_MIN) INTO h_available:n               FROM CALENDAR_DAY_+
1OF_YEAR:n               WHERE ELEMENT_ID = h_res_id AND DAY_YEAR BETWEEN TO_D+
1ATE(SubStr(h_start_DT, 1, 10)) AND TO_DATE(SubStr(h_finish_DT, 1, 10)):
1865:
1           EXCEPTION:: SP_SEARCH_3(866) :: cplan.sql(5460) :: :
1872:
1        RETURN_ERROR:: SP_SEARCH_3(873) :: cplan.sql(5467) :: :
1875:
1                EXIT:: SP_SEARCH_3(876) :: cplan.sql(5470) :: :
1SC_SRCH_PROFILE:
1FC_SEARCH_2:
1PMO_TMP_SEARCH:
1PLANNED_SCHED_FLAG:
1RES_ID:
1UPDATE PMO_TMP_SEARCH SET PLANNED_SCHED_FLAG='0' WHERE RES_ID=h_res_id:
1915:
1           EXCEPTION:: SP_SEARCH_3(916) :: cplan.sql(5510) :: :
1LENGTH:
1WHILE:
1LOOP:
1',':
1START_DT:
1FINISH_DT:
1SELECT TSK_ASSIGNMENT_ID, START_DT, FINISH_DT :n               INTO h_prj_ass+
1ignment_id, h_start_DT, h_finish_DT :n               FROM TASK_ASSIGNMENTS :n+
1               WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id AND BIT_FL+
1AG='0':
1981:
1           EXCEPTION:: SP_SEARCH_3(982) :: cplan.sql(5576) :: :
1SELECT TSK_ASSIGNMENT_ID, START_DT, FINISH_DT :n                  INTO h_prj_+
1assignment_id, h_start_DT, h_finish_DT :n                  FROM TASK_ASSIGNME+
1NTS :n                  WHERE TASK_ID=h_project_id AND RESOURCE_ID=h_res_id A+
1ND BIT_FLAG='2':
11000:
1           EXCEPTION:: SP_SEARCH_3(1001) :: cplan.sql(5595) :: :
1SELECT MIN(tdy.DAY_YEAR) INTO h_SD :n                        FROM CALENDAR_DA+
1Y_OF_YEAR cdy, TASK_DAY_OF_YEAR tdy :n                        WHERE tdy.PROJE+
1CT_ID = h_project_id :n                        AND tdy.TSK_ASSIGNMENT_ID = h_+
1prj_assignment_id:n                        AND tdy.DAY_YEAR >= TO_DATE(SubStr+
1(h_start_date, 1, 10)) :n                        AND tdy.ACTUAL_FLAG = 0:n   +
1                     AND cdy.ELEMENT_ID = h_res_id :n                        +
1AND cdy.DAY_YEAR = tdy.DAY_YEAR:n                        AND (cdy.AVAILABLE_M+
1IN - tdy.SCHED_MIN) > 0:
11067:
1           EXCEPTION:: SP_SEARCH_3(1068) :: cplan.sql(5662) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_STPU.LAST_AVAIL_TIME(BIT_SCHED))+
1 INTO h_start_DT:n                           FROM TASK_DAY_OF_YEAR :n        +
1                   WHERE PROJECT_ID = h_project_id :n                        +
1   AND TSK_ASSIGNMENT_ID = h_prj_assignment_id :n                           A+
1ND DAY_YEAR = h_SD:
11086:
1           EXCEPTION:: SP_SEARCH_3(1087) :: cplan.sql(5681) :: :
1SELECT  (PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_start_DT, 1, 10)) + 1     ,+
1 PMO_ORASTD.TIME('00::00'))) :n                      INTO  h_start_DT FROM DU+
1AL:
11113:
1           EXCEPTION:: SP_SEARCH_3(1114) :: cplan.sql(5708) :: :
11159:
1           EXCEPTION:: SP_SEARCH_3(1160) :: cplan.sql(5754) :: :
11173:
1        RETURN_ERROR:: SP_SEARCH_3(1174) :: cplan.sql(5768) :: :
1CANNOT_ASSIGN_FROM_PROJECT_AFF:
11176:
1                EXIT:: SP_SEARCH_3(1177) :: cplan.sql(5771) :: :
1SELECT t.RESOURCE_ID AS ELEMENT_ID, t.RES_ASSIGNMENT_ID, p.FULL_NAME AS ELEME+
1NT_NAME, 13 AS TYPE_ID, :
1p.E_MAIL_ADDRESS,b.PLANNED_START,b.PLANNED_FINISH,b.BEST AS PLANNED_EFFORT, :
1a.SCHED_START AS START_DATE, a.SCHED_FINISH AS FINISH_DATE, a.BEST AS WORK, a+
1.SCHED_WORK AS REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR,rs.PLANNED AS PLANNED_WORK,:
1rs.SCHED AS SCHED_WORK, :
1 AS WORK_EFFORT, :
1 AS UNIT_EFFORT,(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILIT+
1Y,:
1 AS MINUTE_PER_DAY, rs.CONTOUR AS ASSIGN_STRING, rs.PLANNED_SCHED_FLAG, '' AS+
1 OBJECTIVES,'' AS RANK, p.EXTERNAL_ID, :
1p.LOGON_NAME, p.NICK_NAME, p.E_MAIL_ADDRESS AS RESOURCE_E_MAIL,p.WORK_LOCATIO+
1N, p.WORK_PHONE :
1FROM RESOURCE_ASSIGNMENTS t LEFT JOIN TASK_ASSIGNMENTS a ON a.RES_ASSIGNMENT_+
1ID=t.RES_ASSIGNMENT_ID AND a.BIT_FLAG='2' :
1LEFT JOIN TASK_ASSIGNMENTS b ON b.RES_ASSIGNMENT_ID=t.RES_ASSIGNMENT_ID AND b+
1.BIT_FLAG='0' :
1JOIN RESOURCES p ON t.RESOURCE_ID=p.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON t.RESOURCE_ID=rs.RES_ID :
1WHERE t.ELEMENT_ID=':
1' AND t.RESOURCE_TYPE='0' AND t.RESOURCE_ID IN (':
1') AND BITAND(t.PARTICIPANT, 4112) > 0 :
1UNION ALL :
1SELECT r.PROFILE_ID AS ELEMENT_ID, ta.RES_ASSIGNMENT_ID, r.PROFILE_NAME AS EL+
1EMENT_NAME, 41 AS TYPE_ID, :
1'' AS E_MAIL_ADDRESS,ta.PLANNED_START,ta.PLANNED_FINISH,ta.BEST AS PLANNED_EF+
1FORT,:
1STR_1899_12_31_00_00_00:
1 AS START_DATE, :
1 AS FINISH_DATE, 0 AS WORK, 0 AS REMAINING, :
1rs.START_DATE AS BEST_START, rs.FINISH_DATE AS BEST_FINISH, rs.ASSIGNABLE AS +
1CALENDAR, :
1rs.PLANNED AS PLANNED_WORK,rs.SCHED AS SCHED_WORK, :
1 AS UNIT_EFFORT,:
1(rs.ASSIGNABLE - rs.PLANNED - rs.SCHED) AS PERIOD_AVAILABILITY, :
1 AS MINUTE_PER_DAY , rs.CONTOUR AS ASSIGN_STRING, rs.PLANNED_SCHED_FLAG, '' A+
1S OBJECTIVES,'' AS RANK, '' AS EXTERNAL_ID, :
1'' AS LOGON_NAME, '' AS NICK_NAME, '' AS  RESOURCE_E_MAIL, 0 AS WORK_LOCATION+
1, '' AS WORK_PHONE :
1FROM TASK_ASSIGNMENTS ta JOIN PROFILES r ON ta.TASK_ID=':
1' AND ta.RESOURCE_TYPE='1' AND ta.RESOURCE_ID IN (':
1') AND r.PROFILE_ID=ta.RESOURCE_ID :
1LEFT OUTER JOIN PMO_TMP_SEARCH rs ON ta.RESOURCE_ID=rs.RES_ID :
1ORDER BY TYPE_ID:
11267:
1                EXIT:: SP_SEARCH_3(1268) :: cplan.sql(5862) :: :
11270:
1                EXIT:: SP_SEARCH_3(1271) :: cplan.sql(5865) :: :
1PMO_SELECT_READ:
1RETURN_ERROR_EXCEPTION:
11278:
1           EXCEPTION:: SP_SEARCH_3(1279) :: cplan.sql(5873) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11290:
1           EXCEPTION:: SP_SEARCH_3(1291) :: cplan.sql(5885) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2047
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 :2 a0 6b 1c 81 b0 :2 a0
6b :2 a0 6b 6e a5 b a 10
:2 a0 6b 6e :2 a0 6b 6e a5 b
6e 7e a0 b4 2e 6e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :4 a0 51
a5 b a5 b d a0 51 d
a0 51 d a0 7e b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e a 10 :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a0 7e b4 2e :2 5a
a 10 a0 7e b4 2e :2 5a a
10 :8 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c a0 51 d a0 b7 a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
a 10 :3 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :3 a0
6b :3 a0 51 a5 b :2 a0 6b a5
b 5a 51 a5 b d :4 a0 51
a5 b :2 a0 6b a5 b 5a d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e a0 51 d b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:b a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :6 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 19 3c a0 51 d :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 6e a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c b7 19
3c b7 a0 7e b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :2 a0 d :4 a0 :2 51 a5 b :2 51
a5 b d :3 a0 6b :3 51 a0 a5
b d :3 a0 51 a5 b a5 b
7e 51 b4 2e :18 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 19 3c b7 :2 19 3c :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 a0 51 d b7 19
3c a0 7e 51 b4 2e :2 a0 d
a0 6e d :6 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :3 a0 a5 b d :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
a0 b7 :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 51 a5 b :2 a0
a5 57 b7 :2 19 3c b7 :2 a0 d
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d b7 19 3c b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
52 10 a0 51 d a0 b7 :2 a0
51 a5 b 7e 51 b4 2e a0
51 d a0 b7 19 :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 a0 51 d a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e a0
51 d b7 :2 19 3c b7 19 3c
:2 a0 b4 2e d a0 6e d a0
6e d a0 6e d a0 6e d
:3 a0 :2 51 a5 b d :3 a0 :2 51 a5
b d :2 a0 51 a5 b 7e 51
b4 2e a0 4d d :2 a0 d :2 a0
:2 51 a5 b 7e 6e b4 2e :19 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :2 a0 d
:a a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 b7 :2 a0 :2 51 a5 b
7e 6e b4 2e :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :2 a0 d :19 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a a0 51
d :19 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a a0 7e 51 b4
2e d :3 a0 51 a5 b a5 b
7e 51 b4 2e a0 51 d :a a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c b7 19 3c b7 19
3c b7 19 3c :a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 51 :2 a0 51 a5
b :2 a0 6b a0 a5 b d :2 a0
51 :2 a0 51 a5 b :2 a0 6b a0
a5 b d :25 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 a5 b d b7
:2 a0 b4 2e d :2 a0 51 :2 a0 51
a5 b :2 a0 6b a0 a5 b d
:3 a0 6b d a0 51 d :9 a0 a5
b d :18 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e 5a a0 7e
b4 2e 5a a 10 a0 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b d b7 :5 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e 5a a5
b 7e 51 b4 2e 7e 51 b4
2e a5 b d b7 :2 19 3c :2 a0
:2 51 a5 b 7e 6e b4 2e 7e
b4 2e 5a a0 7e b4 2e 5a
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
5a 52 10 5a a 10 a0 4d
d :20 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e b4 2e 5a
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e :9 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 d b7 :2 a0
d :2 a0 d b7 :2 19 3c b7 :e a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 d b7 :2 19 3c b7 :2 a0
d :2 a0 d b7 :2 19 3c a0 7e
51 b4 2e :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e a 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c a0 b7 a0 7e 51 b4 2e
a0 51 d :f a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 51 d
:d a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e :2 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e 5a b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c b7
:2 19 3c b7 19 3c :2 a0 :2 51 a5
b 7e 6e b4 2e :3 a0 6b d
b7 :3 a0 51 a5 b d b7 :2 19
3c :1e a0 :6 51 a5 b d a0 7e
51 b4 2e :4 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c b7 a0
6e d a0 6e d :2 a0 d :3 a0
a5 b 51 a5 b 7e 51 b4
2e a0 51 d b7 :5 a0 a5 b
51 a5 b 7e 51 b4 2e 5a
7e 51 b4 2e a5 b d b7
:2 19 3c a0 7e 51 b4 2e a0
51 d :3 a0 51 a5 b a0 7e
a0 b4 2e 82 :3 a0 6b :2 51 :2 a0
51 a5 b 7e 51 b4 2e 7e
51 b4 2e a0 a5 b d :3 a0
6b :2 51 :2 a0 51 a5 b 7e 51
b4 2e 7e 51 b4 2e 7e 51
b4 2e a0 a5 b d :2 a0 :2 51
a5 b 7e 6e b4 2e :3 a0 6b
d :3 a0 a5 b 51 a5 b 7e
51 b4 2e :2 a0 d b7 :3 a0 7e
6e b4 2e :2 51 a5 b d :3 a0
7e a0 b4 2e :2 51 a5 b d
b7 :2 19 3c b7 :3 a0 51 a5 b
d :3 a0 a5 b 51 a5 b 7e
51 b4 2e :2 a0 d b7 :3 a0 7e
6e b4 2e :2 51 a5 b d :3 a0
7e a0 b4 2e :2 51 a5 b d
b7 :2 19 3c b7 :2 19 3c :2 a0 :2 51
a5 b 7e 6e b4 2e a0 51
d b7 19 3c a0 51 d a0
51 d :c a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :c a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 51 d b7 :2 a0 d b7 :2 19
3c b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e :3 a0 51 a5 b
d b7 :5 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e 5a a5 b
7e 51 b4 2e 7e 51 b4 2e
a5 b d b7 :2 19 3c :2 a0 :2 51
a5 b 7e 6e b4 2e 7e b4
2e 5a a0 7e b4 2e 5a :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 5a
52 10 5a a 10 a0 4d d
:20 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 7e b4 2e 5a :e a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 d b7 :2 a0 d :2 a0 d
b7 :2 19 3c b7 :2 a0 d :2 a0 d
b7 :2 19 3c a0 b7 :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e a 10 :9 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 :2 a0
d :2 a0 d b7 :2 19 3c b7 :2 a0
d :2 a0 d b7 :2 19 3c :2 a0 51
a5 b 7e 51 b4 2e :2 a0 :2 51
a5 b 7e 6e b4 2e a0 51
d b7 19 3c a0 b7 :2 a0 :2 51
a5 b 7e 6e b4 2e :3 a0 6b
d b7 19 :3 a0 51 a5 b d
b7 :2 19 3c :1e a0 :6 51 a5 b d
a0 7e 51 b4 2e :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
:3 a0 51 a5 b 7e 51 b4 2e
d b7 a0 47 b7 19 3c b7
:2 19 3c a0 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d b7
19 3c :3 a0 a5 b 51 a5 b
7e 51 b4 2e 5a :3 a0 a5 b
51 a5 b 7e 51 b4 2e 5a
a 10 a0 6e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e :3 a0 51 a5 b a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 51 a5 b a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
51 a5 b a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 51 a5 b a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e d a0 b7 :3 a0
a5 b 51 a5 b 7e 51 b4
2e a0 6e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 51 a5 b a5 b b4
2e 7e 6e b4 2e 7e :3 a0 51
a5 b a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e d a0
b7 19 :3 a0 a5 b 51 a5 b
7e 51 b4 2e a0 6e 7e 6e
b4 2e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 51 a5
b a5 b b4 2e 7e 6e b4
2e 7e :3 a0 51 a5 b a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 51 a5 b a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e d
b7 :2 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b a0 a5 b 65 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
2047
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 16a 155
159 15c 15d 165 154 187 175 151
179 17a 182 174 1a4 192 171 196
197 19f 191 1c1 1af 18e 1b3 1b4
1bc 1ae 1de 1cc 1ab 1d0 1d1 1d9
1cb 1fb 1e9 1c8 1ed 1ee 1f6 1e8
218 206 1e5 20a 20b 213 205 234
223 227 22f 202 250 23b 23f 242
243 24b 222 26d 25b 21f 25f 260
268 25a 28a 278 257 27c 27d 285
277 2a7 295 274 299 29a 2a2 294
2c4 2b2 291 2b6 2b7 2bf 2b1 2e1
2cf 2ae 2d3 2d4 2dc 2ce 2fe 2ec
2cb 2f0 2f1 2f9 2eb 31b 309 2e8
30d 30e 316 308 337 326 32a 332
305 34f 33e 342 34a 325 36c 35a
322 35e 35f 367 359 388 377 37b
356 383 376 3a4 393 397 373 39f
392 3c0 3af 3b3 38f 3bb 3ae 3dc
3cb 3cf 3ab 3d7 3ca 3f8 3e7 3eb
3c7 3f3 3e6 414 403 407 3e3 40f
402 430 41f 423 3ff 42b 41e 44c
43b 43f 41b 447 43a 468 457 45b
437 463 456 484 473 477 453 47f
472 4a0 48f 493 46f 49b 48e 4bc
4ab 4af 48b 4b7 4aa 4d8 4c7 4cb
4a7 4d3 4c6 4f4 4e3 4e7 4c3 4ef
4e2 510 4ff 503 4df 50b 4fe 52c
51b 51f 4fb 527 51a 548 537 53b
517 543 536 564 553 557 533 55f
552 580 56f 573 54f 57b 56e 59c
58b 58f 56b 597 58a 5b8 5a7 5ab
587 5b3 5a6 5d4 5c3 5c7 5a3 5cf
5c2 5f0 5df 5e3 5bf 5eb 5de 60c
5fb 5ff 5db 607 5fa 628 617 61b
5f7 623 616 644 633 637 613 63f
632 660 64f 653 62f 65b 64e 67c
66b 66f 64b 677 66a 698 687 68b
667 693 686 6b4 6a3 6a7 683 6af
6a2 6d0 6bf 6c3 69f 6cb 6be 6ec
6db 6df 6bb 6e7 6da 708 6f7 6fb
6d7 703 6f6 725 713 6f3 717 718
720 712 742 730 70f 734 735 73d
72f 75e 74d 751 72c 759 74c 77a
769 76d 749 775 768 797 785 765
789 78a 792 784 7b3 7a2 7a6 781
7ae 7a1 7cf 7be 7c2 79e 7ca 7bd
7eb 7da 7de 7ba 7e6 7d9 807 7f6
7fa 7d6 802 7f5 823 812 816 7f2
81e 811 83f 82e 832 80e 83a 82d
85b 84a 84e 82a 856 849 877 866
86a 872 846 896 87e 882 886 889
891 865 89d 8a1 862 8a5 8a9 8ad
8b0 8b5 8b6 1 8b8 8bd 8c1 8c5
8c8 8cd 8d1 8d5 8d8 8dd 8de 8e0
8e5 8e8 8ec 8ed 8f2 8f7 8fa 8ff
900 905 908 90c 90d 912 915 91a
91b 920 923 928 929 92e 931 936
937 93c 93f 943 944 949 94c 951
952 957 95a 95f 960 965 968 96d
96e 973 976 97a 97b 980 983 988
989 98e 991 996 997 99c 99f 9a3
9a7 9ab 9ac 9ae 9b3 9b4 9b6 9b7
9bc 9bf 9c4 9c5 9ca 9cd 9d1 9d5
9d9 9da 9dc 9e1 9e2 9e4 9e5 9ea
9ed 9f2 9f3 9f8 9fb 9ff a03 a07
a08 a0a a0f a10 a12 a13 a18 a1b
a20 a21 a26 a29 a2d a31 a35 a36
a38 a3d a3e a40 a41 a46 a49 a4e
a4f a54 a57 a5b a5f a63 a64 a66
a6b a6c a6e a6f a74 a77 a7c a7d
a82 a85 a89 a8d a91 a92 a94 a99
a9a a9c a9d aa2 aa5 aaa aab ab0
ab3 ab7 abb abf ac0 ac2 ac7 ac8
aca acb ad0 ad3 ad8 ad9 ade ae1
ae5 ae9 aed aee af0 af5 af6 af8
af9 afe b01 b06 b07 b0c b0f b13
b17 b1b b1c b1e b23 b24 b26 b27
b2c b2f b34 b35 b3a b3d b41 b45
b49 b4a b4c b51 b52 b54 b55 b5a
b5d b62 b63 b68 b6b b70 b71 b76
b79 b7d b7e b83 b86 b8b b8c b91
b94 b99 b9a b9f ba2 ba7 ba8 bad
bb0 bb4 bb5 bba bbd bc2 bc3 bc8
bcb bd0 bd1 bd6 bd7 bdc bde be2
be5 be9 bed bf0 bf4 bf8 bfb bfe
c03 c06 c09 c0c c0d c12 c13 1
c15 c1a c1e c22 c25 c2a c2f c32
c36 c37 c3c c3d c42 c44 c48 c4b
c4f c53 c57 c5b c5f c63 c67 c6b
c6f c73 c77 c7b c7f c83 c87 c8b
c8f c93 c97 c9b c9f ca3 ca7 cab
caf cb3 cb7 cbb cbf cc3 cc7 ccb
ccf cd3 cd7 cdb cdf ce3 ce7 ceb
cef cf3 cf7 cfb cff d03 d07 d0b
d0f d12 d13 d15 d16 d18 d1c d20
d23 d27 d2b d2e d32 d36 d39 d3a
d3f d42 d46 d4a d4d d51 d55 d58
d5b d60 d63 d66 d69 d6a d6f d70
1 d72 d77 d7b d7f d82 d87 d8c
d8f d93 d94 d99 d9c da1 da2 da7
daa daf db0 db5 db8 dbc dc0 dc4
dc8 dcb dcc dce dd3 dd4 dd6 dd7
ddc ddd de2 de4 de8 deb def df3
df6 dfa dfe e01 e04 e09 e0c e0f
e12 e13 e18 e19 1 e1b e20 e24
e28 e2b e30 e35 e38 e3c e3d e42
e43 e48 e4a e4e e51 e55 e59 e5c
e60 e64 e67 e6b e6c e71 e73 e77
e7a e7e e82 e85 e86 e88 e8b e8e
e8f e94 e98 e9c e9f ea0 ea2 ea5
ea8 ea9 1 eae eb3 eb7 ebb ebe
ebf ec1 ec4 ec7 ec8 1 ecd ed2
ed6 eda edd ee1 ee5 ee8 eeb ef0
ef3 ef6 ef9 efa eff f00 1 f02
f07 f0b f0f f12 f17 f1c f1f f23
f24 f29 f2c f31 f32 f37 f3a f3f
f40 f45 f48 f4c f50 f54 f58 f5b
f5c f5e f63 f64 f66 f67 f6c f6d
f72 f74 f78 f7b f7f f83 f86 f8a
f8e f91 f94 f99 f9c f9f fa2 fa3
fa8 fa9 1 fab fb0 fb4 fb8 fbb
fc0 fc5 fc8 fcc fcd fd2 fd3 fd8
fda fde fe1 fe5 fe9 fec ff0 ff4
ff7 ffb ffc 1001 1003 1007 100a 100e
1012 1015 1016 1018 101c 101f 1023 1026
1027 102c 102f 1033 1036 1037 103c 103f
1 1042 1047 104b 104e 104f 1054 1057
1 105a 105f 1063 1067 106b 106f 1073
1077 107b 107f 108b 108f 1093 1096 109a
109e 10a0 10a4 10a8 10ac 10af 10b3 10b7
10b9 10ba 10bf 1 10c3 10c7 10cb 10ce
10d2 10d6 10da 10de 10e1 10e5 10e9 10ec
10ef 10f4 10f7 10fa 10fd 10fe 1103 1104
1 1106 110b 110f 1113 1116 111b 1120
1123 1127 1128 112d 1130 1135 1136 113b
113e 1143 1144 1149 114c 1150 1151 1156
1159 115e 115f 1164 1167 116b 116f 1172
1175 1176 1178 1179 117e 117f 1184 1186
118a 118d 118f 1193 1195 11a1 11a3 11a5
11a6 11ab 11af 11b1 11bd 11bf 11c3 11c7
11ca 11ce 11d1 11d5 11d8 11d9 11de 11e1
11e5 11e9 11ec 11ed 11ef 11f2 11f5 11f6
11fb 1 11fe 1203 1207 120b 120e 1212
1216 1219 121c 1221 1224 1227 122a 122b
1230 1231 1 1233 1238 123c 1240 1243
1248 124d 1250 1254 1255 125a 125d 1262
1263 1268 126b 1270 1271 1276 1279 127d
1281 1285 1289 128c 128d 128f 1294 1295
1297 1298 129d 129e 12a3 12a5 12a9 12ac
12b0 12b4 12b7 12bb 12bf 12c2 12c5 12ca
12cd 12d0 12d3 12d4 12d9 12da 1 12dc
12e1 12e5 12e9 12ec 12f1 12f6 12f9 12fd
12fe 1303 1304 1309 130b 130f 1312 1316
131a 131d 1321 1325 1328 132c 132d 1332
1334 1338 133b 133f 1342 1346 134a 134c
1350 1353 1354 1359 135c 135f 1363 1366
1367 136c 136f 1 1372 1377 137b 137f
1383 138f 1393 1397 139a 139e 13a2 13a4
13a8 13ac 13b0 13b3 13b7 13bb 13bd 13be
13c3 1 13c7 13cb 13cf 13d2 13d6 13da
13de 13e2 13e5 13e9 13ed 13f0 13f3 13f8
13fb 13fe 1401 1402 1407 1408 1 140a
140f 1413 1417 141a 141f 1424 1427 142b
142c 1431 1434 1439 143a 143f 1442 1447
1448 144d 1450 1454 1455 145a 145d 1462
1463 1468 146b 146f 1473 1476 1479 147a
147c 147d 1482 1483 1488 148a 148e 1491
1493 1497 1499 14a5 14a7 14a9 14aa 14af
14b3 14b5 14c1 14c3 14c5 14c9 14cd 14d0
14d4 14d8 14dc 14df 14e3 14e7 14eb 14ee
14ef 14f1 14f5 14f9 14fc 14fd 14ff 1502
1505 1506 1508 150c 1510 1514 1518 151c
151f 1520 1522 1526 152a 152d 152e 1530
1533 1537 153b 153f 1542 1543 1545 1549
154c 1550 1553 1554 1559 155d 1560 1564
1566 156a 156d 1571 1575 1578 1579 157b
157e 1581 1582 1587 158b 158f 1593 1597
159b 159f 15a3 15a7 15ab 15af 15b3 15bf
15c3 15c7 15ca 15ce 15d2 15d4 15d8 15dc
15e0 15e3 15e7 15eb 15ed 15ee 15f3 1
15f7 15fb 15ff 1602 1606 160a 160e 1612
1615 1619 161d 1620 1623 1628 162b 162e
1631 1632 1637 1638 1 163a 163f 1643
1647 164a 164f 1654 1657 165b 165c 1661
1664 1669 166a 166f 1672 1677 1678 167d
1680 1684 1685 168a 168d 1692 1693 1698
169b 169f 16a3 16a6 16a9 16aa 16ac 16ad
16b2 16b3 16b8 16ba 16be 16c1 16c3 16c7
16c9 16d5 16d7 16d9 16da 16df 16e3 16e5
16f1 16f3 16f7 16fb 16fe 1702 1705 1709
170c 170d 1712 1715 1719 171d 1721 1725
1729 172d 1739 173d 1741 1744 1748 174c
174e 1752 1756 175a 175d 1761 1765 1767
1768 176d 1 1771 1775 1779 177c 1780
1784 1788 178c 178f 1793 1797 179a 179d
17a2 17a5 17a8 17ab 17ac 17b1 17b2 1
17b4 17b9 17bd 17c1 17c4 17c9 17ce 17d1
17d5 17d6 17db 17de 17e3 17e4 17e9 17ec
17f1 17f2 17f7 17fa 17fe 17ff 1804 1807
180c 180d 1812 1815 1819 181d 1820 1823
1824 1826 1827 182c 182d 1832 1834 1838
183b 183d 1841 1843 184f 1851 1853 1854
1859 185d 185f 186b 186d 1871 1875 1878
187c 187f 1883 1886 1887 188c 188f 1893
1897 189a 189e 18a2 18a5 18a8 18ad 18b0
18b3 18b6 18b7 18bc 18bd 1 18bf 18c4
18c8 18cc 18cf 18d4 18d9 18dc 18e0 18e1
18e6 18e9 18ee 18ef 18f4 18f7 18fc 18fd
1902 1905 1909 190d 1911 1915 1918 1919
191b 1920 1921 1923 1924 1929 192c 1931
1932 1937 193a 193f 1940 1945 1948 194c
194d 1952 1955 195a 195b 1960 1961 1966
1968 196c 196f 1973 1977 197a 197e 1982
1985 1988 198d 1990 1993 1996 1997 199c
199d 1 199f 19a4 19a8 19ac 19af 19b4
19b9 19bc 19c0 19c1 19c6 19c7 19cc 19ce
19d2 19d5 19d9 19dd 19e0 19e4 19e8 19eb
19ef 19f3 19f4 19f9 19fb 19ff 1a02 1a04
1a08 1a0b 1a0f 1a12 1a16 1a1a 1a1e 1a22
1a26 1a2a 1a36 1a3a 1a3e 1a41 1a45 1a49
1a4b 1a4f 1a53 1a57 1a5a 1a5e 1a62 1a64
1a65 1a6a 1 1a6e 1a72 1a76 1a79 1a7d
1a81 1a85 1a89 1a8c 1a90 1a94 1a97 1a9a
1a9f 1aa2 1aa5 1aa8 1aa9 1aae 1aaf 1
1ab1 1ab6 1aba 1abe 1ac1 1ac6 1acb 1ace
1ad2 1ad3 1ad8 1adb 1ae0 1ae1 1ae6 1ae9
1aee 1aef 1af4 1af7 1afb 1afc 1b01 1b04
1b09 1b0a 1b0f 1b12 1b16 1b1a 1b1d 1b20
1b21 1b23 1b24 1b29 1b2a 1b2f 1b31 1b35
1b38 1b3a 1b3e 1b40 1b4c 1b4e 1b50 1b51
1b56 1b5a 1b5c 1b68 1b6a 1b6e 1b72 1b75
1b76 1b78 1b7b 1b7e 1b7f 1b84 1b88 1b8c
1b90 1b94 1b98 1ba4 1ba8 1bac 1baf 1bb3
1bb7 1bb9 1bbd 1bc1 1bc5 1bc8 1bcc 1bd0
1bd2 1bd3 1bd8 1 1bdc 1be0 1be4 1be7
1beb 1bef 1bf3 1bf7 1bfa 1bfe 1c02 1c05
1c08 1c0d 1c10 1c13 1c16 1c17 1c1c 1c1d
1 1c1f 1c24 1c28 1c2c 1c2f 1c34 1c39
1c3c 1c40 1c41 1c46 1c49 1c4e 1c4f 1c54
1c57 1c5c 1c5d 1c62 1c65 1c69 1c6a 1c6f
1c72 1c77 1c78 1c7d 1c80 1c84 1c88 1c8b
1c8e 1c8f 1c91 1c92 1c97 1c98 1c9d 1c9f
1ca3 1ca6 1ca8 1cac 1cae 1cba 1cbc 1cbe
1cbf 1cc4 1cc8 1cca 1cd6 1cd8 1cdc 1ce0
1ce3 1ce7 1cec 1ced 1cef 1cf2 1cf5 1cf6
1cfb 1cff 1d03 1d06 1d0a 1d0e 1d11 1d14
1d19 1d1c 1d1f 1d22 1d23 1d28 1d29 1
1d2b 1d30 1d34 1d38 1d3b 1d40 1d45 1d48
1d4c 1d4d 1d52 1d55 1d5a 1d5b 1d60 1d63
1d68 1d69 1d6e 1d71 1d75 1d79 1d7d 1d81
1d84 1d85 1d87 1d8c 1d8d 1d8f 1d90 1d95
1d98 1d9d 1d9e 1da3 1da6 1dab 1dac 1db1
1db4 1db8 1db9 1dbe 1dc1 1dc6 1dc7 1dcc
1dcd 1dd2 1dd4 1dd8 1ddb 1ddf 1de3 1de6
1dea 1dee 1df1 1df4 1df9 1dfc 1dff 1e02
1e03 1e08 1e09 1 1e0b 1e10 1e14 1e18
1e1b 1e20 1e25 1e28 1e2c 1e2d 1e32 1e33
1e38 1e3a 1e3e 1e41 1e45 1e49 1e4c 1e50
1e54 1e57 1e5b 1e5f 1e60 1e65 1e67 1e6b
1e6e 1e70 1e74 1e77 1e79 1e7d 1e80 1e81
1e86 1e89 1e8d 1e91 1e94 1e98 1e9c 1e9f
1ea2 1ea7 1eaa 1ead 1eb0 1eb1 1eb6 1eb7
1 1eb9 1ebe 1ec2 1ec6 1ec9 1ece 1ed3
1ed6 1eda 1edb 1ee0 1ee3 1ee8 1ee9 1eee
1ef1 1ef6 1ef7 1efc 1eff 1f03 1f07 1f0b
1f0f 1f12 1f13 1f15 1f1a 1f1b 1f1d 1f1e
1f23 1f24 1f29 1f2b 1f2f 1f32 1f36 1f3a
1f3d 1f41 1f45 1f48 1f4b 1f50 1f53 1f56
1f59 1f5a 1f5f 1f60 1 1f62 1f67 1f6b
1f6f 1f72 1f77 1f7c 1f7f 1f83 1f84 1f89
1f8a 1f8f 1f91 1f95 1f98 1f9c 1fa0 1fa3
1fa7 1fab 1fae 1fb2 1fb3 1fb8 1fba 1fbe
1fc1 1fc5 1fc9 1fcd 1fd1 1fd5 1fd9 1fdd
1fe0 1fe3 1fe4 1fe6 1fe9 1fec 1fed 1fef
1ff3 1ff7 1ffb 1fff 2002 2005 2008 200b
200f 2010 2012 2016 201a 201e 2022 2025
2026 2028 2029 202b 202e 2031 2032 2037
203b 203f 2043 2047 204b 204f 2053 2057
205b 205f 2063 2067 206b 206f 2073 2077
207b 207f 2083 2087 208b 208f 2093 2097
20a3 20a7 20ab 20ae 20b2 20b6 20b8 20bc
20c0 20c4 20c7 20cb 20cf 20d1 20d2 20d7
1 20db 20df 20e3 20e6 20ea 20ee 20f2
20f6 20f9 20fd 2101 2104 2107 210c 210f
2112 2115 2116 211b 211c 1 211e 2123
2127 212b 212e 2133 2138 213b 213f 2140
2145 2148 214d 214e 2153 2156 215b 215c
2161 2164 2168 2169 216e 2171 2176 2177
217c 217f 2183 2187 218a 218d 218e 2190
2191 2196 2197 219c 219e 21a2 21a5 21a7
21ab 21ad 21b9 21bb 21bd 21be 21c3 21c7
21c9 21d5 21d7 21db 21df 21e2 21e6 21e9
21ed 21f0 21f1 21f6 21f9 21fd 2201 2204
2208 220c 220f 2212 2217 221a 221d 2220
2221 2226 2227 1 2229 222e 2232 2236
2239 223e 2243 2246 224a 224b 2250 2253
2258 2259 225e 2261 2266 2267 226c 226f
2273 2277 227b 227f 2282 2283 2285 228a
228b 228d 228e 2293 2296 229b 229c 22a1
22a4 22a9 22aa 22af 22b2 22b6 22b7 22bc
22bf 22c4 22c5 22ca 22cb 22d0 22d2 22d6
22d9 22dd 22e1 22e4 22e8 22ec 22ef 22f2
22f7 22fa 22fd 2300 2301 2306 2307 1
2309 230e 2312 2316 2319 231e 2323 2326
232a 232b 2330 2331 2336 2338 233c 233f
2343 2347 234a 234e 2352 2355 2359 235d
235e 2363 2365 2369 236c 236e 2372 2376
2379 237d 2381 2384 2387 238c 238f 2392
2395 2396 239b 239c 1 239e 23a3 23a7
23ab 23ae 23b3 23b8 23bb 23bf 23c0 23c5
23c8 23cd 23ce 23d3 23d6 23db 23dc 23e1
23e4 23e8 23ec 23f0 23f4 23f7 23f8 23fa
23ff 2400 2402 2403 2408 240b 2410 2411
2416 2419 241e 241f 2424 2427 242b 242c
2431 2434 2439 243a 243f 2440 2445 2447
244b 244e 2452 2456 2459 245d 2461 2464
2467 246c 246f 2472 2475 2476 247b 247c
1 247e 2483 2487 248b 248e 2493 2498
249b 249f 24a0 24a5 24a6 24ab 24ad 24b1
24b4 24b8 24bc 24bf 24c3 24c7 24ca 24ce
24d2 24d3 24d8 24da 24de 24e2 24e5 24e7
24eb 24ef 24f2 24f6 24fa 24fd 24fe 2500
2503 2506 2507 250c 250f 2513 2517 251a
251b 251d 2520 2523 2524 2529 1 252c
2531 2535 2538 253c 253e 2542 2545 2549
254c 254f 2550 2555 2559 255d 2561 2565
256a 256e 2572 2576 257a 257e 2582 2586
2589 258a 258c 2590 2594 2597 2598 259a
259e 25a2 25a5 25a6 25a8 25ac 25b0 25b3
25b4 25b6 25ba 25be 25c1 25c2 25c4 25c8
25cc 25cf 25d0 25d2 25d6 25da 25dd 25de
25e0 25e4 25e8 25eb 25ec 25ee 25f2 25f6
25fa 25fb 25fd 2601 2605 2609 260c 260d
260f 2613 2616 261a 261d 261e 2623 2627
262b 262e 2632 2636 2639 263c 2641 2644
2647 264a 264b 2650 2651 1 2653 2658
265c 2660 2663 2668 266d 2670 2674 2675
267a 267d 2682 2683 2688 268b 2690 2691
2696 2699 269d 26a1 26a5 26a9 26ac 26ad
26af 26b4 26b5 26b7 26b8 26bd 26be 26c3
26c5 26c9 26cc 26d0 26d4 26d7 26db 26df
26e2 26e5 26ea 26ed 26f0 26f3 26f4 26f9
26fa 1 26fc 2701 2705 2709 270c 2711
2716 2719 271d 271e 2723 2724 2729 272b
272f 2732 2736 273a 273d 2741 2745 2748
274c 274d 2752 2756 2758 275c 2760 2763
2764 2766 2769 276c 276d 2772 2776 277a
277d 2781 2785 2788 278b 2790 2793 2796
2799 279a 279f 27a0 1 27a2 27a7 27ab
27af 27b2 27b7 27bc 27bf 27c3 27c4 27c9
27cc 27d1 27d2 27d7 27da 27df 27e0 27e5
27e8 27ec 27f0 27f4 27f5 27f7 27fc 27fd
27ff 2800 2805 2808 280d 280e 2813 2816
281b 281c 2821 2824 2828 2829 282e 2831
2836 2837 283c 283d 2842 2844 2848 284b
284f 2853 2856 285a 285e 2861 2864 2869
286c 286f 2872 2873 2878 2879 1 287b
2880 2884 2888 288b 2890 2895 2898 289c
289d 28a2 28a3 28a8 28aa 28ae 28b1 28b5
28b9 28bc 28c0 28c4 28c7 28c8 28ca 28ce
28d2 28d3 28d8 28da 28de 28e2 28e5 28e7
28eb 28ef 28f3 28f7 28fb 28fe 28ff 2901
2904 2907 2908 290d 2911 2915 2919 291c
291d 291f 2922 2926 292a 292d 292e 2930
2931 2936 293a 293c 2940 2943 2945 2949
294d 2950 2954 2958 295b 295c 295e 2961
2964 2965 296a 296d 2971 2975 2978 2979
297b 297e 2981 2982 2987 1 298a 298f
2993 2997 299a 299b 299d 29a0 29a3 29a4
29a9 29ac 29b0 29b4 29b7 29b8 29ba 29bd
29c0 29c1 29c6 1 29c9 29ce 29d2 29d5
29d9 29dd 29df 29e3 29e7 29ea 29eb 29ed
29f0 29f3 29f4 29f9 29fd 2a00 2a04 2a08
2a0a 2a0e 2a12 2a16 2a19 2a1a 2a1c 2a1f
2a22 2a23 2a28 2a2b 2a2f 2a33 2a36 2a37
2a39 2a3c 2a3f 2a40 2a45 1 2a48 2a4d
2a51 2a54 2a58 2a5c 2a5e 2a62 2a66 2a6a
2a6d 2a6e 2a70 2a73 2a76 2a77 2a7c 2a80
2a83 2a87 2a89 2a8d 2a91 2a94 2a96 2a9a
2a9d 2aa1 2aa5 2aa6 2aab 2aaf 2ab3 2ab8
2abc 2ac0 2ac5 2ac9 2acd 2ad2 2ad6 2ada
2adf 2ae3 2ae7 2aeb 2aef 2af2 2af5 2af6
2af8 2afc 2b00 2b04 2b08 2b0b 2b0e 2b0f
2b11 2b15 2b19 2b1d 2b20 2b21 2b23 2b26
2b29 2b2a 2b2f 2b33 2b34 2b38 2b3c 2b40
2b44 2b48 2b4c 2b4f 2b52 2b53 2b55 2b58
2b5d 2b5e 2b63 2b67 2b6b 2b6f 2b73 2b77
2b7b 2b7f 2b83 2b87 2b8b 2b8f 2b93 2b97
2b9b 2b9f 2ba3 2ba7 2bab 2baf 2bb3 2bb7
2bbb 2bbf 2bc3 2bc7 2bd3 2bd7 2bdb 2bde
2be2 2be6 2be8 2bec 2bf0 2bf4 2bf7 2bfb
2bff 2c01 2c02 2c07 1 2c0b 2c0f 2c13
2c16 2c1a 2c1e 2c22 2c26 2c29 2c2d 2c31
2c34 2c37 2c3c 2c3f 2c42 2c45 2c46 2c4b
2c4c 1 2c4e 2c53 2c57 2c5b 2c5e 2c63
2c68 2c6b 2c6f 2c70 2c75 2c78 2c7d 2c7e
2c83 2c86 2c8b 2c8c 2c91 2c94 2c98 2c99
2c9e 2ca1 2ca6 2ca7 2cac 2caf 2cb3 2cb7
2cba 2cbd 2cbe 2cc0 2cc1 2cc6 2cc7 2ccc
2cce 2cd2 2cd5 2cd7 2cdb 2cdd 2ce9 2ceb
2ced 2cee 2cf3 2cf7 2cf9 2d05 2d07 2d0b
2d0f 2d13 2d17 2d1b 2d27 2d2b 2d2f 2d32
2d36 2d3a 2d3c 2d40 2d44 2d48 2d4b 2d4f
2d53 2d55 2d56 2d5b 1 2d5f 2d63 2d67
2d6a 2d6e 2d72 2d76 2d7a 2d7d 2d81 2d85
2d88 2d8b 2d90 2d93 2d96 2d99 2d9a 2d9f
2da0 1 2da2 2da7 2dab 2daf 2db2 2db7
2dbc 2dbf 2dc3 2dc4 2dc9 2dcc 2dd1 2dd2
2dd7 2dda 2ddf 2de0 2de5 2de8 2dec 2ded
2df2 2df5 2dfa 2dfb 2e00 2e03 2e07 2e0b
2e0e 2e11 2e12 2e14 2e15 2e1a 2e1b 2e20
2e22 2e26 2e29 2e2b 2e2f 2e31 2e3d 2e3f
2e41 2e42 2e47 2e4b 2e4d 2e59 2e5b 2e5f
2e63 2e66 2e6a 2e6d 2e71 2e74 2e75 2e7a
2e7d 2e81 2e85 2e88 2e8c 2e90 2e93 2e96
2e9b 2e9e 2ea1 2ea4 2ea5 2eaa 2eab 1
2ead 2eb2 2eb6 2eba 2ebd 2ec2 2ec7 2eca
2ece 2ecf 2ed4 2ed7 2edc 2edd 2ee2 2ee5
2eea 2eeb 2ef0 2ef3 2ef7 2efb 2eff 2f03
2f06 2f07 2f09 2f0e 2f0f 2f11 2f12 2f17
2f1a 2f1f 2f20 2f25 2f28 2f2d 2f2e 2f33
2f36 2f3a 2f3b 2f40 2f43 2f48 2f49 2f4e
2f4f 2f54 2f56 2f5a 2f5d 2f61 2f65 2f68
2f6c 2f70 2f73 2f76 2f7b 2f7e 2f81 2f84
2f85 2f8a 2f8b 1 2f8d 2f92 2f96 2f9a
2f9d 2fa2 2fa7 2faa 2fae 2faf 2fb4 2fb5
2fba 2fbc 2fc0 2fc3 2fc7 2fcb 2fce 2fd2
2fd6 2fd9 2fdd 2fe1 2fe2 2fe7 2fe9 2fed
2ff0 2ff4 2ff8 2ffc 3000 3004 3008 300c
3010 3014 3018 301c 3020 3024 3030 3034
3038 303b 303f 3043 3045 3049 304d 3051
3054 3058 305c 305e 305f 3064 1 3068
306c 3070 3073 3077 307b 307f 3083 3086
308a 308e 3091 3094 3099 309c 309f 30a2
30a3 30a8 30a9 1 30ab 30b0 30b4 30b8
30bb 30c0 30c5 30c8 30cc 30cd 30d2 30d5
30da 30db 30e0 30e3 30e8 30e9 30ee 30f1
30f5 30f6 30fb 30fe 3103 3104 3109 310c
3110 3114 3117 311a 311b 311d 311e 3123
3124 3129 312b 312f 3132 3134 3138 313a
3146 3148 314a 314b 3150 3154 3156 3162
3164 3168 316a 316e 3172 3175 3178 3179
317b 317e 3183 3184 3189 318d 3191 3195
3199 319d 31a9 31ad 31b1 31b4 31b8 31bc
31be 31c2 31c6 31ca 31cd 31d1 31d5 31d7
31d8 31dd 1 31e1 31e5 31e9 31ec 31f0
31f4 31f8 31fc 31ff 3203 3207 320a 320d
3212 3215 3218 321b 321c 3221 3222 1
3224 3229 322d 3231 3234 3239 323e 3241
3245 3246 324b 324e 3253 3254 3259 325c
3261 3262 3267 326a 326e 326f 3274 3277
327c 327d 3282 3285 3289 328d 3290 3293
3294 3296 3297 329c 329d 32a2 32a4 32a8
32ab 32ad 32b1 32b3 32bf 32c1 32c3 32c4
32c9 32cd 32cf 32db 32dd 32e1 32e5 32e8
32ec 32ef 32f3 32f6 32f7 32fc 32ff 3303
3307 330a 330e 3312 3315 3318 331d 3320
3323 3326 3327 332c 332d 1 332f 3334
3338 333c 333f 3344 3349 334c 3350 3351
3356 3359 335e 335f 3364 3367 336c 336d
3372 3375 3379 337d 3381 3385 3388 3389
338b 3390 3391 3393 3394 3399 339c 33a1
33a2 33a7 33aa 33af 33b0 33b5 33b8 33bc
33bd 33c2 33c5 33ca 33cb 33d0 33d1 33d6
33d8 33dc 33df 33e3 33e7 33ea 33ee 33f2
33f5 33f8 33fd 3400 3403 3406 3407 340c
340d 1 340f 3414 3418 341c 341f 3424
3429 342c 3430 3431 3436 3437 343c 343e
3442 3445 3449 344d 3450 3454 3458 345b
345f 3463 3464 3469 346b 346f 3472 3476
347a 347e 3482 3486 348a 348e 3492 3496
349a 349e 34a2 34a6 34aa 34ae 34b2 34b6
34ba 34be 34c2 34c6 34ca 34ce 34d2 34d6
34da 34de 34e2 34ee 34f2 34f6 34f9 34fd
3501 3503 3507 350b 350f 3512 3516 351a
351c 351d 3522 1 3526 352a 352e 3531
3535 3539 353d 3541 3544 3548 354c 354f
3552 3557 355a 355d 3560 3561 3566 3567
1 3569 356e 3572 3576 3579 357e 3583
3586 358a 358b 3590 3593 3598 3599 359e
35a1 35a6 35a7 35ac 35af 35b3 35b4 35b9
35bc 35c1 35c2 35c7 35ca 35ce 35d2 35d5
35d8 35d9 35db 35dc 35e1 35e2 35e7 35e9
35ed 35f0 35f2 35f6 35f8 3604 3606 3608
3609 360e 3612 3614 3620 3622 3626 362a
362d 3631 3634 3638 363b 363c 3641 3644
3648 364b 364f 3653 3657 365b 365f 3663
3667 366b 366f 3673 3677 367b 367f 3683
3687 368b 368f 3693 3697 369b 369f 36a3
36a7 36ab 36af 36b3 36bf 36c3 36c7 36ca
36ce 36d2 36d4 36d8 36dc 36e0 36e3 36e7
36eb 36ed 36ee 36f3 1 36f7 36fb 36ff
3702 3706 370a 370e 3712 3715 3719 371d
3720 3723 3728 372b 372e 3731 3732 3737
3738 1 373a 373f 3743 3747 374a 374f
3754 3757 375b 375c 3761 3764 3769 376a
376f 3772 3777 3778 377d 3780 3784 3785
378a 378d 3792 3793 3798 379b 379f 37a3
37a6 37a9 37aa 37ac 37ad 37b2 37b3 37b8
37ba 37be 37c1 37c3 37c7 37c9 37d5 37d7
37d9 37da 37df 37e3 37e5 37f1 37f3 37f7
37fb 37fe 3802 3805 3809 380c 380d 3812
3815 3819 381c 381f 3820 3825 3829 382d
3831 3835 3838 3839 383b 383c 383e 3841
3844 3845 384a 384e 3851 3855 3859 385d
3861 3865 3869 386d 3871 3875 3879 387d
3889 388d 3891 3894 3898 389c 389e 38a2
38a6 38aa 38ad 38b1 38b5 38b7 38b8 38bd
1 38c1 38c5 38c9 38cc 38d0 38d4 38d8
38dc 38df 38e3 38e7 38ea 38ed 38f2 38f5
38f8 38fb 38fc 3901 3902 1 3904 3909
390d 3911 3914 3919 391e 3921 3925 3926
392b 392e 3933 3934 3939 393c 3941 3942
3947 394a 394e 394f 3954 3957 395c 395d
3962 3965 3969 396d 3970 3973 3974 3976
3977 397c 397d 3982 3984 3988 398b 398d
3991 3993 399f 39a1 39a3 39a4 39a9 39ad
39af 39bb 39bd 39c1 39c5 39c8 39c9 39cb
39ce 39d1 39d2 39d7 39db 39df 39e2 39e6
39ea 39ed 39f0 39f5 39f8 39fb 39fe 39ff
3a04 3a05 1 3a07 3a0c 3a10 3a14 3a17
3a1c 3a21 3a24 3a28 3a29 3a2e 3a31 3a36
3a37 3a3c 3a3f 3a44 3a45 3a4a 3a4d 3a51
3a55 3a59 3a5d 3a60 3a61 3a63 3a68 3a69
3a6b 3a6c 3a71 3a74 3a79 3a7a 3a7f 3a82
3a87 3a88 3a8d 3a90 3a94 3a95 3a9a 3a9d
3aa2 3aa3 3aa8 3aa9 3aae 3ab0 3ab4 3ab7
3abb 3abf 3ac2 3ac6 3aca 3acd 3ad0 3ad5
3ad8 3adb 3ade 3adf 3ae4 3ae5 1 3ae7
3aec 3af0 3af4 3af7 3afc 3b01 3b04 3b08
3b09 3b0e 3b0f 3b14 3b16 3b1a 3b1d 3b21
3b25 3b28 3b2c 3b30 3b33 3b37 3b3b 3b3c
3b41 3b43 3b47 3b4a 3b4c 3b50 3b53 3b55
3b59 3b5c 3b5e 3b62 3b65 3b69 3b6d 3b71
3b75 3b79 3b7d 3b81 3b85 3b89 3b8d 3b99
3b9d 3ba1 3ba4 3ba8 3bac 3bae 3bb2 3bb6
3bba 3bbd 3bc1 3bc5 3bc7 3bc8 3bcd 1
3bd1 3bd5 3bd9 3bdc 3be0 3be4 3be8 3bec
3bef 3bf3 3bf7 3bfa 3bfd 3c02 3c05 3c08
3c0b 3c0c 3c11 3c12 1 3c14 3c19 3c1d
3c21 3c24 3c29 3c2e 3c31 3c35 3c36 3c3b
3c3e 3c43 3c44 3c49 3c4c 3c51 3c52 3c57
3c5a 3c5e 3c5f 3c64 3c67 3c6c 3c6d 3c72
3c75 3c79 3c7d 3c80 3c83 3c84 3c86 3c87
3c8c 3c8d 3c92 3c94 3c98 3c9b 3c9d 3ca1
3ca3 3caf 3cb1 3cb3 3cb4 3cb9 3cbd 3cbf
3ccb 3ccd 3ccf 3cd3 3cd7 3cdb 3cde 3ce2
3ce6 3ce9 3cec 3cf1 3cf4 3cf7 3cfa 3cfb
3d00 3d01 1 3d03 3d08 3d0c 3d10 3d13
3d18 3d1d 3d20 3d24 3d25 3d2a 3d2d 3d32
3d33 3d38 3d3b 3d40 3d41 3d46 3d49 3d4d
3d51 3d55 3d59 3d5c 3d5d 3d5f 3d64 3d65
3d67 3d68 3d6d 3d6e 3d73 3d75 3d79 3d7c
3d80 3d84 3d87 3d8b 3d8f 3d92 3d95 3d9a
3d9d 3da0 3da3 3da4 3da9 3daa 1 3dac
3db1 3db5 3db9 3dbc 3dc1 3dc6 3dc9 3dcd
3dce 3dd3 3dd4 3dd9 3ddb 3ddf 3de2 3de6
3dea 3ded 3df1 3df5 3df8 3dfc 3dfd 3e02
3e04 3e08 3e0c 3e0f 3e13 3e17 3e1a 3e1e
3e21 3e25 3e28 3e29 3e2e 3e31 3e35 3e39
3e3c 3e40 3e44 3e47 3e48 3e4a 3e4e 3e52
3e55 3e59 3e5a 3e5c 3e60 3e64 3e68 3e6b
3e6f 3e73 3e76 3e77 3e79 3e7d 3e81 3e84
3e88 3e89 3e8b 3e8f 3e93 3e97 3e9b 3e9f
3ea3 3ea7 3eab 3eaf 3eb3 3eb7 3ebb 3ebf
3ec3 3ec7 3ecb 3ecf 3ed3 3ed7 3edb 3edf
3ee3 3ee7 3eeb 3eef 3ef3 3ef7 3efb 3eff
3f03 3f07 3f0b 3f0f 3f13 3f17 3f1b 3f1f
3f23 3f2f 3f33 3f38 3f3c 3f3f 3f40 3f45
3f49 3f4d 3f50 3f53 3f57 3f59 3f5d 3f61
3f64 3f67 3f6b 3f6d 3f71 3f75 3f78 3f7a
3f7e 3f82 3f86 3f89 3f8d 3f91 3f93 3f94
3f99 1 3f9d 3fa1 3fa5 3fa8 3fac 3fb0
3fb4 3fb8 3fbb 3fbf 3fc3 3fc6 3fc9 3fce
3fd1 3fd4 3fd7 3fd8 3fdd 3fde 1 3fe0
3fe5 3fe9 3fed 3ff0 3ff5 3ffa 3ffd 4001
4002 4007 400a 400f 4010 4015 4018 401d
401e 4023 4026 402a 402b 4030 4033 4038
4039 403e 4041 4045 4049 404c 404f 4050
4052 4053 4058 4059 405e 4060 4064 4067
4069 406d 406f 407b 407d 407f 4080 4085
4089 408b 4097 4099 409d 40a1 40a5 40a6
40a8 40ac 40ae 40b2 40b6 40b7 40bc 40c0
40c4 40c8 40cb 40cf 40d3 40d6 40d7 40d9
40dd 40e1 40e4 40e8 40e9 40eb 40ef 40f3
40f7 40fb 40fe 4102 4106 4109 410d 4111
4115 4119 411d 4121 4125 4129 412d 4131
4132 4134 4138 413c 4140 4144 4148 414c
4150 4154 4158 415c 4160 4164 4168 416c
4170 4174 4178 417c 4180 4184 4188 418c
4190 4194 4198 41a4 41a8 41ad 41b1 41b4
41b5 41ba 41be 41c2 41c5 41c8 41cc 41ce
41d2 41d6 41d9 41dc 41e0 41e2 41e6 41ea
41ed 41ef 41f3 41f7 41fb 41fe 4202 4206
4208 4209 420e 1 4212 4216 421a 421d
4221 4225 4229 422d 4230 4234 4238 423b
423e 4243 4246 4249 424c 424d 4252 4253
1 4255 425a 425e 4262 4265 426a 426f
4272 4276 4277 427c 427f 4284 4285 428a
428d 4292 4293 4298 429b 429f 42a0 42a5
42a8 42ad 42ae 42b3 42b6 42ba 42be 42c1
42c4 42c5 42c7 42c8 42cd 42ce 42d3 42d5
42d9 42dc 42de 42e2 42e4 42f0 42f2 42f4
42f5 42fa 42fe 4300 430c 430e 4310 4314
4318 431b 431f 4323 4326 4327 4329 432c
432f 4330 4335 4338 433c 433f 4340 4345
1 4348 434d 4351 4354 4357 4358 435d
1 4360 4365 4369 436d 4370 4371 4373
4376 4379 437a 437f 4383 4387 438a 438b
438d 4390 4393 4394 4399 439d 43a1 43a5
43a8 43a9 43ab 43af 43b1 43b5 43b9 43bd
43c1 43c5 43c8 43c9 43cb 43ce 43d2 43d6
43d9 43da 43dc 43dd 43e2 43e5 43e6 43e8
43eb 43ee 43ef 43f4 43f7 43fa 43fb 4400
4401 4403 4407 4409 440d 4411 4414 4418
441c 441f 4422 4423 4425 4428 442d 442e
4433 4436 4437 443c 443f 4443 4446 4447
444c 444f 4453 4457 445a 445e 4462 4465
4466 4468 446b 446e 446f 4474 4477 447b
447f 4482 4486 448a 448d 448e 4490 4493
4496 4497 449c 1 449f 44a4 1 44a7
44ac 1 44af 44b4 44b8 44b9 44bd 44c1
44c5 44c9 44cd 44d1 44d5 44d9 44dd 44e1
44e5 44e9 44ed 44f1 44f5 44f9 44fd 4501
4505 4509 450d 4511 4515 4519 451d 4521
4525 4529 452d 4531 4535 4539 453d 4549
454d 4551 4554 4558 455c 455e 4562 4566
456a 456d 4571 4575 4577 4578 457d 1
4581 4585 4589 458c 4590 4594 4598 459c
459f 45a3 45a7 45aa 45ad 45b2 45b5 45b8
45bb 45bc 45c1 45c2 1 45c4 45c9 45cd
45d1 45d4 45d9 45de 45e1 45e5 45e6 45eb
45ee 45f3 45f4 45f9 45fc 4601 4602 4607
460a 460e 460f 4614 4617 461c 461d 4622
4625 4629 462d 4630 4633 4634 4636 4637
463c 463d 4642 4644 4648 464b 464d 4651
4653 465f 4661 4663 4664 4669 466d 466f
467b 467d 4681 4684 4685 468a 468d 4691
4695 4698 469c 46a0 46a3 46a4 46a6 46a9
46ac 46ad 46b2 46b6 46ba 46be 46c2 46c6
46ca 46ce 46d2 46d6 46e2 46e6 46ea 46ed
46f1 46f5 46f7 46fb 46ff 4703 4706 470a
470e 4710 4711 4716 1 471a 471e 4722
4725 4729 472d 4731 4735 4738 473c 4740
4743 4746 474b 474e 4751 4754 4755 475a
475b 1 475d 4762 4766 476a 476d 4772
4777 477a 477e 477f 4784 4787 478c 478d
4792 4795 479a 479b 47a0 47a3 47a7 47a8
47ad 47b0 47b5 47b6 47bb 47be 47c2 47c6
47c9 47cc 47cd 47cf 47d0 47d5 47d6 47db
47dd 47e1 47e4 47e6 47ea 47ec 47f8 47fa
47fc 47fd 4802 4806 4808 4814 4816 481a
481e 4822 4824 4828 482c 4830 4834 4838
483c 483e 4842 4846 4849 484b 484f 4853
4857 485b 485f 4863 4867 486b 486f 4873
4877 487b 487f 4883 488f 4893 4897 489a
489e 48a2 48a4 48a8 48ac 48b0 48b3 48b7
48bb 48bd 48be 48c3 1 48c7 48cb 48cf
48d2 48d6 48da 48de 48e2 48e5 48e9 48ed
48f0 48f3 48f8 48fb 48fe 4901 4902 4907
4908 1 490a 490f 4913 4917 491a 491f
4924 4927 492b 492c 4931 4934 4939 493a
493f 4942 4947 4948 494d 4950 4954 4955
495a 495d 4962 4963 4968 496b 496f 4973
4976 4979 497a 497c 497d 4982 4983 4988
498a 498e 4991 4993 4997 4999 49a5 49a7
49a9 49aa 49af 49b3 49b5 49c1 49c3 49c7
49cb 49cf 49d1 49d5 49d9 49dc 49de 49e2
49e6 49ea 49ee 49f2 49f6 49f8 49fc 4a00
4a03 4a07 4a0a 4a0d 4a0e 4a13 4a17 4a1b
4a1e 4a22 4a26 4a29 4a2a 4a2c 4a2f 4a32
4a33 1 4a38 4a3d 4a41 4a45 4a48 4a4c
4a50 4a53 4a56 4a5b 4a5e 4a61 4a64 4a65
4a6a 4a6b 1 4a6d 4a72 4a76 4a7a 4a7d
4a82 4a87 4a8a 4a8e 4a8f 4a94 4a97 4a9c
4a9d 4aa2 4aa5 4aaa 4aab 4ab0 4ab3 4ab7
4abb 4abf 4ac3 4ac6 4ac7 4ac9 4ace 4acf
4ad1 4ad2 4ad7 4ada 4adf 4ae0 4ae5 4ae8
4aed 4aee 4af3 4af6 4afa 4afb 4b00 4b03
4b08 4b09 4b0e 4b0f 4b14 4b16 4b1a 4b1d
4b21 4b25 4b28 4b2c 4b30 4b33 4b36 4b3b
4b3e 4b41 4b44 4b45 4b4a 4b4b 1 4b4d
4b52 4b56 4b5a 4b5d 4b62 4b67 4b6a 4b6e
4b6f 4b74 4b75 4b7a 4b7c 4b80 4b83 4b87
4b8b 4b8e 4b92 4b96 4b99 4b9d 4ba1 4ba2
4ba7 4ba9 4bad 4bb0 4bb4 4bb6 4bba 4bbd
4bc0 4bc1 4bc6 4bca 4bcd 4bd1 4bd5 4bd9
4bdd 4be1 4be5 4be9 4bed 4bf1 4bf5 4bf9
4bfd 4c01 4c05 4c09 4c0d 4c19 4c1d 4c21
4c24 4c28 4c2c 4c2e 4c32 4c36 4c3a 4c3d
4c41 4c45 4c47 4c48 4c4d 1 4c51 4c55
4c59 4c5c 4c60 4c64 4c68 4c6c 4c6f 4c73
4c77 4c7a 4c7d 4c82 4c85 4c88 4c8b 4c8c
4c91 4c92 1 4c94 4c99 4c9d 4ca1 4ca4
4ca9 4cae 4cb1 4cb5 4cb6 4cbb 4cbe 4cc3
4cc4 4cc9 4ccc 4cd1 4cd2 4cd7 4cda 4cde
4cdf 4ce4 4ce7 4cec 4ced 4cf2 4cf5 4cf9
4cfd 4d00 4d03 4d04 4d06 4d07 4d0c 4d0d
4d12 4d14 4d18 4d1b 4d1d 4d21 4d23 4d2f
4d31 4d33 4d34 4d39 4d3d 4d3f 4d4b 4d4d
4d51 4d54 4d58 4d5c 4d60 4d64 4d68 4d6c
4d70 4d74 4d78 4d7c 4d80 4d84 4d88 4d8c
4d98 4d9c 4da0 4da3 4da7 4dab 4dad 4db1
4db5 4db9 4dbc 4dc0 4dc4 4dc6 4dc7 4dcc
1 4dd0 4dd4 4dd8 4ddb 4ddf 4de3 4de7
4deb 4dee 4df2 4df6 4df9 4dfc 4e01 4e04
4e07 4e0a 4e0b 4e10 4e11 1 4e13 4e18
4e1c 4e20 4e23 4e28 4e2d 4e30 4e34 4e35
4e3a 4e3d 4e42 4e43 4e48 4e4b 4e50 4e51
4e56 4e59 4e5d 4e5e 4e63 4e66 4e6b 4e6c
4e71 4e74 4e78 4e7c 4e7f 4e82 4e83 4e85
4e86 4e8b 4e8c 4e91 4e93 4e97 4e9a 4e9c
4ea0 4ea2 4eae 4eb0 4eb2 4eb3 4eb8 4ebc
4ebe 4eca 4ecc 4ed0 4ed4 4ed7 4ed8 4eda
4edd 4ee1 4ee5 4ee8 4ee9 4eeb 4eee 4ef2
4ef6 4ef9 4efa 4efc 4efd 4f02 4f05 4f06
4f0b 4f0f 4f13 4f16 4f1a 4f1e 4f21 4f24
4f29 4f2c 4f2f 4f32 4f33 4f38 4f39 1
4f3b 4f40 4f44 4f48 4f4b 4f50 4f55 4f58
4f5c 4f5d 4f62 4f65 4f6a 4f6b 4f70 4f73
4f78 4f79 4f7e 4f81 4f85 4f89 4f8d 4f91
4f94 4f95 4f97 4f9c 4f9d 4f9f 4fa0 4fa5
4fa8 4fad 4fae 4fb3 4fb6 4fbb 4fbc 4fc1
4fc4 4fc8 4fc9 4fce 4fd1 4fd6 4fd7 4fdc
4fdd 4fe2 4fe4 4fe8 4feb 4fef 4ff3 4ff6
4ffa 4ffe 5001 5004 5009 500c 500f 5012
5013 5018 5019 1 501b 5020 5024 5028
502b 5030 5035 5038 503c 503d 5042 5043
5048 504a 504e 5051 5055 5059 505c 5060
5064 5067 506b 506f 5070 5075 5077 507b
507e 5080 5084 5088 508b 508d 5091 5094
5098 509c 509f 50a2 50a3 50a5 50a8 50ad
50ae 50b3 50b7 50bb 50bf 50c2 50c6 50c8
50cc 50d0 50d4 50d7 50d8 50da 50de 50e0
50e4 50e8 50eb 50ef 50f3 50f7 50fb 50ff
5103 5107 510b 510f 5113 5117 511b 511f
5123 5127 512b 512f 5133 5137 513b 513f
5143 5147 514b 514f 5153 5157 515b 515f
5163 5166 5169 516c 516f 5172 5175 5176
5178 517c 5180 5183 5186 5187 518c 5190
5194 5198 519c 51a8 51ac 51b1 51b5 51b8
51b9 51be 51c2 51c6 51c9 51cc 51d0 51d2
51d6 51da 51dd 51e0 51e4 51e6 51ea 51ee
51f1 51f3 51f7 51fb 51ff 5202 5206 520a
520c 520d 5212 1 5216 521a 521e 5221
5225 5229 522d 5231 5234 5238 523c 523f
5242 5247 524a 524d 5250 5251 5256 5257
1 5259 525e 5262 5266 5269 526e 5273
5276 527a 527b 5280 5283 5288 5289 528e
5291 5296 5297 529c 529f 52a3 52a4 52a9
52ac 52b1 52b2 52b7 52ba 52be 52c2 52c5
52c8 52c9 52cb 52cc 52d1 52d2 52d7 52d9
52dd 52e0 52e2 52e6 52e8 52f4 52f6 52f8
52f9 52fe 5302 5304 5310 5312 5314 5318
531b 531d 5321 5326 532a 532e 5333 5337
533b 533f 5343 5347 534b 534f 5350 5352
5355 5356 5358 535b 535e 535f 5364 5368
536b 536f 5371 5375 5379 537d 5381 5385
5386 5388 538b 538c 538e 5391 5394 5395
539a 539d 53a0 53a3 53a4 53a9 53aa 53ac
53b0 53b2 53b6 53ba 53bd 53c1 53c4 53c7
53c8 53cd 53d1 53d4 53d8 53dc 53e0 53e4
53e7 53e8 53ea 53ee 53f1 53f5 53f6 53fb
53fd 5401 5405 5409 540c 540f 5412 5416
541a 541d 541e 5420 5423 5426 5427 542c
542f 5432 5433 5438 543c 543d 543f 5443
5447 544b 544f 5452 5455 5458 545c 5460
5463 5464 5466 5469 546c 546d 5472 5475
5478 5479 547e 5481 5484 5485 548a 548e
548f 5491 5495 5499 549d 54a0 54a3 54a4
54a6 54a9 54ae 54af 54b4 54b8 54bc 54c0
54c3 54c7 54cb 54cf 54d3 54d4 54d6 54d9
54da 54dc 54df 54e2 54e3 54e8 54ec 54f0
54f4 54f6 54fa 54fe 5502 5505 550a 550b
5510 5513 5516 5517 5519 551d 5521 5525
5529 552c 5530 5531 5536 5539 553c 553d
553f 5543 5545 5549 554d 5550 5552 5556
555a 555e 5561 5562 5564 5568 556c 5570
5574 5575 5577 557a 557b 557d 5580 5583
5584 5589 558d 5591 5595 5597 559b 559f
55a3 55a6 55ab 55ac 55b1 55b4 55b7 55b8
55ba 55be 55c2 55c6 55ca 55cd 55d1 55d2
55d7 55da 55dd 55de 55e0 55e4 55e6 55ea
55ee 55f1 55f3 55f7 55fb 55fe 5602 5606
5609 560c 560d 560f 5612 5617 5618 561d
5621 5624 5628 562a 562e 5631 5635 5638
563c 5640 5643 5647 564b 564f 5653 5657
565b 565f 5663 5667 566b 566f 5673 5677
5683 5687 568b 568e 5692 5696 5698 569c
56a0 56a4 56a7 56ab 56af 56b1 56b2 56b7
1 56bb 56bf 56c3 56c6 56ca 56ce 56d2
56d6 56d9 56dd 56e1 56e4 56e7 56ec 56ef
56f2 56f5 56f6 56fb 56fc 1 56fe 5703
5707 570b 570e 5713 5718 571b 571f 5720
5725 5728 572d 572e 5733 5736 573b 573c
5741 5744 5748 5749 574e 5751 5756 5757
575c 575f 5763 5767 576a 576d 576e 5770
5771 5776 5777 577c 577e 5782 5785 5787
578b 578d 5799 579b 579d 579e 57a3 57a7
57a9 57b5 57b7 57bb 57bf 57c2 57c6 57c9
57cd 57d0 57d1 57d6 57d9 57dd 57e1 57e5
57e9 57ed 57f1 57f5 57f9 57fd 5801 5805
5809 5815 5819 581d 5820 5824 5828 582a
582e 5832 5836 5839 583d 5841 5843 5844
5849 1 584d 5851 5855 5858 585c 5860
5864 5868 586b 586f 5873 5876 5879 587e
5881 5884 5887 5888 588d 588e 1 5890
5895 5899 589d 58a0 58a5 58aa 58ad 58b1
58b2 58b7 58ba 58bf 58c0 58c5 58c8 58cd
58ce 58d3 58d6 58da 58db 58e0 58e3 58e8
58e9 58ee 58f1 58f5 58f9 58fc 58ff 5900
5902 5903 5908 5909 590e 5910 5914 5917
5919 591d 591f 592b 592d 592f 5930 5935
5939 593b 5947 5949 594d 5951 5954 5958
595b 595f 5962 5963 5968 596b 596f 5972
5976 5978 597c 5980 5984 5986 598a 598e
5991 5993 5997 599a 599e 59a2 59a5 59a6
59a8 59ab 59ae 59af 59b4 59b8 59bc 59bf
59c0 59c2 59c5 59c8 59c9 59ce 59d2 59d6
59d9 59da 59dc 59df 59e2 59e3 59e8 59ec
59f0 59f4 59f7 59f8 59fa 59fe 5a00 5a04
5a08 5a0c 5a10 5a14 5a17 5a18 5a1a 5a1d
5a21 5a25 5a28 5a29 5a2b 5a2c 5a31 5a34
5a35 5a37 5a3a 5a3d 5a3e 5a43 5a46 5a49
5a4a 5a4f 5a50 5a52 5a56 5a58 5a5c 5a60
5a63 5a67 5a6b 5a6e 5a71 5a72 5a74 5a77
5a7c 5a7d 5a82 5a85 5a86 5a8b 5a8e 5a92
5a95 5a96 5a9b 5a9e 5aa2 5aa6 5aa9 5aad
5ab1 5ab4 5ab5 5ab7 5aba 5abd 5abe 5ac3
5ac6 5aca 5ace 5ad1 5ad5 5ad9 5adc 5add
5adf 5ae2 5ae5 5ae6 5aeb 1 5aee 5af3
1 5af6 5afb 1 5afe 5b03 5b07 5b08
5b0c 5b10 5b14 5b18 5b1c 5b20 5b24 5b28
5b2c 5b30 5b34 5b38 5b3c 5b40 5b44 5b48
5b4c 5b50 5b54 5b58 5b5c 5b60 5b64 5b68
5b6c 5b70 5b74 5b78 5b7c 5b80 5b84 5b88
5b8c 5b98 5b9c 5ba0 5ba3 5ba7 5bab 5bad
5bb1 5bb5 5bb9 5bbc 5bc0 5bc4 5bc6 5bc7
5bcc 1 5bd0 5bd4 5bd8 5bdb 5bdf 5be3
5be7 5beb 5bee 5bf2 5bf6 5bf9 5bfc 5c01
5c04 5c07 5c0a 5c0b 5c10 5c11 1 5c13
5c18 5c1c 5c20 5c23 5c28 5c2d 5c30 5c34
5c35 5c3a 5c3d 5c42 5c43 5c48 5c4b 5c50
5c51 5c56 5c59 5c5d 5c5e 5c63 5c66 5c6b
5c6c 5c71 5c74 5c78 5c7c 5c7f 5c82 5c83
5c85 5c86 5c8b 5c8c 5c91 5c93 5c97 5c9a
5c9c 5ca0 5ca2 5cae 5cb0 5cb2 5cb3 5cb8
5cbc 5cbe 5cca 5ccc 5cd0 5cd3 5cd4 5cd9
5cdc 5ce0 5ce4 5ce8 5cec 5cf0 5cf4 5cf8
5cfc 5d00 5d04 5d08 5d0c 5d10 5d14 5d20
5d24 5d28 5d2b 5d2f 5d33 5d35 5d39 5d3d
5d41 5d44 5d48 5d4c 5d4e 5d4f 5d54 1
5d58 5d5c 5d60 5d63 5d67 5d6b 5d6f 5d73
5d76 5d7a 5d7e 5d81 5d84 5d89 5d8c 5d8f
5d92 5d93 5d98 5d99 1 5d9b 5da0 5da4
5da8 5dab 5db0 5db5 5db8 5dbc 5dbd 5dc2
5dc5 5dca 5dcb 5dd0 5dd3 5dd8 5dd9 5dde
5de1 5de5 5de6 5deb 5dee 5df3 5df4 5df9
5dfc 5e00 5e04 5e07 5e0a 5e0b 5e0d 5e0e
5e13 5e14 5e19 5e1b 5e1f 5e22 5e24 5e28
5e2a 5e36 5e38 5e3a 5e3b 5e40 5e44 5e46
5e52 5e54 5e58 5e5c 5e60 5e62 5e66 5e6a
5e6e 5e72 5e76 5e7a 5e7c 5e80 5e84 5e87
5e89 5e8d 5e91 5e95 5e99 5e9d 5ea1 5ea3
5ea7 5eab 5eae 5eb2 5eb4 5eb8 5ebc 5ebf
5ec3 5ec7 5eca 5ecb 5ecd 5ed0 5ed3 5ed4
5ed9 5edd 5ee1 5ee4 5ee8 5eec 5eef 5ef0
5ef2 5ef5 5ef8 5ef9 1 5efe 5f03 5f07
5f0b 5f0f 5f13 5f17 5f1b 5f1f 5f23 5f27
5f33 5f37 5f3b 5f3e 5f42 5f46 5f48 5f4c
5f50 5f54 5f57 5f5b 5f5f 5f61 5f62 5f67
1 5f6b 5f6f 5f73 5f76 5f7a 5f7e 5f82
5f86 5f89 5f8d 5f91 5f94 5f97 5f9c 5f9f
5fa2 5fa5 5fa6 5fab 5fac 1 5fae 5fb3
5fb7 5fbb 5fbe 5fc3 5fc8 5fcb 5fcf 5fd0
5fd5 5fd8 5fdd 5fde 5fe3 5fe6 5feb 5fec
5ff1 5ff4 5ff8 5ff9 5ffe 6001 6006 6007
600c 600f 6013 6017 601a 601d 601e 6020
6021 6026 6027 602c 602e 6032 6035 6037
603b 603d 6049 604b 604d 604e 6053 6057
6059 6065 6067 6069 606d 6071 6075 6079
607d 6081 6085 6087 608b 608f 6092 6094
6098 609c 60a0 60a4 60a8 60ac 60ae 60b2
60b6 60b9 60bd 60c1 60c4 60c5 60c7 60ca
60cd 60ce 60d3 60d7 60db 60de 60e1 60e2
60e4 60e7 60ec 60ed 60f2 60f6 60f9 60fd
60ff 6103 6106 610a 610c 6110 6114 6117
611a 611b 611d 6120 6125 6126 612b 612f
6133 6137 613a 613e 6140 6144 6148 614c
6150 6153 6154 6156 615a 615c 6160 6164
6167 616b 616f 6173 6177 617b 617f 6183
6187 618b 618f 6193 6197 619b 619f 61a3
61a7 61ab 61af 61b3 61b7 61bb 61bf 61c3
61c7 61cb 61cf 61d3 61d7 61db 61df 61e2
61e5 61e8 61eb 61ee 61f1 61f2 61f4 61f8
61fc 61ff 6202 6203 6208 620c 6210 6214
6218 6224 6228 622d 6231 6234 6235 623a
623e 6242 6245 6248 624c 624e 6252 6256
6259 625c 6260 6262 6266 626a 626d 626f
6273 6277 627b 627e 6282 6286 6288 6289
628e 1 6292 6296 629a 629d 62a1 62a5
62a9 62ad 62b0 62b4 62b8 62bb 62be 62c3
62c6 62c9 62cc 62cd 62d2 62d3 1 62d5
62da 62de 62e2 62e5 62ea 62ef 62f2 62f6
62f7 62fc 62ff 6304 6305 630a 630d 6312
6313 6318 631b 631f 6320 6325 6328 632d
632e 6333 6336 633a 633e 6341 6344 6345
6347 6348 634d 634e 6353 6355 6359 635c
635e 6362 6364 6370 6372 6374 6375 637a
637e 6380 638c 638e 6390 6394 6397 639b
639f 63a3 63a6 63a7 63a9 63ac 63af 63b0
63b5 63b9 63bb 63bf 63c6 63c8 63cc 63cf
63d1 63d5 63d9 63dc 63e0 63e3 63e6 63e7
63ec 63ef 63f3 63f7 63fa 63fb 63fd 6400
6403 6404 6409 1 640c 6411 6415 6419
641c 6420 6424 6427 642a 642f 6432 6435
6438 6439 643e 643f 1 6441 6446 644a
644e 6451 6456 645b 645e 6462 6463 6468
646b 6470 6471 6476 6479 647e 647f 6484
6487 648b 648f 6493 6497 649a 649b 649d
64a2 64a3 64a5 64a6 64ab 64ae 64b3 64b4
64b9 64bc 64c1 64c2 64c7 64ca 64ce 64cf
64d4 64d7 64dc 64dd 64e2 64e3 64e8 64ea
64ee 64f1 64f5 64f9 64fc 6500 6504 6507
650a 650f 6512 6515 6518 6519 651e 651f
1 6521 6526 652a 652e 6531 6536 653b
653e 6542 6543 6548 6549 654e 6550 6554
6557 655b 655f 6562 6566 656a 656d 6571
6575 6576 657b 657d 6581 6584 6588 658c
658f 6590 6592 6595 6598 6599 659e 65a2
65a6 65aa 65ac 65b0 65b3 65b7 65bb 65bf
65c0 65c2 65c5 65c6 65c8 65cb 65ce 65cf
65d4 65d7 65db 65df 65e3 65e4 65e6 65e9
65ea 65ec 65ef 65f2 65f3 65f8 1 65fb
6600 6604 6609 660c 6611 6612 6617 661a
661f 6620 6625 6628 662d 662e 6633 6636
663b 663c 6641 6644 6648 664c 6650 6653
6654 6656 6657 6659 665a 665f 6662 6667
6668 666d 6670 6674 6678 667c 667f 6680
6682 6683 6685 6686 668b 668e 6693 6694
6699 669c 66a0 66a4 66a8 66ab 66ac 66ae
66af 66b1 66b2 66b7 66ba 66bf 66c0 66c5
66c8 66cd 66ce 66d3 66d6 66db 66dc 66e1
66e4 66e9 66ea 66ef 66f2 66f7 66f8 66fd
6700 6705 6706 670b 670e 6713 6714 6719
671c 6720 6721 6726 6729 672e 672f 6734
6737 673b 673c 6741 6744 6749 674a 674f
6752 6757 6758 675d 6760 6765 6766 676b
676e 6773 6774 6779 677c 6780 6784 6787
6788 678d 6790 6795 6796 679b 679e 67a2
67a6 67a9 67aa 67af 67b2 67b7 67b8 67bd
67c0 67c5 67c6 67cb 67ce 67d3 67d4 67d9
67dc 67e0 67e4 67e8 67eb 67ec 67ee 67ef
67f1 67f2 67f7 67fa 67ff 6800 6805 6808
680c 6810 6814 6817 6818 681a 681b 681d
681e 6823 6826 682b 682c 6831 6834 6839
683a 683f 6842 6846 684a 684e 6851 6852
6854 6855 6857 6858 685d 6860 6865 6866
686b 686e 6873 6874 6879 687c 6881 6882
6887 688a 688e 688f 6894 6897 689c 689d
68a2 68a5 68a9 68aa 68af 68b2 68b7 68b8
68bd 68c0 68c5 68c6 68cb 68ce 68d3 68d4
68d9 68dd 68e1 68e3 68e7 68eb 68ef 68f0
68f2 68f5 68f6 68f8 68fb 68fe 68ff 6904
6908 690d 6910 6915 6916 691b 691e 6923
6924 6929 692c 6931 6932 6937 693a 693f
6940 6945 6948 694c 6950 6954 6957 6958
695a 695b 695d 695e 6963 6966 696b 696c
6971 6974 6978 697c 6980 6983 6984 6986
6987 6989 698a 698f 6992 6997 6998 699d
69a0 69a4 69a8 69ac 69af 69b0 69b2 69b3
69b5 69b6 69bb 69be 69c3 69c4 69c9 69cc
69d1 69d2 69d7 69da 69df 69e0 69e5 69e8
69ed 69ee 69f3 69f6 69fb 69fc 6a01 6a04
6a09 6a0a 6a0f 6a12 6a17 6a18 6a1d 6a20
6a24 6a25 6a2a 6a2d 6a32 6a33 6a38 6a3b
6a3f 6a40 6a45 6a48 6a4d 6a4e 6a53 6a56
6a5b 6a5c 6a61 6a65 6a69 6a6b 6a6f 6a73
6a77 6a7b 6a7c 6a7e 6a81 6a82 6a84 6a87
6a8a 6a8b 6a90 6a94 6a99 6a9c 6aa1 6aa2
6aa7 6aaa 6aae 6ab2 6ab5 6ab6 6abb 6abe
6ac3 6ac4 6ac9 6acc 6ad0 6ad4 6ad7 6ad8
6add 6ae0 6ae5 6ae6 6aeb 6aee 6af3 6af4
6af9 6afc 6b01 6b02 6b07 6b0a 6b0e 6b12
6b16 6b19 6b1a 6b1c 6b1d 6b1f 6b20 6b25
6b28 6b2d 6b2e 6b33 6b36 6b3a 6b3e 6b42
6b45 6b46 6b48 6b49 6b4b 6b4c 6b51 6b54
6b59 6b5a 6b5f 6b62 6b67 6b68 6b6d 6b70
6b74 6b78 6b7c 6b7f 6b80 6b82 6b83 6b85
6b86 6b8b 6b8e 6b93 6b94 6b99 6b9c 6ba1
6ba2 6ba7 6baa 6baf 6bb0 6bb5 6bb8 6bbc
6bbd 6bc2 6bc5 6bca 6bcb 6bd0 6bd3 6bd7
6bd8 6bdd 6be0 6be5 6be6 6beb 6bee 6bf3
6bf4 6bf9 6bfc 6c01 6c02 6c07 6c0b 6c0d
6c11 6c15 6c18 6c1c 6c20 6c23 6c27 6c2b
6c2e 6c31 6c36 6c39 6c3c 6c3f 6c40 6c45
6c46 1 6c48 6c4d 6c51 6c55 6c58 6c5d
6c62 6c65 6c69 6c6a 6c6f 6c70 6c75 6c77
6c7b 6c7e 6c82 6c86 6c89 6c8d 6c91 6c94
6c97 6c9c 6c9f 6ca2 6ca5 6ca6 6cab 6cac
1 6cae 6cb3 6cb7 6cbb 6cbe 6cc3 6cc8
6ccb 6ccf 6cd0 6cd5 6cd6 6cdb 6cdd 6ce1
6ce4 6ce8 6cec 6cf0 6cf3 6cf7 6cf8 6cfa
6cfe 6d00 6d04 6d08 6d0b 6d0f 6d13 6d16
6d1a 6d1e 6d21 6d24 6d29 6d2c 6d2f 6d32
6d33 6d38 6d39 1 6d3b 6d40 6d44 6d48
6d4b 6d50 6d55 6d58 6d5c 6d5d 6d62 6d63
6d68 6d6c 6d70 6d73 6d78 6d7d 6d80 6d84
6d88 6d8b 6d8c 6d91 6d94 6d99 6d9a 6d9f
6da2 6da6 6daa 6dad 6dae 6db3 6db4 6db9
6dbb 6dbf 6dc2 6dc6 6dca 6dce 6dd2 6dd6
6dda 6dde 6de2 6de6 6df2 6df7 6dfb 6dff
6e03 6e07 6e09 6e0a 6e0f 1 6e13 6e17
6e1b 6e1e 6e22 6e26 6e2a 6e2e 6e31 6e35
6e39 6e3c 6e3f 6e44 6e47 6e4a 6e4d 6e4e
6e53 6e54 1 6e56 6e5b 6e5f 6e63 6e66
6e6b 6e70 6e73 6e77 6e78 6e7d 6e7e 6e83
6e87 6e8b 6e8e 6e93 6e98 6e9b 6e9f 6ea0
6ea5 6ea8 6ead 6eae 6eb3 6eb6 6eba 6ebe
6ec1 6ec4 6ec5 6ec7 6ec8 6ecd 6ece 6ed3
6ed5 6ed9 6edc 6ee0 6ee4 6ee8 6eec 6ef0
6ef4 6ef8 6f04 6f09 6f0d 6f11 6f15 6f19
6f1b 6f1f 6f21 6f2d 6f2f 6f31 6f32 6f37
6f3b 6f3d 6f49 6f4d 6f4f 6f50 6f59 
2047
2
0 1 a 6 d :3 6 14 :3 6
15 :3 6 10 :3 6 e :3 6 11 :3 6
c :3 6 b :3 6 11 :3 6 11 :3 6
1d :3 6 10 :3 6 e :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 e 17
16 :2 e :2 4 f 18 17 :2 f :2 4
d 16 15 :2 d :2 4 11 1a 19
:2 11 :2 4 f 18 17 :2 f :2 4 10
19 18 :2 10 :2 4 :3 10 :2 4 11 1a
19 :2 11 :2 4 f 18 17 :2 f :2 4
13 1c 1b :2 13 :2 4 10 19 18
:2 10 :2 4 18 21 20 :2 18 :2 4 10
19 18 :2 10 :2 4 f 18 17 :2 f
:2 4 10 19 18 :2 10 :2 4 :3 9 :2 4
:3 9 :2 4 10 19 18 :2 10 :2 4 :2 c
1b c :2 4 :2 e 1d e :2 4 :2 b
1a b :2 4 :2 d 1c d :2 4 :2 10
1f 10 :2 4 :2 a 19 a :2 4 :2 b
1a b :2 4 :2 11 20 11 :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 :2 b
1a b :2 4 :2 f 1e f :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 f 1e f :2 4 :2 f
1e f :2 4 :2 b 1a b :2 4 :2 f
1e f :2 4 :2 d 1c d :2 4 :2 c
1b c :2 4 :2 c 1b c :2 4 :2 f
1e f :2 4 :2 b 1a b :2 4 :2 f
19 f :2 4 :2 f 1e f :2 4 :2 16
25 16 :2 4 :2 11 20 11 :2 4 :2 10
1f 10 :2 4 :2 14 23 14 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 :2 17
26 17 :2 4 17 1c 1b :2 17 :2 4
18 1d 1c :2 18 :2 4 :2 13 22 13
:2 4 :2 14 23 14 :2 4 9 12 11
:2 9 :2 4 :2 11 20 11 :2 4 :2 f 1e
f :2 4 :2 6 1e 6 :2 4 :2 7 1f
7 :2 4 :2 f 27 f :2 4 :2 d 25
d :2 4 :2 8 20 8 :2 4 :3 d :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 53 59 5c :2 53 6a 7f 8
:2 6a d 10 :2 6a 17 1a :2 6a b
e :2 6a 13 16 :2 6a 1b 1e :2 6a
2c 2f :2 6a b e :2 6a 13 16
:2 6a 1b 1e :2 6a 2d 30 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 1f 27 :2 1f 34 :2 16 :2 6a
b e :2 6a 13 16 1f 27 :2 1f
2f :2 16 :2 6a b e :2 6a 13 16
1f 27 :2 1f 2e :2 16 :2 6a b e
:2 6a 13 16 1f 27 :2 1f 34 :2 16
:2 6a b e :2 6a 13 16 1f 27
:2 1f 34 :2 16 :2 6a b e :2 6a 13
16 1f 27 :2 1f 40 :2 16 :2 6a b
e :2 6a 13 16 1f 27 :2 1f 33
:2 16 :2 6a b e :2 6a 13 16 1f
27 :2 1f 31 :2 16 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4e 4f :2 4b :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e :2 7 52 :3 4
14 :2 4 14 :2 4 13 :2 4 12 :2 4
10 :2 4 e :2 4 14 :2 4 f :2 4
12 :2 4 e :2 4 e :2 4 11 :2 4
11 :2 4 13 :2 4 11 :2 4 14 1d
26 2e :2 1d :2 14 :2 4 12 :2 4 10
4 :4 8 7 a :2 14 26 :2 30 3c
3f 4e 51 52 :2 4e :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b6 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4e 51 52
:2 4e :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 46
:2 7 18 :2 4 7 10 1b :2 7 1e
20 :2 1e 26 2f 37 :2 26 3a 3c
:2 3a :2 7 42 4b 53 :2 42 56 58
:2 56 :2 7 a :2 14 26 :2 30 3c 3f
4e 51 52 :2 4e :2 26 :3 a :2 10 15
21 5f 62 :2 21 6f 72 :2 21 76
79 :2 21 83 86 8f 97 :2 a0 :2 8f
b1 :2 86 :2 21 :2 a 55 :2 7 a :2 14
26 :2 30 3c 3f 4e 51 52 :2 4e
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:2 a 55 :3 7 :2 12 28 :2 31 41 :2 7
5a :2 4 8 11 1c :2 8 22 1f
:2 2b :2 1f 7 :4 46 45 44 :2 7 :4 14
13 12 :2 7 11 1c 21 33 3e
43 :2 f :2 a :2 13 1f a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 8b 8e :2 27 96 99
:2 27 a5 a8 af b8 bb :2 a8 :2 27
:2 10 5c :2 d :2 a :4 16 :2 a 7 :3 31
b :2 14 1f 1d :2 28 :2 1d a 3d
46 4f :2 3d 52 54 :2 52 3c :2 a
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 62
65 :2 24 72 75 :2 24 79 7c :2 24
86 89 92 9a :2 a3 :2 92 c0 :2 89
:2 24 :2 d 58 :2 a d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 62 65 :2 24 :2 d 58
:3 a :2 15 2b :2 34 50 :2 a 57 :3 7
e 7 4 31 :4 c b a :4 2a
29 28 :2 a 11 23 f :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 8b
8e :2 27 96 99 :2 27 a5 a8 af
b8 bb :2 a8 :2 27 :2 10 5c :2 d :2 a
:4 16 :2 a 7 :4 43 31 :3 4 d :2 16
22 29 32 3e :2 29 42 :2 4b :2 22
21 5a :2 d :2 4 13 1a 23 2f
:2 1a 33 :2 3c :2 13 12 4 7 10
1c :2 7 21 1f :2 2a :2 1f 7 15
7 3f :2 4 7 10 18 :2 7 1b
1d :2 1b 11 1a 30 39 51 f
1a 26 f 1d 2a :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 1f b :2 14 1f 1d :2 28
:2 1d a 26 31 3d 4d 5d 6a
:2 d :2 16 22 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :3 38 e :2 17
22 20 :2 2b :2 20 d 10 :2 1a 2c
:2 36 42 46 55 58 59 :2 55 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 89 8c 95
9d :2 a6 :2 95 b7 :2 8c :2 27 bf c2
:2 27 ca cd :2 27 d2 d5 :2 27 e2
e5 :2 27 :2 10 5c :2 d 10 :2 1a 2c
:2 36 42 45 54 57 58 :2 54 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 :2 10
5b :3 d :2 18 2c :2 35 45 53 :2 d
3b :2 a 38 :3 7 15 7 11 21
f 10 1d :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 8b 8e :2 27 96
99 :2 27 a5 a8 af b8 bb :2 a8
:2 27 :2 10 5c :2 d :2 a :4 16 :2 a 7
:3 1f a 13 1f :2 a 22 24 :2 22
14 24 12 13 20 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 26 d :2 18 1f 2d :2 d
32 34 :2 32 10 :2 1a 2c :2 36 42
46 55 58 59 :2 55 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 89 8c 95 9d :2 a6
:2 95 bb :2 8c :2 27 c3 c6 :2 27 ce
d1 :2 27 d6 d9 :2 27 e6 e9 :2 27
:2 10 5c :2 d 10 :2 1a 2c :2 36 42
45 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 :2 10 5b :3 d
:2 18 2c :2 35 49 57 :2 d 36 :2 a
26 :2 7 1f :4 b a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 86 89 92
9a :2 a3 :2 92 b9 :2 89 :2 24 :2 d 58
:2 a d :2 17 29 :2 33 3f 42 51
54 55 :2 51 :2 29 :3 d :2 13 18 24
62 65 :2 24 :2 d 58 :3 a :2 15 2b
:2 34 49 :2 a 1e :3 7 16 :2 7 13
1a 21 2e 31 :2 1a 36 39 :2 13
:2 7 15 :2 1e 27 2a 2d 31 :2 15
7 a 18 21 29 :2 18 :2 a 2d
30 :2 2d 14 20 29 3f 48 60
12 20 2b 37 12 20 2d 3b
47 50 5b 64 70 79 87 90
9e a7 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 32
e :2 17 22 20 :2 2b :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 89
8c 95 9d :2 a6 :2 95 b9 :2 8c :2 27
c1 c4 :2 27 cc cf :2 27 d4 d7
:2 27 e1 e4 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 :2 10 5b :3 d :2 18 2c :2 35 47
52 :2 d 3b :2 a 32 d :2 17 29
:2 33 3f 43 52 55 56 :2 52 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 86 89 92
9a :2 a3 :2 92 b6 :2 89 :2 24 be c1
:2 24 c9 cc :2 24 d1 d4 :2 24 de
e1 :2 24 :2 d 59 :2 a d :2 17 29
:2 33 3f 42 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 :2 d
58 :3 a :2 15 29 :2 32 44 4f :2 a
:4 7 :4 4 8 11 1d :2 8 20 22
:2 20 7 2a 33 3b :2 2a 3e 41
:2 3e 29 :3 7 11 7 46 :2 4 7
b d :2 b 7 15 :2 7 16 :2 7
15 26 32 3f 48 51 :2 3f 55
5e 66 :2 55 22 2b 37 :2 22 3b
44 4f :2 3b 53 20 2b :2 53 2f
38 46 :2 2f 4a 53 5e :2 4a 22
2b 37 :2 22 3b 43 4d :2 15 7
a 13 1f :2 a 24 22 :2 2d :2 22
d :2 17 29 :2 33 3f 42 51 54
55 :2 51 :2 29 :3 d :2 13 18 24 62
65 :2 24 72 75 :2 24 79 7c :2 24
86 89 92 9a :2 a3 :2 92 b4 :2 89
:2 24 :2 d 58 :2 a d :2 17 29 :2 33
3f 42 51 54 55 :2 51 :2 29 :3 d
:2 13 18 24 62 65 :2 24 :2 d 58
:3 a :2 15 2b :2 34 44 :2 a 7 3c
d 16 22 :2 d 25 28 :2 25 d
:2 17 29 :2 33 3f 43 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 62 65
:2 24 72 75 :2 24 79 7c :2 24 86
89 92 9a :2 92 a7 :2 89 :2 24 af
b2 :2 24 ba bd :2 24 c2 c5 :2 24
d2 d5 :2 24 :2 d 59 :2 a d :2 17
29 :2 33 3f 42 51 54 55 :2 51
:2 29 :3 d :2 13 18 24 62 65 :2 24
:2 d 58 :3 a :2 15 29 32 3e :2 29
42 50 :2 a 2a 3c :2 7 f 7
16 7 a 13 1b :2 a 1e 20
:2 1e a 14 1d 25 :2 14 28 2a
33 3f :2 2a :2 14 a 22 :2 7 :4 4
8 11 19 :2 8 1c 1e :2 1c 7
26 2f 37 :2 26 3a 3d :2 3a 25
:2 7 b 14 1c :2 b 1f 21 :2 1f
a 28 31 39 :2 28 3c 3e :2 3c
27 :3 a 15 a 7 41 d 16
1e :2 d 21 23 :2 21 a 15 a
7 25 41 e 17 1f :2 e 22
24 :2 22 d 2b 34 3c :2 2b 3f
41 :2 3f 2a :2 d a 15 a 7
44 41 d 16 1e :2 d 21 23
:2 21 a 15 a 25 41 :2 7 42
:3 4 :3 17 :2 4 12 :2 4 13 :2 4 13
:2 4 13 :2 4 10 17 21 24 :2 10
:2 4 12 19 25 28 :2 12 4 7
10 18 :2 7 1b 1d :2 1b 7 f
:2 7 15 7 a 11 1d 20 :2 a
23 25 :2 23 14 27 2f 36 51
59 60 7c 86 d 1b 12 27
2d 33 3f d 19 12 13 1b
2c 38 45 5b :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 58 5b 5c :2 58 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5f :2 10 :2 d :4 19 :2 d
a :3 29 14 26 37 46 53 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 29 e :2 17 22
20 :2 2b :2 20 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 89 8c 95 9d
:2 a6 :2 95 b9 :2 8c :2 27 c1 c4 :2 27
cc cf :2 27 d4 d7 :2 27 e0 e3
:2 27 :2 10 5c :2 d 10 :2 1a 2c :2 36
42 45 54 57 58 :2 54 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 :2 10 5b
:3 d :2 18 2c :2 35 47 51 :2 d 3b
:3 a 19 a 14 27 38 45 12
13 20 2e 46 54 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5f :2 10 :2 d :4 19
:2 d a :3 29 7 29 d 14 20
23 :2 d 26 28 :2 26 14 23 34
44 52 :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 2c
e :2 17 22 20 :2 2b :2 20 d 10
:2 1a 2c :2 36 42 46 55 58 59
:2 55 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 75 78 :2 27 7c 7f :2 27 89
8c 95 9d :2 a6 :2 95 b9 :2 8c :2 27
c1 c4 :2 27 cc cf :2 27 d4 d7
:2 27 e0 e3 :2 27 :2 10 5c :2 d 10
:2 1a 2c :2 36 42 45 54 57 58
:2 54 :2 2c :3 10 :2 16 1b 27 65 68
:2 27 :2 10 5b :3 d :2 18 2c :2 35 47
51 :2 d 3b :3 a 18 a 14 27
2f 36 51 59 60 7c 86 d
1b 12 27 2d 33 3f d 19
12 13 1b 2c 38 45 5b :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 58 5b
5c :2 58 :2 2f :3 13 :2 19 1e 2a 68
6b :2 2a 78 7b :2 2a 7f 82 :2 2a
8e 91 :2 2a 99 9c :2 2a a8 ab
b2 bb be :2 ab :2 2a :2 13 5f :2 10
:2 d :4 19 :2 d a :3 2c e :2 17 22
20 :2 2b :2 20 :2 d 1b d 17 2a
32 39 54 5c 63 7f 89 10
1e 15 2a 30 36 42 10 1c
15 16 1e 2f 3b 48 5e :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5b 5e
5f :2 5b :2 32 :3 16 :2 1c 21 2d 6b
6e :2 2d 7b 7e :2 2d 82 85 :2 2d
91 94 :2 2d 9c 9f :2 2d ab ae
b5 be c1 :2 ae :2 2d :2 16 62 :2 13
:2 10 :4 1c :2 10 d :3 3b 11 :2 1a 25
23 :2 2e :2 23 :2 10 1e 1f :2 1e 10
13 21 2a 32 :2 21 :2 13 36 39
:2 36 13 21 13 1d 2d 3d 60
1c 29 3a 45 54 62 :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 61 64 65
:2 61 :2 38 :3 1c :2 22 27 33 71 74
:2 33 81 84 :2 33 88 8b :2 33 97
9a :2 33 a2 a5 :2 33 b1 b4 bb
c4 c7 :2 b4 :2 33 :2 1c 68 :2 19 :2 16
:4 22 :2 16 13 :3 3b 16 1f 2b :2 16
2e 31 :2 2e 19 :2 23 35 :2 3f 4b
4f 5e 61 62 :2 5e :2 35 :3 19 :2 1f
24 30 6e 71 :2 30 7e 81 :2 30
85 88 :2 30 92 95 9e a6 :2 af
:2 9e d0 :2 95 :2 30 d8 db :2 30 e3
e6 :2 30 eb ee :2 30 f7 fa :2 30
:2 19 65 :2 16 19 :2 23 35 :2 3f 4b
4e 5d 60 61 :2 5d :2 35 :3 19 :2 1f
24 30 6e 71 :2 30 :2 19 64 :3 16
:2 21 35 :2 3e 5e 1e :2 16 33 :2 13
3b :2 10 3e :2 d 3b :2 a 14 27
38 45 12 13 20 2e 46 54
:2 d :2 16 22 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5f
:2 10 :2 d :4 19 :2 d a :4 2c 29 d
:2 17 29 :2 33 3f 42 51 54 55
:2 51 :2 29 :3 d :2 13 18 24 62 65
:2 24 72 75 :2 24 79 7c :2 24 86
89 92 9a :2 a3 :2 92 b4 :2 89 :2 24
:2 d 58 :2 a d :2 17 29 :2 33 3f
42 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 62 65 :2 24 :2 d 58 :3 a
:2 15 2b :2 34 44 :2 a :4 7 b :2 14
1f 1d :2 28 :2 1d :2 a 1d 2b 2e
37 3f :2 2e 43 :2 4c 24 :2 1d :2 a
1d 2b 2e 37 3f :2 2e 43 :2 4c
24 :2 1d a 14 2d 12 20 38
49 52 5d 66 72 7b 89 92
a0 a9 bd c6 12 20 39 42
12 20 38 41 12 1b 23 30
39 :2 12 20 3a 12 13 27 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 38
a 1d 33 :2 1d a 38 a :3 19
:2 a 1d 2b 2e 37 3f :2 2e 43
:2 4c 24 :2 1d :2 a 20 :2 29 :2 a 1c
:2 a 1d 34 42 4c 54 2d 41
4d :2 1d a 19 2e 41 4d 59
67 d 1c 29 36 43 4d 15
22 30 3b 43 d 19 23 2c
39 4d 5a d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 58 5b 5c
:2 58 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5f :2 10 :2 d
:4 19 :2 d a :7 7 b 14 21 :2 b
24 26 :2 24 a :4 2e 2d :2 a 45
50 52 :2 50 44 :2 a d 16 1e
:2 d 21 23 :2 21 10 19 21 :2 10
24 27 :2 24 10 1e 27 2f :2 1e
10 2b 10 1e 24 2f 38 40
:2 2f 43 45 4e 59 :2 45 :2 2f 2e
:2 24 5e 60 :2 24 68 6a :2 24 :2 1e
10 :4 d 15 1c 28 2b :2 15 2e
30 :2 2e :3 11 10 :4 3b 3a 54 :2 5f
13 21 27 :2 54 2b 2e :2 2b 53
36 :2 41 49 57 15 :2 36 19 1c
:2 19 35 :2 53 52 :2 3a 39 :3 10 18
10 1a 1e 22 31 18 2d 32
43 19 1d 2a 17 1b 2f 17
1b 27 2f 36 17 1b 17 1b
28 17 1b 26 2a 18 1c 2c
30 :2 13 :2 1c 28 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
5e 61 62 :2 5e :2 35 :3 19 :2 1f 24
30 6e 71 :2 30 7e 81 :2 30 85
88 :2 30 94 97 :2 30 9f a2 :2 30
ae b1 b8 c1 c4 :2 b1 :2 30 :2 19
65 :2 16 :2 13 :4 1f :2 13 10 :3 21 :4 14
13 16 :2 21 29 36 3c :2 16 40
43 :2 40 21 2c 39 41 48 60
6b 81 91 :2 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 64 67 68 :2 64 :2 3b :3 1f
:2 25 2a 36 74 77 :2 36 84 87
:2 36 8b 8e :2 36 9a 9d :2 36 a5
a8 :2 36 b4 b7 be c7 ca :2 b7
:2 36 :2 1f 6b :2 1c :2 19 :4 25 :2 19 16
:3 45 16 25 16 45 16 24 :2 16
25 16 :4 13 22 1d 28 35 3f
48 58 69 1b 1c 29 1a 2e
1a 25 :2 16 :2 1f 2b 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 61 64 65 :2 61 :2 38 :3 1c :2 22
27 33 71 74 :2 33 81 84 :2 33
88 8b :2 33 97 9a :2 33 a2 a5
:2 33 b1 b4 bb c4 c7 :2 b4 :2 33
:2 1c 68 :2 19 :2 16 :4 22 :2 16 13 :3 10
13 22 13 :4 10 21 10 1e :2 10
1f 10 :4 d 10 14 16 :2 14 1c
:2 27 2f 3b 48 :2 1c 4c 4e :2 4c
:2 10 13 :2 1d 2f :2 39 45 49 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8c 8f 98 a0 :2 a9 :2 98 c1
:2 8f :2 2a c9 cc :2 2a d4 d7 :2 2a
dc df :2 2a e8 eb :2 2a :2 13 5f
:2 10 13 :2 1d 2f :2 39 45 48 57
5a 5b :2 57 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a :2 13 5e :3 10 :2 1b 2f
:2 38 4f 59 :2 10 50 :2 d a 25
10 14 16 :2 14 d 20 d 17
1b 2b 15 16 23 14 28 14
25 2d 34 4c 54 5b :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5b 5e 5f
:2 5b :2 32 :3 16 :2 1c 21 2d 6b 6e
:2 2d 7b 7e :2 2d 82 85 :2 2d 91
94 :2 2d 9c 9f :2 2d ab ae b5
be c1 :2 ae :2 2d :2 16 62 :2 13 :2 10
:4 1c :2 10 d :3 18 d 1c d 17
1b 2f 15 16 23 30 41 49
50 68 70 77 :2 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5b 5e 5f :2 5b :2 32
:3 16 :2 1c 21 2d 6b 6e :2 2d 7b
7e :2 2d 82 85 :2 2d 91 94 :2 2d
9c 9f :2 2d ab ae b5 be c1
:2 ae :2 2d :2 16 62 :2 13 :2 10 :4 1c :2 10
d :3 18 10 19 26 :2 10 29 2c
35 46 :2 2c 49 4b 54 5e :2 4b
:2 2c 2b :2 29 13 :2 1d 2f :2 39 45
49 58 5b 5c :2 58 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8c 8f 98 a0 :2 a9
:2 98 c1 :2 8f :2 2a c9 cc :2 2a d4
d7 :2 2a dc df :2 2a e8 eb :2 2a
:2 13 5f :2 10 13 :2 1d 2f :2 39 45
48 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a :2 13 5e :3 10
:2 1b 2f :2 38 4f 59 :2 10 62 :2 d
18 25 :2 a 55 :2 7 a 11 1d
20 :2 a 23 25 :2 23 a 15 :2 1e
a 29 a 15 1e 2a :2 15 a
:5 7 13 1f 2c 3a 45 4f 5b
1b 28 35 42 4f 1b 28 34
3e 46 4f 57 5e 1b 27 34
3f 4a 58 1b 26 32 3e 41
44 4a 50 53 :2 13 7 a 13
15 :2 13 14 27 44 4b d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
58 5b 5c :2 58 :2 2f :3 13 :2 19 1e
2a 68 6b :2 2a 78 7b :2 2a 7f
82 :2 2a 8e 91 :2 2a 99 9c :2 2a
a8 ab b2 bb be :2 ab :2 2a :2 13
5f :2 10 :2 d :4 19 :2 d a :4 17 :2 7
1f 7 15 :2 7 16 :2 7 16 7
a 13 1a :2 13 28 :2 a 2b 2d
:2 2b a 16 a 30 a 16 1d
26 2d :2 26 3b :2 1d 3e 40 :2 1d
1c 43 45 :2 1c :2 16 a :4 7 a
13 15 :2 13 a 15 :2 a 10 19
22 :2 10 27 25 30 :2 25 a d
19 :2 22 2b 2f 33 3c 45 :2 33
48 4a :2 33 4c 4d :2 33 50 :2 19
:2 d 1b :2 24 2d 30 33 3c 45
:2 33 48 4a :2 33 4d 4f :2 33 51
52 :2 33 55 :2 1b d 10 17 23
26 :2 10 29 2b :2 29 10 1b :2 24
10 13 1c 23 :2 1c 31 :2 13 34
36 :2 34 13 22 13 38 13 22
29 35 38 :2 29 41 44 :2 22 :2 13
22 29 35 38 :2 29 42 45 :2 22
13 :4 10 2f 10 1b 24 30 :2 1b
10 13 1c 23 :2 1c 30 :2 13 33
35 :2 33 13 21 13 37 13 21
28 33 36 :2 28 3f 42 :2 21 :2 13
21 28 33 36 :2 28 40 43 :2 21
13 :4 10 :4 d 10 17 23 26 :2 10
29 2b :2 29 10 1f 10 2f :3 d
1b :2 d 1c d 17 2a 34 15
2a 36 15 16 1e 2f 3b 48
:2 10 :2 19 25 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5b
5e 5f :2 5b :2 32 :3 16 :2 1c 21 2d
6b 6e :2 2d 7b 7e :2 2d 82 85
:2 2d 91 94 :2 2d 9c 9f :2 2d ab
ae b5 be c1 :2 ae :2 2d :2 16 62
:2 13 :2 10 :4 1c :2 10 d :3 30 11 :2 1a
25 23 :2 2e :2 23 10 1a 2d 37
18 2d 39 18 19 21 32 3e
4b :2 13 :2 1c 28 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
5e 62 63 :2 5e :2 35 :3 19 :2 1f 24
30 6f 72 :2 30 7f 82 :2 30 86
89 :2 30 95 98 :2 30 a0 a3 :2 30
af b2 b9 c2 c5 :2 b2 :2 30 :2 19
66 :2 16 :2 13 :4 1f :2 13 10 :3 3e 14
:2 1d 28 26 :2 31 :2 26 :2 13 22 13
41 13 21 13 :4 10 3e :2 d 10
19 26 :2 10 29 2b :2 29 13 1c
24 :2 13 27 29 :2 27 16 1f 27
:2 16 2a 2d :2 2a 16 24 2d 35
:2 24 16 31 16 24 2a 35 3e
46 :2 35 49 4b 54 5f :2 4b :2 35
34 :2 2a 64 66 :2 2a 6e 70 :2 2a
:2 24 16 :4 13 1b 22 2e 31 :2 1b
34 36 :2 34 :3 17 16 :4 41 40 5a
:2 65 19 27 2d :2 5a 31 34 :2 31
59 3c :2 47 4f 5d 1b :2 3c 1f
22 :2 1f 3b :2 59 58 :2 40 3f :3 16
1e 16 20 24 28 37 1e 33
38 49 1f 23 30 1d 21 35
1d 21 2d 35 3c 1d 21 1d
21 2e 1d 21 2c 30 1e 22
32 36 :2 19 :2 22 2e 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 64 68 69 :2 64 :2 3b :3 1f :2 25
2a 36 75 78 :2 36 85 88 :2 36
8c 8f :2 36 9b 9e :2 36 a6 a9
:2 36 b5 b8 bf c8 cb :2 b8 :2 36
:2 1f 6c :2 1c :2 19 :4 25 :2 19 16 :3 27
:4 1a 19 23 2e 3b 45 4e 5e
6f 21 22 2f 20 34 20 2b
:2 1c :2 25 31 1c 19 21 1f :2 28
34 1f 2f :2 1c :2 21 1f :2 28 34
1f 22 :2 2c 3e :2 48 54 58 67
6b 6c :2 67 :2 3e :3 22 :2 28 2d 39
78 7b :2 39 88 8b :2 39 8f 92
:2 39 9e a1 :2 39 a9 ac :2 39 b8
bb c2 cb ce :2 bb :2 39 :2 22 6f
:2 1f :2 1c :4 28 :2 1c 19 :3 2c 19 28
19 2c 19 27 :2 19 28 19 :4 16
27 16 24 :2 16 25 16 :4 13 10
2b 16 :2 21 29 37 43 :2 16 47
4a :2 47 50 :2 5b 63 18 25 :2 50
29 2c :2 29 :2 16 1f 2a 37 3f
46 64 6f 1d 2d :2 16 :2 1f 2b
16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 61 65 66 :2 61
:2 38 :3 1c :2 22 27 33 72 75 :2 33
82 85 :2 33 89 8c :2 33 98 9b
:2 33 a3 a6 :2 33 b2 b5 bc c5
c8 :2 b5 :2 33 :2 1c 69 :2 19 :2 16 :4 22
:2 16 13 :4 2e 2b 13 21 :2 13 22
13 :4 10 2d 10 1e :2 10 1f 10
:4 d 10 19 25 :2 10 28 2a :2 28
13 1a 26 29 :2 13 2c 2e :2 2c
13 1f 13 32 :2 10 d 2c 13
1a 26 29 :2 13 2c 2e :2 2c 10
1b :2 24 10 32 2c 10 1b 24
30 :2 1b 10 :5 d 19 25 32 40
4b 55 61 1b 28 35 42 4f
1b 28 34 3e 46 4f 57 5e
1b 27 34 3f 4a 58 1b 26
32 3e 41 44 4a 50 53 :2 19
d 10 19 1b :2 19 1a 2d 4a
51 13 1a 16 22 :3 20 16 :2 1f
2b 16 27 16 :2 1f 2b 16 :4 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 5e 62 63 :2 5e :2 35
:3 19 :2 1f 24 30 6f 72 :2 30 7f
82 :2 30 86 89 :2 30 95 98 :2 30
a0 a3 :2 30 af b2 b9 c2 c5
:2 b2 :2 30 :2 19 66 :2 16 :2 13 :4 1f :2 13
10 :4 1d :3 d 18 21 2a :2 18 2d
2f :2 18 d 30 e a 17 :2 7
:4 4 8 11 14 :2 11 7 1c 25
2d :2 1c 30 32 :2 30 1b :2 7 a
:2 14 26 :2 30 3c 40 4f 53 54
:2 4f :2 26 :3 a :2 10 15 21 60 63
:2 21 70 73 :2 21 77 7a :2 21 84
87 90 98 :2 a1 :2 90 c2 :2 87 :2 21
ca cd :2 21 d5 d8 :2 21 dd e0
:2 21 ec ef :2 21 :2 a 57 :2 7 a
:2 14 26 :2 30 3c 3f 4e 52 53
:2 4e :2 26 :3 a :2 10 15 21 60 63
:2 21 :2 a 56 :3 7 :2 12 26 :2 2f 4f
f :2 7 35 :2 4 7 10 18 :2 7
1b 1d :2 1b 7 17 7 1f :2 4
8 11 18 :2 11 25 :2 8 28 2a
:2 28 7 32 3b 42 :2 3b 50 :2 32
53 55 :2 53 31 :3 7 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d 2c 2f 37 40 4a :2 37
:2 2f :2 d 4e 51 :2 d 13 16 1e
27 30 :2 1e :2 16 :2 d 13 16 :2 d
e 11 19 22 2d :2 19 :2 11 :2 d
13 16 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 d 29 2c :2 d
13 16 :2 d 4e 51 :2 d 13 16
:2 d e 11 :2 d e 11 :2 d e
11 :2 d e 11 :2 1a :2 d 32 35
:2 d 48 4b :2 54 :2 d 13 16 :2 d
e 11 :2 d e 11 :2 d 47 4a
52 5b 65 :2 52 :2 4a :2 d 13 16
:2 d 2a 2d 35 3e 47 :2 35 :2 2d
:2 d 4b 4e :2 d e 11 :2 d 54
57 5f 13 1e :2 5f :2 57 :2 d 13
16 :2 d e 11 :2 d e 11 :2 d
4d 50 :2 d 13 16 :2 d 50 53
:2 d 13 16 :2 d e 11 :2 d e
11 :2 d 7 4 58 a 13 1a
:2 13 27 :2 a 2a 2c :2 2a 7 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d 2c 2f 37 40
4a :2 37 :2 2f :2 d 4e 51 :2 d 13
16 1e 27 30 :2 1e :2 16 :2 d 13
16 :2 d e 11 19 22 2d :2 19
:2 11 :2 d 13 16 :2 d e 11 :2 d
e 11 :2 d e 11 :2 d e 11
:2 d e 11 :2 d e 11 :2 d 29
2c :2 d 13 16 :2 d 4e 51 :2 d
13 16 :2 d e 11 :2 d 7 4
2e 58 a 13 1a :2 13 28 :2 a
2b 2d :2 2b 7 d e 11 :2 d
e 11 :2 1a :2 d 32 35 :2 d 48
4b :2 54 :2 d 13 16 :2 d e 11
:2 d e 11 :2 d 47 4a 52 5b
65 :2 52 :2 4a :2 d 13 16 :2 d 2a
2d 35 3e 47 :2 35 :2 2d :2 d 4b
4e :2 d e 11 :2 d 54 57 5f
13 1e :2 5f :2 57 :2 d 13 16 :2 d
e 11 :2 d e 11 :2 d 4d 50
:2 d 13 16 :2 d 50 53 :2 d 13
16 :2 d e 11 :2 d e 11 :2 d
7 2f 58 :2 4 7 :2 11 23 :2 2d
39 3c 4b 4f 50 :2 4b :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :2 7 53
:2 4 7 :2 11 23 :2 2d 39 3c 4b
4f 50 :2 4b :2 23 :3 7 :2 d 12 1e
5d 60 :2 1e :2 7 53 :3 4 b :2 16
26 :2 b 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 4f 53 54
:2 4f :2 26 :3 a :2 10 15 21 60 63
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 57 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4c 50 51
:2 4c :2 23 :3 7 :2 d 12 1e 5d 60
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 54 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
2047
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :5 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :7 21 :7 22 :7 23
:5 24 :5 25 :7 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:7 48 :7 49 :6 4a :6 4b
:7 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:5 54 :7 56 :b 58 :11 59
5a :2 59 :2 5a :2 59
:2 5a :2 59 :2 5b :2 59
:2 5b :2 59 :2 5b :2 59
:2 5b :2 59 :2 5c :2 59
:2 5c :2 59 :2 5c :2 59
:2 5c :2 59 :2 5d :2 59
:9 5d :2 59 :2 5e :2 59
:9 5e :2 59 :2 5f :2 59
:9 5f :2 59 :2 60 :2 59
:9 60 :2 59 :2 61 :2 59
:9 61 :2 59 :2 62 :2 59
:9 62 :2 59 :2 63 :2 59
:9 63 :2 59 :2 64 :2 59
:9 64 :2 59 :2 65 :2 59
:9 65 :2 59 :2 66 :2 59
:9 66 :2 59 :2 67 :2 59
:2 67 :2 59 :2 67 :2 59
:2 67 :2 59 :2 68 :2 59
:2 68 :2 59 :2 68 :2 59
:2 68 :2 59 :2 68 :4 59
:3 58 :11 6b :b 6c :3 6b
:3 73 :3 74 :3 75 :3 76
:3 78 :3 7a :3 7c :3 7e
:3 7f :3 80 :3 81 :3 82
:3 83 :3 84 :3 86 :a 87
:3 8b :3 8c :5 8e :11 8f
:20 90 :3 8f :11 92 :b 93
:3 92 :9 95 :3 8e :1f 98
:11 99 :20 9a :3 99 :11 9c
:b 9d :3 9c :9 9f :3 98
:14 a2 :6 a3 :2 a2 :6 a5
a6 a7 a5 :5 a8
a4 aa :5 ab :3 aa
:2 ac :5 ae :11 af :24 b0
:3 af :2 ad :6 ac a9
:3 a3 :16 b5 :11 b6 :20 b7
:3 b6 :11 b9 :b ba :3 b9
:9 bc :3 b5 :3 bf c0
a3 :e c0 :2 c2 c3
c2 :5 c4 c1 c6
:5 c7 :3 c6 :2 c8 :5 ca
:11 cb :24 cc :3 cb :2 c9
:6 c8 c5 :4 c0 a3
:2 a2 :14 d4 :e d6 :b d9
:3 da :3 d9 :9 dd :5 df
:3 e0 :3 e1 df :5 e2
de e4 :5 e5 :3 e4
:2 e6 :5 e8 :11 e9 :24 ea
:3 e9 :2 e7 :6 e6 e3
:3 dd :a ef :7 f1 :5 f2
f0 f4 :5 f5 :3 f4
:2 f6 :5 f8 :11 f9 :24 fa
:3 f9 :2 f7 :6 f6 f3
:3 ef :a fe :11 ff :30 100
:3 ff :11 102 :b 103 :3 102
:a 105 :3 fe :3 ef :3 109
:2 10b 10c :2 10d 10b
:5 10e 10a 110 :5 111
:3 110 :2 112 :5 114 :11 115
:24 116 :3 115 :2 113 :6 112
10f :3 dd :9 11b :2 11d
11e :2 11f 11d :5 120
11c 122 :5 123 :3 122
:2 124 :5 126 :11 127 :24 128
:3 127 :2 125 :6 124 121
:3 11b :b 12d :11 12e :30 12f
:3 12e :11 131 :b 132 :3 131
:a 134 :3 12d :3 11b dd
:5 138 :11 139 :20 13a :3 139
:11 13c :b 13d :3 13c :9 13f
:3 138 :3 142 :d 146 :b 14a
:c 14c :6 14e :4 14f :e 150
14e :5 151 14d 153
:5 154 :3 153 :2 155 :5 157
:11 158 :24 159 :3 158 :2 156
:6 155 152 :3 14c :a 15e
:11 15f :30 160 :3 15f :11 162
:b 163 :3 162 :a 165 :3 15e
14c :11 168 :30 169 :3 168
:11 16b :b 16c :3 16b :a 16e
167 :3 14c 137 :3 dd
:16 173 :3 174 :3 173 :5 177
:3 179 :3 17a :e 17c :b 17d
:2 17e :2 17d :a 17e :8 17f
:3 17c :b 181 :11 182 :20 183
:3 182 :11 185 :b 186 :3 185
:9 188 189 181 :9 189
:11 18a :2e 18b :3 18a :11 18d
:b 18e :3 18d :c 190 189
:3 181 177 :3 193 :9 195
:f 196 :3 195 192 :3 177
:16 199 :16 19a :3 19b 19c
19a :9 19c :3 19d 19e
19c 19a :16 19e :3 19f
1a0 19e 19a :9 1a0
:3 1a1 1a0 :3 19a :3 199
:5 1a5 :3 1a8 :3 1a9 :3 1aa
:3 1ab :8 1ad :8 1af :9 1b4
:3 1b5 :3 1b6 :a 1b7 :9 1b9
:2 1ba :5 1bb :2 1bc 1bd
:6 1be 1b9 :5 1bf 1b8
1c1 :5 1c2 :3 1c1 :2 1c3
:5 1c5 :11 1c6 :24 1c7 :3 1c6
:2 1c4 :6 1c3 1c0 :3 1b7
:6 1cd :5 1ce 1cc 1d0
:5 1d1 :3 1d0 :2 1d2 :5 1d4
:11 1d5 :24 1d6 :3 1d5 :2 1d3
:6 1d2 1cf :3 1b7 :a 1db
:11 1dc :30 1dd :3 1dc :11 1df
:b 1e0 :3 1df :a 1e2 :3 1db
:3 1e5 :4 1e8 1e9 :5 1ea
1e8 :5 1eb 1e7 1ed
:5 1ee :3 1ed :2 1ef :5 1f1
:11 1f2 :24 1f3 :3 1f2 :2 1f0
:6 1ef 1ec :3 1b7 1f7
1b7 :a 1f7 :6 1f9 :5 1fa
1f8 1fc :5 1fd :3 1fc
:2 1fe :5 200 :11 201 :24 202
:3 201 :2 1ff :6 1fe 1fb
:3 1f7 :a 207 :11 208 :30 209
:3 208 :11 20b :b 20c :3 20b
:a 20e :3 207 :3 211 :9 214
:2 215 :5 216 :2 217 218
:6 219 214 :5 21a 213
21c :5 21d :3 21c :2 21e
:5 220 :11 221 :24 222 :3 221
:2 21f :6 21e 21b :3 1f7
:a 228 :3 229 :9 22b :2 22c
:5 22d :2 22e 22f :6 230
22b :5 231 22a 233
:5 234 :3 233 :2 235 :5 237
:11 238 :24 239 :3 238 :2 236
:6 235 232 :3 228 :a 23e
:6 23f :c 241 :3 242 :4 244
:6 245 244 :5 246 243
248 :5 249 :3 248 :2 24a
:5 24c :11 24d :24 24e :3 24d
:2 24b :6 24a 247 :3 241
:9 252 :11 253 :30 254 :3 253
:11 256 :b 257 :3 256 :7 259
25a :2 259 :3 252 :3 241
:3 23e :3 228 :4 261 262
:5 263 261 :5 264 260
266 :5 267 :3 266 :2 268
:5 26a :11 26b :24 26c :3 26b
:2 269 :6 268 265 :4 1f7
1b7 :11 271 :20 272 :3 271
:11 274 :b 275 :3 274 :9 277
270 :3 1b7 :a 27b :b 27c
27d :3 27c :b 27e 27f
:3 27e :2 282 :f 284 :4 285
:4 286 :5 287 288 :3 28a
28b :2 28d 282 :6 28e
:5 28f 28e :5 291 290
:3 28e 281 294 :5 295
:3 294 :2 296 :5 298 :11 299
:24 29a :3 299 :2 297 :6 296
293 :3 27b :6 29f 27b
:5 2a2 :b 2a4 2a5 :3 2a4
:5 2a7 :3 2a8 :6 2aa :3 2ab
:3 2aa :6 2ae :6 2af :5 2b0
:7 2b1 2ae :6 2b2 :5 2b3
2b2 :5 2b5 2b4 :3 2b2
2ad 2b8 :5 2b9 :3 2b8
:2 2ba :5 2bc :11 2bd :24 2be
:3 2bd :2 2bb :6 2ba 2b7
:4 2a0 :3 27b :19 2c5 :9 2c6
:9 2c7 :7 2c8 2c7 :1e 2ca
2c9 :3 2c7 :16 2ed :3 2ee
:2 2ed :4 2ee 2ed :5 2ee
2ef :2 2ee :4 2ef 2ee
:8 2ed :3 2f0 :4 2f2 :4 2f3
:3 2f4 :3 2f5 :5 2f6 :2 2f7
:3 2f8 :4 2f9 :4 2fa 2f2
:5 2fb 2f1 2fd :5 2fe
:3 2fd :2 2ff :5 301 :11 302
:24 303 :3 302 :2 300 :6 2ff
2fc :3 2ef :5 308 :c 309
:a 30b :5 30c 30a 30e
:5 30f :3 30e :2 310 :5 312
:11 313 :24 314 :3 313 :2 311
:6 310 30d :3 309 :3 318
309 :3 31a :3 31b 319
:3 309 308 :7 31f 320
:2 321 :2 322 :2 323 31f
:5 324 31e 326 :5 327
:3 326 :2 328 :5 32a :11 32b
:24 32c :3 32b :2 329 :6 328
325 :3 31d :3 330 31d
:3 308 2ef :3 333 :3 334
332 :3 2ed :13 337 :11 338
:30 339 :3 338 :11 33b :b 33c
:3 33b :a 33e :3 337 340
2c6 :5 340 :3 341 :3 343
344 :2 345 :2 346 :7 347
343 :5 348 342 34a
:5 34b :3 34a :2 34c :5 34e
:11 34f :24 350 :3 34f :2 34d
:6 34c 349 :3 340 :3 355
:3 357 358 :9 359 357
:5 35a 356 35c :5 35d
:3 35c :2 35e :5 360 :11 361
:24 362 :3 361 :2 35f :6 35e
35b :3 340 :16 367 :11 368
:30 369 :3 368 :11 36b :b 36c
:3 36b :a 36e :3 367 340
:3 2c6 :3 2c5 :a 376 :5 377
376 :7 37a 378 :3 376
:8 37e :5 37f :8 380 :6 381
:9 382 :3 37e :5 385 :5 387
:6 388 :5 389 388 :5 38b
38a :3 388 386 38e
:5 38f :3 38e :2 390 :5 392
:11 393 :24 394 :3 393 :2 391
:6 390 38d :6 385 1b4
:3 39a :3 39b :3 39d :c 39f
:3 3a0 39f :16 3a2 3a1
:3 39f :5 3a5 :3 3a6 :c 3a7
:17 3aa :1b 3ac :a 3ae :5 3af
:c 3b1 :3 3b2 3b1 :c 3b4
:c 3b5 3b3 :3 3b1 3ae
:7 3b8 :c 3ba :3 3bb 3ba
:c 3bd :c 3be 3bc :3 3ba
3b7 :3 3ae :a 3c2 :3 3c3
:3 3c2 :3 3c6 :3 3c7 :3 3ca
:3 3cb 3cc :5 3cd 3ca
:5 3ce 3c9 3d0 :5 3d1
:3 3d0 :2 3d2 :5 3d4 :11 3d5
:24 3d6 :3 3d5 :2 3d3 :6 3d2
3cf :3 3a7 :a 3db :3 3dd
:3 3de 3df :5 3e0 3dd
:5 3e1 3dc 3e3 :5 3e4
:3 3e3 :2 3e5 :5 3e7 :11 3e8
:24 3e9 :3 3e8 :2 3e6 :6 3e5
3e2 :3 3db :a 3ed :3 3ee
3ed :3 3f0 3ef :3 3ed
:3 3db :9 3f4 :9 3f5 :9 3f6
:7 3f7 3f6 :1e 3f9 3f8
:3 3f6 :16 416 :3 417 :2 416
:4 417 416 :5 417 418
:2 417 :4 418 417 :8 416
:3 419 :4 41b :4 41c :3 41d
:3 41e :5 41f :2 420 :3 421
:4 422 :4 423 41b :5 424
41a 426 :5 427 :3 426
:2 428 :5 42a :11 42b :24 42c
:3 42b :2 429 :6 428 425
:3 418 :5 430 :7 432 433
:2 434 :2 435 :2 436 432
:5 437 431 439 :5 43a
:3 439 :2 43b :5 43d :11 43e
:24 43f :3 43e :2 43c :6 43b
438 :3 430 :3 443 430
:3 445 :3 446 444 :3 430
418 :3 449 :3 44a 448
:3 416 44d 3f5 :10 44d
:2 44e :2 44d :4 44e :2 44d
:7 450 :2 451 450 :5 452
44f 454 :5 455 :3 454
:2 456 :5 458 :11 459 :24 45a
:3 459 :2 457 :6 456 453
:4 44e 3f5 :3 45f :3 460
45e :3 3f5 3f4 :3 463
:3 464 462 :3 3f4 :9 467
:a 469 :3 46a :3 469 46c
467 :a 46c :5 46d 46c
467 :7 46f 46e :3 467
:8 472 :5 473 :8 474 :6 475
:9 476 :3 472 :5 479 :5 47b
:6 47c :5 47d 47c :5 47f
47e :3 47c 47a 482
:5 483 :3 482 :2 484 :5 486
:11 487 :24 488 :3 487 :2 485
:6 484 481 :6 479 :b 48e
3a7 48f 3a7 :3 3a5
399 :3 1b4 :12 494 :11 495
:30 496 :3 495 :11 498 :b 499
:3 498 :7 49b 49c :2 49b
:3 494 :9 49f :3 4a0 :3 49f
:1c 4a5 4a6 4a7 :2 4a8
:2 4a7 :2 4a9 :2 4a7 :2 4aa
:2 4a7 :2 4ab :2 4a7 :9 4ab
:2 4a7 :2 4ab :2 4a7 :9 4ac
:2 4a7 :2 4ad :2 4a7 :9 4ae
:2 4a7 :2 4af :2 4a7 :2 4b0
:2 4a7 :2 4b1 :2 4a7 :2 4b2
:2 4a7 :2 4b3 :2 4a7 :2 4b4
:2 4a7 :2 4b5 :2 4a7 :2 4b5
:2 4a7 :2 4b6 :2 4a7 :2 4b6
:2 4a7 :2 4b7 :2 4a7 :2 4b8
:2 4a7 :2 4b9 :2 4a7 :2 4ba
:2 4a7 :4 4bb :2 4a7 :2 4bb
:2 4a7 :4 4bb :2 4a7 :2 4bc
:2 4a7 :2 4bd :2 4a7 :2 4be
:2 4a7 :9 4be :2 4a7 :2 4bf
:2 4a7 :9 4bf :2 4a7 :2 4bf
:2 4a7 :2 4c0 :2 4a7 :3 4c0
:2 4c1 :4 4c0 :2 4a7 :2 4c2
:2 4a7 :2 4c3 :2 4a7 :2 4c4
:2 4a7 :2 4c4 :2 4a7 :2 4c5
:2 4a7 :2 4c5 :2 4a7 :2 4c6
:2 4a7 :2 4c7 :2 4a7 :2 4c8
:2 4a7 4a6 4c9 4a5
:c 4c9 4ca 4cb :2 4cc
:2 4cb :2 4cd :2 4cb :2 4ce
:2 4cb :2 4cf :2 4cb :9 4cf
:2 4cb :2 4cf :2 4cb :9 4d0
:2 4cb :2 4d1 :2 4cb :9 4d2
:2 4cb :2 4d3 :2 4cb :2 4d4
:2 4cb :2 4d5 :2 4cb :2 4d6
:2 4cb :2 4d7 :2 4cb :2 4d8
:2 4cb :2 4d9 :2 4cb :2 4d9
:2 4cb :2 4da :2 4cb :2 4da
:2 4cb :2 4db :2 4cb :2 4dc
:2 4cb 4ca 4dd 4c9
4a5 :c 4dd 4de 4df
:2 4e0 :2 4df :4 4e1 :2 4df
:2 4e1 :2 4df :4 4e1 :2 4df
:2 4e2 :2 4df :2 4e3 :2 4df
:2 4e4 :2 4df :9 4e4 :2 4df
:2 4e5 :2 4df :9 4e5 :2 4df
:2 4e5 :2 4df :2 4e6 :2 4df
:3 4e6 :2 4e7 :4 4e6 :2 4df
:2 4e8 :2 4df :2 4e9 :2 4df
:2 4ea :2 4df :2 4ea :2 4df
:2 4eb :2 4df :2 4eb :2 4df
:2 4ec :2 4df :2 4ed :2 4df
:2 4ee :2 4df 4de 4dd
:3 4a5 :11 4f3 :b 4f4 :3 4f3
:11 4f6 :b 4f7 :3 4f6 :8 4f9
57 :3 4fd :11 4fe :b 4ff
:17 500 :3 4fe :2 502 :3 503
:3 504 505 503 502
503 :3 506 :3 4fd :2 507
:5 509 :11 50a :b 50b :18 50c
:3 50a :2 50e 50f :3 510
511 50f 50e 50f
:3 512 :2 508 :6 507 4fc
:7 1 
6f5b
4
:3 0 1 :3 0 2
:a 0 2042 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 8
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f 4 :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 2042 2 44
:2 0 18 :2 0 33
4 :3 0 18 :2 0
31 47 49 :6 0
4c 4a 0 2040
0 17 :6 0 18
:2 0 37 4 :3 0
35 4e 50 :6 0
53 51 0 2040
0 19 :6 0 18
:2 0 3b 4 :3 0
39 55 57 :6 0
5a 58 0 2040
0 1a :6 0 1d
:2 0 3f 4 :3 0
3d 5c 5e :6 0
61 5f 0 2040
0 1b :6 0 1d
:2 0 43 4 :3 0
41 63 65 :6 0
68 66 0 2040
0 1c :6 0 1d
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 2040
0 1e :6 0 4d
21f 0 4b 4
:3 0 49 71 73
:6 0 76 74 0
2040 0 1f :6 0
23 :2 0 51 21
:3 0 78 :7 0 7b
79 0 2040 0
20 :6 0 4 :3 0
23 :2 0 4f 7d
7f :6 0 82 80
0 2040 0 22
:6 0 23 :2 0 55
4 :3 0 53 84
86 :6 0 89 87
0 2040 0 24
:6 0 18 :2 0 59
4 :3 0 57 8b
8d :6 0 90 8e
0 2040 0 25
:6 0 18 :2 0 5d
4 :3 0 5b 92
94 :6 0 97 95
0 2040 0 26
:6 0 29 :2 0 61
4 :3 0 5f 99
9b :6 0 9e 9c
0 2040 0 27
:6 0 29 :2 0 65
4 :3 0 63 a0
a2 :6 0 a5 a3
0 2040 0 28
:6 0 29 :2 0 69
4 :3 0 67 a7
a9 :6 0 ac aa
0 2040 0 2a
:6 0 6f 322 0
6d 4 :3 0 6b
ae b0 :6 0 b3
b1 0 2040 0
2b :6 0 2f :2 0
71 21 :3 0 b5
:7 0 b8 b6 0
2040 0 2c :6 0
21 :3 0 ba :7 0
bd bb 0 2040
0 2d :6 0 31
:2 0 75 4 :3 0
73 bf c1 :6 0
c4 c2 0 2040
0 2e :6 0 31
:2 0 77 8 :3 0
c6 :7 0 ca c7
c8 2040 0 30
:6 0 31 :2 0 79
8 :3 0 cc :7 0
d0 cd ce 2040
0 32 :6 0 31
:2 0 7b 8 :3 0
d2 :7 0 d6 d3
d4 2040 0 33
:6 0 31 :2 0 7d
8 :3 0 d8 :7 0
dc d9 da 2040
0 34 :6 0 31
:2 0 7f 8 :3 0
de :7 0 e2 df
e0 2040 0 35
:6 0 31 :2 0 81
8 :3 0 e4 :7 0
e8 e5 e6 2040
0 36 :6 0 31
:2 0 83 8 :3 0
ea :7 0 ee eb
ec 2040 0 37
:6 0 31 :2 0 85
8 :3 0 f0 :7 0
f4 f1 f2 2040
0 38 :6 0 31
:2 0 87 8 :3 0
f6 :7 0 fa f7
f8 2040 0 39
:6 0 31 :2 0 89
8 :3 0 fc :7 0
100 fd fe 2040
0 3a :6 0 31
:2 0 8b 8 :3 0
102 :7 0 106 103
104 2040 0 3b
:6 0 31 :2 0 8d
8 :3 0 108 :7 0
10c 109 10a 2040
0 3c :6 0 31
:2 0 8f 8 :3 0
10e :7 0 112 10f
110 2040 0 3d
:6 0 31 :2 0 91
8 :3 0 114 :7 0
118 115 116 2040
0 3e :6 0 31
:2 0 93 8 :3 0
11a :7 0 11e 11b
11c 2040 0 3f
:6 0 31 :2 0 95
8 :3 0 120 :7 0
124 121 122 2040
0 40 :6 0 31
:2 0 97 8 :3 0
126 :7 0 12a 127
128 2040 0 41
:6 0 31 :2 0 99
8 :3 0 12c :7 0
130 12d 12e 2040
0 42 :6 0 31
:2 0 9b 8 :3 0
132 :7 0 136 133
134 2040 0 43
:6 0 31 :2 0 9d
8 :3 0 138 :7 0
13c 139 13a 2040
0 44 :6 0 31
:2 0 9f 8 :3 0
13e :7 0 142 13f
140 2040 0 45
:6 0 31 :2 0 a1
8 :3 0 144 :7 0
148 145 146 2040
0 46 :6 0 31
:2 0 a3 8 :3 0
14a :7 0 14e 14b
14c 2040 0 47
:6 0 31 :2 0 a5
8 :3 0 150 :7 0
154 151 152 2040
0 48 :6 0 31
:2 0 a7 4a :3 0
156 :7 0 15a 157
158 2040 0 49
:6 0 31 :2 0 a9
8 :3 0 15c :7 0
160 15d 15e 2040
0 4b :6 0 31
:2 0 ab 8 :3 0
162 :7 0 166 163
164 2040 0 4c
:6 0 31 :2 0 ad
8 :3 0 168 :7 0
16c 169 16a 2040
0 4d :6 0 31
:2 0 af 8 :3 0
16e :7 0 172 16f
170 2040 0 4e
:6 0 51 :2 0 b1
8 :3 0 174 :7 0
178 175 176 2040
0 4f :6 0 51
:2 0 b3 4a :3 0
17a :7 0 17e 17b
17c 2040 0 50
:6 0 31 :2 0 b5
4a :3 0 180 :7 0
184 181 182 2040
0 52 :6 0 18
:2 0 b7 8 :3 0
186 :7 0 18a 187
188 2040 0 53
:6 0 18 :2 0 bb
55 :3 0 b9 18c
18e :6 0 191 18f
0 2040 0 54
:6 0 31 :2 0 bf
55 :3 0 bd 193
195 :6 0 198 196
0 2040 0 56
:6 0 31 :2 0 c1
8 :3 0 19a :7 0
19e 19b 19c 2040
0 57 :6 0 29
:2 0 c3 8 :3 0
1a0 :7 0 1a4 1a1
1a2 2040 0 58
:6 0 31 :2 0 c7
4 :3 0 c5 1a6
1a8 :6 0 1ab 1a9
0 2040 0 59
:6 0 31 :2 0 c9
8 :3 0 1ad :7 0
1b1 1ae 1af 2040
0 5a :6 0 23
:2 0 cb 8 :3 0
1b3 :7 0 1b7 1b4
1b5 2040 0 5b
:6 0 23 :2 0 cd
8 :3 0 1b9 0
2 :5 0 1bd 1ba
1bb 2040 0 5c
:6 0 31 :2 0 cf
8 :3 0 1bf 0
2 :5 0 1c3 1c0
1c1 2040 0 5d
:6 0 31 :2 0 d1
8 :3 0 1c5 0
2 :5 0 1c9 1c6
1c7 2040 0 5e
:6 0 31 :2 0 d3
8 :3 0 1cb 0
2 :5 0 1cf 1cc
1cd 2040 0 5f
:6 0 d7 862 0
d5 8 :3 0 1d1
0 2 :5 0 1d5
1d2 1d3 2040 0
60 :6 0 1e2 1e3
0 d9 8 :3 0
1d7 :7 0 1da 1d8
0 2040 0 61
:6 0 15 :3 0 16
:2 0 4 1dc 1dd
0 1de :7 0 1e1
1df 0 2040 0
62 :6 0 63 :3 0
64 :3 0 63 :3 0
65 :3 0 1e5 1e6
0 2 :4 0 db
1e7 1e9 1e4 1eb
1ea :2 0 66 :3 0
67 :3 0 1ed 1ee
0 68 :4 0 63
:3 0 69 :3 0 1f1
1f2 0 2 :4 0
dd 1f3 1f5 6a
:4 0 6b :2 0 6c
:3 0 df 1f8 1fa
:3 0 6d :4 0 6b
:2 0 6e :4 0 e2
1fd 1ff :3 0 6b
:2 0 3 :3 0 e5
201 203 :3 0 6b
:2 0 6e :4 0 e8
205 207 :3 0 6b
:2 0 6f :4 0 eb
209 20b :3 0 6b
:2 0 6e :4 0 ee
20d 20f :3 0 6b
:2 0 5 :3 0 f1
211 213 :3 0 6b
:2 0 6e :4 0 f4
215 217 :3 0 6b
:2 0 6f :4 0 f7
219 21b :3 0 6b
:2 0 6e :4 0 fa
21d 21f :3 0 6b
:2 0 6 :3 0 fd
221 223 :3 0 6b
:2 0 6e :4 0 100
225 227 :3 0 6b
:2 0 6f :4 0 103
229 22b :3 0 6b
:2 0 70 :3 0 71
:3 0 7 :3 0 106
22f 231 72 :4 0
108 22e 234 10b
22d 236 :3 0 6b
:2 0 6f :4 0 10e
238 23a :3 0 6b
:2 0 70 :3 0 71
:3 0 9 :3 0 111
23e 240 72 :4 0
113 23d 243 116
23c 245 :3 0 6b
:2 0 6f :4 0 119
247 249 :3 0 6b
:2 0 70 :3 0 71
:3 0 a :3 0 11c
24d 24f 72 :4 0
11e 24c 252 121
24b 254 :3 0 6b
:2 0 6f :4 0 124
256 258 :3 0 6b
:2 0 70 :3 0 71
:3 0 b :3 0 127
25c 25e 72 :4 0
129 25b 261 12c
25a 263 :3 0 6b
:2 0 6f :4 0 12f
265 267 :3 0 6b
:2 0 70 :3 0 71
:3 0 c :3 0 132
26b 26d 72 :4 0
134 26a 270 137
269 272 :3 0 6b
:2 0 6f :4 0 13a
274 276 :3 0 6b
:2 0 70 :3 0 71
:3 0 d :3 0 13d
27a 27c 72 :4 0
13f 279 27f 142
278 281 :3 0 6b
:2 0 6f :4 0 145
283 285 :3 0 6b
:2 0 70 :3 0 71
:3 0 e :3 0 148
289 28b 72 :4 0
14a 288 28e 14d
287 290 :3 0 6b
:2 0 6f :4 0 150
292 294 :3 0 6b
:2 0 70 :3 0 71
:3 0 f :3 0 153
298 29a 72 :4 0
155 297 29d 158
296 29f :3 0 6b
:2 0 6f :4 0 15b
2a1 2a3 :3 0 6b
:2 0 70 :3 0 71
:3 0 10 :3 0 15e
2a7 2a9 72 :4 0
160 2a6 2ac 163
2a5 2ae :3 0 6b
:2 0 6f :4 0 166
2b0 2b2 :3 0 6b
:2 0 70 :3 0 71
:3 0 11 :3 0 169
2b6 2b8 72 :4 0
16b 2b5 2bb 16e
2b4 2bd :3 0 6b
:2 0 6f :4 0 171
2bf 2c1 :3 0 6b
:2 0 6e :4 0 174
2c3 2c5 :3 0 6b
:2 0 12 :3 0 177
2c7 2c9 :3 0 6b
:2 0 6e :4 0 17a
2cb 2cd :3 0 6b
:2 0 6f :4 0 17d
2cf 2d1 :3 0 6b
:2 0 6e :4 0 180
2d3 2d5 :3 0 6b
:2 0 13 :3 0 183
2d7 2d9 :3 0 6b
:2 0 6e :4 0 186
2db 2dd :3 0 6b
:2 0 73 :4 0 189
2df 2e1 :3 0 18c
1ef 2e3 :2 0 2e5
191 2e6 1ec 2e5
0 2e7 193 0
1fa0 63 :3 0 64
:3 0 2e8 2e9 0
63 :3 0 74 :3 0
2eb 2ec 0 23
:2 0 2 :4 0 75
:2 0 76 :2 0 23
:2 0 195 2f1 2f3
:3 0 198 2ed 2f5
2ea 2f7 2f6 :2 0
66 :3 0 77 :3 0
2f9 2fa 0 68
:4 0 78 :4 0 6b
:2 0 6c :3 0 19c
2fe 300 :3 0 19f
2fb 302 :2 0 304
1a2 305 2f8 304
0 306 1a4 0
1fa0 17 :3 0 3
:3 0 307 308 0
1fa0 1c :3 0 5
:3 0 30a 30b 0
1fa0 1f :3 0 6
:3 0 30d 30e 0
1fa0 1a :3 0 13
:3 0 310 311 0
1fa0 39 :3 0 7
:3 0 313 314 0
1fa0 37 :3 0 9
:3 0 316 317 0
1fa0 38 :3 0 e
:3 0 319 31a 0
1fa0 3a :3 0 b
:3 0 31c 31d 0
1fa0 3c :3 0 f
:3 0 31f 320 0
1fa0 3b :3 0 c
:3 0 322 323 0
1fa0 33 :3 0 11
:3 0 325 326 0
1fa0 32 :3 0 a
:3 0 328 329 0
1fa0 3d :3 0 d
:3 0 32b 32c 0
1fa0 35 :3 0 10
:3 0 32e 32f 0
1fa0 19 :3 0 17
:3 0 331 332 0
1fa0 5a :3 0 79
:3 0 70 :3 0 33
:3 0 31 :2 0 1a6
336 339 1a9 335
33b 334 33c 0
1fa0 49 :3 0 51
:2 0 33e 33f 0
1fa0 34 :3 0 31
:2 0 341 342 0
1fa0 3 :3 0 7a
:2 0 1ab 345 346
:3 0 347 :2 0 63
:3 0 64 :3 0 349
34a 0 63 :3 0
74 :3 0 34c 34d
0 7b :2 0 2
:4 0 7c :2 0 76
:2 0 23 :2 0 1ad
352 354 :3 0 1b0
34e 356 34b 358
357 :2 0 66 :3 0
77 :3 0 35a 35b
0 68 :4 0 7d
:4 0 6b :2 0 6c
:3 0 1b4 35f 361
:3 0 6b :2 0 7e
:4 0 1b7 363 365
:3 0 6b :2 0 7f
:4 0 1ba 367 369
:3 0 6b :2 0 70
:3 0 71 :3 0 80
:3 0 81 :3 0 36e
36f 0 1bd 36d
371 72 :4 0 1bf
36c 374 1c2 36b
376 :3 0 1c5 35c
378 :2 0 37a 1c8
37b 359 37a 0
37c 1ca 0 3a5
63 :3 0 64 :3 0
37d 37e 0 63
:3 0 74 :3 0 380
381 0 23 :2 0
2 :4 0 82 :2 0
76 :2 0 23 :2 0
1cc 386 388 :3 0
1cf 382 38a 37f
38c 38b :2 0 66
:3 0 77 :3 0 38e
38f 0 68 :4 0
83 :4 0 6b :2 0
6c :3 0 1d3 393
395 :3 0 1d6 390
397 :2 0 399 1d9
39a 38d 399 0
39b 1db 0 3a5
84 :3 0 85 :3 0
39c 39d 0 80
:3 0 81 :3 0 39f
3a0 0 86 :3 0
1dd 39e 3a3 :2 0
3a5 1e0 3a6 348
3a5 0 3a7 1e4
0 1fa0 70 :3 0
32 :3 0 31 :2 0
1e6 3a8 3ab 87
:2 0 88 :2 0 1eb
3ad 3af :3 0 70
:3 0 3b :3 0 31
:2 0 1ee 3b1 3b4
87 :2 0 88 :2 0
1f3 3b6 3b8 :3 0
3b0 3ba 3b9 :2 0
70 :3 0 37 :3 0
31 :2 0 1f6 3bc
3bf 87 :2 0 88
:2 0 1fb 3c1 3c3
:3 0 3bb 3c5 3c4
:2 0 63 :3 0 64
:3 0 3c7 3c8 0
63 :3 0 74 :3 0
3ca 3cb 0 7b
:2 0 2 :4 0 89
:2 0 76 :2 0 23
:2 0 1fe 3d0 3d2
:3 0 201 3cc 3d4
3c9 3d6 3d5 :2 0
66 :3 0 77 :3 0
3d8 3d9 0 68
:4 0 8a :4 0 6b
:2 0 6c :3 0 205
3dd 3df :3 0 6b
:2 0 7e :4 0 208
3e1 3e3 :3 0 6b
:2 0 7f :4 0 20b
3e5 3e7 :3 0 6b
:2 0 70 :3 0 71
:3 0 80 :3 0 8b
:3 0 3ec 3ed 0
20e 3eb 3ef 72
:4 0 210 3ea 3f2
213 3e9 3f4 :3 0
216 3da 3f6 :2 0
3f8 219 3f9 3d7
3f8 0 3fa 21b
0 423 63 :3 0
64 :3 0 3fb 3fc
0 63 :3 0 74
:3 0 3fe 3ff 0
23 :2 0 2 :4 0
8c :2 0 76 :2 0
23 :2 0 21d 404
406 :3 0 220 400
408 3fd 40a 409
:2 0 66 :3 0 77
:3 0 40c 40d 0
68 :4 0 8d :4 0
6b :2 0 6c :3 0
224 411 413 :3 0
227 40e 415 :2 0
417 22a 418 40b
417 0 419 22c
0 423 84 :3 0
85 :3 0 41a 41b
0 80 :3 0 8b
:3 0 41d 41e 0
86 :3 0 22e 41c
421 :2 0 423 231
424 3c6 423 0
425 235 0 1fa0
70 :3 0 32 :3 0
31 :2 0 237 426
429 80 :3 0 8e
:2 0 8f :3 0 42b
42d 0 23c 42c
42f :3 0 430 :2 0
5 :3 0 90 :2 0
23f 433 434 :3 0
435 :2 0 436 :2 0
431 438 437 :2 0
6 :3 0 90 :2 0
241 43b 43c :3 0
43d :2 0 43e :2 0
439 440 43f :2 0
91 :3 0 92 :3 0
6 :3 0 91 :3 0
92 :3 0 5 :3 0
45 :3 0 93 :4 0
94 1 :8 0 450
15 :3 0 95 :3 0
44b 44c 0 96
:3 0 44d 44e 0
450 243 4a3 97
:3 0 15 :3 0 95
:3 0 452 453 0
96 :3 0 454 455
0 457 246 459
248 458 457 :2 0
4a1 98 :3 0 15
:3 0 95 :3 0 45c
45d 0 96 :3 0
45e 45f 0 499
63 :3 0 64 :3 0
461 462 0 63
:3 0 74 :3 0 464
465 0 99 :2 0
2 :4 0 9a :2 0
76 :2 0 23 :2 0
24a 46a 46c :3 0
24d 466 46e 463
470 46f :2 0 66
:3 0 77 :3 0 472
473 0 68 :4 0
9b :4 0 6b :2 0
6c :3 0 251 477
479 :3 0 6b :2 0
7e :4 0 254 47b
47d :3 0 6b :2 0
9c :4 0 257 47f
481 :3 0 6b :2 0
96 :3 0 25a 483
485 :3 0 6b :2 0
9d :4 0 25d 487
489 :3 0 6b :2 0
9e :3 0 9f :3 0
23 :2 0 a0 :2 0
260 48c 490 264
48b 492 :3 0 267
474 494 :2 0 496
26a 497 471 496
0 498 26c 0
499 26e 49c :3 0
49c 0 49c 49b
499 49a :6 0 49e
2 :3 0 271 4a0
273 49f 49e :2 0
4a1 275 :2 0 4a3
0 4a3 4a2 450
4a1 :6 0 51e 1
:3 0 15 :3 0 95
:3 0 4a5 4a6 0
15 :3 0 87 :2 0
a1 :3 0 4a8 4aa
0 27a 4a9 4ac
:3 0 4ad :2 0 70
:3 0 45 :3 0 31
:2 0 27d 4af 4b2
a2 :2 0 31 :2 0
282 4b4 4b6 :3 0
4b7 :2 0 4ae 4b9
4b8 :2 0 63 :3 0
64 :3 0 4bb 4bc
0 63 :3 0 74
:3 0 4be 4bf 0
7b :2 0 2 :4 0
a3 :2 0 76 :2 0
23 :2 0 285 4c4
4c6 :3 0 288 4c0
4c8 4bd 4ca 4c9
:2 0 66 :3 0 77
:3 0 4cc 4cd 0
68 :4 0 a4 :4 0
6b :2 0 6c :3 0
28c 4d1 4d3 :3 0
6b :2 0 7e :4 0
28f 4d5 4d7 :3 0
6b :2 0 7f :4 0
292 4d9 4db :3 0
6b :2 0 70 :3 0
71 :3 0 80 :3 0
a5 :3 0 4e0 4e1
0 295 4df 4e3
72 :4 0 297 4de
4e6 29a 4dd 4e8
:3 0 29d 4ce 4ea
:2 0 4ec 2a0 4ed
4cb 4ec 0 4ee
2a2 0 517 63
:3 0 64 :3 0 4ef
4f0 0 63 :3 0
74 :3 0 4f2 4f3
0 23 :2 0 2
:4 0 a6 :2 0 76
:2 0 23 :2 0 2a4
4f8 4fa :3 0 2a7
4f4 4fc 4f1 4fe
4fd :2 0 66 :3 0
77 :3 0 500 501
0 68 :4 0 a7
:4 0 6b :2 0 6c
:3 0 2ab 505 507
:3 0 2ae 502 509
:2 0 50b 2b1 50c
4ff 50b 0 50d
2b3 0 517 84
:3 0 85 :3 0 50e
50f 0 80 :3 0
a5 :3 0 511 512
0 86 :3 0 2b5
510 515 :2 0 517
2b8 518 4ba 517
0 519 2bc 0
51e 60 :3 0 23
:2 0 51a 51b 0
51e a8 :3 0 2be
58d 5 :3 0 7a
:2 0 2c2 520 521
:3 0 522 :2 0 523
:2 0 6 :3 0 7a
:2 0 2c4 526 527
:3 0 528 :2 0 529
:2 0 524 52b 52a
:2 0 6c :3 0 1c
:3 0 93 :4 0 a9
1 :8 0 536 15
:3 0 95 :3 0 531
532 0 96 :3 0
533 534 0 536
2c6 589 97 :3 0
15 :3 0 95 :3 0
538 539 0 96
:3 0 53a 53b 0
53d 2c9 53f 2cb
53e 53d :2 0 587
98 :3 0 15 :3 0
95 :3 0 542 543
0 96 :3 0 544
545 0 57f 63
:3 0 64 :3 0 547
548 0 63 :3 0
74 :3 0 54a 54b
0 99 :2 0 2
:4 0 aa :2 0 76
:2 0 23 :2 0 2cd
550 552 :3 0 2d0
54c 554 549 556
555 :2 0 66 :3 0
77 :3 0 558 559
0 68 :4 0 ab
:4 0 6b :2 0 6c
:3 0 2d4 55d 55f
:3 0 6b :2 0 7e
:4 0 2d7 561 563
:3 0 6b :2 0 9c
:4 0 2da 565 567
:3 0 6b :2 0 96
:3 0 2dd 569 56b
:3 0 6b :2 0 9d
:4 0 2e0 56d 56f
:3 0 6b :2 0 9e
:3 0 9f :3 0 23
:2 0 a0 :2 0 2e3
572 576 2e7 571
578 :3 0 2ea 55a
57a :2 0 57c 2ed
57d 557 57c 0
57e 2ef 0 57f
2f1 582 :3 0 582
0 582 581 57f
580 :6 0 584 4
:3 0 2f4 586 2f6
585 584 :2 0 587
2f8 :2 0 589 0
589 588 536 587
:6 0 58b 1 :3 0
2fb 58c 52c 58b
0 58e 441 51e
0 58e 2fd 0
1fa0 36 :3 0 ac
:3 0 ad :3 0 590
591 0 ae :3 0
70 :3 0 3c :3 0
31 :2 0 300 594
597 80 :3 0 af
:3 0 599 59a 0
303 593 59c 59d
:2 0 b0 :2 0 306
592 5a0 58f 5a1
0 1fa0 3c :3 0
ae :3 0 70 :3 0
3c :3 0 31 :2 0
309 5a5 5a8 80
:3 0 b1 :3 0 5aa
5ab 0 30c 5a4
5ad 5ae :2 0 5a3
5af 0 1fa0 70
:3 0 3c :3 0 31
:2 0 30f 5b1 5b4
80 :3 0 87 :2 0
b2 :3 0 5b6 5b8
0 314 5b7 5ba
:3 0 3c :3 0 99
:2 0 5bc 5bd 0
5bf 317 5c0 5bb
5bf 0 5c1 319
0 1fa0 70 :3 0
33 :3 0 31 :2 0
31b 5c2 5c5 87
:2 0 31 :2 0 320
5c7 5c9 :3 0 70
:3 0 b3 :3 0 70
:3 0 b4 :3 0 b5
:3 0 3f :3 0 40
:3 0 47 :3 0 b6
:3 0 b7 :3 0 17
:4 0 b8 1 :8 0
5dc 15 :3 0 95
:3 0 5d7 5d8 0
96 :3 0 5d9 5da
0 5dc 323 62f
97 :3 0 15 :3 0
95 :3 0 5de 5df
0 96 :3 0 5e0
5e1 0 5e3 326
5e5 328 5e4 5e3
:2 0 62d 98 :3 0
15 :3 0 95 :3 0
5e8 5e9 0 96
:3 0 5ea 5eb 0
625 63 :3 0 64
:3 0 5ed 5ee 0
63 :3 0 74 :3 0
5f0 5f1 0 99
:2 0 2 :4 0 b9
:2 0 76 :2 0 23
:2 0 32a 5f6 5f8
:3 0 32d 5f2 5fa
5ef 5fc 5fb :2 0
66 :3 0 77 :3 0
5fe 5ff 0 68
:4 0 ba :4 0 6b
:2 0 6c :3 0 331
603 605 :3 0 6b
:2 0 7e :4 0 334
607 609 :3 0 6b
:2 0 9c :4 0 337
60b 60d :3 0 6b
:2 0 96 :3 0 33a
60f 611 :3 0 6b
:2 0 9d :4 0 33d
613 615 :3 0 6b
:2 0 9e :3 0 9f
:3 0 23 :2 0 a0
:2 0 340 618 61c
344 617 61e :3 0
347 600 620 :2 0
622 34a 623 5fd
622 0 624 34c
0 625 34e 628
:3 0 628 0 628
627 625 626 :6 0
62a 6 :3 0 351
62c 353 62b 62a
:2 0 62d 355 :2 0
62f 0 62f 62e
5dc 62d :6 0 863
1 :3 0 15 :3 0
95 :3 0 631 632
0 15 :3 0 87
:2 0 bb :3 0 634
636 0 35a 635
638 :3 0 639 :2 0
3f :3 0 40 :3 0
47 :3 0 bc :3 0
b7 :3 0 17 :4 0
bd 1 :8 0 647
15 :3 0 95 :3 0
642 643 0 96
:3 0 644 645 0
647 35d 69a 97
:3 0 15 :3 0 95
:3 0 649 64a 0
96 :3 0 64b 64c
0 64e 360 650
362 64f 64e :2 0
698 98 :3 0 15
:3 0 95 :3 0 653
654 0 96 :3 0
655 656 0 690
63 :3 0 64 :3 0
658 659 0 63
:3 0 74 :3 0 65b
65c 0 99 :2 0
2 :4 0 be :2 0
76 :2 0 23 :2 0
364 661 663 :3 0
367 65d 665 65a
667 666 :2 0 66
:3 0 77 :3 0 669
66a 0 68 :4 0
bf :4 0 6b :2 0
6c :3 0 36b 66e
670 :3 0 6b :2 0
7e :4 0 36e 672
674 :3 0 6b :2 0
9c :4 0 371 676
678 :3 0 6b :2 0
96 :3 0 374 67a
67c :3 0 6b :2 0
9d :4 0 377 67e
680 :3 0 6b :2 0
9e :3 0 9f :3 0
23 :2 0 a0 :2 0
37a 683 687 37e
682 689 :3 0 381
66b 68b :2 0 68d
384 68e 668 68d
0 68f 386 0
690 388 693 :3 0
693 0 693 692
690 691 :6 0 695
8 :3 0 38b 697
38d 696 695 :2 0
698 38f :2 0 69a
0 69a 699 647
698 :6 0 716 1
:3 0 15 :3 0 95
:3 0 69c 69d 0
15 :3 0 87 :2 0
bb :3 0 69f 6a1
0 394 6a0 6a3
:3 0 6a4 :2 0 63
:3 0 64 :3 0 6a6
6a7 0 63 :3 0
74 :3 0 6a9 6aa
0 18 :2 0 2
:4 0 2f :2 0 76
:2 0 23 :2 0 397
6af 6b1 :3 0 39a
6ab 6b3 6a8 6b5
6b4 :2 0 66 :3 0
77 :3 0 6b7 6b8
0 68 :4 0 c0
:4 0 6b :2 0 6c
:3 0 39e 6bc 6be
:3 0 6b :2 0 7e
:4 0 3a1 6c0 6c2
:3 0 6b :2 0 7f
:4 0 3a4 6c4 6c6
:3 0 6b :2 0 70
:3 0 71 :3 0 80
:3 0 8b :3 0 6cb
6cc 0 3a7 6ca
6ce 72 :4 0 3a9
6c9 6d1 3ac 6c8
6d3 :3 0 6b :2 0
c1 :4 0 3af 6d5
6d7 :3 0 6b :2 0
6e :4 0 3b2 6d9
6db :3 0 6b :2 0
17 :3 0 3b5 6dd
6df :3 0 6b :2 0
6e :4 0 3b8 6e1
6e3 :3 0 3bb 6b9
6e5 :2 0 6e7 3be
6e8 6b6 6e7 0
6e9 3c0 0 713
63 :3 0 64 :3 0
6ea 6eb 0 63
:3 0 74 :3 0 6ed
6ee 0 23 :2 0
2 :4 0 c2 :2 0
76 :2 0 23 :2 0
3c2 6f3 6f5 :3 0
3c5 6ef 6f7 6ec
6f9 6f8 :2 0 66
:3 0 77 :3 0 6fb
6fc 0 68 :4 0
c3 :4 0 6b :2 0
6c :3 0 3c9 700
702 :3 0 3cc 6fd
704 :2 0 706 3cf
707 6fa 706 0
708 3d1 0 713
84 :3 0 c4 :3 0
709 70a 0 80
:3 0 8b :3 0 70c
70d 0 17 :3 0
86 :3 0 3d3 70b
711 :2 0 713 3d7
714 6a5 713 0
715 3db 0 716
3dd 717 63a 716
0 718 3e0 0
863 5b :3 0 31
:2 0 719 71a 0
863 c5 :3 0 5b
:3 0 c6 :3 0 c7
:3 0 17 :4 0 c8
1 :8 0 727 15
:3 0 95 :3 0 722
723 0 96 :3 0
724 725 0 727
3e2 77a 97 :3 0
15 :3 0 95 :3 0
729 72a 0 96
:3 0 72b 72c 0
72e 3e5 730 3e7
72f 72e :2 0 778
98 :3 0 15 :3 0
95 :3 0 733 734
0 96 :3 0 735
736 0 770 63
:3 0 64 :3 0 738
739 0 63 :3 0
74 :3 0 73b 73c
0 99 :2 0 2
:4 0 c9 :2 0 76
:2 0 23 :2 0 3e9
741 743 :3 0 3ec
73d 745 73a 747
746 :2 0 66 :3 0
77 :3 0 749 74a
0 68 :4 0 ca
:4 0 6b :2 0 6c
:3 0 3f0 74e 750
:3 0 6b :2 0 7e
:4 0 3f3 752 754
:3 0 6b :2 0 9c
:4 0 3f6 756 758
:3 0 6b :2 0 96
:3 0 3f9 75a 75c
:3 0 6b :2 0 9d
:4 0 3fc 75e 760
:3 0 6b :2 0 9e
:3 0 9f :3 0 23
:2 0 a0 :2 0 3ff
763 767 403 762
769 :3 0 406 74b
76b :2 0 76d 409
76e 748 76d 0
76f 40b 0 770
40d 773 :3 0 773
0 773 772 770
771 :6 0 775 a
:3 0 410 777 412
776 775 :2 0 778
414 :2 0 77a 0
77a 779 727 778
:6 0 863 1 :3 0
70 :3 0 5b :3 0
31 :2 0 417 77c
77f cb :2 0 31
:2 0 41c 781 783
:3 0 cc :3 0 22
:3 0 b6 :3 0 b7
:3 0 17 :4 0 cd
1 :8 0 790 15
:3 0 95 :3 0 78b
78c 0 96 :3 0
78d 78e 0 790
41f 7e3 97 :3 0
15 :3 0 95 :3 0
792 793 0 96
:3 0 794 795 0
797 422 799 424
798 797 :2 0 7e1
98 :3 0 15 :3 0
95 :3 0 79c 79d
0 96 :3 0 79e
79f 0 7d9 63
:3 0 64 :3 0 7a1
7a2 0 63 :3 0
74 :3 0 7a4 7a5
0 99 :2 0 2
:4 0 ce :2 0 76
:2 0 23 :2 0 426
7aa 7ac :3 0 429
7a6 7ae 7a3 7b0
7af :2 0 66 :3 0
77 :3 0 7b2 7b3
0 68 :4 0 cf
:4 0 6b :2 0 6c
:3 0 42d 7b7 7b9
:3 0 6b :2 0 7e
:4 0 430 7bb 7bd
:3 0 6b :2 0 9c
:4 0 433 7bf 7c1
:3 0 6b :2 0 96
:3 0 436 7c3 7c5
:3 0 6b :2 0 9d
:4 0 439 7c7 7c9
:3 0 6b :2 0 9e
:3 0 9f :3 0 23
:2 0 a0 :2 0 43c
7cc 7d0 440 7cb
7d2 :3 0 443 7b4
7d4 :2 0 7d6 446
7d7 7b1 7d6 0
7d8 448 0 7d9
44a 7dc :3 0 7dc
0 7dc 7db 7d9
7da :6 0 7de c
:3 0 44d 7e0 44f
7df 7de :2 0 7e1
451 :2 0 7e3 0
7e3 7e2 790 7e1
:6 0 860 1 :3 0
91 :3 0 d0 :3 0
7e5 7e6 0 22
:3 0 d1 :4 0 454
7e7 7ea 87 :2 0
31 :2 0 459 7ec
7ee :3 0 63 :3 0
64 :3 0 7f0 7f1
0 63 :3 0 74
:3 0 7f3 7f4 0
18 :2 0 2 :4 0
d2 :2 0 76 :2 0
23 :2 0 45c 7f9
7fb :3 0 45f 7f5
7fd 7f2 7ff 7fe
:2 0 66 :3 0 77
:3 0 801 802 0
68 :4 0 d3 :4 0
6b :2 0 6c :3 0
463 806 808 :3 0
6b :2 0 7e :4 0
466 80a 80c :3 0
6b :2 0 7f :4 0
469 80e 810 :3 0
6b :2 0 70 :3 0
71 :3 0 80 :3 0
d4 :3 0 815 816
0 46c 814 818
72 :4 0 46e 813
81b 471 812 81d
:3 0 6b :2 0 c1
:4 0 474 81f 821
:3 0 6b :2 0 6e
:4 0 477 823 825
:3 0 6b :2 0 17
:3 0 47a 827 829
:3 0 6b :2 0 6e
:4 0 47d 82b 82d
:3 0 480 803 82f
:2 0 831 483 832
800 831 0 833
485 0 85d 63
:3 0 64 :3 0 834
835 0 63 :3 0
74 :3 0 837 838
0 23 :2 0 2
:4 0 d5 :2 0 76
:2 0 23 :2 0 487
83d 83f :3 0 48a
839 841 836 843
842 :2 0 66 :3 0
77 :3 0 845 846
0 68 :4 0 d6
:4 0 6b :2 0 6c
:3 0 48e 84a 84c
:3 0 491 847 84e
:2 0 850 494 851
844 850 0 852
496 0 85d 84
:3 0 c4 :3 0 853
854 0 80 :3 0
d4 :3 0 856 857
0 17 :3 0 86
:3 0 498 855 85b
:2 0 85d 49c 85e
7ef 85d 0 85f
4a0 0 860 4a2
861 784 860 0
862 4a5 0 863
4a7 a4f 12 :3 0
7a :2 0 4ad 865
866 :3 0 867 :2 0
63 :3 0 64 :3 0
869 86a 0 63
:3 0 74 :3 0 86c
86d 0 7b :2 0
2 :4 0 d7 :2 0
76 :2 0 23 :2 0
4af 872 874 :3 0
4b2 86e 876 86b
878 877 :2 0 66
:3 0 77 :3 0 87a
87b 0 68 :4 0
d8 :4 0 6b :2 0
6c :3 0 4b6 87f
881 :3 0 6b :2 0
7e :4 0 4b9 883
885 :3 0 6b :2 0
7f :4 0 4bc 887
889 :3 0 6b :2 0
70 :3 0 71 :3 0
80 :3 0 81 :3 0
88e 88f 0 4bf
88d 891 72 :4 0
4c1 88c 894 4c4
88b 896 :3 0 4c7
87c 898 :2 0 89a
4ca 89b 879 89a
0 89c 4cc 0
8c5 63 :3 0 64
:3 0 89d 89e 0
63 :3 0 74 :3 0
8a0 8a1 0 23
:2 0 2 :4 0 d9
:2 0 76 :2 0 23
:2 0 4ce 8a6 8a8
:3 0 4d1 8a2 8aa
89f 8ac 8ab :2 0
66 :3 0 77 :3 0
8ae 8af 0 68
:4 0 da :4 0 6b
:2 0 6c :3 0 4d5
8b3 8b5 :3 0 4d8
8b0 8b7 :2 0 8b9
4db 8ba 8ad 8b9
0 8bb 4dd 0
8c5 84 :3 0 85
:3 0 8bc 8bd 0
80 :3 0 81 :3 0
8bf 8c0 0 86
:3 0 4df 8be 8c3
:2 0 8c5 4e2 8c6
868 8c5 0 8c7
4e6 0 a4e 28
:3 0 12 :3 0 8c8
8c9 0 a4e 1b
:3 0 9e :3 0 9e
:3 0 28 :3 0 23
:2 0 18 :2 0 4e8
8cd 8d1 23 :2 0
18 :2 0 4ec 8cc
8d5 8cb 8d6 0
a4e 24 :3 0 db
:3 0 dc :3 0 8d9
8da 0 23 :2 0
23 :2 0 dd :2 0
28 :3 0 4f0 8db
8e0 8d8 8e1 0
a4e de :3 0 70
:3 0 33 :3 0 31
:2 0 4f5 8e4 8e7
4f8 8e3 8e9 8e
:2 0 31 :2 0 4fc
8eb 8ed :3 0 c7
:3 0 70 :3 0 b3
:3 0 70 :3 0 b4
:3 0 b5 :3 0 17
:3 0 3f :3 0 40
:3 0 47 :3 0 b6
:3 0 b7 :3 0 19
:3 0 df :3 0 80
:3 0 e0 :3 0 80
:3 0 e1 :3 0 80
:3 0 e2 :3 0 80
:3 0 e3 :3 0 80
:3 0 e4 :4 0 e5
1 :8 0 90d 15
:3 0 95 :3 0 908
909 0 96 :3 0
90a 90b 0 90d
4ff 960 97 :3 0
15 :3 0 95 :3 0
90f 910 0 96
:3 0 911 912 0
914 502 916 504
915 914 :2 0 95e
98 :3 0 15 :3 0
95 :3 0 919 91a
0 96 :3 0 91b
91c 0 956 63
:3 0 64 :3 0 91e
91f 0 63 :3 0
74 :3 0 921 922
0 99 :2 0 2
:4 0 e6 :2 0 76
:2 0 23 :2 0 506
927 929 :3 0 509
923 92b 920 92d
92c :2 0 66 :3 0
77 :3 0 92f 930
0 68 :4 0 e7
:4 0 6b :2 0 6c
:3 0 50d 934 936
:3 0 6b :2 0 7e
:4 0 510 938 93a
:3 0 6b :2 0 9c
:4 0 513 93c 93e
:3 0 6b :2 0 96
:3 0 516 940 942
:3 0 6b :2 0 9d
:4 0 519 944 946
:3 0 6b :2 0 9e
:3 0 9f :3 0 23
:2 0 a0 :2 0 51c
949 94d 520 948
94f :3 0 523 931
951 :2 0 953 526
954 92e 953 0
955 528 0 956
52a 959 :3 0 959
0 959 958 956
957 :6 0 95b e
:3 0 52d 95d 52f
95c 95b :2 0 95e
531 :2 0 960 0
960 95f 90d 95e
:6 0 9dc 1 :3 0
15 :3 0 95 :3 0
962 963 0 15
:3 0 87 :2 0 bb
:3 0 965 967 0
536 966 969 :3 0
96a :2 0 63 :3 0
64 :3 0 96c 96d
0 63 :3 0 74
:3 0 96f 970 0
18 :2 0 2 :4 0
e8 :2 0 76 :2 0
23 :2 0 539 975
977 :3 0 53c 971
979 96e 97b 97a
:2 0 66 :3 0 77
:3 0 97d 97e 0
68 :4 0 e9 :4 0
6b :2 0 6c :3 0
540 982 984 :3 0
6b :2 0 7e :4 0
543 986 988 :3 0
6b :2 0 7f :4 0
546 98a 98c :3 0
6b :2 0 70 :3 0
71 :3 0 80 :3 0
ea :3 0 991 992
0 549 990 994
72 :4 0 54b 98f
997 54e 98e 999
:3 0 6b :2 0 c1
:4 0 551 99b 99d
:3 0 6b :2 0 6e
:4 0 554 99f 9a1
:3 0 6b :2 0 19
:3 0 557 9a3 9a5
:3 0 6b :2 0 6e
:4 0 55a 9a7 9a9
:3 0 55d 97f 9ab
:2 0 9ad 560 9ae
97c 9ad 0 9af
562 0 9d9 63
:3 0 64 :3 0 9b0
9b1 0 63 :3 0
74 :3 0 9b3 9b4
0 23 :2 0 2
:4 0 eb :2 0 76
:2 0 23 :2 0 564
9b9 9bb :3 0 567
9b5 9bd 9b2 9bf
9be :2 0 66 :3 0
77 :3 0 9c1 9c2
0 68 :4 0 ec
:4 0 6b :2 0 6c
:3 0 56b 9c6 9c8
:3 0 56e 9c3 9ca
:2 0 9cc 571 9cd
9c0 9cc 0 9ce
573 0 9d9 84
:3 0 c4 :3 0 9cf
9d0 0 80 :3 0
ea :3 0 9d2 9d3
0 19 :3 0 86
:3 0 575 9d1 9d7
:2 0 9d9 579 9da
96b 9d9 0 9db
57d 0 9dc 57f
a4b 63 :3 0 64
:3 0 9dd 9de 0
63 :3 0 74 :3 0
9e0 9e1 0 18
:2 0 2 :4 0 ed
:2 0 76 :2 0 23
:2 0 582 9e6 9e8
:3 0 585 9e2 9ea
9df 9ec 9eb :2 0
66 :3 0 77 :3 0
9ee 9ef 0 68
:4 0 ee :4 0 6b
:2 0 6c :3 0 589
9f3 9f5 :3 0 6b
:2 0 7e :4 0 58c
9f7 9f9 :3 0 6b
:2 0 7f :4 0 58f
9fb 9fd :3 0 6b
:2 0 70 :3 0 71
:3 0 80 :3 0 ea
:3 0 a02 a03 0
592 a01 a05 72
:4 0 594 a00 a08
597 9ff a0a :3 0
6b :2 0 c1 :4 0
59a a0c a0e :3 0
6b :2 0 6e :4 0
59d a10 a12 :3 0
6b :2 0 19 :3 0
5a0 a14 a16 :3 0
6b :2 0 6e :4 0
5a3 a18 a1a :3 0
5a6 9f0 a1c :2 0
a1e 5a9 a1f 9ed
a1e 0 a20 5ab
0 a4a 63 :3 0
64 :3 0 a21 a22
0 63 :3 0 74
:3 0 a24 a25 0
23 :2 0 2 :4 0
ef :2 0 76 :2 0
23 :2 0 5ad a2a
a2c :3 0 5b0 a26
a2e a23 a30 a2f
:2 0 66 :3 0 77
:3 0 a32 a33 0
68 :4 0 f0 :4 0
6b :2 0 6c :3 0
5b4 a37 a39 :3 0
5b7 a34 a3b :2 0
a3d 5ba a3e a31
a3d 0 a3f 5bc
0 a4a 84 :3 0
c4 :3 0 a40 a41
0 80 :3 0 ea
:3 0 a43 a44 0
19 :3 0 86 :3 0
5be a42 a48 :2 0
a4a 5c2 a4c 8ee
9dc 0 a4d 0
a4a 0 a4d 5c6
0 a4e 5c9 a50
5ca 863 0 a51
0 a4e 0 a51
5cf 0 1fa0 70
:3 0 d :3 0 31
:2 0 5d2 a52 a55
87 :2 0 31 :2 0
5d7 a57 a59 :3 0
a5a :2 0 70 :3 0
3b :3 0 31 :2 0
5da a5c a5f 8e
:2 0 f1 :2 0 5df
a61 a63 :3 0 a64
:2 0 a5b a66 a65
:2 0 37 :3 0 31
:2 0 a68 a69 0
a6b 5e2 a6c a67
a6b 0 a6d 5e4
0 1fa0 60 :3 0
87 :2 0 31 :2 0
5e8 a6f a71 :3 0
1e :3 0 5 :3 0
a73 a74 0 b8e
1f :3 0 f2 :4 0
a76 a77 0 b8e
5b :3 0 f3 :3 0
1e :3 0 1f :3 0
70 :3 0 3a :3 0
31 :2 0 5eb a7d
a80 70 :3 0 3b
:3 0 31 :2 0 5ee
a82 a85 70 :3 0
3c :3 0 31 :2 0
5f1 a87 a8a 70
:3 0 32 :3 0 31
:2 0 5f4 a8c a8f
70 :3 0 3d :3 0
31 :2 0 5f7 a91
a94 70 :3 0 38
:3 0 31 :2 0 5fa
a96 a99 70 :3 0
3f :3 0 31 :2 0
5fd a9b a9e 70
:3 0 40 :3 0 31
:2 0 600 aa0 aa3
37 :3 0 39 :3 0
43 :3 0 603 a7a
aa8 a79 aa9 0
b8e 70 :3 0 5b
:3 0 31 :2 0 611
aab aae 80 :3 0
87 :2 0 8b :3 0
ab0 ab2 0 616
ab1 ab4 :3 0 63
:3 0 64 :3 0 ab6
ab7 0 63 :3 0
74 :3 0 ab9 aba
0 7b :2 0 2
:4 0 f4 :2 0 76
:2 0 23 :2 0 619
abf ac1 :3 0 61c
abb ac3 ab8 ac5
ac4 :2 0 66 :3 0
77 :3 0 ac7 ac8
0 68 :4 0 f5
:4 0 6b :2 0 6c
:3 0 620 acc ace
:3 0 6b :2 0 7e
:4 0 623 ad0 ad2
:3 0 6b :2 0 7f
:4 0 626 ad4 ad6
:3 0 6b :2 0 70
:3 0 71 :3 0 80
:3 0 8b :3 0 adb
adc 0 629 ada
ade 72 :4 0 62b
ad9 ae1 62e ad8
ae3 :3 0 631 ac9
ae5 :2 0 ae7 634
ae8 ac6 ae7 0
ae9 636 0 b13
63 :3 0 64 :3 0
aea aeb 0 63
:3 0 74 :3 0 aed
aee 0 23 :2 0
2 :4 0 f6 :2 0
76 :2 0 23 :2 0
638 af3 af5 :3 0
63b aef af7 aec
af9 af8 :2 0 66
:3 0 77 :3 0 afb
afc 0 68 :4 0
f7 :4 0 6b :2 0
6c :3 0 63f b00
b02 :3 0 642 afd
b04 :2 0 b06 645
b07 afa b06 0
b08 647 0 b13
84 :3 0 85 :3 0
b09 b0a 0 80
:3 0 8b :3 0 b0c
b0d 0 86 :3 0
649 b0b b10 :2 0
b13 a8 :3 0 64c
b8c 70 :3 0 5b
:3 0 31 :2 0 650
b14 b17 8e :2 0
31 :2 0 655 b19
b1b :3 0 63 :3 0
64 :3 0 b1d b1e
0 63 :3 0 74
:3 0 b20 b21 0
18 :2 0 2 :4 0
f8 :2 0 76 :2 0
23 :2 0 658 b26
b28 :3 0 65b b22
b2a b1f b2c b2b
:2 0 66 :3 0 77
:3 0 b2e b2f 0
68 :4 0 f9 :4 0
6b :2 0 6c :3 0
65f b33 b35 :3 0
6b :2 0 7e :4 0
662 b37 b39 :3 0
6b :2 0 7f :4 0
665 b3b b3d :3 0
6b :2 0 70 :3 0
71 :3 0 5b :3 0
668 b41 b43 72
:4 0 66a b40 b46
66d b3f b48 :3 0
6b :2 0 c1 :4 0
670 b4a b4c :3 0
6b :2 0 6e :4 0
673 b4e b50 :3 0
6b :2 0 17 :3 0
676 b52 b54 :3 0
6b :2 0 6e :4 0
679 b56 b58 :3 0
67c b30 b5a :2 0
b5c 67f b5d b2d
b5c 0 b5e 681
0 b8a 63 :3 0
64 :3 0 b5f b60
0 63 :3 0 74
:3 0 b62 b63 0
23 :2 0 2 :4 0
fa :2 0 76 :2 0
23 :2 0 683 b68
b6a :3 0 686 b64
b6c b61 b6e b6d
:2 0 66 :3 0 77
:3 0 b70 b71 0
68 :4 0 fb :4 0
6b :2 0 6c :3 0
68a b75 b77 :3 0
68d b72 b79 :2 0
b7b 690 b7c b6f
b7b 0 b7d 692
0 b8a 84 :3 0
c4 :3 0 b7e b7f
0 70 :3 0 5b
:3 0 31 :2 0 694
b81 b84 17 :3 0
86 :3 0 697 b80
b88 :2 0 b8a 69b
b8b b1c b8a 0
b8d ab5 b13 0
b8d 69f 0 b8e
6a2 bae 1f :3 0
6 :3 0 b8f b90
0 bad 70 :3 0
3b :3 0 31 :2 0
6a7 b92 b95 87
:2 0 88 :2 0 6ac
b97 b99 :3 0 37
:3 0 70 :3 0 37
:3 0 31 :2 0 6af
b9c b9f fc :2 0
70 :3 0 40 :3 0
31 :2 0 6b2 ba2
ba5 6b5 ba1 ba7
:3 0 b9b ba8 0
baa 6b8 bab b9a
baa 0 bac 6ba
0 bad 6bc baf
a72 b8e 0 bb0
0 bad 0 bb0
6bf 0 1fa0 70
:3 0 37 :3 0 31
:2 0 6c2 bb1 bb4
cb :2 0 31 :2 0
6c7 bb6 bb8 :3 0
bb9 :2 0 70 :3 0
3b :3 0 31 :2 0
6ca bbb bbe 8e
:2 0 f1 :2 0 6cf
bc0 bc2 :3 0 bc3
:2 0 bba bc5 bc4
:2 0 70 :3 0 3b
:3 0 31 :2 0 6d2
bc7 bca 87 :2 0
23 :2 0 6d7 bcc
bce :3 0 bcf :2 0
70 :3 0 3b :3 0
31 :2 0 6da bd1
bd4 87 :2 0 fd
:2 0 6df bd6 bd8
:3 0 bd9 :2 0 bd0
bdb bda :2 0 3a
:3 0 fd :2 0 bdd
bde 0 be1 a8
:3 0 6e2 c1b 70
:3 0 3b :3 0 31
:2 0 6e4 be2 be5
87 :2 0 31 :2 0
6e9 be7 be9 :3 0
3a :3 0 23 :2 0
beb bec 0 bef
a8 :3 0 6ec bf0
bea bef 0 c1c
70 :3 0 3b :3 0
31 :2 0 6ee bf1
bf4 87 :2 0 fe
:2 0 6f3 bf6 bf8
:3 0 bf9 :2 0 70
:3 0 3b :3 0 31
:2 0 6f6 bfb bfe
87 :2 0 ff :2 0
6fb c00 c02 :3 0
c03 :2 0 bfa c05
c04 :2 0 3a :3 0
23 :2 0 c07 c08
0 c0b a8 :3 0
6fe c0c c06 c0b
0 c1c 70 :3 0
3b :3 0 31 :2 0
700 c0d c10 87
:2 0 88 :2 0 705
c12 c14 :3 0 3a
:3 0 fe :2 0 c16
c17 0 c19 708
c1a c15 c19 0
c1c bdc be1 0
c1c 70a 0 c1d
70f c1e bc6 c1d
0 c1f 711 0
1fa0 58 :3 0 100
:4 0 c21 c22 :3 0
c20 c23 0 1fa0
2a :3 0 f2 :4 0
c25 c26 0 1fa0
2b :3 0 f2 :4 0
c28 c29 0 1fa0
20 :3 0 f2 :4 0
c2b c2c 0 1fa0
26 :3 0 f2 :4 0
c2e c2f 0 1fa0
1b :3 0 9e :3 0
1b :3 0 23 :2 0
18 :2 0 713 c32
c36 c31 c37 0
1fa0 24 :3 0 9e
:3 0 24 :3 0 23
:2 0 23 :2 0 717
c3a c3e c39 c3f
0 1fa0 70 :3 0
33 :3 0 31 :2 0
71b c41 c44 cb
:2 0 31 :2 0 720
c46 c48 :3 0 2c
:4 0 c4a c4b 0
17d8 1e :3 0 1c
:3 0 c4d c4e 0
17d8 9e :3 0 24
:3 0 23 :2 0 23
:2 0 723 c50 c54
87 :2 0 23 :4 0
729 c56 c58 :3 0
101 :3 0 102 :3 0
9e :3 0 103 :3 0
102 :3 0 9e :3 0
104 :3 0 105 :3 0
106 :3 0 107 :3 0
108 :3 0 27 :3 0
2c :3 0 2d :3 0
4b :3 0 4c :3 0
50 :3 0 52 :3 0
109 :3 0 10a :3 0
17 :3 0 10b :3 0
1b :3 0 10c :3 0
10d :4 0 10e 1
:8 0 c79 15 :3 0
95 :3 0 c74 c75
0 96 :3 0 c76
c77 0 c79 72c
ccc 97 :3 0 15
:3 0 95 :3 0 c7b
c7c 0 96 :3 0
c7d c7e 0 c80
72f c82 731 c81
c80 :2 0 cca 98
:3 0 15 :3 0 95
:3 0 c85 c86 0
96 :3 0 c87 c88
0 cc2 63 :3 0
64 :3 0 c8a c8b
0 63 :3 0 74
:3 0 c8d c8e 0
99 :2 0 2 :4 0
10f :2 0 76 :2 0
23 :2 0 733 c93
c95 :3 0 736 c8f
c97 c8c c99 c98
:2 0 66 :3 0 77
:3 0 c9b c9c 0
68 :4 0 110 :4 0
6b :2 0 6c :3 0
73a ca0 ca2 :3 0
6b :2 0 7e :4 0
73d ca4 ca6 :3 0
6b :2 0 9c :4 0
740 ca8 caa :3 0
6b :2 0 96 :3 0
743 cac cae :3 0
6b :2 0 9d :4 0
746 cb0 cb2 :3 0
6b :2 0 9e :3 0
9f :3 0 23 :2 0
a0 :2 0 749 cb5
cb9 74d cb4 cbb
:3 0 750 c9d cbd
:2 0 cbf 753 cc0
c9a cbf 0 cc1
755 0 cc2 757
cc5 :3 0 cc5 0
cc5 cc4 cc2 cc3
:6 0 cc7 10 :3 0
75a cc9 75c cc8
cc7 :2 0 cca 75e
:2 0 ccc 0 ccc
ccb c79 cca :6 0
e11 1 :3 0 111
:3 0 2e :3 0 112
:3 0 113 :3 0 1b
:4 0 114 1 :8 0
cd9 15 :3 0 95
:3 0 cd4 cd5 0
96 :3 0 cd6 cd7
0 cd9 761 d2c
97 :3 0 15 :3 0
95 :3 0 cdb cdc
0 96 :3 0 cdd
cde 0 ce0 764
ce2 766 ce1 ce0
:2 0 d2a 98 :3 0
15 :3 0 95 :3 0
ce5 ce6 0 96
:3 0 ce7 ce8 0
d22 63 :3 0 64
:3 0 cea ceb 0
63 :3 0 74 :3 0
ced cee 0 99
:2 0 2 :4 0 115
:2 0 76 :2 0 23
:2 0 768 cf3 cf5
:3 0 76b cef cf7
cec cf9 cf8 :2 0
66 :3 0 77 :3 0
cfb cfc 0 68
:4 0 116 :4 0 6b
:2 0 6c :3 0 76f
d00 d02 :3 0 6b
:2 0 7e :4 0 772
d04 d06 :3 0 6b
:2 0 9c :4 0 775
d08 d0a :3 0 6b
:2 0 96 :3 0 778
d0c d0e :3 0 6b
:2 0 9d :4 0 77b
d10 d12 :3 0 6b
:2 0 9e :3 0 9f
:3 0 23 :2 0 a0
:2 0 77e d15 d19
782 d14 d1b :3 0
785 cfd d1d :2 0
d1f 788 d20 cfa
d1f 0 d21 78a
0 d22 78c d25
:3 0 d25 0 d25
d24 d22 d23 :6 0
d27 12 :3 0 78f
d29 791 d28 d27
:2 0 d2a 793 :2 0
d2c 0 d2c d2b
cd9 d2a :6 0 e11
1 :3 0 15 :3 0
95 :3 0 d2e d2f
0 15 :3 0 87
:2 0 bb :3 0 d31
d33 0 798 d32
d35 :3 0 d36 :2 0
63 :3 0 64 :3 0
d38 d39 0 63
:3 0 74 :3 0 d3b
d3c 0 18 :2 0
2 :4 0 117 :2 0
76 :2 0 23 :2 0
79b d41 d43 :3 0
79e d3d d45 d3a
d47 d46 :2 0 66
:3 0 77 :3 0 d49
d4a 0 68 :4 0
118 :4 0 6b :2 0
6c :3 0 7a2 d4e
d50 :3 0 6b :2 0
7e :4 0 7a5 d52
d54 :3 0 6b :2 0
7f :4 0 7a8 d56
d58 :3 0 6b :2 0
70 :3 0 71 :3 0
80 :3 0 ea :3 0
d5d d5e 0 7ab
d5c d60 72 :4 0
7ad d5b d63 7b0
d5a d65 :3 0 6b
:2 0 c1 :4 0 7b3
d67 d69 :3 0 6b
:2 0 6e :4 0 7b6
d6b d6d :3 0 6b
:2 0 1b :3 0 7b9
d6f d71 :3 0 6b
:2 0 6e :4 0 7bc
d73 d75 :3 0 7bf
d4b d77 :2 0 d79
7c2 d7a d48 d79
0 d7b 7c4 0
da5 63 :3 0 64
:3 0 d7c d7d 0
63 :3 0 74 :3 0
d7f d80 0 23
:2 0 2 :4 0 119
:2 0 76 :2 0 23
:2 0 7c6 d85 d87
:3 0 7c9 d81 d89
d7e d8b d8a :2 0
66 :3 0 77 :3 0
d8d d8e 0 68
:4 0 11a :4 0 6b
:2 0 6c :3 0 7cd
d92 d94 :3 0 7d0
d8f d96 :2 0 d98
7d3 d99 d8c d98
0 d9a 7d5 0
da5 84 :3 0 c4
:3 0 d9b d9c 0
80 :3 0 ea :3 0
d9e d9f 0 1b
:3 0 86 :3 0 7d7
d9d da3 :2 0 da5
7db da6 d37 da5
0 da7 7df 0
e11 2b :3 0 1b
:3 0 da8 da9 0
e11 11b :3 0 11c
:3 0 26 :3 0 44
:3 0 11d :3 0 b7
:3 0 19 :3 0 10c
:3 0 10b :3 0 1b
:4 0 11e 1 :8 0
dbb 15 :3 0 95
:3 0 db6 db7 0
96 :3 0 db8 db9
0 dbb 7e1 e0e
97 :3 0 15 :3 0
95 :3 0 dbd dbe
0 96 :3 0 dbf
dc0 0 dc2 7e4
dc4 7e6 dc3 dc2
:2 0 e0c 98 :3 0
15 :3 0 95 :3 0
dc7 dc8 0 96
:3 0 dc9 dca 0
e04 63 :3 0 64
:3 0 dcc dcd 0
63 :3 0 74 :3 0
dcf dd0 0 99
:2 0 2 :4 0 11f
:2 0 76 :2 0 23
:2 0 7e8 dd5 dd7
:3 0 7eb dd1 dd9
dce ddb dda :2 0
66 :3 0 77 :3 0
ddd dde 0 68
:4 0 120 :4 0 6b
:2 0 6c :3 0 7ef
de2 de4 :3 0 6b
:2 0 7e :4 0 7f2
de6 de8 :3 0 6b
:2 0 9c :4 0 7f5
dea dec :3 0 6b
:2 0 96 :3 0 7f8
dee df0 :3 0 6b
:2 0 9d :4 0 7fb
df2 df4 :3 0 6b
:2 0 9e :3 0 9f
:3 0 23 :2 0 a0
:2 0 7fe df7 dfb
802 df6 dfd :3 0
805 ddf dff :2 0
e01 808 e02 ddc
e01 0 e03 80a
0 e04 80c e07
:3 0 e07 0 e07
e06 e04 e05 :6 0
e09 14 :3 0 80f
e0b 811 e0a e09
:2 0 e0c 813 :2 0
e0e 0 e0e e0d
dbb e0c :6 0 e11
1 :3 0 a8 :3 0
816 11b8 9e :3 0
24 :3 0 23 :2 0
23 :2 0 81c e12
e16 87 :2 0 31
:4 0 822 e18 e1a
:3 0 121 :3 0 2e
:3 0 122 :3 0 10b
:3 0 1b :4 0 123
1 :8 0 e27 15
:3 0 95 :3 0 e22
e23 0 96 :3 0
e24 e25 0 e27
825 e7a 97 :3 0
15 :3 0 95 :3 0
e29 e2a 0 96
:3 0 e2b e2c 0
e2e 828 e30 82a
e2f e2e :2 0 e78
98 :3 0 15 :3 0
95 :3 0 e33 e34
0 96 :3 0 e35
e36 0 e70 63
:3 0 64 :3 0 e38
e39 0 63 :3 0
74 :3 0 e3b e3c
0 99 :2 0 2
:4 0 124 :2 0 76
:2 0 23 :2 0 82c
e41 e43 :3 0 82f
e3d e45 e3a e47
e46 :2 0 66 :3 0
77 :3 0 e49 e4a
0 68 :4 0 125
:4 0 6b :2 0 6c
:3 0 833 e4e e50
:3 0 6b :2 0 7e
:4 0 836 e52 e54
:3 0 6b :2 0 9c
:4 0 839 e56 e58
:3 0 6b :2 0 96
:3 0 83c e5a e5c
:3 0 6b :2 0 9d
:4 0 83f e5e e60
:3 0 6b :2 0 9e
:3 0 9f :3 0 23
:2 0 a0 :2 0 842
e63 e67 846 e62
e69 :3 0 849 e4b
e6b :2 0 e6d 84c
e6e e48 e6d 0
e6f 84e 0 e70
850 e73 :3 0 e73
0 e73 e72 e70
e71 :6 0 e75 16
:3 0 853 e77 855
e76 e75 :2 0 e78
857 :2 0 e7a 0
e7a e79 e27 e78
:6 0 1159 1 :3 0
15 :3 0 95 :3 0
e7c e7d 0 15
:3 0 87 :2 0 bb
:3 0 e7f e81 0
85c e80 e83 :3 0
e84 :2 0 63 :3 0
64 :3 0 e86 e87
0 63 :3 0 74
:3 0 e89 e8a 0
18 :2 0 2 :4 0
126 :2 0 76 :2 0
23 :2 0 85f e8f
e91 :3 0 862 e8b
e93 e88 e95 e94
:2 0 66 :3 0 77
:3 0 e97 e98 0
68 :4 0 127 :4 0
6b :2 0 6c :3 0
866 e9c e9e :3 0
6b :2 0 7e :4 0
869 ea0 ea2 :3 0
6b :2 0 7f :4 0
86c ea4 ea6 :3 0
6b :2 0 70 :3 0
71 :3 0 80 :3 0
ea :3 0 eab eac
0 86f eaa eae
72 :4 0 871 ea9
eb1 874 ea8 eb3
:3 0 6b :2 0 c1
:4 0 877 eb5 eb7
:3 0 6b :2 0 6e
:4 0 87a eb9 ebb
:3 0 6b :2 0 1b
:3 0 87d ebd ebf
:3 0 6b :2 0 6e
:4 0 880 ec1 ec3
:3 0 883 e99 ec5
:2 0 ec7 886 ec8
e96 ec7 0 ec9
888 0 ef3 63
:3 0 64 :3 0 eca
ecb 0 63 :3 0
74 :3 0 ecd ece
0 23 :2 0 2
:4 0 128 :2 0 76
:2 0 23 :2 0 88a
ed3 ed5 :3 0 88d
ecf ed7 ecc ed9
ed8 :2 0 66 :3 0
77 :3 0 edb edc
0 68 :4 0 129
:4 0 6b :2 0 6c
:3 0 891 ee0 ee2
:3 0 894 edd ee4
:2 0 ee6 897 ee7
eda ee6 0 ee8
899 0 ef3 84
:3 0 c4 :3 0 ee9
eea 0 80 :3 0
ea :3 0 eec eed
0 1b :3 0 86
:3 0 89b eeb ef1
:2 0 ef3 89f ef4
e85 ef3 0 ef5
8a3 0 1159 2a
:3 0 1b :3 0 ef6
ef7 0 1159 101
:3 0 102 :3 0 9e
:3 0 103 :3 0 102
:3 0 9e :3 0 104
:3 0 105 :3 0 106
:3 0 107 :3 0 108
:3 0 27 :3 0 2c
:3 0 2d :3 0 4b
:3 0 4c :3 0 50
:3 0 52 :3 0 109
:3 0 10a :3 0 17
:3 0 10b :3 0 1b
:3 0 10c :3 0 10d
:4 0 12a 1 :8 0
f18 15 :3 0 95
:3 0 f13 f14 0
96 :3 0 f15 f16
0 f18 8a5 f6b
97 :3 0 15 :3 0
95 :3 0 f1a f1b
0 96 :3 0 f1c
f1d 0 f1f 8a8
f21 8aa f20 f1f
:2 0 f69 98 :3 0
15 :3 0 95 :3 0
f24 f25 0 96
:3 0 f26 f27 0
f61 63 :3 0 64
:3 0 f29 f2a 0
63 :3 0 74 :3 0
f2c f2d 0 99
:2 0 2 :4 0 12b
:2 0 76 :2 0 23
:2 0 8ac f32 f34
:3 0 8af f2e f36
f2b f38 f37 :2 0
66 :3 0 77 :3 0
f3a f3b 0 68
:4 0 12c :4 0 6b
:2 0 6c :3 0 8b3
f3f f41 :3 0 6b
:2 0 7e :4 0 8b6
f43 f45 :3 0 6b
:2 0 9c :4 0 8b9
f47 f49 :3 0 6b
:2 0 96 :3 0 8bc
f4b f4d :3 0 6b
:2 0 9d :4 0 8bf
f4f f51 :3 0 6b
:2 0 9e :3 0 9f
:3 0 23 :2 0 a0
:2 0 8c2 f54 f58
8c6 f53 f5a :3 0
8c9 f3c f5c :2 0
f5e 8cc f5f f39
f5e 0 f60 8ce
0 f61 8d0 f64
:3 0 f64 0 f64
f63 f61 f62 :6 0
f66 18 :3 0 8d3
f68 8d5 f67 f66
:2 0 f69 8d7 :2 0
f6b 0 f6b f6a
f18 f69 :6 0 1159
1 :3 0 15 :3 0
95 :3 0 f6d f6e
0 15 :3 0 87
:2 0 bb :3 0 f70
f72 0 8dc f71
f74 :3 0 f75 :2 0
5e :3 0 23 :2 0
f77 f78 0 10f1
101 :3 0 102 :3 0
9e :3 0 103 :3 0
102 :3 0 9e :3 0
104 :3 0 105 :3 0
106 :3 0 107 :3 0
108 :3 0 27 :3 0
2c :3 0 2d :3 0
4b :3 0 4c :3 0
50 :3 0 52 :3 0
109 :3 0 10a :3 0
17 :3 0 10b :3 0
1b :3 0 10c :3 0
10d :4 0 12d 1
:8 0 f99 15 :3 0
95 :3 0 f94 f95
0 96 :3 0 f96
f97 0 f99 8df
fec 97 :3 0 15
:3 0 95 :3 0 f9b
f9c 0 96 :3 0
f9d f9e 0 fa0
8e2 fa2 8e4 fa1
fa0 :2 0 fea 98
:3 0 15 :3 0 95
:3 0 fa5 fa6 0
96 :3 0 fa7 fa8
0 fe2 63 :3 0
64 :3 0 faa fab
0 63 :3 0 74
:3 0 fad fae 0
99 :2 0 2 :4 0
12e :2 0 76 :2 0
23 :2 0 8e6 fb3
fb5 :3 0 8e9 faf
fb7 fac fb9 fb8
:2 0 66 :3 0 77
:3 0 fbb fbc 0
68 :4 0 12f :4 0
6b :2 0 6c :3 0
8ed fc0 fc2 :3 0
6b :2 0 7e :4 0
8f0 fc4 fc6 :3 0
6b :2 0 9c :4 0
8f3 fc8 fca :3 0
6b :2 0 96 :3 0
8f6 fcc fce :3 0
6b :2 0 9d :4 0
8f9 fd0 fd2 :3 0
6b :2 0 9e :3 0
9f :3 0 23 :2 0
a0 :2 0 8fc fd5
fd9 900 fd4 fdb
:3 0 903 fbd fdd
:2 0 fdf 906 fe0
fba fdf 0 fe1
908 0 fe2 90a
fe5 :3 0 fe5 0
fe5 fe4 fe2 fe3
:6 0 fe7 1a :3 0
90d fe9 90f fe8
fe7 :2 0 fea 911
:2 0 fec 0 fec
feb f99 fea :6 0
10f1 1 :3 0 15
:3 0 95 :3 0 fee
fef 0 15 :3 0
87 :2 0 bb :3 0
ff1 ff3 0 916
ff2 ff5 :3 0 ff6
:2 0 5e :3 0 130
:2 0 23 :2 0 919
ff9 ffb :3 0 ff8
ffc 0 10ee de
:3 0 70 :3 0 33
:3 0 31 :2 0 91b
fff 1002 91e ffe
1004 8e :2 0 31
:2 0 922 1006 1008
:3 0 5b :3 0 31
:2 0 100a 100b 0
10eb 131 :3 0 5b
:3 0 93 :3 0 109
:3 0 c7 :3 0 17
:3 0 10a :3 0 c7
:3 0 10b :3 0 1b
:4 0 132 1 :8 0
101d 15 :3 0 95
:3 0 1018 1019 0
96 :3 0 101a 101b
0 101d 925 1070
97 :3 0 15 :3 0
95 :3 0 101f 1020
0 96 :3 0 1021
1022 0 1024 928
1026 92a 1025 1024
:2 0 106e 98 :3 0
15 :3 0 95 :3 0
1029 102a 0 96
:3 0 102b 102c 0
1066 63 :3 0 64
:3 0 102e 102f 0
63 :3 0 74 :3 0
1031 1032 0 99
:2 0 2 :4 0 133
:2 0 76 :2 0 23
:2 0 92c 1037 1039
:3 0 92f 1033 103b
1030 103d 103c :2 0
66 :3 0 77 :3 0
103f 1040 0 68
:4 0 134 :4 0 6b
:2 0 6c :3 0 933
1044 1046 :3 0 6b
:2 0 7e :4 0 936
1048 104a :3 0 6b
:2 0 9c :4 0 939
104c 104e :3 0 6b
:2 0 96 :3 0 93c
1050 1052 :3 0 6b
:2 0 9d :4 0 93f
1054 1056 :3 0 6b
:2 0 9e :3 0 9f
:3 0 23 :2 0 a0
:2 0 942 1059 105d
946 1058 105f :3 0
949 1041 1061 :2 0
1063 94c 1064 103e
1063 0 1065 94e
0 1066 950 1069
:3 0 1069 0 1069
1068 1066 1067 :6 0
106b 1c :3 0 953
106d 955 106c 106b
:2 0 106e 957 :2 0
1070 0 1070 106f
101d 106e :6 0 10eb
1 :3 0 70 :3 0
5b :3 0 31 :2 0
95a 1072 1075 8e
:2 0 31 :2 0 95f
1077 1079 :3 0 63
:3 0 64 :3 0 107b
107c 0 63 :3 0
74 :3 0 107e 107f
0 18 :2 0 2
:4 0 135 :2 0 76
:2 0 23 :2 0 962
1084 1086 :3 0 965
1080 1088 107d 108a
1089 :2 0 66 :3 0
77 :3 0 108c 108d
0 68 :4 0 136
:4 0 6b :2 0 6c
:3 0 969 1091 1093
:3 0 6b :2 0 7e
:4 0 96c 1095 1097
:3 0 6b :2 0 7f
:4 0 96f 1099 109b
:3 0 6b :2 0 70
:3 0 71 :3 0 80
:3 0 137 :3 0 10a0
10a1 0 972 109f
10a3 72 :4 0 974
109e 10a6 977 109d
10a8 :3 0 6b :2 0
c1 :4 0 97a 10aa
10ac :3 0 6b :2 0
6e :4 0 97d 10ae
10b0 :3 0 6b :2 0
1b :3 0 980 10b2
10b4 :3 0 6b :2 0
6e :4 0 983 10b6
10b8 :3 0 986 108e
10ba :2 0 10bc 989
10bd 108b 10bc 0
10be 98b 0 10e8
63 :3 0 64 :3 0
10bf 10c0 0 63
:3 0 74 :3 0 10c2
10c3 0 23 :2 0
2 :4 0 138 :2 0
76 :2 0 23 :2 0
98d 10c8 10ca :3 0
990 10c4 10cc 10c1
10ce 10cd :2 0 66
:3 0 77 :3 0 10d0
10d1 0 68 :4 0
139 :4 0 6b :2 0
6c :3 0 994 10d5
10d7 :3 0 997 10d2
10d9 :2 0 10db 99a
10dc 10cf 10db 0
10dd 99c 0 10e8
84 :3 0 c4 :3 0
10de 10df 0 80
:3 0 137 :3 0 10e1
10e2 0 1b :3 0
86 :3 0 99e 10e0
10e6 :2 0 10e8 9a2
10e9 107a 10e8 0
10ea 9a6 0 10eb
9a8 10ec 1009 10eb
0 10ed 9ac 0
10ee 9ae 10ef ff7
10ee 0 10f0 9b1
0 10f1 9b3 10f2
f76 10f1 0 10f3
9b7 0 1159 11b
:3 0 11c :3 0 26
:3 0 44 :3 0 11d
:3 0 b7 :3 0 19
:3 0 10c :3 0 10b
:3 0 1b :4 0 13a
1 :8 0 1104 15
:3 0 95 :3 0 10ff
1100 0 96 :3 0
1101 1102 0 1104
9b9 1157 97 :3 0
15 :3 0 95 :3 0
1106 1107 0 96
:3 0 1108 1109 0
110b 9bc 110d 9be
110c 110b :2 0 1155
98 :3 0 15 :3 0
95 :3 0 1110 1111
0 96 :3 0 1112
1113 0 114d 63
:3 0 64 :3 0 1115
1116 0 63 :3 0
74 :3 0 1118 1119
0 99 :2 0 2
:4 0 13b :2 0 76
:2 0 23 :2 0 9c0
111e 1120 :3 0 9c3
111a 1122 1117 1124
1123 :2 0 66 :3 0
77 :3 0 1126 1127
0 68 :4 0 13c
:4 0 6b :2 0 6c
:3 0 9c7 112b 112d
:3 0 6b :2 0 7e
:4 0 9ca 112f 1131
:3 0 6b :2 0 9c
:4 0 9cd 1133 1135
:3 0 6b :2 0 96
:3 0 9d0 1137 1139
:3 0 6b :2 0 9d
:4 0 9d3 113b 113d
:3 0 6b :2 0 9e
:3 0 9f :3 0 23
:2 0 a0 :2 0 9d6
1140 1144 9da 113f
1146 :3 0 9dd 1128
1148 :2 0 114a 9e0
114b 1125 114a 0
114c 9e2 0 114d
9e4 1150 :3 0 1150
0 1150 114f 114d
114e :6 0 1152 1e
:3 0 9e7 1154 9e9
1153 1152 :2 0 1155
9eb :2 0 1157 0
1157 1156 1104 1155
:6 0 1159 1 :3 0
9ee 115a e1b 1159
0 11ba 63 :3 0
64 :3 0 115b 115c
0 63 :3 0 74
:3 0 115e 115f 0
7b :2 0 2 :4 0
13d :2 0 76 :2 0
23 :2 0 9f5 1164
1166 :3 0 9f8 1160
1168 115d 116a 1169
:2 0 66 :3 0 77
:3 0 116c 116d 0
68 :4 0 13e :4 0
6b :2 0 6c :3 0
9fc 1171 1173 :3 0
6b :2 0 7e :4 0
9ff 1175 1177 :3 0
6b :2 0 7f :4 0
a02 1179 117b :3 0
6b :2 0 70 :3 0
71 :3 0 80 :3 0
8b :3 0 1180 1181
0 a05 117f 1183
72 :4 0 a07 117e
1186 a0a 117d 1188
:3 0 a0d 116e 118a
:2 0 118c a10 118d
116b 118c 0 118e
a12 0 11b7 63
:3 0 64 :3 0 118f
1190 0 63 :3 0
74 :3 0 1192 1193
0 23 :2 0 2
:4 0 13f :2 0 76
:2 0 23 :2 0 a14
1198 119a :3 0 a17
1194 119c 1191 119e
119d :2 0 66 :3 0
77 :3 0 11a0 11a1
0 68 :4 0 140
:4 0 6b :2 0 6c
:3 0 a1b 11a5 11a7
:3 0 a1e 11a2 11a9
:2 0 11ab a21 11ac
119f 11ab 0 11ad
a23 0 11b7 84
:3 0 85 :3 0 11ae
11af 0 80 :3 0
8b :3 0 11b1 11b2
0 86 :3 0 a25
11b0 11b5 :2 0 11b7
a28 11b9 c59 e11
0 11ba 0 11b7
0 11ba a2c 0
17d8 15 :3 0 95
:3 0 11bb 11bc 0
15 :3 0 87 :2 0
a1 :3 0 11be 11c0
0 a32 11bf 11c2
:3 0 11c3 :2 0 58
:3 0 141 :3 0 31
:2 0 70 :3 0 33
:3 0 31 :2 0 a35
11c8 11cb 80 :3 0
142 :3 0 11cd 11ce
0 54 :3 0 a38
11c6 11d1 11c5 11d2
0 1279 58 :3 0
141 :3 0 31 :2 0
70 :3 0 33 :3 0
31 :2 0 a3d 11d7
11da 80 :3 0 143
:3 0 11dc 11dd 0
56 :3 0 a40 11d5
11e0 11d4 11e1 0
1279 11d :3 0 11c
:3 0 144 :3 0 56
:3 0 145 :3 0 80
:3 0 e0 :3 0 80
:3 0 e1 :3 0 80
:3 0 e2 :3 0 80
:3 0 e3 :3 0 80
:3 0 e4 :3 0 80
:3 0 146 :3 0 144
:3 0 56 :3 0 80
:3 0 147 :3 0 144
:3 0 54 :3 0 80
:3 0 146 :3 0 db
:3 0 148 :3 0 11c
:3 0 80 :3 0 147
:3 0 144 :3 0 144
:3 0 56 :3 0 54
:3 0 144 :3 0 11b
:3 0 26 :4 0 149
1 :8 0 121e 14a
:4 0 1209 :3 0 86
:3 0 87 :2 0 a47
120c 120d :3 0 15
:3 0 95 :3 0 120f
1210 0 31 :2 0
1211 1212 0 1214
a4a 121b 15 :3 0
95 :3 0 1215 1216
0 f1 :2 0 1217
1218 0 121a a4c
121c 120e 1214 0
121d 0 121a 0
121d a4e 0 121e
a51 1271 97 :3 0
15 :3 0 95 :3 0
1220 1221 0 96
:3 0 1222 1223 0
1225 a54 1227 a56
1226 1225 :2 0 126f
98 :3 0 15 :3 0
95 :3 0 122a 122b
0 96 :3 0 122c
122d 0 1267 63
:3 0 64 :3 0 122f
1230 0 63 :3 0
74 :3 0 1232 1233
0 99 :2 0 2
:4 0 14b :2 0 76
:2 0 23 :2 0 a58
1238 123a :3 0 a5b
1234 123c 1231 123e
123d :2 0 66 :3 0
77 :3 0 1240 1241
0 68 :4 0 14c
:4 0 6b :2 0 6c
:3 0 a5f 1245 1247
:3 0 6b :2 0 7e
:4 0 a62 1249 124b
:3 0 6b :2 0 9c
:4 0 a65 124d 124f
:3 0 6b :2 0 96
:3 0 a68 1251 1253
:3 0 6b :2 0 9d
:4 0 a6b 1255 1257
:3 0 6b :2 0 9e
:3 0 9f :3 0 23
:2 0 a0 :2 0 a6e
125a 125e a72 1259
1260 :3 0 a75 1242
1262 :2 0 1264 a78
1265 123f 1264 0
1266 a7a 0 1267
a7c 126a :3 0 126a
0 126a 1269 1267
1268 :6 0 126c 20
:3 0 a7f 126e a81
126d 126c :2 0 126f
a83 :2 0 1271 0
1271 1270 121e 126f
:6 0 1279 1 :3 0
58 :3 0 14d :3 0
26 :3 0 a86 1274
1276 1273 1277 0
1279 a88 1326 26
:3 0 14e :4 0 127b
127c :3 0 127a 127d
0 1325 58 :3 0
141 :3 0 31 :2 0
70 :3 0 33 :3 0
31 :2 0 a8d 1282
1285 80 :3 0 142
:3 0 1287 1288 0
54 :3 0 a90 1280
128b 127f 128c 0
1325 53 :3 0 80
:3 0 146 :3 0 128f
1290 0 128e 1291
0 1325 57 :3 0
23 :2 0 1293 1294
0 1325 58 :3 0
14f :3 0 17 :3 0
1b :3 0 33 :3 0
53 :3 0 54 :3 0
24 :3 0 57 :3 0
a95 1297 129f 1296
12a0 0 1325 11d
:3 0 11b :3 0 c7
:3 0 b7 :3 0 145
:3 0 150 :3 0 10c
:3 0 10b :3 0 11c
:3 0 144 :3 0 151
:3 0 152 :3 0 26
:3 0 17 :3 0 19
:3 0 33 :3 0 5a
:3 0 24 :3 0 1b
:3 0 80 :3 0 146
:3 0 54 :3 0 13
:3 0 6c :4 0 153
1 :8 0 12d0 14a
:4 0 12bb :3 0 86
:3 0 87 :2 0 a9f
12be 12bf :3 0 15
:3 0 95 :3 0 12c1
12c2 0 31 :2 0
12c3 12c4 0 12c6
aa2 12cd 15 :3 0
95 :3 0 12c7 12c8
0 f1 :2 0 12c9
12ca 0 12cc aa4
12ce 12c0 12c6 0
12cf 0 12cc 0
12cf aa6 0 12d0
aa9 1323 97 :3 0
15 :3 0 95 :3 0
12d2 12d3 0 96
:3 0 12d4 12d5 0
12d7 aac 12d9 aae
12d8 12d7 :2 0 1321
98 :3 0 15 :3 0
95 :3 0 12dc 12dd
0 96 :3 0 12de
12df 0 1319 63
:3 0 64 :3 0 12e1
12e2 0 63 :3 0
74 :3 0 12e4 12e5
0 99 :2 0 2
:4 0 154 :2 0 76
:2 0 23 :2 0 ab0
12ea 12ec :3 0 ab3
12e6 12ee 12e3 12f0
12ef :2 0 66 :3 0
77 :3 0 12f2 12f3
0 68 :4 0 155
:4 0 6b :2 0 6c
:3 0 ab7 12f7 12f9
:3 0 6b :2 0 7e
:4 0 aba 12fb 12fd
:3 0 6b :2 0 9c
:4 0 abd 12ff 1301
:3 0 6b :2 0 96
:3 0 ac0 1303 1305
:3 0 6b :2 0 9d
:4 0 ac3 1307 1309
:3 0 6b :2 0 9e
:3 0 9f :3 0 23
:2 0 a0 :2 0 ac6
130c 1310 aca 130b
1312 :3 0 acd 12f4
1314 :2 0 1316 ad0
1317 12f1 1316 0
1318 ad2 0 1319
ad4 131c :3 0 131c
0 131c 131b 1319
131a :6 0 131e 22
:3 0 ad7 1320 ad9
131f 131e :2 0 1321
adb :2 0 1323 0
1323 1322 12d0 1321
:6 0 1325 1 :3 0
ade 1327 11c4 1279
0 1328 0 1325
0 1328 ae5 0
17d8 70 :3 0 35
:3 0 31 :2 0 ae8
1329 132c 87 :2 0
31 :2 0 aed 132e
1330 :3 0 1331 :2 0
2c :3 0 90 :2 0
af0 1334 1335 :3 0
1336 :2 0 1332 1338
1337 :2 0 5e :3 0
87 :2 0 31 :2 0
af4 133b 133d :3 0
133e :2 0 1339 1340
133f :2 0 70 :3 0
37 :3 0 31 :2 0
af7 1342 1345 cb
:2 0 31 :2 0 afc
1347 1349 :3 0 70
:3 0 3b :3 0 31
:2 0 aff 134b 134e
8e :2 0 f1 :2 0
b04 1350 1352 :3 0
5b :3 0 70 :3 0
37 :3 0 31 :2 0
b07 1355 1358 1354
1359 0 135b b0a
137b 5b :3 0 156
:3 0 157 :3 0 70
:3 0 37 :3 0 31
:2 0 b0c 135f 1362
fc :2 0 70 :3 0
3f :3 0 31 :2 0
b0f 1365 1368 b12
1364 136a :3 0 136b
:2 0 b15 135e 136d
158 :2 0 159 :2 0
b17 136f 1371 :3 0
76 :2 0 15a :2 0
b1a 1373 1375 :3 0
b1d 135d 1377 135c
1378 0 137a b1f
137c 1353 135b 0
137d 0 137a 0
137d b21 0 15b4
9e :3 0 24 :3 0
23 :2 0 23 :2 0
b24 137e 1382 87
:2 0 23 :4 0 b2a
1384 1386 :3 0 15b
:2 0 b2d 1388 1389
:3 0 138a :2 0 1e
:3 0 7a :2 0 b2f
138d 138e :3 0 138f
:2 0 91 :3 0 15c
:3 0 1391 1392 0
1c :3 0 2c :3 0
15d :2 0 b31 1393
1397 15e :2 0 31
:2 0 b37 1399 139b
:3 0 139c :2 0 91
:3 0 15c :3 0 139e
139f 0 1c :3 0
2d :3 0 15d :2 0
b3a 13a0 13a4 15f
:2 0 31 :2 0 b40
13a6 13a8 :3 0 13a9
:2 0 139d 13ab 13aa
:2 0 13ac :2 0 1390
13ae 13ad :2 0 13af
:2 0 138b 13b1 13b0
:2 0 2c :4 0 13b3
13b4 0 1525 160
:3 0 161 :3 0 162
:3 0 2c :3 0 163
:3 0 164 :3 0 165
:3 0 161 :3 0 161
:3 0 c7 :3 0 17
:3 0 161 :3 0 101
:3 0 27 :3 0 161
:3 0 162 :3 0 102
:3 0 9e :3 0 1e
:3 0 161 :3 0 166
:3 0 164 :3 0 b7
:3 0 1b :3 0 164
:3 0 162 :3 0 161
:3 0 162 :3 0 164
:3 0 167 :3 0 161
:3 0 168 :4 0 169
1 :8 0 13dc 15
:3 0 95 :3 0 13d7
13d8 0 96 :3 0
13d9 13da 0 13dc
b43 142f 97 :3 0
15 :3 0 95 :3 0
13de 13df 0 96
:3 0 13e0 13e1 0
13e3 b46 13e5 b48
13e4 13e3 :2 0 142d
98 :3 0 15 :3 0
95 :3 0 13e8 13e9
0 96 :3 0 13ea
13eb 0 1425 63
:3 0 64 :3 0 13ed
13ee 0 63 :3 0
74 :3 0 13f0 13f1
0 99 :2 0 2
:4 0 16a :2 0 76
:2 0 23 :2 0 b4a
13f6 13f8 :3 0 b4d
13f2 13fa 13ef 13fc
13fb :2 0 66 :3 0
77 :3 0 13fe 13ff
0 68 :4 0 16b
:4 0 6b :2 0 6c
:3 0 b51 1403 1405
:3 0 6b :2 0 7e
:4 0 b54 1407 1409
:3 0 6b :2 0 9c
:4 0 b57 140b 140d
:3 0 6b :2 0 96
:3 0 b5a 140f 1411
:3 0 6b :2 0 9d
:4 0 b5d 1413 1415
:3 0 6b :2 0 9e
:3 0 9f :3 0 23
:2 0 a0 :2 0 b60
1418 141c b64 1417
141e :3 0 b67 1400
1420 :2 0 1422 b6a
1423 13fd 1422 0
1424 b6c 0 1425
b6e 1428 :3 0 1428
0 1428 1427 1425
1426 :6 0 142a 24
:3 0 b71 142c b73
142b 142a :2 0 142d
b75 :2 0 142f 0
142f 142e 13dc 142d
:6 0 1525 1 :3 0
2c :3 0 7a :2 0
b78 1432 1433 :3 0
1434 :2 0 91 :3 0
15c :3 0 1436 1437
0 1f :3 0 2d
:3 0 15d :2 0 b7a
1438 143c 15e :2 0
31 :2 0 b80 143e
1440 :3 0 91 :3 0
16c :3 0 102 :3 0
9e :3 0 2d :3 0
91 :3 0 16d :3 0
1e :3 0 93 :4 0
16e 1 :8 0 1451
15 :3 0 95 :3 0
144c 144d 0 96
:3 0 144e 144f 0
1451 b83 14a4 97
:3 0 15 :3 0 95
:3 0 1453 1454 0
96 :3 0 1455 1456
0 1458 b86 145a
b88 1459 1458 :2 0
14a2 98 :3 0 15
:3 0 95 :3 0 145d
145e 0 96 :3 0
145f 1460 0 149a
63 :3 0 64 :3 0
1462 1463 0 63
:3 0 74 :3 0 1465
1466 0 99 :2 0
2 :4 0 16f :2 0
76 :2 0 23 :2 0
b8a 146b 146d :3 0
b8d 1467 146f 1464
1471 1470 :2 0 66
:3 0 77 :3 0 1473
1474 0 68 :4 0
170 :4 0 6b :2 0
6c :3 0 b91 1478
147a :3 0 6b :2 0
7e :4 0 b94 147c
147e :3 0 6b :2 0
9c :4 0 b97 1480
1482 :3 0 6b :2 0
96 :3 0 b9a 1484
1486 :3 0 6b :2 0
9d :4 0 b9d 1488
148a :3 0 6b :2 0
9e :3 0 9f :3 0
23 :2 0 a0 :2 0
ba0 148d 1491 ba4
148c 1493 :3 0 ba7
1475 1495 :2 0 1497
baa 1498 1472 1497
0 1499 bac 0
149a bae 149d :3 0
149d 0 149d 149c
149a 149b :6 0 149f
26 :3 0 bb1 14a1
bb3 14a0 149f :2 0
14a2 bb5 :2 0 14a4
0 14a4 14a3 1451
14a2 :6 0 14a9 1
:3 0 1f :3 0 6
:3 0 14a6 14a7 0
14a9 bb8 14b1 1e
:3 0 1c :3 0 14aa
14ab 0 14b0 1f
:3 0 6 :3 0 14ad
14ae 0 14b0 bbb
14b2 1441 14a9 0
14b3 0 14b0 0
14b3 bbe 0 14b4
bc1 1522 91 :3 0
16c :3 0 162 :3 0
db :3 0 171 :3 0
172 :3 0 1e :3 0
165 :3 0 c7 :3 0
17 :3 0 101 :3 0
27 :3 0 162 :3 0
2c :4 0 173 1
:8 0 14c9 15 :3 0
95 :3 0 14c4 14c5
0 96 :3 0 14c6
14c7 0 14c9 bc3
151c 97 :3 0 15
:3 0 95 :3 0 14cb
14cc 0 96 :3 0
14cd 14ce 0 14d0
bc6 14d2 bc8 14d1
14d0 :2 0 151a 98
:3 0 15 :3 0 95
:3 0 14d5 14d6 0
96 :3 0 14d7 14d8
0 1512 63 :3 0
64 :3 0 14da 14db
0 63 :3 0 74
:3 0 14dd 14de 0
99 :2 0 2 :4 0
174 :2 0 76 :2 0
23 :2 0 bca 14e3
14e5 :3 0 bcd 14df
14e7 14dc 14e9 14e8
:2 0 66 :3 0 77
:3 0 14eb 14ec 0
68 :4 0 175 :4 0
6b :2 0 6c :3 0
bd1 14f0 14f2 :3 0
6b :2 0 7e :4 0
bd4 14f4 14f6 :3 0
6b :2 0 9c :4 0
bd7 14f8 14fa :3 0
6b :2 0 96 :3 0
bda 14fc 14fe :3 0
6b :2 0 9d :4 0
bdd 1500 1502 :3 0
6b :2 0 9e :3 0
9f :3 0 23 :2 0
a0 :2 0 be0 1505
1509 be4 1504 150b
:3 0 be7 14ed 150d
:2 0 150f bea 1510
14ea 150f 0 1511
bec 0 1512 bee
1515 :3 0 1515 0
1515 1514 1512 1513
:6 0 1517 28 :3 0
bf1 1519 bf3 1518
1517 :2 0 151a bf5
:2 0 151c 0 151c
151b 14c9 151a :6 0
1521 1 :3 0 1f
:3 0 6 :3 0 151e
151f 0 1521 bf8
1523 1435 14b4 0
1524 0 1521 0
1524 bfb 0 1525
bfe 152d 1e :3 0
1c :3 0 1526 1527
0 152c 1f :3 0
6 :3 0 1529 152a
0 152c c02 152e
13b2 1525 0 152f
0 152c 0 152f
c05 0 15b4 60
:3 0 87 :2 0 23
:2 0 c0a 1531 1533
:3 0 91 :3 0 15c
:3 0 1535 1536 0
1e :3 0 1f :3 0
15d :2 0 c0d 1537
153b cb :2 0 31
:2 0 c13 153d 153f
:3 0 1534 1541 1540
:2 0 63 :3 0 64
:3 0 1543 1544 0
63 :3 0 74 :3 0
1546 1547 0 18
:2 0 2 :4 0 176
:2 0 76 :2 0 23
:2 0 c16 154c 154e
:3 0 c19 1548 1550
1545 1552 1551 :2 0
66 :3 0 77 :3 0
1554 1555 0 68
:4 0 177 :4 0 6b
:2 0 6c :3 0 c1d
1559 155b :3 0 6b
:2 0 7e :4 0 c20
155d 155f :3 0 6b
:2 0 7f :4 0 c23
1561 1563 :3 0 6b
:2 0 70 :3 0 71
:3 0 80 :3 0 178
:3 0 1568 1569 0
c26 1567 156b 72
:4 0 c28 1566 156e
c2b 1565 1570 :3 0
6b :2 0 c1 :4 0
c2e 1572 1574 :3 0
6b :2 0 6e :4 0
c31 1576 1578 :3 0
6b :2 0 1b :3 0
c34 157a 157c :3 0
6b :2 0 6e :4 0
c37 157e 1580 :3 0
c3a 1556 1582 :2 0
1584 c3d 1585 1553
1584 0 1586 c3f
0 15b0 63 :3 0
64 :3 0 1587 1588
0 63 :3 0 74
:3 0 158a 158b 0
23 :2 0 2 :4 0
179 :2 0 76 :2 0
23 :2 0 c41 1590
1592 :3 0 c44 158c
1594 1589 1596 1595
:2 0 66 :3 0 77
:3 0 1598 1599 0
68 :4 0 17a :4 0
6b :2 0 6c :3 0
c48 159d 159f :3 0
c4b 159a 15a1 :2 0
15a3 c4e 15a4 1597
15a3 0 15a5 c50
0 15b0 84 :3 0
c4 :3 0 15a6 15a7
0 80 :3 0 178
:3 0 15a9 15aa 0
1b :3 0 86 :3 0
c52 15a8 15ae :2 0
15b0 c56 15b1 1542
15b0 0 15b2 c5a
0 15b4 a8 :3 0
c5c 171a 60 :3 0
87 :2 0 23 :2 0
c62 15b6 15b8 :3 0
4f :3 0 31 :2 0
15ba 15bb 0 1718
17b :3 0 168 :3 0
4f :3 0 165 :3 0
c7 :3 0 17 :3 0
101 :3 0 27 :3 0
162 :3 0 102 :3 0
9e :3 0 1e :3 0
102 :3 0 9e :3 0
1f :4 0 17c 1
:8 0 15d2 15 :3 0
95 :3 0 15cd 15ce
0 96 :3 0 15cf
15d0 0 15d2 c65
1625 97 :3 0 15
:3 0 95 :3 0 15d4
15d5 0 96 :3 0
15d6 15d7 0 15d9
c68 15db c6a 15da
15d9 :2 0 1623 98
:3 0 15 :3 0 95
:3 0 15de 15df 0
96 :3 0 15e0 15e1
0 161b 63 :3 0
64 :3 0 15e3 15e4
0 63 :3 0 74
:3 0 15e6 15e7 0
99 :2 0 2 :4 0
17d :2 0 76 :2 0
23 :2 0 c6c 15ec
15ee :3 0 c6f 15e8
15f0 15e5 15f2 15f1
:2 0 66 :3 0 77
:3 0 15f4 15f5 0
68 :4 0 17e :4 0
6b :2 0 6c :3 0
c73 15f9 15fb :3 0
6b :2 0 7e :4 0
c76 15fd 15ff :3 0
6b :2 0 9c :4 0
c79 1601 1603 :3 0
6b :2 0 96 :3 0
c7c 1605 1607 :3 0
6b :2 0 9d :4 0
c7f 1609 160b :3 0
6b :2 0 9e :3 0
9f :3 0 23 :2 0
a0 :2 0 c82 160e
1612 c86 160d 1614
:3 0 c89 15f6 1616
:2 0 1618 c8c 1619
15f3 1618 0 161a
c8e 0 161b c90
161e :3 0 161e 0
161e 161d 161b 161c
:6 0 1620 2a :3 0
c93 1622 c95 1621
1620 :2 0 1623 c97
:2 0 1625 0 1625
1624 15d2 1623 :6 0
1718 1 :3 0 4e
:3 0 31 :2 0 1627
1628 0 1718 17b
:3 0 167 :3 0 4e
:3 0 163 :3 0 b7
:3 0 1b :3 0 162
:3 0 102 :3 0 9e
:3 0 1e :3 0 102
:3 0 9e :3 0 1f
:4 0 17f 1 :8 0
163d 15 :3 0 95
:3 0 1638 1639 0
96 :3 0 163a 163b
0 163d c9a 1690
97 :3 0 15 :3 0
95 :3 0 163f 1640
0 96 :3 0 1641
1642 0 1644 c9d
1646 c9f 1645 1644
:2 0 168e 98 :3 0
15 :3 0 95 :3 0
1649 164a 0 96
:3 0 164b 164c 0
1686 63 :3 0 64
:3 0 164e 164f 0
63 :3 0 74 :3 0
1651 1652 0 99
:2 0 2 :4 0 180
:2 0 76 :2 0 23
:2 0 ca1 1657 1659
:3 0 ca4 1653 165b
1650 165d 165c :2 0
66 :3 0 77 :3 0
165f 1660 0 68
:4 0 181 :4 0 6b
:2 0 6c :3 0 ca8
1664 1666 :3 0 6b
:2 0 7e :4 0 cab
1668 166a :3 0 6b
:2 0 9c :4 0 cae
166c 166e :3 0 6b
:2 0 96 :3 0 cb1
1670 1672 :3 0 6b
:2 0 9d :4 0 cb4
1674 1676 :3 0 6b
:2 0 9e :3 0 9f
:3 0 23 :2 0 a0
:2 0 cb7 1679 167d
cbb 1678 167f :3 0
cbe 1661 1681 :2 0
1683 cc1 1684 165e
1683 0 1685 cc3
0 1686 cc5 1689
:3 0 1689 0 1689
1688 1686 1687 :6 0
168b 2c :3 0 cc8
168d cca 168c 168b
:2 0 168e ccc :2 0
1690 0 1690 168f
163d 168e :6 0 1718
1 :3 0 70 :3 0
4e :3 0 31 :2 0
ccf 1692 1695 a2
:2 0 70 :3 0 4f
:3 0 31 :2 0 cd2
1698 169b 76 :2 0
70 :3 0 39 :3 0
31 :2 0 cd5 169e
16a1 cd8 169d 16a3
:3 0 16a4 :2 0 cdd
1697 16a6 :3 0 63
:3 0 64 :3 0 16a8
16a9 0 63 :3 0
74 :3 0 16ab 16ac
0 18 :2 0 2
:4 0 182 :2 0 76
:2 0 23 :2 0 ce0
16b1 16b3 :3 0 ce3
16ad 16b5 16aa 16b7
16b6 :2 0 66 :3 0
77 :3 0 16b9 16ba
0 68 :4 0 183
:4 0 6b :2 0 6c
:3 0 ce7 16be 16c0
:3 0 6b :2 0 7e
:4 0 cea 16c2 16c4
:3 0 6b :2 0 7f
:4 0 ced 16c6 16c8
:3 0 6b :2 0 70
:3 0 71 :3 0 80
:3 0 178 :3 0 16cd
16ce 0 cf0 16cc
16d0 72 :4 0 cf2
16cb 16d3 cf5 16ca
16d5 :3 0 6b :2 0
c1 :4 0 cf8 16d7
16d9 :3 0 6b :2 0
6e :4 0 cfb 16db
16dd :3 0 6b :2 0
1b :3 0 cfe 16df
16e1 :3 0 6b :2 0
6e :4 0 d01 16e3
16e5 :3 0 d04 16bb
16e7 :2 0 16e9 d07
16ea 16b8 16e9 0
16eb d09 0 1715
63 :3 0 64 :3 0
16ec 16ed 0 63
:3 0 74 :3 0 16ef
16f0 0 23 :2 0
2 :4 0 184 :2 0
76 :2 0 23 :2 0
d0b 16f5 16f7 :3 0
d0e 16f1 16f9 16ee
16fb 16fa :2 0 66
:3 0 77 :3 0 16fd
16fe 0 68 :4 0
185 :4 0 6b :2 0
6c :3 0 d12 1702
1704 :3 0 d15 16ff
1706 :2 0 1708 d18
1709 16fc 1708 0
170a d1a 0 1715
84 :3 0 c4 :3 0
170b 170c 0 80
:3 0 178 :3 0 170e
170f 0 1b :3 0
86 :3 0 d1c 170d
1713 :2 0 1715 d20
1716 16a7 1715 0
1717 d24 0 1718
d26 1719 15b9 1718
0 171b 134a 15b4
0 171b d2c 0
171c d2f 171d 1341
171c 0 171e d31
0 17d8 9e :3 0
24 :3 0 23 :2 0
23 :2 0 d33 171f
1723 87 :2 0 23
:4 0 d39 1725 1727
:3 0 46 :3 0 80
:3 0 186 :3 0 172a
172b 0 1729 172c
0 172e d3c 1737
46 :3 0 70 :3 0
3c :3 0 31 :2 0
d3e 1730 1733 172f
1734 0 1736 d41
1738 1728 172e 0
1739 0 1736 0
1739 d43 0 17d8
5f :3 0 187 :3 0
26 :3 0 17 :3 0
19 :3 0 1b :3 0
49 :3 0 33 :3 0
20 :3 0 20 :3 0
20 :3 0 20 :3 0
1e :3 0 1f :3 0
43 :3 0 39 :3 0
37 :3 0 3a :3 0
3b :3 0 36 :3 0
46 :3 0 24 :3 0
35 :3 0 32 :3 0
3d :3 0 38 :3 0
34 :3 0 3f :3 0
47 :3 0 1a :3 0
31 :2 0 31 :2 0
51 :2 0 51 :2 0
31 :2 0 31 :2 0
d46 173b 175e 173a
175f 0 17d8 5f
:3 0 87 :2 0 31
:2 0 d6b 1762 1764
:3 0 188 :3 0 189
:3 0 18a :3 0 1b
:4 0 18b 1 :8 0
1780 14a :4 0 176b
:3 0 86 :3 0 87
:2 0 d70 176e 176f
:3 0 15 :3 0 95
:3 0 1771 1772 0
31 :2 0 1773 1774
0 1776 d73 177d
15 :3 0 95 :3 0
1777 1778 0 f1
:2 0 1779 177a 0
177c d75 177e 1770
1776 0 177f 0
177c 0 177f d77
0 1780 d7a 17d3
97 :3 0 15 :3 0
95 :3 0 1782 1783
0 96 :3 0 1784
1785 0 1787 d7d
1789 d7f 1788 1787
:2 0 17d1 98 :3 0
15 :3 0 95 :3 0
178c 178d 0 96
:3 0 178e 178f 0
17c9 63 :3 0 64
:3 0 1791 1792 0
63 :3 0 74 :3 0
1794 1795 0 99
:2 0 2 :4 0 18c
:2 0 76 :2 0 23
:2 0 d81 179a 179c
:3 0 d84 1796 179e
1793 17a0 179f :2 0
66 :3 0 77 :3 0
17a2 17a3 0 68
:4 0 18d :4 0 6b
:2 0 6c :3 0 d88
17a7 17a9 :3 0 6b
:2 0 7e :4 0 d8b
17ab 17ad :3 0 6b
:2 0 9c :4 0 d8e
17af 17b1 :3 0 6b
:2 0 96 :3 0 d91
17b3 17b5 :3 0 6b
:2 0 9d :4 0 d94
17b7 17b9 :3 0 6b
:2 0 9e :3 0 9f
:3 0 23 :2 0 a0
:2 0 d97 17bc 17c0
d9b 17bb 17c2 :3 0
d9e 17a4 17c4 :2 0
17c6 da1 17c7 17a1
17c6 0 17c8 da3
0 17c9 da5 17cc
:3 0 17cc 0 17cc
17cb 17c9 17ca :6 0
17ce 2e :3 0 da8
17d0 daa 17cf 17ce
:2 0 17d1 dac :2 0
17d3 0 17d3 17d2
1780 17d1 :6 0 17d5
1 :3 0 daf 17d6
1765 17d5 0 17d7
db1 0 17d8 db3
1cc8 2a :3 0 f2
:4 0 17d9 17da 0
1cc7 2b :3 0 f2
:4 0 17dc 17dd 0
1cc7 28 :3 0 12
:3 0 17df 17e0 0
1cc7 70 :3 0 18e
:3 0 28 :3 0 dbc
17e3 17e5 31 :2 0
dbe 17e2 17e8 a2
:2 0 18 :2 0 dc3
17ea 17ec :3 0 61
:3 0 31 :2 0 17ee
17ef 0 17f1 dc6
1809 61 :3 0 156
:3 0 70 :3 0 18e
:3 0 28 :3 0 dc8
17f5 17f7 31 :2 0
dca 17f4 17fa 76
:2 0 23 :2 0 dcd
17fc 17fe :3 0 17ff
:2 0 158 :2 0 dd
:2 0 dd0 1801 1803
:3 0 dd3 17f3 1805
17f2 1806 0 1808
dd5 180a 17ed 17f1
0 180b 0 1808
0 180b dd7 0
1cc7 61 :3 0 cb
:2 0 31 :2 0 ddc
180d 180f :3 0 30
:3 0 31 :2 0 1811
1812 0 1cc4 18f
:3 0 70 :3 0 30
:3 0 31 :2 0 ddf
1815 1818 61 :3 0
a2 :2 0 190 :3 0
de4 181b 181d :3 0
181e 1cc3 1b :3 0
db :3 0 dc :3 0
1821 1822 0 18
:2 0 18 :2 0 70
:3 0 30 :3 0 31
:2 0 de7 1826 1829
fc :2 0 dd :2 0
dea 182b 182d :3 0
76 :2 0 23 :2 0
ded 182f 1831 :3 0
28 :3 0 df0 1823
1834 1820 1835 0
1cc1 24 :3 0 db
:3 0 dc :3 0 1838
1839 0 23 :2 0
23 :2 0 70 :3 0
30 :3 0 31 :2 0
df5 183d 1840 fc
:2 0 dd :2 0 df8
1842 1844 :3 0 76
:2 0 18 :2 0 dfb
1846 1848 :3 0 76
:2 0 23 :2 0 dfe
184a 184c :3 0 28
:3 0 e01 183a 184f
1837 1850 0 1cc1
9e :3 0 24 :3 0
23 :2 0 23 :2 0
e06 1852 1856 87
:2 0 23 :4 0 e0c
1858 185a :3 0 46
:3 0 80 :3 0 186
:3 0 185d 185e 0
185c 185f 0 188d
70 :3 0 18e :3 0
2b :3 0 e0f 1862
1864 31 :2 0 e11
1861 1867 87 :2 0
31 :2 0 e16 1869
186b :3 0 2b :3 0
1b :3 0 186d 186e
0 1870 e19 188a
2b :3 0 9e :3 0
2b :3 0 6b :2 0
191 :4 0 e1b 1874
1876 :3 0 23 :2 0
29 :2 0 e1e 1872
187a 1871 187b 0
1889 2b :3 0 9e
:3 0 2b :3 0 6b
:2 0 1b :3 0 e22
1880 1882 :3 0 23
:2 0 29 :2 0 e25
187e 1886 187d 1887
0 1889 e29 188b
186c 1870 0 188c
0 1889 0 188c
e2c 0 188d e2f
18c2 46 :3 0 70
:3 0 3c :3 0 31
:2 0 e32 188f 1892
188e 1893 0 18c1
70 :3 0 18e :3 0
2a :3 0 e35 1896
1898 31 :2 0 e37
1895 189b 87 :2 0
31 :2 0 e3c 189d
189f :3 0 2a :3 0
1b :3 0 18a1 18a2
0 18a4 e3f 18be
2a :3 0 9e :3 0
2a :3 0 6b :2 0
191 :4 0 e41 18a8
18aa :3 0 23 :2 0
29 :2 0 e44 18a6
18ae 18a5 18af 0
18bd 2a :3 0 9e
:3 0 2a :3 0 6b
:2 0 1b :3 0 e48
18b4 18b6 :3 0 23
:2 0 29 :2 0 e4b
18b2 18ba 18b1 18bb
0 18bd e4f 18bf
18a0 18a4 0 18c0
0 18bd 0 18c0
e52 0 18c1 e55
18c3 185b 188d 0
18c4 0 18c1 0
18c4 e58 0 1cc1
9e :3 0 24 :3 0
23 :2 0 23 :2 0
e5b 18c5 18c9 87
:2 0 23 :4 0 e61
18cb 18cd :3 0 35
:3 0 31 :2 0 18cf
18d0 0 18d2 e64
18d3 18ce 18d2 0
18d4 e66 0 1cc1
41 :3 0 31 :2 0
18d5 18d6 0 1cc1
35 :3 0 31 :2 0
18d8 18d9 0 1cc1
101 :3 0 192 :3 0
193 :3 0 27 :3 0
1e :3 0 1f :3 0
109 :3 0 10a :3 0
17 :3 0 10b :3 0
1b :3 0 10d :4 0
194 1 :8 0 18ed
15 :3 0 95 :3 0
18e8 18e9 0 96
:3 0 18ea 18eb 0
18ed e68 1940 97
:3 0 15 :3 0 95
:3 0 18ef 18f0 0
96 :3 0 18f1 18f2
0 18f4 e6b 18f6
e6d 18f5 18f4 :2 0
193e 98 :3 0 15
:3 0 95 :3 0 18f9
18fa 0 96 :3 0
18fb 18fc 0 1936
63 :3 0 64 :3 0
18fe 18ff 0 63
:3 0 74 :3 0 1901
1902 0 99 :2 0
2 :4 0 195 :2 0
76 :2 0 23 :2 0
e6f 1907 1909 :3 0
e72 1903 190b 1900
190d 190c :2 0 66
:3 0 77 :3 0 190f
1910 0 68 :4 0
196 :4 0 6b :2 0
6c :3 0 e76 1914
1916 :3 0 6b :2 0
7e :4 0 e79 1918
191a :3 0 6b :2 0
9c :4 0 e7c 191c
191e :3 0 6b :2 0
96 :3 0 e7f 1920
1922 :3 0 6b :2 0
9d :4 0 e82 1924
1926 :3 0 6b :2 0
9e :3 0 9f :3 0
23 :2 0 a0 :2 0
e85 1929 192d e89
1928 192f :3 0 e8c
1911 1931 :2 0 1933
e8f 1934 190e 1933
0 1935 e91 0
1936 e93 1939 :3 0
1939 0 1939 1938
1936 1937 :6 0 193b
31 :3 0 e96 193d
e98 193c 193b :2 0
193e e9a :2 0 1940
0 1940 193f 18ed
193e :6 0 1cc1 30
:3 0 15 :3 0 95
:3 0 1942 1943 0
15 :3 0 87 :2 0
bb :3 0 1945 1947
0 e9f 1946 1949
:3 0 194a :2 0 101
:3 0 192 :3 0 193
:3 0 27 :3 0 1e
:3 0 1f :3 0 109
:3 0 10a :3 0 17
:3 0 10b :3 0 1b
:3 0 10d :4 0 197
1 :8 0 195e 15
:3 0 95 :3 0 1959
195a 0 96 :3 0
195b 195c 0 195e
ea2 19b1 97 :3 0
15 :3 0 95 :3 0
1960 1961 0 96
:3 0 1962 1963 0
1965 ea5 1967 ea7
1966 1965 :2 0 19af
98 :3 0 15 :3 0
95 :3 0 196a 196b
0 96 :3 0 196c
196d 0 19a7 63
:3 0 64 :3 0 196f
1970 0 63 :3 0
74 :3 0 1972 1973
0 99 :2 0 2
:4 0 198 :2 0 76
:2 0 23 :2 0 ea9
1978 197a :3 0 eac
1974 197c 1971 197e
197d :2 0 66 :3 0
77 :3 0 1980 1981
0 68 :4 0 199
:4 0 6b :2 0 6c
:3 0 eb0 1985 1987
:3 0 6b :2 0 7e
:4 0 eb3 1989 198b
:3 0 6b :2 0 9c
:4 0 eb6 198d 198f
:3 0 6b :2 0 96
:3 0 eb9 1991 1993
:3 0 6b :2 0 9d
:4 0 ebc 1995 1997
:3 0 6b :2 0 9e
:3 0 9f :3 0 23
:2 0 a0 :2 0 ebf
199a 199e ec3 1999
19a0 :3 0 ec6 1982
19a2 :2 0 19a4 ec9
19a5 197f 19a4 0
19a6 ecb 0 19a7
ecd 19aa :3 0 19aa
0 19aa 19a9 19a7
19a8 :6 0 19ac 33
:3 0 ed0 19ae ed2
19ad 19ac :2 0 19af
ed4 :2 0 19b1 0
19b1 19b0 195e 19af
:6 0 19c8 30 :3 0
15 :3 0 95 :3 0
19b3 19b4 0 15
:3 0 87 :2 0 a1
:3 0 19b6 19b8 0
ed9 19b7 19ba :3 0
19bb :2 0 35 :3 0
fd :2 0 19bd 19be
0 19c0 edc 19c5
1e :3 0 1c :3 0
19c1 19c2 0 19c4
ede 19c6 19bc 19c0
0 19c7 0 19c4
0 19c7 ee0 0
19c8 ee3 19c9 194b
19c8 0 19ca ee6
0 1cc1 70 :3 0
35 :3 0 31 :2 0
ee8 19cb 19ce 87
:2 0 31 :2 0 eed
19d0 19d2 :3 0 70
:3 0 37 :3 0 31
:2 0 ef0 19d4 19d7
cb :2 0 31 :2 0
ef5 19d9 19db :3 0
70 :3 0 3b :3 0
31 :2 0 ef8 19dd
19e0 8e :2 0 f1
:2 0 efd 19e2 19e4
:3 0 5b :3 0 70
:3 0 37 :3 0 31
:2 0 f00 19e7 19ea
19e6 19eb 0 19ed
f03 1a0d 5b :3 0
156 :3 0 157 :3 0
70 :3 0 37 :3 0
31 :2 0 f05 19f1
19f4 fc :2 0 70
:3 0 3f :3 0 31
:2 0 f08 19f7 19fa
f0b 19f6 19fc :3 0
19fd :2 0 f0e 19f0
19ff 158 :2 0 159
:2 0 f10 1a01 1a03
:3 0 76 :2 0 15a
:2 0 f13 1a05 1a07
:3 0 f16 19ef 1a09
19ee 1a0a 0 1a0c
f18 1a0e 19e5 19ed
0 1a0f 0 1a0c
0 1a0f f1a 0
1b4b 9e :3 0 24
:3 0 23 :2 0 23
:2 0 f1d 1a10 1a14
87 :2 0 23 :4 0
f23 1a16 1a18 :3 0
15b :2 0 f26 1a1a
1a1b :3 0 1a1c :2 0
1e :3 0 7a :2 0
f28 1a1f 1a20 :3 0
1a21 :2 0 91 :3 0
15c :3 0 1a23 1a24
0 1c :3 0 2c
:3 0 15d :2 0 f2a
1a25 1a29 15e :2 0
31 :2 0 f30 1a2b
1a2d :3 0 1a2e :2 0
91 :3 0 15c :3 0
1a30 1a31 0 1c
:3 0 2d :3 0 15d
:2 0 f33 1a32 1a36
15f :2 0 31 :2 0
f39 1a38 1a3a :3 0
1a3b :2 0 1a2f 1a3d
1a3c :2 0 1a3e :2 0
1a22 1a40 1a3f :2 0
1a41 :2 0 1a1d 1a43
1a42 :2 0 2c :4 0
1a45 1a46 0 1b3f
160 :3 0 161 :3 0
162 :3 0 2c :3 0
163 :3 0 164 :3 0
165 :3 0 161 :3 0
161 :3 0 c7 :3 0
17 :3 0 161 :3 0
101 :3 0 27 :3 0
161 :3 0 162 :3 0
102 :3 0 9e :3 0
1c :3 0 161 :3 0
166 :3 0 164 :3 0
b7 :3 0 1b :3 0
164 :3 0 162 :3 0
161 :3 0 162 :3 0
164 :3 0 167 :3 0
161 :3 0 168 :4 0
19a 1 :8 0 1a6e
15 :3 0 95 :3 0
1a69 1a6a 0 96
:3 0 1a6b 1a6c 0
1a6e f3c 1ac1 97
:3 0 15 :3 0 95
:3 0 1a70 1a71 0
96 :3 0 1a72 1a73
0 1a75 f3f 1a77
f41 1a76 1a75 :2 0
1abf 98 :3 0 15
:3 0 95 :3 0 1a7a
1a7b 0 96 :3 0
1a7c 1a7d 0 1ab7
63 :3 0 64 :3 0
1a7f 1a80 0 63
:3 0 74 :3 0 1a82
1a83 0 99 :2 0
2 :4 0 19b :2 0
76 :2 0 23 :2 0
f43 1a88 1a8a :3 0
f46 1a84 1a8c 1a81
1a8e 1a8d :2 0 66
:3 0 77 :3 0 1a90
1a91 0 68 :4 0
19c :4 0 6b :2 0
6c :3 0 f4a 1a95
1a97 :3 0 6b :2 0
7e :4 0 f4d 1a99
1a9b :3 0 6b :2 0
9c :4 0 f50 1a9d
1a9f :3 0 6b :2 0
96 :3 0 f53 1aa1
1aa3 :3 0 6b :2 0
9d :4 0 f56 1aa5
1aa7 :3 0 6b :2 0
9e :3 0 9f :3 0
23 :2 0 a0 :2 0
f59 1aaa 1aae f5d
1aa9 1ab0 :3 0 f60
1a92 1ab2 :2 0 1ab4
f63 1ab5 1a8f 1ab4
0 1ab6 f65 0
1ab7 f67 1aba :3 0
1aba 0 1aba 1ab9
1ab7 1ab8 :6 0 1abc
35 :3 0 f6a 1abe
f6c 1abd 1abc :2 0
1abf f6e :2 0 1ac1
0 1ac1 1ac0 1a6e
1abf :6 0 1b3f 30
:3 0 2c :3 0 90
:2 0 f71 1ac4 1ac5
:3 0 1ac6 :2 0 91
:3 0 16c :3 0 162
:3 0 db :3 0 171
:3 0 172 :3 0 1e
:3 0 165 :3 0 c7
:3 0 17 :3 0 101
:3 0 27 :3 0 162
:3 0 2c :4 0 19d
1 :8 0 1adc 15
:3 0 95 :3 0 1ad7
1ad8 0 96 :3 0
1ad9 1ada 0 1adc
f73 1b2f 97 :3 0
15 :3 0 95 :3 0
1ade 1adf 0 96
:3 0 1ae0 1ae1 0
1ae3 f76 1ae5 f78
1ae4 1ae3 :2 0 1b2d
98 :3 0 15 :3 0
95 :3 0 1ae8 1ae9
0 96 :3 0 1aea
1aeb 0 1b25 63
:3 0 64 :3 0 1aed
1aee 0 63 :3 0
74 :3 0 1af0 1af1
0 99 :2 0 2
:4 0 19e :2 0 76
:2 0 23 :2 0 f7a
1af6 1af8 :3 0 f7d
1af2 1afa 1aef 1afc
1afb :2 0 66 :3 0
77 :3 0 1afe 1aff
0 68 :4 0 19f
:4 0 6b :2 0 6c
:3 0 f81 1b03 1b05
:3 0 6b :2 0 7e
:4 0 f84 1b07 1b09
:3 0 6b :2 0 9c
:4 0 f87 1b0b 1b0d
:3 0 6b :2 0 96
:3 0 f8a 1b0f 1b11
:3 0 6b :2 0 9d
:4 0 f8d 1b13 1b15
:3 0 6b :2 0 9e
:3 0 9f :3 0 23
:2 0 a0 :2 0 f90
1b18 1b1c f94 1b17
1b1e :3 0 f97 1b00
1b20 :2 0 1b22 f9a
1b23 1afd 1b22 0
1b24 f9c 0 1b25
f9e 1b28 :3 0 1b28
0 1b28 1b27 1b25
1b26 :6 0 1b2a 37
:3 0 fa1 1b2c fa3
1b2b 1b2a :2 0 1b2d
fa5 :2 0 1b2f 0
1b2f 1b2e 1adc 1b2d
:6 0 1b34 30 :3 0
1f :3 0 6 :3 0
1b31 1b32 0 1b34
fa8 1b3c 1e :3 0
1c :3 0 1b35 1b36
0 1b3b 1f :3 0
6 :3 0 1b38 1b39
0 1b3b fab 1b3d
1ac7 1b34 0 1b3e
0 1b3b 0 1b3e
fae 0 1b3f fb1
1b47 1e :3 0 1c
:3 0 1b40 1b41 0
1b46 1f :3 0 6
:3 0 1b43 1b44 0
1b46 fb5 1b48 1a44
1b3f 0 1b49 0
1b46 0 1b49 fb8
0 1b4b a8 :3 0
fbb 1bd3 91 :3 0
15c :3 0 1b4c 1b4d
0 1c :3 0 1e
:3 0 99 :2 0 fbe
1b4e 1b52 15f :2 0
31 :2 0 fc4 1b54
1b56 :3 0 91 :3 0
15c :3 0 1b58 1b59
0 1c :3 0 1f
:3 0 99 :2 0 fc7
1b5a 1b5e 15e :2 0
31 :2 0 fcd 1b60
1b62 :3 0 1b57 1b64
1b63 :2 0 91 :3 0
16c :3 0 102 :3 0
9e :3 0 1e :3 0
91 :3 0 16d :3 0
1e :3 0 93 :4 0
1a0 1 :8 0 1b75
15 :3 0 95 :3 0
1b70 1b71 0 96
:3 0 1b72 1b73 0
1b75 fd0 1bc8 97
:3 0 15 :3 0 95
:3 0 1b77 1b78 0
96 :3 0 1b79 1b7a
0 1b7c fd3 1b7e
fd5 1b7d 1b7c :2 0
1bc6 98 :3 0 15
:3 0 95 :3 0 1b81
1b82 0 96 :3 0
1b83 1b84 0 1bbe
63 :3 0 64 :3 0
1b86 1b87 0 63
:3 0 74 :3 0 1b89
1b8a 0 99 :2 0
2 :4 0 1a1 :2 0
76 :2 0 23 :2 0
fd7 1b8f 1b91 :3 0
fda 1b8b 1b93 1b88
1b95 1b94 :2 0 66
:3 0 77 :3 0 1b97
1b98 0 68 :4 0
1a2 :4 0 6b :2 0
6c :3 0 fde 1b9c
1b9e :3 0 6b :2 0
7e :4 0 fe1 1ba0
1ba2 :3 0 6b :2 0
9c :4 0 fe4 1ba4
1ba6 :3 0 6b :2 0
96 :3 0 fe7 1ba8
1baa :3 0 6b :2 0
9d :4 0 fea 1bac
1bae :3 0 6b :2 0
9e :3 0 9f :3 0
23 :2 0 a0 :2 0
fed 1bb1 1bb5 ff1
1bb0 1bb7 :3 0 ff4
1b99 1bb9 :2 0 1bbb
ff7 1bbc 1b96 1bbb
0 1bbd ff9 0
1bbe ffb 1bc1 :3 0
1bc1 0 1bc1 1bc0
1bbe 1bbf :6 0 1bc3
39 :3 0 ffe 1bc5
1000 1bc4 1bc3 :2 0
1bc6 1002 :2 0 1bc8
0 1bc8 1bc7 1b75
1bc6 :6 0 1bca 30
:3 0 1005 1bcb 1b65
1bca 0 1bd5 1e
:3 0 1c :3 0 1bcc
1bcd 0 1bd2 1f
:3 0 6 :3 0 1bcf
1bd0 0 1bd2 1007
1bd4 19dc 1b4b 0
1bd5 0 1bd2 0
1bd5 100a 0 1bd6
100e 1bde 1e :3 0
1c :3 0 1bd7 1bd8
0 1bdd 1f :3 0
6 :3 0 1bda 1bdb
0 1bdd 1010 1bdf
19d3 1bd6 0 1be0
0 1bdd 0 1be0
1013 0 1cc1 70
:3 0 41 :3 0 31
:2 0 1016 1be1 1be4
cb :2 0 31 :2 0
101b 1be6 1be8 :3 0
9e :3 0 24 :3 0
23 :2 0 23 :2 0
101e 1bea 1bee 87
:2 0 23 :4 0 1024
1bf0 1bf2 :3 0 34
:3 0 fe :2 0 1bf4
1bf5 0 1bf7 1027
1bf8 1bf3 1bf7 0
1bf9 1029 0 1bfb
a8 :3 0 102b 1c15
9e :3 0 24 :3 0
23 :2 0 23 :2 0
102d 1bfc 1c00 87
:2 0 23 :4 0 1033
1c02 1c04 :3 0 46
:3 0 80 :3 0 186
:3 0 1c07 1c08 0
1c06 1c09 0 1c0b
1036 1c0c 1c05 1c0b
0 1c17 46 :3 0
70 :3 0 3c :3 0
31 :2 0 1038 1c0e
1c11 1c0d 1c12 0
1c14 103b 1c16 1be9
1bfb 0 1c17 0
1c14 0 1c17 103d
0 1cc1 5f :3 0
187 :3 0 26 :3 0
17 :3 0 19 :3 0
1b :3 0 49 :3 0
33 :3 0 20 :3 0
20 :3 0 20 :3 0
20 :3 0 1e :3 0
1f :3 0 43 :3 0
39 :3 0 37 :3 0
3a :3 0 3b :3 0
36 :3 0 46 :3 0
24 :3 0 35 :3 0
32 :3 0 3d :3 0
38 :3 0 34 :3 0
3f :3 0 47 :3 0
1a :3 0 31 :2 0
31 :2 0 51 :2 0
51 :2 0 31 :2 0
31 :2 0 1041 1c19
1c3c 1c18 1c3d 0
1cc1 5f :3 0 87
:2 0 31 :2 0 1066
1c40 1c42 :3 0 188
:3 0 189 :3 0 18a
:3 0 1b :4 0 18b
1 :8 0 1c5e 14a
:4 0 1c49 :3 0 86
:3 0 87 :2 0 106b
1c4c 1c4d :3 0 15
:3 0 95 :3 0 1c4f
1c50 0 31 :2 0
1c51 1c52 0 1c54
106e 1c5b 15 :3 0
95 :3 0 1c55 1c56
0 f1 :2 0 1c57
1c58 0 1c5a 1070
1c5c 1c4e 1c54 0
1c5d 0 1c5a 0
1c5d 1072 0 1c5e
1075 1cb1 97 :3 0
15 :3 0 95 :3 0
1c60 1c61 0 96
:3 0 1c62 1c63 0
1c65 1078 1c67 107a
1c66 1c65 :2 0 1caf
98 :3 0 15 :3 0
95 :3 0 1c6a 1c6b
0 96 :3 0 1c6c
1c6d 0 1ca7 63
:3 0 64 :3 0 1c6f
1c70 0 63 :3 0
74 :3 0 1c72 1c73
0 99 :2 0 2
:4 0 1a3 :2 0 76
:2 0 23 :2 0 107c
1c78 1c7a :3 0 107f
1c74 1c7c 1c71 1c7e
1c7d :2 0 66 :3 0
77 :3 0 1c80 1c81
0 68 :4 0 1a4
:4 0 6b :2 0 6c
:3 0 1083 1c85 1c87
:3 0 6b :2 0 7e
:4 0 1086 1c89 1c8b
:3 0 6b :2 0 9c
:4 0 1089 1c8d 1c8f
:3 0 6b :2 0 96
:3 0 108c 1c91 1c93
:3 0 6b :2 0 9d
:4 0 108f 1c95 1c97
:3 0 6b :2 0 9e
:3 0 9f :3 0 23
:2 0 a0 :2 0 1092
1c9a 1c9e 1096 1c99
1ca0 :3 0 1099 1c82
1ca2 :2 0 1ca4 109c
1ca5 1c7f 1ca4 0
1ca6 109e 0 1ca7
10a0 1caa :3 0 1caa
0 1caa 1ca9 1ca7
1ca8 :6 0 1cac 3b
:3 0 10a3 1cae 10a5
1cad 1cac :2 0 1caf
10a7 :2 0 1cb1 0
1cb1 1cb0 1c5e 1caf
:6 0 1cb3 30 :3 0
10aa 1cb4 1c43 1cb3
0 1cb5 10ac 0
1cc1 30 :3 0 70
:3 0 30 :3 0 31
:2 0 10ae 1cb7 1cba
76 :2 0 23 :2 0
10b1 1cbc 1cbe :3 0
1cb6 1cbf 0 1cc1
10b4 1cc3 190 :3 0
181f 1cc1 :4 0 1cc4
10c2 1cc5 1810 1cc4
0 1cc6 10c5 0
1cc7 10c7 1cc9 c49
17d8 0 1cca 0
1cc7 0 1cca 10cd
0 1fa0 5f :3 0
8e :2 0 31 :2 0
10d2 1ccc 1cce :3 0
1ccf :2 0 70 :3 0
33 :3 0 31 :2 0
10d5 1cd1 1cd4 cb
:2 0 31 :2 0 10da
1cd6 1cd8 :3 0 1cd9
:2 0 1cd0 1cdb 1cda
:2 0 63 :3 0 64
:3 0 1cdd 1cde 0
63 :3 0 74 :3 0
1ce0 1ce1 0 18
:2 0 2 :4 0 1a5
:2 0 76 :2 0 23
:2 0 10dd 1ce6 1ce8
:3 0 10e0 1ce2 1cea
1cdf 1cec 1ceb :2 0
66 :3 0 77 :3 0
1cee 1cef 0 68
:4 0 1a6 :4 0 6b
:2 0 6c :3 0 10e4
1cf3 1cf5 :3 0 6b
:2 0 7e :4 0 10e7
1cf7 1cf9 :3 0 6b
:2 0 7f :4 0 10ea
1cfb 1cfd :3 0 6b
:2 0 70 :3 0 71
:3 0 80 :3 0 1a7
:3 0 1d02 1d03 0
10ed 1d01 1d05 72
:4 0 10ef 1d00 1d08
10f2 1cff 1d0a :3 0
6b :2 0 c1 :4 0
10f5 1d0c 1d0e :3 0
6b :2 0 6e :4 0
10f8 1d10 1d12 :3 0
6b :2 0 26 :3 0
10fb 1d14 1d16 :3 0
6b :2 0 6e :4 0
10fe 1d18 1d1a :3 0
1101 1cf0 1d1c :2 0
1d1e 1104 1d1f 1ced
1d1e 0 1d20 1106
0 1d4a 63 :3 0
64 :3 0 1d21 1d22
0 63 :3 0 74
:3 0 1d24 1d25 0
23 :2 0 2 :4 0
1a8 :2 0 76 :2 0
23 :2 0 1108 1d2a
1d2c :3 0 110b 1d26
1d2e 1d23 1d30 1d2f
:2 0 66 :3 0 77
:3 0 1d32 1d33 0
68 :4 0 1a9 :4 0
6b :2 0 6c :3 0
110f 1d37 1d39 :3 0
1112 1d34 1d3b :2 0
1d3d 1115 1d3e 1d31
1d3d 0 1d3f 1117
0 1d4a 84 :3 0
c4 :3 0 1d40 1d41
0 80 :3 0 1a7
:3 0 1d43 1d44 0
26 :3 0 86 :3 0
1119 1d42 1d48 :2 0
1d4a 111d 1d4b 1cdc
1d4a 0 1d4c 1121
0 1fa0 70 :3 0
33 :3 0 31 :2 0
1123 1d4d 1d50 cb
:2 0 31 :2 0 1128
1d52 1d54 :3 0 17
:3 0 19 :3 0 1d56
1d57 0 1d59 112b
1d5a 1d55 1d59 0
1d5b 112d 0 1fa0
70 :3 0 18e :3 0
2a :3 0 112f 1d5d
1d5f 31 :2 0 1131
1d5c 1d62 cb :2 0
31 :2 0 1136 1d64
1d66 :3 0 1d67 :2 0
70 :3 0 18e :3 0
2b :3 0 1139 1d6a
1d6c 31 :2 0 113b
1d69 1d6f cb :2 0
31 :2 0 1140 1d71
1d73 :3 0 1d74 :2 0
1d68 1d76 1d75 :2 0
59 :3 0 1aa :4 0
6b :2 0 1ab :4 0
1143 1d7a 1d7c :3 0
6b :2 0 1ac :4 0
1146 1d7e 1d80 :3 0
6b :2 0 1ad :4 0
1149 1d82 1d84 :3 0
6b :2 0 1ae :4 0
114c 1d86 1d88 :3 0
6b :2 0 71 :3 0
70 :3 0 39 :3 0
31 :2 0 114f 1d8c
1d8f 1152 1d8b 1d91
1154 1d8a 1d93 :3 0
6b :2 0 1af :4 0
1157 1d95 1d97 :3 0
6b :2 0 71 :3 0
70 :3 0 3a :3 0
31 :2 0 115a 1d9b
1d9e 115d 1d9a 1da0
115f 1d99 1da2 :3 0
6b :2 0 1b0 :4 0
1162 1da4 1da6 :3 0
6b :2 0 71 :3 0
70 :3 0 3f :3 0
31 :2 0 1165 1daa
1dad 1168 1da9 1daf
116a 1da8 1db1 :3 0
6b :2 0 1b1 :4 0
116d 1db3 1db5 :3 0
6b :2 0 1b2 :4 0
1170 1db7 1db9 :3 0
6b :2 0 1b3 :4 0
1173 1dbb 1dbd :3 0
6b :2 0 1b4 :4 0
1176 1dbf 1dc1 :3 0
6b :2 0 1b5 :4 0
1179 1dc3 1dc5 :3 0
6b :2 0 1b6 :4 0
117c 1dc7 1dc9 :3 0
6b :2 0 1b7 :4 0
117f 1dcb 1dcd :3 0
6b :2 0 17 :3 0
1182 1dcf 1dd1 :3 0
6b :2 0 1b8 :4 0
1185 1dd3 1dd5 :3 0
6b :2 0 2a :3 0
1188 1dd7 1dd9 :3 0
6b :2 0 1b9 :4 0
118b 1ddb 1ddd :3 0
6b :2 0 1ba :4 0
118e 1ddf 1de1 :3 0
6b :2 0 1bb :4 0
1191 1de3 1de5 :3 0
6b :2 0 1bc :4 0
1194 1de7 1de9 :3 0
6b :2 0 80 :3 0
1bd :3 0 1dec 1ded
0 1197 1deb 1def
:3 0 6b :2 0 1be
:4 0 119a 1df1 1df3
:3 0 6b :2 0 80
:3 0 1bd :3 0 1df6
1df7 0 119d 1df5
1df9 :3 0 6b :2 0
1bf :4 0 11a0 1dfb
1dfd :3 0 6b :2 0
1c0 :4 0 11a3 1dff
1e01 :3 0 6b :2 0
1c1 :4 0 11a6 1e03
1e05 :3 0 6b :2 0
71 :3 0 70 :3 0
39 :3 0 31 :2 0
11a9 1e09 1e0c 11ac
1e08 1e0e 11ae 1e07
1e10 :3 0 6b :2 0
1af :4 0 11b1 1e12
1e14 :3 0 6b :2 0
71 :3 0 70 :3 0
3a :3 0 31 :2 0
11b4 1e18 1e1b 11b7
1e17 1e1d 11b9 1e16
1e1f :3 0 6b :2 0
1c2 :4 0 11bc 1e21
1e23 :3 0 6b :2 0
1c3 :4 0 11bf 1e25
1e27 :3 0 6b :2 0
71 :3 0 70 :3 0
3f :3 0 31 :2 0
11c2 1e2b 1e2e 11c5
1e2a 1e30 11c7 1e29
1e32 :3 0 6b :2 0
1c4 :4 0 11ca 1e34
1e36 :3 0 6b :2 0
1c5 :4 0 11cd 1e38
1e3a :3 0 6b :2 0
1c6 :4 0 11d0 1e3c
1e3e :3 0 6b :2 0
17 :3 0 11d3 1e40
1e42 :3 0 6b :2 0
1c7 :4 0 11d6 1e44
1e46 :3 0 6b :2 0
2b :3 0 11d9 1e48
1e4a :3 0 6b :2 0
1c8 :4 0 11dc 1e4c
1e4e :3 0 6b :2 0
1c9 :4 0 11df 1e50
1e52 :3 0 6b :2 0
1ca :4 0 11e2 1e54
1e56 :3 0 1d78 1e57
0 1e5a a8 :3 0
11e5 1f58 70 :3 0
18e :3 0 2a :3 0
11e7 1e5c 1e5e 31
:2 0 11e9 1e5b 1e61
cb :2 0 31 :2 0
11ee 1e63 1e65 :3 0
59 :3 0 1aa :4 0
6b :2 0 1ab :4 0
11f1 1e69 1e6b :3 0
6b :2 0 1ac :4 0
11f4 1e6d 1e6f :3 0
6b :2 0 1ad :4 0
11f7 1e71 1e73 :3 0
6b :2 0 1ae :4 0
11fa 1e75 1e77 :3 0
6b :2 0 71 :3 0
70 :3 0 39 :3 0
31 :2 0 11fd 1e7b
1e7e 1200 1e7a 1e80
1202 1e79 1e82 :3 0
6b :2 0 1af :4 0
1205 1e84 1e86 :3 0
6b :2 0 71 :3 0
70 :3 0 3a :3 0
31 :2 0 1208 1e8a
1e8d 120b 1e89 1e8f
120d 1e88 1e91 :3 0
6b :2 0 1b0 :4 0
1210 1e93 1e95 :3 0
6b :2 0 71 :3 0
70 :3 0 3f :3 0
31 :2 0 1213 1e99
1e9c 1216 1e98 1e9e
1218 1e97 1ea0 :3 0
6b :2 0 1b1 :4 0
121b 1ea2 1ea4 :3 0
6b :2 0 1b2 :4 0
121e 1ea6 1ea8 :3 0
6b :2 0 1b3 :4 0
1221 1eaa 1eac :3 0
6b :2 0 1b4 :4 0
1224 1eae 1eb0 :3 0
6b :2 0 1b5 :4 0
1227 1eb2 1eb4 :3 0
6b :2 0 1b6 :4 0
122a 1eb6 1eb8 :3 0
6b :2 0 1b7 :4 0
122d 1eba 1ebc :3 0
6b :2 0 17 :3 0
1230 1ebe 1ec0 :3 0
6b :2 0 1b8 :4 0
1233 1ec2 1ec4 :3 0
6b :2 0 2a :3 0
1236 1ec6 1ec8 :3 0
6b :2 0 1b9 :4 0
1239 1eca 1ecc :3 0
6b :2 0 1ca :4 0
123c 1ece 1ed0 :3 0
1e67 1ed1 0 1ed4
a8 :3 0 123f 1ed5
1e66 1ed4 0 1f59
70 :3 0 18e :3 0
2b :3 0 1241 1ed7
1ed9 31 :2 0 1243
1ed6 1edc cb :2 0
31 :2 0 1248 1ede
1ee0 :3 0 59 :3 0
1bb :4 0 6b :2 0
1bc :4 0 124b 1ee4
1ee6 :3 0 6b :2 0
80 :3 0 1bd :3 0
1ee9 1eea 0 124e
1ee8 1eec :3 0 6b
:2 0 1be :4 0 1251
1eee 1ef0 :3 0 6b
:2 0 80 :3 0 1bd
:3 0 1ef3 1ef4 0
1254 1ef2 1ef6 :3 0
6b :2 0 1bf :4 0
1257 1ef8 1efa :3 0
6b :2 0 1c0 :4 0
125a 1efc 1efe :3 0
6b :2 0 1c1 :4 0
125d 1f00 1f02 :3 0
6b :2 0 71 :3 0
70 :3 0 39 :3 0
31 :2 0 1260 1f06
1f09 1263 1f05 1f0b
1265 1f04 1f0d :3 0
6b :2 0 1af :4 0
1268 1f0f 1f11 :3 0
6b :2 0 71 :3 0
70 :3 0 3a :3 0
31 :2 0 126b 1f15
1f18 126e 1f14 1f1a
1270 1f13 1f1c :3 0
6b :2 0 1c2 :4 0
1273 1f1e 1f20 :3 0
6b :2 0 1c3 :4 0
1276 1f22 1f24 :3 0
6b :2 0 71 :3 0
70 :3 0 3f :3 0
31 :2 0 1279 1f28
1f2b 127c 1f27 1f2d
127e 1f26 1f2f :3 0
6b :2 0 1c4 :4 0
1281 1f31 1f33 :3 0
6b :2 0 1c5 :4 0
1284 1f35 1f37 :3 0
6b :2 0 1c6 :4 0
1287 1f39 1f3b :3 0
6b :2 0 17 :3 0
128a 1f3d 1f3f :3 0
6b :2 0 1c7 :4 0
128d 1f41 1f43 :3 0
6b :2 0 2b :3 0
1290 1f45 1f47 :3 0
6b :2 0 1c8 :4 0
1293 1f49 1f4b :3 0
6b :2 0 1c9 :4 0
1296 1f4d 1f4f :3 0
6b :2 0 1ca :4 0
1299 1f51 1f53 :3 0
1ee2 1f54 0 1f56
129c 1f57 1ee1 1f56
0 1f59 1d77 1e5a
0 1f59 129e 0
1fa0 63 :3 0 64
:3 0 1f5a 1f5b 0
63 :3 0 74 :3 0
1f5d 1f5e 0 23
:2 0 2 :4 0 1cb
:2 0 76 :2 0 23
:2 0 12a2 1f63 1f65
:3 0 12a5 1f5f 1f67
1f5c 1f69 1f68 :2 0
66 :3 0 77 :3 0
1f6b 1f6c 0 68
:4 0 1cc :4 0 6b
:2 0 6c :3 0 12a9
1f70 1f72 :3 0 12ac
1f6d 1f74 :2 0 1f76
12af 1f77 1f6a 1f76
0 1f78 12b1 0
1fa0 63 :3 0 64
:3 0 1f79 1f7a 0
63 :3 0 74 :3 0
1f7c 1f7d 0 23
:2 0 2 :4 0 1cd
:2 0 76 :2 0 23
:2 0 12b3 1f82 1f84
:3 0 12b6 1f7e 1f86
1f7b 1f88 1f87 :2 0
66 :3 0 77 :3 0
1f8a 1f8b 0 68
:4 0 1ce :4 0 6b
:2 0 6c :3 0 12ba
1f8f 1f91 :3 0 12bd
1f8c 1f93 :2 0 1f95
12c0 1f96 1f89 1f95
0 1f97 12c2 0
1fa0 14 :3 0 84
:3 0 1cf :3 0 1f99
1f9a 0 59 :3 0
12c4 1f9b 1f9d 1f9e
:2 0 1fa0 12c6 2041
15 :3 0 1d0 :2 0
4 1fa1 1fa2 0
63 :3 0 64 :3 0
1fa4 1fa5 0 63
:3 0 74 :3 0 1fa7
1fa8 0 99 :2 0
2 :4 0 1d1 :2 0
76 :2 0 23 :2 0
12f3 1fad 1faf :3 0
12f6 1fa9 1fb1 1fa6
1fb3 1fb2 :2 0 66
:3 0 77 :3 0 1fb5
1fb6 0 68 :4 0
1d2 :4 0 6b :2 0
6c :3 0 12fa 1fba
1fbc :3 0 12fd 1fb7
1fbe :2 0 1fd7 66
:3 0 77 :3 0 1fc0
1fc1 0 68 :4 0
1d3 :4 0 6b :2 0
15 :3 0 1d4 :3 0
1fc6 1fc7 0 1300
1fc5 1fc9 :3 0 6b
:2 0 c1 :4 0 1303
1fcb 1fcd :3 0 6b
:2 0 15 :3 0 1d5
:3 0 1fd0 1fd1 0
1306 1fcf 1fd3 :3 0
1309 1fc2 1fd5 :2 0
1fd7 130c 1fd8 1fb4
1fd7 0 1fd9 130f
0 1fe9 1d6 :3 0
62 :3 0 15 :3 0
1d4 :3 0 1d7 :3 0
15 :3 0 1d5 :3 0
1d8 :3 0 93 :4 0
1d9 1 :a 0 1fe5
:2 0 1fe9 1fdb 1fe3
:2 0 14 :3 0 62
:3 0 1fe7 :2 0 1fe9
1311 1feb 1315 1fea
1fe9 :2 0 203f 98
:3 0 15 :3 0 95
:3 0 1fee 1fef 0
96 :3 0 1ff0 1ff1
0 2037 63 :3 0
64 :3 0 1ff3 1ff4
0 63 :3 0 74
:3 0 1ff6 1ff7 0
99 :2 0 2 :4 0
1da :2 0 76 :2 0
23 :2 0 1317 1ffc
1ffe :3 0 131a 1ff8
2000 1ff5 2002 2001
:2 0 66 :3 0 77
:3 0 2004 2005 0
68 :4 0 1db :4 0
6b :2 0 6c :3 0
131e 2009 200b :3 0
1321 2006 200d :2 0
2027 66 :3 0 77
:3 0 200f 2010 0
68 :4 0 9c :4 0
6b :2 0 96 :3 0
1324 2014 2016 :3 0
6b :2 0 9d :4 0
1327 2018 201a :3 0
6b :2 0 9e :3 0
9f :3 0 23 :2 0
a0 :2 0 132a 201d
2021 132e 201c 2023
:3 0 1331 2011 2025
:2 0 2027 1334 2028
2003 2027 0 2029
1337 0 2037 1d6
:3 0 62 :3 0 1d7
:3 0 15 :3 0 1d5
:3 0 1d8 :3 0 93
:4 0 1dc 1 :a 0
2033 :2 0 2037 202b
2031 :2 0 14 :3 0
62 :3 0 2035 :2 0
2037 1339 203a :3 0
203a 0 203a 2039
2037 2038 :6 0 203c
1 :3 0 133e 203e
1340 203d 203c :2 0
203f 1342 :2 0 2041
1345 2041 2040 1fa0
203f :6 0 2042 :2 0
2 44 2041 2045
:3 0 2044 2042 2046
:8 0 
1388
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
4f 1 4d 1
56 1 54 1
5d 1 5b 1
64 1 62 1
6b 1 69 1
72 1 70 1
77 1 7e 1
7c 1 85 1
83 1 8c 1
8a 1 93 1
91 1 9a 1
98 1 a1 1
9f 1 a8 1
a6 1 af 1
ad 1 b4 1
b9 1 c0 1
be 1 c5 1
cb 1 d1 1
d7 1 dd 1
e3 1 e9 1
ef 1 f5 1
fb 1 101 1
107 1 10d 1
113 1 119 1
11f 1 125 1
12b 1 131 1
137 1 13d 1
143 1 149 1
14f 1 155 1
15b 1 161 1
167 1 16d 1
173 1 179 1
17f 1 185 1
18d 1 18b 1
194 1 192 1
199 1 19f 1
1a7 1 1a5 1
1ac 1 1b2 1
1b8 1 1be 1
1c4 1 1ca 1
1d0 1 1d6 1
1db 1 1e8 1
1f4 2 1f7 1f9
2 1fc 1fe 2
200 202 2 204
206 2 208 20a
2 20c 20e 2
210 212 2 214
216 2 218 21a
2 21c 21e 2
220 222 2 224
226 2 228 22a
1 230 2 232
233 2 22c 235
2 237 239 1
23f 2 241 242
2 23b 244 2
246 248 1 24e
2 250 251 2
24a 253 2 255
257 1 25d 2
25f 260 2 259
262 2 264 266
1 26c 2 26e
26f 2 268 271
2 273 275 1
27b 2 27d 27e
2 277 280 2
282 284 1 28a
2 28c 28d 2
286 28f 2 291
293 1 299 2
29b 29c 2 295
29e 2 2a0 2a2
1 2a8 2 2aa
2ab 2 2a4 2ad
2 2af 2b1 1
2b7 2 2b9 2ba
2 2b3 2bc 2
2be 2c0 2 2c2
2c4 2 2c6 2c8
2 2ca 2cc 2
2ce 2d0 2 2d2
2d4 2 2d6 2d8
2 2da 2dc 2
2de 2e0 4 1f0
1f6 1fb 2e2 1
2e4 1 2e6 2
2f0 2f2 3 2ee
2ef 2f4 2 2fd
2ff 2 2fc 301
1 303 1 305
2 337 338 1
33a 1 344 2
351 353 3 34f
350 355 2 35e
360 2 362 364
2 366 368 1
370 2 372 373
2 36a 375 2
35d 377 1 379
1 37b 2 385
387 3 383 384
389 2 392 394
2 391 396 1
398 1 39a 2
3a1 3a2 3 37c
39b 3a4 1 3a6
2 3a9 3aa 1
3ae 2 3ac 3ae
2 3b2 3b3 1
3b7 2 3b5 3b7
2 3bd 3be 1
3c2 2 3c0 3c2
2 3cf 3d1 3
3cd 3ce 3d3 2
3dc 3de 2 3e0
3e2 2 3e4 3e6
1 3ee 2 3f0
3f1 2 3e8 3f3
2 3db 3f5 1
3f7 1 3f9 2
403 405 3 401
402 407 2 410
412 2 40f 414
1 416 1 418
2 41f 420 3
3fa 419 422 1
424 2 427 428
1 42e 2 42a
42e 1 432 1
43a 2 44a 44f
1 456 1 451
2 469 46b 3
467 468 46d 2
476 478 2 47a
47c 2 47e 480
2 482 484 2
486 488 3 48d
48e 48f 2 48a
491 2 475 493
1 495 1 497
2 460 498 1
49c 1 45b 2
459 4a0 1 4ab
2 4a7 4ab 2
4b0 4b1 1 4b5
2 4b3 4b5 2
4c3 4c5 3 4c1
4c2 4c7 2 4d0
4d2 2 4d4 4d6
2 4d8 4da 1
4e2 2 4e4 4e5
2 4dc 4e7 2
4cf 4e9 1 4eb
1 4ed 2 4f7
4f9 3 4f5 4f6
4fb 2 504 506
2 503 508 1
50a 1 50c 2
513 514 3 4ee
50d 516 1 518
3 4a3 519 51c
1 51f 1 525
2 530 535 1
53c 1 537 2
54f 551 3 54d
54e 553 2 55c
55e 2 560 562
2 564 566 2
568 56a 2 56c
56e 3 573 574
575 2 570 577
2 55b 579 1
57b 1 57d 2
546 57e 1 582
1 541 2 53f
586 1 589 2
58d 58c 2 595
596 2 598 59b
2 59e 59f 2
5a6 5a7 2 5a9
5ac 2 5b2 5b3
1 5b9 2 5b5
5b9 1 5be 1
5c0 2 5c3 5c4
1 5c8 2 5c6
5c8 2 5d6 5db
1 5e2 1 5dd
2 5f5 5f7 3
5f3 5f4 5f9 2
602 604 2 606
608 2 60a 60c
2 60e 610 2
612 614 3 619
61a 61b 2 616
61d 2 601 61f
1 621 1 623
2 5ec 624 1
628 1 5e7 2
5e5 62c 1 637
2 633 637 2
641 646 1 64d
1 648 2 660
662 3 65e 65f
664 2 66d 66f
2 671 673 2
675 677 2 679
67b 2 67d 67f
3 684 685 686
2 681 688 2
66c 68a 1 68c
1 68e 2 657
68f 1 693 1
652 2 650 697
1 6a2 2 69e
6a2 2 6ae 6b0
3 6ac 6ad 6b2
2 6bb 6bd 2
6bf 6c1 2 6c3
6c5 1 6cd 2
6cf 6d0 2 6c7
6d2 2 6d4 6d6
2 6d8 6da 2
6dc 6de 2 6e0
6e2 2 6ba 6e4
1 6e6 1 6e8
2 6f2 6f4 3
6f0 6f1 6f6 2
6ff 701 2 6fe
703 1 705 1
707 3 70e 70f
710 3 6e9 708
712 1 714 2
69a 715 1 717
2 721 726 1
72d 1 728 2
740 742 3 73e
73f 744 2 74d
74f 2 751 753
2 755 757 2
759 75b 2 75d
75f 3 764 765
766 2 761 768
2 74c 76a 1
76c 1 76e 2
737 76f 1 773
1 732 2 730
777 2 77d 77e
1 782 2 780
782 2 78a 78f
1 796 1 791
2 7a9 7ab 3
7a7 7a8 7ad 2
7b6 7b8 2 7ba
7bc 2 7be 7c0
2 7c2 7c4 2
7c6 7c8 3 7cd
7ce 7cf 2 7ca
7d1 2 7b5 7d3
1 7d5 1 7d7
2 7a0 7d8 1
7dc 1 79b 2
799 7e0 2 7e8
7e9 1 7ed 2
7eb 7ed 2 7f8
7fa 3 7f6 7f7
7fc 2 805 807
2 809 80b 2
80d 80f 1 817
2 819 81a 2
811 81c 2 81e
820 2 822 824
2 826 828 2
82a 82c 2 804
82e 1 830 1
832 2 83c 83e
3 83a 83b 840
2 849 84b 2
848 84d 1 84f
1 851 3 858
859 85a 3 833
852 85c 1 85e
2 7e3 85f 1
861 5 62f 718
71b 77a 862 1
864 2 871 873
3 86f 870 875
2 87e 880 2
882 884 2 886
888 1 890 2
892 893 2 88a
895 2 87d 897
1 899 1 89b
2 8a5 8a7 3
8a3 8a4 8a9 2
8b2 8b4 2 8b1
8b6 1 8b8 1
8ba 2 8c1 8c2
3 89c 8bb 8c4
1 8c6 3 8ce
8cf 8d0 3 8d2
8d3 8d4 4 8dc
8dd 8de 8df 2
8e5 8e6 1 8e8
1 8ec 2 8ea
8ec 2 907 90c
1 913 1 90e
2 926 928 3
924 925 92a 2
933 935 2 937
939 2 93b 93d
2 93f 941 2
943 945 3 94a
94b 94c 2 947
94e 2 932 950
1 952 1 954
2 91d 955 1
959 1 918 2
916 95d 1 968
2 964 968 2
974 976 3 972
973 978 2 981
983 2 985 987
2 989 98b 1
993 2 995 996
2 98d 998 2
99a 99c 2 99e
9a0 2 9a2 9a4
2 9a6 9a8 2
980 9aa 1 9ac
1 9ae 2 9b8
9ba 3 9b6 9b7
9bc 2 9c5 9c7
2 9c4 9c9 1
9cb 1 9cd 3
9d4 9d5 9d6 3
9af 9ce 9d8 1
9da 2 960 9db
2 9e5 9e7 3
9e3 9e4 9e9 2
9f2 9f4 2 9f6
9f8 2 9fa 9fc
1 a04 2 a06
a07 2 9fe a09
2 a0b a0d 2
a0f a11 2 a13
a15 2 a17 a19
2 9f1 a1b 1
a1d 1 a1f 2
a29 a2b 3 a27
a28 a2d 2 a36
a38 2 a35 a3a
1 a3c 1 a3e
3 a45 a46 a47
3 a20 a3f a49
2 a4b a4c 5
8c7 8ca 8d7 8e2
a4d 2 a4f a50
2 a53 a54 1
a58 2 a56 a58
2 a5d a5e 1
a62 2 a60 a62
1 a6a 1 a6c
1 a70 2 a6e
a70 2 a7e a7f
2 a83 a84 2
a88 a89 2 a8d
a8e 2 a92 a93
2 a97 a98 2
a9c a9d 2 aa1
aa2 d a7b a7c
a81 a86 a8b a90
a95 a9a a9f aa4
aa5 aa6 aa7 2
aac aad 1 ab3
2 aaf ab3 2
abe ac0 3 abc
abd ac2 2 acb
acd 2 acf ad1
2 ad3 ad5 1
add 2 adf ae0
2 ad7 ae2 2
aca ae4 1 ae6
1 ae8 2 af2
af4 3 af0 af1
af6 2 aff b01
2 afe b03 1
b05 1 b07 2
b0e b0f 3 ae9
b08 b11 2 b15
b16 1 b1a 2
b18 b1a 2 b25
b27 3 b23 b24
b29 2 b32 b34
2 b36 b38 2
b3a b3c 1 b42
2 b44 b45 2
b3e b47 2 b49
b4b 2 b4d b4f
2 b51 b53 2
b55 b57 2 b31
b59 1 b5b 1
b5d 2 b67 b69
3 b65 b66 b6b
2 b74 b76 2
b73 b78 1 b7a
1 b7c 2 b82
b83 3 b85 b86
b87 3 b5e b7d
b89 2 b8c b8b
4 a75 a78 aaa
b8d 2 b93 b94
1 b98 2 b96
b98 2 b9d b9e
2 ba3 ba4 2
ba0 ba6 1 ba9
1 bab 2 b91
bac 2 bae baf
2 bb2 bb3 1
bb7 2 bb5 bb7
2 bbc bbd 1
bc1 2 bbf bc1
2 bc8 bc9 1
bcd 2 bcb bcd
2 bd2 bd3 1
bd7 2 bd5 bd7
1 bdf 2 be3
be4 1 be8 2
be6 be8 1 bed
2 bf2 bf3 1
bf7 2 bf5 bf7
2 bfc bfd 1
c01 2 bff c01
1 c09 2 c0e
c0f 1 c13 2
c11 c13 1 c18
4 c1b bf0 c0c
c1a 1 c1c 1
c1e 3 c33 c34
c35 3 c3b c3c
c3d 2 c42 c43
1 c47 2 c45
c47 3 c51 c52
c53 1 c57 2
c55 c57 2 c73
c78 1 c7f 1
c7a 2 c92 c94
3 c90 c91 c96
2 c9f ca1 2
ca3 ca5 2 ca7
ca9 2 cab cad
2 caf cb1 3
cb6 cb7 cb8 2
cb3 cba 2 c9e
cbc 1 cbe 1
cc0 2 c89 cc1
1 cc5 1 c84
2 c82 cc9 2
cd3 cd8 1 cdf
1 cda 2 cf2
cf4 3 cf0 cf1
cf6 2 cff d01
2 d03 d05 2
d07 d09 2 d0b
d0d 2 d0f d11
3 d16 d17 d18
2 d13 d1a 2
cfe d1c 1 d1e
1 d20 2 ce9
d21 1 d25 1
ce4 2 ce2 d29
1 d34 2 d30
d34 2 d40 d42
3 d3e d3f d44
2 d4d d4f 2
d51 d53 2 d55
d57 1 d5f 2
d61 d62 2 d59
d64 2 d66 d68
2 d6a d6c 2
d6e d70 2 d72
d74 2 d4c d76
1 d78 1 d7a
2 d84 d86 3
d82 d83 d88 2
d91 d93 2 d90
d95 1 d97 1
d99 3 da0 da1
da2 3 d7b d9a
da4 1 da6 2
db5 dba 1 dc1
1 dbc 2 dd4
dd6 3 dd2 dd3
dd8 2 de1 de3
2 de5 de7 2
de9 deb 2 ded
def 2 df1 df3
3 df8 df9 dfa
2 df5 dfc 2
de0 dfe 1 e00
1 e02 2 dcb
e03 1 e07 1
dc6 2 dc4 e0b
5 ccc d2c da7
daa e0e 3 e13
e14 e15 1 e19
2 e17 e19 2
e21 e26 1 e2d
1 e28 2 e40
e42 3 e3e e3f
e44 2 e4d e4f
2 e51 e53 2
e55 e57 2 e59
e5b 2 e5d e5f
3 e64 e65 e66
2 e61 e68 2
e4c e6a 1 e6c
1 e6e 2 e37
e6f 1 e73 1
e32 2 e30 e77
1 e82 2 e7e
e82 2 e8e e90
3 e8c e8d e92
2 e9b e9d 2
e9f ea1 2 ea3
ea5 1 ead 2
eaf eb0 2 ea7
eb2 2 eb4 eb6
2 eb8 eba 2
ebc ebe 2 ec0
ec2 2 e9a ec4
1 ec6 1 ec8
2 ed2 ed4 3
ed0 ed1 ed6 2
edf ee1 2 ede
ee3 1 ee5 1
ee7 3 eee eef
ef0 3 ec9 ee8
ef2 1 ef4 2
f12 f17 1 f1e
1 f19 2 f31
f33 3 f2f f30
f35 2 f3e f40
2 f42 f44 2
f46 f48 2 f4a
f4c 2 f4e f50
3 f55 f56 f57
2 f52 f59 2
f3d f5b 1 f5d
1 f5f 2 f28
f60 1 f64 1
f23 2 f21 f68
1 f73 2 f6f
f73 2 f93 f98
1 f9f 1 f9a
2 fb2 fb4 3
fb0 fb1 fb6 2
fbf fc1 2 fc3
fc5 2 fc7 fc9
2 fcb fcd 2
fcf fd1 3 fd6
fd7 fd8 2 fd3
fda 2 fbe fdc
1 fde 1 fe0
2 fa9 fe1 1
fe5 1 fa4 2
fa2 fe9 1 ff4
2 ff0 ff4 1
ffa 2 1000 1001
1 1003 1 1007
2 1005 1007 2
1017 101c 1 1023
1 101e 2 1036
1038 3 1034 1035
103a 2 1043 1045
2 1047 1049 2
104b 104d 2 104f
1051 2 1053 1055
3 105a 105b 105c
2 1057 105e 2
1042 1060 1 1062
1 1064 2 102d
1065 1 1069 1
1028 2 1026 106d
2 1073 1074 1
1078 2 1076 1078
2 1083 1085 3
1081 1082 1087 2
1090 1092 2 1094
1096 2 1098 109a
1 10a2 2 10a4
10a5 2 109c 10a7
2 10a9 10ab 2
10ad 10af 2 10b1
10b3 2 10b5 10b7
2 108f 10b9 1
10bb 1 10bd 2
10c7 10c9 3 10c5
10c6 10cb 2 10d4
10d6 2 10d3 10d8
1 10da 1 10dc
3 10e3 10e4 10e5
3 10be 10dd 10e7
1 10e9 3 100c
1070 10ea 1 10ec
2 ffd 10ed 1
10ef 3 f79 fec
10f0 1 10f2 2
10fe 1103 1 110a
1 1105 2 111d
111f 3 111b 111c
1121 2 112a 112c
2 112e 1130 2
1132 1134 2 1136
1138 2 113a 113c
3 1141 1142 1143
2 113e 1145 2
1129 1147 1 1149
1 114b 2 1114
114c 1 1150 1
110f 2 110d 1154
6 e7a ef5 ef8
f6b 10f3 1157 2
1163 1165 3 1161
1162 1167 2 1170
1172 2 1174 1176
2 1178 117a 1
1182 2 1184 1185
2 117c 1187 2
116f 1189 1 118b
1 118d 2 1197
1199 3 1195 1196
119b 2 11a4 11a6
2 11a3 11a8 1
11aa 1 11ac 2
11b3 11b4 3 118e
11ad 11b6 3 11b8
115a 11b9 1 11c1
2 11bd 11c1 2
11c9 11ca 4 11c7
11cc 11cf 11d0 2
11d8 11d9 4 11d6
11db 11de 11df 1
120b 2 120a 120b
1 1213 1 1219
2 121b 121c 2
1208 121d 1 1224
1 121f 2 1237
1239 3 1235 1236
123b 2 1244 1246
2 1248 124a 2
124c 124e 2 1250
1252 2 1254 1256
3 125b 125c 125d
2 1258 125f 2
1243 1261 1 1263
1 1265 2 122e
1266 1 126a 1
1229 2 1227 126e
1 1275 4 11d3
11e2 1271 1278 2
1283 1284 4 1281
1286 1289 128a 7
1298 1299 129a 129b
129c 129d 129e 1
12bd 2 12bc 12bd
1 12c5 1 12cb
2 12cd 12ce 2
12ba 12cf 1 12d6
1 12d1 2 12e9
12eb 3 12e7 12e8
12ed 2 12f6 12f8
2 12fa 12fc 2
12fe 1300 2 1302
1304 2 1306 1308
3 130d 130e 130f
2 130a 1311 2
12f5 1313 1 1315
1 1317 2 12e0
1318 1 131c 1
12db 2 12d9 1320
6 127e 128d 1292
1295 12a1 1323 2
1326 1327 2 132a
132b 1 132f 2
132d 132f 1 1333
1 133c 2 133a
133c 2 1343 1344
1 1348 2 1346
1348 2 134c 134d
1 1351 2 134f
1351 2 1356 1357
1 135a 2 1360
1361 2 1366 1367
2 1363 1369 1
136c 2 136e 1370
2 1372 1374 1
1376 1 1379 2
137b 137c 3 137f
1380 1381 1 1385
2 1383 1385 1
1387 1 138c 3
1394 1395 1396 1
139a 2 1398 139a
3 13a1 13a2 13a3
1 13a7 2 13a5
13a7 2 13d6 13db
1 13e2 1 13dd
2 13f5 13f7 3
13f3 13f4 13f9 2
1402 1404 2 1406
1408 2 140a 140c
2 140e 1410 2
1412 1414 3 1419
141a 141b 2 1416
141d 2 1401 141f
1 1421 1 1423
2 13ec 1424 1
1428 1 13e7 2
13e5 142c 1 1431
3 1439 143a 143b
1 143f 2 143d
143f 2 144b 1450
1 1457 1 1452
2 146a 146c 3
1468 1469 146e 2
1477 1479 2 147b
147d 2 147f 1481
2 1483 1485 2
1487 1489 3 148e
148f 1490 2 148b
1492 2 1476 1494
1 1496 1 1498
2 1461 1499 1
149d 1 145c 2
145a 14a1 2 14a4
14a8 2 14ac 14af
2 14b1 14b2 1
14b3 2 14c3 14c8
1 14cf 1 14ca
2 14e2 14e4 3
14e0 14e1 14e6 2
14ef 14f1 2 14f3
14f5 2 14f7 14f9
2 14fb 14fd 2
14ff 1501 3 1506
1507 1508 2 1503
150a 2 14ee 150c
1 150e 1 1510
2 14d9 1511 1
1515 1 14d4 2
14d2 1519 2 151c
1520 2 1522 1523
3 13b5 142f 1524
2 1528 152b 2
152d 152e 1 1532
2 1530 1532 3
1538 1539 153a 1
153e 2 153c 153e
2 154b 154d 3
1549 154a 154f 2
1558 155a 2 155c
155e 2 1560 1562
1 156a 2 156c
156d 2 1564 156f
2 1571 1573 2
1575 1577 2 1579
157b 2 157d 157f
2 1557 1581 1
1583 1 1585 2
158f 1591 3 158d
158e 1593 2 159c
159e 2 159b 15a0
1 15a2 1 15a4
3 15ab 15ac 15ad
3 1586 15a5 15af
1 15b1 3 137d
152f 15b2 1 15b7
2 15b5 15b7 2
15cc 15d1 1 15d8
1 15d3 2 15eb
15ed 3 15e9 15ea
15ef 2 15f8 15fa
2 15fc 15fe 2
1600 1602 2 1604
1606 2 1608 160a
3 160f 1610 1611
2 160c 1613 2
15f7 1615 1 1617
1 1619 2 15e2
161a 1 161e 1
15dd 2 15db 1622
2 1637 163c 1
1643 1 163e 2
1656 1658 3 1654
1655 165a 2 1663
1665 2 1667 1669
2 166b 166d 2
166f 1671 2 1673
1675 3 167a 167b
167c 2 1677 167e
2 1662 1680 1
1682 1 1684 2
164d 1685 1 1689
1 1648 2 1646
168d 2 1693 1694
2 1699 169a 2
169f 16a0 2 169c
16a2 1 16a5 2
1696 16a5 2 16b0
16b2 3 16ae 16af
16b4 2 16bd 16bf
2 16c1 16c3 2
16c5 16c7 1 16cf
2 16d1 16d2 2
16c9 16d4 2 16d6
16d8 2 16da 16dc
2 16de 16e0 2
16e2 16e4 2 16bc
16e6 1 16e8 1
16ea 2 16f4 16f6
3 16f2 16f3 16f8
2 1701 1703 2
1700 1705 1 1707
1 1709 3 1710
1711 1712 3 16eb
170a 1714 1 1716
5 15bc 1625 1629
1690 1717 2 171a
1719 1 171b 1
171d 3 1720 1721
1722 1 1726 2
1724 1726 1 172d
2 1731 1732 1
1735 2 1737 1738
22 173c 173d 173e
173f 1740 1741 1742
1743 1744 1745 1746
1747 1748 1749 174a
174b 174c 174d 174e
174f 1750 1751 1752
1753 1754 1755 1756
1757 1758 1759 175a
175b 175c 175d 1
1763 2 1761 1763
1 176d 2 176c
176d 1 1775 1
177b 2 177d 177e
2 176a 177f 1
1786 1 1781 2
1799 179b 3 1797
1798 179d 2 17a6
17a8 2 17aa 17ac
2 17ae 17b0 2
17b2 17b4 2 17b6
17b8 3 17bd 17be
17bf 2 17ba 17c1
2 17a5 17c3 1
17c5 1 17c7 2
1790 17c8 1 17cc
1 178b 2 1789
17d0 1 17d3 1
17d6 8 c4c c4f
11ba 1328 171e 1739
1760 17d7 1 17e4
2 17e6 17e7 1
17eb 2 17e9 17eb
1 17f0 1 17f6
2 17f8 17f9 2
17fb 17fd 2 1800
1802 1 1804 1
1807 2 1809 180a
1 180e 2 180c
180e 2 1816 1817
1 181a 2 1819
181a 2 1827 1828
2 182a 182c 2
182e 1830 4 1824
1825 1832 1833 2
183e 183f 2 1841
1843 2 1845 1847
2 1849 184b 4
183b 183c 184d 184e
3 1853 1854 1855
1 1859 2 1857
1859 1 1863 2
1865 1866 1 186a
2 1868 186a 1
186f 2 1873 1875
3 1877 1878 1879
2 187f 1881 3
1883 1884 1885 2
187c 1888 2 188a
188b 2 1860 188c
2 1890 1891 1
1897 2 1899 189a
1 189e 2 189c
189e 1 18a3 2
18a7 18a9 3 18ab
18ac 18ad 2 18b3
18b5 3 18b7 18b8
18b9 2 18b0 18bc
2 18be 18bf 2
1894 18c0 2 18c2
18c3 3 18c6 18c7
18c8 1 18cc 2
18ca 18cc 1 18d1
1 18d3 2 18e7
18ec 1 18f3 1
18ee 2 1906 1908
3 1904 1905 190a
2 1913 1915 2
1917 1919 2 191b
191d 2 191f 1921
2 1923 1925 3
192a 192b 192c 2
1927 192e 2 1912
1930 1 1932 1
1934 2 18fd 1935
1 1939 1 18f8
2 18f6 193d 1
1948 2 1944 1948
2 1958 195d 1
1964 1 195f 2
1977 1979 3 1975
1976 197b 2 1984
1986 2 1988 198a
2 198c 198e 2
1990 1992 2 1994
1996 3 199b 199c
199d 2 1998 199f
2 1983 19a1 1
19a3 1 19a5 2
196e 19a6 1 19aa
1 1969 2 1967
19ae 1 19b9 2
19b5 19b9 1 19bf
1 19c3 2 19c5
19c6 2 19b1 19c7
1 19c9 2 19cc
19cd 1 19d1 2
19cf 19d1 2 19d5
19d6 1 19da 2
19d8 19da 2 19de
19df 1 19e3 2
19e1 19e3 2 19e8
19e9 1 19ec 2
19f2 19f3 2 19f8
19f9 2 19f5 19fb
1 19fe 2 1a00
1a02 2 1a04 1a06
1 1a08 1 1a0b
2 1a0d 1a0e 3
1a11 1a12 1a13 1
1a17 2 1a15 1a17
1 1a19 1 1a1e
3 1a26 1a27 1a28
1 1a2c 2 1a2a
1a2c 3 1a33 1a34
1a35 1 1a39 2
1a37 1a39 2 1a68
1a6d 1 1a74 1
1a6f 2 1a87 1a89
3 1a85 1a86 1a8b
2 1a94 1a96 2
1a98 1a9a 2 1a9c
1a9e 2 1aa0 1aa2
2 1aa4 1aa6 3
1aab 1aac 1aad 2
1aa8 1aaf 2 1a93
1ab1 1 1ab3 1
1ab5 2 1a7e 1ab6
1 1aba 1 1a79
2 1a77 1abe 1
1ac3 2 1ad6 1adb
1 1ae2 1 1add
2 1af5 1af7 3
1af3 1af4 1af9 2
1b02 1b04 2 1b06
1b08 2 1b0a 1b0c
2 1b0e 1b10 2
1b12 1b14 3 1b19
1b1a 1b1b 2 1b16
1b1d 2 1b01 1b1f
1 1b21 1 1b23
2 1aec 1b24 1
1b28 1 1ae7 2
1ae5 1b2c 2 1b2f
1b33 2 1b37 1b3a
2 1b3c 1b3d 3
1a47 1ac1 1b3e 2
1b42 1b45 2 1b47
1b48 2 1a0f 1b49
3 1b4f 1b50 1b51
1 1b55 2 1b53
1b55 3 1b5b 1b5c
1b5d 1 1b61 2
1b5f 1b61 2 1b6f
1b74 1 1b7b 1
1b76 2 1b8e 1b90
3 1b8c 1b8d 1b92
2 1b9b 1b9d 2
1b9f 1ba1 2 1ba3
1ba5 2 1ba7 1ba9
2 1bab 1bad 3
1bb2 1bb3 1bb4 2
1baf 1bb6 2 1b9a
1bb8 1 1bba 1
1bbc 2 1b85 1bbd
1 1bc1 1 1b80
2 1b7e 1bc5 1
1bc8 2 1bce 1bd1
3 1bd3 1bcb 1bd4
1 1bd5 2 1bd9
1bdc 2 1bde 1bdf
2 1be2 1be3 1
1be7 2 1be5 1be7
3 1beb 1bec 1bed
1 1bf1 2 1bef
1bf1 1 1bf6 1
1bf8 1 1bf9 3
1bfd 1bfe 1bff 1
1c03 2 1c01 1c03
1 1c0a 2 1c0f
1c10 1 1c13 3
1c15 1c0c 1c16 22
1c1a 1c1b 1c1c 1c1d
1c1e 1c1f 1c20 1c21
1c22 1c23 1c24 1c25
1c26 1c27 1c28 1c29
1c2a 1c2b 1c2c 1c2d
1c2e 1c2f 1c30 1c31
1c32 1c33 1c34 1c35
1c36 1c37 1c38 1c39
1c3a 1c3b 1 1c41
2 1c3f 1c41 1
1c4b 2 1c4a 1c4b
1 1c53 1 1c59
2 1c5b 1c5c 2
1c48 1c5d 1 1c64
1 1c5f 2 1c77
1c79 3 1c75 1c76
1c7b 2 1c84 1c86
2 1c88 1c8a 2
1c8c 1c8e 2 1c90
1c92 2 1c94 1c96
3 1c9b 1c9c 1c9d
2 1c98 1c9f 2
1c83 1ca1 1 1ca3
1 1ca5 2 1c6e
1ca6 1 1caa 1
1c69 2 1c67 1cae
1 1cb1 1 1cb4
2 1cb8 1cb9 2
1cbb 1cbd d 1836
1851 18c4 18d4 18d7
18da 1940 19ca 1be0
1c17 1c3e 1cb5 1cc0
2 1813 1cc3 1
1cc5 5 17db 17de
17e1 180b 1cc6 2
1cc8 1cc9 1 1ccd
2 1ccb 1ccd 2
1cd2 1cd3 1 1cd7
2 1cd5 1cd7 2
1ce5 1ce7 3 1ce3
1ce4 1ce9 2 1cf2
1cf4 2 1cf6 1cf8
2 1cfa 1cfc 1
1d04 2 1d06 1d07
2 1cfe 1d09 2
1d0b 1d0d 2 1d0f
1d11 2 1d13 1d15
2 1d17 1d19 2
1cf1 1d1b 1 1d1d
1 1d1f 2 1d29
1d2b 3 1d27 1d28
1d2d 2 1d36 1d38
2 1d35 1d3a 1
1d3c 1 1d3e 3
1d45 1d46 1d47 3
1d20 1d3f 1d49 1
1d4b 2 1d4e 1d4f
1 1d53 2 1d51
1d53 1 1d58 1
1d5a 1 1d5e 2
1d60 1d61 1 1d65
2 1d63 1d65 1
1d6b 2 1d6d 1d6e
1 1d72 2 1d70
1d72 2 1d79 1d7b
2 1d7d 1d7f 2
1d81 1d83 2 1d85
1d87 2 1d8d 1d8e
1 1d90 2 1d89
1d92 2 1d94 1d96
2 1d9c 1d9d 1
1d9f 2 1d98 1da1
2 1da3 1da5 2
1dab 1dac 1 1dae
2 1da7 1db0 2
1db2 1db4 2 1db6
1db8 2 1dba 1dbc
2 1dbe 1dc0 2
1dc2 1dc4 2 1dc6
1dc8 2 1dca 1dcc
2 1dce 1dd0 2
1dd2 1dd4 2 1dd6
1dd8 2 1dda 1ddc
2 1dde 1de0 2
1de2 1de4 2 1de6
1de8 2 1dea 1dee
2 1df0 1df2 2
1df4 1df8 2 1dfa
1dfc 2 1dfe 1e00
2 1e02 1e04 2
1e0a 1e0b 1 1e0d
2 1e06 1e0f 2
1e11 1e13 2 1e19
1e1a 1 1e1c 2
1e15 1e1e 2 1e20
1e22 2 1e24 1e26
2 1e2c 1e2d 1
1e2f 2 1e28 1e31
2 1e33 1e35 2
1e37 1e39 2 1e3b
1e3d 2 1e3f 1e41
2 1e43 1e45 2
1e47 1e49 2 1e4b
1e4d 2 1e4f 1e51
2 1e53 1e55 1
1e58 1 1e5d 2
1e5f 1e60 1 1e64
2 1e62 1e64 2
1e68 1e6a 2 1e6c
1e6e 2 1e70 1e72
2 1e74 1e76 2
1e7c 1e7d 1 1e7f
2 1e78 1e81 2
1e83 1e85 2 1e8b
1e8c 1 1e8e 2
1e87 1e90 2 1e92
1e94 2 1e9a 1e9b
1 1e9d 2 1e96
1e9f 2 1ea1 1ea3
2 1ea5 1ea7 2
1ea9 1eab 2 1ead
1eaf 2 1eb1 1eb3
2 1eb5 1eb7 2
1eb9 1ebb 2 1ebd
1ebf 2 1ec1 1ec3
2 1ec5 1ec7 2
1ec9 1ecb 2 1ecd
1ecf 1 1ed2 1
1ed8 2 1eda 1edb
1 1edf 2 1edd
1edf 2 1ee3 1ee5
2 1ee7 1eeb 2
1eed 1eef 2 1ef1
1ef5 2 1ef7 1ef9
2 1efb 1efd 2
1eff 1f01 2 1f07
1f08 1 1f0a 2
1f03 1f0c 2 1f0e
1f10 2 1f16 1f17
1 1f19 2 1f12
1f1b 2 1f1d 1f1f
2 1f21 1f23 2
1f29 1f2a 1 1f2c
2 1f25 1f2e 2
1f30 1f32 2 1f34
1f36 2 1f38 1f3a
2 1f3c 1f3e 2
1f40 1f42 2 1f44
1f46 2 1f48 1f4a
2 1f4c 1f4e 2
1f50 1f52 1 1f55
3 1f58 1ed5 1f57
2 1f62 1f64 3
1f60 1f61 1f66 2
1f6f 1f71 2 1f6e
1f73 1 1f75 1
1f77 2 1f81 1f83
3 1f7f 1f80 1f85
2 1f8e 1f90 2
1f8d 1f92 1 1f94
1 1f96 1 1f9c
2c 2e7 306 309
30c 30f 312 315
318 31b 31e 321
324 327 32a 32d
330 333 33d 340
343 3a7 425 58e
5a2 5b0 5c1 a51
a6d bb0 c1f c24
c27 c2a c2d c30
c38 c40 1cca 1d4c
1d5b 1f59 1f78 1f97
1f9f 2 1fac 1fae
3 1faa 1fab 1fb0
2 1fb9 1fbb 2
1fb8 1fbd 2 1fc4
1fc8 2 1fca 1fcc
2 1fce 1fd2 2
1fc3 1fd4 2 1fbf
1fd6 1 1fd8 3
1fd9 1fe4 1fe8 1
1fa3 2 1ffb 1ffd
3 1ff9 1ffa 1fff
2 2008 200a 2
2007 200c 2 2013
2015 2 2017 2019
3 201e 201f 2020
2 201b 2022 2
2012 2024 2 200e
2026 1 2028 4
1ff2 2029 2032 2036
1 203a 1 1fed
2 1feb 203e 42
4b 52 59 60
67 6e 75 7a
81 88 8f 96
9d a4 ab b2
b7 bc c3 c9
cf d5 db e1
e7 ed f3 f9
ff 105 10b 111
117 11d 123 129
12f 135 13b 141
147 14d 153 159
15f 165 16b 171
177 17d 183 189
190 197 19d 1a3
1aa 1b0 1b6 1bc
1c2 1c8 1ce 1d4
1d9 1e0 
1
4
0 
2045
0
1
50
3d
52
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 31 30 33 30 35 30 37
30 39 30 3b 1 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3b 1 0
143 1 0
2b 1 0
173 1 0
185 1 0
1ca 1 0
14f 1 0
2f 1 0
1b2 1 0
a6 1 0
107 1 0
e3 1 0
1be 1 0
8a 1 0
27 1 0
167 1 0
18b 1 0
98 1 0
1f 1 0
1b 1 0
1d0 1 0
83 1 0
c5 1 0
17f 1 0
16d 1 0
91 1 0
d7 1 0
1a5 1 0
77 1 0
1d6 1 0
19f 1 0
13 1 0
101 1 0
f5 1 0
69 1 0
7c 1 0
137 1 0
9f 1 0
62 1 0
f 1 0
ef 1 0
15b 1 0
3 1 0
cb 1 0
b9 1 0
70 1 0
199 1 0
13d 1 0
161 1 0
11f 1 0
113 1 0
23 1 0
2 0 1
125 1 0
4d 1 0
1b8 1 0
7 1 0
155 1 0
fb 1 0
e9 1 0
149 1 0
dd 1 0
1ac 1 0
d1 1 0
5b 1 0
46 1 0
119 1 0
37 1 0
ad 1 0
12b 1 0
17 1 0
179 1 0
b4 1 0
be 1 0
131 1 0
54 1 0
33 1 0
1c4 1 0
10d 1 0
b 1 0
1db 1 0
192 1 0
0

/
SHOW ERRORS FUNCTION SP_SEARCH_3;
ALTER FUNCTION SP_SEARCH_3 COMPILE DEBUG;
/*
#Stored Procedure  :SP_I_PROFILE
#Short Description :Assign a profile to a task or project
#Description       :used tables: RESOURCE_ASSIGNMENTS, PROFILES
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_I_PROFILE ==
CREATE OR REPLACE FUNCTION SP_I_PROFILE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
b8
2 :e:
1FUNCTION:
1SP_I_PROFILE:
1PRJ_ID:
1VARCHAR2:
1AND_ROLES:
1AND_SKILLS:
1ORG_ID001:
1GEO_ID001:
1POOL_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_UNIQUEID:
132:
1H_AND_ROLES:
18000:
1H_ROLE_ID:
1H_FULL_NAME:
1255:
1H_COUNT:
1PLS_INTEGER:
10:
1H_NUMBER:
1H_TYPE_ID:
1NUMITEMS:
1NUMITEMS001:
1CURSOR:
1CEXISTS:
1PROFILE_ID:
1PROFILES:
1ROWNUM:
1PROJECT_ID:
1ROLE_ID:
1SELECT PROFILE_ID FROM PROFILES:n         WHERE  ROWNUM <= 1 AND  PROJECT_ID=+
1prj_id AND ROLE_ID=h_role_id:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_I_PROFILE(:
1':
1, :
1);:
1CHECK_TRACE:
11:
139:
1+:
1FPUT:
1               ENTER:: SP_I_PROFILE(40) :: cplan.sql(5949) :: :
1IS NULL:
18:
146:
1      RETURN_INVALID:: SP_I_PROFILE(47) :: cplan.sql(5956) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
149:
1                EXIT:: SP_I_PROFILE(50) :: cplan.sql(5959) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SUBSTR:
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
1TNGROLE:
17:
1=:
1OPEN:
1FOUND:
1SC_STATE:
1100:
1SC_SQL_SUCCESS:
1CLOSE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
191:
1           EXCEPTION:: SP_I_PROFILE(92) :: cplan.sql(6001) :: :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
196:
1        RETURN_ERROR:: SP_I_PROFILE(97) :: cplan.sql(6006) :: :
1 ID:: :
199:
1                EXIT:: SP_I_PROFILE(100) :: cplan.sql(6009) :: :
1PMO_RETURN_ERROR_SP:
1113:
1           EXCEPTION:: SP_I_PROFILE(114) :: cplan.sql(6023) :: :
1MAX:
1PROF_NUMBER:
1SELECT COALESCE(MAX(PROF_NUMBER),0)+1 INTO h_number:n      FROM PROFILES:n   +
1   WHERE PROJECT_ID=prj_id/**prj_id*/ AND ROLE_ID=h_role_id:
1133:
1           EXCEPTION:: SP_I_PROFILE(134) :: cplan.sql(6043) :: :
1STRINGCONCAT:
1RTRIM:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1ELEMENT_ID:
1PARENT_ID:
1SELECT PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConca+
1t(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEMENT_NAME), ',+
1 '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(h_number))), ')'):n      IN+
1TO h_full_name FROM TMT_COMPETENCIES TC, TMT_COMPETENCIES TCP:n      WHERE TC+
1.ELEMENT_ID = h_role_id AND TCP.ELEMENT_ID = TC.PARENT_ID:
1150:
1           EXCEPTION:: SP_I_PROFILE(151) :: cplan.sql(6060) :: :
1SC_SQL_NO_DATA:
1157:
1        RETURN_ERROR:: SP_I_PROFILE(158) :: cplan.sql(6067) :: :
1RECORD_NOT_FOUND:
1160:
1                EXIT:: SP_I_PROFILE(161) :: cplan.sql(6070) :: :
1TYPE_ID:
1TMT_WBS:
1SELECT TYPE_ID INTO h_type_id:n      FROM TMT_WBS:n      WHERE ELEMENT_ID=prj+
1_id:
1177:
1           EXCEPTION:: SP_I_PROFILE(178) :: cplan.sql(6087) :: :
1!=:
1ISPROJECTTYPE:
1NOT:
1185:
1        RETURN_ERROR:: SP_I_PROFILE(186) :: cplan.sql(6095) :: :
1188:
1                EXIT:: SP_I_PROFILE(189) :: cplan.sql(6098) :: :
1SYS_GUID:
1PROFILE_NAME:
1POOL_ID:
1GEO_ID:
1ORG_ID:
1INSERT INTO PROFILES(PROFILE_ID,PROJECT_ID,ROLE_ID,PROF_NUMBER, PROFILE_NAME,+
1 POOL_ID, GEO_ID, ORG_ID):n      VALUES(h_uniqueID, prj_id, h_role_id, h_numb+
1er, h_full_name, pool_id001, geo_id001, org_id001):
1211:
1           EXCEPTION:: SP_I_PROFILE(212) :: cplan.sql(6121) :: :
1TRUNC:
1LENGTH:
1/:
1>:
1WHILE:
1<:
1LOOP:
1PMO_STPU:
1STRNPCPY:
1*:
1RESOURCE_ASSIGN_ROLES:
1PROFICIENCY_LEVEL_ID:
1PREFERENCE_LEVEL_ID:
1EXPERIENCE_ID:
1LAST_USED_DATETIME:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n               SELECT h_uniqueID, ELEMENT_+
1ID, PROFICIENCY_LEVEL_ID, PREFERENCE_LEVEL_ID,:n               EXPERIENCE_ID,+
1 LAST_USED_DATETIME, TO_CHAR(h_count):n               FROM TMT_COMPETENCIES W+
1HERE ELEMENT_ID = h_role_id:
1244:
1           EXCEPTION:: SP_I_PROFILE(245) :: cplan.sql(6154) :: :
1RESOURCE_ASSIGN_SKILLS:
1INSERT INTO RESOURCE_ASSIGN_SKILLS:n                  SELECT h_uniqueID, h_ro+
1le_id, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID,:n                  PREFERENCE_LEV+
1EL_ID, LAST_USED_DATETIME, TO_CHAR(h_count):n                  FROM TMT_COMPE+
1TENCIES WHERE ELEMENT_ID = h_role_id:
1283:
1           EXCEPTION:: SP_I_PROFILE(284) :: cplan.sql(6193) :: :
14:
1295:
1       RETURN_STATUS:: SP_I_PROFILE(296) :: cplan.sql(6205) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1302:
1           EXCEPTION:: SP_I_PROFILE(303) :: cplan.sql(6212) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1314:
1           EXCEPTION:: SP_I_PROFILE(315) :: cplan.sql(6224) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
874
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a0 f4 b4 bf
c8 :7 a0 12a bd b7 11 a4 b1
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c a0 7e b4
2e :2 5a a0 7e b4 2e :2 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :2 a0 d :4 a0 :2 51 a5
b :2 51 a5 b d a0 7e b4
2e 5a :2 a0 d :2 a0 6b a0 6e
51 a5 b 7e 51 b4 2e :2 a0
e9 dd b3 :2 a0 e9 d3 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 19
3c b7 19 3c :9 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :1f a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :3 a0 51
a5 b a5 b 5a 7e 51 b4
2e 7e b4 2e 52 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:2 a0 b4 2e d :11 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :5 a0 a5 b
51 a5 b 7e 51 b4 2e 5a
7e 51 b4 2e a5 b d a0
7e 51 b4 2e a0 51 d :3 a0
51 a5 b a0 7e a0 b4 2e
82 :3 a0 6b :2 51 :2 a0 51 a5 b
7e 51 b4 2e 7e 51 b4 2e
a0 a5 b d :c a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 51 a5 b
7e 51 b4 2e d b7 a0 47
b7 19 3c a0 7e b4 2e 5a
:2 a0 d :5 a0 a5 b 51 a5 b
7e 51 b4 2e 5a 7e 51 b4
2e a5 b d a0 7e 51 b4
2e a0 51 d :3 a0 51 a5 b
a0 7e a0 b4 2e 82 :3 a0 6b
:2 51 :2 a0 51 a5 b 7e 51 b4
2e 7e 51 b4 2e a0 a5 b
d :c a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b 7e 51 b4
2e d b7 a0 47 b7 19 3c
b7 19 3c b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 a0 6b :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e a5 57
b7 19 3c :9 a0 12a e9 dd :2 a0
65 b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c :7 a0 12a e9 dd :2 a0 65 b7
a4 b1 11 4f b7 a6 9 a4
b1 11 68 4f 1d 17 b5 
874
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d 7c
a2 a6 aa ae b1 b5 d2 bd
c1 c4 c5 cd bc ef dd b9
e1 e2 ea dc 10c fa d9 fe
ff 107 f9 129 117 f6 11b 11c
124 116 145 134 138 113 140 133
161 150 154 130 15c 14f 17d 16c
170 14c 178 16b 199 188 18c 194
168 1b1 1a0 1a4 1ac 187 1b8 1bc
184 1cd 1d0 1d4 1d8 1dc 1e0 1e4
1e8 1ec 1f0 1fc 201 203 20f 213
231 219 21d 221 224 22c 218 238
23c 215 240 244 248 24b 250 251
1 253 258 25c 260 263 268 26c
270 273 278 279 27b 280 283 287
288 28d 292 295 29a 29b 2a0 2a3
2a7 2a8 2ad 2b0 2b5 2b6 2bb 2be
2c3 2c4 2c9 2cc 2d1 2d2 2d7 2da
2de 2df 2e4 2e7 2ec 2ed 2f2 2f5
2fa 2fb 300 303 308 309 30e 311
315 316 31b 31e 323 324 329 32c
331 332 337 33a 33f 340 345 348
34c 34d 352 355 35a 35b 360 363
368 369 36e 371 376 377 37c 37f
383 384 389 38c 391 392 397 39a
39f 3a0 3a5 3a8 3ad 3ae 3b3 3b6
3ba 3bb 3c0 3c3 3c8 3c9 3ce 3d1
3d6 3d7 3dc 3df 3e4 3e5 3ea 3ed
3f1 3f2 3f7 3fa 3ff 400 405 408
40d 40e 413 414 419 41b 41f 422
426 42a 42d 431 435 438 43b 440
443 446 449 44a 44f 450 1 452
457 45b 45f 462 467 46c 46f 473
474 479 47a 47f 481 485 488 48c
48f 490 495 498 49b 49f 4a2 4a3
4a8 4ab 1 4ae 4b3 4b7 4bb 4be
4c2 4c6 4c9 4cc 4d1 4d4 4d7 4da
4db 4e0 4e1 1 4e3 4e8 4ec 4f0
4f3 4f8 4fd 500 504 505 50a 50d
512 513 518 51b 520 521 526 529
52d 531 535 539 53c 53d 53f 544
545 547 548 54d 54e 553 555 559
55c 560 564 567 56b 56f 572 575
57a 57d 580 583 584 589 58a 1
58c 591 595 599 59c 5a1 5a6 5a9
5ad 5ae 5b3 5b4 5b9 5bb 5bf 5c2
5c6 5ca 5cd 5d1 5d5 5d8 5dc 5dd
5e2 5e4 5e8 5eb 5ef 5f3 5f7 5fb
5ff 603 607 60a 60d 60e 610 613
616 617 619 61d 621 624 625 62a
62d 631 635 639 63d 641 644 648
64d 650 651 653 656 659 65a 65f
663 667 66c 670 671 675 679 67e
683 687 68b 690 694 698 69b 69e
6a2 6a4 6a8 6ac 6af 6b2 6b6 6b8
6bc 6c0 6c3 6c7 6cb 6ce 6d2 6d5
6d9 6dc 6dd 6e2 6e5 6e9 6ed 6f2
6f4 6f8 6fc 6ff 703 707 709 70d
711 715 718 71c 720 722 723 728
1 72c 730 734 737 73b 73f 743
747 74a 74e 752 755 758 75d 760
763 766 767 76c 76d 1 76f 774
778 77c 77f 784 789 78c 790 791
796 799 79e 79f 7a4 7a7 7ac 7ad
7b2 7b5 7b9 7ba 7bf 7c2 7c7 7c8
7cd 7d0 7d4 7d8 7db 7de 7df 7e1
7e2 7e7 7e8 7ed 7ef 7f3 7f6 7f8
7fc 7fe 80a 80c 80e 80f 814 818
81a 826 828 82c 830 833 837 83b
83e 841 846 849 84c 84f 850 855
856 1 858 85d 861 865 868 86d
872 875 879 87a 87f 882 887 888
88d 890 895 896 89b 89e 8a2 8a6
8aa 8ae 8b1 8b2 8b4 8b9 8ba 8bc
8bd 8c2 8c5 8ca 8cb 8d0 8d3 8d8
8d9 8de 8e1 8e5 8e6 8eb 8ee 8f3
8f4 8f9 8fa 8ff 901 905 908 90c
910 913 917 91b 91e 921 926 929
92c 92f 930 935 936 1 938 93d
941 945 948 94d 952 955 959 95a
95f 960 965 967 96b 96e 972 976
979 97d 981 984 988 98c 98d 992
994 998 99c 9a1 9a3 9a7 9ab 9ae
9b2 9b6 9b8 9bc 9c0 9c4 9c7 9cb
9cf 9d1 9d2 9d7 1 9db 9df 9e3
9e6 9ea 9ee 9f2 9f6 9f9 9fd a01
a04 a07 a0c a0f a12 a15 a16 a1b
a1c 1 a1e a23 a27 a2b a2e a33
a38 a3b a3f a40 a45 a48 a4d a4e
a53 a56 a5b a5c a61 a64 a68 a69
a6e a71 a76 a77 a7c a7f a83 a87
a8a a8d a8e a90 a91 a96 a97 a9c
a9e aa2 aa5 aa7 aab aad ab9 abb
abd abe ac3 ac7 ac9 ad5 ad7 ad9
add ae1 ae4 ae6 aea aed aef af3
af6 afa afe b02 b06 b0a b0e b12
b16 b1a b26 b2a b2e b31 b35 b39
b3b b3f b43 b47 b4a b4e b52 b54
b55 b5a 1 b5e b62 b66 b69 b6d
b71 b75 b79 b7c b80 b84 b87 b8a
b8f b92 b95 b98 b99 b9e b9f 1
ba1 ba6 baa bae bb1 bb6 bbb bbe
bc2 bc3 bc8 bcb bd0 bd1 bd6 bd9
bde bdf be4 be7 beb bec bf1 bf4
bf9 bfa bff c02 c06 c0a c0d c10
c11 c13 c14 c19 c1a c1f c21 c25
c28 c2a c2e c30 c3c c3e c40 c41
c46 c4a c4c c58 c5a c5e c62 c66
c6a c6e c72 c76 c7a c7e c82 c86
c8a c8e c92 c96 c9a c9e ca2 ca6
caa cae cb2 cb6 cba cbe cc2 cc6
cca cce cd2 cd6 ce2 ce6 cea ced
cf1 cf5 cf7 cfb cff d03 d06 d0a
d0e d10 d11 d16 1 d1a d1e d22
d25 d29 d2d d31 d35 d38 d3c d40
d43 d46 d4b d4e d51 d54 d55 d5a
d5b 1 d5d d62 d66 d6a d6d d72
d77 d7a d7e d7f d84 d87 d8c d8d
d92 d95 d9a d9b da0 da3 da7 da8
dad db0 db5 db6 dbb dbe dc2 dc6
dc9 dcc dcd dcf dd0 dd5 dd6 ddb
ddd de1 de4 de6 dea dec df8 dfa
dfc dfd e02 e06 e08 e14 e16 e1a
e1e e21 e25 e28 e2c e2f e30 e35
e38 e3c e40 e43 e47 e4b e4e e51
e56 e59 e5c e5f e60 e65 e66 1
e68 e6d e71 e75 e78 e7d e82 e85
e89 e8a e8f e92 e97 e98 e9d ea0
ea5 ea6 eab eae eb2 eb6 eba ebe
ec1 ec2 ec4 ec9 eca ecc ecd ed2
ed5 eda edb ee0 ee3 ee8 ee9 eee
ef1 ef5 ef6 efb efe f03 f04 f09
f0a f0f f11 f15 f18 f1c f20 f23
f27 f2b f2e f31 f36 f39 f3c f3f
f40 f45 f46 1 f48 f4d f51 f55
f58 f5d f62 f65 f69 f6a f6f f70
f75 f77 f7b f7e f82 f86 f89 f8d
f91 f94 f98 f9c f9d fa2 fa4 fa8
fab faf fb3 fb7 fbb fbf fcb fcf
fd3 fd6 fda fde fe0 fe4 fe8 fec
fef ff3 ff7 ff9 ffa fff 1 1003
1007 100b 100e 1012 1016 101a 101e 1021
1025 1029 102c 102f 1034 1037 103a 103d
103e 1043 1044 1 1046 104b 104f 1053
1056 105b 1060 1063 1067 1068 106d 1070
1075 1076 107b 107e 1083 1084 1089 108c
1090 1091 1096 1099 109e 109f 10a4 10a7
10ab 10af 10b2 10b5 10b6 10b8 10b9 10be
10bf 10c4 10c6 10ca 10cd 10cf 10d3 10d5
10e1 10e3 10e5 10e6 10eb 10ef 10f1 10fd
10ff 1103 1107 110a 110e 1111 1115 1118
1119 111e 1121 1125 1129 112d 1130 1131
1133 1134 1136 1139 113c 113f 1140 1145
1148 1149 1 114e 1153 1157 115b 115e
1162 1166 1169 116c 1171 1174 1177 117a
117b 1180 1181 1 1183 1188 118c 1190
1193 1198 119d 11a0 11a4 11a5 11aa 11ad
11b2 11b3 11b8 11bb 11c0 11c1 11c6 11c9
11cd 11d1 11d5 11d9 11dc 11dd 11df 11e4
11e5 11e7 11e8 11ed 11f0 11f5 11f6 11fb
11fe 1203 1204 1209 120c 1210 1211 1216
1219 121e 121f 1224 1225 122a 122c 1230
1233 1237 123b 123e 1242 1246 1249 124c
1251 1254 1257 125a 125b 1260 1261 1
1263 1268 126c 1270 1273 1278 127d 1280
1284 1285 128a 128b 1290 1292 1296 1299
129d 12a1 12a4 12a8 12ac 12af 12b3 12b7
12b8 12bd 12bf 12c3 12c6 12ca 12ce 12cf
12d4 12d8 12dc 12e0 12e4 12e8 12ec 12f0
12f4 12f8 12fc 1300 1304 1308 130c 1310
1314 1318 131c 1328 132c 1331 1335 1338
1339 133e 1342 1346 1349 134c 1350 1352
1356 135a 135d 1360 1364 1366 136a 136e
1371 1373 1377 137b 137f 1382 1386 138a
138c 138d 1392 1 1396 139a 139e 13a1
13a5 13a9 13ad 13b1 13b4 13b8 13bc 13bf
13c2 13c7 13ca 13cd 13d0 13d1 13d6 13d7
1 13d9 13de 13e2 13e6 13e9 13ee 13f3
13f6 13fa 13fb 1400 1403 1408 1409 140e
1411 1416 1417 141c 141f 1423 1424 1429
142c 1431 1432 1437 143a 143e 1442 1445
1448 1449 144b 144c 1451 1452 1457 1459
145d 1460 1462 1466 1468 1474 1476 1478
1479 147e 1482 1484 1490 1492 1496 149a
149d 14a1 14a4 14a8 14ab 14ac 14b1 14b4
14b8 14bc 14c0 14c4 14c8 14c9 14cb 14ce
14cf 14d1 14d4 14d7 14d8 14dd 14e0 14e3
14e6 14e7 14ec 14ed 14ef 14f3 14f7 14fa
14fd 14fe 1503 1507 150a 150e 1512 1516
151a 151d 151e 1520 1524 1527 152b 152c
1531 1533 1537 153b 153f 1542 1545 1548
154c 1550 1553 1554 1556 1559 155c 155d
1562 1565 1568 1569 156e 1572 1573 1575
1579 157d 1581 1585 1589 158d 1591 1595
1599 159d 15a1 15a5 15a9 15b5 15b9 15be
15c2 15c5 15c6 15cb 15cf 15d3 15d6 15d9
15dd 15df 15e3 15e7 15ea 15ed 15f1 15f3
15f7 15fb 15fe 1600 1604 1608 160c 160f
1613 1617 1619 161a 161f 1 1623 1627
162b 162e 1632 1636 163a 163e 1641 1645
1649 164c 164f 1654 1657 165a 165d 165e
1663 1664 1 1666 166b 166f 1673 1676
167b 1680 1683 1687 1688 168d 1690 1695
1696 169b 169e 16a3 16a4 16a9 16ac 16b0
16b1 16b6 16b9 16be 16bf 16c4 16c7 16cb
16cf 16d2 16d5 16d6 16d8 16d9 16de 16df
16e4 16e6 16ea 16ed 16ef 16f3 16f5 1701
1703 1705 1706 170b 170f 1711 171d 171f
1723 1727 172b 172e 172f 1731 1734 1737
1738 173d 1741 1743 1747 174e 1750 1754
1757 175b 175e 175f 1764 1767 176b 176f
1773 1777 177b 177f 1783 1787 1788 178a
178d 178e 1790 1793 1796 1797 179c 179f
17a2 17a5 17a6 17ab 17ac 17ae 17b2 17b6
17b9 17bc 17bd 17c2 17c6 17c9 17cd 17d1
17d5 17d9 17dc 17dd 17df 17e3 17e6 17ea
17eb 17f0 17f2 17f6 17fa 17fe 1801 1804
1807 180b 180f 1812 1813 1815 1818 181b
181c 1821 1824 1827 1828 182d 1831 1832
1834 1838 183c 1840 1844 1848 184c 1850
1854 1858 185c 1860 1864 1868 1874 1878
187d 1881 1884 1885 188a 188e 1892 1895
1898 189c 189e 18a2 18a6 18a9 18ac 18b0
18b2 18b6 18ba 18bd 18bf 18c3 18c7 18cb
18ce 18d2 18d6 18d8 18d9 18de 1 18e2
18e6 18ea 18ed 18f1 18f5 18f9 18fd 1900
1904 1908 190b 190e 1913 1916 1919 191c
191d 1922 1923 1 1925 192a 192e 1932
1935 193a 193f 1942 1946 1947 194c 194f
1954 1955 195a 195d 1962 1963 1968 196b
196f 1970 1975 1978 197d 197e 1983 1986
198a 198e 1991 1994 1995 1997 1998 199d
199e 19a3 19a5 19a9 19ac 19ae 19b2 19b4
19c0 19c2 19c4 19c5 19ca 19ce 19d0 19dc
19de 19e2 19e6 19ea 19ed 19ee 19f0 19f3
19f6 19f7 19fc 1a00 1a02 1a06 1a0d 1a0f
1a13 1a16 1a18 1a1c 1a1f 1a21 1a25 1a28
1a2c 1a30 1a33 1a37 1a3b 1a3e 1a41 1a46
1a49 1a4c 1a4f 1a50 1a55 1a56 1 1a58
1a5d 1a61 1a65 1a68 1a6d 1a72 1a75 1a79
1a7a 1a7f 1a82 1a87 1a88 1a8d 1a90 1a95
1a96 1a9b 1a9e 1aa2 1aa6 1aaa 1aae 1ab1
1ab2 1ab4 1ab9 1aba 1abc 1abd 1ac2 1ac5
1aca 1acb 1ad0 1ad3 1ad8 1ad9 1ade 1ae1
1ae5 1ae6 1aeb 1aee 1af3 1af4 1af9 1afa
1aff 1b01 1b05 1b08 1b0c 1b10 1b13 1b17
1b1b 1b1e 1b22 1b26 1b27 1b2c 1b2e 1b32
1b36 1b39 1b3d 1b41 1b44 1b48 1b4c 1b4f
1b52 1b57 1b5a 1b5d 1b60 1b61 1b66 1b67
1 1b69 1b6e 1b72 1b76 1b79 1b7e 1b83
1b86 1b8a 1b8b 1b90 1b91 1b96 1b9a 1b9e
1ba1 1ba6 1bab 1bae 1bb2 1bb6 1bb9 1bba
1bbf 1bc2 1bc7 1bc8 1bcd 1bd0 1bd4 1bd8
1bdb 1bdc 1be1 1be2 1be7 1be9 1bed 1bf0
1bf4 1bf8 1bfc 1c00 1c04 1c08 1c0c 1c10
1c14 1c20 1c25 1c29 1c2d 1c31 1c35 1c37
1c38 1c3d 1 1c41 1c45 1c49 1c4c 1c50
1c54 1c58 1c5c 1c5f 1c63 1c67 1c6a 1c6d
1c72 1c75 1c78 1c7b 1c7c 1c81 1c82 1
1c84 1c89 1c8d 1c91 1c94 1c99 1c9e 1ca1
1ca5 1ca6 1cab 1cac 1cb1 1cb5 1cb9 1cbc
1cc1 1cc6 1cc9 1ccd 1cce 1cd3 1cd6 1cdb
1cdc 1ce1 1ce4 1ce8 1cec 1cef 1cf2 1cf3
1cf5 1cf6 1cfb 1cfc 1d01 1d03 1d07 1d0a
1d0e 1d12 1d16 1d1a 1d1e 1d22 1d26 1d32
1d37 1d3b 1d3f 1d43 1d47 1d49 1d4d 1d4f
1d5b 1d5d 1d5f 1d60 1d65 1d69 1d6b 1d77
1d7b 1d7d 1d7e 1d87 
874
2
0 1 a 6 d :3 6 10 :3 6
11 :3 6 10 :3 6 10 :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 f 18 17 :2 f :2 4 10 19
18 :2 10 :2 4 e 17 16 :2 e :2 4
10 19 18 :2 10 :2 4 :2 c 1b c
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :3 d :2 4 :3 10 4 7 e 0
:2 7 11 21 11 22 2d 38 40
a :5 7 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 54 5a 5d :2 54
6b 81 8 :2 6b d 10 :2 6b 17
1a :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 28 2b :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 29
2c :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 28 2b :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 28
2b :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 29 2c :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 2a
2d :2 6b 32 35 :2 6b :2 7 4a :2 4
7 :2 11 23 :2 2d 39 3c 4c 4e
4f :2 4c :2 23 :3 7 :2 d 12 1e 5c
5f :2 1e :2 7 52 :2 4 :4 9 8 7
:4 1f 1e 1d :2 7 a :2 14 26 :2 30
3c 3f 4f 51 52 :2 4f :2 26 :3 a
:2 10 15 21 5f 62 :2 21 6f 72
:2 21 76 79 :2 21 83 86 8f 97
:2 a0 :2 8f b1 :2 86 :2 21 :2 a 55 :2 7
a :2 14 26 :2 30 3c 3f 4f 51
52 :2 4f :2 26 :3 a :2 10 15 21 5f
62 :2 21 :2 a 55 :3 7 :2 12 28 :2 31
41 :2 7 33 :3 4 13 :2 4 11 18
1f 2c 2f :2 18 34 37 :2 11 4
:4 8 :2 7 15 7 a :2 15 1d 29
34 :2 a 37 39 :2 37 a f :3 a
10 1d :2 a d 15 :2 d :2 16 22
d 1b d :2 16 22 d :4 a e
:2 17 22 20 :2 2b :2 20 d 10 16
:3 10 :2 19 25 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5c
5e 5f :2 5c :2 32 :3 16 :2 1c 21 2d
6b 6e :2 2d 7b 7e :2 2d 82 85
:2 2d 91 94 :2 2d 9c 9f :2 2d ab
ae b5 be c1 :2 ae :2 2d :2 16 62
:2 13 :2 10 :4 1c :2 10 d :3 3b 10 :2 1a
2c :2 36 42 46 56 58 59 :2 56
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 89 8c
95 9d :2 a6 :2 95 b1 :2 8c :2 27 b9
bc :2 27 c4 c7 :2 27 cc cf :2 27
da dd :2 27 :2 10 5c :2 d 10 :2 1a
2c :2 36 42 45 55 57 58 :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
:2 10 5b :3 d :2 18 2c :2 35 3f 4b
:2 d 3b 10 16 :3 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5c 5f 60 :2 5c :2 32
:3 16 :2 1c 21 2d 6c 6f :2 2d 7c
7f :2 2d 83 86 :2 2d 92 95 :2 2d
9d a0 :2 2d ac af b6 bf c2
:2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10
d :7 a 3b :2 7 20 :2 4 e 17
1b 32 c d 18 2e 36 :2 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 53 56
57 :2 53 :2 29 :3 d :2 13 18 24 63
66 :2 24 73 76 :2 24 7a 7d :2 24
89 8c :2 24 94 97 :2 24 a3 a6
ad b6 b9 :2 a6 :2 24 :2 d 5a :2 a
:2 7 :4 13 :2 7 4 :3 1 e 19 26
31 3e 49 56 61 6e 79 86
8c 90 a6 ac af c5 cb d3
c 1d 2e 32 43 d 10 1d
2b 2f 3c 3f :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 53 56 57 :2 53 :2 29
:3 d :2 13 18 24 63 66 :2 24 73
76 :2 24 7a 7d :2 24 89 8c :2 24
94 97 :2 24 a3 a6 ad b6 b9
:2 a6 :2 24 :2 d 5a :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 a :2 14 26 :2 30 3c 40 50
53 54 :2 50 :2 26 :3 a :2 10 15 21
60 63 :2 21 70 73 :2 21 77 7a
:2 21 84 87 90 98 :2 a1 :2 90 b4
:2 87 :2 21 bc bf :2 21 c7 ca :2 21
cf d2 :2 21 dc df :2 21 :2 a 57
:2 7 a :2 14 26 :2 30 3c 3f 4f
52 53 :2 4f :2 26 :3 a :2 10 15 21
60 63 :2 21 :2 a 56 :3 7 :2 12 26
:2 2f 41 4c :2 7 35 :2 4 e 1b
c d 18 :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 53 56 57 :2 53 :2 29 :3 d
:2 13 18 24 63 66 :2 24 73 76
:2 24 7a 7d :2 24 89 8c :2 24 94
97 :2 24 a3 a6 ad b6 b9 :2 a6
:2 24 :2 d 5a :2 a :2 7 :4 13 :2 7 4
:3 1 8 :2 11 1d 1a :2 26 :2 1a 7
3e 4c a 15 :2 4c :2 3e 3d 1a
1d :2 1a :3 39 :2 7 a :2 14 26 :2 30
3c 40 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 60 63 :2 21 70 73
:2 21 77 7a :2 21 84 87 90 98
:2 a1 :2 90 ac :2 87 :2 21 b4 b7 :2 21
bf c2 :2 21 c7 ca :2 21 d1 d4
:2 21 :2 a 57 :2 7 a :2 14 26 :2 30
3c 3f 4f 52 53 :2 4f :2 26 :3 a
:2 10 15 21 60 63 :2 21 :2 a 56
:3 7 :2 12 26 :2 2f 39 41 :2 7 1f
:3 4 :3 12 4 13 1c 27 32 3a
47 55 5e 66 e 1a 22 2d
37 44 50 5b 7 e a 16
:3 14 a :2 13 1f a 1b a :2 13
1f a :4 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 53 56
57 :2 53 :2 29 :3 d :2 13 18 24 63
66 :2 24 73 76 :2 24 7a 7d :2 24
89 8c :2 24 94 97 :2 24 a3 a6
ad b6 b9 :2 a6 :2 24 :2 d 5a :2 a
:2 7 :4 13 :2 7 4 :3 1 8 :2 11 1c
1a :2 25 :2 1a :2 7 13 1a 23 2a
:2 23 38 :2 1a 3b 3d :2 1a 19 40
42 :2 19 :2 13 7 a 13 15 :2 13
a 15 :2 a 10 19 22 :2 10 27
25 30 :2 25 a d 1a :2 23 2c
30 34 3d 46 :2 34 49 4b :2 34
4d 4e :2 34 51 :2 1a d 1c 17
23 2f 45 10 1f 33 3b 15
2c 39 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5c 5f 60 :2 5c
:2 32 :3 16 :2 1c 21 2d 6c 6f :2 2d
7c 7f :2 2d 83 86 :2 2d 92 95
:2 2d 9d a0 :2 2d ac af b6 bf
c2 :2 af :2 2d :2 16 63 :2 13 :2 10 :4 1c
:2 10 d :3 30 d 18 21 2a :2 18
2d 2f :2 18 d 30 e a 17
:2 7 :4 b :2 a 19 :2 a 19 20 29
30 :2 29 3e :2 20 41 43 :2 20 1f
46 48 :2 1f :2 19 a d 19 1b
:2 19 d 18 :2 d 13 1c 25 :2 13
2a 28 36 :2 28 d 10 1d :2 26
2f 33 37 40 49 :2 37 4c 4e
:2 37 50 51 :2 37 54 :2 1d 10 1f
1a 26 31 47 13 28 3c 44
18 2f 3c 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 5f 62 63
:2 5f :2 35 :3 19 :2 1f 24 30 6f 72
:2 30 7f 82 :2 30 86 89 :2 30 95
98 :2 30 a0 a3 :2 30 af b2 b9
c2 c5 :2 b2 :2 30 :2 19 66 :2 16 :2 13
:4 1f :2 13 10 :3 36 10 1b 24 2d
:2 1b 30 32 :2 1b 10 36 11 d
1d :2 a 23 :2 7 35 :2 4 7 :2 11
23 :2 2d 39 3c 4c 4f 50 :2 4c
:2 23 :3 7 :2 d 12 1e 5d 60 :2 1e
6d 70 :2 1e 74 77 :2 1e 81 84
8d 95 :2 9e :2 8d a9 :2 84 :2 1e b1
b4 :2 1e bc bf :2 1e c4 c7 :2 1e
d2 d5 :2 1e :2 7 53 :3 4 :2 f 21
:2 2a 34 40 :2 4 1 9 12 9
a :2 14 26 :2 30 3c 40 50 53
54 :2 50 :2 26 :3 a :2 10 15 21 60
63 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 57 :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 4d 50
51 :2 4d :2 23 :3 7 :2 d 12 1e 5d
60 :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 54 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
874
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 2 :4 a :2 1
:7 c :7 d :7 e :7 f
:6 10 :6 11 :6 12 :5 13
:5 14 :2 16 0 :2 16
:2 17 :5 18 17 :5 16
:7 1a :b 1c :11 1d 1e
:2 1d :2 1e :2 1d :2 1e
:2 1d :2 1f :2 1d :2 1f
:2 1d :2 1f :2 1d :2 1f
:2 1d :2 20 :2 1d :2 20
:2 1d :2 20 :2 1d :2 20
:2 1d :2 21 :2 1d :2 21
:2 1d :2 21 :2 1d :2 21
:2 1d :2 22 :2 1d :2 22
:2 1d :2 22 :2 1d :2 22
:2 1d :2 23 :2 1d :2 23
:2 1d :2 23 :2 1d :2 23
:2 1d :2 24 :2 1d :2 24
:2 1d :2 24 :2 1d :2 24
:2 1d :2 24 :4 1d :3 1c
:11 27 :b 28 :3 27 :e 2d
:11 2e :20 2f :3 2e :11 31
:b 32 :3 31 :9 34 :3 2d
:3 38 :d 3b :5 3d :3 3e
:c 40 :5 48 :4 4a :3 4b
:5 4c 4b :5 4e 4d
:3 4b :a 51 :4 53 :5 54
52 56 :5 57 :3 56
:2 58 :5 5a :11 5b :24 5c
:3 5b :2 59 :6 58 55
:3 51 :11 60 :30 61 :3 60
:11 63 :b 64 :3 63 :a 66
51 :4 69 :5 6a 68
6c :5 6d :3 6c :2 6e
:5 70 :11 71 :24 72 :3 71
:2 6f :6 6e 6b :4 67
:3 51 :3 40 :3 3d :4 7b
7c :4 7d 7b :5 7e
7a 80 :5 81 :3 80
:2 82 :5 84 :11 85 :24 86
:3 85 :2 83 :6 82 7f
:3 1b :13 8c :5 8d :7 8e
8c :5 8f 8b 91
:5 92 :3 91 :2 93 :5 95
:11 96 :24 97 :3 96 :2 94
:6 93 90 :3 1b :a 9c
:11 9d :30 9e :3 9d :11 a0
:b a1 :3 a0 :a a3 :3 9c
:2 a7 a8 :2 a9 a7
:5 aa a6 ac :5 ad
:3 ac :2 ae :5 b0 :11 b1
:24 b2 :3 b1 :2 af :6 ae
ab :3 1b :c b7 :2 b8
:5 b7 :4 b8 :5 b7 :11 b9
:30 ba :3 b9 :11 bc :b bd
:3 bc :a bf b8 :2 b7
:5 c3 :9 c6 :8 c7 c6
:6 c8 :5 c9 c8 :5 cb
ca :3 c8 c5 ce
:5 cf :3 ce :2 d0 :5 d2
:11 d3 :24 d4 :3 d3 :2 d1
:6 d0 cd :3 1b :a d9
:16 db :5 dc :3 dd :c de
:17 e2 e5 :4 e6 :4 e7
:3 e8 e5 :6 e9 :5 ea
e9 :5 ec eb :3 e9
e4 ef :5 f0 :3 ef
:2 f1 :5 f3 :11 f4 :24 f5
:3 f4 :2 f2 :6 f1 ee
:3 de :b f9 de fa
de :3 dc :5 fe :3 100
:16 101 :5 103 :3 104 :c 105
:17 109 10c :4 10d :4 10e
:3 10f 10c :6 110 :5 111
110 :5 113 112 :3 110
10b 116 :5 117 :3 116
:2 118 :5 11a :11 11b :24 11c
:3 11b :2 119 :6 118 115
:3 105 :b 121 105 122
105 :3 103 :3 fe :3 d9
:11 127 :30 128 :3 127 :a 12a
1b :3 12d :11 12e :b 12f
:17 130 :3 12e :2 132 :3 133
:3 134 135 133 132
133 :3 136 :3 12d :2 137
:5 139 :11 13a :b 13b :18 13c
:3 13a :2 13e 13f :3 140
141 13f 13e 13f
:3 142 :2 138 :6 137 12c
:7 1 
1d89
4
:3 0 1 :3 0 2
:a 0 86f 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 7
:7 0 11 10 :3 0
4 :3 0 8 :7 0
15 14 :3 0 11
:2 0 f 4 :3 0
9 :7 0 19 18
:3 0 4 :3 0 a
:7 0 1d 1c :3 0
b :3 0 c :3 0
d :2 0 4 21
22 0 1f 23
0 86f 2 24
:2 0 11 :2 0 1b
4 :3 0 f :2 0
19 27 29 :6 0
2c 2a 0 86d
0 e :6 0 f
:2 0 1f 4 :3 0
1d 2e 30 :6 0
33 31 0 86d
0 10 :6 0 14
:2 0 23 4 :3 0
21 35 37 :6 0
3a 38 0 86d
0 12 :6 0 17
:2 0 27 4 :3 0
25 3c 3e :6 0
41 3f 0 86d
0 13 :6 0 17
:2 0 29 16 :3 0
43 :7 0 47 44
45 86d 0 15
:6 0 17 :2 0 2b
16 :3 0 49 :7 0
4d 4a 4b 86d
0 18 :6 0 2f
184 0 2d 16
:3 0 4f :7 0 53
50 51 86d 0
19 :9 0 31 16
:3 0 55 :7 0 58
56 0 86d 0
1a :6 0 16 :3 0
5a :7 0 5d 5b
0 86d 0 1b
:6 0 1c :3 0 1d
:a 0 2 6b :4 0
5f 62 0 60
:3 0 1e :3 0 1f
:3 0 20 :3 0 21
:3 0 3 :3 0 22
:3 0 12 :4 0 23
1 :8 0 6c 5f
62 6d 0 86d
33 6d 6f 6c
6e :6 0 6b :7 0
6d 77 78 0
35 c :3 0 d
:2 0 4 71 72
0 73 :7 0 76
74 0 86d 0
24 :6 0 25 :3 0
26 :3 0 25 :3 0
27 :3 0 7a 7b
0 2 :4 0 37
7c 7e 79 80
7f :2 0 28 :3 0
29 :3 0 82 83
0 2a :4 0 25
:3 0 2b :3 0 86
87 0 2 :4 0
39 88 8a 2c
:4 0 2d :2 0 2e
:3 0 3b 8d 8f
:3 0 2f :4 0 2d
:2 0 30 :4 0 3e
92 94 :3 0 2d
:2 0 3 :3 0 41
96 98 :3 0 2d
:2 0 30 :4 0 44
9a 9c :3 0 2d
:2 0 31 :4 0 47
9e a0 :3 0 2d
:2 0 30 :4 0 4a
a2 a4 :3 0 2d
:2 0 5 :3 0 4d
a6 a8 :3 0 2d
:2 0 30 :4 0 50
aa ac :3 0 2d
:2 0 31 :4 0 53
ae b0 :3 0 2d
:2 0 30 :4 0 56
b2 b4 :3 0 2d
:2 0 6 :3 0 59
b6 b8 :3 0 2d
:2 0 30 :4 0 5c
ba bc :3 0 2d
:2 0 31 :4 0 5f
be c0 :3 0 2d
:2 0 30 :4 0 62
c2 c4 :3 0 2d
:2 0 7 :3 0 65
c6 c8 :3 0 2d
:2 0 30 :4 0 68
ca cc :3 0 2d
:2 0 31 :4 0 6b
ce d0 :3 0 2d
:2 0 30 :4 0 6e
d2 d4 :3 0 2d
:2 0 8 :3 0 71
d6 d8 :3 0 2d
:2 0 30 :4 0 74
da dc :3 0 2d
:2 0 31 :4 0 77
de e0 :3 0 2d
:2 0 30 :4 0 7a
e2 e4 :3 0 2d
:2 0 9 :3 0 7d
e6 e8 :3 0 2d
:2 0 30 :4 0 80
ea ec :3 0 2d
:2 0 31 :4 0 83
ee f0 :3 0 2d
:2 0 30 :4 0 86
f2 f4 :3 0 2d
:2 0 a :3 0 89
f6 f8 :3 0 2d
:2 0 30 :4 0 8c
fa fc :3 0 2d
:2 0 32 :4 0 8f
fe 100 :3 0 92
84 102 :2 0 104
97 105 81 104
0 106 99 0
7cd 25 :3 0 26
:3 0 107 108 0
25 :3 0 33 :3 0
10a 10b 0 34
:2 0 2 :4 0 35
:2 0 36 :2 0 34
:2 0 9b 110 112
:3 0 9e 10c 114
109 116 115 :2 0
28 :3 0 37 :3 0
118 119 0 2a
:4 0 38 :4 0 2d
:2 0 2e :3 0 a2
11d 11f :3 0 a5
11a 121 :2 0 123
a8 124 117 123
0 125 aa 0
7cd 3 :3 0 39
:2 0 ac 127 128
:3 0 129 :2 0 12a
:2 0 5 :3 0 39
:2 0 ae 12d 12e
:3 0 12f :2 0 130
:2 0 12b 132 131
:2 0 25 :3 0 26
:3 0 134 135 0
25 :3 0 33 :3 0
137 138 0 3a
:2 0 2 :4 0 3b
:2 0 36 :2 0 34
:2 0 b0 13d 13f
:3 0 b3 139 141
136 143 142 :2 0
28 :3 0 37 :3 0
145 146 0 2a
:4 0 3c :4 0 2d
:2 0 2e :3 0 b7
14a 14c :3 0 2d
:2 0 3d :4 0 ba
14e 150 :3 0 2d
:2 0 3e :4 0 bd
152 154 :3 0 2d
:2 0 3f :3 0 40
:3 0 41 :3 0 42
:3 0 159 15a 0
c0 158 15c 43
:4 0 c2 157 15f
c5 156 161 :3 0
c8 147 163 :2 0
165 cb 166 144
165 0 167 cd
0 190 25 :3 0
26 :3 0 168 169
0 25 :3 0 33
:3 0 16b 16c 0
34 :2 0 2 :4 0
44 :2 0 36 :2 0
34 :2 0 cf 171
173 :3 0 d2 16d
175 16a 177 176
:2 0 28 :3 0 37
:3 0 179 17a 0
2a :4 0 45 :4 0
2d :2 0 2e :3 0
d6 17e 180 :3 0
d9 17b 182 :2 0
184 dc 185 178
184 0 186 de
0 190 46 :3 0
47 :3 0 187 188
0 41 :3 0 42
:3 0 18a 18b 0
48 :3 0 e0 189
18e :2 0 190 e3
191 133 190 0
192 e7 0 7cd
10 :3 0 5 :3 0
193 194 0 7cd
12 :3 0 49 :3 0
49 :3 0 10 :3 0
34 :2 0 f :2 0
e9 198 19c 34
:2 0 f :2 0 ed
197 1a0 196 1a1
0 7cd 9 :3 0
4a :2 0 f1 1a4
1a5 :3 0 1a6 :2 0
e :3 0 9 :3 0
1a8 1a9 0 30d
4b :3 0 4c :3 0
1ab 1ac 0 e
:3 0 4d :4 0 4e
:2 0 f3 1ad 1b1
4f :2 0 17 :2 0
f9 1b3 1b5 :3 0
50 :3 0 1d :4 0
1ba :2 0 30a 1b8
1bb :3 0 1d :3 0
e :4 0 1bf :2 0
30a 1bc 1bd :3 0
1d :3 0 51 :3 0
1c0 1c1 :3 0 c
:3 0 52 :3 0 1c3
1c4 0 17 :2 0
1c5 1c6 0 1c8
fc 1cf c :3 0
52 :3 0 1c9 1ca
0 53 :2 0 1cb
1cc 0 1ce fe
1d0 1c2 1c8 0
1d1 0 1ce 0
1d1 100 0 30a
c :3 0 52 :3 0
1d2 1d3 0 c
:3 0 4f :2 0 54
:3 0 1d5 1d7 0
105 1d6 1d9 :3 0
1da :2 0 55 :3 0
1d :4 0 1df :2 0
1e5 1dd 0 c
:3 0 52 :3 0 1e0
1e1 0 56 :3 0
1e2 1e3 0 1e5
108 238 57 :3 0
c :3 0 52 :3 0
1e7 1e8 0 56
:3 0 1e9 1ea 0
1ec 10b 1ee 10d
1ed 1ec :2 0 236
58 :3 0 c :3 0
52 :3 0 1f1 1f2
0 56 :3 0 1f3
1f4 0 22e 25
:3 0 26 :3 0 1f6
1f7 0 25 :3 0
33 :3 0 1f9 1fa
0 59 :2 0 2
:4 0 5a :2 0 36
:2 0 34 :2 0 10f
1ff 201 :3 0 112
1fb 203 1f8 205
204 :2 0 28 :3 0
37 :3 0 207 208
0 2a :4 0 5b
:4 0 2d :2 0 2e
:3 0 116 20c 20e
:3 0 2d :2 0 3d
:4 0 119 210 212
:3 0 2d :2 0 5c
:4 0 11c 214 216
:3 0 2d :2 0 56
:3 0 11f 218 21a
:3 0 2d :2 0 5d
:4 0 122 21c 21e
:3 0 2d :2 0 49
:3 0 5e :3 0 34
:2 0 5f :2 0 125
221 225 129 220
227 :3 0 12c 209
229 :2 0 22b 12f
22c 206 22b 0
22d 131 0 22e
133 231 :3 0 231
0 231 230 22e
22f :6 0 233 3
:3 0 136 235 138
234 233 :2 0 236
13a :2 0 238 0
238 237 1e5 236
:6 0 2a7 1 :3 0
25 :3 0 26 :3 0
23a 23b 0 25
:3 0 33 :3 0 23d
23e 0 f :2 0
2 :4 0 60 :2 0
36 :2 0 34 :2 0
13d 243 245 :3 0
140 23f 247 23c
249 248 :2 0 28
:3 0 37 :3 0 24b
24c 0 2a :4 0
61 :4 0 2d :2 0
2e :3 0 144 250
252 :3 0 2d :2 0
3d :4 0 147 254
256 :3 0 2d :2 0
3e :4 0 14a 258
25a :3 0 2d :2 0
3f :3 0 40 :3 0
c :3 0 52 :3 0
25f 260 0 14d
25e 262 43 :4 0
14f 25d 265 152
25c 267 :3 0 2d
:2 0 62 :4 0 155
269 26b :3 0 2d
:2 0 30 :4 0 158
26d 26f :3 0 2d
:2 0 e :3 0 15b
271 273 :3 0 2d
:2 0 30 :4 0 15e
275 277 :3 0 161
24d 279 :2 0 27b
164 27c 24a 27b
0 27d 166 0
2a7 25 :3 0 26
:3 0 27e 27f 0
25 :3 0 33 :3 0
281 282 0 34
:2 0 2 :4 0 63
:2 0 36 :2 0 34
:2 0 168 287 289
:3 0 16b 283 28b
280 28d 28c :2 0
28 :3 0 37 :3 0
28f 290 0 2a
:4 0 64 :4 0 2d
:2 0 2e :3 0 16f
294 296 :3 0 172
291 298 :2 0 29a
175 29b 28e 29a
0 29c 177 0
2a7 46 :3 0 65
:3 0 29d 29e 0
c :3 0 52 :3 0
2a0 2a1 0 e
:3 0 48 :3 0 179
29f 2a5 :2 0 2a7
17d 307 55 :3 0
1d :4 0 2ab :2 0
2b1 2a9 0 c
:3 0 52 :3 0 2ac
2ad 0 56 :3 0
2ae 2af 0 2b1
182 304 57 :3 0
c :3 0 52 :3 0
2b3 2b4 0 56
:3 0 2b5 2b6 0
2b8 185 2ba 187
2b9 2b8 :2 0 302
58 :3 0 c :3 0
52 :3 0 2bd 2be
0 56 :3 0 2bf
2c0 0 2fa 25
:3 0 26 :3 0 2c2
2c3 0 25 :3 0
33 :3 0 2c5 2c6
0 59 :2 0 2
:4 0 66 :2 0 36
:2 0 34 :2 0 189
2cb 2cd :3 0 18c
2c7 2cf 2c4 2d1
2d0 :2 0 28 :3 0
37 :3 0 2d3 2d4
0 2a :4 0 67
:4 0 2d :2 0 2e
:3 0 190 2d8 2da
:3 0 2d :2 0 3d
:4 0 193 2dc 2de
:3 0 2d :2 0 5c
:4 0 196 2e0 2e2
:3 0 2d :2 0 56
:3 0 199 2e4 2e6
:3 0 2d :2 0 5d
:4 0 19c 2e8 2ea
:3 0 2d :2 0 49
:3 0 5e :3 0 34
:2 0 5f :2 0 19f
2ed 2f1 1a3 2ec
2f3 :3 0 1a6 2d5
2f5 :2 0 2f7 1a9
2f8 2d2 2f7 0
2f9 1ab 0 2fa
1ad 2fd :3 0 2fd
0 2fd 2fc 2fa
2fb :6 0 2ff 5
:3 0 1b0 301 1b2
300 2ff :2 0 302
1b4 :2 0 304 0
304 303 2b1 302
:6 0 306 1 :3 0
1b7 308 1db 2a7
0 309 0 306
0 309 1b9 0
30a 1bc 30b 1b6
30a 0 30c 1c1
0 30d 1c3 30e
1a7 30d 0 30f
1c6 0 7cd 3f
:3 0 68 :3 0 69
:3 0 18 :3 0 1f
:3 0 21 :3 0 3
:3 0 22 :3 0 12
:4 0 6a 1 :8 0
31f c :3 0 52
:3 0 31a 31b 0
56 :3 0 31c 31d
0 31f 1c8 372
57 :3 0 c :3 0
52 :3 0 321 322
0 56 :3 0 323
324 0 326 1cb
328 1cd 327 326
:2 0 370 58 :3 0
c :3 0 52 :3 0
32b 32c 0 56
:3 0 32d 32e 0
368 25 :3 0 26
:3 0 330 331 0
25 :3 0 33 :3 0
333 334 0 59
:2 0 2 :4 0 6b
:2 0 36 :2 0 34
:2 0 1cf 339 33b
:3 0 1d2 335 33d
332 33f 33e :2 0
28 :3 0 37 :3 0
341 342 0 2a
:4 0 6c :4 0 2d
:2 0 2e :3 0 1d6
346 348 :3 0 2d
:2 0 3d :4 0 1d9
34a 34c :3 0 2d
:2 0 5c :4 0 1dc
34e 350 :3 0 2d
:2 0 56 :3 0 1df
352 354 :3 0 2d
:2 0 5d :4 0 1e2
356 358 :3 0 2d
:2 0 49 :3 0 5e
:3 0 34 :2 0 5f
:2 0 1e5 35b 35f
1e9 35a 361 :3 0
1ec 343 363 :2 0
365 1ef 366 340
365 0 367 1f1
0 368 1f3 36b
:3 0 36b 0 36b
36a 368 369 :6 0
36d 7 :3 0 1f6
36f 1f8 36e 36d
:2 0 370 1fa :2 0
372 0 372 371
31f 370 :6 0 7cd
1 :3 0 4b :3 0
6d :3 0 4b :3 0
6d :3 0 4b :3 0
6d :3 0 4b :3 0
6d :3 0 4b :3 0
6d :3 0 6e :3 0
6f :3 0 70 :3 0
6e :3 0 71 :3 0
70 :3 0 6e :3 0
40 :3 0 18 :3 0
13 :3 0 72 :3 0
71 :3 0 72 :3 0
6f :3 0 71 :3 0
73 :3 0 12 :3 0
6f :3 0 73 :3 0
71 :3 0 74 :4 0
75 1 :8 0 399
c :3 0 52 :3 0
394 395 0 56
:3 0 396 397 0
399 1fd 3ec 57
:3 0 c :3 0 52
:3 0 39b 39c 0
56 :3 0 39d 39e
0 3a0 200 3a2
202 3a1 3a0 :2 0
3ea 58 :3 0 c
:3 0 52 :3 0 3a5
3a6 0 56 :3 0
3a7 3a8 0 3e2
25 :3 0 26 :3 0
3aa 3ab 0 25
:3 0 33 :3 0 3ad
3ae 0 59 :2 0
2 :4 0 76 :2 0
36 :2 0 34 :2 0
204 3b3 3b5 :3 0
207 3af 3b7 3ac
3b9 3b8 :2 0 28
:3 0 37 :3 0 3bb
3bc 0 2a :4 0
77 :4 0 2d :2 0
2e :3 0 20b 3c0
3c2 :3 0 2d :2 0
3d :4 0 20e 3c4
3c6 :3 0 2d :2 0
5c :4 0 211 3c8
3ca :3 0 2d :2 0
56 :3 0 214 3cc
3ce :3 0 2d :2 0
5d :4 0 217 3d0
3d2 :3 0 2d :2 0
49 :3 0 5e :3 0
34 :2 0 5f :2 0
21a 3d5 3d9 21e
3d4 3db :3 0 221
3bd 3dd :2 0 3df
224 3e0 3ba 3df
0 3e1 226 0
3e2 228 3e5 :3 0
3e5 0 3e5 3e4
3e2 3e3 :6 0 3e7
9 :3 0 22b 3e9
22d 3e8 3e7 :2 0
3ea 22f :2 0 3ec
0 3ec 3eb 399
3ea :6 0 7cd 1
:3 0 c :3 0 52
:3 0 3ee 3ef 0
c :3 0 4f :2 0
78 :3 0 3f1 3f3
0 234 3f2 3f5
:3 0 3f6 :2 0 25
:3 0 26 :3 0 3f8
3f9 0 25 :3 0
33 :3 0 3fb 3fc
0 f :2 0 2
:4 0 79 :2 0 36
:2 0 34 :2 0 237
401 403 :3 0 23a
3fd 405 3fa 407
406 :2 0 28 :3 0
37 :3 0 409 40a
0 2a :4 0 7a
:4 0 2d :2 0 2e
:3 0 23e 40e 410
:3 0 2d :2 0 3d
:4 0 241 412 414
:3 0 2d :2 0 3e
:4 0 244 416 418
:3 0 2d :2 0 3f
:3 0 40 :3 0 41
:3 0 7b :3 0 41d
41e 0 247 41c
420 43 :4 0 249
41b 423 24c 41a
425 :3 0 2d :2 0
62 :4 0 24f 427
429 :3 0 2d :2 0
30 :4 0 252 42b
42d :3 0 2d :2 0
12 :3 0 255 42f
431 :3 0 2d :2 0
30 :4 0 258 433
435 :3 0 25b 40b
437 :2 0 439 25e
43a 408 439 0
43b 260 0 465
25 :3 0 26 :3 0
43c 43d 0 25
:3 0 33 :3 0 43f
440 0 34 :2 0
2 :4 0 7c :2 0
36 :2 0 34 :2 0
262 445 447 :3 0
265 441 449 43e
44b 44a :2 0 28
:3 0 37 :3 0 44d
44e 0 2a :4 0
7d :4 0 2d :2 0
2e :3 0 269 452
454 :3 0 26c 44f
456 :2 0 458 26f
459 44c 458 0
45a 271 0 465
46 :3 0 65 :3 0
45b 45c 0 41
:3 0 7b :3 0 45e
45f 0 12 :3 0
48 :3 0 273 45d
463 :2 0 465 277
466 3f7 465 0
467 27b 0 7cd
7e :3 0 19 :3 0
7f :3 0 73 :3 0
3 :4 0 80 1
:8 0 473 c :3 0
52 :3 0 46e 46f
0 56 :3 0 470
471 0 473 27d
4c6 57 :3 0 c
:3 0 52 :3 0 475
476 0 56 :3 0
477 478 0 47a
280 47c 282 47b
47a :2 0 4c4 58
:3 0 c :3 0 52
:3 0 47f 480 0
56 :3 0 481 482
0 4bc 25 :3 0
26 :3 0 484 485
0 25 :3 0 33
:3 0 487 488 0
59 :2 0 2 :4 0
81 :2 0 36 :2 0
34 :2 0 284 48d
48f :3 0 287 489
491 486 493 492
:2 0 28 :3 0 37
:3 0 495 496 0
2a :4 0 82 :4 0
2d :2 0 2e :3 0
28b 49a 49c :3 0
2d :2 0 3d :4 0
28e 49e 4a0 :3 0
2d :2 0 5c :4 0
291 4a2 4a4 :3 0
2d :2 0 56 :3 0
294 4a6 4a8 :3 0
2d :2 0 5d :4 0
297 4aa 4ac :3 0
2d :2 0 49 :3 0
5e :3 0 34 :2 0
5f :2 0 29a 4af
4b3 29e 4ae 4b5
:3 0 2a1 497 4b7
:2 0 4b9 2a4 4ba
494 4b9 0 4bb
2a6 0 4bc 2a8
4bf :3 0 4bf 0
4bf 4be 4bc 4bd
:6 0 4c1 b :3 0
2ab 4c3 2ad 4c2
4c1 :2 0 4c4 2af
:2 0 4c6 0 4c6
4c5 473 4c4 :6 0
7cd 1 :3 0 c
:3 0 52 :3 0 4c8
4c9 0 c :3 0
83 :2 0 54 :3 0
4cb 4cd 0 2b4
4cc 4cf :3 0 4d0
:2 0 84 :3 0 3f
:3 0 19 :3 0 17
:2 0 2b7 4d3 4d6
2ba 4d2 4d8 4d9
:2 0 83 :2 0 17
:2 0 2be 4db 4dd
:3 0 85 :2 0 2c1
4df 4e0 :3 0 4d1
4e2 4e1 :2 0 25
:3 0 26 :3 0 4e4
4e5 0 25 :3 0
33 :3 0 4e7 4e8
0 f :2 0 2
:4 0 86 :2 0 36
:2 0 34 :2 0 2c3
4ed 4ef :3 0 2c6
4e9 4f1 4e6 4f3
4f2 :2 0 28 :3 0
37 :3 0 4f5 4f6
0 2a :4 0 87
:4 0 2d :2 0 2e
:3 0 2ca 4fa 4fc
:3 0 2d :2 0 3d
:4 0 2cd 4fe 500
:3 0 2d :2 0 3e
:4 0 2d0 502 504
:3 0 2d :2 0 3f
:3 0 40 :3 0 c
:3 0 52 :3 0 509
50a 0 2d3 508
50c 43 :4 0 2d5
507 50f 2d8 506
511 :3 0 2d :2 0
62 :4 0 2db 513
515 :3 0 2d :2 0
30 :4 0 2de 517
519 :3 0 2d :2 0
3 :3 0 2e1 51b
51d :3 0 2d :2 0
30 :4 0 2e4 51f
521 :3 0 2e7 4f7
523 :2 0 525 2ea
526 4f4 525 0
527 2ec 0 551
25 :3 0 26 :3 0
528 529 0 25
:3 0 33 :3 0 52b
52c 0 34 :2 0
2 :4 0 88 :2 0
36 :2 0 34 :2 0
2ee 531 533 :3 0
2f1 52d 535 52a
537 536 :2 0 28
:3 0 37 :3 0 539
53a 0 2a :4 0
89 :4 0 2d :2 0
2e :3 0 2f5 53e
540 :3 0 2f8 53b
542 :2 0 544 2fb
545 538 544 0
546 2fd 0 551
46 :3 0 65 :3 0
547 548 0 c
:3 0 52 :3 0 54a
54b 0 3 :3 0
48 :3 0 2ff 549
54f :2 0 551 303
552 4e3 551 0
553 307 0 7cd
e :3 0 8a :4 0
555 556 :3 0 554
557 0 7cd 1f
:3 0 1e :3 0 21
:3 0 22 :3 0 69
:3 0 8b :3 0 8c
:3 0 8d :3 0 8e
:3 0 e :3 0 3
:3 0 12 :3 0 18
:3 0 13 :3 0 9
:3 0 8 :3 0 7
:4 0 8f 1 :8 0
580 51 :4 0 56b
:3 0 48 :3 0 4f
:2 0 30b 56e 56f
:3 0 c :3 0 52
:3 0 571 572 0
17 :2 0 573 574
0 576 30e 57d
c :3 0 52 :3 0
577 578 0 53
:2 0 579 57a 0
57c 310 57e 570
576 0 57f 0
57c 0 57f 312
0 580 315 5d3
57 :3 0 c :3 0
52 :3 0 582 583
0 56 :3 0 584
585 0 587 318
589 31a 588 587
:2 0 5d1 58 :3 0
c :3 0 52 :3 0
58c 58d 0 56
:3 0 58e 58f 0
5c9 25 :3 0 26
:3 0 591 592 0
25 :3 0 33 :3 0
594 595 0 59
:2 0 2 :4 0 90
:2 0 36 :2 0 34
:2 0 31c 59a 59c
:3 0 31f 596 59e
593 5a0 59f :2 0
28 :3 0 37 :3 0
5a2 5a3 0 2a
:4 0 91 :4 0 2d
:2 0 2e :3 0 323
5a7 5a9 :3 0 2d
:2 0 3d :4 0 326
5ab 5ad :3 0 2d
:2 0 5c :4 0 329
5af 5b1 :3 0 2d
:2 0 56 :3 0 32c
5b3 5b5 :3 0 2d
:2 0 5d :4 0 32f
5b7 5b9 :3 0 2d
:2 0 49 :3 0 5e
:3 0 34 :2 0 5f
:2 0 332 5bc 5c0
336 5bb 5c2 :3 0
339 5a4 5c4 :2 0
5c6 33c 5c7 5a1
5c6 0 5c8 33e
0 5c9 340 5cc
:3 0 5cc 0 5cc
5cb 5c9 5ca :6 0
5ce d :3 0 343
5d0 345 5cf 5ce
:2 0 5d1 347 :2 0
5d3 0 5d3 5d2
580 5d1 :6 0 7cd
1 :3 0 c :3 0
52 :3 0 5d5 5d6
0 c :3 0 4f
:2 0 54 :3 0 5d8
5da 0 34c 5d9
5dc :3 0 5dd :2 0
1a :3 0 92 :3 0
3f :3 0 93 :3 0
10 :3 0 34f 5e2
5e4 17 :2 0 351
5e1 5e7 36 :2 0
34 :2 0 354 5e9
5eb :3 0 5ec :2 0
94 :2 0 f :2 0
357 5ee 5f0 :3 0
35a 5e0 5f2 5df
5f3 0 77c 1a
:3 0 95 :2 0 34
:2 0 35e 5f6 5f8
:3 0 15 :3 0 34
:2 0 5fa 5fb 0
6a5 96 :3 0 3f
:3 0 15 :3 0 17
:2 0 361 5fe 601
1a :3 0 97 :2 0
98 :3 0 366 604
606 :3 0 607 6a4
12 :3 0 99 :3 0
9a :3 0 60a 60b
0 f :2 0 f
:2 0 3f :3 0 15
:3 0 17 :2 0 369
60f 612 9b :2 0
f :2 0 36c 614
616 :3 0 36 :2 0
34 :2 0 36f 618
61a :3 0 10 :3 0
372 60c 61d 609
61e 0 6a2 9c
:3 0 e :3 0 73
:3 0 9d :3 0 9e
:3 0 9f :3 0 a0
:3 0 40 :3 0 15
:3 0 72 :3 0 73
:3 0 12 :4 0 a1
1 :8 0 642 51
:4 0 62d :3 0 48
:3 0 4f :2 0 379
630 631 :3 0 c
:3 0 52 :3 0 633
634 0 17 :2 0
635 636 0 638
37c 63f c :3 0
52 :3 0 639 63a
0 53 :2 0 63b
63c 0 63e 37e
640 632 638 0
641 0 63e 0
641 380 0 642
383 695 57 :3 0
c :3 0 52 :3 0
644 645 0 56
:3 0 646 647 0
649 386 64b 388
64a 649 :2 0 693
58 :3 0 c :3 0
52 :3 0 64e 64f
0 56 :3 0 650
651 0 68b 25
:3 0 26 :3 0 653
654 0 25 :3 0
33 :3 0 656 657
0 59 :2 0 2
:4 0 a2 :2 0 36
:2 0 34 :2 0 38a
65c 65e :3 0 38d
658 660 655 662
661 :2 0 28 :3 0
37 :3 0 664 665
0 2a :4 0 a3
:4 0 2d :2 0 2e
:3 0 391 669 66b
:3 0 2d :2 0 3d
:4 0 394 66d 66f
:3 0 2d :2 0 5c
:4 0 397 671 673
:3 0 2d :2 0 56
:3 0 39a 675 677
:3 0 2d :2 0 5d
:4 0 39d 679 67b
:3 0 2d :2 0 49
:3 0 5e :3 0 34
:2 0 5f :2 0 3a0
67e 682 3a4 67d
684 :3 0 3a7 666
686 :2 0 688 3aa
689 663 688 0
68a 3ac 0 68b
3ae 68e :3 0 68e
0 68e 68d 68b
68c :6 0 690 10
:3 0 3b1 692 3b3
691 690 :2 0 693
3b5 :2 0 695 0
695 694 642 693
:6 0 6a2 f :3 0
15 :3 0 3f :3 0
15 :3 0 17 :2 0
3b8 698 69b 36
:2 0 34 :2 0 3bb
69d 69f :3 0 697
6a0 0 6a2 3be
6a4 98 :3 0 608
6a2 :4 0 6a5 3c2
6a6 5f9 6a5 0
6a7 3c5 0 77c
6 :3 0 4a :2 0
3c7 6a9 6aa :3 0
6ab :2 0 10 :3 0
6 :3 0 6ad 6ae
0 779 1b :3 0
92 :3 0 3f :3 0
93 :3 0 10 :3 0
3c9 6b3 6b5 17
:2 0 3cb 6b2 6b8
36 :2 0 34 :2 0
3ce 6ba 6bc :3 0
6bd :2 0 94 :2 0
f :2 0 3d1 6bf
6c1 :3 0 3d4 6b1
6c3 6b0 6c4 0
779 1b :3 0 95
:2 0 17 :2 0 3d8
6c7 6c9 :3 0 15
:3 0 17 :2 0 6cb
6cc 0 776 96
:3 0 3f :3 0 15
:3 0 17 :2 0 3db
6cf 6d2 1b :3 0
97 :2 0 98 :3 0
3e0 6d5 6d7 :3 0
6d8 775 12 :3 0
99 :3 0 9a :3 0
6db 6dc 0 f
:2 0 f :2 0 3f
:3 0 15 :3 0 17
:2 0 3e3 6e0 6e3
9b :2 0 f :2 0
3e6 6e5 6e7 :3 0
36 :2 0 34 :2 0
3e9 6e9 6eb :3 0
10 :3 0 3ec 6dd
6ee 6da 6ef 0
773 a4 :3 0 e
:3 0 12 :3 0 9d
:3 0 9f :3 0 9e
:3 0 a0 :3 0 40
:3 0 15 :3 0 72
:3 0 73 :3 0 12
:4 0 a5 1 :8 0
713 51 :4 0 6fe
:3 0 48 :3 0 4f
:2 0 3f3 701 702
:3 0 c :3 0 52
:3 0 704 705 0
17 :2 0 706 707
0 709 3f6 710
c :3 0 52 :3 0
70a 70b 0 53
:2 0 70c 70d 0
70f 3f8 711 703
709 0 712 0
70f 0 712 3fa
0 713 3fd 766
57 :3 0 c :3 0
52 :3 0 715 716
0 56 :3 0 717
718 0 71a 400
71c 402 71b 71a
:2 0 764 58 :3 0
c :3 0 52 :3 0
71f 720 0 56
:3 0 721 722 0
75c 25 :3 0 26
:3 0 724 725 0
25 :3 0 33 :3 0
727 728 0 59
:2 0 2 :4 0 a6
:2 0 36 :2 0 34
:2 0 404 72d 72f
:3 0 407 729 731
726 733 732 :2 0
28 :3 0 37 :3 0
735 736 0 2a
:4 0 a7 :4 0 2d
:2 0 2e :3 0 40b
73a 73c :3 0 2d
:2 0 3d :4 0 40e
73e 740 :3 0 2d
:2 0 5c :4 0 411
742 744 :3 0 2d
:2 0 56 :3 0 414
746 748 :3 0 2d
:2 0 5d :4 0 417
74a 74c :3 0 2d
:2 0 49 :3 0 5e
:3 0 34 :2 0 5f
:2 0 41a 74f 753
41e 74e 755 :3 0
421 737 757 :2 0
759 424 75a 734
759 0 75b 426
0 75c 428 75f
:3 0 75f 0 75f
75e 75c 75d :6 0
761 13 :3 0 42b
763 42d 762 761
:2 0 764 42f :2 0
766 0 766 765
713 764 :6 0 773
12 :3 0 15 :3 0
3f :3 0 15 :3 0
17 :2 0 432 769
76c 36 :2 0 34
:2 0 435 76e 770
:3 0 768 771 0
773 438 775 98
:3 0 6d9 773 :4 0
776 43c 777 6ca
776 0 778 43f
0 779 441 77a
6ac 779 0 77b
445 0 77c 447
77d 5de 77c 0
77e 44b 0 7cd
25 :3 0 26 :3 0
77f 780 0 25
:3 0 33 :3 0 782
783 0 a8 :2 0
2 :4 0 a9 :2 0
36 :2 0 34 :2 0
44d 788 78a :3 0
450 784 78c 781
78e 78d :2 0 28
:3 0 37 :3 0 790
791 0 2a :4 0
aa :4 0 2d :2 0
2e :3 0 454 795
797 :3 0 2d :2 0
3d :4 0 457 799
79b :3 0 2d :2 0
3e :4 0 45a 79d
79f :3 0 2d :2 0
3f :3 0 40 :3 0
c :3 0 52 :3 0
7a4 7a5 0 45d
7a3 7a7 43 :4 0
45f 7a2 7aa 462
7a1 7ac :3 0 2d
:2 0 62 :4 0 465
7ae 7b0 :3 0 2d
:2 0 30 :4 0 468
7b2 7b4 :3 0 2d
:2 0 e :3 0 46b
7b6 7b8 :3 0 2d
:2 0 30 :4 0 46e
7ba 7bc :3 0 471
792 7be :2 0 7c0
474 7c1 78f 7c0
0 7c2 476 0
7cd 46 :3 0 ab
:3 0 7c3 7c4 0
c :3 0 52 :3 0
7c6 7c7 0 e
:3 0 48 :3 0 478
7c5 7cb :2 0 7cd
47c 86e c :3 0
ac :2 0 4 7ce
7cf 0 25 :3 0
26 :3 0 7d1 7d2
0 25 :3 0 33
:3 0 7d4 7d5 0
59 :2 0 2 :4 0
ad :2 0 36 :2 0
34 :2 0 48d 7da
7dc :3 0 490 7d6
7de 7d3 7e0 7df
:2 0 28 :3 0 37
:3 0 7e2 7e3 0
2a :4 0 ae :4 0
2d :2 0 2e :3 0
494 7e7 7e9 :3 0
497 7e4 7eb :2 0
804 28 :3 0 37
:3 0 7ed 7ee 0
2a :4 0 af :4 0
2d :2 0 c :3 0
b0 :3 0 7f3 7f4
0 49a 7f2 7f6
:3 0 2d :2 0 62
:4 0 49d 7f8 7fa
:3 0 2d :2 0 c
:3 0 b1 :3 0 7fd
7fe 0 4a0 7fc
800 :3 0 4a3 7ef
802 :2 0 804 4a6
805 7e1 804 0
806 4a9 0 816
50 :3 0 24 :3 0
c :3 0 b0 :3 0
b2 :3 0 c :3 0
b1 :3 0 b3 :3 0
b4 :4 0 b5 1
:a 0 812 :2 0 816
808 810 :2 0 b
:3 0 24 :3 0 814
:2 0 816 4ab 818
4af 817 816 :2 0
86c 58 :3 0 c
:3 0 52 :3 0 81b
81c 0 56 :3 0
81d 81e 0 864
25 :3 0 26 :3 0
820 821 0 25
:3 0 33 :3 0 823
824 0 59 :2 0
2 :4 0 b6 :2 0
36 :2 0 34 :2 0
4b1 829 82b :3 0
4b4 825 82d 822
82f 82e :2 0 28
:3 0 37 :3 0 831
832 0 2a :4 0
b7 :4 0 2d :2 0
2e :3 0 4b8 836
838 :3 0 4bb 833
83a :2 0 854 28
:3 0 37 :3 0 83c
83d 0 2a :4 0
5c :4 0 2d :2 0
56 :3 0 4be 841
843 :3 0 2d :2 0
5d :4 0 4c1 845
847 :3 0 2d :2 0
49 :3 0 5e :3 0
34 :2 0 5f :2 0
4c4 84a 84e 4c8
849 850 :3 0 4cb
83e 852 :2 0 854
4ce 855 830 854
0 856 4d1 0
864 50 :3 0 24
:3 0 b2 :3 0 c
:3 0 b1 :3 0 b3
:3 0 b4 :4 0 b8
1 :a 0 860 :2 0
864 858 85e :2 0
b :3 0 24 :3 0
862 :2 0 864 4d3
867 :3 0 867 0
867 866 864 865
:6 0 869 1 :3 0
4d8 86b 4da 86a
869 :2 0 86c 4dc
:2 0 86e 4df 86e
86d 7cd 86c :6 0
86f :2 0 2 24
86e 872 :3 0 871
86f 873 :8 0 
4eb
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 7
6 a e 12
16 1a 1e 1
28 1 26 1
2f 1 2d 1
36 1 34 1
3d 1 3b 1
42 1 48 1
4e 1 54 1
59 1 6a 1
70 1 7d 1
89 2 8c 8e
2 91 93 2
95 97 2 99
9b 2 9d 9f
2 a1 a3 2
a5 a7 2 a9
ab 2 ad af
2 b1 b3 2
b5 b7 2 b9
bb 2 bd bf
2 c1 c3 2
c5 c7 2 c9
cb 2 cd cf
2 d1 d3 2
d5 d7 2 d9
db 2 dd df
2 e1 e3 2
e5 e7 2 e9
eb 2 ed ef
2 f1 f3 2
f5 f7 2 f9
fb 2 fd ff
4 85 8b 90
101 1 103 1
105 2 10f 111
3 10d 10e 113
2 11c 11e 2
11b 120 1 122
1 124 1 126
1 12c 2 13c
13e 3 13a 13b
140 2 149 14b
2 14d 14f 2
151 153 1 15b
2 15d 15e 2
155 160 2 148
162 1 164 1
166 2 170 172
3 16e 16f 174
2 17d 17f 2
17c 181 1 183
1 185 2 18c
18d 3 167 186
18f 1 191 3
199 19a 19b 3
19d 19e 19f 1
1a3 3 1ae 1af
1b0 1 1b4 2
1b2 1b4 1 1c7
1 1cd 2 1cf
1d0 1 1d8 2
1d4 1d8 2 1de
1e4 1 1eb 1
1e6 2 1fe 200
3 1fc 1fd 202
2 20b 20d 2
20f 211 2 213
215 2 217 219
2 21b 21d 3
222 223 224 2
21f 226 2 20a
228 1 22a 1
22c 2 1f5 22d
1 231 1 1f0
2 1ee 235 2
242 244 3 240
241 246 2 24f
251 2 253 255
2 257 259 1
261 2 263 264
2 25b 266 2
268 26a 2 26c
26e 2 270 272
2 274 276 2
24e 278 1 27a
1 27c 2 286
288 3 284 285
28a 2 293 295
2 292 297 1
299 1 29b 3
2a2 2a3 2a4 4
238 27d 29c 2a6
2 2aa 2b0 1
2b7 1 2b2 2
2ca 2cc 3 2c8
2c9 2ce 2 2d7
2d9 2 2db 2dd
2 2df 2e1 2
2e3 2e5 2 2e7
2e9 3 2ee 2ef
2f0 2 2eb 2f2
2 2d6 2f4 1
2f6 1 2f8 2
2c1 2f9 1 2fd
1 2bc 2 2ba
301 1 304 2
307 308 4 1b9
1be 1d1 309 1
30b 2 1aa 30c
1 30e 2 319
31e 1 325 1
320 2 338 33a
3 336 337 33c
2 345 347 2
349 34b 2 34d
34f 2 351 353
2 355 357 3
35c 35d 35e 2
359 360 2 344
362 1 364 1
366 2 32f 367
1 36b 1 32a
2 328 36f 2
393 398 1 39f
1 39a 2 3b2
3b4 3 3b0 3b1
3b6 2 3bf 3c1
2 3c3 3c5 2
3c7 3c9 2 3cb
3cd 2 3cf 3d1
3 3d6 3d7 3d8
2 3d3 3da 2
3be 3dc 1 3de
1 3e0 2 3a9
3e1 1 3e5 1
3a4 2 3a2 3e9
1 3f4 2 3f0
3f4 2 400 402
3 3fe 3ff 404
2 40d 40f 2
411 413 2 415
417 1 41f 2
421 422 2 419
424 2 426 428
2 42a 42c 2
42e 430 2 432
434 2 40c 436
1 438 1 43a
2 444 446 3
442 443 448 2
451 453 2 450
455 1 457 1
459 3 460 461
462 3 43b 45a
464 1 466 2
46d 472 1 479
1 474 2 48c
48e 3 48a 48b
490 2 499 49b
2 49d 49f 2
4a1 4a3 2 4a5
4a7 2 4a9 4ab
3 4b0 4b1 4b2
2 4ad 4b4 2
498 4b6 1 4b8
1 4ba 2 483
4bb 1 4bf 1
47e 2 47c 4c3
1 4ce 2 4ca
4ce 2 4d4 4d5
1 4d7 1 4dc
2 4da 4dc 1
4de 2 4ec 4ee
3 4ea 4eb 4f0
2 4f9 4fb 2
4fd 4ff 2 501
503 1 50b 2
50d 50e 2 505
510 2 512 514
2 516 518 2
51a 51c 2 51e
520 2 4f8 522
1 524 1 526
2 530 532 3
52e 52f 534 2
53d 53f 2 53c
541 1 543 1
545 3 54c 54d
54e 3 527 546
550 1 552 1
56d 2 56c 56d
1 575 1 57b
2 57d 57e 2
56a 57f 1 586
1 581 2 599
59b 3 597 598
59d 2 5a6 5a8
2 5aa 5ac 2
5ae 5b0 2 5b2
5b4 2 5b6 5b8
3 5bd 5be 5bf
2 5ba 5c1 2
5a5 5c3 1 5c5
1 5c7 2 590
5c8 1 5cc 1
58b 2 589 5d0
1 5db 2 5d7
5db 1 5e3 2
5e5 5e6 2 5e8
5ea 2 5ed 5ef
1 5f1 1 5f7
2 5f5 5f7 2
5ff 600 1 603
2 602 603 2
610 611 2 613
615 2 617 619
4 60d 60e 61b
61c 1 62f 2
62e 62f 1 637
1 63d 2 63f
640 2 62c 641
1 648 1 643
2 65b 65d 3
659 65a 65f 2
668 66a 2 66c
66e 2 670 672
2 674 676 2
678 67a 3 67f
680 681 2 67c
683 2 667 685
1 687 1 689
2 652 68a 1
68e 1 64d 2
64b 692 2 699
69a 2 69c 69e
3 61f 695 6a1
2 5fc 6a4 1
6a6 1 6a8 1
6b4 2 6b6 6b7
2 6b9 6bb 2
6be 6c0 1 6c2
1 6c8 2 6c6
6c8 2 6d0 6d1
1 6d4 2 6d3
6d4 2 6e1 6e2
2 6e4 6e6 2
6e8 6ea 4 6de
6df 6ec 6ed 1
700 2 6ff 700
1 708 1 70e
2 710 711 2
6fd 712 1 719
1 714 2 72c
72e 3 72a 72b
730 2 739 73b
2 73d 73f 2
741 743 2 745
747 2 749 74b
3 750 751 752
2 74d 754 2
738 756 1 758
1 75a 2 723
75b 1 75f 1
71e 2 71c 763
2 76a 76b 2
76d 76f 3 6f0
766 772 2 6cd
775 1 777 3
6af 6c5 778 1
77a 3 5f4 6a7
77b 1 77d 2
787 789 3 785
786 78b 2 794
796 2 798 79a
2 79c 79e 1
7a6 2 7a8 7a9
2 7a0 7ab 2
7ad 7af 2 7b1
7b3 2 7b5 7b7
2 7b9 7bb 2
793 7bd 1 7bf
1 7c1 3 7c8
7c9 7ca 10 106
125 192 195 1a2
30f 372 3ec 467
4c6 553 558 5d3
77e 7c2 7cc 2
7d9 7db 3 7d7
7d8 7dd 2 7e6
7e8 2 7e5 7ea
2 7f1 7f5 2
7f7 7f9 2 7fb
7ff 2 7f0 801
2 7ec 803 1
805 3 806 811
815 1 7d0 2
828 82a 3 826
827 82c 2 835
837 2 834 839
2 840 842 2
844 846 3 84b
84c 84d 2 848
84f 2 83f 851
2 83b 853 1
855 4 81f 856
85f 863 1 867
1 81a 2 818
86b b 2b 32
39 40 46 4c
52 57 5c 6b
75 
1
4
0 
872
0
1
28
15
13
0 1 1 3 1 5 1 7
1 9 1 b 1 d 1 f
10 1 12 13 1 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

1b 1 0
b 1 0
34 1 0
42 1 0
54 1 0
4e 1 0
17 1 0
48 1 0
2d 1 0
13 1 0
f 1 0
26 1 0
3 1 0
59 1 0
5f 1 2
2 0 1
7 1 0
3b 1 0
70 1 0
0

/
SHOW ERRORS FUNCTION SP_I_PROFILE;
ALTER FUNCTION SP_I_PROFILE COMPILE DEBUG;
/*######################################################################################*/
/* assign a profile to a task or project, used tables: RESOURCE_ASSIGNMENTS, PROFILES   */
/****************************************************************************************/
/*  RES_ID is profile_id, role_id is role_id in TMT_COMPETENCIES    */
/****************************************************************************************/
/*
#Stored Procedure  :SP_A_TSKPROF
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_TSKPROF ==
CREATE OR REPLACE FUNCTION SP_A_TSKPROF wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
d7
2 :e:
1FUNCTION:
1SP_A_TSKPROF:
1TASK_ID001:
1VARCHAR2:
1RES_ID001:
1ROLE_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_UNIQUEID:
132:
1H_PROJECT_ID:
1H_RES_ID:
1H_AND_ROLES:
18000:
1H_ROLE_ID:
1H_REC_STATUS:
11:
1H_FULL_NAME:
1255:
1H_TYPE:
1PLS_INTEGER:
10:
1H_CRI:
1H_BITFLAG:
1H_NUMBER:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_RES_TYPE:
1H_TEMP_SC_STATE:
1H_TABLE_TYPE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_TSKPROF(:
1':
1, :
1);:
1CHECK_TRACE:
137:
1+:
1FPUT:
1               ENTER:: SP_A_TSKPROF(38) :: cplan.sql(6296) :: :
1IS NULL:
18:
144:
1      RETURN_INVALID:: SP_A_TSKPROF(45) :: cplan.sql(6303) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
147:
1                EXIT:: SP_A_TSKPROF(48) :: cplan.sql(6306) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1PROJECT_ID:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type FROM TMT_WBS WHERE ELEME+
1NT_ID = task_id001:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
162:
1           EXCEPTION:: SP_A_TSKPROF(63) :: cplan.sql(6321) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type FROM TMT_CRI WHERE ELEME+
1NT_ID = task_id001:
178:
1           EXCEPTION:: SP_A_TSKPROF(79) :: cplan.sql(6337) :: :
185:
1        RETURN_ERROR:: SP_A_TSKPROF(86) :: cplan.sql(6344) :: :
1RECORD_NOT_FOUND:
1 ID:: :
188:
1                EXIT:: SP_A_TSKPROF(89) :: cplan.sql(6347) :: :
1PMO_RETURN_ERROR_SP:
1SC_TABLE_CRI:
1SC_TABLE_WBS:
1PROFILE_ID:
1PROFILE_NAME:
1REC_STATUS:
1PROFILES:
1SELECT PROFILE_ID, PROFILE_NAME, REC_STATUS INTO h_res_id, h_full_name, h_rec+
1_status:n      FROM PROFILES WHERE PROFILE_ID = h_res_id:
1113:
1           EXCEPTION:: SP_A_TSKPROF(114) :: cplan.sql(6372) :: :
1MAX:
1PROF_NUMBER:
1ROLE_ID:
1SELECT COALESCE(MAX(PROF_NUMBER),0)+1 INTO h_number:n         FROM PROFILES:n+
1         WHERE PROJECT_ID=h_project_id AND ROLE_ID=h_role_id:
1135:
1           EXCEPTION:: SP_A_TSKPROF(136) :: cplan.sql(6394) :: :
1PMO_ORASTD:
1STRINGCONCAT:
1RTRIM:
1TCP:
1ELEMENT_NAME:
1TC:
1TMT_COMPETENCIES:
1PARENT_ID:
1SELECT PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConca+
1t(PMO_ORASTD.StringConcat(PMO_ORASTD.StringConcat(RTRIM(TCP.ELEMENT_NAME), ',+
1 '), RTRIM(TC.ELEMENT_NAME)), '('), RTRIM(TO_CHAR(h_number))), ')') INTO h_fu+
1ll_name:n         FROM TMT_COMPETENCIES TC, TMT_COMPETENCIES TCP:n         WH+
1ERE TC.ELEMENT_ID = h_role_id AND TCP.ELEMENT_ID = TC.PARENT_ID:
1152:
1           EXCEPTION:: SP_A_TSKPROF(153) :: cplan.sql(6411) :: :
1159:
1        RETURN_ERROR:: SP_A_TSKPROF(160) :: cplan.sql(6418) :: :
1162:
1                EXIT:: SP_A_TSKPROF(163) :: cplan.sql(6421) :: :
1INSERT INTO PROFILES(PROFILE_ID,PROJECT_ID,ROLE_ID,PROF_NUMBER, PROFILE_NAME)+
1:n         VALUES(h_res_id, h_project_id, h_role_id, h_number, h_full_name):
1FOUND:
1100:
1182:
1           EXCEPTION:: SP_A_TSKPROF(183) :: cplan.sql(6441) :: :
1!=:
1SC_SQL_SUCCESS:
1189:
1        RETURN_ERROR:: SP_A_TSKPROF(190) :: cplan.sql(6448) :: :
1192:
1                EXIT:: SP_A_TSKPROF(193) :: cplan.sql(6451) :: :
1ELSIF:
1ISNOTPROJECTTYPE:
1A:
1RES_ASSIGNMENT_ID:
1RESOURCE_ASSIGNMENTS:
1RESOURCE_ID:
1RESOURCE_TYPE:
1SELECT a.RES_ASSIGNMENT_ID INTO h_uniqueID :n            FROM RESOURCE_ASSIGN+
1MENTS a:n            WHERE a.ELEMENT_ID = task_id001  :n            AND a.RES+
1OURCE_ID = res_id001:n            AND a.RESOURCE_TYPE = '1':
1212:
1           EXCEPTION:: SP_A_TSKPROF(213) :: cplan.sql(6471) :: :
1219:
1        RETURN_ERROR:: SP_A_TSKPROF(220) :: cplan.sql(6478) :: :
1RECORD_ALREADY_ASSIGNED:
1222:
1                EXIT:: SP_A_TSKPROF(223) :: cplan.sql(6481) :: :
1D:
1UPDATE PROFILES SET REC_STATUS = 'U' WHERE PROFILE_ID = h_res_id:
1243:
1           EXCEPTION:: SP_A_TSKPROF(244) :: cplan.sql(6502) :: :
1250:
1        RETURN_ERROR:: SP_A_TSKPROF(251) :: cplan.sql(6509) :: :
1253:
1                EXIT:: SP_A_TSKPROF(254) :: cplan.sql(6512) :: :
1SELECT RES_ASSIGNMENT_ID INTO h_uniqueID :n      FROM RESOURCE_ASSIGNMENTS:n +
1     WHERE ELEMENT_ID = task_id001 :n      AND RESOURCE_ID = h_res_id :n     +
1 AND RESOURCE_TYPE = '1':
1273:
1           EXCEPTION:: SP_A_TSKPROF(274) :: cplan.sql(6532) :: :
1ASSIGN_NAMES:
1INSTR:
1LENGTH:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n            ELSE:n  +
1          CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) >+
1 2040 THEN ASSIGN_NAMES:n            ELSE ASSIGN_NAMES || h_full_name || ';'+
1:n            END:n            END:n            WHERE ELEMENT_ID = task_id001:
1304:
1           EXCEPTION:: SP_A_TSKPROF(305) :: cplan.sql(6563) :: :
1UPDATE TMT_CRI SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n            ELSE:n  +
1          CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) >+
1 2040 THEN ASSIGN_NAMES:n            ELSE ASSIGN_NAMES || h_full_name || ';'+
1:n            END:n            END:n            WHERE ELEMENT_ID = task_id001:
1332:
1           EXCEPTION:: SP_A_TSKPROF(333) :: cplan.sql(6591) :: :
1SYS_GUID:
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1ISPROJECTTYPE:
1SC_AFFECTED:
1SC_TEAMMEMBER:
1FC_BEFORE_I_RES_ASSIGN:
1ELEMENT_TYPE:
1PARTICIPANT:
1SECURITY_ID:
1REC_USER:
1REC_DATETIME:
1TABLE_TYPE:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE,:n         RESOURCE_TYPE, RESOURCE_ID, PARTICIPANT, SECURITY_ID, +
1REC_USER, REC_DATETIME,TABLE_TYPE) :n         VALUES (h_uniqueID, h_project_i+
1d,task_id001, h_type, :n         '1', h_res_id, h_temp_participant, h_temp_se+
1curity_id, rec_user001, SYSTIMESTAMP,h_table_type):
1372:
1           EXCEPTION:: SP_A_TSKPROF(373) :: cplan.sql(6631) :: :
1PMO_STPU:
1BIT_OR:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT = PMO_STPU.BIT_OR(PARTICIPANT, pm+
1o_cnst.SC_TEAMMEMBER):n         WHERE RES_ASSIGNMENT_ID = h_uniqueID:
1393:
1           EXCEPTION:: SP_A_TSKPROF(394) :: cplan.sql(6652) :: :
1FC_AFTER_U_RES_ASSIGN:
14:
1402:
1       RETURN_STATUS:: SP_A_TSKPROF(403) :: cplan.sql(6661) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1409:
1           EXCEPTION:: SP_A_TSKPROF(410) :: cplan.sql(6668) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1421:
1           EXCEPTION:: SP_A_TSKPROF(422) :: cplan.sql(6680) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
b52
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a 52 10
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :7 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :7 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c a0 51 d :3 a0 6b d b7
a0 51 d :3 a0 6b d b7 :2 19
3c :2 a0 d :9 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 d
:3 a0 :2 51 a5 b d :9 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :1f a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c a0
b7 :2 a0 6b a0 7e a0 6b b4
2e 5a :3 a0 51 a5 b a5 b
7e 51 b4 2e :d a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 19 3c :2 a0 :2 51 a5 b
7e 6e b4 2e :4 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
19 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 19 3c a0 51 d :8 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e :f a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :2 a0 b4
2e d :4 a0 51 a5 b :2 a0 51
a5 b :2 a0 6b a0 a5 b d
:3 a0 51 a5 b a5 b 7e 51
b4 2e :3 a0 6b d b7 :3 a0 6b
d b7 :2 19 3c a0 6e d a0
51 d :9 a0 a5 b d :16 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 b7
:2 a0 6b a0 7e a0 6b b4 2e
5a :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 a5 b d b7 :2 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
b52
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ef
dd bc e1 e2 ea dc 10c fa
d9 fe ff 107 f9 129 117 f6
11b 11c 124 116 146 134 113 138
139 141 133 162 151 155 130 15d
150 17e 16d 171 14d 179 16c 19a
189 18d 169 195 188 1b6 1a5 1a9
185 1b1 1a4 1d2 1c1 1c5 1a1 1cd
1c0 1ef 1dd 1bd 1e1 1e2 1ea 1dc
20b 1fa 1fe 1d9 206 1f9 228 216
1f6 21a 21b 223 215 244 233 237
212 23f 232 260 24f 253 22f 25b
24e 280 26b 26f 24b 273 27b 26a
287 28b 267 28f 293 297 29a 29f
2a0 1 2a2 2a7 2ab 2af 2b2 2b7
2bb 2bf 2c2 2c7 2c8 2ca 2cf 2d2
2d6 2d7 2dc 2e1 2e4 2e9 2ea 2ef
2f2 2f6 2f7 2fc 2ff 304 305 30a
30d 312 313 318 31b 320 321 326
329 32d 32e 333 336 33b 33c 341
344 349 34a 34f 352 357 358 35d
360 364 365 36a 36d 372 373 378
37b 380 381 386 389 38e 38f 394
397 39b 39c 3a1 3a4 3a9 3aa 3af
3b2 3b7 3b8 3bd 3be 3c3 3c5 3c9
3cc 3d0 3d4 3d7 3db 3df 3e2 3e5
3ea 3ed 3f0 3f3 3f4 3f9 3fa 1
3fc 401 405 409 40c 411 416 419
41d 41e 423 424 429 42b 42f 432
436 439 43a 43f 442 445 449 44c
44d 452 455 1 458 45d 461 464
465 46a 46d 1 470 475 479 47d
480 484 488 48b 48e 493 496 499
49c 49d 4a2 4a3 1 4a5 4aa 4ae
4b2 4b5 4ba 4bf 4c2 4c6 4c7 4cc
4cf 4d4 4d5 4da 4dd 4e2 4e3 4e8
4eb 4ef 4f3 4f7 4fb 4fe 4ff 501
506 507 509 50a 50f 510 515 517
51b 51e 522 526 529 52d 531 534
537 53c 53f 542 545 546 54b 54c
1 54e 553 557 55b 55e 563 568
56b 56f 570 575 576 57b 57d 581
584 588 58c 58f 593 597 59a 59e
59f 5a4 5a6 5aa 5ad 5b1 5b5 5b9
5bd 5c1 5c5 5c9 5d5 5d9 5dd 5e0
5e4 5e8 5ea 5ee 5f2 5f6 5f9 5fd
601 603 604 609 1 60d 611 615
618 61c 620 624 628 62b 62f 633
636 639 63e 641 644 647 648 64d
64e 1 650 655 659 65d 660 665
66a 66d 671 672 677 67a 67f 680
685 688 68d 68e 693 696 69a 69b
6a0 6a3 6a8 6a9 6ae 6b1 6b5 6b9
6bc 6bf 6c0 6c2 6c3 6c8 6c9 6ce
6d0 6d4 6d7 6d9 6dd 6df 6eb 6ed
6ef 6f0 6f5 6f9 6fb 707 709 70d
711 714 718 71b 71f 722 723 728
72b 72f 733 737 73b 73f 743 747
753 757 75b 75e 762 766 768 76c
770 774 777 77b 77f 781 782 787
1 78b 78f 793 796 79a 79e 7a2
7a6 7a9 7ad 7b1 7b4 7b7 7bc 7bf
7c2 7c5 7c6 7cb 7cc 1 7ce 7d3
7d7 7db 7de 7e3 7e8 7eb 7ef 7f0
7f5 7f8 7fd 7fe 803 806 80b 80c
811 814 818 819 81e 821 826 827
82c 82f 833 837 83a 83d 83e 840
841 846 847 84c 84e 852 855 857
85b 85d 869 86b 86d 86e 873 877
879 885 887 88b 88f 892 896 899
89d 8a0 8a1 8a6 8a9 8ad 8b1 8b4
8b8 8bc 8bf 8c2 8c7 8ca 8cd 8d0
8d1 8d6 8d7 1 8d9 8de 8e2 8e6
8e9 8ee 8f3 8f6 8fa 8fb 900 903
908 909 90e 911 916 917 91c 91f
923 927 92b 92f 932 933 935 93a
93b 93d 93e 943 946 94b 94c 951
954 959 95a 95f 962 966 967 96c
96f 974 975 97a 97b 980 982 986
989 98d 991 994 998 99c 99f 9a2
9a7 9aa 9ad 9b0 9b1 9b6 9b7 1
9b9 9be 9c2 9c6 9c9 9ce 9d3 9d6
9da 9db 9e0 9e1 9e6 9e8 9ec 9ef
9f3 9f7 9fa 9fe a02 a05 a09 a0d
a0e a13 a15 a19 a1c a20 a23 a27
a2b a2f a33 a36 a3a a3c a40 a43
a47 a4b a4f a53 a56 a5a a5c a60
a64 a67 a6b a6f a73 a77 a7b a7f
a83 a87 a8b a8f a93 a97 aa3 aa7
aab aae ab2 ab6 ab8 abc ac0 ac4
ac7 acb acf ad1 ad2 ad7 1 adb
adf ae3 ae6 aea aee af2 af6 af9
afd b01 b04 b07 b0c b0f b12 b15
b16 b1b b1c 1 b1e b23 b27 b2b
b2e b33 b38 b3b b3f b40 b45 b48
b4d b4e b53 b56 b5b b5c b61 b64
b68 b69 b6e b71 b76 b77 b7c b7f
b83 b87 b8a b8d b8e b90 b91 b96
b97 b9c b9e ba2 ba5 ba7 bab bad
bb9 bbb bbd bbe bc3 bc7 bc9 bd5
bd7 bdb bdf be2 be6 be9 bed bf0
bf1 bf6 bf9 bfd c01 c05 c09 c0d
c11 c14 c17 c18 c1a c1e c22 c26
c2a c2e c32 c36 c3a c3e c42 c4e
c52 c56 c59 c5d c61 c63 c67 c6b
c6f c72 c76 c7a c7c c7d c82 1
c86 c8a c8e c91 c95 c99 c9d ca1
ca4 ca8 cac caf cb2 cb7 cba cbd
cc0 cc1 cc6 cc7 1 cc9 cce cd2
cd6 cd9 cde ce3 ce6 cea ceb cf0
cf3 cf8 cf9 cfe d01 d06 d07 d0c
d0f d13 d14 d19 d1c d21 d22 d27
d2a d2e d32 d35 d38 d39 d3b d3c
d41 d42 d47 d49 d4d d50 d52 d56
d58 d64 d66 d68 d69 d6e d72 d74
d80 d82 d86 d8a d8e d92 d96 d9a
d9e da2 da6 daa dae db2 db6 dba
dbe dc2 dc6 dca dce dd2 dd6 dda
dde de2 de6 dea dee df2 df6 dfa
dfe e0a e0e e12 e15 e19 e1d e1f
e23 e27 e2b e2e e32 e36 e38 e39
e3e 1 e42 e46 e4a e4d e51 e55
e59 e5d e60 e64 e68 e6b e6e e73
e76 e79 e7c e7d e82 e83 1 e85
e8a e8e e92 e95 e9a e9f ea2 ea6
ea7 eac eaf eb4 eb5 eba ebd ec2
ec3 ec8 ecb ecf ed0 ed5 ed8 edd
ede ee3 ee6 eea eee ef1 ef4 ef5
ef7 ef8 efd efe f03 f05 f09 f0c
f0e f12 f14 f20 f22 f24 f25 f2a
f2e f30 f3c f3e f42 f46 f49 f4d
f50 f54 f57 f58 f5d f60 f64 f68
f6b f6f f73 f76 f79 f7e f81 f84
f87 f88 f8d f8e 1 f90 f95 f99
f9d fa0 fa5 faa fad fb1 fb2 fb7
fba fbf fc0 fc5 fc8 fcd fce fd3
fd6 fda fde fe2 fe6 fe9 fea fec
ff1 ff2 ff4 ff5 ffa ffd 1002 1003
1008 100b 1010 1011 1016 1019 101d 101e
1023 1026 102b 102c 1031 1032 1037 1039
103d 1040 1044 1048 104b 104f 1053 1056
1059 105e 1061 1064 1067 1068 106d 106e
1 1070 1075 1079 107d 1080 1085 108a
108d 1091 1092 1097 1098 109d 109f 10a3
10a6 10aa 10ae 10b1 10b5 10b9 10bc 10c0
10c4 10c5 10ca 10cc 10d0 10d3 10d7 10db
10df 10e3 10e7 10eb 10ef 10f3 10f7 10fb
10ff 110b 110f 1114 1118 111b 111c 1121
1125 1129 112c 112f 1133 1135 1139 113d
1140 1143 1147 1149 114d 1151 1154 1156
115a 115e 1162 1165 1169 116d 116f 1170
1175 1 1179 117d 1181 1184 1188 118c
1190 1194 1197 119b 119f 11a2 11a5 11aa
11ad 11b0 11b3 11b4 11b9 11ba 1 11bc
11c1 11c5 11c9 11cc 11d1 11d6 11d9 11dd
11de 11e3 11e6 11eb 11ec 11f1 11f4 11f9
11fa 11ff 1202 1206 1207 120c 120f 1214
1215 121a 121d 1221 1225 1228 122b 122c
122e 122f 1234 1235 123a 123c 1240 1243
1245 1249 124b 1257 1259 125b 125c 1261
1265 1267 1273 1275 1279 127d 1280 1284
1287 128b 128e 128f 1294 1297 129b 129f
12a2 12a6 12aa 12ad 12b0 12b5 12b8 12bb
12be 12bf 12c4 12c5 1 12c7 12cc 12d0
12d4 12d7 12dc 12e1 12e4 12e8 12e9 12ee
12f1 12f6 12f7 12fc 12ff 1304 1305 130a
130d 1311 1315 1319 131d 1320 1321 1323
1328 1329 132b 132c 1331 1334 1339 133a
133f 1342 1347 1348 134d 1350 1354 1355
135a 135d 1362 1363 1368 1369 136e 1370
1374 1377 137b 137f 1382 1386 138a 138d
1390 1395 1398 139b 139e 139f 13a4 13a5
1 13a7 13ac 13b0 13b4 13b7 13bc 13c1
13c4 13c8 13c9 13ce 13cf 13d4 13d6 13da
13dd 13e1 13e5 13e8 13ec 13f0 13f3 13f7
13fb 13fc 1401 1403 1407 140a 140e 1410
1414 1418 141b 141f 1422 1426 1429 142a
142f 1432 1436 143a 143e 1441 1442 1444
1445 1447 144a 144d 144e 1453 1457 145b
145f 1463 1467 146b 146f 1473 1477 147b
147f 1483 1487 1493 1497 149b 149e 14a2
14a6 14a8 14ac 14b0 14b4 14b7 14bb 14bf
14c1 14c2 14c7 1 14cb 14cf 14d3 14d6
14da 14de 14e2 14e6 14e9 14ed 14f1 14f4
14f7 14fc 14ff 1502 1505 1506 150b 150c
1 150e 1513 1517 151b 151e 1523 1528
152b 152f 1530 1535 1538 153d 153e 1543
1546 154b 154c 1551 1554 1558 1559 155e
1561 1566 1567 156c 156f 1573 1577 157a
157d 157e 1580 1581 1586 1587 158c 158e
1592 1595 1597 159b 159d 15a9 15ab 15ad
15ae 15b3 15b7 15b9 15c5 15c7 15cb 15cf
15d2 15d6 15d9 15dd 15e0 15e1 15e6 15e9
15ed 15f1 15f4 15f8 15fc 15ff 1602 1607
160a 160d 1610 1611 1616 1617 1 1619
161e 1622 1626 1629 162e 1633 1636 163a
163b 1640 1643 1648 1649 164e 1651 1656
1657 165c 165f 1663 1667 166b 166f 1672
1673 1675 167a 167b 167d 167e 1683 1686
168b 168c 1691 1694 1699 169a 169f 16a2
16a6 16a7 16ac 16af 16b4 16b5 16ba 16bb
16c0 16c2 16c6 16c9 16cd 16d1 16d4 16d8
16dc 16df 16e2 16e7 16ea 16ed 16f0 16f1
16f6 16f7 1 16f9 16fe 1702 1706 1709
170e 1713 1716 171a 171b 1720 1721 1726
1728 172c 172f 1733 1737 173a 173e 1742
1745 1749 174d 174e 1753 1755 1759 175c
175e 1762 1765 1769 176d 1770 1773 1774
1776 1779 177e 177f 1784 1788 178c 1790
1794 17a0 17a4 17a9 17ad 17b0 17b1 17b6
17ba 17be 17c1 17c4 17c8 17ca 17ce 17d2
17d5 17d8 17dc 17de 17e2 17e6 17e9 17eb
17ef 17f3 17f7 17fa 17fe 1802 1804 1805
180a 1 180e 1812 1816 1819 181d 1821
1825 1829 182c 1830 1834 1837 183a 183f
1842 1845 1848 1849 184e 184f 1 1851
1856 185a 185e 1861 1866 186b 186e 1872
1873 1878 187b 1880 1881 1886 1889 188e
188f 1894 1897 189b 189c 18a1 18a4 18a9
18aa 18af 18b2 18b6 18ba 18bd 18c0 18c1
18c3 18c4 18c9 18ca 18cf 18d1 18d5 18d8
18da 18de 18e0 18ec 18ee 18f0 18f1 18f6
18fa 18fc 1908 190a 190c 1910 1913 1915
1919 191d 1921 1924 1928 192c 192f 1932
1937 193a 193d 1940 1941 1946 1947 1
1949 194e 1952 1956 1959 195e 1963 1966
196a 196b 1970 1973 1978 1979 197e 1981
1986 1987 198c 198f 1993 1997 199b 199f
19a2 19a3 19a5 19aa 19ab 19ad 19ae 19b3
19b6 19bb 19bc 19c1 19c4 19c9 19ca 19cf
19d2 19d6 19d7 19dc 19df 19e4 19e5 19ea
19eb 19f0 19f2 19f6 19f9 19fd 1a01 1a04
1a08 1a0c 1a0f 1a12 1a17 1a1a 1a1d 1a20
1a21 1a26 1a27 1 1a29 1a2e 1a32 1a36
1a39 1a3e 1a43 1a46 1a4a 1a4b 1a50 1a51
1a56 1a58 1a5c 1a5f 1a63 1a67 1a6a 1a6e
1a72 1a75 1a79 1a7d 1a7e 1a83 1a85 1a89
1a8d 1a90 1a94 1a97 1a9b 1a9f 1aa3 1aa7
1aab 1aaf 1ab3 1ab7 1abb 1ac7 1acb 1acf
1ad2 1ad6 1ada 1adc 1ae0 1ae4 1ae8 1aeb
1aef 1af3 1af5 1af6 1afb 1 1aff 1b03
1b07 1b0a 1b0e 1b12 1b16 1b1a 1b1d 1b21
1b25 1b28 1b2b 1b30 1b33 1b36 1b39 1b3a
1b3f 1b40 1 1b42 1b47 1b4b 1b4f 1b52
1b57 1b5c 1b5f 1b63 1b64 1b69 1b6c 1b71
1b72 1b77 1b7a 1b7f 1b80 1b85 1b88 1b8c
1b8d 1b92 1b95 1b9a 1b9b 1ba0 1ba3 1ba7
1bab 1bae 1bb1 1bb2 1bb4 1bb5 1bba 1bbb
1bc0 1bc2 1bc6 1bc9 1bcb 1bcf 1bd1 1bdd
1bdf 1be1 1be2 1be7 1beb 1bed 1bf9 1bfb
1bff 1c03 1c06 1c0a 1c0d 1c11 1c14 1c15
1c1a 1c1d 1c21 1c25 1c28 1c29 1c2b 1c2e
1c31 1c32 1c37 1c3b 1c3f 1c43 1c47 1c4b
1c4f 1c53 1c57 1c5b 1c5f 1c63 1c67 1c6b
1c6f 1c73 1c7f 1c83 1c88 1c8c 1c8f 1c90
1c95 1c99 1c9d 1ca0 1ca3 1ca7 1ca9 1cad
1cb1 1cb4 1cb7 1cbb 1cbd 1cc1 1cc5 1cc8
1cca 1cce 1cd2 1cd6 1cd9 1cdd 1ce1 1ce3
1ce4 1ce9 1 1ced 1cf1 1cf5 1cf8 1cfc
1d00 1d04 1d08 1d0b 1d0f 1d13 1d16 1d19
1d1e 1d21 1d24 1d27 1d28 1d2d 1d2e 1
1d30 1d35 1d39 1d3d 1d40 1d45 1d4a 1d4d
1d51 1d52 1d57 1d5a 1d5f 1d60 1d65 1d68
1d6d 1d6e 1d73 1d76 1d7a 1d7b 1d80 1d83
1d88 1d89 1d8e 1d91 1d95 1d99 1d9c 1d9f
1da0 1da2 1da3 1da8 1da9 1dae 1db0 1db4
1db7 1db9 1dbd 1dbf 1dcb 1dcd 1dcf 1dd0
1dd5 1dd9 1ddb 1de7 1de9 1ded 1def 1df3
1df7 1dfa 1dfb 1dfd 1e00 1e03 1e04 1e09
1e0d 1e11 1e15 1e19 1e1d 1e21 1e25 1e29
1e2d 1e31 1e35 1e39 1e3d 1e41 1e45 1e51
1e55 1e5a 1e5e 1e61 1e62 1e67 1e6b 1e6f
1e72 1e75 1e79 1e7b 1e7f 1e83 1e86 1e89
1e8d 1e8f 1e93 1e97 1e9a 1e9c 1ea0 1ea4
1ea8 1eab 1eaf 1eb3 1eb5 1eb6 1ebb 1
1ebf 1ec3 1ec7 1eca 1ece 1ed2 1ed6 1eda
1edd 1ee1 1ee5 1ee8 1eeb 1ef0 1ef3 1ef6
1ef9 1efa 1eff 1f00 1 1f02 1f07 1f0b
1f0f 1f12 1f17 1f1c 1f1f 1f23 1f24 1f29
1f2c 1f31 1f32 1f37 1f3a 1f3f 1f40 1f45
1f48 1f4c 1f4d 1f52 1f55 1f5a 1f5b 1f60
1f63 1f67 1f6b 1f6e 1f71 1f72 1f74 1f75
1f7a 1f7b 1f80 1f82 1f86 1f89 1f8b 1f8f
1f91 1f9d 1f9f 1fa1 1fa2 1fa7 1fab 1fad
1fb9 1fbb 1fbd 1fc1 1fc5 1fc8 1fcc 1fd0
1fd1 1fd6 1fda 1fde 1fe2 1fe6 1fea 1fed
1fee 1ff0 1ff4 1ff8 1ffb 1ffc 1ffe 2002
2006 2009 200d 200e 2010 2014 2018 201c
2020 2023 2024 2026 2027 2029 202c 202f
2030 2035 2039 203d 2041 2044 2048 204a
204e 2052 2056 2059 205d 205f 2063 2067
206a 206e 2073 2077 207b 207e 2082 2086
208a 208e 2092 2096 209a 209e 20a2 20a6
20a7 20a9 20ad 20b1 20b5 20b9 20bd 20c1
20c5 20c9 20cd 20d1 20d5 20d9 20dd 20e1
20e5 20e9 20ed 20f1 20f5 20f9 20fd 2101
2105 2111 2115 211a 211e 2121 2122 2127
212b 212f 2132 2135 2139 213b 213f 2143
2146 2149 214d 214f 2153 2157 215a 215c
2160 2164 2168 216b 216f 2173 2175 2176
217b 1 217f 2183 2187 218a 218e 2192
2196 219a 219d 21a1 21a5 21a8 21ab 21b0
21b3 21b6 21b9 21ba 21bf 21c0 1 21c2
21c7 21cb 21cf 21d2 21d7 21dc 21df 21e3
21e4 21e9 21ec 21f1 21f2 21f7 21fa 21ff
2200 2205 2208 220c 220d 2212 2215 221a
221b 2220 2223 2227 222b 222e 2231 2232
2234 2235 223a 223b 2240 2242 2246 2249
224b 224f 2251 225d 225f 2261 2262 2267
226b 226d 2279 227b 227f 2281 2285 2289
228c 2290 2293 2297 229a 229b 22a0 22a3
22a7 22ab 22af 22b3 22b7 22bb 22bf 22c3
22c7 22d3 22d7 22dc 22e0 22e3 22e4 22e9
22ed 22f1 22f4 22f7 22fb 22fd 2301 2305
2308 230b 230f 2311 2315 2319 231c 231e
2322 2326 232a 232d 2331 2335 2337 2338
233d 1 2341 2345 2349 234c 2350 2354
2358 235c 235f 2363 2367 236a 236d 2372
2375 2378 237b 237c 2381 2382 1 2384
2389 238d 2391 2394 2399 239e 23a1 23a5
23a6 23ab 23ae 23b3 23b4 23b9 23bc 23c1
23c2 23c7 23ca 23ce 23cf 23d4 23d7 23dc
23dd 23e2 23e5 23e9 23ed 23f0 23f3 23f4
23f6 23f7 23fc 23fd 2402 2404 2408 240b
240d 2411 2413 241f 2421 2423 2424 2429
242d 242f 243b 243d 2441 2445 2449 244a
244c 2450 2452 2456 245a 245d 2461 2465
2468 246c 2470 2473 2476 247b 247e 2481
2484 2485 248a 248b 1 248d 2492 2496
249a 249d 24a2 24a7 24aa 24ae 24af 24b4
24b7 24bc 24bd 24c2 24c5 24ca 24cb 24d0
24d3 24d7 24db 24df 24e3 24e6 24e7 24e9
24ee 24ef 24f1 24f2 24f7 24fa 24ff 2500
2505 2508 250d 250e 2513 2516 251a 251b
2520 2523 2528 2529 252e 252f 2534 2536
253a 253d 2541 2545 2548 254c 2550 2553
2557 255b 255c 2561 2563 2567 256b 256e
2572 2576 2579 257d 2581 2584 2587 258c
258f 2592 2595 2596 259b 259c 1 259e
25a3 25a7 25ab 25ae 25b3 25b8 25bb 25bf
25c0 25c5 25c6 25cb 25cf 25d3 25d6 25db
25e0 25e3 25e7 25eb 25ee 25ef 25f4 25f7
25fc 25fd 2602 2605 2609 260d 2610 2611
2616 2617 261c 261e 2622 2625 2629 262d
2631 2635 2639 263d 2641 2645 2649 2655
265a 265e 2662 2666 266a 266c 266d 2672
1 2676 267a 267e 2681 2685 2689 268d
2691 2694 2698 269c 269f 26a2 26a7 26aa
26ad 26b0 26b1 26b6 26b7 1 26b9 26be
26c2 26c6 26c9 26ce 26d3 26d6 26da 26db
26e0 26e1 26e6 26ea 26ee 26f1 26f6 26fb
26fe 2702 2703 2708 270b 2710 2711 2716
2719 271d 2721 2724 2727 2728 272a 272b
2730 2731 2736 2738 273c 273f 2743 2747
274b 274f 2753 2757 275b 2767 276c 2770
2774 2778 277c 277e 2782 2784 2790 2792
2794 2795 279a 279e 27a0 27ac 27b0 27b2
27b3 27bc 
b52
2
0 1 a 6 11 :3 6 10 :3 6
11 :3 6 12 :2 6 1 3 a 13
a :2 1 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 d 16 15
:2 d :2 4 10 19 18 :2 10 :2 4 e
17 16 :2 e :2 4 11 1a 19 :2 11
:2 4 10 19 18 :2 10 :2 4 :2 b 1a
b :2 4 :2 a 19 a :2 4 :2 e 1d
e :2 4 :2 d 1c d :2 4 :2 17 26
17 :2 4 17 20 1f :2 17 :2 4 :2 13
22 13 :2 4 14 1d 1c :2 14 :2 4
:2 14 23 14 :2 4 :2 11 20 11 :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 54 5a 5d :2 54 6b 81 8
:2 6b d 10 :2 6b 1b 1e :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
28 2b :2 6b b e :2 6b 13 16
:2 6b 1b 1e :2 6b 29 2c :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
2a 2d :2 6b 32 35 :2 6b :2 7 4a
:2 4 7 :2 11 23 :2 2d 39 3c 4c
4e 4f :2 4c :2 23 :3 7 :2 d 12 1e
5c 5f :2 1e :2 7 52 :2 4 :4 9 8
7 :4 23 22 21 :2 7 :4 3c 3b 3a
:2 7 a :2 14 26 :2 30 3c 3f 4f
51 52 :2 4f :2 26 :3 a :2 10 15 21
5f 62 :2 21 6f 72 :2 21 76 79
:2 21 83 86 8f 97 :2 a0 :2 8f b1
:2 86 :2 21 :2 a 55 :2 7 a :2 14 26
:2 30 3c 3f 4f 51 52 :2 4f :2 26
:3 a :2 10 15 21 5f 62 :2 21 :2 a
55 :3 7 :2 12 28 :2 31 41 :2 7 51
:2 4 e 1a 27 35 41 4f 5c
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 53
55 56 :2 53 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 88 8b :2 24 93 96 :2 24 a2
a5 ac b5 b8 :2 a5 :2 24 :2 d 59
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1c 1a :2 25 :2 1a 7 11 1d 2a
38 44 52 5f :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 58 59 :2 56 :2 2c
:3 10 :2 16 1b 27 65 68 :2 27 75
78 :2 27 7c 7f :2 27 8b 8e :2 27
96 99 :2 27 a5 a8 af b8 bb
:2 a8 :2 27 :2 10 5c :2 d :2 a :4 16 :2 a
7 :3 35 b :2 14 1f 1d :2 28 :2 1d
a d :2 17 29 :2 33 3f 43 53
55 56 :2 53 :2 29 :3 d :2 13 18 24
62 65 :2 24 72 75 :2 24 79 7c
:2 24 86 89 92 9a :2 a3 :2 92 b6
:2 89 :2 24 be c1 :2 24 c9 cc :2 24
d1 d4 :2 24 df e2 :2 24 :2 d 59
:2 a d :2 17 29 :2 33 3f 42 52
54 55 :2 52 :2 29 :3 d :2 13 18 24
62 65 :2 24 :2 d 58 :3 a :2 15 29
:2 32 44 50 :2 a 38 :3 7 10 :2 7
17 :2 20 7 35 7 10 :2 7 17
:2 20 7 :5 4 10 4 e 1a 28
38 42 4f c 1b 28 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 53 56 57
:2 53 :2 29 :3 d :2 13 18 24 63 66
:2 24 73 76 :2 24 7a 7d :2 24 89
8c :2 24 94 97 :2 24 a3 a6 ad
b6 b9 :2 a6 :2 24 :2 d 5a :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a :2 7 16 :2 7 14 1b 28
2b :2 14 7 11 1a 1e 35 f
10 1b 2c 34 :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 35 11 1c 29 34 41 4c
59 64 71 7c 89 8f 93 a9
af b2 c8 ce d6 ed f 20
24 35 10 13 20 2e 32 3f
42 :2 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 35 b
:2 14 1f 1d :2 28 :2 1d a d :2 17
29 :2 33 3f 43 53 56 57 :2 53
:2 29 :3 d :2 13 18 24 63 66 :2 24
73 76 :2 24 7a 7d :2 24 87 8a
93 9b :2 a4 :2 93 b7 :2 8a :2 24 bf
c2 :2 24 ca cd :2 24 d2 d5 :2 24
de e1 :2 24 :2 d 5a :2 a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 63 66 :2 24
:2 d 59 :3 a :2 15 29 :2 32 44 4e
:2 a 38 :2 7 16 1f 2a 35 3d
4a 11 1b 29 34 3e a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 66 69 :2 27 76 79 :2 27 7d
80 :2 27 8c 8f :2 27 97 9a :2 27
a6 a9 b0 b9 bc :2 a9 :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 35 b
:2 14 20 1d :2 29 :2 1d a d :2 17
29 :2 33 3f 43 53 56 57 :2 53
:2 29 :3 d :2 13 18 24 63 66 :2 24
73 76 :2 24 7a 7d :2 24 87 8a
93 9b :2 a4 :2 93 af :2 8a :2 24 b7
ba :2 24 c2 c5 :2 24 ca cd :2 24
d7 da :2 24 :2 d 5a :2 a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 63 66 :2 24
:2 d 59 :3 a :2 15 29 :2 32 3c 47
:2 a 39 :2 7 4 35 b :2 14 1f
1d :2 28 :2 1d :2 a 1b 24 2c :2 1b
:2 a 30 33 :2 30 14 16 2d 12
27 13 15 22 11 13 21 11
13 :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
59 5c 5d :2 59 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8f 92 :2 2a 9a 9d :2 2a
a9 ac b3 bc bf :2 ac :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :3 35 e
:2 17 22 20 :2 2b :2 20 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
76 79 :2 27 7d 80 :2 27 8a 8d
96 9e :2 a7 :2 96 c1 :2 8d :2 27 c9
cc :2 27 d4 d7 :2 27 dc df :2 27
e9 ec :2 27 :2 10 5d :2 d 10 :2 1a
2c :2 36 42 45 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 66 69 :2 27
:2 10 5c :3 d :2 18 2c :2 35 4e 59
:2 d 3b :2 a 35 :2 7 a 11 1f
22 :2 a 25 27 :2 25 14 21 38
45 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5c 5d :2 59 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :4 2b :2 7 38 35 a :2 14 26
:2 30 3c 40 50 53 54 :2 50 :2 26
:3 a :2 10 15 21 60 63 :2 21 70
73 :2 21 77 7a :2 21 84 87 90
98 :2 a1 :2 90 b4 :2 87 :2 21 bc bf
:2 21 c7 ca :2 21 cf d2 :2 21 dc
df :2 21 :2 a 57 :2 7 a :2 14 26
:2 30 3c 3f 4f 52 53 :2 4f :2 26
:3 a :2 10 15 21 60 63 :2 21 :2 a
56 :3 7 :2 12 26 :2 2f 41 4c :2 7
:5 4 11 4 e 25 c d 1a
b 19 b :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 53 56 57 :2 53 :2 29 :3 d
:2 13 18 24 63 66 :2 24 73 76
:2 24 7a 7d :2 24 89 8c :2 24 94
97 :2 24 a3 a6 ad b6 b9 :2 a6
:2 24 :2 d 5a :2 a :2 7 :4 13 :2 7 4
:3 1 8 :2 11 1c 1a :2 25 :2 1a 7
a 13 1a :2 a 1d 1f :2 1d 14
20 12 19 27 44 12 19 28
2f 49 12 22 13 20 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
59 5c 5d :2 59 :2 2f :3 13 :2 19 1e
2a 69 6c :2 2a 79 7c :2 2a 80
83 :2 2a 8f 92 :2 2a 9a 9d :2 2a
a9 ac b3 bc bf :2 ac :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :3 21 7
21 d 16 1d :2 d 20 22 :2 20
14 20 12 19 27 44 12 19
28 2f 49 12 22 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 59 5c 5d :2 59 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8f 92 :2 2a 9a 9d
:2 2a a9 ac b3 bc bf :2 ac :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :4 24
21 :3 7 :3 15 :2 7 1a 28 31 3f
:2 28 43 4c 54 :2 43 24 :2 2d 42
:2 1a 7 a 18 21 29 :2 18 :2 a
2d 30 :2 2d a 20 :2 29 a 32
a 20 :2 29 a :5 7 1a :2 7 19
:2 7 1a 31 3f 49 51 2d 41
52 :2 1a 7 16 2b 3e 4a 56
a 19 26 33 40 4a 57 12
1e 2b 37 f 19 2d 41 4e
5b a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 66 69 :2 27 76
79 :2 27 7d 80 :2 27 8c 8f :2 27
97 9a :2 27 a6 a9 b0 b9 bc
:2 a9 :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 35 4 35 b :2 14 1f 1d
:2 28 :2 1d a 11 2a 38 41 48
55 5e 10 24 a 11 d 19
:3 17 d :2 16 22 d 1e d :2 16
22 d :4 a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 38 7 1a 30
:2 1a 7 38 35 :2 4 7 :2 11 23
:2 2d 39 3c 4c 4f 50 :2 4c :2 23
:3 7 :2 d 12 1e 5d 60 :2 1e 6d
70 :2 1e 74 77 :2 1e 81 84 8d
95 :2 9e :2 8d a9 :2 84 :2 1e b1 b4
:2 1e bc bf :2 1e c4 c7 :2 1e d2
d5 :2 1e :2 7 53 :3 4 :2 f 21 :2 2a
34 40 :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 50 53 54
:2 50 :2 26 :3 a :2 10 15 21 60 63
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 57 :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 4d 50 51
:2 4d :2 23 :3 7 :2 d 12 1e 5d 60
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 54 :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
b52
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:7 c :7 d :7 e :7 f
:6 10 :6 11 :6 12 :6 13
:6 14 :7 15 :6 16 :7 17
:6 18 :6 19 :7 1b :b 1d
:11 1e 1f :2 1e :2 1f
:2 1e :2 1f :2 1e :2 20
:2 1e :2 20 :2 1e :2 20
:2 1e :2 20 :2 1e :2 21
:2 1e :2 21 :2 1e :2 21
:2 1e :2 21 :2 1e :2 22
:2 1e :2 22 :2 1e :2 22
:2 1e :2 22 :2 1e :2 22
:4 1e :3 1d :11 25 :b 26
:3 25 :16 2b :11 2c :20 2d
:3 2c :11 2f :b 30 :3 2f
:9 32 :3 2b :8 36 :5 37
35 39 :5 3a :3 39
:2 3b :5 3d :11 3e :24 3f
:3 3e :2 3c :6 3b 38
:3 1c :a 44 :8 46 :5 47
45 49 :5 4a :3 49
:2 4b :5 4d :11 4e :24 4f
:3 4e :2 4c :6 4b 48
:3 44 :a 54 :11 55 :30 56
:3 55 :11 58 :b 59 :3 58
:a 5b :3 54 :3 5d :5 5e
44 :3 60 :5 61 5f
:3 44 :3 64 :6 68 :3 69
68 :5 6a 67 6c
:5 6d :3 6c :2 6e :5 70
:11 71 :24 72 :3 71 :2 6f
:6 6e 6b :3 1c :a 77
:3 78 :8 7a :4 7d 7e
:4 7f 7d :5 80 7c
82 :5 83 :3 82 :2 84
:5 86 :11 87 :24 88 :3 87
:2 85 :6 84 81 :3 77
:14 8e :4 8f :7 90 8e
:5 91 8d 93 :5 94
:3 93 :2 95 :5 97 :11 98
:24 99 :3 98 :2 96 :6 95
92 :3 77 :a 9e :11 9f
:30 a0 :3 9f :11 a2 :b a3
:3 a2 :a a5 :3 9e :6 a9
:5 aa a9 :6 ab :5 ac
ab :5 ae ad :3 ab
a8 b1 :5 b2 :3 b1
:2 b3 :5 b5 :11 b6 :24 b7
:3 b6 :2 b4 :6 b3 b0
:3 77 :a bc :11 bd :30 be
:3 bd :11 c0 :b c1 :3 c0
:a c3 :3 bc c5 77
:a c5 :c c6 :3 c8 :2 c9
:3 ca :3 cb :2 cc c8
:5 cd c7 cf :5 d0
:3 cf :2 d1 :5 d3 :11 d4
:24 d5 :3 d4 :2 d2 :6 d1
ce :3 c6 :a da :11 db
:30 dc :3 db :11 de :b df
:3 de :a e1 :3 da :3 c6
:a e5 :5 e7 :6 e8 :5 e9
e8 :5 eb ea :3 e8
e6 ee :5 ef :3 ee
:2 f0 :5 f2 :11 f3 :24 f4
:3 f3 :2 f1 :6 f0 ed
:6 e5 c5 77 :11 fa
:30 fb :3 fa :11 fd :b fe
:3 fd :a 100 f9 :3 77
:3 103 :2 105 106 :2 107
:2 108 109 105 :5 10a
104 10c :5 10d :3 10c
:2 10e :5 110 :11 111 :24 112
:3 111 :2 10f :6 10e 10b
:3 1c :a 118 :9 119 :2 11b
:4 11d :5 120 :2 121 :2 124
11b :6 125 :5 126 125
:5 128 127 :3 125 11a
12b :5 12c :3 12b :2 12d
:5 12f :11 130 :24 131 :3 130
:2 12e :6 12d 12a :3 119
135 119 :9 135 :2 137
:4 139 :5 13c :2 13d :2 140
137 :6 141 :5 142 141
:5 144 143 :3 141 136
147 :5 148 :3 147 :2 149
:5 14b :11 14c :24 14d :3 14c
:2 14a :6 149 146 :4 135
:3 119 :5 154 :c 155 :4 156
:3 155 :c 158 :5 159 158
:5 15b 15a :3 158 :3 15e
:3 15f :6 161 :3 162 :3 161
:5 165 :7 166 :4 167 :6 168
165 :6 169 :5 16a 169
:5 16c 16b :3 169 164
16f :5 170 :3 16f :2 171
:5 173 :11 174 :24 175 :3 174
:2 172 :6 171 16e :3 118
17a 118 :a 17a :7 17c
:2 17d 17c :6 17e :5 17f
17e :5 181 180 :3 17e
17b 184 :5 185 :3 184
:2 186 :5 188 :11 189 :24 18a
:3 189 :2 187 :6 186 183
:3 17a :6 18f 17a :3 118
:11 192 :30 193 :3 192 :a 195
1c :3 198 :11 199 :b 19a
:17 19b :3 199 :2 19d :3 19e
:3 19f 1a0 19e 19d
19e :3 1a1 :3 198 :2 1a2
:5 1a4 :11 1a5 :b 1a6 :18 1a7
:3 1a5 :2 1a9 1aa :3 1ab
1ac 1aa 1a9 1aa
:3 1ad :2 1a3 :6 1a2 197
:7 1 
27be
4
:3 0 1 :3 0 2
:a 0 b4d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 15 16 0
b 4 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :3 0
a :2 0 4 13
17 0 b4d 2
18 :2 0 c :2 0
12 4 :3 0 c
:2 0 10 1b 1d
:6 0 20 1e 0
b4b 0 b :6 0
c :2 0 16 4
:3 0 14 22 24
:6 0 27 25 0
b4b 0 d :6 0
10 :2 0 1a 4
:3 0 18 29 2b
:6 0 2e 2c 0
b4b 0 e :6 0
c :2 0 1e 4
:3 0 1c 30 32
:6 0 35 33 0
b4b 0 f :6 0
13 :2 0 22 4
:3 0 20 37 39
:6 0 3c 3a 0
b4b 0 11 :6 0
15 :2 0 26 4
:3 0 24 3e 40
:6 0 43 41 0
b4b 0 12 :6 0
18 :2 0 2a 4
:3 0 28 45 47
:6 0 4a 48 0
b4b 0 14 :6 0
18 :2 0 2c 17
:3 0 4c :7 0 50
4d 4e b4b 0
16 :6 0 18 :2 0
2e 17 :3 0 52
:7 0 56 53 54
b4b 0 19 :6 0
18 :2 0 30 17
:3 0 58 :7 0 5c
59 5a b4b 0
1a :6 0 18 :2 0
32 17 :3 0 5e
:7 0 62 5f 60
b4b 0 1b :6 0
c :2 0 34 17
:3 0 64 :7 0 68
65 66 b4b 0
1c :6 0 18 :2 0
38 4 :3 0 36
6a 6c :6 0 6f
6d 0 b4b 0
1d :6 0 13 :2 0
3a 17 :3 0 71
:7 0 75 72 73
b4b 0 1e :6 0
18 :2 0 3e 4
:3 0 3c 77 79
:6 0 7c 7a 0
b4b 0 1f :6 0
18 :2 0 40 17
:3 0 7e :7 0 82
7f 80 b4b 0
20 :6 0 8a 8b
0 42 17 :3 0
84 :7 0 88 85
86 b4b 0 21
:6 0 90 91 0
44 9 :3 0 a
:2 0 4 8c :7 0
8f 8d 0 b4b
0 22 :6 0 23
:3 0 24 :3 0 23
:3 0 25 :3 0 93
94 0 2 :4 0
46 95 97 92
99 98 :2 0 26
:3 0 27 :3 0 9b
9c 0 28 :4 0
23 :3 0 29 :3 0
9f a0 0 2
:4 0 48 a1 a3
2a :4 0 2b :2 0
2c :3 0 4a a6
a8 :3 0 2d :4 0
2b :2 0 2e :4 0
4d ab ad :3 0
2b :2 0 3 :3 0
50 af b1 :3 0
2b :2 0 2e :4 0
53 b3 b5 :3 0
2b :2 0 2f :4 0
56 b7 b9 :3 0
2b :2 0 2e :4 0
59 bb bd :3 0
2b :2 0 5 :3 0
5c bf c1 :3 0
2b :2 0 2e :4 0
5f c3 c5 :3 0
2b :2 0 2f :4 0
62 c7 c9 :3 0
2b :2 0 2e :4 0
65 cb cd :3 0
2b :2 0 6 :3 0
68 cf d1 :3 0
2b :2 0 2e :4 0
6b d3 d5 :3 0
2b :2 0 2f :4 0
6e d7 d9 :3 0
2b :2 0 2e :4 0
71 db dd :3 0
2b :2 0 7 :3 0
74 df e1 :3 0
2b :2 0 2e :4 0
77 e3 e5 :3 0
2b :2 0 30 :4 0
7a e7 e9 :3 0
7d 9d eb :2 0
ed 82 ee 9a
ed 0 ef 84
0 aab 23 :3 0
24 :3 0 f0 f1
0 23 :3 0 31
:3 0 f3 f4 0
13 :2 0 2 :4 0
32 :2 0 33 :2 0
13 :2 0 86 f9
fb :3 0 89 f5
fd f2 ff fe
:2 0 26 :3 0 34
:3 0 101 102 0
28 :4 0 35 :4 0
2b :2 0 2c :3 0
8d 106 108 :3 0
90 103 10a :2 0
10c 93 10d 100
10c 0 10e 95
0 aab 3 :3 0
36 :2 0 97 110
111 :3 0 112 :2 0
113 :2 0 5 :3 0
36 :2 0 99 116
117 :3 0 118 :2 0
119 :2 0 114 11b
11a :2 0 6 :3 0
36 :2 0 9b 11e
11f :3 0 120 :2 0
121 :2 0 11c 123
122 :2 0 23 :3 0
24 :3 0 125 126
0 23 :3 0 31
:3 0 128 129 0
37 :2 0 2 :4 0
38 :2 0 33 :2 0
13 :2 0 9d 12e
130 :3 0 a0 12a
132 127 134 133
:2 0 26 :3 0 34
:3 0 136 137 0
28 :4 0 39 :4 0
2b :2 0 2c :3 0
a4 13b 13d :3 0
2b :2 0 3a :4 0
a7 13f 141 :3 0
2b :2 0 3b :4 0
aa 143 145 :3 0
2b :2 0 3c :3 0
3d :3 0 3e :3 0
3f :3 0 14a 14b
0 ad 149 14d
40 :4 0 af 148
150 b2 147 152
:3 0 b5 138 154
:2 0 156 b8 157
135 156 0 158
ba 0 181 23
:3 0 24 :3 0 159
15a 0 23 :3 0
31 :3 0 15c 15d
0 13 :2 0 2
:4 0 41 :2 0 33
:2 0 13 :2 0 bc
162 164 :3 0 bf
15e 166 15b 168
167 :2 0 26 :3 0
34 :3 0 16a 16b
0 28 :4 0 42
:4 0 2b :2 0 2c
:3 0 c3 16f 171
:3 0 c6 16c 173
:2 0 175 c9 176
169 175 0 177
cb 0 181 43
:3 0 44 :3 0 178
179 0 3e :3 0
3f :3 0 17b 17c
0 45 :3 0 cd
17a 17f :2 0 181
d0 182 124 181
0 183 d4 0
aab 46 :3 0 47
:3 0 d :3 0 16
:3 0 48 :3 0 49
:3 0 3 :4 0 4a
1 :8 0 191 9
:3 0 4b :3 0 18c
18d 0 4c :3 0
18e 18f 0 191
d6 1e4 4d :3 0
9 :3 0 4b :3 0
193 194 0 4c
:3 0 195 196 0
198 d9 19a db
199 198 :2 0 1e2
4e :3 0 9 :3 0
4b :3 0 19d 19e
0 4c :3 0 19f
1a0 0 1da 23
:3 0 24 :3 0 1a2
1a3 0 23 :3 0
31 :3 0 1a5 1a6
0 4f :2 0 2
:4 0 50 :2 0 33
:2 0 13 :2 0 dd
1ab 1ad :3 0 e0
1a7 1af 1a4 1b1
1b0 :2 0 26 :3 0
34 :3 0 1b3 1b4
0 28 :4 0 51
:4 0 2b :2 0 2c
:3 0 e4 1b8 1ba
:3 0 2b :2 0 3a
:4 0 e7 1bc 1be
:3 0 2b :2 0 52
:4 0 ea 1c0 1c2
:3 0 2b :2 0 4c
:3 0 ed 1c4 1c6
:3 0 2b :2 0 53
:4 0 f0 1c8 1ca
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 f3
1cd 1d1 f7 1cc
1d3 :3 0 fa 1b5
1d5 :2 0 1d7 fd
1d8 1b2 1d7 0
1d9 ff 0 1da
101 1dd :3 0 1dd
0 1dd 1dc 1da
1db :6 0 1df 2
:3 0 104 1e1 106
1e0 1df :2 0 1e2
108 :2 0 1e4 0
1e4 1e3 191 1e2
:6 0 aab 1 :3 0
9 :3 0 4b :3 0
1e6 1e7 0 9
:3 0 57 :2 0 58
:3 0 1e9 1eb 0
10d 1ea 1ed :3 0
1ee :2 0 46 :3 0
47 :3 0 d :3 0
16 :3 0 59 :3 0
49 :3 0 3 :4 0
5a 1 :8 0 1fd
9 :3 0 4b :3 0
1f8 1f9 0 4c
:3 0 1fa 1fb 0
1fd 110 250 4d
:3 0 9 :3 0 4b
:3 0 1ff 200 0
4c :3 0 201 202
0 204 113 206
115 205 204 :2 0
24e 4e :3 0 9
:3 0 4b :3 0 209
20a 0 4c :3 0
20b 20c 0 246
23 :3 0 24 :3 0
20e 20f 0 23
:3 0 31 :3 0 211
212 0 4f :2 0
2 :4 0 5b :2 0
33 :2 0 13 :2 0
117 217 219 :3 0
11a 213 21b 210
21d 21c :2 0 26
:3 0 34 :3 0 21f
220 0 28 :4 0
5c :4 0 2b :2 0
2c :3 0 11e 224
226 :3 0 2b :2 0
3a :4 0 121 228
22a :3 0 2b :2 0
52 :4 0 124 22c
22e :3 0 2b :2 0
4c :3 0 127 230
232 :3 0 2b :2 0
53 :4 0 12a 234
236 :3 0 2b :2 0
54 :3 0 55 :3 0
13 :2 0 56 :2 0
12d 239 23d 131
238 23f :3 0 134
221 241 :2 0 243
137 244 21e 243
0 245 139 0
246 13b 249 :3 0
249 0 249 248
246 247 :6 0 24b
4 :3 0 13e 24d
140 24c 24b :2 0
24e 142 :2 0 250
0 250 24f 1fd
24e :6 0 2d4 1
:3 0 9 :3 0 4b
:3 0 252 253 0
9 :3 0 57 :2 0
58 :3 0 255 257
0 147 256 259
:3 0 25a :2 0 23
:3 0 24 :3 0 25c
25d 0 23 :3 0
31 :3 0 25f 260
0 c :2 0 2
:4 0 5d :2 0 33
:2 0 13 :2 0 14a
265 267 :3 0 14d
261 269 25e 26b
26a :2 0 26 :3 0
34 :3 0 26d 26e
0 28 :4 0 5e
:4 0 2b :2 0 2c
:3 0 151 272 274
:3 0 2b :2 0 3a
:4 0 154 276 278
:3 0 2b :2 0 3b
:4 0 157 27a 27c
:3 0 2b :2 0 3c
:3 0 3d :3 0 3e
:3 0 5f :3 0 281
282 0 15a 280
284 40 :4 0 15c
27f 287 15f 27e
289 :3 0 2b :2 0
60 :4 0 162 28b
28d :3 0 2b :2 0
2e :4 0 165 28f
291 :3 0 2b :2 0
3 :3 0 168 293
295 :3 0 2b :2 0
2e :4 0 16b 297
299 :3 0 16e 26f
29b :2 0 29d 171
29e 26c 29d 0
29f 173 0 2c9
23 :3 0 24 :3 0
2a0 2a1 0 23
:3 0 31 :3 0 2a3
2a4 0 13 :2 0
2 :4 0 61 :2 0
33 :2 0 13 :2 0
175 2a9 2ab :3 0
178 2a5 2ad 2a2
2af 2ae :2 0 26
:3 0 34 :3 0 2b1
2b2 0 28 :4 0
62 :4 0 2b :2 0
2c :3 0 17c 2b6
2b8 :3 0 17f 2b3
2ba :2 0 2bc 182
2bd 2b0 2bc 0
2be 184 0 2c9
43 :3 0 63 :3 0
2bf 2c0 0 3e
:3 0 5f :3 0 2c2
2c3 0 3 :3 0
45 :3 0 186 2c1
2c7 :2 0 2c9 18a
2ca 25b 2c9 0
2cb 18e 0 2d4
19 :3 0 13 :2 0
2cc 2cd 0 2d4
21 :3 0 3e :3 0
64 :3 0 2d0 2d1
0 2cf 2d2 0
2d4 190 2de 19
:3 0 18 :2 0 2d5
2d6 0 2dd 21
:3 0 3e :3 0 65
:3 0 2d9 2da 0
2d8 2db 0 2dd
195 2df 1ef 2d4
0 2e0 0 2dd
0 2e0 198 0
aab e :3 0 5
:3 0 2e1 2e2 0
aab 66 :3 0 67
:3 0 68 :3 0 e
:3 0 14 :3 0 12
:3 0 69 :3 0 66
:3 0 e :4 0 6a
1 :8 0 2f3 9
:3 0 4b :3 0 2ee
2ef 0 4c :3 0
2f0 2f1 0 2f3
19b 346 4d :3 0
9 :3 0 4b :3 0
2f5 2f6 0 4c
:3 0 2f7 2f8 0
2fa 19e 2fc 1a0
2fb 2fa :2 0 344
4e :3 0 9 :3 0
4b :3 0 2ff 300
0 4c :3 0 301
302 0 33c 23
:3 0 24 :3 0 304
305 0 23 :3 0
31 :3 0 307 308
0 4f :2 0 2
:4 0 6b :2 0 33
:2 0 13 :2 0 1a2
30d 30f :3 0 1a5
309 311 306 313
312 :2 0 26 :3 0
34 :3 0 315 316
0 28 :4 0 6c
:4 0 2b :2 0 2c
:3 0 1a9 31a 31c
:3 0 2b :2 0 3a
:4 0 1ac 31e 320
:3 0 2b :2 0 52
:4 0 1af 322 324
:3 0 2b :2 0 4c
:3 0 1b2 326 328
:3 0 2b :2 0 53
:4 0 1b5 32a 32c
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 1b8
32f 333 1bc 32e
335 :3 0 1bf 317
337 :2 0 339 1c2
33a 314 339 0
33b 1c4 0 33c
1c6 33f :3 0 33f
0 33f 33e 33c
33d :6 0 341 6
:3 0 1c9 343 1cb
342 341 :2 0 344
1cd :2 0 346 0
346 345 2f3 344
:6 0 aab 1 :3 0
9 :3 0 4b :3 0
348 349 0 9
:3 0 57 :2 0 58
:3 0 34b 34d 0
1d2 34c 34f :3 0
350 :2 0 f :3 0
6 :3 0 352 353
0 5a6 11 :3 0
54 :3 0 f :3 0
13 :2 0 c :2 0
1d5 356 35a 355
35b 0 5a6 3c
:3 0 6d :3 0 6e
:3 0 1b :3 0 69
:3 0 46 :3 0 d
:3 0 6f :3 0 11
:4 0 70 1 :8 0
36c 9 :3 0 4b
:3 0 367 368 0
4c :3 0 369 36a
0 36c 1d9 3bf
4d :3 0 9 :3 0
4b :3 0 36e 36f
0 4c :3 0 370
371 0 373 1dc
375 1de 374 373
:2 0 3bd 4e :3 0
9 :3 0 4b :3 0
378 379 0 4c
:3 0 37a 37b 0
3b5 23 :3 0 24
:3 0 37d 37e 0
23 :3 0 31 :3 0
380 381 0 4f
:2 0 2 :4 0 71
:2 0 33 :2 0 13
:2 0 1e0 386 388
:3 0 1e3 382 38a
37f 38c 38b :2 0
26 :3 0 34 :3 0
38e 38f 0 28
:4 0 72 :4 0 2b
:2 0 2c :3 0 1e7
393 395 :3 0 2b
:2 0 3a :4 0 1ea
397 399 :3 0 2b
:2 0 52 :4 0 1ed
39b 39d :3 0 2b
:2 0 4c :3 0 1f0
39f 3a1 :3 0 2b
:2 0 53 :4 0 1f3
3a3 3a5 :3 0 2b
:2 0 54 :3 0 55
:3 0 13 :2 0 56
:2 0 1f6 3a8 3ac
1fa 3a7 3ae :3 0
1fd 390 3b0 :2 0
3b2 200 3b3 38d
3b2 0 3b4 202
0 3b5 204 3b8
:3 0 3b8 0 3b8
3b7 3b5 3b6 :6 0
3ba 8 :3 0 207
3bc 209 3bb 3ba
:2 0 3bd 20b :2 0
3bf 0 3bf 3be
36c 3bd :6 0 5a6
1 :3 0 73 :3 0
74 :3 0 73 :3 0
74 :3 0 73 :3 0
74 :3 0 73 :3 0
74 :3 0 73 :3 0
74 :3 0 75 :3 0
76 :3 0 77 :3 0
75 :3 0 78 :3 0
77 :3 0 75 :3 0
3d :3 0 1b :3 0
14 :3 0 79 :3 0
78 :3 0 79 :3 0
76 :3 0 78 :3 0
49 :3 0 11 :3 0
76 :3 0 49 :3 0
78 :3 0 7a :4 0
7b 1 :8 0 3e6
9 :3 0 4b :3 0
3e1 3e2 0 4c
:3 0 3e3 3e4 0
3e6 20e 439 4d
:3 0 9 :3 0 4b
:3 0 3e8 3e9 0
4c :3 0 3ea 3eb
0 3ed 211 3ef
213 3ee 3ed :2 0
437 4e :3 0 9
:3 0 4b :3 0 3f2
3f3 0 4c :3 0
3f4 3f5 0 42f
23 :3 0 24 :3 0
3f7 3f8 0 23
:3 0 31 :3 0 3fa
3fb 0 4f :2 0
2 :4 0 7c :2 0
33 :2 0 13 :2 0
215 400 402 :3 0
218 3fc 404 3f9
406 405 :2 0 26
:3 0 34 :3 0 408
409 0 28 :4 0
7d :4 0 2b :2 0
2c :3 0 21c 40d
40f :3 0 2b :2 0
3a :4 0 21f 411
413 :3 0 2b :2 0
52 :4 0 222 415
417 :3 0 2b :2 0
4c :3 0 225 419
41b :3 0 2b :2 0
53 :4 0 228 41d
41f :3 0 2b :2 0
54 :3 0 55 :3 0
13 :2 0 56 :2 0
22b 422 426 22f
421 428 :3 0 232
40a 42a :2 0 42c
235 42d 407 42c
0 42e 237 0
42f 239 432 :3 0
432 0 432 431
42f 430 :6 0 434
a :3 0 23c 436
23e 435 434 :2 0
437 240 :2 0 439
0 439 438 3e6
437 :6 0 5a6 1
:3 0 9 :3 0 4b
:3 0 43b 43c 0
9 :3 0 57 :2 0
58 :3 0 43e 440
0 245 43f 442
:3 0 443 :2 0 23
:3 0 24 :3 0 445
446 0 23 :3 0
31 :3 0 448 449
0 c :2 0 2
:4 0 7e :2 0 33
:2 0 13 :2 0 248
44e 450 :3 0 24b
44a 452 447 454
453 :2 0 26 :3 0
34 :3 0 456 457
0 28 :4 0 7f
:4 0 2b :2 0 2c
:3 0 24f 45b 45d
:3 0 2b :2 0 3a
:4 0 252 45f 461
:3 0 2b :2 0 3b
:4 0 255 463 465
:3 0 2b :2 0 3c
:3 0 3d :3 0 3e
:3 0 5f :3 0 46a
46b 0 258 469
46d 40 :4 0 25a
468 470 25d 467
472 :3 0 2b :2 0
60 :4 0 260 474
476 :3 0 2b :2 0
2e :4 0 263 478
47a :3 0 2b :2 0
e :3 0 266 47c
47e :3 0 2b :2 0
2e :4 0 269 480
482 :3 0 26c 458
484 :2 0 486 26f
487 455 486 0
488 271 0 4b2
23 :3 0 24 :3 0
489 48a 0 23
:3 0 31 :3 0 48c
48d 0 13 :2 0
2 :4 0 80 :2 0
33 :2 0 13 :2 0
273 492 494 :3 0
276 48e 496 48b
498 497 :2 0 26
:3 0 34 :3 0 49a
49b 0 28 :4 0
81 :4 0 2b :2 0
2c :3 0 27a 49f
4a1 :3 0 27d 49c
4a3 :2 0 4a5 280
4a6 499 4a5 0
4a7 282 0 4b2
43 :3 0 63 :3 0
4a8 4a9 0 3e
:3 0 5f :3 0 4ab
4ac 0 e :3 0
45 :3 0 284 4aa
4b0 :2 0 4b2 288
4b3 444 4b2 0
4b4 28c 0 5a6
69 :3 0 66 :3 0
46 :3 0 6f :3 0
6e :3 0 67 :3 0
e :3 0 d :3 0
11 :3 0 1b :3 0
14 :4 0 82 1
:8 0 4d6 83 :4 0
4c1 :3 0 45 :3 0
57 :2 0 290 4c4
4c5 :3 0 9 :3 0
4b :3 0 4c7 4c8
0 18 :2 0 4c9
4ca 0 4cc 293
4d3 9 :3 0 4b
:3 0 4cd 4ce 0
84 :2 0 4cf 4d0
0 4d2 295 4d4
4c6 4cc 0 4d5
0 4d2 0 4d5
297 0 4d6 29a
529 4d :3 0 9
:3 0 4b :3 0 4d8
4d9 0 4c :3 0
4da 4db 0 4dd
29d 4df 29f 4de
4dd :2 0 527 4e
:3 0 9 :3 0 4b
:3 0 4e2 4e3 0
4c :3 0 4e4 4e5
0 51f 23 :3 0
24 :3 0 4e7 4e8
0 23 :3 0 31
:3 0 4ea 4eb 0
4f :2 0 2 :4 0
85 :2 0 33 :2 0
13 :2 0 2a1 4f0
4f2 :3 0 2a4 4ec
4f4 4e9 4f6 4f5
:2 0 26 :3 0 34
:3 0 4f8 4f9 0
28 :4 0 86 :4 0
2b :2 0 2c :3 0
2a8 4fd 4ff :3 0
2b :2 0 3a :4 0
2ab 501 503 :3 0
2b :2 0 52 :4 0
2ae 505 507 :3 0
2b :2 0 4c :3 0
2b1 509 50b :3 0
2b :2 0 53 :4 0
2b4 50d 50f :3 0
2b :2 0 54 :3 0
55 :3 0 13 :2 0
56 :2 0 2b7 512
516 2bb 511 518
:3 0 2be 4fa 51a
:2 0 51c 2c1 51d
4f7 51c 0 51e
2c3 0 51f 2c5
522 :3 0 522 0
522 521 51f 520
:6 0 524 c :3 0
2c8 526 2ca 525
524 :2 0 527 2cc
:2 0 529 0 529
528 4d6 527 :6 0
5a6 1 :3 0 9
:3 0 4b :3 0 52b
52c 0 9 :3 0
87 :2 0 88 :3 0
52e 530 0 2d1
52f 532 :3 0 533
:2 0 23 :3 0 24
:3 0 535 536 0
23 :3 0 31 :3 0
538 539 0 c
:2 0 2 :4 0 89
:2 0 33 :2 0 13
:2 0 2d4 53e 540
:3 0 2d7 53a 542
537 544 543 :2 0
26 :3 0 34 :3 0
546 547 0 28
:4 0 8a :4 0 2b
:2 0 2c :3 0 2db
54b 54d :3 0 2b
:2 0 3a :4 0 2de
54f 551 :3 0 2b
:2 0 3b :4 0 2e1
553 555 :3 0 2b
:2 0 3c :3 0 3d
:3 0 9 :3 0 4b
:3 0 55a 55b 0
2e4 559 55d 40
:4 0 2e6 558 560
2e9 557 562 :3 0
2b :2 0 60 :4 0
2ec 564 566 :3 0
2b :2 0 2e :4 0
2ef 568 56a :3 0
2b :2 0 5 :3 0
2f2 56c 56e :3 0
2b :2 0 2e :4 0
2f5 570 572 :3 0
2f8 548 574 :2 0
576 2fb 577 545
576 0 578 2fd
0 5a2 23 :3 0
24 :3 0 579 57a
0 23 :3 0 31
:3 0 57c 57d 0
13 :2 0 2 :4 0
8b :2 0 33 :2 0
13 :2 0 2ff 582
584 :3 0 302 57e
586 57b 588 587
:2 0 26 :3 0 34
:3 0 58a 58b 0
28 :4 0 8c :4 0
2b :2 0 2c :3 0
306 58f 591 :3 0
309 58c 593 :2 0
595 30c 596 589
595 0 597 30e
0 5a2 43 :3 0
63 :3 0 598 599
0 9 :3 0 4b
:3 0 59b 59c 0
5 :3 0 45 :3 0
310 59a 5a0 :2 0
5a2 314 5a3 534
5a2 0 5a4 318
0 5a6 8d :3 0
31a 78e 9 :3 0
4b :3 0 5a7 5a8
0 9 :3 0 57
:2 0 88 :3 0 5aa
5ac 0 324 5ab
5ae :3 0 5af :2 0
8e :3 0 3c :3 0
16 :3 0 18 :2 0
327 5b2 5b5 32a
5b1 5b7 87 :2 0
18 :2 0 32e 5b9
5bb :3 0 8f :3 0
90 :3 0 b :3 0
91 :3 0 8f :3 0
8f :3 0 49 :3 0
3 :3 0 8f :3 0
92 :3 0 5 :3 0
8f :3 0 93 :4 0
94 1 :8 0 5d0
9 :3 0 4b :3 0
5cb 5cc 0 4c
:3 0 5cd 5ce 0
5d0 331 623 4d
:3 0 9 :3 0 4b
:3 0 5d2 5d3 0
4c :3 0 5d4 5d5
0 5d7 334 5d9
336 5d8 5d7 :2 0
621 4e :3 0 9
:3 0 4b :3 0 5dc
5dd 0 4c :3 0
5de 5df 0 619
23 :3 0 24 :3 0
5e1 5e2 0 23
:3 0 31 :3 0 5e4
5e5 0 4f :2 0
2 :4 0 95 :2 0
33 :2 0 13 :2 0
338 5ea 5ec :3 0
33b 5e6 5ee 5e3
5f0 5ef :2 0 26
:3 0 34 :3 0 5f2
5f3 0 28 :4 0
96 :4 0 2b :2 0
2c :3 0 33f 5f7
5f9 :3 0 2b :2 0
3a :4 0 342 5fb
5fd :3 0 2b :2 0
52 :4 0 345 5ff
601 :3 0 2b :2 0
4c :3 0 348 603
605 :3 0 2b :2 0
53 :4 0 34b 607
609 :3 0 2b :2 0
54 :3 0 55 :3 0
13 :2 0 56 :2 0
34e 60c 610 352
60b 612 :3 0 355
5f4 614 :2 0 616
358 617 5f1 616
0 618 35a 0
619 35c 61c :3 0
61c 0 61c 61b
619 61a :6 0 61e
e :3 0 35f 620
361 61f 61e :2 0
621 363 :2 0 623
0 623 622 5d0
621 :6 0 69f 1
:3 0 9 :3 0 4b
:3 0 625 626 0
9 :3 0 57 :2 0
88 :3 0 628 62a
0 368 629 62c
:3 0 62d :2 0 23
:3 0 24 :3 0 62f
630 0 23 :3 0
31 :3 0 632 633
0 c :2 0 2
:4 0 97 :2 0 33
:2 0 13 :2 0 36b
638 63a :3 0 36e
634 63c 631 63e
63d :2 0 26 :3 0
34 :3 0 640 641
0 28 :4 0 98
:4 0 2b :2 0 2c
:3 0 372 645 647
:3 0 2b :2 0 3a
:4 0 375 649 64b
:3 0 2b :2 0 3b
:4 0 378 64d 64f
:3 0 2b :2 0 3c
:3 0 3d :3 0 3e
:3 0 99 :3 0 654
655 0 37b 653
657 40 :4 0 37d
652 65a 380 651
65c :3 0 2b :2 0
60 :4 0 383 65e
660 :3 0 2b :2 0
2e :4 0 386 662
664 :3 0 2b :2 0
5 :3 0 389 666
668 :3 0 2b :2 0
2e :4 0 38c 66a
66c :3 0 38f 642
66e :2 0 670 392
671 63f 670 0
672 394 0 69c
23 :3 0 24 :3 0
673 674 0 23
:3 0 31 :3 0 676
677 0 13 :2 0
2 :4 0 9a :2 0
33 :2 0 13 :2 0
396 67c 67e :3 0
399 678 680 675
682 681 :2 0 26
:3 0 34 :3 0 684
685 0 28 :4 0
9b :4 0 2b :2 0
2c :3 0 39d 689
68b :3 0 3a0 686
68d :2 0 68f 3a3
690 683 68f 0
691 3a5 0 69c
43 :3 0 63 :3 0
692 693 0 3e
:3 0 99 :3 0 695
696 0 5 :3 0
45 :3 0 3a7 694
69a :2 0 69c 3ab
69d 62e 69c 0
69e 3af 0 69f
3b1 6a0 5bc 69f
0 6a1 3b4 0
71e 54 :3 0 12
:3 0 13 :2 0 13
:2 0 3b6 6a2 6a6
57 :2 0 9c :4 0
3bc 6a8 6aa :3 0
69 :3 0 68 :3 0
66 :3 0 e :4 0
9d 1 :8 0 6c6
83 :4 0 6b1 :3 0
45 :3 0 57 :2 0
3c1 6b4 6b5 :3 0
9 :3 0 4b :3 0
6b7 6b8 0 18
:2 0 6b9 6ba 0
6bc 3c4 6c3 9
:3 0 4b :3 0 6bd
6be 0 84 :2 0
6bf 6c0 0 6c2
3c6 6c4 6b6 6bc
0 6c5 0 6c2
0 6c5 3c8 0
6c6 3cb 719 4d
:3 0 9 :3 0 4b
:3 0 6c8 6c9 0
4c :3 0 6ca 6cb
0 6cd 3ce 6cf
3d0 6ce 6cd :2 0
717 4e :3 0 9
:3 0 4b :3 0 6d2
6d3 0 4c :3 0
6d4 6d5 0 70f
23 :3 0 24 :3 0
6d7 6d8 0 23
:3 0 31 :3 0 6da
6db 0 4f :2 0
2 :4 0 9e :2 0
33 :2 0 13 :2 0
3d2 6e0 6e2 :3 0
3d5 6dc 6e4 6d9
6e6 6e5 :2 0 26
:3 0 34 :3 0 6e8
6e9 0 28 :4 0
9f :4 0 2b :2 0
2c :3 0 3d9 6ed
6ef :3 0 2b :2 0
3a :4 0 3dc 6f1
6f3 :3 0 2b :2 0
52 :4 0 3df 6f5
6f7 :3 0 2b :2 0
4c :3 0 3e2 6f9
6fb :3 0 2b :2 0
53 :4 0 3e5 6fd
6ff :3 0 2b :2 0
54 :3 0 55 :3 0
13 :2 0 56 :2 0
3e8 702 706 3ec
701 708 :3 0 3ef
6ea 70a :2 0 70c
3f2 70d 6e7 70c
0 70e 3f4 0
70f 3f6 712 :3 0
712 0 712 711
70f 710 :6 0 714
10 :3 0 3f9 716
3fb 715 714 :2 0
717 3fd :2 0 719
0 719 718 6c6
717 :6 0 71b 1
:3 0 400 71c 6ab
71b 0 71d 402
0 71e 404 71f
5b0 71e 0 790
23 :3 0 24 :3 0
720 721 0 23
:3 0 31 :3 0 723
724 0 c :2 0
2 :4 0 a0 :2 0
33 :2 0 13 :2 0
407 729 72b :3 0
40a 725 72d 722
72f 72e :2 0 26
:3 0 34 :3 0 731
732 0 28 :4 0
a1 :4 0 2b :2 0
2c :3 0 40e 736
738 :3 0 2b :2 0
3a :4 0 411 73a
73c :3 0 2b :2 0
3b :4 0 414 73e
740 :3 0 2b :2 0
3c :3 0 3d :3 0
3e :3 0 5f :3 0
745 746 0 417
744 748 40 :4 0
419 743 74b 41c
742 74d :3 0 2b
:2 0 60 :4 0 41f
74f 751 :3 0 2b
:2 0 2e :4 0 422
753 755 :3 0 2b
:2 0 5 :3 0 425
757 759 :3 0 2b
:2 0 2e :4 0 428
75b 75d :3 0 42b
733 75f :2 0 761
42e 762 730 761
0 763 430 0
78d 23 :3 0 24
:3 0 764 765 0
23 :3 0 31 :3 0
767 768 0 13
:2 0 2 :4 0 a2
:2 0 33 :2 0 13
:2 0 432 76d 76f
:3 0 435 769 771
766 773 772 :2 0
26 :3 0 34 :3 0
775 776 0 28
:4 0 a3 :4 0 2b
:2 0 2c :3 0 439
77a 77c :3 0 43c
777 77e :2 0 780
43f 781 774 780
0 782 441 0
78d 43 :3 0 63
:3 0 783 784 0
3e :3 0 5f :3 0
786 787 0 5
:3 0 45 :3 0 443
785 78b :2 0 78d
447 78f 351 5a6
0 790 0 78d
0 790 44b 0
aab 1a :3 0 18
:2 0 791 792 0
aab 90 :3 0 b
:3 0 91 :3 0 49
:3 0 3 :3 0 92
:3 0 e :3 0 93
:4 0 a4 1 :8 0
7a2 9 :3 0 4b
:3 0 79d 79e 0
4c :3 0 79f 7a0
0 7a2 44f 7f5
4d :3 0 9 :3 0
4b :3 0 7a4 7a5
0 4c :3 0 7a6
7a7 0 7a9 452
7ab 454 7aa 7a9
:2 0 7f3 4e :3 0
9 :3 0 4b :3 0
7ae 7af 0 4c
:3 0 7b0 7b1 0
7eb 23 :3 0 24
:3 0 7b3 7b4 0
23 :3 0 31 :3 0
7b6 7b7 0 4f
:2 0 2 :4 0 a5
:2 0 33 :2 0 13
:2 0 456 7bc 7be
:3 0 459 7b8 7c0
7b5 7c2 7c1 :2 0
26 :3 0 34 :3 0
7c4 7c5 0 28
:4 0 a6 :4 0 2b
:2 0 2c :3 0 45d
7c9 7cb :3 0 2b
:2 0 3a :4 0 460
7cd 7cf :3 0 2b
:2 0 52 :4 0 463
7d1 7d3 :3 0 2b
:2 0 4c :3 0 466
7d5 7d7 :3 0 2b
:2 0 53 :4 0 469
7d9 7db :3 0 2b
:2 0 54 :3 0 55
:3 0 13 :2 0 56
:2 0 46c 7de 7e2
470 7dd 7e4 :3 0
473 7c6 7e6 :2 0
7e8 476 7e9 7c3
7e8 0 7ea 478
0 7eb 47a 7ee
:3 0 7ee 0 7ee
7ed 7eb 7ec :6 0
7f0 12 :3 0 47d
7f2 47f 7f1 7f0
:2 0 7f3 481 :2 0
7f5 0 7f5 7f4
7a2 7f3 :6 0 aab
1 :3 0 9 :3 0
4b :3 0 7f7 7f8
0 9 :3 0 57
:2 0 58 :3 0 7fa
7fc 0 486 7fb
7fe :3 0 7ff :2 0
3c :3 0 19 :3 0
18 :2 0 489 801
804 57 :2 0 18
:2 0 48e 806 808
:3 0 48 :3 0 a7
:3 0 a8 :3 0 a7
:3 0 14 :3 0 a7
:3 0 a9 :3 0 14
:3 0 a9 :3 0 a7
:3 0 a7 :3 0 a7
:3 0 14 :3 0 49
:3 0 3 :4 0 aa
1 :8 0 82f 83
:4 0 81a :3 0 45
:3 0 57 :2 0 493
81d 81e :3 0 9
:3 0 4b :3 0 820
821 0 18 :2 0
822 823 0 825
496 82c 9 :3 0
4b :3 0 826 827
0 84 :2 0 828
829 0 82b 498
82d 81f 825 0
82e 0 82b 0
82e 49a 0 82f
49d 882 4d :3 0
9 :3 0 4b :3 0
831 832 0 4c
:3 0 833 834 0
836 4a0 838 4a2
837 836 :2 0 880
4e :3 0 9 :3 0
4b :3 0 83b 83c
0 4c :3 0 83d
83e 0 878 23
:3 0 24 :3 0 840
841 0 23 :3 0
31 :3 0 843 844
0 4f :2 0 2
:4 0 ab :2 0 33
:2 0 13 :2 0 4a4
849 84b :3 0 4a7
845 84d 842 84f
84e :2 0 26 :3 0
34 :3 0 851 852
0 28 :4 0 ac
:4 0 2b :2 0 2c
:3 0 4ab 856 858
:3 0 2b :2 0 3a
:4 0 4ae 85a 85c
:3 0 2b :2 0 52
:4 0 4b1 85e 860
:3 0 2b :2 0 4c
:3 0 4b4 862 864
:3 0 2b :2 0 53
:4 0 4b7 866 868
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 4ba
86b 86f 4be 86a
871 :3 0 4c1 853
873 :2 0 875 4c4
876 850 875 0
877 4c6 0 878
4c8 87b :3 0 87b
0 87b 87a 878
879 :6 0 87d 14
:3 0 4cb 87f 4cd
87e 87d :2 0 880
4cf :2 0 882 0
882 881 82f 880
:6 0 885 1 :3 0
8d :3 0 4d2 90b
3c :3 0 19 :3 0
18 :2 0 4d4 886
889 57 :2 0 13
:2 0 4d9 88b 88d
:3 0 59 :3 0 a7
:3 0 a8 :3 0 a7
:3 0 14 :3 0 a7
:3 0 a9 :3 0 14
:3 0 a9 :3 0 a7
:3 0 a7 :3 0 a7
:3 0 14 :3 0 49
:3 0 3 :4 0 ad
1 :8 0 8b4 83
:4 0 89f :3 0 45
:3 0 57 :2 0 4de
8a2 8a3 :3 0 9
:3 0 4b :3 0 8a5
8a6 0 18 :2 0
8a7 8a8 0 8aa
4e1 8b1 9 :3 0
4b :3 0 8ab 8ac
0 84 :2 0 8ad
8ae 0 8b0 4e3
8b2 8a4 8aa 0
8b3 0 8b0 0
8b3 4e5 0 8b4
4e8 907 4d :3 0
9 :3 0 4b :3 0
8b6 8b7 0 4c
:3 0 8b8 8b9 0
8bb 4eb 8bd 4ed
8bc 8bb :2 0 905
4e :3 0 9 :3 0
4b :3 0 8c0 8c1
0 4c :3 0 8c2
8c3 0 8fd 23
:3 0 24 :3 0 8c5
8c6 0 23 :3 0
31 :3 0 8c8 8c9
0 4f :2 0 2
:4 0 ae :2 0 33
:2 0 13 :2 0 4ef
8ce 8d0 :3 0 4f2
8ca 8d2 8c7 8d4
8d3 :2 0 26 :3 0
34 :3 0 8d6 8d7
0 28 :4 0 af
:4 0 2b :2 0 2c
:3 0 4f6 8db 8dd
:3 0 2b :2 0 3a
:4 0 4f9 8df 8e1
:3 0 2b :2 0 52
:4 0 4fc 8e3 8e5
:3 0 2b :2 0 4c
:3 0 4ff 8e7 8e9
:3 0 2b :2 0 53
:4 0 502 8eb 8ed
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 505
8f0 8f4 509 8ef
8f6 :3 0 50c 8d8
8f8 :2 0 8fa 50f
8fb 8d5 8fa 0
8fc 511 0 8fd
513 900 :3 0 900
0 900 8ff 8fd
8fe :6 0 902 16
:3 0 516 904 518
903 902 :2 0 905
51a :2 0 907 0
907 906 8b4 905
:6 0 909 1 :3 0
51d 90a 88e 909
0 90c 809 885
0 90c 51f 0
9d4 b :3 0 b0
:4 0 90e 90f :3 0
90d 910 0 9d4
20 :3 0 b1 :3 0
3c :3 0 21 :3 0
18 :2 0 522 914
917 3c :3 0 16
:3 0 18 :2 0 525
919 91c 3e :3 0
b2 :3 0 91e 91f
0 1d :3 0 528
913 922 912 923
0 9d4 b3 :3 0
3c :3 0 16 :3 0
18 :2 0 52d 926
929 530 925 92b
87 :2 0 18 :2 0
534 92d 92f :3 0
1c :3 0 3e :3 0
b4 :3 0 932 933
0 931 934 0
936 537 93d 1c
:3 0 3e :3 0 b5
:3 0 938 939 0
937 93a 0 93c
539 93e 930 936
0 93f 0 93c
0 93f 53b 0
9d4 1f :3 0 13
:4 0 940 941 0
9d4 1e :3 0 13
:2 0 943 944 0
9d4 20 :3 0 b6
:3 0 d :3 0 e
:3 0 16 :3 0 1c
:3 0 1d :3 0 1f
:3 0 1e :3 0 53e
947 94f 946 950
0 9d4 91 :3 0
90 :3 0 46 :3 0
49 :3 0 b7 :3 0
93 :3 0 92 :3 0
b8 :3 0 b9 :3 0
ba :3 0 bb :3 0
bc :3 0 b :3 0
d :3 0 3 :3 0
16 :3 0 e :3 0
1c :3 0 1d :3 0
7 :3 0 2c :3 0
21 :4 0 bd 1
:8 0 97e 83 :4 0
969 :3 0 45 :3 0
57 :2 0 548 96c
96d :3 0 9 :3 0
4b :3 0 96f 970
0 18 :2 0 971
972 0 974 54b
97b 9 :3 0 4b
:3 0 975 976 0
84 :2 0 977 978
0 97a 54d 97c
96e 974 0 97d
0 97a 0 97d
54f 0 97e 552
9d1 4d :3 0 9
:3 0 4b :3 0 980
981 0 4c :3 0
982 983 0 985
555 987 557 986
985 :2 0 9cf 4e
:3 0 9 :3 0 4b
:3 0 98a 98b 0
4c :3 0 98c 98d
0 9c7 23 :3 0
24 :3 0 98f 990
0 23 :3 0 31
:3 0 992 993 0
4f :2 0 2 :4 0
be :2 0 33 :2 0
13 :2 0 559 998
99a :3 0 55c 994
99c 991 99e 99d
:2 0 26 :3 0 34
:3 0 9a0 9a1 0
28 :4 0 bf :4 0
2b :2 0 2c :3 0
560 9a5 9a7 :3 0
2b :2 0 3a :4 0
563 9a9 9ab :3 0
2b :2 0 52 :4 0
566 9ad 9af :3 0
2b :2 0 4c :3 0
569 9b1 9b3 :3 0
2b :2 0 53 :4 0
56c 9b5 9b7 :3 0
2b :2 0 54 :3 0
55 :3 0 13 :2 0
56 :2 0 56f 9ba
9be 573 9b9 9c0
:3 0 576 9a2 9c2
:2 0 9c4 579 9c5
99f 9c4 0 9c6
57b 0 9c7 57d
9ca :3 0 9ca 0
9ca 9c9 9c7 9c8
:6 0 9cc 18 :3 0
580 9ce 582 9cd
9cc :2 0 9cf 584
:2 0 9d1 0 9d1
9d0 97e 9cf :6 0
9d4 1 :3 0 8d
:3 0 587 a5b 9
:3 0 4b :3 0 9d5
9d6 0 9 :3 0
57 :2 0 88 :3 0
9d8 9da 0 592
9d9 9dc :3 0 9dd
:2 0 91 :3 0 b8
:3 0 c0 :3 0 c1
:3 0 b8 :3 0 3e
:3 0 b5 :3 0 90
:3 0 b :4 0 c2
1 :8 0 9fe 83
:4 0 9e9 :3 0 45
:3 0 57 :2 0 597
9ec 9ed :3 0 9
:3 0 4b :3 0 9ef
9f0 0 18 :2 0
9f1 9f2 0 9f4
59a 9fb 9 :3 0
4b :3 0 9f5 9f6
0 84 :2 0 9f7
9f8 0 9fa 59c
9fc 9ee 9f4 0
9fd 0 9fa 0
9fd 59e 0 9fe
5a1 a51 4d :3 0
9 :3 0 4b :3 0
a00 a01 0 4c
:3 0 a02 a03 0
a05 5a4 a07 5a6
a06 a05 :2 0 a4f
4e :3 0 9 :3 0
4b :3 0 a0a a0b
0 4c :3 0 a0c
a0d 0 a47 23
:3 0 24 :3 0 a0f
a10 0 23 :3 0
31 :3 0 a12 a13
0 4f :2 0 2
:4 0 c3 :2 0 33
:2 0 13 :2 0 5a8
a18 a1a :3 0 5ab
a14 a1c a11 a1e
a1d :2 0 26 :3 0
34 :3 0 a20 a21
0 28 :4 0 c4
:4 0 2b :2 0 2c
:3 0 5af a25 a27
:3 0 2b :2 0 3a
:4 0 5b2 a29 a2b
:3 0 2b :2 0 52
:4 0 5b5 a2d a2f
:3 0 2b :2 0 4c
:3 0 5b8 a31 a33
:3 0 2b :2 0 53
:4 0 5bb a35 a37
:3 0 2b :2 0 54
:3 0 55 :3 0 13
:2 0 56 :2 0 5be
a3a a3e 5c2 a39
a40 :3 0 5c5 a22
a42 :2 0 a44 5c8
a45 a1f a44 0
a46 5ca 0 a47
5cc a4a :3 0 a4a
0 a4a a49 a47
a48 :6 0 a4c 1a
:3 0 5cf a4e 5d1
a4d a4c :2 0 a4f
5d3 :2 0 a51 0
a51 a50 9fe a4f
:6 0 a59 1 :3 0
20 :3 0 c5 :3 0
b :3 0 5d6 a54
a56 a53 a57 0
a59 5d8 a5a 9de
a59 0 a5c 800
9d4 0 a5c 5db
0 aab 23 :3 0
24 :3 0 a5d a5e
0 23 :3 0 31
:3 0 a60 a61 0
c6 :2 0 2 :4 0
c7 :2 0 33 :2 0
13 :2 0 5de a66
a68 :3 0 5e1 a62
a6a a5f a6c a6b
:2 0 26 :3 0 34
:3 0 a6e a6f 0
28 :4 0 c8 :4 0
2b :2 0 2c :3 0
5e5 a73 a75 :3 0
2b :2 0 3a :4 0
5e8 a77 a79 :3 0
2b :2 0 3b :4 0
5eb a7b a7d :3 0
2b :2 0 3c :3 0
3d :3 0 9 :3 0
4b :3 0 a82 a83
0 5ee a81 a85
40 :4 0 5f0 a80
a88 5f3 a7f a8a
:3 0 2b :2 0 60
:4 0 5f6 a8c a8e
:3 0 2b :2 0 2e
:4 0 5f9 a90 a92
:3 0 2b :2 0 b
:3 0 5fc a94 a96
:3 0 2b :2 0 2e
:4 0 5ff a98 a9a
:3 0 602 a70 a9c
:2 0 a9e 605 a9f
a6d a9e 0 aa0
607 0 aab 43
:3 0 c9 :3 0 aa1
aa2 0 9 :3 0
4b :3 0 aa4 aa5
0 b :3 0 45
:3 0 609 aa3 aa9
:2 0 aab 60d b4c
9 :3 0 ca :2 0
4 aac aad 0
23 :3 0 24 :3 0
aaf ab0 0 23
:3 0 31 :3 0 ab2
ab3 0 4f :2 0
2 :4 0 cb :2 0
33 :2 0 13 :2 0
61b ab8 aba :3 0
61e ab4 abc ab1
abe abd :2 0 26
:3 0 34 :3 0 ac0
ac1 0 28 :4 0
cc :4 0 2b :2 0
2c :3 0 622 ac5
ac7 :3 0 625 ac2
ac9 :2 0 ae2 26
:3 0 34 :3 0 acb
acc 0 28 :4 0
cd :4 0 2b :2 0
9 :3 0 ce :3 0
ad1 ad2 0 628
ad0 ad4 :3 0 2b
:2 0 60 :4 0 62b
ad6 ad8 :3 0 2b
:2 0 9 :3 0 cf
:3 0 adb adc 0
62e ada ade :3 0
631 acd ae0 :2 0
ae2 634 ae3 abf
ae2 0 ae4 637
0 af4 d0 :3 0
22 :3 0 9 :3 0
ce :3 0 d1 :3 0
9 :3 0 cf :3 0
d2 :3 0 d3 :4 0
d4 1 :a 0 af0
:2 0 af4 ae6 aee
:2 0 8 :3 0 22
:3 0 af2 :2 0 af4
639 af6 63d af5
af4 :2 0 b4a 4e
:3 0 9 :3 0 4b
:3 0 af9 afa 0
4c :3 0 afb afc
0 b42 23 :3 0
24 :3 0 afe aff
0 23 :3 0 31
:3 0 b01 b02 0
4f :2 0 2 :4 0
d5 :2 0 33 :2 0
13 :2 0 63f b07
b09 :3 0 642 b03
b0b b00 b0d b0c
:2 0 26 :3 0 34
:3 0 b0f b10 0
28 :4 0 d6 :4 0
2b :2 0 2c :3 0
646 b14 b16 :3 0
649 b11 b18 :2 0
b32 26 :3 0 34
:3 0 b1a b1b 0
28 :4 0 52 :4 0
2b :2 0 4c :3 0
64c b1f b21 :3 0
2b :2 0 53 :4 0
64f b23 b25 :3 0
2b :2 0 54 :3 0
55 :3 0 13 :2 0
56 :2 0 652 b28
b2c 656 b27 b2e
:3 0 659 b1c b30
:2 0 b32 65c b33
b0e b32 0 b34
65f 0 b42 d0
:3 0 22 :3 0 d1
:3 0 9 :3 0 cf
:3 0 d2 :3 0 d3
:4 0 d7 1 :a 0
b3e :2 0 b42 b36
b3c :2 0 8 :3 0
22 :3 0 b40 :2 0
b42 661 b45 :3 0
b45 0 b45 b44
b42 b43 :6 0 b47
1 :3 0 666 b49
668 b48 b47 :2 0
b4a 66a :2 0 b4c
66d b4c b4b aab
b4a :6 0 b4d :2 0
2 18 b4c b50
:3 0 b4f b4d b51
:8 0 
680
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 31
1 2f 1 38
1 36 1 3f
1 3d 1 46
1 44 1 4b
1 51 1 57
1 5d 1 63
1 6b 1 69
1 70 1 78
1 76 1 7d
1 83 1 89
1 96 1 a2
2 a5 a7 2
aa ac 2 ae
b0 2 b2 b4
2 b6 b8 2
ba bc 2 be
c0 2 c2 c4
2 c6 c8 2
ca cc 2 ce
d0 2 d2 d4
2 d6 d8 2
da dc 2 de
e0 2 e2 e4
2 e6 e8 4
9e a4 a9 ea
1 ec 1 ee
2 f8 fa 3
f6 f7 fc 2
105 107 2 104
109 1 10b 1
10d 1 10f 1
115 1 11d 2
12d 12f 3 12b
12c 131 2 13a
13c 2 13e 140
2 142 144 1
14c 2 14e 14f
2 146 151 2
139 153 1 155
1 157 2 161
163 3 15f 160
165 2 16e 170
2 16d 172 1
174 1 176 2
17d 17e 3 158
177 180 1 182
2 18b 190 1
197 1 192 2
1aa 1ac 3 1a8
1a9 1ae 2 1b7
1b9 2 1bb 1bd
2 1bf 1c1 2
1c3 1c5 2 1c7
1c9 3 1ce 1cf
1d0 2 1cb 1d2
2 1b6 1d4 1
1d6 1 1d8 2
1a1 1d9 1 1dd
1 19c 2 19a
1e1 1 1ec 2
1e8 1ec 2 1f7
1fc 1 203 1
1fe 2 216 218
3 214 215 21a
2 223 225 2
227 229 2 22b
22d 2 22f 231
2 233 235 3
23a 23b 23c 2
237 23e 2 222
240 1 242 1
244 2 20d 245
1 249 1 208
2 206 24d 1
258 2 254 258
2 264 266 3
262 263 268 2
271 273 2 275
277 2 279 27b
1 283 2 285
286 2 27d 288
2 28a 28c 2
28e 290 2 292
294 2 296 298
2 270 29a 1
29c 1 29e 2
2a8 2aa 3 2a6
2a7 2ac 2 2b5
2b7 2 2b4 2b9
1 2bb 1 2bd
3 2c4 2c5 2c6
3 29f 2be 2c8
1 2ca 4 250
2cb 2ce 2d3 2
2d7 2dc 2 2de
2df 2 2ed 2f2
1 2f9 1 2f4
2 30c 30e 3
30a 30b 310 2
319 31b 2 31d
31f 2 321 323
2 325 327 2
329 32b 3 330
331 332 2 32d
334 2 318 336
1 338 1 33a
2 303 33b 1
33f 1 2fe 2
2fc 343 1 34e
2 34a 34e 3
357 358 359 2
366 36b 1 372
1 36d 2 385
387 3 383 384
389 2 392 394
2 396 398 2
39a 39c 2 39e
3a0 2 3a2 3a4
3 3a9 3aa 3ab
2 3a6 3ad 2
391 3af 1 3b1
1 3b3 2 37c
3b4 1 3b8 1
377 2 375 3bc
2 3e0 3e5 1
3ec 1 3e7 2
3ff 401 3 3fd
3fe 403 2 40c
40e 2 410 412
2 414 416 2
418 41a 2 41c
41e 3 423 424
425 2 420 427
2 40b 429 1
42b 1 42d 2
3f6 42e 1 432
1 3f1 2 3ef
436 1 441 2
43d 441 2 44d
44f 3 44b 44c
451 2 45a 45c
2 45e 460 2
462 464 1 46c
2 46e 46f 2
466 471 2 473
475 2 477 479
2 47b 47d 2
47f 481 2 459
483 1 485 1
487 2 491 493
3 48f 490 495
2 49e 4a0 2
49d 4a2 1 4a4
1 4a6 3 4ad
4ae 4af 3 488
4a7 4b1 1 4b3
1 4c3 2 4c2
4c3 1 4cb 1
4d1 2 4d3 4d4
2 4c0 4d5 1
4dc 1 4d7 2
4ef 4f1 3 4ed
4ee 4f3 2 4fc
4fe 2 500 502
2 504 506 2
508 50a 2 50c
50e 3 513 514
515 2 510 517
2 4fb 519 1
51b 1 51d 2
4e6 51e 1 522
1 4e1 2 4df
526 1 531 2
52d 531 2 53d
53f 3 53b 53c
541 2 54a 54c
2 54e 550 2
552 554 1 55c
2 55e 55f 2
556 561 2 563
565 2 567 569
2 56b 56d 2
56f 571 2 549
573 1 575 1
577 2 581 583
3 57f 580 585
2 58e 590 2
58d 592 1 594
1 596 3 59d
59e 59f 3 578
597 5a1 1 5a3
7 354 35c 3bf
439 4b4 529 5a4
1 5ad 2 5a9
5ad 2 5b3 5b4
1 5b6 1 5ba
2 5b8 5ba 2
5ca 5cf 1 5d6
1 5d1 2 5e9
5eb 3 5e7 5e8
5ed 2 5f6 5f8
2 5fa 5fc 2
5fe 600 2 602
604 2 606 608
3 60d 60e 60f
2 60a 611 2
5f5 613 1 615
1 617 2 5e0
618 1 61c 1
5db 2 5d9 620
1 62b 2 627
62b 2 637 639
3 635 636 63b
2 644 646 2
648 64a 2 64c
64e 1 656 2
658 659 2 650
65b 2 65d 65f
2 661 663 2
665 667 2 669
66b 2 643 66d
1 66f 1 671
2 67b 67d 3
679 67a 67f 2
688 68a 2 687
68c 1 68e 1
690 3 697 698
699 3 672 691
69b 1 69d 2
623 69e 1 6a0
3 6a3 6a4 6a5
1 6a9 2 6a7
6a9 1 6b3 2
6b2 6b3 1 6bb
1 6c1 2 6c3
6c4 2 6b0 6c5
1 6cc 1 6c7
2 6df 6e1 3
6dd 6de 6e3 2
6ec 6ee 2 6f0
6f2 2 6f4 6f6
2 6f8 6fa 2
6fc 6fe 3 703
704 705 2 700
707 2 6eb 709
1 70b 1 70d
2 6d6 70e 1
712 1 6d1 2
6cf 716 1 719
1 71c 2 6a1
71d 2 728 72a
3 726 727 72c
2 735 737 2
739 73b 2 73d
73f 1 747 2
749 74a 2 741
74c 2 74e 750
2 752 754 2
756 758 2 75a
75c 2 734 75e
1 760 1 762
2 76c 76e 3
76a 76b 770 2
779 77b 2 778
77d 1 77f 1
781 3 788 789
78a 3 763 782
78c 3 78e 71f
78f 2 79c 7a1
1 7a8 1 7a3
2 7bb 7bd 3
7b9 7ba 7bf 2
7c8 7ca 2 7cc
7ce 2 7d0 7d2
2 7d4 7d6 2
7d8 7da 3 7df
7e0 7e1 2 7dc
7e3 2 7c7 7e5
1 7e7 1 7e9
2 7b2 7ea 1
7ee 1 7ad 2
7ab 7f2 1 7fd
2 7f9 7fd 2
802 803 1 807
2 805 807 1
81c 2 81b 81c
1 824 1 82a
2 82c 82d 2
819 82e 1 835
1 830 2 848
84a 3 846 847
84c 2 855 857
2 859 85b 2
85d 85f 2 861
863 2 865 867
3 86c 86d 86e
2 869 870 2
854 872 1 874
1 876 2 83f
877 1 87b 1
83a 2 838 87f
1 882 2 887
888 1 88c 2
88a 88c 1 8a1
2 8a0 8a1 1
8a9 1 8af 2
8b1 8b2 2 89e
8b3 1 8ba 1
8b5 2 8cd 8cf
3 8cb 8cc 8d1
2 8da 8dc 2
8de 8e0 2 8e2
8e4 2 8e6 8e8
2 8ea 8ec 3
8f1 8f2 8f3 2
8ee 8f5 2 8d9
8f7 1 8f9 1
8fb 2 8c4 8fc
1 900 1 8bf
2 8bd 904 1
907 2 90b 90a
2 915 916 2
91a 91b 4 918
91d 920 921 2
927 928 1 92a
1 92e 2 92c
92e 1 935 1
93b 2 93d 93e
7 948 949 94a
94b 94c 94d 94e
1 96b 2 96a
96b 1 973 1
979 2 97b 97c
2 968 97d 1
984 1 97f 2
997 999 3 995
996 99b 2 9a4
9a6 2 9a8 9aa
2 9ac 9ae 2
9b0 9b2 2 9b4
9b6 3 9bb 9bc
9bd 2 9b8 9bf
2 9a3 9c1 1
9c3 1 9c5 2
98e 9c6 1 9ca
1 989 2 987
9ce 8 90c 911
924 93f 942 945
951 9d1 1 9db
2 9d7 9db 1
9eb 2 9ea 9eb
1 9f3 1 9f9
2 9fb 9fc 2
9e8 9fd 1 a04
1 9ff 2 a17
a19 3 a15 a16
a1b 2 a24 a26
2 a28 a2a 2
a2c a2e 2 a30
a32 2 a34 a36
3 a3b a3c a3d
2 a38 a3f 2
a23 a41 1 a43
1 a45 2 a0e
a46 1 a4a 1
a09 2 a07 a4e
1 a55 2 a51
a58 2 a5b a5a
2 a65 a67 3
a63 a64 a69 2
a72 a74 2 a76
a78 2 a7a a7c
1 a84 2 a86
a87 2 a7e a89
2 a8b a8d 2
a8f a91 2 a93
a95 2 a97 a99
2 a71 a9b 1
a9d 1 a9f 3
aa6 aa7 aa8 d
ef 10e 183 1e4
2e0 2e3 346 790
793 7f5 a5c aa0
aaa 2 ab7 ab9
3 ab5 ab6 abb
2 ac4 ac6 2
ac3 ac8 2 acf
ad3 2 ad5 ad7
2 ad9 add 2
ace adf 2 aca
ae1 1 ae3 3
ae4 aef af3 1
aae 2 b06 b08
3 b04 b05 b0a
2 b13 b15 2
b12 b17 2 b1e
b20 2 b22 b24
3 b29 b2a b2b
2 b26 b2d 2
b1d b2f 2 b19
b31 1 b33 4
afd b34 b3d b41
1 b45 1 af8
2 af6 b49 12
1f 26 2d 34
3b 42 49 4f
55 5b 61 67
6e 74 7b 81
87 8e 
1
4
0 
b50
0
1
28
1c
17
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 0 0 0 0
0 0 0 0 0 0 0 0

f 1 0
63 1 0
51 1 0
69 1 0
7 1 0
36 1 0
76 1 0
7d 1 0
b 1 0
3d 1 0
5d 1 0
2f 1 0
1a 1 0
57 1 0
3 1 0
70 1 0
2 0 1
83 1 0
4b 1 0
28 1 0
21 1 0
44 1 0
89 1 0
0

/
SHOW ERRORS FUNCTION SP_A_TSKPROF;
ALTER FUNCTION SP_A_TSKPROF COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_TSKRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_TSKRES ==
CREATE OR REPLACE FUNCTION SP_A_TSKRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
62
2 :e:
1FUNCTION:
1SP_A_TSKRES:
1ID001:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_PROJECT_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_TSKRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
126:
1+:
1FPUT:
1               ENTER:: SP_A_TSKRES(27) :: cplan.sql(6733) :: :
1IS NULL:
18:
131:
1      RETURN_INVALID:: SP_A_TSKRES(32) :: cplan.sql(6738) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
134:
1                EXIT:: SP_A_TSKRES(35) :: cplan.sql(6741) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_TABLE_WBS:
1TYPE_ID:
1PROJECT_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID, PROJECT_ID INTO h_type_id, h_project_id:n      FROM TMT_WBS W+
1HERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
157:
1           EXCEPTION:: SP_A_TSKRES(58) :: cplan.sql(6764) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1ASSIGNRESOURCE:
1=:
1RECORD_ALREADY_ASSIGNED:
14:
172:
1       RETURN_STATUS:: SP_A_TSKRES(73) :: cplan.sql(6779) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
179:
1           EXCEPTION:: SP_A_TSKRES(80) :: cplan.sql(6786) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
191:
1           EXCEPTION:: SP_A_TSKRES(92) :: cplan.sql(6798) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2bc
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 :2 a0 6b 1c 81 b0 :2 a0
6b :2 a0 6b 6e a5 b a 10
:2 a0 6b 6e :2 a0 6b 6e a5 b
6e 7e a0 b4 2e 6e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
52 10 a0 7e b4 2e :2 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :2 a0 d :2 a0 d :2 a0
d :3 a0 6b d :7 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 b4
2e d :8 a0 a5 b d :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
d b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 51 a5 b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
2bc
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 116 105 109 e4 111 104 132
121 125 101 12d 120 14e 13d 141
11d 149 13c 16e 159 15d 139 161
169 158 175 179 155 17d 181 185
188 18d 18e 1 190 195 199 19d
1a0 1a5 1a9 1ad 1b0 1b5 1b6 1b8
1bd 1c0 1c4 1c5 1ca 1cf 1d2 1d7
1d8 1dd 1e0 1e4 1e5 1ea 1ed 1f2
1f3 1f8 1fb 200 201 206 209 20e
20f 214 217 21b 21c 221 224 229
22a 22f 232 237 238 23d 240 245
246 24b 24e 252 253 258 25b 260
261 266 269 26e 26f 274 275 27a
27c 280 283 287 28b 28e 292 296
299 29c 2a1 2a4 2a7 2aa 2ab 2b0
2b1 1 2b3 2b8 2bc 2c0 2c3 2c8
2cd 2d0 2d4 2d5 2da 2db 2e0 2e2
2e6 2e9 2ed 2f0 2f1 2f6 2f9 2fc
300 303 304 309 30c 1 30f 314
318 31b 31c 321 324 1 327 32c
330 334 337 33b 33f 342 345 34a
34d 350 353 354 359 35a 1 35c
361 365 369 36c 371 376 379 37d
37e 383 386 38b 38c 391 394 399
39a 39f 3a2 3a6 3aa 3ae 3b2 3b5
3b6 3b8 3bd 3be 3c0 3c1 3c6 3c7
3cc 3ce 3d2 3d5 3d9 3dd 3e0 3e4
3e8 3eb 3ee 3f3 3f6 3f9 3fc 3fd
402 403 1 405 40a 40e 412 415
41a 41f 422 426 427 42c 42d 432
434 438 43b 43f 443 446 44a 44e
451 455 456 45b 45d 461 464 468
46c 470 474 478 47c 480 484 488
48c 490 494 497 49b 49f 4a3 4a7
4ab 4af 4b3 4b7 4c3 4c7 4cb 4ce
4d2 4d6 4d8 4dc 4e0 4e4 4e7 4eb
4ef 4f1 4f2 4f7 1 4fb 4ff 503
506 50a 50e 512 516 519 51d 521
524 527 52c 52f 532 535 536 53b
53c 1 53e 543 547 54b 54e 553
558 55b 55f 560 565 568 56d 56e
573 576 57b 57c 581 584 588 589
58e 591 596 597 59c 59f 5a3 5a7
5aa 5ad 5ae 5b0 5b1 5b6 5b7 5bc
5be 5c2 5c5 5c7 5cb 5cd 5d9 5db
5dd 5de 5e3 5e7 5e9 5f5 5f7 5fb
5ff 600 605 609 60d 611 615 619
61d 621 625 629 62a 62c 630 634
638 63b 63c 63e 641 644 645 64a
64e 652 656 659 65d 65f 663 666
66a 66e 671 675 679 67c 67f 684
687 68a 68d 68e 693 694 1 696
69b 69f 6a3 6a6 6ab 6b0 6b3 6b7
6b8 6bd 6c0 6c5 6c6 6cb 6ce 6d3
6d4 6d9 6dc 6e0 6e4 6e8 6e9 6eb
6f0 6f1 6f3 6f4 6f9 6fc 701 702
707 70a 70f 710 715 718 71c 71d
722 725 72a 72b 730 731 736 738
73c 73f 743 747 74a 74e 752 755
756 758 75c 760 761 766 768 76c
770 773 777 77b 77e 782 786 789
78c 791 794 797 79a 79b 7a0 7a1
1 7a3 7a8 7ac 7b0 7b3 7b8 7bd
7c0 7c4 7c5 7ca 7cb 7d0 7d4 7d8
7db 7e0 7e5 7e8 7ec 7f0 7f3 7f4
7f9 7fc 801 802 807 80a 80e 812
815 816 81b 81c 821 823 827 82a
82e 832 836 83a 83e 842 846 84a
84e 85a 85f 863 867 86b 86f 871
872 877 1 87b 87f 883 886 88a
88e 892 896 899 89d 8a1 8a4 8a7
8ac 8af 8b2 8b5 8b6 8bb 8bc 1
8be 8c3 8c7 8cb 8ce 8d3 8d8 8db
8df 8e0 8e5 8e6 8eb 8ef 8f3 8f6
8fb 900 903 907 908 90d 910 915
916 91b 91e 922 926 929 92c 92d
92f 930 935 936 93b 93d 941 944
948 94c 950 954 958 95c 960 96c
971 975 979 97d 981 983 987 989
995 997 999 99a 99f 9a3 9a5 9b1
9b5 9b7 9b8 9c1 
2bc
2
0 1 a 6 c :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 11 1a 19 :2 11 :2 4
f 18 17 :2 f :2 4 12 1b 1a
:2 12 :2 4 :2 11 20 11 :2 4 :2 e 1d
e :2 4 :2 14 23 14 :2 4 e 17
:3 e 4 7 :2 11 23 :2 2d 3a :2 23
:3 7 :2 d 19 25 :2 2f 43 :2 25 53
59 5c :2 53 6a 7f 8 :2 6a d
10 :2 6a 16 19 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4d 4e :2 4b :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 51 :2 4
:4 9 8 7 :4 1e 1d 1c :2 7 :4 37
36 35 :2 7 a :2 14 26 :2 30 3c
3f 4e 50 51 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 6e 71 :2 21
75 78 :2 21 82 85 8e 96 :2 9f
:2 8e b0 :2 85 :2 21 :2 a 54 :2 7 a
:2 14 26 :2 30 3c 3f 4e 50 51
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 :2 a 54 :3 7 :2 12 28 :2 31 41
:2 7 4d :3 4 14 :2 4 15 :2 4 12
:2 4 14 :2 1d 4 e 17 27 32
c 1a 27 :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 52 54 55 :2 52 :2 29 :3 d
:2 13 18 24 61 64 :2 24 71 74
:2 24 78 7b :2 24 87 8a :2 24 92
95 :2 24 a1 a4 ab b4 b7 :2 a4
:2 24 :2 d 58 :2 a :2 7 :4 13 :2 7 4
:3 1 4 :3 f :2 4 17 26 34 3f
4d 5c 25 :2 17 4 7 10 21
:2 7 24 26 :2 24 7 1a :2 23 7
28 :2 4 7 :2 11 23 :2 2d 39 3c
4b 4d 4e :2 4b :2 23 :3 7 :2 d 12
1e 5b 5e :2 1e 6b 6e :2 1e 72
75 :2 1e 7f 82 8b 93 :2 8b a5
:2 82 :2 1e ad b0 :2 1e b8 bb :2 1e
c0 c3 :2 1e cb ce :2 1e :2 7 51
:3 4 :2 f 21 2a 3b :2 21 3f 48
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 4f 51 52 :2 4f :2 26
:3 a :2 10 15 21 5e 61 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 55
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 4c 4e 4f :2 4c :2 23
:3 7 :2 d 12 1e 5b 5e :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 52 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
2bc
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :6 d :6 e :6 f
:7 11 :b 13 :11 14 15
:2 14 :2 15 :2 14 :2 15
:2 14 :2 16 :2 14 :2 16
:2 14 :2 16 :2 14 :2 16
:2 14 :2 17 :2 14 :2 17
:2 14 :2 17 :2 14 :2 17
:2 14 :2 17 :4 14 :3 13
:11 1a :b 1b :3 1a :16 1e
:11 1f :20 20 :3 1f :11 22
:b 23 :3 22 :9 25 :3 1e
:3 2a :3 2b :3 2c :5 2d
:4 30 :3 31 30 :5 32
2f 34 :5 35 :3 34
:2 36 :5 38 :11 39 :24 3a
:3 39 :2 37 :6 36 33
:3 12 :5 3f :7 41 42
:3 41 :9 44 :5 45 :3 44
:11 48 :2e 49 :3 48 :c 4b
12 :3 4e :11 4f :b 50
:17 51 :3 4f :2 53 :3 54
:3 55 56 54 53
54 :3 57 :3 4e :2 58
:5 5a :11 5b :b 5c :18 5d
:3 5b :2 5f 60 :3 61
62 60 5f 60
:3 63 :2 59 :6 58 4d
:7 1 
9c3
4
:3 0 1 :3 0 2
:a 0 2b7 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 2b7 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 2b5
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 2b5
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 2b5
0 d :6 0 b
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 2b5
0 e :6 0 12
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 2b5
0 f :6 0 12
:2 0 21 11 :3 0
3a :7 0 3e 3b
3c 2b5 0 10
:6 0 12 :2 0 23
11 :3 0 40 :7 0
44 41 42 2b5
0 13 :6 0 4c
4d 0 25 11
:3 0 46 :7 0 4a
47 48 2b5 0
14 :6 0 52 53
0 27 8 :3 0
9 :2 0 4 4e
:7 0 51 4f 0
2b5 0 15 :6 0
16 :3 0 17 :3 0
16 :3 0 18 :3 0
55 56 0 2
:4 0 29 57 59
54 5b 5a :2 0
19 :3 0 1a :3 0
5d 5e 0 1b
:4 0 16 :3 0 1c
:3 0 61 62 0
2 :4 0 2b 63
65 1d :4 0 1e
:2 0 1f :3 0 2d
68 6a :3 0 20
:4 0 1e :2 0 21
:4 0 30 6d 6f
:3 0 1e :2 0 3
:3 0 33 71 73
:3 0 1e :2 0 21
:4 0 36 75 77
:3 0 1e :2 0 22
:4 0 39 79 7b
:3 0 1e :2 0 21
:4 0 3c 7d 7f
:3 0 1e :2 0 5
:3 0 3f 81 83
:3 0 1e :2 0 21
:4 0 42 85 87
:3 0 1e :2 0 22
:4 0 45 89 8b
:3 0 1e :2 0 21
:4 0 48 8d 8f
:3 0 1e :2 0 6
:3 0 4b 91 93
:3 0 1e :2 0 21
:4 0 4e 95 97
:3 0 1e :2 0 23
:4 0 51 99 9b
:3 0 54 5f 9d
:2 0 9f 59 a0
5c 9f 0 a1
5b 0 215 16
:3 0 17 :3 0 a2
a3 0 16 :3 0
24 :3 0 a5 a6
0 25 :2 0 2
:4 0 26 :2 0 27
:2 0 25 :2 0 5d
ab ad :3 0 60
a7 af a4 b1
b0 :2 0 19 :3 0
28 :3 0 b3 b4
0 1b :4 0 29
:4 0 1e :2 0 1f
:3 0 64 b8 ba
:3 0 67 b5 bc
:2 0 be 6a bf
b2 be 0 c0
6c 0 215 3
:3 0 2a :2 0 6e
c2 c3 :3 0 c4
:2 0 c5 :2 0 5
:3 0 2a :2 0 70
c8 c9 :3 0 ca
:2 0 cb :2 0 c6
cd cc :2 0 6
:3 0 2a :2 0 72
d0 d1 :3 0 d2
:2 0 d3 :2 0 ce
d5 d4 :2 0 16
:3 0 17 :3 0 d7
d8 0 16 :3 0
24 :3 0 da db
0 2b :2 0 2
:4 0 2c :2 0 27
:2 0 25 :2 0 74
e0 e2 :3 0 77
dc e4 d9 e6
e5 :2 0 19 :3 0
28 :3 0 e8 e9
0 1b :4 0 2d
:4 0 1e :2 0 1f
:3 0 7b ed ef
:3 0 1e :2 0 2e
:4 0 7e f1 f3
:3 0 1e :2 0 2f
:4 0 81 f5 f7
:3 0 1e :2 0 30
:3 0 31 :3 0 32
:3 0 33 :3 0 fc
fd 0 84 fb
ff 34 :4 0 86
fa 102 89 f9
104 :3 0 8c ea
106 :2 0 108 8f
109 e7 108 0
10a 91 0 133
16 :3 0 17 :3 0
10b 10c 0 16
:3 0 24 :3 0 10e
10f 0 25 :2 0
2 :4 0 35 :2 0
27 :2 0 25 :2 0
93 114 116 :3 0
96 110 118 10d
11a 119 :2 0 19
:3 0 28 :3 0 11c
11d 0 1b :4 0
36 :4 0 1e :2 0
1f :3 0 9a 121
123 :3 0 9d 11e
125 :2 0 127 a0
128 11b 127 0
129 a2 0 133
37 :3 0 38 :3 0
12a 12b 0 32
:3 0 33 :3 0 12d
12e 0 39 :3 0
a4 12c 131 :2 0
133 a7 134 d6
133 0 135 ab
0 215 a :3 0
3 :3 0 136 137
0 215 f :3 0
5 :3 0 139 13a
0 215 e :3 0
6 :3 0 13c 13d
0 215 10 :3 0
32 :3 0 3a :3 0
140 141 0 13f
142 0 215 3b
:3 0 3c :3 0 13
:3 0 d :3 0 3d
:3 0 3e :3 0 a
:4 0 3f 1 :8 0
151 8 :3 0 40
:3 0 14c 14d 0
41 :3 0 14e 14f
0 151 ad 1a4
42 :3 0 8 :3 0
40 :3 0 153 154
0 41 :3 0 155
156 0 158 b0
15a b2 159 158
:2 0 1a2 43 :3 0
8 :3 0 40 :3 0
15d 15e 0 41
:3 0 15f 160 0
19a 16 :3 0 17
:3 0 162 163 0
16 :3 0 24 :3 0
165 166 0 44
:2 0 2 :4 0 45
:2 0 27 :2 0 25
:2 0 b4 16b 16d
:3 0 b7 167 16f
164 171 170 :2 0
19 :3 0 28 :3 0
173 174 0 1b
:4 0 46 :4 0 1e
:2 0 1f :3 0 bb
178 17a :3 0 1e
:2 0 2e :4 0 be
17c 17e :3 0 1e
:2 0 47 :4 0 c1
180 182 :3 0 1e
:2 0 41 :3 0 c4
184 186 :3 0 1e
:2 0 48 :4 0 c7
188 18a :3 0 1e
:2 0 49 :3 0 4a
:3 0 25 :2 0 4b
:2 0 ca 18d 191
ce 18c 193 :3 0
d1 175 195 :2 0
197 d4 198 172
197 0 199 d6
0 19a d8 19d
:3 0 19d 0 19d
19c 19a 19b :6 0
19f 2 :3 0 db
1a1 dd 1a0 19f
:2 0 1a2 df :2 0
1a4 0 1a4 1a3
151 1a2 :6 0 215
1 :3 0 c :3 0
4c :4 0 1a7 1a8
:3 0 1a6 1a9 0
215 14 :3 0 4d
:3 0 10 :3 0 13
:3 0 a :3 0 f
:3 0 e :3 0 c
:3 0 e2 1ac 1b3
1ab 1b4 0 215
30 :3 0 14 :3 0
12 :2 0 e9 1b6
1b9 4e :2 0 25
:2 0 ee 1bb 1bd
:3 0 14 :3 0 32
:3 0 4f :3 0 1c0
1c1 0 1bf 1c2
0 1c4 f1 1c5
1be 1c4 0 1c6
f3 0 215 16
:3 0 17 :3 0 1c7
1c8 0 16 :3 0
24 :3 0 1ca 1cb
0 50 :2 0 2
:4 0 51 :2 0 27
:2 0 25 :2 0 f5
1d0 1d2 :3 0 f8
1cc 1d4 1c9 1d6
1d5 :2 0 19 :3 0
28 :3 0 1d8 1d9
0 1b :4 0 52
:4 0 1e :2 0 1f
:3 0 fc 1dd 1df
:3 0 1e :2 0 2e
:4 0 ff 1e1 1e3
:3 0 1e :2 0 2f
:4 0 102 1e5 1e7
:3 0 1e :2 0 30
:3 0 31 :3 0 14
:3 0 105 1eb 1ed
34 :4 0 107 1ea
1f0 10a 1e9 1f2
:3 0 1e :2 0 53
:4 0 10d 1f4 1f6
:3 0 1e :2 0 21
:4 0 110 1f8 1fa
:3 0 1e :2 0 c
:3 0 113 1fc 1fe
:3 0 1e :2 0 21
:4 0 116 200 202
:3 0 119 1da 204
:2 0 206 11c 207
1d7 206 0 208
11e 0 215 37
:3 0 54 :3 0 209
20a 0 30 :3 0
14 :3 0 12 :2 0
120 20c 20f c
:3 0 39 :3 0 123
20b 213 :2 0 215
127 2b6 8 :3 0
55 :2 0 4 216
217 0 16 :3 0
17 :3 0 219 21a
0 16 :3 0 24
:3 0 21c 21d 0
44 :2 0 2 :4 0
56 :2 0 27 :2 0
25 :2 0 135 222
224 :3 0 138 21e
226 21b 228 227
:2 0 19 :3 0 28
:3 0 22a 22b 0
1b :4 0 57 :4 0
1e :2 0 1f :3 0
13c 22f 231 :3 0
13f 22c 233 :2 0
24c 19 :3 0 28
:3 0 235 236 0
1b :4 0 58 :4 0
1e :2 0 8 :3 0
59 :3 0 23b 23c
0 142 23a 23e
:3 0 1e :2 0 53
:4 0 145 240 242
:3 0 1e :2 0 8
:3 0 5a :3 0 245
246 0 148 244
248 :3 0 14b 237
24a :2 0 24c 14e
24d 229 24c 0
24e 151 0 25e
5b :3 0 15 :3 0
8 :3 0 59 :3 0
5c :3 0 8 :3 0
5a :3 0 5d :3 0
5e :4 0 5f 1
:a 0 25a :2 0 25e
250 258 :2 0 7
:3 0 15 :3 0 25c
:2 0 25e 153 260
157 25f 25e :2 0
2b4 43 :3 0 8
:3 0 40 :3 0 263
264 0 41 :3 0
265 266 0 2ac
16 :3 0 17 :3 0
268 269 0 16
:3 0 24 :3 0 26b
26c 0 44 :2 0
2 :4 0 60 :2 0
27 :2 0 25 :2 0
159 271 273 :3 0
15c 26d 275 26a
277 276 :2 0 19
:3 0 28 :3 0 279
27a 0 1b :4 0
61 :4 0 1e :2 0
1f :3 0 160 27e
280 :3 0 163 27b
282 :2 0 29c 19
:3 0 28 :3 0 284
285 0 1b :4 0
47 :4 0 1e :2 0
41 :3 0 166 289
28b :3 0 1e :2 0
48 :4 0 169 28d
28f :3 0 1e :2 0
49 :3 0 4a :3 0
25 :2 0 4b :2 0
16c 292 296 170
291 298 :3 0 173
286 29a :2 0 29c
176 29d 278 29c
0 29e 179 0
2ac 5b :3 0 15
:3 0 5c :3 0 8
:3 0 5a :3 0 5d
:3 0 5e :4 0 62
1 :a 0 2a8 :2 0
2ac 2a0 2a6 :2 0
7 :3 0 15 :3 0
2aa :2 0 2ac 17b
2af :3 0 2af 0
2af 2ae 2ac 2ad
:6 0 2b1 1 :3 0
180 2b3 182 2b2
2b1 :2 0 2b4 184
:2 0 2b6 187 2b6
2b5 215 2b4 :6 0
2b7 :2 0 2 14
2b6 2ba :3 0 2b9
2b7 2bb :8 0 
191
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
39 1 3f 1
45 1 4b 1
58 1 64 2
67 69 2 6c
6e 2 70 72
2 74 76 2
78 7a 2 7c
7e 2 80 82
2 84 86 2
88 8a 2 8c
8e 2 90 92
2 94 96 2
98 9a 4 60
66 6b 9c 1
9e 1 a0 2
aa ac 3 a8
a9 ae 2 b7
b9 2 b6 bb
1 bd 1 bf
1 c1 1 c7
1 cf 2 df
e1 3 dd de
e3 2 ec ee
2 f0 f2 2
f4 f6 1 fe
2 100 101 2
f8 103 2 eb
105 1 107 1
109 2 113 115
3 111 112 117
2 120 122 2
11f 124 1 126
1 128 2 12f
130 3 10a 129
132 1 134 2
14b 150 1 157
1 152 2 16a
16c 3 168 169
16e 2 177 179
2 17b 17d 2
17f 181 2 183
185 2 187 189
3 18e 18f 190
2 18b 192 2
176 194 1 196
1 198 2 161
199 1 19d 1
15c 2 15a 1a1
6 1ad 1ae 1af
1b0 1b1 1b2 2
1b7 1b8 1 1bc
2 1ba 1bc 1
1c3 1 1c5 2
1cf 1d1 3 1cd
1ce 1d3 2 1dc
1de 2 1e0 1e2
2 1e4 1e6 1
1ec 2 1ee 1ef
2 1e8 1f1 2
1f3 1f5 2 1f7
1f9 2 1fb 1fd
2 1ff 201 2
1db 203 1 205
1 207 2 20d
20e 3 210 211
212 d a1 c0
135 138 13b 13e
143 1a4 1aa 1b5
1c6 208 214 2
221 223 3 21f
220 225 2 22e
230 2 22d 232
2 239 23d 2
23f 241 2 243
247 2 238 249
2 234 24b 1
24d 3 24e 259
25d 1 218 2
270 272 3 26e
26f 274 2 27d
27f 2 27c 281
2 288 28a 2
28c 28e 3 293
294 295 2 290
297 2 287 299
2 283 29b 1
29d 4 267 29e
2a7 2ab 1 2af
1 262 2 260
2b3 9 1b 22
29 30 37 3d
43 49 50 
1
4
0 
2ba
0
1
14
4
d
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
32 1 0
7 1 0
2 0 1
45 1 0
3f 1 0
3 1 0
1d 1 0
39 1 0
24 1 0
2b 1 0
4b 1 0
0

/
SHOW ERRORS FUNCTION SP_A_TSKRES;
ALTER FUNCTION SP_A_TSKRES COMPILE DEBUG;
/**********************************************************************************************/
/*
#Stored Procedure  :SP_A_CRIRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_CRIRES ==
CREATE OR REPLACE FUNCTION SP_A_CRIRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
66
2 :e:
1FUNCTION:
1SP_A_CRIRES:
1ID001:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_CRIRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
125:
1+:
1FPUT:
1               ENTER:: SP_A_CRIRES(26) :: cplan.sql(6850) :: :
1IS NULL:
18:
130:
1      RETURN_INVALID:: SP_A_CRIRES(31) :: cplan.sql(6855) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
133:
1                EXIT:: SP_A_CRIRES(34) :: cplan.sql(6858) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_WBS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
154:
1           EXCEPTION:: SP_A_CRIRES(55) :: cplan.sql(6879) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT TYPE_ID INTO h_type_id FROM TMT_CRI WHERE ELEMENT_ID = h_element_id:
171:
1           EXCEPTION:: SP_A_CRIRES(72) :: cplan.sql(6896) :: :
1SC_TABLE_CRI:
1SC_TABLE_WBS:
1SYS_GUID:
1ASSIGNRESOURCE:
1RECORD_ALREADY_ASSIGNED:
14:
191:
1       RETURN_STATUS:: SP_A_CRIRES(92) :: cplan.sql(6916) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
198:
1           EXCEPTION:: SP_A_CRIRES(99) :: cplan.sql(6923) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1110:
1           EXCEPTION:: SP_A_CRIRES(111) :: cplan.sql(6935) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
327
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a 52 10 a0 7e b4 2e :2 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c :2 a0 d :2 a0 d
:2 a0 d :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
6b d b7 :3 a0 6b d b7 :2 19
3c :2 a0 b4 2e d :8 a0 a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :3 a0 6b d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
327
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
115 104 108 e4 110 103 131 120
124 100 12c 11f 151 13c 140 11c
144 14c 13b 158 15c 138 160 164
168 16b 170 171 1 173 178 17c
180 183 188 18c 190 193 198 199
19b 1a0 1a3 1a7 1a8 1ad 1b2 1b5
1ba 1bb 1c0 1c3 1c7 1c8 1cd 1d0
1d5 1d6 1db 1de 1e3 1e4 1e9 1ec
1f1 1f2 1f7 1fa 1fe 1ff 204 207
20c 20d 212 215 21a 21b 220 223
228 229 22e 231 235 236 23b 23e
243 244 249 24c 251 252 257 258
25d 25f 263 266 26a 26e 271 275
279 27c 27f 284 287 28a 28d 28e
293 294 1 296 29b 29f 2a3 2a6
2ab 2b0 2b3 2b7 2b8 2bd 2be 2c3
2c5 2c9 2cc 2d0 2d3 2d4 2d9 2dc
2df 2e3 2e6 2e7 2ec 2ef 1 2f2
2f7 2fb 2fe 2ff 304 307 1 30a
30f 313 317 31a 31e 322 325 328
32d 330 333 336 337 33c 33d 1
33f 344 348 34c 34f 354 359 35c
360 361 366 369 36e 36f 374 377
37c 37d 382 385 389 38d 391 395
398 399 39b 3a0 3a1 3a3 3a4 3a9
3aa 3af 3b1 3b5 3b8 3bc 3c0 3c3
3c7 3cb 3ce 3d1 3d6 3d9 3dc 3df
3e0 3e5 3e6 1 3e8 3ed 3f1 3f5
3f8 3fd 402 405 409 40a 40f 410
415 417 41b 41e 422 426 429 42d
431 434 438 439 43e 440 444 447
44b 44f 453 457 45b 45f 463 467
46b 46f 473 477 47b 47f 48b 48f
493 496 49a 49e 4a0 4a4 4a8 4ac
4af 4b3 4b7 4b9 4ba 4bf 1 4c3
4c7 4cb 4ce 4d2 4d6 4da 4de 4e1
4e5 4e9 4ec 4ef 4f4 4f7 4fa 4fd
4fe 503 504 1 506 50b 50f 513
516 51b 520 523 527 528 52d 530
535 536 53b 53e 543 544 549 54c
550 551 556 559 55e 55f 564 567
56b 56f 572 575 576 578 579 57e
57f 584 586 58a 58d 58f 593 595
5a1 5a3 5a5 5a6 5ab 5af 5b1 5bd
5bf 5c3 5c7 5ca 5ce 5d1 5d5 5d8
5d9 5de 5e1 5e5 5e9 5ed 5f1 5f5
601 605 609 60c 610 614 616 61a
61e 622 625 629 62d 62f 630 635
1 639 63d 641 644 648 64c 650
654 657 65b 65f 662 665 66a 66d
670 673 674 679 67a 1 67c 681
685 689 68c 691 696 699 69d 69e
6a3 6a6 6ab 6ac 6b1 6b4 6b9 6ba
6bf 6c2 6c6 6c7 6cc 6cf 6d4 6d5
6da 6dd 6e1 6e5 6e8 6eb 6ec 6ee
6ef 6f4 6f5 6fa 6fc 700 703 705
709 70b 717 719 71b 71c 721 725
727 733 735 739 73d 741 744 748
74a 74e 752 756 759 75d 75f 763
767 76a 76e 772 773 778 77c 780
784 788 78c 790 794 798 79c 79d
79f 7a3 7a7 7ab 7ae 7af 7b1 7b4
7b7 7b8 7bd 7c1 7c5 7c9 7cc 7d0
7d2 7d6 7d9 7dd 7e1 7e4 7e8 7ec
7ef 7f2 7f7 7fa 7fd 800 801 806
807 1 809 80e 812 816 819 81e
823 826 82a 82b 830 833 838 839
83e 841 846 847 84c 84f 853 857
85b 85c 85e 863 864 866 867 86c
86f 874 875 87a 87d 882 883 888
88b 88f 890 895 898 89d 89e 8a3
8a4 8a9 8ab 8af 8b2 8b6 8ba 8bd
8c1 8c5 8c8 8c9 8cb 8cf 8d3 8d4
8d9 8db 8df 8e3 8e6 8ea 8ee 8f1
8f5 8f9 8fc 8ff 904 907 90a 90d
90e 913 914 1 916 91b 91f 923
926 92b 930 933 937 938 93d 93e
943 947 94b 94e 953 958 95b 95f
963 966 967 96c 96f 974 975 97a
97d 981 985 988 989 98e 98f 994
996 99a 99d 9a1 9a5 9a9 9ad 9b1
9b5 9b9 9bd 9c1 9cd 9d2 9d6 9da
9de 9e2 9e4 9e5 9ea 1 9ee 9f2
9f6 9f9 9fd a01 a05 a09 a0c a10
a14 a17 a1a a1f a22 a25 a28 a29
a2e a2f 1 a31 a36 a3a a3e a41
a46 a4b a4e a52 a53 a58 a59 a5e
a62 a66 a69 a6e a73 a76 a7a a7b
a80 a83 a88 a89 a8e a91 a95 a99
a9c a9f aa0 aa2 aa3 aa8 aa9 aae
ab0 ab4 ab7 abb abf ac3 ac7 acb
acf ad3 adf ae4 ae8 aec af0 af4
af6 afa afc b08 b0a b0c b0d b12
b16 b18 b24 b28 b2a b2b b34 
327
2
0 1 a 6 c :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 :2 14 23 14
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 53 59 5c :2 53 6a 7f
8 :2 6a d 10 :2 6a 16 19 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 28 2b :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 2a 2d :2 6a
32 35 :2 6a :2 7 49 :2 4 7 :2 11
23 :2 2d 39 3c 4b 4d 4e :2 4b
:2 23 :3 7 :2 d 12 1e 5b 5e :2 1e
:2 7 51 :2 4 :4 9 8 7 :4 1e 1d
1c :2 7 :4 37 36 35 :2 7 a :2 14
26 :2 30 3c 3f 4e 50 51 :2 4e
:2 26 :3 a :2 10 15 21 5e 61 :2 21
6e 71 :2 21 75 78 :2 21 82 85
8e 96 :2 9f :2 8e b0 :2 85 :2 21 :2 a
54 :2 7 a :2 14 26 :2 30 3c 3f
4e 50 51 :2 4e :2 26 :3 a :2 10 15
21 5e 61 :2 21 :2 a 54 :3 7 :2 12
28 :2 31 41 :2 7 4d :3 4 14 :2 4
15 :2 4 12 4 e 1b 2a 38
45 :2 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
52 54 55 :2 52 :2 29 :3 d :2 13 18
24 61 64 :2 24 71 74 :2 24 78
7b :2 24 87 8a :2 24 92 95 :2 24
a1 a4 ab b4 b7 :2 a4 :2 24 :2 d
58 :2 a :2 7 :4 13 :2 7 4 :3 1 8
:2 11 1c 1a :2 25 :2 1a 7 11 1e
2d 3b 48 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 57 58 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 8a 8d :2 27 95
98 :2 27 a4 a7 ae b7 ba :2 a7
:2 27 :2 10 5b :2 d :2 a :4 16 :2 a 7
:3 35 7 17 :2 20 7 35 7 17
:2 20 7 :5 4 :3 f :2 4 17 26 34
3f 4d 5c 25 :2 17 4 7 10
21 :2 7 24 26 :2 24 7 1a :2 23
7 28 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4d 4e :2 4b :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e 6b 6e :2 1e
72 75 :2 1e 7f 82 8b 93 :2 8b
a5 :2 82 :2 1e ad b0 :2 1e b8 bb
:2 1e c0 c3 :2 1e cb ce :2 1e :2 7
51 :3 4 :2 f 21 2a 3b :2 21 3f
48 :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 4f 51 52 :2 4f
:2 26 :3 a :2 10 15 21 5e 61 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
55 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4c 4f 50 :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 53 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
327
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :6 d :6 e :7 10
:b 12 :11 13 14 :2 13
:2 14 :2 13 :2 14 :2 13
:2 15 :2 13 :2 15 :2 13
:2 15 :2 13 :2 15 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :4 13 :3 12 :11 19
:b 1a :3 19 :16 1d :11 1e
:20 1f :3 1e :11 21 :b 22
:3 21 :9 24 :3 1d :3 29
:3 2a :3 2b :6 2e :5 2f
2d 31 :5 32 :3 31
:2 33 :5 35 :11 36 :24 37
:3 36 :2 34 :6 33 30
:3 11 :a 3d :6 3f :5 40
3e 42 :5 43 :3 42
:2 44 :5 46 :11 47 :24 48
:3 47 :2 45 :6 44 41
:3 3d :5 4d 3d :5 4f
4e :3 3d :5 52 :7 54
55 :3 54 :9 57 :5 58
:3 57 :11 5b :2e 5c :3 5b
:c 5e 11 :3 61 :11 62
:b 63 :17 64 :3 62 :2 66
:3 67 :3 68 69 67
66 67 :3 6a :3 61
:2 6b :5 6d :11 6e :b 6f
:18 70 :3 6e :2 72 73
:3 74 75 73 72
73 :3 76 :2 6c :6 6b
60 :7 1 
b36
4
:3 0 1 :3 0 2
:a 0 322 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 322 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 320
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 320
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 320
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 320
0 e :6 0 11
:2 0 1d 10 :3 0
33 :7 0 37 34
35 320 0 f
:6 0 11 :2 0 1f
10 :3 0 39 :7 0
3d 3a 3b 320
0 12 :6 0 45
46 0 21 10
:3 0 3f :7 0 43
40 41 320 0
13 :6 0 4b 4c
0 23 8 :3 0
9 :2 0 4 47
:7 0 4a 48 0
320 0 14 :6 0
15 :3 0 16 :3 0
15 :3 0 17 :3 0
4e 4f 0 2
:4 0 25 50 52
4d 54 53 :2 0
18 :3 0 19 :3 0
56 57 0 1a
:4 0 15 :3 0 1b
:3 0 5a 5b 0
2 :4 0 27 5c
5e 1c :4 0 1d
:2 0 1e :3 0 29
61 63 :3 0 1f
:4 0 1d :2 0 20
:4 0 2c 66 68
:3 0 1d :2 0 3
:3 0 2f 6a 6c
:3 0 1d :2 0 20
:4 0 32 6e 70
:3 0 1d :2 0 21
:4 0 35 72 74
:3 0 1d :2 0 20
:4 0 38 76 78
:3 0 1d :2 0 5
:3 0 3b 7a 7c
:3 0 1d :2 0 20
:4 0 3e 7e 80
:3 0 1d :2 0 21
:4 0 41 82 84
:3 0 1d :2 0 20
:4 0 44 86 88
:3 0 1d :2 0 6
:3 0 47 8a 8c
:3 0 1d :2 0 20
:4 0 4a 8e 90
:3 0 1d :2 0 22
:4 0 4d 92 94
:3 0 50 58 96
:2 0 98 55 99
55 98 0 9a
57 0 280 15
:3 0 16 :3 0 9b
9c 0 15 :3 0
23 :3 0 9e 9f
0 24 :2 0 2
:4 0 25 :2 0 26
:2 0 24 :2 0 59
a4 a6 :3 0 5c
a0 a8 9d aa
a9 :2 0 18 :3 0
27 :3 0 ac ad
0 1a :4 0 28
:4 0 1d :2 0 1e
:3 0 60 b1 b3
:3 0 63 ae b5
:2 0 b7 66 b8
ab b7 0 b9
68 0 280 3
:3 0 29 :2 0 6a
bb bc :3 0 bd
:2 0 be :2 0 5
:3 0 29 :2 0 6c
c1 c2 :3 0 c3
:2 0 c4 :2 0 bf
c6 c5 :2 0 6
:3 0 29 :2 0 6e
c9 ca :3 0 cb
:2 0 cc :2 0 c7
ce cd :2 0 15
:3 0 16 :3 0 d0
d1 0 15 :3 0
23 :3 0 d3 d4
0 2a :2 0 2
:4 0 2b :2 0 26
:2 0 24 :2 0 70
d9 db :3 0 73
d5 dd d2 df
de :2 0 18 :3 0
27 :3 0 e1 e2
0 1a :4 0 2c
:4 0 1d :2 0 1e
:3 0 77 e6 e8
:3 0 1d :2 0 2d
:4 0 7a ea ec
:3 0 1d :2 0 2e
:4 0 7d ee f0
:3 0 1d :2 0 2f
:3 0 30 :3 0 31
:3 0 32 :3 0 f5
f6 0 80 f4
f8 33 :4 0 82
f3 fb 85 f2
fd :3 0 88 e3
ff :2 0 101 8b
102 e0 101 0
103 8d 0 12c
15 :3 0 16 :3 0
104 105 0 15
:3 0 23 :3 0 107
108 0 24 :2 0
2 :4 0 34 :2 0
26 :2 0 24 :2 0
8f 10d 10f :3 0
92 109 111 106
113 112 :2 0 18
:3 0 27 :3 0 115
116 0 1a :4 0
35 :4 0 1d :2 0
1e :3 0 96 11a
11c :3 0 99 117
11e :2 0 120 9c
121 114 120 0
122 9e 0 12c
36 :3 0 37 :3 0
123 124 0 31
:3 0 32 :3 0 126
127 0 38 :3 0
a0 125 12a :2 0
12c a3 12d cf
12c 0 12e a7
0 280 a :3 0
3 :3 0 12f 130
0 280 e :3 0
5 :3 0 132 133
0 280 d :3 0
6 :3 0 135 136
0 280 39 :3 0
12 :3 0 3a :3 0
3b :3 0 a :4 0
3c 1 :8 0 143
8 :3 0 3d :3 0
13e 13f 0 3e
:3 0 140 141 0
143 a9 196 3f
:3 0 8 :3 0 3d
:3 0 145 146 0
3e :3 0 147 148
0 14a ac 14c
ae 14b 14a :2 0
194 40 :3 0 8
:3 0 3d :3 0 14f
150 0 3e :3 0
151 152 0 18c
15 :3 0 16 :3 0
154 155 0 15
:3 0 23 :3 0 157
158 0 41 :2 0
2 :4 0 42 :2 0
26 :2 0 24 :2 0
b0 15d 15f :3 0
b3 159 161 156
163 162 :2 0 18
:3 0 27 :3 0 165
166 0 1a :4 0
43 :4 0 1d :2 0
1e :3 0 b7 16a
16c :3 0 1d :2 0
2d :4 0 ba 16e
170 :3 0 1d :2 0
44 :4 0 bd 172
174 :3 0 1d :2 0
3e :3 0 c0 176
178 :3 0 1d :2 0
45 :4 0 c3 17a
17c :3 0 1d :2 0
46 :3 0 47 :3 0
24 :2 0 48 :2 0
c6 17f 183 ca
17e 185 :3 0 cd
167 187 :2 0 189
d0 18a 164 189
0 18b d2 0
18c d4 18f :3 0
18f 0 18f 18e
18c 18d :6 0 191
2 :3 0 d7 193
d9 192 191 :2 0
194 db :2 0 196
0 196 195 143
194 :6 0 280 1
:3 0 8 :3 0 3d
:3 0 198 199 0
8 :3 0 49 :2 0
4a :3 0 19b 19d
0 e0 19c 19f
:3 0 1a0 :2 0 39
:3 0 12 :3 0 4b
:3 0 3b :3 0 a
:4 0 4c 1 :8 0
1ad 8 :3 0 3d
:3 0 1a8 1a9 0
3e :3 0 1aa 1ab
0 1ad e3 200
3f :3 0 8 :3 0
3d :3 0 1af 1b0
0 3e :3 0 1b1
1b2 0 1b4 e6
1b6 e8 1b5 1b4
:2 0 1fe 40 :3 0
8 :3 0 3d :3 0
1b9 1ba 0 3e
:3 0 1bb 1bc 0
1f6 15 :3 0 16
:3 0 1be 1bf 0
15 :3 0 23 :3 0
1c1 1c2 0 41
:2 0 2 :4 0 4d
:2 0 26 :2 0 24
:2 0 ea 1c7 1c9
:3 0 ed 1c3 1cb
1c0 1cd 1cc :2 0
18 :3 0 27 :3 0
1cf 1d0 0 1a
:4 0 4e :4 0 1d
:2 0 1e :3 0 f1
1d4 1d6 :3 0 1d
:2 0 2d :4 0 f4
1d8 1da :3 0 1d
:2 0 44 :4 0 f7
1dc 1de :3 0 1d
:2 0 3e :3 0 fa
1e0 1e2 :3 0 1d
:2 0 45 :4 0 fd
1e4 1e6 :3 0 1d
:2 0 46 :3 0 47
:3 0 24 :2 0 48
:2 0 100 1e9 1ed
104 1e8 1ef :3 0
107 1d1 1f1 :2 0
1f3 10a 1f4 1ce
1f3 0 1f5 10c
0 1f6 10e 1f9
:3 0 1f9 0 1f9
1f8 1f6 1f7 :6 0
1fb 4 :3 0 111
1fd 113 1fc 1fb
:2 0 1fe 115 :2 0
200 0 200 1ff
1ad 1fe :6 0 207
1 :3 0 f :3 0
31 :3 0 4f :3 0
203 204 0 202
205 0 207 118
20e f :3 0 31
:3 0 50 :3 0 209
20a 0 208 20b
0 20d 11b 20f
1a1 207 0 210
0 20d 0 210
11d 0 280 c
:3 0 51 :4 0 212
213 :3 0 211 214
0 280 13 :3 0
52 :3 0 f :3 0
12 :3 0 a :3 0
e :3 0 d :3 0
c :3 0 120 217
21e 216 21f 0
280 2f :3 0 13
:3 0 11 :2 0 127
221 224 49 :2 0
24 :2 0 12c 226
228 :3 0 13 :3 0
31 :3 0 53 :3 0
22b 22c 0 22a
22d 0 22f 12f
230 229 22f 0
231 131 0 280
15 :3 0 16 :3 0
232 233 0 15
:3 0 23 :3 0 235
236 0 54 :2 0
2 :4 0 55 :2 0
26 :2 0 24 :2 0
133 23b 23d :3 0
136 237 23f 234
241 240 :2 0 18
:3 0 27 :3 0 243
244 0 1a :4 0
56 :4 0 1d :2 0
1e :3 0 13a 248
24a :3 0 1d :2 0
2d :4 0 13d 24c
24e :3 0 1d :2 0
2e :4 0 140 250
252 :3 0 1d :2 0
2f :3 0 30 :3 0
13 :3 0 143 256
258 33 :4 0 145
255 25b 148 254
25d :3 0 1d :2 0
57 :4 0 14b 25f
261 :3 0 1d :2 0
20 :4 0 14e 263
265 :3 0 1d :2 0
c :3 0 151 267
269 :3 0 1d :2 0
20 :4 0 154 26b
26d :3 0 157 245
26f :2 0 271 15a
272 242 271 0
273 15c 0 280
36 :3 0 58 :3 0
274 275 0 2f
:3 0 13 :3 0 11
:2 0 15e 277 27a
c :3 0 38 :3 0
161 276 27e :2 0
280 165 321 8
:3 0 59 :2 0 4
281 282 0 15
:3 0 16 :3 0 284
285 0 15 :3 0
23 :3 0 287 288
0 41 :2 0 2
:4 0 5a :2 0 26
:2 0 24 :2 0 173
28d 28f :3 0 176
289 291 286 293
292 :2 0 18 :3 0
27 :3 0 295 296
0 1a :4 0 5b
:4 0 1d :2 0 1e
:3 0 17a 29a 29c
:3 0 17d 297 29e
:2 0 2b7 18 :3 0
27 :3 0 2a0 2a1
0 1a :4 0 5c
:4 0 1d :2 0 8
:3 0 5d :3 0 2a6
2a7 0 180 2a5
2a9 :3 0 1d :2 0
57 :4 0 183 2ab
2ad :3 0 1d :2 0
8 :3 0 5e :3 0
2b0 2b1 0 186
2af 2b3 :3 0 189
2a2 2b5 :2 0 2b7
18c 2b8 294 2b7
0 2b9 18f 0
2c9 5f :3 0 14
:3 0 8 :3 0 5d
:3 0 60 :3 0 8
:3 0 5e :3 0 61
:3 0 62 :4 0 63
1 :a 0 2c5 :2 0
2c9 2bb 2c3 :2 0
7 :3 0 14 :3 0
2c7 :2 0 2c9 191
2cb 195 2ca 2c9
:2 0 31f 40 :3 0
8 :3 0 3d :3 0
2ce 2cf 0 3e
:3 0 2d0 2d1 0
317 15 :3 0 16
:3 0 2d3 2d4 0
15 :3 0 23 :3 0
2d6 2d7 0 41
:2 0 2 :4 0 64
:2 0 26 :2 0 24
:2 0 197 2dc 2de
:3 0 19a 2d8 2e0
2d5 2e2 2e1 :2 0
18 :3 0 27 :3 0
2e4 2e5 0 1a
:4 0 65 :4 0 1d
:2 0 1e :3 0 19e
2e9 2eb :3 0 1a1
2e6 2ed :2 0 307
18 :3 0 27 :3 0
2ef 2f0 0 1a
:4 0 44 :4 0 1d
:2 0 3e :3 0 1a4
2f4 2f6 :3 0 1d
:2 0 45 :4 0 1a7
2f8 2fa :3 0 1d
:2 0 46 :3 0 47
:3 0 24 :2 0 48
:2 0 1aa 2fd 301
1ae 2fc 303 :3 0
1b1 2f1 305 :2 0
307 1b4 308 2e3
307 0 309 1b7
0 317 5f :3 0
14 :3 0 60 :3 0
8 :3 0 5e :3 0
61 :3 0 62 :4 0
66 1 :a 0 313
:2 0 317 30b 311
:2 0 7 :3 0 14
:3 0 315 :2 0 317
1b9 31a :3 0 31a
0 31a 319 317
318 :6 0 31c 1
:3 0 1be 31e 1c0
31d 31c :2 0 31f
1c2 :2 0 321 1c5
321 320 280 31f
:6 0 322 :2 0 2
14 321 325 :3 0
324 322 326 :8 0

1ce
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
3e 1 44 1
51 1 5d 2
60 62 2 65
67 2 69 6b
2 6d 6f 2
71 73 2 75
77 2 79 7b
2 7d 7f 2
81 83 2 85
87 2 89 8b
2 8d 8f 2
91 93 4 59
5f 64 95 1
97 1 99 2
a3 a5 3 a1
a2 a7 2 b0
b2 2 af b4
1 b6 1 b8
1 ba 1 c0
1 c8 2 d8
da 3 d6 d7
dc 2 e5 e7
2 e9 eb 2
ed ef 1 f7
2 f9 fa 2
f1 fc 2 e4
fe 1 100 1
102 2 10c 10e
3 10a 10b 110
2 119 11b 2
118 11d 1 11f
1 121 2 128
129 3 103 122
12b 1 12d 2
13d 142 1 149
1 144 2 15c
15e 3 15a 15b
160 2 169 16b
2 16d 16f 2
171 173 2 175
177 2 179 17b
3 180 181 182
2 17d 184 2
168 186 1 188
1 18a 2 153
18b 1 18f 1
14e 2 14c 193
1 19e 2 19a
19e 2 1a7 1ac
1 1b3 1 1ae
2 1c6 1c8 3
1c4 1c5 1ca 2
1d3 1d5 2 1d7
1d9 2 1db 1dd
2 1df 1e1 2
1e3 1e5 3 1ea
1eb 1ec 2 1e7
1ee 2 1d2 1f0
1 1f2 1 1f4
2 1bd 1f5 1
1f9 1 1b8 2
1b6 1fd 2 200
206 1 20c 2
20e 20f 6 218
219 21a 21b 21c
21d 2 222 223
1 227 2 225
227 1 22e 1
230 2 23a 23c
3 238 239 23e
2 247 249 2
24b 24d 2 24f
251 1 257 2
259 25a 2 253
25c 2 25e 260
2 262 264 2
266 268 2 26a
26c 2 246 26e
1 270 1 272
2 278 279 3
27b 27c 27d d
9a b9 12e 131
134 137 196 210
215 220 231 273
27f 2 28c 28e
3 28a 28b 290
2 299 29b 2
298 29d 2 2a4
2a8 2 2aa 2ac
2 2ae 2b2 2
2a3 2b4 2 29f
2b6 1 2b8 3
2b9 2c4 2c8 1
283 2 2db 2dd
3 2d9 2da 2df
2 2e8 2ea 2
2e7 2ec 2 2f3
2f5 2 2f7 2f9
3 2fe 2ff 300
2 2fb 302 2
2f2 304 2 2ee
306 1 308 4
2d2 309 312 316
1 31a 1 2cd
2 2cb 31e 8
1b 22 29 30
36 3c 42 49

1
4
0 
325
0
1
14
6
c
0 1 2 1 4 1 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
7 1 0
3e 1 0
38 1 0
3 1 0
2 0 1
1d 1 0
32 1 0
24 1 0
44 1 0
0

/
SHOW ERRORS FUNCTION SP_A_CRIRES;
ALTER FUNCTION SP_A_CRIRES COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_REQRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_REQRES ==
CREATE OR REPLACE FUNCTION SP_A_REQRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
5a
2 :e:
1FUNCTION:
1SP_A_REQRES:
1ID001:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TYPE_ID:
1PLS_INTEGER:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_REQRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
123:
1+:
1FPUT:
1               ENTER:: SP_A_REQRES(24) :: cplan.sql(6985) :: :
1IS NULL:
18:
128:
1      RETURN_INVALID:: SP_A_REQRES(29) :: cplan.sql(6990) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
131:
1                EXIT:: SP_A_REQRES(32) :: cplan.sql(6993) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TYPE_ID:
1TMT_WBS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_WBS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
152:
1           EXCEPTION:: SP_A_REQRES(53) :: cplan.sql(7014) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
14:
164:
1       RETURN_STATUS:: SP_A_REQRES(65) :: cplan.sql(7026) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
171:
1           EXCEPTION:: SP_A_REQRES(72) :: cplan.sql(7033) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
183:
1           EXCEPTION:: SP_A_REQRES(84) :: cplan.sql(7045) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
284
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c a0 7e b4 2e 5a
a0 7e b4 2e 5a 52 10 a0
7e b4 2e :2 5a 52 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 b4 2e d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
284
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
119 104 108 e4 10c 114 103 120
124 100 128 12c 130 133 138 139
1 13b 140 144 148 14b 150 154
158 15b 160 161 163 168 16b 16f
170 175 17a 17d 182 183 188 18b
18f 190 195 198 19d 19e 1a3 1a6
1ab 1ac 1b1 1b4 1b9 1ba 1bf 1c2
1c6 1c7 1cc 1cf 1d4 1d5 1da 1dd
1e2 1e3 1e8 1eb 1f0 1f1 1f6 1f9
1fd 1fe 203 206 20b 20c 211 214
219 21a 21f 220 225 227 22b 22e
232 236 239 23d 241 244 247 24c
24f 252 255 256 25b 25c 1 25e
263 267 26b 26e 273 278 27b 27f
280 285 286 28b 28d 291 294 298
29b 29c 2a1 2a4 2a8 2ab 2ac 2b1
1 2b4 2b9 2bd 2c0 2c1 2c6 2c9
1 2cc 2d1 2d5 2d9 2dc 2e0 2e4
2e7 2ea 2ef 2f2 2f5 2f8 2f9 2fe
2ff 1 301 306 30a 30e 311 316
31b 31e 322 323 328 32b 330 331
336 339 33e 33f 344 347 34b 34f
353 357 35a 35b 35d 362 363 365
366 36b 36c 371 373 377 37a 37e
382 385 389 38d 390 393 398 39b
39e 3a1 3a2 3a7 3a8 1 3aa 3af
3b3 3b7 3ba 3bf 3c4 3c7 3cb 3cc
3d1 3d2 3d7 3d9 3dd 3e0 3e4 3e8
3eb 3ef 3f3 3f6 3fa 3fb 400 402
406 409 40d 411 415 419 41d 421
425 429 42d 431 435 439 43d 441
44d 451 455 458 45c 460 462 466
46a 46e 471 475 479 47b 47c 481
1 485 489 48d 490 494 498 49c
4a0 4a3 4a7 4ab 4ae 4b1 4b6 4b9
4bc 4bf 4c0 4c5 4c6 1 4c8 4cd
4d1 4d5 4d8 4dd 4e2 4e5 4e9 4ea
4ef 4f2 4f7 4f8 4fd 500 505 506
50b 50e 512 513 518 51b 520 521
526 529 52d 531 534 537 538 53a
53b 540 541 546 548 54c 54f 551
555 557 563 565 567 568 56d 571
573 57f 581 585 589 58a 58f 593
597 59b 59e 5a2 5a6 5a9 5ac 5b1
5b4 5b7 5ba 5bb 5c0 5c1 1 5c3
5c8 5cc 5d0 5d3 5d8 5dd 5e0 5e4
5e5 5ea 5ed 5f2 5f3 5f8 5fb 600
601 606 609 60d 611 615 619 61c
61d 61f 624 625 627 628 62d 630
635 636 63b 63e 643 644 649 64c
650 651 656 659 65e 65f 664 665
66a 66c 670 673 677 67b 67e 682
686 689 68d 691 692 697 699 69d
6a1 6a4 6a8 6ac 6af 6b3 6b7 6ba
6bd 6c2 6c5 6c8 6cb 6cc 6d1 6d2
1 6d4 6d9 6dd 6e1 6e4 6e9 6ee
6f1 6f5 6f6 6fb 6fc 701 705 709
70c 711 716 719 71d 721 724 725
72a 72d 732 733 738 73b 73f 743
746 747 74c 74d 752 754 758 75b
75f 763 767 76b 76f 773 777 77b
77f 78b 790 794 798 79c 7a0 7a2
7a3 7a8 1 7ac 7b0 7b4 7b7 7bb
7bf 7c3 7c7 7ca 7ce 7d2 7d5 7d8
7dd 7e0 7e3 7e6 7e7 7ec 7ed 1
7ef 7f4 7f8 7fc 7ff 804 809 80c
810 811 816 817 81c 820 824 827
82c 831 834 838 839 83e 841 846
847 84c 84f 853 857 85a 85d 85e
860 861 866 867 86c 86e 872 875
879 87d 881 885 889 88d 891 89d
8a2 8a6 8aa 8ae 8b2 8b4 8b8 8ba
8c6 8c8 8ca 8cb 8d0 8d4 8d6 8e2
8e6 8e8 8e9 8f2 
284
2
0 1 a 6 c :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 e 1d e
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 53 59 5c :2 53 6a 7f
8 :2 6a d 10 :2 6a 16 19 :2 6a
b e :2 6a 13 16 :2 6a 1b 1e
:2 6a 28 2b :2 6a b e :2 6a 13
16 :2 6a 1b 1e :2 6a 2a 2d :2 6a
32 35 :2 6a :2 7 49 :2 4 7 :2 11
23 :2 2d 39 3c 4b 4d 4e :2 4b
:2 23 :3 7 :2 d 12 1e 5b 5e :2 1e
:2 7 51 :2 4 :4 8 7 :4 1b 1a :2 7
:4 33 32 31 :2 7 a :2 14 26 :2 30
3c 3f 4e 50 51 :2 4e :2 26 :3 a
:2 10 15 21 5e 61 :2 21 6e 71
:2 21 75 78 :2 21 82 85 8e 96
:2 9f :2 8e b0 :2 85 :2 21 :2 a 54 :2 7
a :2 14 26 :2 30 3c 3f 4e 50
51 :2 4e :2 26 :3 a :2 10 15 21 5e
61 :2 21 :2 a 54 :3 7 :2 12 28 :2 31
41 :2 7 49 :3 4 14 :2 4 15 :2 4
12 4 e 1b 2a 38 45 :2 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 52 54
55 :2 52 :2 29 :3 d :2 13 18 24 61
64 :2 24 71 74 :2 24 78 7b :2 24
87 8a :2 24 92 95 :2 24 a1 a4
ab b4 b7 :2 a4 :2 24 :2 d 58 :2 a
:2 7 :4 13 :2 7 4 :3 1 4 :3 f 4
7 :2 11 23 :2 2d 39 3c 4b 4d
4e :2 4b :2 23 :3 7 :2 d 12 1e 5b
5e :2 1e 6b 6e :2 1e 72 75 :2 1e
7f 82 8b 93 :2 9c :2 8b a7 :2 82
:2 1e af b2 :2 1e ba bd :2 1e c2
c5 :2 1e cd d0 :2 1e :2 7 51 :3 4
:2 f 21 :2 2a 34 3d :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
4f 51 52 :2 4f :2 26 :3 a :2 10 15
21 5e 61 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 55 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4c 4e 4f :2 4c :2 23 :3 7 :2 d 12
1e 5b 5e :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 52 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
284
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :7 e :b 10 :11 11
12 :2 11 :2 12 :2 11
:2 12 :2 11 :2 13 :2 11
:2 13 :2 11 :2 13 :2 11
:2 13 :2 11 :2 14 :2 11
:2 14 :2 11 :2 14 :2 11
:2 14 :2 11 :2 14 :4 11
:3 10 :11 17 :b 18 :3 17
:14 1b :11 1c :20 1d :3 1c
:11 1f :b 20 :3 1f :9 22
:3 1b :3 27 :3 28 :3 29
:6 2c :5 2d 2b 2f
:5 30 :3 2f :2 31 :5 33
:11 34 :24 35 :3 34 :2 32
:6 31 2e :3 f :5 3c
:11 40 :30 41 :3 40 :a 43
f :3 46 :11 47 :b 48
:17 49 :3 47 :2 4b :3 4c
:3 4d 4e 4c 4b
4c :3 4f :3 46 :2 50
:5 52 :11 53 :b 54 :18 55
:3 53 :2 57 58 :3 59
5a 58 57 58
:3 5b :2 51 :6 50 45
:7 1 
8f4
4
:3 0 1 :3 0 2
:a 0 27f 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 27f 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 27d
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 27d
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 27d
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 27d
0 e :6 0 39
3a 0 1d 10
:3 0 33 :7 0 37
34 35 27d 0
f :6 0 3f 40
0 1f 8 :3 0
9 :2 0 4 3b
:7 0 3e 3c 0
27d 0 12 :6 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
42 43 0 2
:4 0 21 44 46
41 48 47 :2 0
16 :3 0 17 :3 0
4a 4b 0 18
:4 0 13 :3 0 19
:3 0 4e 4f 0
2 :4 0 23 50
52 1a :4 0 1b
:2 0 1c :3 0 25
55 57 :3 0 1d
:4 0 1b :2 0 1e
:4 0 28 5a 5c
:3 0 1b :2 0 3
:3 0 2b 5e 60
:3 0 1b :2 0 1e
:4 0 2e 62 64
:3 0 1b :2 0 1f
:4 0 31 66 68
:3 0 1b :2 0 1e
:4 0 34 6a 6c
:3 0 1b :2 0 5
:3 0 37 6e 70
:3 0 1b :2 0 1e
:4 0 3a 72 74
:3 0 1b :2 0 1f
:4 0 3d 76 78
:3 0 1b :2 0 1e
:4 0 40 7a 7c
:3 0 1b :2 0 6
:3 0 43 7e 80
:3 0 1b :2 0 1e
:4 0 46 82 84
:3 0 1b :2 0 20
:4 0 49 86 88
:3 0 :2 4c 8a :2 0
8c 51 8d 49
8c 0 8e 53
0 1dd 13 :3 0
14 :3 0 8f 90
0 13 :3 0 21
:3 0 92 93 0
22 :2 0 2 :4 0
23 :2 0 24 :2 0
22 :2 0 55 98
9a :3 0 58 94
9c 91 9e 9d
:2 0 16 :3 0 25
:3 0 a0 a1 0
18 :4 0 26 :4 0
1b :2 0 1c :3 0
5c a5 a7 :3 0
5f a2 a9 :2 0
ab 62 ac 9f
ab 0 ad 64
0 1dd 3 :3 0
27 :2 0 66 af
b0 :3 0 b1 :2 0
5 :3 0 27 :2 0
68 b4 b5 :3 0
b6 :2 0 b2 b8
b7 :2 0 6 :3 0
27 :2 0 6a bb
bc :3 0 bd :2 0
be :2 0 b9 c0
bf :2 0 13 :3 0
14 :3 0 c2 c3
0 13 :3 0 21
:3 0 c5 c6 0
28 :2 0 2 :4 0
29 :2 0 24 :2 0
22 :2 0 6c cb
cd :3 0 6f c7
cf c4 d1 d0
:2 0 16 :3 0 25
:3 0 d3 d4 0
18 :4 0 2a :4 0
1b :2 0 1c :3 0
73 d8 da :3 0
1b :2 0 2b :4 0
76 dc de :3 0
1b :2 0 2c :4 0
79 e0 e2 :3 0
1b :2 0 2d :3 0
2e :3 0 2f :3 0
30 :3 0 e7 e8
0 7c e6 ea
31 :4 0 7e e5
ed 81 e4 ef
:3 0 84 d5 f1
:2 0 f3 87 f4
d2 f3 0 f5
89 0 11e 13
:3 0 14 :3 0 f6
f7 0 13 :3 0
21 :3 0 f9 fa
0 22 :2 0 2
:4 0 32 :2 0 24
:2 0 22 :2 0 8b
ff 101 :3 0 8e
fb 103 f8 105
104 :2 0 16 :3 0
25 :3 0 107 108
0 18 :4 0 33
:4 0 1b :2 0 1c
:3 0 92 10c 10e
:3 0 95 109 110
:2 0 112 98 113
106 112 0 114
9a 0 11e 34
:3 0 35 :3 0 115
116 0 2f :3 0
30 :3 0 118 119
0 36 :3 0 9c
117 11c :2 0 11e
9f 11f c1 11e
0 120 a3 0
1dd a :3 0 3
:3 0 121 122 0
1dd e :3 0 5
:3 0 124 125 0
1dd d :3 0 6
:3 0 127 128 0
1dd 37 :3 0 f
:3 0 38 :3 0 39
:3 0 a :4 0 3a
1 :8 0 135 8
:3 0 3b :3 0 130
131 0 3c :3 0
132 133 0 135
a5 188 3d :3 0
8 :3 0 3b :3 0
137 138 0 3c
:3 0 139 13a 0
13c a8 13e aa
13d 13c :2 0 186
3e :3 0 8 :3 0
3b :3 0 141 142
0 3c :3 0 143
144 0 17e 13
:3 0 14 :3 0 146
147 0 13 :3 0
21 :3 0 149 14a
0 3f :2 0 2
:4 0 40 :2 0 24
:2 0 22 :2 0 ac
14f 151 :3 0 af
14b 153 148 155
154 :2 0 16 :3 0
25 :3 0 157 158
0 18 :4 0 41
:4 0 1b :2 0 1c
:3 0 b3 15c 15e
:3 0 1b :2 0 2b
:4 0 b6 160 162
:3 0 1b :2 0 42
:4 0 b9 164 166
:3 0 1b :2 0 3c
:3 0 bc 168 16a
:3 0 1b :2 0 43
:4 0 bf 16c 16e
:3 0 1b :2 0 44
:3 0 45 :3 0 22
:2 0 46 :2 0 c2
171 175 c6 170
177 :3 0 c9 159
179 :2 0 17b cc
17c 156 17b 0
17d ce 0 17e
d0 181 :3 0 181
0 181 180 17e
17f :6 0 183 2
:3 0 d3 185 d5
184 183 :2 0 186
d7 :2 0 188 0
188 187 135 186
:6 0 1dd 1 :3 0
c :3 0 47 :4 0
18b 18c :3 0 18a
18d 0 1dd 13
:3 0 14 :3 0 18f
190 0 13 :3 0
21 :3 0 192 193
0 48 :2 0 2
:4 0 49 :2 0 24
:2 0 22 :2 0 da
198 19a :3 0 dd
194 19c 191 19e
19d :2 0 16 :3 0
25 :3 0 1a0 1a1
0 18 :4 0 4a
:4 0 1b :2 0 1c
:3 0 e1 1a5 1a7
:3 0 1b :2 0 2b
:4 0 e4 1a9 1ab
:3 0 1b :2 0 2c
:4 0 e7 1ad 1af
:3 0 1b :2 0 2d
:3 0 2e :3 0 8
:3 0 3b :3 0 1b4
1b5 0 ea 1b3
1b7 31 :4 0 ec
1b2 1ba ef 1b1
1bc :3 0 1b :2 0
4b :4 0 f2 1be
1c0 :3 0 1b :2 0
1e :4 0 f5 1c2
1c4 :3 0 1b :2 0
c :3 0 f8 1c6
1c8 :3 0 1b :2 0
1e :4 0 fb 1ca
1cc :3 0 fe 1a2
1ce :2 0 1d0 101
1d1 19f 1d0 0
1d2 103 0 1dd
34 :3 0 4c :3 0
1d3 1d4 0 8
:3 0 3b :3 0 1d6
1d7 0 c :3 0
36 :3 0 105 1d5
1db :2 0 1dd 109
27e 8 :3 0 4d
:2 0 4 1de 1df
0 13 :3 0 14
:3 0 1e1 1e2 0
13 :3 0 21 :3 0
1e4 1e5 0 3f
:2 0 2 :4 0 4e
:2 0 24 :2 0 22
:2 0 114 1ea 1ec
:3 0 117 1e6 1ee
1e3 1f0 1ef :2 0
16 :3 0 25 :3 0
1f2 1f3 0 18
:4 0 4f :4 0 1b
:2 0 1c :3 0 11b
1f7 1f9 :3 0 11e
1f4 1fb :2 0 214
16 :3 0 25 :3 0
1fd 1fe 0 18
:4 0 50 :4 0 1b
:2 0 8 :3 0 51
:3 0 203 204 0
121 202 206 :3 0
1b :2 0 4b :4 0
124 208 20a :3 0
1b :2 0 8 :3 0
52 :3 0 20d 20e
0 127 20c 210
:3 0 12a 1ff 212
:2 0 214 12d 215
1f1 214 0 216
130 0 226 53
:3 0 12 :3 0 8
:3 0 51 :3 0 54
:3 0 8 :3 0 52
:3 0 55 :3 0 56
:4 0 57 1 :a 0
222 :2 0 226 218
220 :2 0 7 :3 0
12 :3 0 224 :2 0
226 132 228 136
227 226 :2 0 27c
3e :3 0 8 :3 0
3b :3 0 22b 22c
0 3c :3 0 22d
22e 0 274 13
:3 0 14 :3 0 230
231 0 13 :3 0
21 :3 0 233 234
0 3f :2 0 2
:4 0 58 :2 0 24
:2 0 22 :2 0 138
239 23b :3 0 13b
235 23d 232 23f
23e :2 0 16 :3 0
25 :3 0 241 242
0 18 :4 0 59
:4 0 1b :2 0 1c
:3 0 13f 246 248
:3 0 142 243 24a
:2 0 264 16 :3 0
25 :3 0 24c 24d
0 18 :4 0 42
:4 0 1b :2 0 3c
:3 0 145 251 253
:3 0 1b :2 0 43
:4 0 148 255 257
:3 0 1b :2 0 44
:3 0 45 :3 0 22
:2 0 46 :2 0 14b
25a 25e 14f 259
260 :3 0 152 24e
262 :2 0 264 155
265 240 264 0
266 158 0 274
53 :3 0 12 :3 0
54 :3 0 8 :3 0
52 :3 0 55 :3 0
56 :4 0 5a 1
:a 0 270 :2 0 274
268 26e :2 0 7
:3 0 12 :3 0 272
:2 0 274 15a 277
:3 0 277 0 277
276 274 275 :6 0
279 1 :3 0 15f
27b 161 27a 279
:2 0 27c 163 :2 0
27e 166 27e 27d
1dd 27c :6 0 27f
:2 0 2 14 27e
282 :3 0 281 27f
283 :8 0 
16d
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
45 1 51 2
54 56 2 59
5b 2 5d 5f
2 61 63 2
65 67 2 69
6b 2 6d 6f
2 71 73 2
75 77 2 79
7b 2 7d 7f
2 81 83 2
85 87 4 4d
53 58 89 1
8b 1 8d 2
97 99 3 95
96 9b 2 a4
a6 2 a3 a8
1 aa 1 ac
1 ae 1 b3
1 ba 2 ca
cc 3 c8 c9
ce 2 d7 d9
2 db dd 2
df e1 1 e9
2 eb ec 2
e3 ee 2 d6
f0 1 f2 1
f4 2 fe 100
3 fc fd 102
2 10b 10d 2
10a 10f 1 111
1 113 2 11a
11b 3 f5 114
11d 1 11f 2
12f 134 1 13b
1 136 2 14e
150 3 14c 14d
152 2 15b 15d
2 15f 161 2
163 165 2 167
169 2 16b 16d
3 172 173 174
2 16f 176 2
15a 178 1 17a
1 17c 2 145
17d 1 181 1
140 2 13e 185
2 197 199 3
195 196 19b 2
1a4 1a6 2 1a8
1aa 2 1ac 1ae
1 1b6 2 1b8
1b9 2 1b0 1bb
2 1bd 1bf 2
1c1 1c3 2 1c5
1c7 2 1c9 1cb
2 1a3 1cd 1
1cf 1 1d1 3
1d8 1d9 1da a
8e ad 120 123
126 129 188 18e
1d2 1dc 2 1e9
1eb 3 1e7 1e8
1ed 2 1f6 1f8
2 1f5 1fa 2
201 205 2 207
209 2 20b 20f
2 200 211 2
1fc 213 1 215
3 216 221 225
1 1e0 2 238
23a 3 236 237
23c 2 245 247
2 244 249 2
250 252 2 254
256 3 25b 25c
25d 2 258 25f
2 24f 261 2
24b 263 1 265
4 22f 266 26f
273 1 277 1
22a 2 228 27b
6 1b 22 29
30 36 3d 
1
4
0 
282
0
1
14
4
a
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
7 1 0
32 1 0
3 1 0
1d 1 0
24 1 0
2 0 1
38 1 0
0

/
SHOW ERRORS FUNCTION SP_A_REQRES;
ALTER FUNCTION SP_A_REQRES COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_POOLRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_POOLRES ==
CREATE OR REPLACE FUNCTION SP_A_POOLRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
60
2 :e:
1FUNCTION:
1SP_A_POOLRES:
1ID001:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
1PLS_INTEGER:
10:
1H_TYPE_ID:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_POOLRES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
125:
1+:
1FPUT:
1               ENTER:: SP_A_POOLRES(26) :: cplan.sql(7095) :: :
1IS NULL:
18:
130:
1      RETURN_INVALID:: SP_A_POOLRES(31) :: cplan.sql(7100) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
133:
1                EXIT:: SP_A_POOLRES(34) :: cplan.sql(7103) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_TABLE_POL:
1TYPE_ID:
1TMT_POOLS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_POOLS WHERE ELEMENT_ID = h_element_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
155:
1           EXCEPTION:: SP_A_POOLRES(56) :: cplan.sql(7125) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SYS_GUID:
1ASSIGNRESOURCE:
1=:
1RECORD_ALREADY_ASSIGNED:
14:
170:
1       RETURN_STATUS:: SP_A_POOLRES(71) :: cplan.sql(7140) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
177:
1           EXCEPTION:: SP_A_POOLRES(78) :: cplan.sql(7147) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
189:
1           EXCEPTION:: SP_A_POOLRES(90) :: cplan.sql(7159) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2b3
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c a0
7e b4 2e :2 5a a0 7e b4 2e
:2 5a 52 10 a0 7e b4 2e :2 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c :2 a0 d :2 a0 d
:2 a0 d :3 a0 6b d :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
b4 2e d :8 a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e :3 a0
6b d b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 51 a5 b :2 a0
a5 57 b7 :2 a0 6b :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e a5 57
b7 19 3c :9 a0 12a e9 dd :2 a0
65 b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c :7 a0 12a e9 dd :2 a0 65 b7
a4 b1 11 4f b7 a6 9 a4
b1 11 68 4f 1d 17 b5 
2b3
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca f9 e8 ec c7 f4 e7
115 104 108 e4 110 103 131 120
124 100 12c 11f 151 13c 140 11c
144 14c 13b 158 15c 138 160 164
168 16b 170 171 1 173 178 17c
180 183 188 18c 190 193 198 199
19b 1a0 1a3 1a7 1a8 1ad 1b2 1b5
1ba 1bb 1c0 1c3 1c7 1c8 1cd 1d0
1d5 1d6 1db 1de 1e3 1e4 1e9 1ec
1f1 1f2 1f7 1fa 1fe 1ff 204 207
20c 20d 212 215 21a 21b 220 223
228 229 22e 231 235 236 23b 23e
243 244 249 24c 251 252 257 258
25d 25f 263 266 26a 26e 271 275
279 27c 27f 284 287 28a 28d 28e
293 294 1 296 29b 29f 2a3 2a6
2ab 2b0 2b3 2b7 2b8 2bd 2be 2c3
2c5 2c9 2cc 2d0 2d3 2d4 2d9 2dc
2df 2e3 2e6 2e7 2ec 2ef 1 2f2
2f7 2fb 2fe 2ff 304 307 1 30a
30f 313 317 31a 31e 322 325 328
32d 330 333 336 337 33c 33d 1
33f 344 348 34c 34f 354 359 35c
360 361 366 369 36e 36f 374 377
37c 37d 382 385 389 38d 391 395
398 399 39b 3a0 3a1 3a3 3a4 3a9
3aa 3af 3b1 3b5 3b8 3bc 3c0 3c3
3c7 3cb 3ce 3d1 3d6 3d9 3dc 3df
3e0 3e5 3e6 1 3e8 3ed 3f1 3f5
3f8 3fd 402 405 409 40a 40f 410
415 417 41b 41e 422 426 429 42d
431 434 438 439 43e 440 444 447
44b 44f 453 457 45b 45f 463 467
46b 46f 473 477 47a 47e 482 486
48a 48e 492 49e 4a2 4a6 4a9 4ad
4b1 4b3 4b7 4bb 4bf 4c2 4c6 4ca
4cc 4cd 4d2 1 4d6 4da 4de 4e1
4e5 4e9 4ed 4f1 4f4 4f8 4fc 4ff
502 507 50a 50d 510 511 516 517
1 519 51e 522 526 529 52e 533
536 53a 53b 540 543 548 549 54e
551 556 557 55c 55f 563 564 569
56c 571 572 577 57a 57e 582 585
588 589 58b 58c 591 592 597 599
59d 5a0 5a2 5a6 5a8 5b4 5b6 5b8
5b9 5be 5c2 5c4 5d0 5d2 5d6 5da
5db 5e0 5e4 5e8 5ec 5f0 5f4 5f8
5fc 600 604 605 607 60b 60f 613
616 617 619 61c 61f 620 625 629
62d 631 634 638 63a 63e 641 645
649 64c 650 654 657 65a 65f 662
665 668 669 66e 66f 1 671 676
67a 67e 681 686 68b 68e 692 693
698 69b 6a0 6a1 6a6 6a9 6ae 6af
6b4 6b7 6bb 6bf 6c3 6c4 6c6 6cb
6cc 6ce 6cf 6d4 6d7 6dc 6dd 6e2
6e5 6ea 6eb 6f0 6f3 6f7 6f8 6fd
700 705 706 70b 70c 711 713 717
71a 71e 722 725 729 72d 730 731
733 737 73b 73c 741 743 747 74b
74e 752 756 759 75d 761 764 767
76c 76f 772 775 776 77b 77c 1
77e 783 787 78b 78e 793 798 79b
79f 7a0 7a5 7a6 7ab 7af 7b3 7b6
7bb 7c0 7c3 7c7 7cb 7ce 7cf 7d4
7d7 7dc 7dd 7e2 7e5 7e9 7ed 7f0
7f1 7f6 7f7 7fc 7fe 802 805 809
80d 811 815 819 81d 821 825 829
835 83a 83e 842 846 84a 84c 84d
852 1 856 85a 85e 861 865 869
86d 871 874 878 87c 87f 882 887
88a 88d 890 891 896 897 1 899
89e 8a2 8a6 8a9 8ae 8b3 8b6 8ba
8bb 8c0 8c1 8c6 8ca 8ce 8d1 8d6
8db 8de 8e2 8e3 8e8 8eb 8f0 8f1
8f6 8f9 8fd 901 904 907 908 90a
90b 910 911 916 918 91c 91f 923
927 92b 92f 933 937 93b 947 94c
950 954 958 95c 95e 962 964 970
972 974 975 97a 97e 980 98c 990
992 993 99c 
2b3
2
0 1 a 6 c :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 11 1a 19 :2 11 :2 4 c 15
14 :2 c :2 4 f 18 17 :2 f :2 4
12 1b 1a :2 12 :2 4 :2 11 20 11
:2 4 :2 e 1d e :2 4 :2 14 23 14
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 54 5a 5d :2 54 6b 81
8 :2 6b d 10 :2 6b 16 19 :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 28 2b :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 2a 2d :2 6b
32 35 :2 6b :2 7 4a :2 4 7 :2 11
23 :2 2d 39 3c 4c 4e 4f :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:2 7 52 :2 4 :4 9 8 7 :4 1e 1d
1c :2 7 :4 37 36 35 :2 7 a :2 14
26 :2 30 3c 3f 4f 51 52 :2 4f
:2 26 :3 a :2 10 15 21 5f 62 :2 21
6f 72 :2 21 76 79 :2 21 83 86
8f 97 :2 a0 :2 8f b1 :2 86 :2 21 :2 a
55 :2 7 a :2 14 26 :2 30 3c 3f
4f 51 52 :2 4f :2 26 :3 a :2 10 15
21 5f 62 :2 21 :2 a 55 :3 7 :2 12
28 :2 31 41 :2 7 4d :3 4 14 :2 4
15 :2 4 12 :2 4 14 :2 1d 4 e
1b 2a 3a 47 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 53 55 56 :2 53 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 88 8b :2 24
93 96 :2 24 a2 a5 ac b5 b8
:2 a5 :2 24 :2 d 59 :2 a :2 7 :4 13 :2 7
4 :3 1 4 :3 f :2 4 17 26 34
3f 4d 5c 25 :2 17 4 7 10
21 :2 7 24 26 :2 24 7 1a :2 23
7 28 :2 4 7 :2 11 23 :2 2d 39
3c 4c 4e 4f :2 4c :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e 6c 6f :2 1e
73 76 :2 1e 80 83 8c 94 :2 8c
a6 :2 83 :2 1e ae b1 :2 1e b9 bc
:2 1e c1 c4 :2 1e cc cf :2 1e :2 7
52 :3 4 :2 f 21 2a 3b :2 21 3f
48 :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 50 52 53 :2 50
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
56 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4d 4f 50 :2 4d
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 53 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
2b3
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:6 c :6 d :6 e :7 10
:b 12 :11 13 14 :2 13
:2 14 :2 13 :2 14 :2 13
:2 15 :2 13 :2 15 :2 13
:2 15 :2 13 :2 15 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :2 13 :2 16 :2 13
:2 16 :4 13 :3 12 :11 19
:b 1a :3 19 :16 1d :11 1e
:20 1f :3 1e :11 21 :b 22
:3 21 :9 24 :3 1d :3 29
:3 2a :3 2b :5 2c :6 2f
:5 30 2e 32 :5 33
:3 32 :2 34 :5 36 :11 37
:24 38 :3 37 :2 35 :6 34
31 :3 11 :5 3d :7 3f
40 :3 3f :9 42 :5 43
:3 42 :11 46 :2e 47 :3 46
:c 49 11 :3 4c :11 4d
:b 4e :17 4f :3 4d :2 51
:3 52 :3 53 54 52
51 52 :3 55 :3 4c
:2 56 :5 58 :11 59 :b 5a
:18 5b :3 59 :2 5d 5e
:3 5f 60 5e 5d
5e :3 61 :2 57 :6 56
4b :7 1 
99e
4
:3 0 1 :3 0 2
:a 0 2ae 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 2ae 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 2ac
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 2ac
0 c :6 0 b
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 2ac
0 d :6 0 11
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 2ac
0 e :6 0 11
:2 0 1d 10 :3 0
33 :7 0 37 34
35 2ac 0 f
:6 0 11 :2 0 1f
10 :3 0 39 :7 0
3d 3a 3b 2ac
0 12 :6 0 45
46 0 21 10
:3 0 3f :7 0 43
40 41 2ac 0
13 :6 0 4b 4c
0 23 8 :3 0
9 :2 0 4 47
:7 0 4a 48 0
2ac 0 14 :6 0
15 :3 0 16 :3 0
15 :3 0 17 :3 0
4e 4f 0 2
:4 0 25 50 52
4d 54 53 :2 0
18 :3 0 19 :3 0
56 57 0 1a
:4 0 15 :3 0 1b
:3 0 5a 5b 0
2 :4 0 27 5c
5e 1c :4 0 1d
:2 0 1e :3 0 29
61 63 :3 0 1f
:4 0 1d :2 0 20
:4 0 2c 66 68
:3 0 1d :2 0 3
:3 0 2f 6a 6c
:3 0 1d :2 0 20
:4 0 32 6e 70
:3 0 1d :2 0 21
:4 0 35 72 74
:3 0 1d :2 0 20
:4 0 38 76 78
:3 0 1d :2 0 5
:3 0 3b 7a 7c
:3 0 1d :2 0 20
:4 0 3e 7e 80
:3 0 1d :2 0 21
:4 0 41 82 84
:3 0 1d :2 0 20
:4 0 44 86 88
:3 0 1d :2 0 6
:3 0 47 8a 8c
:3 0 1d :2 0 20
:4 0 4a 8e 90
:3 0 1d :2 0 22
:4 0 4d 92 94
:3 0 50 58 96
:2 0 98 55 99
55 98 0 9a
57 0 20c 15
:3 0 16 :3 0 9b
9c 0 15 :3 0
23 :3 0 9e 9f
0 24 :2 0 2
:4 0 25 :2 0 26
:2 0 24 :2 0 59
a4 a6 :3 0 5c
a0 a8 9d aa
a9 :2 0 18 :3 0
27 :3 0 ac ad
0 1a :4 0 28
:4 0 1d :2 0 1e
:3 0 60 b1 b3
:3 0 63 ae b5
:2 0 b7 66 b8
ab b7 0 b9
68 0 20c 3
:3 0 29 :2 0 6a
bb bc :3 0 bd
:2 0 be :2 0 5
:3 0 29 :2 0 6c
c1 c2 :3 0 c3
:2 0 c4 :2 0 bf
c6 c5 :2 0 6
:3 0 29 :2 0 6e
c9 ca :3 0 cb
:2 0 cc :2 0 c7
ce cd :2 0 15
:3 0 16 :3 0 d0
d1 0 15 :3 0
23 :3 0 d3 d4
0 2a :2 0 2
:4 0 2b :2 0 26
:2 0 24 :2 0 70
d9 db :3 0 73
d5 dd d2 df
de :2 0 18 :3 0
27 :3 0 e1 e2
0 1a :4 0 2c
:4 0 1d :2 0 1e
:3 0 77 e6 e8
:3 0 1d :2 0 2d
:4 0 7a ea ec
:3 0 1d :2 0 2e
:4 0 7d ee f0
:3 0 1d :2 0 2f
:3 0 30 :3 0 31
:3 0 32 :3 0 f5
f6 0 80 f4
f8 33 :4 0 82
f3 fb 85 f2
fd :3 0 88 e3
ff :2 0 101 8b
102 e0 101 0
103 8d 0 12c
15 :3 0 16 :3 0
104 105 0 15
:3 0 23 :3 0 107
108 0 24 :2 0
2 :4 0 34 :2 0
26 :2 0 24 :2 0
8f 10d 10f :3 0
92 109 111 106
113 112 :2 0 18
:3 0 27 :3 0 115
116 0 1a :4 0
35 :4 0 1d :2 0
1e :3 0 96 11a
11c :3 0 99 117
11e :2 0 120 9c
121 114 120 0
122 9e 0 12c
36 :3 0 37 :3 0
123 124 0 31
:3 0 32 :3 0 126
127 0 38 :3 0
a0 125 12a :2 0
12c a3 12d cf
12c 0 12e a7
0 20c a :3 0
3 :3 0 12f 130
0 20c e :3 0
5 :3 0 132 133
0 20c d :3 0
6 :3 0 135 136
0 20c f :3 0
31 :3 0 39 :3 0
139 13a 0 138
13b 0 20c 3a
:3 0 12 :3 0 3b
:3 0 3c :3 0 a
:4 0 3d 1 :8 0
148 8 :3 0 3e
:3 0 143 144 0
3f :3 0 145 146
0 148 a9 19b
40 :3 0 8 :3 0
3e :3 0 14a 14b
0 3f :3 0 14c
14d 0 14f ac
151 ae 150 14f
:2 0 199 41 :3 0
8 :3 0 3e :3 0
154 155 0 3f
:3 0 156 157 0
191 15 :3 0 16
:3 0 159 15a 0
15 :3 0 23 :3 0
15c 15d 0 42
:2 0 2 :4 0 43
:2 0 26 :2 0 24
:2 0 b0 162 164
:3 0 b3 15e 166
15b 168 167 :2 0
18 :3 0 27 :3 0
16a 16b 0 1a
:4 0 44 :4 0 1d
:2 0 1e :3 0 b7
16f 171 :3 0 1d
:2 0 2d :4 0 ba
173 175 :3 0 1d
:2 0 45 :4 0 bd
177 179 :3 0 1d
:2 0 3f :3 0 c0
17b 17d :3 0 1d
:2 0 46 :4 0 c3
17f 181 :3 0 1d
:2 0 47 :3 0 48
:3 0 24 :2 0 49
:2 0 c6 184 188
ca 183 18a :3 0
cd 16c 18c :2 0
18e d0 18f 169
18e 0 190 d2
0 191 d4 194
:3 0 194 0 194
193 191 192 :6 0
196 2 :3 0 d7
198 d9 197 196
:2 0 199 db :2 0
19b 0 19b 19a
148 199 :6 0 20c
1 :3 0 c :3 0
4a :4 0 19e 19f
:3 0 19d 1a0 0
20c 13 :3 0 4b
:3 0 f :3 0 12
:3 0 a :3 0 e
:3 0 d :3 0 c
:3 0 de 1a3 1aa
1a2 1ab 0 20c
2f :3 0 13 :3 0
11 :2 0 e5 1ad
1b0 4c :2 0 24
:2 0 ea 1b2 1b4
:3 0 13 :3 0 31
:3 0 4d :3 0 1b7
1b8 0 1b6 1b9
0 1bb ed 1bc
1b5 1bb 0 1bd
ef 0 20c 15
:3 0 16 :3 0 1be
1bf 0 15 :3 0
23 :3 0 1c1 1c2
0 4e :2 0 2
:4 0 4f :2 0 26
:2 0 24 :2 0 f1
1c7 1c9 :3 0 f4
1c3 1cb 1c0 1cd
1cc :2 0 18 :3 0
27 :3 0 1cf 1d0
0 1a :4 0 50
:4 0 1d :2 0 1e
:3 0 f8 1d4 1d6
:3 0 1d :2 0 2d
:4 0 fb 1d8 1da
:3 0 1d :2 0 2e
:4 0 fe 1dc 1de
:3 0 1d :2 0 2f
:3 0 30 :3 0 13
:3 0 101 1e2 1e4
33 :4 0 103 1e1
1e7 106 1e0 1e9
:3 0 1d :2 0 51
:4 0 109 1eb 1ed
:3 0 1d :2 0 20
:4 0 10c 1ef 1f1
:3 0 1d :2 0 c
:3 0 10f 1f3 1f5
:3 0 1d :2 0 20
:4 0 112 1f7 1f9
:3 0 115 1d1 1fb
:2 0 1fd 118 1fe
1ce 1fd 0 1ff
11a 0 20c 36
:3 0 52 :3 0 200
201 0 2f :3 0
13 :3 0 11 :2 0
11c 203 206 c
:3 0 38 :3 0 11f
202 20a :2 0 20c
123 2ad 8 :3 0
53 :2 0 4 20d
20e 0 15 :3 0
16 :3 0 210 211
0 15 :3 0 23
:3 0 213 214 0
42 :2 0 2 :4 0
54 :2 0 26 :2 0
24 :2 0 131 219
21b :3 0 134 215
21d 212 21f 21e
:2 0 18 :3 0 27
:3 0 221 222 0
1a :4 0 55 :4 0
1d :2 0 1e :3 0
138 226 228 :3 0
13b 223 22a :2 0
243 18 :3 0 27
:3 0 22c 22d 0
1a :4 0 56 :4 0
1d :2 0 8 :3 0
57 :3 0 232 233
0 13e 231 235
:3 0 1d :2 0 51
:4 0 141 237 239
:3 0 1d :2 0 8
:3 0 58 :3 0 23c
23d 0 144 23b
23f :3 0 147 22e
241 :2 0 243 14a
244 220 243 0
245 14d 0 255
59 :3 0 14 :3 0
8 :3 0 57 :3 0
5a :3 0 8 :3 0
58 :3 0 5b :3 0
5c :4 0 5d 1
:a 0 251 :2 0 255
247 24f :2 0 7
:3 0 14 :3 0 253
:2 0 255 14f 257
153 256 255 :2 0
2ab 41 :3 0 8
:3 0 3e :3 0 25a
25b 0 3f :3 0
25c 25d 0 2a3
15 :3 0 16 :3 0
25f 260 0 15
:3 0 23 :3 0 262
263 0 42 :2 0
2 :4 0 5e :2 0
26 :2 0 24 :2 0
155 268 26a :3 0
158 264 26c 261
26e 26d :2 0 18
:3 0 27 :3 0 270
271 0 1a :4 0
5f :4 0 1d :2 0
1e :3 0 15c 275
277 :3 0 15f 272
279 :2 0 293 18
:3 0 27 :3 0 27b
27c 0 1a :4 0
45 :4 0 1d :2 0
3f :3 0 162 280
282 :3 0 1d :2 0
46 :4 0 165 284
286 :3 0 1d :2 0
47 :3 0 48 :3 0
24 :2 0 49 :2 0
168 289 28d 16c
288 28f :3 0 16f
27d 291 :2 0 293
172 294 26f 293
0 295 175 0
2a3 59 :3 0 14
:3 0 5a :3 0 8
:3 0 58 :3 0 5b
:3 0 5c :4 0 60
1 :a 0 29f :2 0
2a3 297 29d :2 0
7 :3 0 14 :3 0
2a1 :2 0 2a3 177
2a6 :3 0 2a6 0
2a6 2a5 2a3 2a4
:6 0 2a8 1 :3 0
17c 2aa 17e 2a9
2a8 :2 0 2ab 180
:2 0 2ad 183 2ad
2ac 20c 2ab :6 0
2ae :2 0 2 14
2ad 2b1 :3 0 2b0
2ae 2b2 :8 0 
18c
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
32 1 38 1
3e 1 44 1
51 1 5d 2
60 62 2 65
67 2 69 6b
2 6d 6f 2
71 73 2 75
77 2 79 7b
2 7d 7f 2
81 83 2 85
87 2 89 8b
2 8d 8f 2
91 93 4 59
5f 64 95 1
97 1 99 2
a3 a5 3 a1
a2 a7 2 b0
b2 2 af b4
1 b6 1 b8
1 ba 1 c0
1 c8 2 d8
da 3 d6 d7
dc 2 e5 e7
2 e9 eb 2
ed ef 1 f7
2 f9 fa 2
f1 fc 2 e4
fe 1 100 1
102 2 10c 10e
3 10a 10b 110
2 119 11b 2
118 11d 1 11f
1 121 2 128
129 3 103 122
12b 1 12d 2
142 147 1 14e
1 149 2 161
163 3 15f 160
165 2 16e 170
2 172 174 2
176 178 2 17a
17c 2 17e 180
3 185 186 187
2 182 189 2
16d 18b 1 18d
1 18f 2 158
190 1 194 1
153 2 151 198
6 1a4 1a5 1a6
1a7 1a8 1a9 2
1ae 1af 1 1b3
2 1b1 1b3 1
1ba 1 1bc 2
1c6 1c8 3 1c4
1c5 1ca 2 1d3
1d5 2 1d7 1d9
2 1db 1dd 1
1e3 2 1e5 1e6
2 1df 1e8 2
1ea 1ec 2 1ee
1f0 2 1f2 1f4
2 1f6 1f8 2
1d2 1fa 1 1fc
1 1fe 2 204
205 3 207 208
209 d 9a b9
12e 131 134 137
13c 19b 1a1 1ac
1bd 1ff 20b 2
218 21a 3 216
217 21c 2 225
227 2 224 229
2 230 234 2
236 238 2 23a
23e 2 22f 240
2 22b 242 1
244 3 245 250
254 1 20f 2
267 269 3 265
266 26b 2 274
276 2 273 278
2 27f 281 2
283 285 3 28a
28b 28c 2 287
28e 2 27e 290
2 27a 292 1
294 4 25e 295
29e 2a2 1 2a6
1 259 2 257
2aa 8 1b 22
29 30 36 3c
42 49 
1
4
0 
2b1
0
1
14
4
c
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
16 1 0
2b 1 0
2 0 1
7 1 0
3e 1 0
38 1 0
3 1 0
1d 1 0
32 1 0
24 1 0
44 1 0
0

/
SHOW ERRORS FUNCTION SP_A_POOLRES;
ALTER FUNCTION SP_A_POOLRES COMPILE DEBUG;
/***************************************************************************************************/
/*
#Stored Procedure  :SP_A_DOCRES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_DOCRES ==
CREATE OR REPLACE FUNCTION SP_A_DOCRES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
7f
2 :e:
1FUNCTION:
1SP_A_DOCRES:
1TABLE_TYPE001:
1PLS_INTEGER:
1ID001:
1VARCHAR2:
1RES_ID001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_ID:
132:
1H_RA_ID:
1H_REC_USER:
1H_RESOURCE_ID:
1H_TABLE_TYPE:
10:
1H_TYPE_ID:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_DOCRES(:
1COALESCE:
1TO_CHAR:
1NULL:
1, :
1':
1);:
1CHECK_TRACE:
11:
127:
1+:
1FPUT:
1               ENTER:: SP_A_DOCRES(28) :: cplan.sql(7213) :: :
1IS NULL:
18:
1      RETURN_INVALID:: SP_A_DOCRES(33) :: cplan.sql(7218) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
135:
1                EXIT:: SP_A_DOCRES(36) :: cplan.sql(7221) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1=:
1SC_TABLE_DOC:
1TYPE_ID:
1TMT_DOCUMENTS:
1ELEMENT_ID:
1SELECT TYPE_ID INTO h_type_id FROM TMT_DOCUMENTS WHERE ELEMENT_ID = h_element+
1_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
158:
1           EXCEPTION:: SP_A_DOCRES(59) :: cplan.sql(7244) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1ELSIF:
1SC_TABLE_SCD:
1TMT_ASSIGNED_SCORECARDS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_ASSIGNED_SCORECARDS WHERE ELEMENT_ID =+
1 h_element_id:
173:
1           EXCEPTION:: SP_A_DOCRES(74) :: cplan.sql(7259) :: :
1SC_TABLE_POL_DOC:
1TMT_POOL_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_POOL_DOCUMENTS WHERE ELEMENT_ID = h_el+
1ement_id:
188:
1           EXCEPTION:: SP_A_DOCRES(89) :: cplan.sql(7274) :: :
1SC_TABLE_RES_DOC:
1TMT_RESOURCE_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_RESOURCE_DOCUMENTS WHERE ELEMENT_ID = +
1h_element_id:
1103:
1           EXCEPTION:: SP_A_DOCRES(104) :: cplan.sql(7289) :: :
1SC_TABLE_CLN_DOC:
1TMT_CLIENT_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_CLIENT_DOCUMENTS WHERE ELEMENT_ID = h_+
1element_id:
1118:
1           EXCEPTION:: SP_A_DOCRES(119) :: cplan.sql(7304) :: :
1SC_TABLE_AST_DOC:
1TMT_ASSET_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_ASSET_DOCUMENTS WHERE ELEMENT_ID = h_e+
1lement_id:
1133:
1           EXCEPTION:: SP_A_DOCRES(134) :: cplan.sql(7319) :: :
1SC_TABLE_VDR_DOC:
1TMT_VENDOR_DOCUMENTS:
1SELECT TYPE_ID INTO h_type_id FROM TMT_VENDOR_DOCUMENTS WHERE ELEMENT_ID = h_+
1element_id:
1148:
1           EXCEPTION:: SP_A_DOCRES(149) :: cplan.sql(7334) :: :
1SYS_GUID:
1ASSIGNRESOURCE:
1RECORD_ALREADY_ASSIGNED:
14:
1164:
1       RETURN_STATUS:: SP_A_DOCRES(165) :: cplan.sql(7350) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1171:
1           EXCEPTION:: SP_A_DOCRES(172) :: cplan.sql(7357) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1183:
1           EXCEPTION:: SP_A_DOCRES(184) :: cplan.sql(7369) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
566
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
a0 7e b4 2e :2 5a a0 7e b4
2e :2 5a 52 10 a0 7e b4 2e
:2 5a 52 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 19 3c :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 51 a5
b a0 7e a0 6b b4 2e :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 51 a5 b a0
7e a0 6b b4 2e :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
b7 19 :2 a0 51 a5 b a0 7e
a0 6b b4 2e :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 b7
19 :2 a0 51 a5 b a0 7e a0
6b b4 2e :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 b7 19
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 b7 19 :2 a0
51 a5 b a0 7e a0 6b b4
2e :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 b4 2e
d :8 a0 a5 b d :2 a0 51 a5
b 7e 51 b4 2e :3 a0 6b d
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 51 a5 b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
566
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ef
dd bc e1 e2 ea dc 10b fa
fe d9 106 f9 127 116 11a f6
122 115 143 132 136 112 13e 131
163 14e 152 12e 156 15e 14d 16a
16e 14a 172 176 17a 17d 182 183
1 185 18a 18e 192 195 19a 19e
1a2 1a5 1aa 1ab 1ad 1b2 1b5 1b9
1ba 1bf 1c4 1c7 1cb 1cf 1d3 1d4
1d6 1db 1dc 1de 1df 1e4 1e7 1ec
1ed 1f2 1f5 1fa 1fb 200 203 207
208 20d 210 215 216 21b 21e 223
224 229 22c 231 232 237 23a 23e
23f 244 247 24c 24d 252 255 25a
25b 260 263 268 269 26e 271 275
276 27b 27e 283 284 289 28c 291
292 297 298 29d 29f 2a3 2a6 2aa
2ae 2b1 2b5 2b9 2bc 2bf 2c4 2c7
2ca 2cd 2ce 2d3 2d4 1 2d6 2db
2df 2e3 2e6 2eb 2f0 2f3 2f7 2f8
2fd 2fe 303 305 309 30c 310 313
314 319 31c 31f 323 326 327 32c
32f 1 332 337 33b 33e 33f 344
347 1 34a 34f 353 357 35a 35e
362 365 368 36d 370 373 376 377
37c 37d 1 37f 384 388 38c 38f
394 399 39c 3a0 3a1 3a6 3a9 3ae
3af 3b4 3b7 3bc 3bd 3c2 3c5 3c9
3cd 3d1 3d5 3d8 3d9 3db 3e0 3e1
3e3 3e4 3e9 3ea 3ef 3f1 3f5 3f8
3fc 400 403 407 40b 40e 411 416
419 41c 41f 420 425 426 1 428
42d 431 435 438 43d 442 445 449
44a 44f 450 455 457 45b 45e 462
466 469 46d 471 474 478 479 47e
480 484 487 48b 48f 493 497 49b
49f 4a3 4a7 4ab 4af 4b3 4b7 4bb
4bf 4c2 4c3 4c5 4c9 4cc 4d0 4d3
4d4 4d9 4dd 4e1 4e5 4e9 4ed 4f9
4fd 501 504 508 50c 50e 512 516
51a 51d 521 525 527 528 52d 1
531 535 539 53c 540 544 548 54c
54f 553 557 55a 55d 562 565 568
56b 56c 571 572 1 574 579 57d
581 584 589 58e 591 595 596 59b
59e 5a3 5a4 5a9 5ac 5b1 5b2 5b7
5ba 5be 5bf 5c4 5c7 5cc 5cd 5d2
5d5 5d9 5dd 5e0 5e3 5e4 5e6 5e7
5ec 5ed 5f2 5f4 5f8 5fb 5fd 601
603 60f 611 613 614 619 61d 61f
62b 62d 631 633 637 63b 63e 63f
641 645 648 64c 64f 650 655 659
65d 661 665 669 675 679 67d 680
684 688 68a 68e 692 696 699 69d
6a1 6a3 6a4 6a9 1 6ad 6b1 6b5
6b8 6bc 6c0 6c4 6c8 6cb 6cf 6d3
6d6 6d9 6de 6e1 6e4 6e7 6e8 6ed
6ee 1 6f0 6f5 6f9 6fd 700 705
70a 70d 711 712 717 71a 71f 720
725 728 72d 72e 733 736 73a 73b
740 743 748 749 74e 751 755 759
75c 75f 760 762 763 768 769 76e
770 774 777 779 77d 77f 78b 78d
78f 790 795 799 79b 7a7 7a9 7ad
7af 7b3 7b7 7bb 7be 7bf 7c1 7c5
7c8 7cc 7cf 7d0 7d5 7d9 7dd 7e1
7e5 7e9 7f5 7f9 7fd 800 804 808
80a 80e 812 816 819 81d 821 823
824 829 1 82d 831 835 838 83c
840 844 848 84b 84f 853 856 859
85e 861 864 867 868 86d 86e 1
870 875 879 87d 880 885 88a 88d
891 892 897 89a 89f 8a0 8a5 8a8
8ad 8ae 8b3 8b6 8ba 8bb 8c0 8c3
8c8 8c9 8ce 8d1 8d5 8d9 8dc 8df
8e0 8e2 8e3 8e8 8e9 8ee 8f0 8f4
8f7 8f9 8fd 8ff 90b 90d 90f 910
915 919 91b 927 929 92d 92f 933
937 93b 93e 93f 941 945 948 94c
94f 950 955 959 95d 961 965 969
975 979 97d 980 984 988 98a 98e
992 996 999 99d 9a1 9a3 9a4 9a9
1 9ad 9b1 9b5 9b8 9bc 9c0 9c4
9c8 9cb 9cf 9d3 9d6 9d9 9de 9e1
9e4 9e7 9e8 9ed 9ee 1 9f0 9f5
9f9 9fd a00 a05 a0a a0d a11 a12
a17 a1a a1f a20 a25 a28 a2d a2e
a33 a36 a3a a3b a40 a43 a48 a49
a4e a51 a55 a59 a5c a5f a60 a62
a63 a68 a69 a6e a70 a74 a77 a79
a7d a7f a8b a8d a8f a90 a95 a99
a9b aa7 aa9 aad aaf ab3 ab7 abb
abe abf ac1 ac5 ac8 acc acf ad0
ad5 ad9 add ae1 ae5 ae9 af5 af9
afd b00 b04 b08 b0a b0e b12 b16
b19 b1d b21 b23 b24 b29 1 b2d
b31 b35 b38 b3c b40 b44 b48 b4b
b4f b53 b56 b59 b5e b61 b64 b67
b68 b6d b6e 1 b70 b75 b79 b7d
b80 b85 b8a b8d b91 b92 b97 b9a
b9f ba0 ba5 ba8 bad bae bb3 bb6
bba bbb bc0 bc3 bc8 bc9 bce bd1
bd5 bd9 bdc bdf be0 be2 be3 be8
be9 bee bf0 bf4 bf7 bf9 bfd bff
c0b c0d c0f c10 c15 c19 c1b c27
c29 c2d c2f c33 c37 c3b c3e c3f
c41 c45 c48 c4c c4f c50 c55 c59
c5d c61 c65 c69 c75 c79 c7d c80
c84 c88 c8a c8e c92 c96 c99 c9d
ca1 ca3 ca4 ca9 1 cad cb1 cb5
cb8 cbc cc0 cc4 cc8 ccb ccf cd3
cd6 cd9 cde ce1 ce4 ce7 ce8 ced
cee 1 cf0 cf5 cf9 cfd d00 d05
d0a d0d d11 d12 d17 d1a d1f d20
d25 d28 d2d d2e d33 d36 d3a d3b
d40 d43 d48 d49 d4e d51 d55 d59
d5c d5f d60 d62 d63 d68 d69 d6e
d70 d74 d77 d79 d7d d7f d8b d8d
d8f d90 d95 d99 d9b da7 da9 dad
daf db3 db7 dbb dbe dbf dc1 dc5
dc8 dcc dcf dd0 dd5 dd9 ddd de1
de5 de9 df5 df9 dfd e00 e04 e08
e0a e0e e12 e16 e19 e1d e21 e23
e24 e29 1 e2d e31 e35 e38 e3c
e40 e44 e48 e4b e4f e53 e56 e59
e5e e61 e64 e67 e68 e6d e6e 1
e70 e75 e79 e7d e80 e85 e8a e8d
e91 e92 e97 e9a e9f ea0 ea5 ea8
ead eae eb3 eb6 eba ebb ec0 ec3
ec8 ec9 ece ed1 ed5 ed9 edc edf
ee0 ee2 ee3 ee8 ee9 eee ef0 ef4
ef7 ef9 efd eff f0b f0d f0f f10
f15 f19 f1b f27 f29 f2b f2f f33
f36 f3a f3e f3f f44 f48 f4c f50
f54 f58 f5c f60 f64 f68 f69 f6b
f6f f73 f77 f7a f7b f7d f80 f83
f84 f89 f8d f91 f95 f98 f9c f9e
fa2 fa5 fa9 fad fb0 fb4 fb8 fbb
fbe fc3 fc6 fc9 fcc fcd fd2 fd3
1 fd5 fda fde fe2 fe5 fea fef
ff2 ff6 ff7 ffc fff 1004 1005 100a
100d 1012 1013 1018 101b 101f 1023 1027
1028 102a 102f 1030 1032 1033 1038 103b
1040 1041 1046 1049 104e 104f 1054 1057
105b 105c 1061 1064 1069 106a 106f 1070
1075 1077 107b 107e 1082 1086 1089 108d
1091 1094 1095 1097 109b 109f 10a0 10a5
10a7 10ab 10af 10b2 10b6 10ba 10bd 10c1
10c5 10c8 10cb 10d0 10d3 10d6 10d9 10da
10df 10e0 1 10e2 10e7 10eb 10ef 10f2
10f7 10fc 10ff 1103 1104 1109 110a 110f
1113 1117 111a 111f 1124 1127 112b 112f
1132 1133 1138 113b 1140 1141 1146 1149
114d 1151 1154 1155 115a 115b 1160 1162
1166 1169 116d 1171 1175 1179 117d 1181
1185 1189 118d 1199 119e 11a2 11a6 11aa
11ae 11b0 11b1 11b6 1 11ba 11be 11c2
11c5 11c9 11cd 11d1 11d5 11d8 11dc 11e0
11e3 11e6 11eb 11ee 11f1 11f4 11f5 11fa
11fb 1 11fd 1202 1206 120a 120d 1212
1217 121a 121e 121f 1224 1225 122a 122e
1232 1235 123a 123f 1242 1246 1247 124c
124f 1254 1255 125a 125d 1261 1265 1268
126b 126c 126e 126f 1274 1275 127a 127c
1280 1283 1287 128b 128f 1293 1297 129b
129f 12ab 12b0 12b4 12b8 12bc 12c0 12c2
12c6 12c8 12d4 12d6 12d8 12d9 12de 12e2
12e4 12f0 12f4 12f6 12f7 1300 
566
2
0 1 a 6 14 :3 6 c :3 6
10 :3 6 12 :2 6 1 3 a 13
a :2 1 4 11 1a 19 :2 11 :2 4
c 15 14 :2 c :2 4 f 18 17
:2 f :2 4 12 1b 1a :2 12 :2 4 :2 11
20 11 :2 4 :2 e 1d e :2 4 :2 14
23 14 :2 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 53 59 5c :2 53
6a 7f 8 11 19 :2 11 29 :2 8
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 24 27 :2 6a b e :2 6a
13 16 :2 6a 1b 1e :2 6a 28 2b
:2 6a b e :2 6a 13 16 :2 6a 1b
1e :2 6a 2a 2d :2 6a 32 35 :2 6a
:2 7 49 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4d 4e :2 4b :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 51 :2 4
:4 9 8 7 :4 1e 1d 1c :2 7 :4 37
36 35 :2 7 a :2 14 26 :2 30 3c
3f 4e 50 51 :2 4e :2 26 :3 a :2 10
15 21 5e 61 :2 21 6e 71 :2 21
75 78 :2 21 82 85 8e 96 :2 9f
:2 8e b0 :2 85 :2 21 :2 a 54 :2 7 a
:2 14 26 :2 30 3c 3f 4e 50 51
:2 4e :2 26 :3 a :2 10 15 21 5e 61
:2 21 :2 a 54 :3 7 :2 12 28 :2 31 41
:2 7 4d :3 4 14 :2 4 15 :2 4 12
:2 4 14 4 7 10 1e :2 7 23
21 :2 2c :2 21 11 1e 2d 41 4e
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 55
57 58 :2 55 :2 2c :3 10 :2 16 1b 27
64 67 :2 27 74 77 :2 27 7b 7e
:2 27 8a 8d :2 27 95 98 :2 27 a4
a7 ae b7 ba :2 a7 :2 27 :2 10 5b
:2 d :2 a :4 16 :2 a 7 :3 39 4 39
a 13 21 :2 a 26 24 :2 2f :2 24
11 1e 2d 4b 58 :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 57 58 :2 55
:2 2c :3 10 :2 16 1b 27 64 67 :2 27
74 77 :2 27 7b 7e :2 27 8a 8d
:2 27 95 98 :2 27 a4 a7 ae b7
ba :2 a7 :2 27 :2 10 5b :2 d :2 a :4 16
:2 a 7 :3 3c 4 3c 39 a 13
21 :2 a 26 24 :2 2f :2 24 11 1e
2d 46 53 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 57 58 :2 55 :2 2c :3 10
:2 16 1b 27 64 67 :2 27 74 77
:2 27 7b 7e :2 27 8a 8d :2 27 95
98 :2 27 a4 a7 ae b7 ba :2 a7
:2 27 :2 10 5b :2 d :2 a :4 16 :2 a 7
:3 40 4 40 39 a 13 21 :2 a
26 24 :2 2f :2 24 11 1e 2d 4a
57 :2 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
55 58 59 :2 55 :2 2c :3 10 :2 16 1b
27 65 68 :2 27 75 78 :2 27 7c
7f :2 27 8b 8e :2 27 96 99 :2 27
a5 a8 af b8 bb :2 a8 :2 27 :2 10
5c :2 d :2 a :4 16 :2 a 7 :3 40 4
40 39 a 13 21 :2 a 26 24
:2 2f :2 24 11 1e 2d 48 55 :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 55 58
59 :2 55 :2 2c :3 10 :2 16 1b 27 65
68 :2 27 75 78 :2 27 7c 7f :2 27
8b 8e :2 27 96 99 :2 27 a5 a8
af b8 bb :2 a8 :2 27 :2 10 5c :2 d
:2 a :4 16 :2 a 7 :3 40 4 40 39
a 13 21 :2 a 26 24 :2 2f :2 24
11 1e 2d 47 54 :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 55 58 59 :2 55
:2 2c :3 10 :2 16 1b 27 65 68 :2 27
75 78 :2 27 7c 7f :2 27 8b 8e
:2 27 96 99 :2 27 a5 a8 af b8
bb :2 a8 :2 27 :2 10 5c :2 d :2 a :4 16
:2 a 7 :3 40 4 40 39 a 13
21 :2 a 26 24 :2 2f :2 24 11 1e
2d 48 55 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 55 58 59 :2 55 :2 2c :3 10
:2 16 1b 27 65 68 :2 27 75 78
:2 27 7c 7f :2 27 8b 8e :2 27 96
99 :2 27 a5 a8 af b8 bb :2 a8
:2 27 :2 10 5c :2 d :2 a :4 16 :2 a 7
:4 40 39 :3 4 :3 f :2 4 17 26 34
3f 4d 5c 25 :2 17 4 7 10
21 :2 7 24 26 :2 24 7 1a :2 23
7 28 :2 4 7 :2 11 23 :2 2d 39
3c 4b 4e 4f :2 4b :2 23 :3 7 :2 d
12 1e 5c 5f :2 1e 6c 6f :2 1e
73 76 :2 1e 80 83 8c 94 :2 8c
a6 :2 83 :2 1e ae b1 :2 1e b9 bc
:2 1e c1 c4 :2 1e cc cf :2 1e :2 7
52 :3 4 :2 f 21 2a 3b :2 21 3f
48 :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 4f 52 53 :2 4f
:2 26 :3 a :2 10 15 21 5f 62 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
56 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4c 4f 50 :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 53 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
566
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:7 c :6 d :6 e :6 f
:7 11 :b 13 :11 14 :8 15
:2 14 :2 16 :2 14 :2 16
:2 14 :2 16 :2 14 :2 16
:2 14 :2 17 :2 14 :2 17
:2 14 :2 17 :2 14 :2 17
:2 14 :2 18 :2 14 :2 18
:2 14 :2 18 :2 14 :2 18
:2 14 :2 18 :4 14 :3 13
:11 1b :b 1c :3 1b :16 1f
:11 20 :20 21 :3 20 :11 23
:b 24 :3 23 :9 26 :3 1f
:3 2b :3 2c :3 2d :3 2e
:b 30 :6 32 :5 33 31
35 :5 36 :3 35 :2 37
:5 39 :11 3a :24 3b :3 3a
:2 38 :6 37 34 :3 30
3f 30 :b 3f :6 41
:5 42 40 44 :5 45
:3 44 :2 46 :5 48 :11 49
:24 4a :3 49 :2 47 :6 46
43 :3 3f 4e 3f
30 :b 4e :6 50 :5 51
4f 53 :5 54 :3 53
:2 55 :5 57 :11 58 :24 59
:3 58 :2 56 :6 55 52
:3 4e 5d 4e 30
:b 5d :6 5f :5 60 5e
62 :5 63 :3 62 :2 64
:5 66 :11 67 :24 68 :3 67
:2 65 :6 64 61 :3 5d
6c 5d 30 :b 6c
:6 6e :5 6f 6d 71
:5 72 :3 71 :2 73 :5 75
:11 76 :24 77 :3 76 :2 74
:6 73 70 :3 6c 7b
6c 30 :b 7b :6 7d
:5 7e 7c 80 :5 81
:3 80 :2 82 :5 84 :11 85
:24 86 :3 85 :2 83 :6 82
7f :3 7b 8a 7b
30 :b 8a :6 8c :5 8d
8b 8f :5 90 :3 8f
:2 91 :5 93 :11 94 :24 95
:3 94 :2 92 :6 91 8e
:4 8a :3 30 :5 9b :7 9d
9e :3 9d :9 a0 :5 a1
:3 a0 :11 a4 :2e a5 :3 a4
:c a7 12 :3 aa :11 ab
:b ac :17 ad :3 ab :2 af
:3 b0 :3 b1 b2 b0
af b0 :3 b3 :3 aa
:2 b4 :5 b6 :11 b7 :b b8
:18 b9 :3 b7 :2 bb bc
:3 bd be bc bb
bc :3 bf :2 b5 :6 b4
a9 :7 1 
1302
4
:3 0 1 :3 0 2
:a 0 561 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 15 16 0
b 6 :3 0 8
:7 0 11 10 :3 0
9 :3 0 a :3 0
b :2 0 4 13
17 0 561 2
18 :2 0 d :2 0
12 6 :3 0 d
:2 0 10 1b 1d
:6 0 20 1e 0
55f 0 c :6 0
d :2 0 16 6
:3 0 14 22 24
:6 0 27 25 0
55f 0 e :6 0
d :2 0 1a 6
:3 0 18 29 2b
:6 0 2e 2c 0
55f 0 f :6 0
12 :2 0 1e 6
:3 0 1c 30 32
:6 0 35 33 0
55f 0 10 :6 0
12 :2 0 20 4
:3 0 37 :7 0 3b
38 39 55f 0
11 :6 0 12 :2 0
22 4 :3 0 3d
:7 0 41 3e 3f
55f 0 13 :6 0
49 4a 0 24
4 :3 0 43 :7 0
47 44 45 55f
0 14 :6 0 4f
50 0 26 a
:3 0 b :2 0 4
4b :7 0 4e 4c
0 55f 0 15
:6 0 16 :3 0 17
:3 0 16 :3 0 18
:3 0 52 53 0
2 :4 0 28 54
56 51 58 57
:2 0 19 :3 0 1a
:3 0 5a 5b 0
1b :4 0 16 :3 0
1c :3 0 5e 5f
0 2 :4 0 2a
60 62 1d :4 0
1e :2 0 1f :3 0
2c 65 67 :3 0
20 :4 0 1e :2 0
21 :3 0 22 :3 0
3 :3 0 2f 6c
6e 23 :4 0 31
6b 71 34 6a
73 :3 0 1e :2 0
24 :4 0 37 75
77 :3 0 1e :2 0
25 :4 0 3a 79
7b :3 0 1e :2 0
5 :3 0 3d 7d
7f :3 0 1e :2 0
25 :4 0 40 81
83 :3 0 1e :2 0
24 :4 0 43 85
87 :3 0 1e :2 0
25 :4 0 46 89
8b :3 0 1e :2 0
7 :3 0 49 8d
8f :3 0 1e :2 0
25 :4 0 4c 91
93 :3 0 1e :2 0
24 :4 0 4f 95
97 :3 0 1e :2 0
25 :4 0 52 99
9b :3 0 1e :2 0
8 :3 0 55 9d
9f :3 0 1e :2 0
25 :4 0 58 a1
a3 :3 0 1e :2 0
26 :4 0 5b a5
a7 :3 0 5e 5c
a9 :2 0 ab 63
ac 59 ab 0
ad 65 0 4bf
16 :3 0 17 :3 0
ae af 0 16
:3 0 27 :3 0 b1
b2 0 28 :2 0
2 :4 0 29 :2 0
2a :2 0 28 :2 0
67 b7 b9 :3 0
6a b3 bb b0
bd bc :2 0 19
:3 0 2b :3 0 bf
c0 0 1b :4 0
2c :4 0 1e :2 0
1f :3 0 6e c4
c6 :3 0 71 c1
c8 :2 0 ca 74
cb be ca 0
cc 76 0 4bf
5 :3 0 2d :2 0
78 ce cf :3 0
d0 :2 0 d1 :2 0
7 :3 0 2d :2 0
7a d4 d5 :3 0
d6 :2 0 d7 :2 0
d2 d9 d8 :2 0
8 :3 0 2d :2 0
7c dc dd :3 0
de :2 0 df :2 0
da e1 e0 :2 0
16 :3 0 17 :3 0
e3 e4 0 16
:3 0 27 :3 0 e6
e7 0 2e :2 0
2 :4 0 d :2 0
2a :2 0 28 :2 0
7e ec ee :3 0
81 e8 f0 e5
f2 f1 :2 0 19
:3 0 2b :3 0 f4
f5 0 1b :4 0
2f :4 0 1e :2 0
1f :3 0 85 f9
fb :3 0 1e :2 0
30 :4 0 88 fd
ff :3 0 1e :2 0
31 :4 0 8b 101
103 :3 0 1e :2 0
21 :3 0 22 :3 0
32 :3 0 33 :3 0
108 109 0 8e
107 10b 23 :4 0
90 106 10e 93
105 110 :3 0 96
f6 112 :2 0 114
99 115 f3 114
0 116 9b 0
13f 16 :3 0 17
:3 0 117 118 0
16 :3 0 27 :3 0
11a 11b 0 28
:2 0 2 :4 0 34
:2 0 2a :2 0 28
:2 0 9d 120 122
:3 0 a0 11c 124
119 126 125 :2 0
19 :3 0 2b :3 0
128 129 0 1b
:4 0 35 :4 0 1e
:2 0 1f :3 0 a4
12d 12f :3 0 a7
12a 131 :2 0 133
aa 134 127 133
0 135 ac 0
13f 36 :3 0 37
:3 0 136 137 0
32 :3 0 33 :3 0
139 13a 0 38
:3 0 ae 138 13d
:2 0 13f b1 140
e2 13f 0 141
b5 0 4bf c
:3 0 5 :3 0 142
143 0 4bf 10
:3 0 7 :3 0 145
146 0 4bf f
:3 0 8 :3 0 148
149 0 4bf 11
:3 0 3 :3 0 14b
14c 0 4bf 21
:3 0 11 :3 0 12
:2 0 b7 14e 151
32 :3 0 39 :2 0
3a :3 0 153 155
0 bc 154 157
:3 0 3b :3 0 13
:3 0 3c :3 0 3d
:3 0 c :4 0 3e
1 :8 0 164 a
:3 0 3f :3 0 15f
160 0 40 :3 0
161 162 0 164
bf 1b7 41 :3 0
a :3 0 3f :3 0
166 167 0 40
:3 0 168 169 0
16b c2 16d c4
16c 16b :2 0 1b5
42 :3 0 a :3 0
3f :3 0 170 171
0 40 :3 0 172
173 0 1ad 16
:3 0 17 :3 0 175
176 0 16 :3 0
27 :3 0 178 179
0 43 :2 0 2
:4 0 44 :2 0 2a
:2 0 28 :2 0 c6
17e 180 :3 0 c9
17a 182 177 184
183 :2 0 19 :3 0
2b :3 0 186 187
0 1b :4 0 45
:4 0 1e :2 0 1f
:3 0 cd 18b 18d
:3 0 1e :2 0 30
:4 0 d0 18f 191
:3 0 1e :2 0 46
:4 0 d3 193 195
:3 0 1e :2 0 40
:3 0 d6 197 199
:3 0 1e :2 0 47
:4 0 d9 19b 19d
:3 0 1e :2 0 48
:3 0 49 :3 0 28
:2 0 4a :2 0 dc
1a0 1a4 e0 19f
1a6 :3 0 e3 188
1a8 :2 0 1aa e6
1ab 185 1aa 0
1ac e8 0 1ad
ea 1b0 :3 0 1b0
0 1b0 1af 1ad
1ae :6 0 1b2 2
:3 0 ed 1b4 ef
1b3 1b2 :2 0 1b5
f1 :2 0 1b7 0
1b7 1b6 164 1b5
:6 0 1ba 1 :3 0
4b :3 0 f4 44e
21 :3 0 11 :3 0
12 :2 0 f6 1bb
1be 32 :3 0 39
:2 0 4c :3 0 1c0
1c2 0 fb 1c1
1c4 :3 0 3b :3 0
13 :3 0 4d :3 0
3d :3 0 c :4 0
4e 1 :8 0 1d1
a :3 0 3f :3 0
1cc 1cd 0 40
:3 0 1ce 1cf 0
1d1 fe 224 41
:3 0 a :3 0 3f
:3 0 1d3 1d4 0
40 :3 0 1d5 1d6
0 1d8 101 1da
103 1d9 1d8 :2 0
222 42 :3 0 a
:3 0 3f :3 0 1dd
1de 0 40 :3 0
1df 1e0 0 21a
16 :3 0 17 :3 0
1e2 1e3 0 16
:3 0 27 :3 0 1e5
1e6 0 43 :2 0
2 :4 0 4f :2 0
2a :2 0 28 :2 0
105 1eb 1ed :3 0
108 1e7 1ef 1e4
1f1 1f0 :2 0 19
:3 0 2b :3 0 1f3
1f4 0 1b :4 0
50 :4 0 1e :2 0
1f :3 0 10c 1f8
1fa :3 0 1e :2 0
30 :4 0 10f 1fc
1fe :3 0 1e :2 0
46 :4 0 112 200
202 :3 0 1e :2 0
40 :3 0 115 204
206 :3 0 1e :2 0
47 :4 0 118 208
20a :3 0 1e :2 0
48 :3 0 49 :3 0
28 :2 0 4a :2 0
11b 20d 211 11f
20c 213 :3 0 122
1f5 215 :2 0 217
125 218 1f2 217
0 219 127 0
21a 129 21d :3 0
21d 0 21d 21c
21a 21b :6 0 21f
4 :3 0 12c 221
12e 220 21f :2 0
222 130 :2 0 224
0 224 223 1d1
222 :6 0 227 1
:3 0 4b :3 0 133
228 1c5 227 0
44f 21 :3 0 11
:3 0 12 :2 0 135
229 22c 32 :3 0
39 :2 0 51 :3 0
22e 230 0 13a
22f 232 :3 0 3b
:3 0 13 :3 0 52
:3 0 3d :3 0 c
:4 0 53 1 :8 0
23f a :3 0 3f
:3 0 23a 23b 0
40 :3 0 23c 23d
0 23f 13d 292
41 :3 0 a :3 0
3f :3 0 241 242
0 40 :3 0 243
244 0 246 140
248 142 247 246
:2 0 290 42 :3 0
a :3 0 3f :3 0
24b 24c 0 40
:3 0 24d 24e 0
288 16 :3 0 17
:3 0 250 251 0
16 :3 0 27 :3 0
253 254 0 43
:2 0 2 :4 0 54
:2 0 2a :2 0 28
:2 0 144 259 25b
:3 0 147 255 25d
252 25f 25e :2 0
19 :3 0 2b :3 0
261 262 0 1b
:4 0 55 :4 0 1e
:2 0 1f :3 0 14b
266 268 :3 0 1e
:2 0 30 :4 0 14e
26a 26c :3 0 1e
:2 0 46 :4 0 151
26e 270 :3 0 1e
:2 0 40 :3 0 154
272 274 :3 0 1e
:2 0 47 :4 0 157
276 278 :3 0 1e
:2 0 48 :3 0 49
:3 0 28 :2 0 4a
:2 0 15a 27b 27f
15e 27a 281 :3 0
161 263 283 :2 0
285 164 286 260
285 0 287 166
0 288 168 28b
:3 0 28b 0 28b
28a 288 289 :6 0
28d 6 :3 0 16b
28f 16d 28e 28d
:2 0 290 16f :2 0
292 0 292 291
23f 290 :6 0 295
1 :3 0 4b :3 0
172 296 233 295
0 44f 21 :3 0
11 :3 0 12 :2 0
174 297 29a 32
:3 0 39 :2 0 56
:3 0 29c 29e 0
179 29d 2a0 :3 0
3b :3 0 13 :3 0
57 :3 0 3d :3 0
c :4 0 58 1
:8 0 2ad a :3 0
3f :3 0 2a8 2a9
0 40 :3 0 2aa
2ab 0 2ad 17c
300 41 :3 0 a
:3 0 3f :3 0 2af
2b0 0 40 :3 0
2b1 2b2 0 2b4
17f 2b6 181 2b5
2b4 :2 0 2fe 42
:3 0 a :3 0 3f
:3 0 2b9 2ba 0
40 :3 0 2bb 2bc
0 2f6 16 :3 0
17 :3 0 2be 2bf
0 16 :3 0 27
:3 0 2c1 2c2 0
43 :2 0 2 :4 0
59 :2 0 2a :2 0
28 :2 0 183 2c7
2c9 :3 0 186 2c3
2cb 2c0 2cd 2cc
:2 0 19 :3 0 2b
:3 0 2cf 2d0 0
1b :4 0 5a :4 0
1e :2 0 1f :3 0
18a 2d4 2d6 :3 0
1e :2 0 30 :4 0
18d 2d8 2da :3 0
1e :2 0 46 :4 0
190 2dc 2de :3 0
1e :2 0 40 :3 0
193 2e0 2e2 :3 0
1e :2 0 47 :4 0
196 2e4 2e6 :3 0
1e :2 0 48 :3 0
49 :3 0 28 :2 0
4a :2 0 199 2e9
2ed 19d 2e8 2ef
:3 0 1a0 2d1 2f1
:2 0 2f3 1a3 2f4
2ce 2f3 0 2f5
1a5 0 2f6 1a7
2f9 :3 0 2f9 0
2f9 2f8 2f6 2f7
:6 0 2fb 8 :3 0
1aa 2fd 1ac 2fc
2fb :2 0 2fe 1ae
:2 0 300 0 300
2ff 2ad 2fe :6 0
303 1 :3 0 4b
:3 0 1b1 304 2a1
303 0 44f 21
:3 0 11 :3 0 12
:2 0 1b3 305 308
32 :3 0 39 :2 0
5b :3 0 30a 30c
0 1b8 30b 30e
:3 0 3b :3 0 13
:3 0 5c :3 0 3d
:3 0 c :4 0 5d
1 :8 0 31b a
:3 0 3f :3 0 316
317 0 40 :3 0
318 319 0 31b
1bb 36e 41 :3 0
a :3 0 3f :3 0
31d 31e 0 40
:3 0 31f 320 0
322 1be 324 1c0
323 322 :2 0 36c
42 :3 0 a :3 0
3f :3 0 327 328
0 40 :3 0 329
32a 0 364 16
:3 0 17 :3 0 32c
32d 0 16 :3 0
27 :3 0 32f 330
0 43 :2 0 2
:4 0 5e :2 0 2a
:2 0 28 :2 0 1c2
335 337 :3 0 1c5
331 339 32e 33b
33a :2 0 19 :3 0
2b :3 0 33d 33e
0 1b :4 0 5f
:4 0 1e :2 0 1f
:3 0 1c9 342 344
:3 0 1e :2 0 30
:4 0 1cc 346 348
:3 0 1e :2 0 46
:4 0 1cf 34a 34c
:3 0 1e :2 0 40
:3 0 1d2 34e 350
:3 0 1e :2 0 47
:4 0 1d5 352 354
:3 0 1e :2 0 48
:3 0 49 :3 0 28
:2 0 4a :2 0 1d8
357 35b 1dc 356
35d :3 0 1df 33f
35f :2 0 361 1e2
362 33c 361 0
363 1e4 0 364
1e6 367 :3 0 367
0 367 366 364
365 :6 0 369 a
:3 0 1e9 36b 1eb
36a 369 :2 0 36c
1ed :2 0 36e 0
36e 36d 31b 36c
:6 0 371 1 :3 0
4b :3 0 1f0 372
30f 371 0 44f
21 :3 0 11 :3 0
12 :2 0 1f2 373
376 32 :3 0 39
:2 0 60 :3 0 378
37a 0 1f7 379
37c :3 0 3b :3 0
13 :3 0 61 :3 0
3d :3 0 c :4 0
62 1 :8 0 389
a :3 0 3f :3 0
384 385 0 40
:3 0 386 387 0
389 1fa 3dc 41
:3 0 a :3 0 3f
:3 0 38b 38c 0
40 :3 0 38d 38e
0 390 1fd 392
1ff 391 390 :2 0
3da 42 :3 0 a
:3 0 3f :3 0 395
396 0 40 :3 0
397 398 0 3d2
16 :3 0 17 :3 0
39a 39b 0 16
:3 0 27 :3 0 39d
39e 0 43 :2 0
2 :4 0 63 :2 0
2a :2 0 28 :2 0
201 3a3 3a5 :3 0
204 39f 3a7 39c
3a9 3a8 :2 0 19
:3 0 2b :3 0 3ab
3ac 0 1b :4 0
64 :4 0 1e :2 0
1f :3 0 208 3b0
3b2 :3 0 1e :2 0
30 :4 0 20b 3b4
3b6 :3 0 1e :2 0
46 :4 0 20e 3b8
3ba :3 0 1e :2 0
40 :3 0 211 3bc
3be :3 0 1e :2 0
47 :4 0 214 3c0
3c2 :3 0 1e :2 0
48 :3 0 49 :3 0
28 :2 0 4a :2 0
217 3c5 3c9 21b
3c4 3cb :3 0 21e
3ad 3cd :2 0 3cf
221 3d0 3aa 3cf
0 3d1 223 0
3d2 225 3d5 :3 0
3d5 0 3d5 3d4
3d2 3d3 :6 0 3d7
c :3 0 228 3d9
22a 3d8 3d7 :2 0
3da 22c :2 0 3dc
0 3dc 3db 389
3da :6 0 3df 1
:3 0 4b :3 0 22f
3e0 37d 3df 0
44f 21 :3 0 11
:3 0 12 :2 0 231
3e1 3e4 32 :3 0
39 :2 0 65 :3 0
3e6 3e8 0 236
3e7 3ea :3 0 3b
:3 0 13 :3 0 66
:3 0 3d :3 0 c
:4 0 67 1 :8 0
3f7 a :3 0 3f
:3 0 3f2 3f3 0
40 :3 0 3f4 3f5
0 3f7 239 44a
41 :3 0 a :3 0
3f :3 0 3f9 3fa
0 40 :3 0 3fb
3fc 0 3fe 23c
400 23e 3ff 3fe
:2 0 448 42 :3 0
a :3 0 3f :3 0
403 404 0 40
:3 0 405 406 0
440 16 :3 0 17
:3 0 408 409 0
16 :3 0 27 :3 0
40b 40c 0 43
:2 0 2 :4 0 68
:2 0 2a :2 0 28
:2 0 240 411 413
:3 0 243 40d 415
40a 417 416 :2 0
19 :3 0 2b :3 0
419 41a 0 1b
:4 0 69 :4 0 1e
:2 0 1f :3 0 247
41e 420 :3 0 1e
:2 0 30 :4 0 24a
422 424 :3 0 1e
:2 0 46 :4 0 24d
426 428 :3 0 1e
:2 0 40 :3 0 250
42a 42c :3 0 1e
:2 0 47 :4 0 253
42e 430 :3 0 1e
:2 0 48 :3 0 49
:3 0 28 :2 0 4a
:2 0 256 433 437
25a 432 439 :3 0
25d 41b 43b :2 0
43d 260 43e 418
43d 0 43f 262
0 440 264 443
:3 0 443 0 443
442 440 441 :6 0
445 e :3 0 267
447 269 446 445
:2 0 448 26b :2 0
44a 0 44a 449
3f7 448 :6 0 44c
1 :3 0 26e 44d
3eb 44c 0 44f
158 1ba 0 44f
270 0 4bf e
:3 0 6a :4 0 451
452 :3 0 450 453
0 4bf 14 :3 0
6b :3 0 11 :3 0
13 :3 0 c :3 0
10 :3 0 f :3 0
e :3 0 278 456
45d 455 45e 0
4bf 21 :3 0 14
:3 0 12 :2 0 27f
460 463 39 :2 0
28 :2 0 284 465
467 :3 0 14 :3 0
32 :3 0 6c :3 0
46a 46b 0 469
46c 0 46e 287
46f 468 46e 0
470 289 0 4bf
16 :3 0 17 :3 0
471 472 0 16
:3 0 27 :3 0 474
475 0 6d :2 0
2 :4 0 6e :2 0
2a :2 0 28 :2 0
28b 47a 47c :3 0
28e 476 47e 473
480 47f :2 0 19
:3 0 2b :3 0 482
483 0 1b :4 0
6f :4 0 1e :2 0
1f :3 0 292 487
489 :3 0 1e :2 0
30 :4 0 295 48b
48d :3 0 1e :2 0
31 :4 0 298 48f
491 :3 0 1e :2 0
21 :3 0 22 :3 0
14 :3 0 29b 495
497 23 :4 0 29d
494 49a 2a0 493
49c :3 0 1e :2 0
70 :4 0 2a3 49e
4a0 :3 0 1e :2 0
25 :4 0 2a6 4a2
4a4 :3 0 1e :2 0
e :3 0 2a9 4a6
4a8 :3 0 1e :2 0
25 :4 0 2ac 4aa
4ac :3 0 2af 484
4ae :2 0 4b0 2b2
4b1 481 4b0 0
4b2 2b4 0 4bf
36 :3 0 71 :3 0
4b3 4b4 0 21
:3 0 14 :3 0 12
:2 0 2b6 4b6 4b9
e :3 0 38 :3 0
2b9 4b5 4bd :2 0
4bf 2bd 560 a
:3 0 72 :2 0 4
4c0 4c1 0 16
:3 0 17 :3 0 4c3
4c4 0 16 :3 0
27 :3 0 4c6 4c7
0 43 :2 0 2
:4 0 73 :2 0 2a
:2 0 28 :2 0 2cb
4cc 4ce :3 0 2ce
4c8 4d0 4c5 4d2
4d1 :2 0 19 :3 0
2b :3 0 4d4 4d5
0 1b :4 0 74
:4 0 1e :2 0 1f
:3 0 2d2 4d9 4db
:3 0 2d5 4d6 4dd
:2 0 4f6 19 :3 0
2b :3 0 4df 4e0
0 1b :4 0 75
:4 0 1e :2 0 a
:3 0 76 :3 0 4e5
4e6 0 2d8 4e4
4e8 :3 0 1e :2 0
70 :4 0 2db 4ea
4ec :3 0 1e :2 0
a :3 0 77 :3 0
4ef 4f0 0 2de
4ee 4f2 :3 0 2e1
4e1 4f4 :2 0 4f6
2e4 4f7 4d3 4f6
0 4f8 2e7 0
508 78 :3 0 15
:3 0 a :3 0 76
:3 0 79 :3 0 a
:3 0 77 :3 0 7a
:3 0 7b :4 0 7c
1 :a 0 504 :2 0
508 4fa 502 :2 0
9 :3 0 15 :3 0
506 :2 0 508 2e9
50a 2ed 509 508
:2 0 55e 42 :3 0
a :3 0 3f :3 0
50d 50e 0 40
:3 0 50f 510 0
556 16 :3 0 17
:3 0 512 513 0
16 :3 0 27 :3 0
515 516 0 43
:2 0 2 :4 0 7d
:2 0 2a :2 0 28
:2 0 2ef 51b 51d
:3 0 2f2 517 51f
514 521 520 :2 0
19 :3 0 2b :3 0
523 524 0 1b
:4 0 7e :4 0 1e
:2 0 1f :3 0 2f6
528 52a :3 0 2f9
525 52c :2 0 546
19 :3 0 2b :3 0
52e 52f 0 1b
:4 0 46 :4 0 1e
:2 0 40 :3 0 2fc
533 535 :3 0 1e
:2 0 47 :4 0 2ff
537 539 :3 0 1e
:2 0 48 :3 0 49
:3 0 28 :2 0 4a
:2 0 302 53c 540
306 53b 542 :3 0
309 530 544 :2 0
546 30c 547 522
546 0 548 30f
0 556 78 :3 0
15 :3 0 79 :3 0
a :3 0 77 :3 0
7a :3 0 7b :4 0
7f 1 :a 0 552
:2 0 556 54a 550
:2 0 9 :3 0 15
:3 0 554 :2 0 556
311 559 :3 0 559
0 559 558 556
557 :6 0 55b 1
:3 0 316 55d 318
55c 55b :2 0 55e
31a :2 0 560 31d
560 55f 4bf 55e
:6 0 561 :2 0 2
18 560 564 :3 0
563 561 565 :8 0

326
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 31
1 2f 1 36
1 3c 1 42
1 48 1 55
1 61 2 64
66 1 6d 2
6f 70 2 69
72 2 74 76
2 78 7a 2
7c 7e 2 80
82 2 84 86
2 88 8a 2
8c 8e 2 90
92 2 94 96
2 98 9a 2
9c 9e 2 a0
a2 2 a4 a6
4 5d 63 68
a8 1 aa 1
ac 2 b6 b8
3 b4 b5 ba
2 c3 c5 2
c2 c7 1 c9
1 cb 1 cd
1 d3 1 db
2 eb ed 3
e9 ea ef 2
f8 fa 2 fc
fe 2 100 102
1 10a 2 10c
10d 2 104 10f
2 f7 111 1
113 1 115 2
11f 121 3 11d
11e 123 2 12c
12e 2 12b 130
1 132 1 134
2 13b 13c 3
116 135 13e 1
140 2 14f 150
1 156 2 152
156 2 15e 163
1 16a 1 165
2 17d 17f 3
17b 17c 181 2
18a 18c 2 18e
190 2 192 194
2 196 198 2
19a 19c 3 1a1
1a2 1a3 2 19e
1a5 2 189 1a7
1 1a9 1 1ab
2 174 1ac 1
1b0 1 16f 2
16d 1b4 1 1b7
2 1bc 1bd 1
1c3 2 1bf 1c3
2 1cb 1d0 1
1d7 1 1d2 2
1ea 1ec 3 1e8
1e9 1ee 2 1f7
1f9 2 1fb 1fd
2 1ff 201 2
203 205 2 207
209 3 20e 20f
210 2 20b 212
2 1f6 214 1
216 1 218 2
1e1 219 1 21d
1 1dc 2 1da
221 1 224 2
22a 22b 1 231
2 22d 231 2
239 23e 1 245
1 240 2 258
25a 3 256 257
25c 2 265 267
2 269 26b 2
26d 26f 2 271
273 2 275 277
3 27c 27d 27e
2 279 280 2
264 282 1 284
1 286 2 24f
287 1 28b 1
24a 2 248 28f
1 292 2 298
299 1 29f 2
29b 29f 2 2a7
2ac 1 2b3 1
2ae 2 2c6 2c8
3 2c4 2c5 2ca
2 2d3 2d5 2
2d7 2d9 2 2db
2dd 2 2df 2e1
2 2e3 2e5 3
2ea 2eb 2ec 2
2e7 2ee 2 2d2
2f0 1 2f2 1
2f4 2 2bd 2f5
1 2f9 1 2b8
2 2b6 2fd 1
300 2 306 307
1 30d 2 309
30d 2 315 31a
1 321 1 31c
2 334 336 3
332 333 338 2
341 343 2 345
347 2 349 34b
2 34d 34f 2
351 353 3 358
359 35a 2 355
35c 2 340 35e
1 360 1 362
2 32b 363 1
367 1 326 2
324 36b 1 36e
2 374 375 1
37b 2 377 37b
2 383 388 1
38f 1 38a 2
3a2 3a4 3 3a0
3a1 3a6 2 3af
3b1 2 3b3 3b5
2 3b7 3b9 2
3bb 3bd 2 3bf
3c1 3 3c6 3c7
3c8 2 3c3 3ca
2 3ae 3cc 1
3ce 1 3d0 2
399 3d1 1 3d5
1 394 2 392
3d9 1 3dc 2
3e2 3e3 1 3e9
2 3e5 3e9 2
3f1 3f6 1 3fd
1 3f8 2 410
412 3 40e 40f
414 2 41d 41f
2 421 423 2
425 427 2 429
42b 2 42d 42f
3 434 435 436
2 431 438 2
41c 43a 1 43c
1 43e 2 407
43f 1 443 1
402 2 400 447
1 44a 7 44e
228 296 304 372
3e0 44d 6 457
458 459 45a 45b
45c 2 461 462
1 466 2 464
466 1 46d 1
46f 2 479 47b
3 477 478 47d
2 486 488 2
48a 48c 2 48e
490 1 496 2
498 499 2 492
49b 2 49d 49f
2 4a1 4a3 2
4a5 4a7 2 4a9
4ab 2 485 4ad
1 4af 1 4b1
2 4b7 4b8 3
4ba 4bb 4bc d
ad cc 141 144
147 14a 14d 44f
454 45f 470 4b2
4be 2 4cb 4cd
3 4c9 4ca 4cf
2 4d8 4da 2
4d7 4dc 2 4e3
4e7 2 4e9 4eb
2 4ed 4f1 2
4e2 4f3 2 4de
4f5 1 4f7 3
4f8 503 507 1
4c2 2 51a 51c
3 518 519 51e
2 527 529 2
526 52b 2 532
534 2 536 538
3 53d 53e 53f
2 53a 541 2
531 543 2 52d
545 1 547 4
511 548 551 555
1 559 1 50c
2 50a 55d 8
1f 26 2d 34
3a 40 46 4d

1
4
0 
564
0
1
14
10
d
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
0 0 0 0 
f 1 0
1a 1 0
2f 1 0
b 1 0
42 1 0
3c 1 0
7 1 0
21 1 0
36 1 0
28 1 0
3 1 0
2 0 1
48 1 0
0

/
SHOW ERRORS FUNCTION SP_A_DOCRES;
ALTER FUNCTION SP_A_DOCRES COMPILE DEBUG;
/*****************************************************************************************/
Prompt == FUNCTION FC_U_CREATETMPTABLE ==
CREATE OR REPLACE FUNCTION FC_U_CREATETMPTABLE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1f
2 :e:
1FUNCTION:
1FC_U_CREATETMPTABLE:
1RETURN:
1PLS_INTEGER:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_CREATETMPTABLE();:
1CHECK_TRACE:
11:
18:
1+:
1FPUT:
1               ENTER:: FC_U_CREATETMPTABLE(9) :: cplan.sql(7394) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLN01_TEMP:
1PMO_DB2M:
1SC_STATE:
10:
117:
1                EXIT:: FC_U_CREATETMPTABLE(18) :: cplan.sql(7403) :: :
1 :
1STATE:: :
0

0
0
8c
2
0 a0 8d a0 b4 a0 2c 6a
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6e 11e 11d :2 a0 6b 51 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 a4 b1 11 68 4f
1d 17 b5 
8c
2
0 3 f b a 23 27 2b
2f 33 7 37 3b 3f 42 47
48 1 4a 4f 53 57 5a 5f
63 67 6a 6f 70 72 77 7a
7e 7f 84 89 8a 8f 91 95
98 9c a0 a3 a7 ab ae b1
b6 b9 bc bf c0 c5 c6 1
c8 cd d1 d5 d8 dd e2 e5
e9 ea ef f0 f5 f7 fb fe
102 106 10b 110 114 118 11c 11f
122 126 12a 12e 131 135 139 13c
13f 144 147 14a 14d 14e 153 154
1 156 15b 15f 163 166 16b 170
173 177 178 17d 180 185 186 18b
18e 193 194 199 19c 1a0 1a4 1a7
1a8 1ad 1ae 1b3 1b5 1b9 1bc 1c0
1c4 1c8 1cb 1cf 1d1 1d5 1d7 1e3
1e7 1e9 1ea 1f3 
8c
2
0 1 a 1e 0 25 :2 1 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 5b 61 64 :2 5b
72 :2 7 51 :2 4 7 :2 11 23 :2 2d
39 3c 53 54 55 :2 53 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 58
:3 4 c 16 :3 4 :2 d 19 4 7
:2 11 23 :2 2d 39 3c 53 55 56
:2 53 :2 23 :3 7 :2 d 12 1e 63 66
:2 1e 73 76 :2 1e 7a 7d :2 1e 87
8a :2 93 :2 1e :2 7 59 :3 4 b :2 14
4 :9 1 
8c
4
0 :3 1 0 :3 1
:b 4 :12 5 :3 4 :11 8
:b 9 :3 8 :5 e :5 f
:11 11 :19 12 :3 11 :5 14
:2 3 :7 1 
1f5
4
:3 0 1 :3 0 8
9 :2 0 3 :3 0
2 :a 0 87 1
:7 0 4 :3 0 4
5 0 87 2
6 :2 0 5 :3 0
6 :3 0 5 :3 0
7 :3 0 b c
0 2 :4 0 3
d f a 11
10 :2 0 8 :3 0
9 :3 0 13 14
0 a :4 0 5
:3 0 b :3 0 17
18 0 2 :4 0
5 19 1b c
:4 0 d :2 0 e
:3 0 7 1e 20
:3 0 f :4 0 a
15 23 :2 0 25
f 26 12 25
0 27 11 0
83 5 :3 0 6
:3 0 28 29 0
5 :3 0 10 :3 0
2b 2c 0 11
:2 0 2 :4 0 12
:2 0 13 :2 0 11
:2 0 13 31 33
:3 0 16 2d 35
2a 37 36 :2 0
8 :3 0 14 :3 0
39 3a 0 a
:4 0 15 :4 0 d
:2 0 e :3 0 1a
3e 40 :3 0 1d
3b 42 :2 0 44
20 45 38 44
0 46 22 0
83 16 :3 0 17
:3 0 18 :4 0 49
:4 0 4a :2 0 83
19 :3 0 1a :3 0
4c 4d 0 1b
:2 0 4e 4f 0
83 5 :3 0 6
:3 0 51 52 0
5 :3 0 10 :3 0
54 55 0 11
:2 0 2 :4 0 1c
:2 0 13 :2 0 11
:2 0 24 5a 5c
:3 0 27 56 5e
53 60 5f :2 0
8 :3 0 14 :3 0
62 63 0 a
:4 0 1d :4 0 d
:2 0 e :3 0 2b
67 69 :3 0 d
:2 0 1e :4 0 2e
6b 6d :3 0 d
:2 0 1f :4 0 31
6f 71 :3 0 d
:2 0 19 :3 0 1a
:3 0 74 75 0
34 73 77 :3 0
37 64 79 :2 0
7b 3a 7c 61
7b 0 7d 3c
0 83 3 :3 0
19 :3 0 1a :3 0
7f 80 0 81
:2 0 83 3e 86
:3 0 86 0 86
85 83 84 :6 0
87 :2 0 2 6
86 8a :3 0 89
87 8b :8 0 
45
4
:3 0 1 e 1
1a 2 1d 1f
4 16 1c 21
22 1 24 1
26 2 30 32
3 2e 2f 34
2 3d 3f 2
3c 41 1 43
1 45 2 59
5b 3 57 58
5d 2 66 68
2 6a 6c 2
6e 70 2 72
76 2 65 78
1 7a 1 7c
6 27 46 4b
50 7d 82 
1
4
0 
8a
0
1
14
1
1
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
0

/
SHOW ERRORS FUNCTION FC_U_CREATETMPTABLE;
ALTER FUNCTION FC_U_CREATETMPTABLE COMPILE DEBUG;
/************************************************************************************************/
/*****************************************************************************************/
Prompt == FUNCTION FC_U_TSKRES2 ==
CREATE OR REPLACE FUNCTION FC_U_TSKRES2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ee
2 :e:
1FUNCTION:
1FC_U_TSKRES2:
1H_ASSIGN_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1H_AND_ROLES:
1H_AND_SKILLS:
1SH_H_WORK_LOCATION:
1PLS_INTEGER:
1H_START_DATE:
1H_FINISH_DATE:
1SH_H_EFFORT:
1SH_H_WORK:
1SH_H_EUNIT:
1SH_H_UNIT:
1SH_H_WORK_TYPE:
1SH_H_BITFLAG:
1SH_H_CONTOUR:
1SH_H_CONTOUR_TYPE:
1SH_H_OCCURRENCE:
1H_ASSIGN_STRING:
1H_REC_USER:
1RETURN:
1H_WORK_LOCATION:
1H_EFFORT:
1H_WORK:
1H_EUNIT:
1H_UNIT:
1H_WORK_TYPE:
1H_BITFLAG:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_OCCURRENCE:
1H_TASK_ID:
132:
1H_RES_ID:
1H_START_DT:
126:
1H_FINISH_DT:
1H_DAYOFYEAR:
1DATE:
1H_LAST_SUBMITTED:
1H_TSK_ASSIGNMENT_ID:
1H_PROJECT_ID:
1H_CALENDAR_ID:
1H_SECURITY_ID:
1H_RES_TYPE:
11:
1H_BIT_FLAG:
1H_FULL_NAME:
1255:
1H_NULL_STR:
1H_MIN_PER_DAY:
10:
1H_TYPE:
1H_PER_WEEK:
1H_CONSIDER:
1H_ROLLUP:
1H_CRI:
1H_TEMP_SC_STATE:
1H_TRANSFED_CRI:
1H_WORK_TODATE:
1H_TEMP_VAR:
1H_TEMP_SECURITY_ID:
1H_TEMP2_SECURITY_ID:
1H_SD:
1H_FD:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DURATION:
1H_PERCENT_UNITS:
1H_SCHED_WORK:
1H_PRIORITY:
1H_UPDATE:
1H_ZERO:
1H_RES_COST:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_TSKRES2(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
194:
1+:
1FPUT:
1               ENTER:: FC_U_TSKRES2(95) :: cplan.sql(7510) :: :
1PMO_CNST:
1>=:
1SC_BIT_30:
1PMO_FUNC:
1SHIFTRIGHT:
1BITAND:
1SC_C0000000:
130:
1SC_1FFFFFFF:
1ELSIF:
1SC_BIT_28:
1SC_BIT_NOT_28:
10.00:
1=:
1PROJECT_ID:
1TASK_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1LAST_SUBMITTED:
1WORK_TODATE:
1TO_DATE:
1SUBSTR:
1SCHED_START:
1SCHED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT:n         PROJECT_ID,:n         TASK_ID,:n         RESOURCE_ID,:n     +
1    RESOURCE_TYPE,:n         LAST_SUBMITTED,:n         WORK_TODATE,:n        +
1 TO_DATE(SubStr(SCHED_START, 1, 10)),:n         TO_DATE(SubStr(SCHED_FINISH, +
11, 10)),:n         BILLABLE,:n         CAPITAL_EXPENSE,:n         REGULAR_COS+
1T,:n         REGULAR_RATE:n         INTO:n         h_project_id,:n         h_+
1task_id,:n         h_res_id,:n         h_res_type,:n         h_last_submitted+
1,:n         h_work_todate,:n         h_SD,:n         h_FD,:n         h_billab+
1le,:n         h_capital_expense,:n         h_reg_cost,:n         h_reg_sale:n+
1         FROM TASK_ASSIGNMENTS:n         WHERE TSK_ASSIGNMENT_ID = h_tsk_assi+
1gnment_id:
1PMO_DB2M:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1165:
1           EXCEPTION:: FC_U_TSKRES2(166) :: cplan.sql(7581) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1172:
1                EXIT:: FC_U_TSKRES2(173) :: cplan.sql(7588) :: :
1RECORD_NOT_FOUND:
1ELEMENT_ID:
1ELEMENT_TYPE:
1SECURITY_ID:
1CRI_SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1RES_ASSIGNMENT_ID:
1SELECT PROJECT_ID, ELEMENT_ID, RESOURCE_ID, ELEMENT_TYPE, :n         RESOURCE+
1_TYPE, SECURITY_ID, CASE WHEN CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END:n    +
1     INTO h_project_id, h_task_id, h_res_id, h_type,:n         h_res_type, h_+
1security_id, h_transfed_cri:n         FROM RESOURCE_ASSIGNMENTS :n         WH+
1ERE RES_ASSIGNMENT_ID = h_assign_id:
1192:
1           EXCEPTION:: FC_U_TSKRES2(193) :: cplan.sql(7608) :: :
1199:
1                EXIT:: FC_U_TSKRES2(200) :: cplan.sql(7615) :: :
1ISWBSTRANSFEREDDELIV:
1!=:
1204:
1                EXIT:: FC_U_TSKRES2(205) :: cplan.sql(7620) :: :
1TASK_ASSIGNMENT_ERROR:
1WORK_LOCATION:
1UPDATE RESOURCE_ASSIGNMENTS SET WORK_LOCATION = h_work_location:n         WHE+
1RE RES_ASSIGNMENT_ID = h_assign_id:
1FOUND:
1TRUE:
1100:
1224:
1           EXCEPTION:: FC_U_TSKRES2(225) :: cplan.sql(7640) :: :
1ISPROJECTTYPE:
1NOT:
1SELECT TSK_ASSIGNMENT_ID INTO h_tsk_assignment_id:n            FROM TASK_ASSI+
1GNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
1241:
1           EXCEPTION:: FC_U_TSKRES2(242) :: cplan.sql(7657) :: :
1SC_SQL_SUCCESS:
1248:
1                EXIT:: FC_U_TSKRES2(249) :: cplan.sql(7664) :: :
1RECORD_ALREADY_ASSIGNED:
1FC_AFTER_U_RES_ASSIGN:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1CALENDAR_ID:
1PRIORITY:
1TMT_WBS:
1SELECT COALESCE(MINUTE_PER_DAY, 480), COALESCE(MINUTE_PER_WEEK, 2400), CALEND+
1AR_ID, PRIORITY:n      INTO h_min_per_day, h_per_week, h_calendar_id, h_prior+
1ity:n      FROM TMT_WBS WHERE ELEMENT_ID = h_project_id:
1270:
1           EXCEPTION:: FC_U_TSKRES2(271) :: cplan.sql(7686) :: :
1>:
15:
1*:
1IS NULL:
1SUM:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1DAY_YEAR:
1SELECT SUM(AVAILABLE_MIN) INTO h_effort FROM CALENDAR_DAY_OF_YEAR:n          +
1     WHERE ELEMENT_ID=h_project_id AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_star+
1t_date, 1, 10)) AND TO_DATE(SubStr(h_finish_date, 1, 10)):
1298:
1           EXCEPTION:: FC_U_TSKRES2(299) :: cplan.sql(7714) :: :
160:
12:
13:
1315:
1                EXIT:: FC_U_TSKRES2(316) :: cplan.sql(7731) :: :
1SC_BIT_NOT_30:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1BIT_FLAG:
1SELECT TSK_ASSIGNMENT_ID, UNRESOLVED_START, UNRESOLVED_FINISH, PLANNED_WORK+S+
1CHED_WORK, BIT_FLAG:n         INTO h_tsk_assignment_id, h_start_DT, h_finish_+
1DT, h_sched_work, h_bit_flag:n         FROM TASK_ASSIGNMENTS:n         WHERE +
1PROJECT_ID = h_project_id AND TASK_ID = h_project_id AND RESOURCE_ID = h_res_+
1id:
1338:
1           EXCEPTION:: FC_U_TSKRES2(339) :: cplan.sql(7754) :: :
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1BIT_OR:
1<:
1FC_DECLARE_PMO_TMP_SEARCH:
1SC_SRCH_FROM_PROJECT:
1FC_SEARCH_2:
1ETC:
1UPDATE TASK_ASSIGNMENTS SET ETC = h_effort:n                  WHERE RES_ASSIG+
1NMENT_ID = h_assign_id:
1389:
1           EXCEPTION:: FC_U_TSKRES2(390) :: cplan.sql(7805) :: :
1395:
1                EXIT:: FC_U_TSKRES2(396) :: cplan.sql(7811) :: :
1U_TSKRES2:
1110:
1RESOURCE_UNAVAILABLE:
1439:
1                EXIT:: FC_U_TSKRES2(440) :: cplan.sql(7855) :: :
1STATE:: :
0

0
0
af4
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 8f
a0 b0 3d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 90
:3 a0 b0 3f 90 :3 a0 b0 3f b4
:2 a0 2c 6a a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 51 a5 b a0 7e
a0 6b b4 2e :3 a0 6b :3 a0 51
a5 b :2 a0 6b a5 b 5a 51
a5 b d :4 a0 51 a5 b :2 a0
6b a5 b d a0 51 d a0
51 d a0 b7 :2 a0 51 a5 b
a0 7e a0 6b b4 2e :4 a0 51
a5 b :2 a0 6b a5 b 5a d
:4 a0 51 a5 b :2 a0 6b a5 b
5a d a0 51 d b7 19 :3 a0
51 a5 b d a0 51 d a0
51 d b7 :2 19 3c a0 51 d
a0 6e d a0 51 d a0 4d
d a0 4d d a0 4d d a0
4d d a0 51 d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d :1f a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c b7 :11 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 a0 b7 :3 a0
51 a5 b a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
:2 19 3c :5 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b a5 b
5a 7e 51 b4 2e 7e b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c b7 19 3c :3 a0
a5 b d b7 :2 19 3c :d a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e a0 7e b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d b7 19 3c b7
:d a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 :2 a0 51
a5 b 7e 51 b4 2e :3 a0 51
a5 b 7e 51 b4 2e d a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d a0 b7 19
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d b7 :2 19 3c b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e :4 a0 51
a5 b :2 a0 6b a5 b 5a d
a0 b7 :2 a0 :2 51 a5 b 7e 6e
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :12 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e 5a a 10
:4 a0 51 a5 b :2 a0 6b a5 b
5a d :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 :2 51 a5 b 7e 6e
b4 2e :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 19 3c
a0 51 d b7 19 3c b7 :2 a0
51 a5 b 7e 51 b4 2e :3 a0
6b :2 a0 51 a5 b :2 a0 6b a5
b 5a d b7 19 3c :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a 10 :2 a0 :2 51
a5 b 7e 6e b4 2e a0 51
d b7 19 3c :2 a0 b4 2e d
:3 a0 6b d :20 a0 51 a5 b :5 51
a5 b d b7 19 3c :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c a0 51 65 b7 19 3c b7
:2 19 3c b7 19 3c b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e 5a 52 10
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 51
a5 b a5 b 5a d b7 19
3c :18 a0 :3 51 a5 b d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 51
a5 b a5 b 5a d b7 19
3c :18 a0 :3 51 a5 b d b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b d a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
a 10 :2 a0 6b :2 a0 6b d b7
:2 19 3c :2 a0 6b 7e 51 b4 2e
:2 a0 6b 51 d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 a4 b1 11 68 4f
1d 17 b5 
af4
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 73 6f 37
7b 8c 80 84 88 6e 93 a8
9c a0 a4 6b af b8 b4 9b
c0 cd c9 98 d5 de da c8
e6 f3 ef c5 fb 104 100 ee
10c 119 115 eb 121 12a 126 114
132 13f 13b 111 147 150 14c 13a
158 16d 161 165 169 137 174 185
179 17d 181 160 18c 15d 191 195
199 19d 1ba 1a5 1a9 1b1 1b5 1a4
1da 1c5 1c9 1d1 1d5 1a1 1f6 1e1
1e5 1ed 1f1 1c4 216 201 205 20d
211 1c1 232 21d 221 229 22d 200
252 23d 241 249 24d 1fd 26e 259
25d 265 269 23c 28e 279 27d 285
289 239 2aa 295 299 2a1 2a5 278
2ca 2b5 2b9 2c1 2c5 275 2e6 2d1
2d5 2d8 2d9 2e1 2b4 303 2f1 2b1
2f5 2f6 2fe 2f0 320 30e 2ed 312
313 31b 30d 33d 32b 30a 32f 330
338 32a 359 348 34c 354 327 371
360 364 36c 347 38e 37c 344 380
381 389 37b 3ab 399 378 39d 39e
3a6 398 3c8 3b6 395 3ba 3bb 3c3
3b5 3e5 3d3 3b2 3d7 3d8 3e0 3d2
402 3f0 3cf 3f4 3f5 3fd 3ef 41f
40d 3ec 411 412 41a 40c 43c 42a
409 42e 42f 437 429 459 447 426
44b 44c 454 446 475 464 468 443
470 463 491 480 484 460 48c 47f
4ad 49c 4a0 47c 4a8 49b 4c9 4b8
4bc 498 4c4 4b7 4e5 4d4 4d8 4b4
4e0 4d3 501 4f0 4f4 4d0 4fc 4ef
51d 50c 510 4ec 518 50b 539 528
52c 508 534 527 555 544 548 524
550 543 571 560 564 540 56c 55f
58e 57c 55c 580 581 589 57b 5ab
599 578 59d 59e 5a6 598 5c7 5b6
5ba 5c2 595 5df 5ce 5d2 5da 5b5
5fb 5ea 5ee 5b2 5f6 5e9 617 606
60a 5e6 612 605 633 622 626 602
62e 621 64f 63e 642 61e 64a 63d
66b 65a 65e 63a 666 659 687 676
67a 656 682 675 6a3 692 696 672
69e 691 6bf 6ae 6b2 68e 6ba 6ad
6db 6ca 6ce 6aa 6d6 6c9 6f7 6e6
6ea 6c6 6f2 6e5 713 702 706 6e2
70e 701 72f 71e 722 6fe 72a 71d
736 73a 71a 73e 742 746 749 74e
74f 1 751 756 75a 75e 761 766
76a 76e 771 776 777 779 77e 781
785 786 78b 790 793 798 799 79e
7a1 7a5 7a6 7ab 7ae 7b3 7b4 7b9
7bc 7c1 7c2 7c7 7ca 7cf 7d0 7d5
7d8 7dc 7dd 7e2 7e5 7ea 7eb 7f0
7f3 7f8 7f9 7fe 801 806 807 80c
80f 813 814 819 81c 821 822 827
82a 82f 830 835 838 83c 840 844
845 847 84c 84d 84f 850 855 858
85d 85e 863 866 86b 86c 871 874
878 879 87e 881 886 887 88c 88f
894 895 89a 89d 8a2 8a3 8a8 8ab
8af 8b0 8b5 8b8 8bd 8be 8c3 8c6
8cb 8cc 8d1 8d4 8d8 8dc 8e0 8e1
8e3 8e8 8e9 8eb 8ec 8f1 8f4 8f9
8fa 8ff 902 906 90a 90e 90f 911
916 917 919 91a 91f 922 927 928
92d 930 934 938 93c 93d 93f 944
945 947 948 94d 950 955 956 95b
95e 962 966 96a 96b 96d 972 973
975 976 97b 97e 983 984 989 98c
990 994 998 999 99b 9a0 9a1 9a3
9a4 9a9 9ac 9b1 9b2 9b7 9ba 9be
9c2 9c6 9c7 9c9 9ce 9cf 9d1 9d2
9d7 9da 9df 9e0 9e5 9e8 9ec 9f0
9f4 9f5 9f7 9fc 9fd 9ff a00 a05
a08 a0d a0e a13 a16 a1a a1e a22
a23 a25 a2a a2b a2d a2e a33 a36
a3b a3c a41 a44 a48 a4c a50 a51
a53 a58 a59 a5b a5c a61 a64 a69
a6a a6f a72 a77 a78 a7d a80 a84
a85 a8a a8d a92 a93 a98 a9b aa0
aa1 aa6 aa9 aae aaf ab4 ab7 abb
abc ac1 ac4 ac9 aca acf ad2 ad7
ad8 add ade ae3 ae5 ae9 aec af0
af4 af7 afb aff b02 b05 b0a b0d
b10 b13 b14 b19 b1a 1 b1c b21
b25 b29 b2c b31 b36 b39 b3d b3e
b43 b44 b49 b4b b4f b52 b56 b5a
b5d b5e b60 b64 b67 b6b b6e b6f
b74 b78 b7c b80 b83 b87 b8b b8f
b92 b93 b95 b99 b9d ba0 ba1 ba3
ba6 ba9 baa bac bb0 bb4 bb8 bbc
bc0 bc3 bc4 bc6 bca bce bd1 bd2
bd4 bd8 bdc bdf be3 be7 bea bee
bf2 bf4 bf8 bfc bff c00 c02 c06
c09 c0d c10 c11 c16 c1a c1e c22
c26 c29 c2a c2c c30 c34 c37 c38
c3a c3d c41 c45 c49 c4d c51 c54
c55 c57 c5b c5f c62 c63 c65 c68
c6c c70 c73 c77 c79 c7d c81 c85
c89 c8c c8d c8f c93 c97 c9a c9e
ca2 ca5 ca9 cab caf cb3 cb6 cba
cbd cc1 cc5 cca cce cd2 cd5 cd9
cdd cde ce2 ce6 ce7 ceb cef cf0
cf4 cf8 cf9 cfd d01 d04 d08 d0c
d10 d13 d14 d16 d19 d1c d1d d22
d26 d2a d2e d32 d36 d3a d3e d42
d46 d4a d4e d52 d56 d5a d5e d62
d66 d6a d6e d72 d76 d7a d7e d82
d86 d8a d8e d92 d96 d9a d9e da2
da6 daa db6 dba dbe dc1 dc5 dc9
dcb dcf dd3 dd7 dda dde de2 de4
de5 dea 1 dee df2 df6 df9 dfd
e01 e05 e09 e0c e10 e14 e17 e1a
e1f e22 e25 e28 e29 e2e e2f 1
e31 e36 e3a e3e e41 e46 e4b e4e
e52 e53 e58 e5b e60 e61 e66 e69
e6e e6f e74 e77 e7b e7c e81 e84
e89 e8a e8f e92 e96 e9a e9d ea0
ea1 ea3 ea4 ea9 eaa eaf eb1 eb5
eb8 eba ebe ec0 ecc ece ed0 ed1
ed6 eda edc ee8 eea eee ef2 ef5
ef9 efc f00 f03 f04 f09 f0c f10
f14 f17 f1b f1f f22 f25 f2a f2d
f30 f33 f34 f39 f3a 1 f3c f41
f45 f49 f4c f51 f56 f59 f5d f5e
f63 f64 f69 f6b f6f f72 f76 f7a
f7e f81 f85 f87 f8b f8e f90 f94
f98 f9c fa0 fa4 fa8 fac fb0 fb4
fb8 fbc fc0 fc4 fc8 fcc fd0 fd4
fe0 fe4 fe8 feb fef ff3 ff5 ff9
ffd 1001 1004 1008 100c 100e 100f 1014
1 1018 101c 1020 1023 1027 102b 102f
1033 1036 103a 103e 1041 1044 1049 104c
104f 1052 1053 1058 1059 1 105b 1060
1064 1068 106b 1070 1075 1078 107c 107d
1082 1085 108a 108b 1090 1093 1098 1099
109e 10a1 10a5 10a6 10ab 10ae 10b3 10b4
10b9 10bc 10c0 10c4 10c7 10ca 10cb 10cd
10ce 10d3 10d4 10d9 10db 10df 10e2 10e4
10e8 10ea 10f6 10f8 10fa 10fb 1100 1104
1106 1112 1114 1118 111c 111f 1123 1126
112a 112d 112e 1133 1136 113a 113e 1141
1145 1149 114c 114f 1154 1157 115a 115d
115e 1163 1164 1 1166 116b 116f 1173
1176 117b 1180 1183 1187 1188 118d 118e
1193 1195 1199 119c 11a0 11a4 11a8 11ab
11af 11b3 11b5 11b9 11bd 11c1 11c4 11c5
11c7 11c8 11ca 11cd 11d0 11d1 11d6 11da
11de 11e1 11e5 11e9 11ec 11ef 11f4 11f7
11fa 11fd 11fe 1203 1204 1 1206 120b
120f 1213 1216 121b 1220 1223 1227 1228
122d 122e 1233 1235 1239 123c 1240 1244
1248 124b 124f 1251 1255 1259 125c 1260
1264 1268 126c 1270 127c 1280 1285 1289
128c 128d 1292 1296 129a 129d 12a0 12a4
12a6 12aa 12ae 12b1 12b4 12b8 12ba 12be
12c2 12c5 12c7 12cb 12cf 12d3 12d6 12da
12de 12e0 12e1 12e6 1 12ea 12ee 12f2
12f5 12f9 12fd 1301 1305 1308 130c 1310
1313 1316 131b 131e 1321 1324 1325 132a
132b 1 132d 1332 1336 133a 133d 1342
1347 134a 134e 134f 1354 1357 135c 135d
1362 1365 136a 136b 1370 1373 1377 1378
137d 1380 1385 1386 138b 138e 1392 1396
1399 139c 139d 139f 13a0 13a5 13a6 13ab
13ad 13b1 13b4 13b6 13ba 13bc 13c8 13ca
13cc 13cd 13d2 13d6 13d8 13e4 13e6 13ea
13ee 13f2 13f5 13f6 13f8 13f9 13fb 13fe
1401 1404 1405 140a 140d 140e 1413 1417
141b 141f 1423 1427 1433 1437 143b 143e
1442 1446 1448 144c 1450 1454 1457 145b
145f 1461 1462 1467 1 146b 146f 1473
1476 147a 147e 1482 1486 1489 148d 1491
1494 1497 149c 149f 14a2 14a5 14a6 14ab
14ac 1 14ae 14b3 14b7 14bb 14be 14c3
14c8 14cb 14cf 14d0 14d5 14d8 14dd 14de
14e3 14e6 14eb 14ec 14f1 14f4 14f8 14f9
14fe 1501 1506 1507 150c 150f 1513 1517
151a 151d 151e 1520 1521 1526 1527 152c
152e 1532 1535 1537 153b 153d 1549 154b
154d 154e 1553 1557 1559 1565 1567 156b
156f 1572 1576 1579 157d 1580 1581 1586
1589 158d 1591 1594 1598 159c 159f 15a2
15a7 15aa 15ad 15b0 15b1 15b6 15b7 1
15b9 15be 15c2 15c6 15c9 15ce 15d3 15d6
15da 15db 15e0 15e1 15e6 15e8 15ec 15ef
15f3 15f7 15fb 15fe 1602 1604 1608 160b
160d 1611 1614 1618 161c 1620 1621 1623
1627 1629 162d 1631 1634 1638 163c 1640
1644 1648 164c 1650 1654 1658 165c 1660
1664 1668 1674 1678 167c 167f 1683 1687
1689 168d 1691 1695 1698 169c 16a0 16a2
16a3 16a8 1 16ac 16b0 16b4 16b7 16bb
16bf 16c3 16c7 16ca 16ce 16d2 16d5 16d8
16dd 16e0 16e3 16e6 16e7 16ec 16ed 1
16ef 16f4 16f8 16fc 16ff 1704 1709 170c
1710 1711 1716 1719 171e 171f 1724 1727
172c 172d 1732 1735 1739 173a 173f 1742
1747 1748 174d 1750 1754 1758 175b 175e
175f 1761 1762 1767 1768 176d 176f 1773
1776 1778 177c 177e 178a 178c 178e 178f
1794 1798 179a 17a6 17a8 17ac 17b0 17b3
17b4 17b6 17b9 17bc 17bd 17c2 17c6 17ca
17cd 17ce 17d0 17d3 17d6 17d7 17dc 17df
17e3 17e7 17ea 17eb 17ed 17f0 17f3 17f4
17f9 1 17fc 1801 1805 1809 180d 1810
1811 1813 1816 181a 181e 1821 1822 1824
1825 182a 182e 1830 1834 1837 183b 183f
1842 1843 1845 1848 184b 184c 1851 1855
1858 1859 185e 1861 1865 1869 186c 186d
186f 1872 1875 1876 187b 187f 1883 1887
188a 188b 188d 1890 1894 1898 189b 189c
189e 189f 18a4 18a8 18aa 18ae 18b1 18b3
18b7 18bb 18bf 18c3 18c7 18cb 18cf 18d3
18d7 18db 18df 18e3 18e7 18f3 18f7 18fb
18fe 1902 1906 1908 190c 1910 1914 1917
191b 191f 1921 1922 1927 1 192b 192f
1933 1936 193a 193e 1942 1946 1949 194d
1951 1954 1957 195c 195f 1962 1965 1966
196b 196c 1 196e 1973 1977 197b 197e
1983 1988 198b 198f 1990 1995 1998 199d
199e 19a3 19a6 19ab 19ac 19b1 19b4 19b8
19b9 19be 19c1 19c6 19c7 19cc 19cf 19d3
19d7 19da 19dd 19de 19e0 19e1 19e6 19e7
19ec 19ee 19f2 19f5 19f7 19fb 19fd 1a09
1a0b 1a0d 1a0e 1a13 1a17 1a19 1a25 1a27
1a29 1a2d 1a31 1a34 1a36 1a3a 1a3e 1a41
1a42 1a44 1a47 1a4a 1a4b 1a50 1a54 1a58
1a5c 1a5f 1a60 1a62 1a65 1a68 1a69 1a6e
1a72 1a76 1a78 1a7c 1a80 1a83 1a84 1a86
1a89 1a8c 1a8d 1a92 1a96 1a9a 1a9e 1aa1
1aa2 1aa4 1aa7 1aab 1aaf 1ab2 1ab3 1ab5
1ab6 1abb 1abf 1ac3 1ac5 1ac9 1acd 1ad1
1ad4 1ad5 1ad7 1ada 1add 1ade 1ae3 1ae7
1aeb 1aef 1af2 1af3 1af5 1af8 1afc 1b00
1b03 1b04 1b06 1b07 1b0c 1b10 1b12 1b16
1b1a 1b1d 1b1f 1b23 1b27 1b2a 1b2e 1b32
1b35 1b36 1b38 1b3b 1b3e 1b3f 1b44 1b48
1b4c 1b4f 1b53 1b57 1b5a 1b5d 1b62 1b65
1b68 1b6b 1b6c 1b71 1b72 1 1b74 1b79
1b7d 1b81 1b84 1b89 1b8e 1b91 1b95 1b96
1b9b 1b9c 1ba1 1ba3 1ba7 1baa 1bae 1bb2
1bb6 1bb9 1bbd 1bbf 1bc3 1bc6 1bc8 1bcc
1bcf 1bd3 1bd7 1bda 1bdb 1bdd 1be0 1be3
1be4 1be9 1bed 1bf1 1bf5 1bf9 1bfc 1bfd
1bff 1c03 1c07 1c0a 1c0b 1c0d 1c10 1c14
1c18 1c1a 1c1e 1c22 1c25 1c28 1c29 1c2b
1c2e 1c33 1c34 1c39 1c3c 1c40 1c44 1c47
1c48 1c4a 1c4d 1c50 1c51 1c56 1 1c59
1c5e 1c62 1c66 1c6a 1c6e 1c72 1c76 1c7a
1c7e 1c82 1c86 1c8a 1c8e 1c92 1c96 1c9a
1c9e 1ca2 1ca6 1cb2 1cb6 1cba 1cbd 1cc1
1cc5 1cc7 1ccb 1ccf 1cd3 1cd6 1cda 1cde
1ce0 1ce1 1ce6 1 1cea 1cee 1cf2 1cf5
1cf9 1cfd 1d01 1d05 1d08 1d0c 1d10 1d13
1d16 1d1b 1d1e 1d21 1d24 1d25 1d2a 1d2b
1 1d2d 1d32 1d36 1d3a 1d3d 1d42 1d47
1d4a 1d4e 1d4f 1d54 1d57 1d5c 1d5d 1d62
1d65 1d6a 1d6b 1d70 1d73 1d77 1d78 1d7d
1d80 1d85 1d86 1d8b 1d8e 1d92 1d96 1d99
1d9c 1d9d 1d9f 1da0 1da5 1da6 1dab 1dad
1db1 1db4 1db6 1dba 1dbc 1dc8 1dca 1dcc
1dcd 1dd2 1dd6 1dd8 1de4 1de6 1dea 1dee
1df1 1df5 1df8 1dfc 1dff 1e00 1e05 1e08
1e0c 1e0f 1e10 1e15 1 1e18 1e1d 1e21
1e25 1e29 1e2d 1e30 1e31 1e33 1e37 1e3b
1e3e 1e3f 1e41 1e44 1e48 1e4c 1e50 1e53
1e57 1e5b 1e5e 1e5f 1e61 1e64 1e67 1e68
1e6d 1e70 1e74 1e78 1e7b 1e7f 1e83 1e86
1e87 1e89 1e8c 1e8f 1e90 1e95 1 1e98
1e9d 1ea1 1ea5 1ea8 1eab 1eac 1eae 1eb1
1eb6 1eb7 1ebc 1ec0 1ec4 1ec7 1ec8 1eca
1ecd 1ed0 1ed1 1ed6 1eda 1edd 1ee1 1ee3
1ee7 1eea 1eee 1ef1 1ef5 1ef7 1efb 1efe
1f00 1f04 1f08 1f0b 1f0c 1f0e 1f11 1f14
1f15 1f1a 1f1e 1f22 1f26 1f29 1f2d 1f31
1f34 1f35 1f37 1f3b 1f3f 1f42 1f43 1f45
1f48 1f4c 1f4e 1f52 1f55 1f59 1f5d 1f60
1f61 1f63 1f67 1f6a 1f6e 1f71 1f72 1f74
1f75 1f7a 1f7e 1f82 1f85 1f86 1f88 1f8b
1f8e 1f8f 1f94 1f98 1f9c 1f9f 1fa3 1fa7
1faa 1fab 1fad 1fb0 1fb3 1fb4 1 1fb9
1fbe 1fc2 1fc6 1fc9 1fcc 1fcd 1fcf 1fd2
1fd7 1fd8 1fdd 1fe1 1fe4 1fe8 1fea 1fee
1ff1 1ff5 1ff9 1ffa 1fff 2003 2007 200b
200f 2012 2016 201a 201e 2022 2026 202a
202e 2032 2036 203a 203e 2042 2046 204a
204e 2052 2056 205a 205e 2062 2066 206a
206e 2072 2076 207a 207e 2082 2086 208a
208e 2092 2096 2099 209a 209c 209f 20a2
20a5 20a8 20ab 20ac 20ae 20b2 20b4 20b8
20bb 20bf 20c3 20c7 20cb 20cf 20db 20df
20e4 20e8 20eb 20ec 20f1 20f5 20f9 20fc
20ff 2103 2105 2109 210d 2110 2113 2117
2119 211d 2121 2124 2126 212a 212e 2132
2135 2139 213d 213f 2140 2145 1 2149
214d 2151 2154 2158 215c 2160 2164 2167
216b 216f 2172 2175 217a 217d 2180 2183
2184 2189 218a 1 218c 2191 2195 2199
219c 21a1 21a6 21a9 21ad 21ae 21b3 21b6
21bb 21bc 21c1 21c4 21c9 21ca 21cf 21d2
21d6 21d7 21dc 21df 21e4 21e5 21ea 21ed
21f1 21f5 21f8 21fb 21fc 21fe 21ff 2204
2205 220a 220c 2210 2213 2215 2219 221b
2227 2229 222b 222c 2231 2235 2237 2243
2245 2249 224d 2250 2254 2258 225b 225e
2263 2266 2269 226c 226d 2272 2273 1
2275 227a 227e 2282 2285 228a 228f 2292
2296 2297 229c 229d 22a2 22a4 22a8 22ab
22af 22b2 22b6 22b8 22bc 22bf 22c1 22c5
22c9 22cc 22ce 22d2 22d5 22d7 22db 22df
22e2 22e6 22ea 22ed 22ee 22f0 22f3 22f6
22f7 22fc 22ff 2303 2307 230a 230b 230d
2311 2314 2318 231b 231c 231e 231f 2324
1 2327 232c 2330 2334 2337 2338 233a
233d 2340 2341 2346 234a 234e 2352 2355
2359 235d 2360 2361 2363 2367 236b 236e
236f 2371 2372 2374 2377 237b 237d 2381
2384 2388 238c 2390 2394 2398 239c 23a0
23a4 23a8 23ac 23b0 23b4 23b8 23bc 23c0
23c4 23c8 23cc 23d0 23d4 23d8 23dc 23e0
23e4 23e7 23ea 23ed 23ee 23f0 23f4 23f8
23fa 23fe 2402 2405 2406 2408 240b 240e
240f 2414 2418 241c 241f 2420 2422 2425
2428 2429 242e 2432 2436 243a 243d 2441
2445 2448 2449 244b 244f 2453 2456 2457
2459 245a 245c 245f 2463 2465 2469 246c
2470 2474 2478 247c 2480 2484 2488 248c
2490 2494 2498 249c 24a0 24a4 24a8 24ac
24b0 24b4 24b8 24bc 24c0 24c4 24c8 24cc
24cf 24d2 24d5 24d6 24d8 24dc 24de 24e2
24e6 24e9 24ed 24f1 24f4 24f5 24f7 24fa
24fd 24fe 2503 2507 250b 250e 2512 2516
2519 251d 2521 2523 2527 252b 252e 252f
2531 2534 2537 2538 253d 2541 2545 2548
2549 254b 254e 2551 2552 1 2557 255c
2560 2564 2567 256b 256f 2572 2576 2578
257c 2580 2583 2587 258b 258e 2591 2594
2595 259a 259e 25a2 25a5 25a8 25ac 25ae
25b2 25b5 25b9 25bd 25c0 25c4 25c8 25cb
25ce 25d3 25d6 25d9 25dc 25dd 25e2 25e3
1 25e5 25ea 25ee 25f2 25f5 25fa 25ff
2602 2606 2607 260c 260f 2614 2615 261a
261d 2622 2623 2628 262b 262f 2633 2636
2637 263c 263d 2642 2644 2648 264b 264f
2653 2657 265a 265e 2660 2664 2666 2672
2676 2678 2679 2682 
af4
2
0 1 a 6 15 19 20 :3 6
15 19 20 :3 6 16 1a 21 :3 6
19 :3 6 16 1a 21 :3 6 17 1b
22 :3 6 12 :3 6 10 :3 6 11 :3 6
10 :3 6 15 :3 6 13 :3 6 13 :3 6
18 :3 6 16 :3 6 19 1d 24 :3 6
14 18 1f :2 6 1 3 a :2 1
4 :2 14 23 14 :2 4 :2 d 1c d
:2 4 :2 b 1a b :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 10 1f 10
:2 4 :2 e 1d e :2 4 :2 e 1d e
:2 4 :2 13 22 13 :2 4 :2 11 20 11
:2 4 e 17 16 :2 e :2 4 d 16
15 :2 d :2 4 f 18 17 :2 f :2 4
10 19 18 :2 10 :2 4 :3 10 :2 4 :3 15
:2 4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 12 1b 1a :2 12 :2 4
12 1b 1a :2 12 :2 4 f 18 17
:2 f :2 4 f 18 17 :2 f :2 4 10
19 18 :2 10 :2 4 f 18 17 :2 f
:2 4 :2 12 21 12 :2 4 :2 b 1a b
:2 4 :2 f 1e f :2 4 :2 f 1e f
:2 4 :2 d 1c d :2 4 :2 a 19 a
:2 4 :2 14 23 14 :2 4 :2 13 22 13
:2 4 :2 12 21 12 :2 4 :2 f 1e f
:2 4 17 20 1f :2 17 :2 4 18 21
20 :2 18 :2 4 :3 9 :2 4 :3 9 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 :2 f
1e f :2 4 :2 16 25 16 :2 4 :2 11
20 11 :2 4 :2 f 1e f :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 :2 f
1e f :2 4 :2 d 1c d :2 4 :2 b
1a b :2 4 :2 f 19 f 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 54 5a 5d :2 54
6b 81 8 :2 6b d 10 :2 6b 1c
1f :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 2a 2d :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 2b
2e :2 6b b e :2 6b 13 16 1f
27 :2 1f 3c :2 16 :2 6b b e :2 6b
13 16 :2 6b 1b 1e :2 6b 2b 2e
:2 6b b e :2 6b 13 16 :2 6b 1b
1e :2 6b 2c 2f :2 6b b e :2 6b
13 16 1f 27 :2 1f 35 :2 16 :2 6b
b e :2 6b 13 16 1f 27 :2 1f
33 :2 16 :2 6b b e :2 6b 13 16
1f 27 :2 1f 34 :2 16 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 33 :2 16
:2 6b b e :2 6b 13 16 1f 27
:2 1f 38 :2 16 :2 6b b e :2 6b 13
16 1f 27 :2 1f 36 :2 16 :2 6b b
e :2 6b 13 16 1f 27 :2 1f 36
:2 16 :2 6b b e :2 6b 13 16 1f
27 :2 1f 3b :2 16 :2 6b b e :2 6b
13 16 1f 27 :2 1f 39 :2 16 :2 6b
b e :2 6b 13 16 :2 6b 1b 1e
:2 6b 2e 31 :2 6b b e :2 6b 13
16 :2 6b 1b 1e :2 6b 29 2c :2 6b
31 34 :2 6b :2 7 4a :2 4 7 :2 11
23 :2 2d 39 3c 4c 4e 4f :2 4c
:2 23 :3 7 :2 d 12 1e 5c 5f :2 1e
:2 7 52 :2 4 7 10 1b :2 7 21
1e :2 2a :2 1e 7 10 :2 19 25 2c
35 40 :2 2c 44 :2 4d :2 25 24 5c
:2 10 :2 7 15 1c 25 30 :2 1c 34
:2 3d :2 15 :2 7 14 :2 7 13 7 4
34 a 13 1e :2 a 24 21 :2 2d
:2 21 7 14 1b 24 2f :2 1b 33
:2 3c :2 14 13 :2 7 15 1c 25 30
:2 1c 34 :2 3d :2 15 14 :2 7 15 7
37 34 7 15 1e 29 :2 15 :2 7
14 :2 7 13 7 :5 4 12 :2 4 12
:2 4 15 :2 4 18 :2 4 c :2 4 c
:2 4 12 :2 4 12 4 7 10 1b
:2 7 1e 20 :2 1e 7 1e 7 :7 a
12 19 a 12 19 :10 a f 10
24 fffa a :2 13 1f a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 66 69 :2 27 76 79 :2 27
7d 80 :2 27 8c 8f :2 27 97 9a
:2 27 a6 a9 b0 b9 bc :2 a9 :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 22
b :2 14 1f 1d :2 28 :2 1d a d
:2 17 29 :2 33 3f 42 52 55 56
:2 52 :2 29 :3 d :2 13 18 24 63 66
:2 24 :2 d 59 :3 a 11 :2 1a a 38
:2 7 22 11 1d 29 36 a 19
30 f 1d 28 32 a 16 25
f 10 24 :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 66 69 :2 27 76 79
:2 27 7d 80 :2 27 8c 8f :2 27 97
9a :2 27 a6 a9 b0 b9 bc :2 a9
:2 27 :2 10 5d :2 d :2 a :4 16 :2 a 7
:3 4 b :2 14 1f 1d :2 28 :2 1d a
d :2 17 29 :2 33 3f 42 52 55
56 :2 52 :2 29 :3 d :2 13 18 24 63
66 :2 24 :2 d 59 :3 a 11 :2 1a a
7 38 d 22 2b 33 :2 22 :2 d
37 3a :2 37 d :2 17 29 :2 33 3f
42 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 63 66 :2 24 :2 d 59 :3 a
11 :2 1a a 3c 38 :2 7 11 2a
3a 10 24 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 66 69
:2 27 76 79 :2 27 7d 80 :2 27 8c
8f :2 27 97 9a :2 27 a6 a9 b0
b9 bc :2 a9 :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 4 f 1d 26 2e
:2 1d :2 f e 33 36 :2 33 :3 a 14
2b 12 29 3d :2 d :2 16 22 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5c 5d :2 59 :2 2f
:3 13 :2 19 1e 2a 69 6c :2 2a 79
7c :2 2a 80 83 :2 2a 8f 92 :2 2a
9a 9d :2 2a a9 ac b3 bc bf
:2 ac :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :3 38 e :2 17 22 20 :2 2b :2 20
d 10 :2 1a 2c :2 36 42 45 55
58 59 :2 55 :2 2c :3 10 :2 16 1b 27
66 69 :2 27 :2 10 5c :3 d 14 :2 1d
d 3b :2 a 38 :3 7 1a 30 :2 1a
7 :4 4 e 17 2d 36 4e 5b
c 1b 27 36 c 1a 27 :2 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 53 56
57 :2 53 :2 29 :3 d :2 13 18 24 63
66 :2 24 73 76 :2 24 7a 7d :2 24
89 8c :2 24 94 97 :2 24 a3 a6
ad b6 b9 :2 a6 :2 24 :2 d 5a :2 a
:2 7 :4 13 :2 7 4 :3 1 7 10 1a
:2 7 1d 1f :2 1d b 14 1c :2 b
1f 21 :2 1f a 29 32 3a :2 29
3d 3f :2 3d 28 :3 a 14 1d 2c
:2 14 2f 31 3a 42 :2 31 :2 14 a
42 :2 7 a 13 1d :2 a 20 22
:2 20 :4 e d 10 19 21 :2 10 24
26 :2 24 10 1c 25 33 :2 1c 36
38 41 49 :2 38 :2 1c 10 28 :2 d
25 17 1b 2f 3d 16 21 32
43 4b 52 6c 74 7b :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5c 5f 60
:2 5c :2 32 :3 16 :2 1c 21 2d 6c 6f
:2 2d 7c 7f :2 2d 83 86 :2 2d 92
95 :2 2d 9d a0 :2 2d ac af b6
bf c2 :2 af :2 2d :2 16 63 :2 13 :2 10
:4 1c :2 10 d :7 a 24 d 16 1f
:2 d 22 24 :2 22 d 19 22 2c
:2 19 2f 31 :2 19 d a 26 10
19 22 :2 10 25 27 :2 25 d 19
22 31 :2 19 34 36 3f 49 :2 36
:2 19 d a 29 26 10 19 22
:2 10 25 27 :2 25 d 19 22 2e
:2 19 31 33 3c 46 :2 33 :2 19 d
29 26 :2 a :4 7 a 13 1d :2 a
20 22 :2 20 d :2 17 29 :2 33 3f
42 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 63 66 :2 24 :2 d 59 :3 a
11 :2 1a a 24 :2 7 21 :2 4 7
10 1b :2 7 1e 20 :2 1e 7 15
1c 25 30 :2 1c 34 :2 3d :2 15 14
7 4 22 b 12 1e 21 :2 b
24 26 :2 24 a 30 39 46 :2 30
49 4b :2 49 2f :2 a 11 24 36
49 56 62 f 24 30 3d 4b
f 10 1d 2e 38 49 57 :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 66
69 :2 27 76 79 :2 27 7d 80 :2 27
8c 8f :2 27 97 9a :2 27 a6 a9
b0 b9 bc :2 a9 :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 4e b :2 14 1f
1d :2 28 :2 1d a :4 3d 3c :3 a 18
1f 28 33 :2 1f 37 :2 40 :2 18 17
a e :2 19 21 2f 3b :2 e 3f
42 :2 3f d 4a :2 55 5d 12 21
:2 4a 25 28 :2 25 49 :2 d 10 17
23 26 :2 10 29 2b :2 29 13 1c
26 :2 13 29 2b :2 29 13 20 13
2d :3 10 1f 10 2f :2 d 2b 10
19 24 :2 10 27 29 :2 27 10 1f
:2 28 2f 38 44 :2 2f 48 :2 51 :2 1f
1e 10 2b :2 d 10 19 27 :2 10
2c 2a 35 3f :2 2c :2 2a 13 1c
2a :2 13 2d 2f :2 2d 35 :2 40 48
56 63 :2 35 67 6a :2 67 :2 13 16
1d 29 2c :2 16 2f 31 :2 2f 16
22 16 35 :3 13 :3 26 :2 13 21 :2 2a
:2 13 26 32 3f 4d 58 62 6e
22 2f 3d 49 55 22 2f 37
45 4d 56 5e 22 2e 3a 47
52 22 30 3a 49 55 22 2b
3a :2 22 3e 41 47 4d 50 :2 26
13 6c :2 10 1a 2f 35 19 2d
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 5f 62 63 :2 5f :2 35 :3 19
:2 1f 24 30 6f 72 :2 30 7f 82
:2 30 86 89 :2 30 95 98 :2 30 a0
a3 :2 30 af b2 b9 c2 c5 :2 b2
:2 30 :2 19 66 :2 16 :2 13 :4 1f :2 13 10
:3 42 13 :2 1d 2f :2 39 45 48 58
5b 5c :2 58 :2 2f :3 13 :2 19 1e 2a
69 6c :2 2a :2 13 5f :3 10 17 10
42 :2 d :4 a 5e :2 7 4e 22 :2 4
8 11 1c :2 8 1f 21 :2 1f 7
28 31 3f :2 28 44 42 4d 5c
:2 44 :2 42 27 :2 7 a 13 1d :2 a
20 23 :2 20 a 18 :2 21 28 31
3c :2 28 40 49 53 :2 40 :2 18 17
a 25 :3 7 1a 24 31 3f 4a
54 20 2e 3c 4b 55 5d 20
28 34 41 4c 57 20 2e 3a
4b 57 20 26 2c :2 1a 7 4
60 a 13 1e :2 a 21 23 :2 21
a 13 1d :2 a 20 23 :2 20 a
18 :2 21 28 31 3c :2 28 40 49
53 :2 40 :2 18 17 a 25 :3 7 1a
24 39 47 52 5c 20 2e 3c
4b 55 5d 20 28 34 41 4c
57 20 2e 3a 4b 57 20 26
2c :2 1a 7 25 60 :2 4 7 10
21 :2 7 24 26 :2 24 7 :2 10 1c
:2 25 7 4 2a a 13 24 :2 a
27 2a :2 27 30 39 4a :2 30 4d
50 :2 4d :2 a 7 :2 10 1c :2 25 7
54 2a :2 4 7 :2 10 19 1b :2 19
7 :2 10 1c 7 1f :2 4 7 :2 11
23 :2 2d 39 3c 4c 4f 50 :2 4c
:2 23 :3 7 :2 d 12 1e 5d 60 :2 1e
6d 70 :2 1e 74 77 :2 1e 81 84
:2 8d :2 1e :2 7 53 :3 4 b :2 14 4
:9 1 
af4
4
0 :2 1 :6 3 :6 4
:6 5 :4 6 :6 7 :6 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :6 12 :6 13 2
:2 14 :2 1 :6 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:7 20 :7 21 :7 22 :7 23
:5 24 :5 25 :7 26 :7 27
:7 28 :7 29 :7 2a :7 2b
:7 2c :7 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:7 38 :7 39 :5 3a :5 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:b 49 :11 4a 4b :2 4a
:2 4b :2 4a :2 4b :2 4a
:2 4c :2 4a :2 4c :2 4a
:2 4c :2 4a :2 4c :2 4a
:2 4d :2 4a :2 4d :2 4a
:2 4d :2 4a :2 4d :2 4a
:2 4e :2 4a :9 4e :2 4a
:2 4f :2 4a :2 4f :2 4a
:2 4f :2 4a :2 4f :2 4a
:2 50 :2 4a :2 50 :2 4a
:2 50 :2 4a :2 50 :2 4a
:2 51 :2 4a :9 51 :2 4a
:2 52 :2 4a :9 52 :2 4a
:2 53 :2 4a :9 53 :2 4a
:2 54 :2 4a :9 54 :2 4a
:2 55 :2 4a :9 55 :2 4a
:2 56 :2 4a :9 56 :2 4a
:2 57 :2 4a :9 57 :2 4a
:2 58 :2 4a :9 58 :2 4a
:2 59 :2 4a :9 59 :2 4a
:2 5a :2 4a :2 5a :2 4a
:2 5a :2 4a :2 5a :2 4a
:2 5b :2 4a :2 5b :2 4a
:2 5b :2 4a :2 5b :2 4a
:2 5b :4 4a :3 49 :11 5e
:b 5f :3 5e :b 64 :14 65
:d 67 :3 68 :3 69 6a
64 :b 6a :e 6b :e 6d
:3 6f 6a 64 :7 71
:3 72 :3 73 70 :3 64
:3 76 :3 77 :3 78 :3 79
:3 7a :3 7b :3 7c :3 7d
:9 7f :3 80 83 84
85 86 87 88
:3 89 :3 8a 8b 8c
8d 8e 90 91
92 93 94 95
96 97 98 99
9a 9b 9c :2 9d
83 :5 9e 81 a0
:5 a1 :3 a0 :2 a2 :5 a4
:11 a5 :24 a6 :3 a5 :2 a3
:6 a2 9f :3 7f :a ab
:11 ac :b ad :3 ac :5 af
:3 ab 7f :4 b3 :3 b4
:4 b5 :3 b6 b7 :2 b8
b3 :5 b9 b2 bb
:5 bc :3 bb :2 bd :5 bf
:11 c0 :24 c1 :3 c0 :2 be
:6 bd ba :3 b1 :a c6
:11 c7 :b c8 :3 c7 :5 ca
cb c6 :c cb :11 cc
:b cd :3 cc :5 cf cb
:3 c6 :3 d3 :2 d4 d3
:6 d5 :5 d6 d5 :5 d8
d7 :3 d5 d2 db
:5 dc :3 db :2 dd :5 df
:11 e0 :24 e1 :3 e0 :2 de
:6 dd da :3 b1 :10 e6
:2 e8 :3 e9 e8 :5 ea
e7 ec :5 ed :3 ec
:2 ee :5 f0 :11 f1 :24 f2
:3 f1 :2 ef :6 ee eb
:3 e6 :a f7 :11 f8 :b f9
:3 f8 :5 fb :3 f7 :3 e6
:6 ff b1 :3 7f :6 104
:4 105 :3 106 104 :5 107
103 109 :5 10a :3 109
:2 10b :5 10d :11 10e :24 10f
:3 10e :2 10c :6 10b 108
:3 48 :9 114 :16 115 :f 116
:3 115 :9 119 :5 11b :9 11c
:f 11d :3 11c 11b :4 121
:9 122 121 :5 123 120
125 :5 126 :3 125 :2 127
:5 129 :11 12a :24 12b :3 12a
:2 128 :6 127 124 :4 11f
:3 11b 119 :9 131 :b 132
133 131 :9 133 :f 134
135 133 131 :9 135
:f 136 135 :3 131 130
:3 119 :9 13a :11 13b :b 13c
:3 13b :5 13e :3 13a :3 114
:9 142 :e 143 145 142
:17 145 :6 147 :5 148 149
:6 14a 147 :5 14b 146
14d :5 14e :3 14d :2 14f
:5 151 :11 152 :24 153 :3 152
:2 150 :6 14f 14c :3 145
:11 158 :e 159 :11 15b :2 15c
:2 15b :4 15c :3 15b :a 15d
:9 15e :3 15f :3 15e :3 161
:3 15d 15c :9 164 :10 165
:3 164 :d 168 :17 169 :a 16a
:3 16b :3 16a :5 16d :5 16e
:8 16f :5 170 :7 171 :5 172
:5 173 :a 174 :3 16f :3 169
:3 178 :2 179 178 :6 17a
:5 17b 17a :5 17d 17c
:3 17a 177 180 :5 181
:3 180 :2 182 :5 184 :11 185
:24 186 :3 185 :2 183 :6 182
17f :3 168 :11 18b :b 18c
:3 18b :3 18e :3 168 163
:3 15b :3 158 145 :3 142
:1a 194 :9 195 :12 196 :3 195
:7 19a :6 19b :6 19c :5 19d
:3 19e :3 19a 19f 194
:9 19f :9 1a0 :12 1a1 :3 1a0
:7 1a5 :6 1a6 :6 1a7 :5 1a8
:3 1a9 :3 1a5 19f :3 194
:9 1ad :7 1ae 1af 1ad
:14 1af :7 1b0 1af :3 1ad
:7 1b3 :5 1b4 :3 1b3 :11 1b7
:19 1b8 :3 1b7 :5 1ba :2 48
:7 1 
2684
4
:3 0 1 :3 0 2
:a 0 aef 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
6 :3 0 8 :5 0
1 13 12 :3 0
d 98 0 b
a :3 0 9 :7 0
17 16 :3 0 4
:3 0 5 :3 0 6
:3 0 b :5 0 1
1d 1c :3 0 11
c5 0 f 4
:3 0 5 :3 0 6
:3 0 c :5 0 1
23 22 :3 0 a
:3 0 d :7 0 27
26 :3 0 15 eb
0 13 a :3 0
e :7 0 2b 2a
:3 0 a :3 0 f
:7 0 2f 2e :3 0
19 111 0 17
a :3 0 10 :7 0
33 32 :3 0 a
:3 0 11 :7 0 37
36 :3 0 1d 137
0 1b a :3 0
12 :7 0 3b 3a
:3 0 a :3 0 13
:7 0 3f 3e :3 0
21 15d 0 1f
a :3 0 14 :7 0
43 42 :3 0 a
:3 0 15 :7 0 47
46 :3 0 25 :2 0
23 4 :3 0 5
:3 0 6 :3 0 16
:5 0 1 4d 4c
:3 0 4 :3 0 5
:3 0 6 :3 0 17
:5 0 1 53 52
:3 0 18 :3 0 a
:3 0 55 57 0
aef 2 58 :2 0
39 1c1 0 37
a :3 0 5b :7 0
9 :3 0 5f 5c
5d aed 0 19
:6 0 3d 1fd 0
3b a :3 0 61
:7 0 d :3 0 65
62 63 aed 0
1a :6 0 a :3 0
67 :7 0 e :3 0
6b 68 69 aed
0 1b :6 0 41
239 0 3f a
:3 0 6d :7 0 f
:3 0 71 6e 6f
aed 0 1c :6 0
a :3 0 73 :7 0
10 :3 0 77 74
75 aed 0 1d
:6 0 45 275 0
43 a :3 0 79
:7 0 11 :3 0 7d
7a 7b aed 0
1e :6 0 a :3 0
7f :7 0 12 :3 0
83 80 81 aed
0 1f :6 0 49
2b1 0 47 a
:3 0 85 :7 0 13
:3 0 89 86 87
aed 0 20 :6 0
a :3 0 8b :7 0
14 :3 0 8f 8c
8d aed 0 21
:6 0 24 :2 0 4d
a :3 0 91 :7 0
15 :3 0 95 92
93 aed 0 22
:6 0 6 :3 0 24
:2 0 4b 97 99
:6 0 9c 9a 0
aed 0 23 :6 0
27 :2 0 51 6
:3 0 4f 9e a0
:6 0 a3 a1 0
aed 0 25 :6 0
27 :2 0 55 6
:3 0 53 a5 a7
:6 0 aa a8 0
aed 0 26 :6 0
5b 344 0 59
6 :3 0 57 ac
ae :6 0 b1 af
0 aed 0 28
:6 0 24 :2 0 5d
2a :3 0 b3 :7 0
b6 b4 0 aed
0 29 :6 0 2a
:3 0 b8 :7 0 bb
b9 0 aed 0
2b :6 0 24 :2 0
61 6 :3 0 5f
bd bf :6 0 c2
c0 0 aed 0
2c :6 0 24 :2 0
65 6 :3 0 63
c4 c6 :6 0 c9
c7 0 aed 0
2d :6 0 24 :2 0
69 6 :3 0 67
cb cd :6 0 d0
ce 0 aed 0
2e :6 0 31 :2 0
6d 6 :3 0 6b
d2 d4 :6 0 d7
d5 0 aed 0
2f :6 0 31 :2 0
71 6 :3 0 6f
d9 db :6 0 de
dc 0 aed 0
30 :6 0 34 :2 0
75 6 :3 0 73
e0 e2 :6 0 e5
e3 0 aed 0
32 :6 0 31 :2 0
79 6 :3 0 77
e7 e9 :6 0 ec
ea 0 aed 0
33 :6 0 37 :2 0
7d 6 :3 0 7b
ee f0 :6 0 f3
f1 0 aed 0
35 :6 0 37 :2 0
7f a :3 0 f5
:7 0 f9 f6 f7
aed 0 36 :6 0
37 :2 0 81 a
:3 0 fb :7 0 ff
fc fd aed 0
38 :6 0 37 :2 0
83 a :3 0 101
:7 0 105 102 103
aed 0 39 :6 0
37 :2 0 85 a
:3 0 107 :7 0 10b
108 109 aed 0
3a :6 0 37 :2 0
87 a :3 0 10d
:7 0 111 10e 10f
aed 0 3b :6 0
37 :2 0 89 a
:3 0 113 :7 0 117
114 115 aed 0
3c :6 0 37 :2 0
8b a :3 0 119
:7 0 11d 11a 11b
aed 0 3d :6 0
37 :2 0 8d a
:3 0 11f :7 0 123
120 121 aed 0
3e :6 0 37 :2 0
8f a :3 0 125
:7 0 129 126 127
aed 0 3f :6 0
24 :2 0 91 a
:3 0 12b :7 0 12f
12c 12d aed 0
40 :6 0 24 :2 0
95 6 :3 0 93
131 133 :6 0 136
134 0 aed 0
41 :6 0 9b 5b2
0 99 6 :3 0
97 138 13a :6 0
13d 13b 0 aed
0 42 :6 0 37
:2 0 9d 2a :3 0
13f :7 0 142 140
0 aed 0 43
:6 0 2a :3 0 144
:7 0 147 145 0
aed 0 44 :6 0
37 :2 0 9f 46
:3 0 149 :7 0 14d
14a 14b aed 0
45 :6 0 37 :2 0
a1 46 :3 0 14f
:7 0 153 150 151
aed 0 47 :6 0
37 :2 0 a3 a
:3 0 155 :7 0 159
156 157 aed 0
48 :6 0 37 :2 0
a5 a :3 0 15b
:7 0 15f 15c 15d
aed 0 49 :6 0
37 :2 0 a7 a
:3 0 161 :7 0 165
162 163 aed 0
4a :6 0 37 :2 0
a9 a :3 0 167
:7 0 16b 168 169
aed 0 4b :6 0
37 :2 0 ab a
:3 0 16d :7 0 171
16e 16f aed 0
4c :6 0 37 :2 0
ad a :3 0 173
:7 0 177 174 175
aed 0 4d :6 0
37 :2 0 af a
:3 0 179 :7 0 17d
17a 17b aed 0
4e :6 0 37 :2 0
b1 a :3 0 17f
:7 0 183 180 181
aed 0 4f :6 0
37 :2 0 b3 a
:3 0 185 :7 0 189
186 187 aed 0
50 :6 0 190 191
0 b5 46 :3 0
18b :7 0 18f 18c
18d aed 0 51
:6 0 52 :3 0 53
:3 0 52 :3 0 54
:3 0 193 194 0
2 :4 0 b7 195
197 192 199 198
:2 0 55 :3 0 56
:3 0 19b 19c 0
57 :4 0 52 :3 0
58 :3 0 19f 1a0
0 2 :4 0 b9
1a1 1a3 59 :4 0
5a :2 0 5b :3 0
bb 1a6 1a8 :3 0
5c :4 0 5a :2 0
5d :4 0 be 1ab
1ad :3 0 5a :2 0
3 :3 0 c1 1af
1b1 :3 0 5a :2 0
5d :4 0 c4 1b3
1b5 :3 0 5a :2 0
5e :4 0 c7 1b7
1b9 :3 0 5a :2 0
5d :4 0 ca 1bb
1bd :3 0 5a :2 0
7 :3 0 cd 1bf
1c1 :3 0 5a :2 0
5d :4 0 d0 1c3
1c5 :3 0 5a :2 0
5e :4 0 d3 1c7
1c9 :3 0 5a :2 0
5d :4 0 d6 1cb
1cd :3 0 5a :2 0
8 :3 0 d9 1cf
1d1 :3 0 5a :2 0
5d :4 0 dc 1d3
1d5 :3 0 5a :2 0
5e :4 0 df 1d7
1d9 :3 0 5a :2 0
5f :3 0 60 :3 0
9 :3 0 e2 1dd
1df 61 :4 0 e4
1dc 1e2 e7 1db
1e4 :3 0 5a :2 0
5e :4 0 ea 1e6
1e8 :3 0 5a :2 0
5d :4 0 ed 1ea
1ec :3 0 5a :2 0
b :3 0 f0 1ee
1f0 :3 0 5a :2 0
5d :4 0 f3 1f2
1f4 :3 0 5a :2 0
5e :4 0 f6 1f6
1f8 :3 0 5a :2 0
5d :4 0 f9 1fa
1fc :3 0 5a :2 0
c :3 0 fc 1fe
200 :3 0 5a :2 0
5d :4 0 ff 202
204 :3 0 5a :2 0
5e :4 0 102 206
208 :3 0 5a :2 0
5f :3 0 60 :3 0
d :3 0 105 20c
20e 61 :4 0 107
20b 211 10a 20a
213 :3 0 5a :2 0
5e :4 0 10d 215
217 :3 0 5a :2 0
5f :3 0 60 :3 0
e :3 0 110 21b
21d 61 :4 0 112
21a 220 115 219
222 :3 0 5a :2 0
5e :4 0 118 224
226 :3 0 5a :2 0
5f :3 0 60 :3 0
f :3 0 11b 22a
22c 61 :4 0 11d
229 22f 120 228
231 :3 0 5a :2 0
5e :4 0 123 233
235 :3 0 5a :2 0
5f :3 0 60 :3 0
10 :3 0 126 239
23b 61 :4 0 128
238 23e 12b 237
240 :3 0 5a :2 0
5e :4 0 12e 242
244 :3 0 5a :2 0
5f :3 0 60 :3 0
11 :3 0 131 248
24a 61 :4 0 133
247 24d 136 246
24f :3 0 5a :2 0
5e :4 0 139 251
253 :3 0 5a :2 0
5f :3 0 60 :3 0
12 :3 0 13c 257
259 61 :4 0 13e
256 25c 141 255
25e :3 0 5a :2 0
5e :4 0 144 260
262 :3 0 5a :2 0
5f :3 0 60 :3 0
13 :3 0 147 266
268 61 :4 0 149
265 26b 14c 264
26d :3 0 5a :2 0
5e :4 0 14f 26f
271 :3 0 5a :2 0
5f :3 0 60 :3 0
14 :3 0 152 275
277 61 :4 0 154
274 27a 157 273
27c :3 0 5a :2 0
5e :4 0 15a 27e
280 :3 0 5a :2 0
5f :3 0 60 :3 0
15 :3 0 15d 284
286 61 :4 0 15f
283 289 162 282
28b :3 0 5a :2 0
5e :4 0 165 28d
28f :3 0 5a :2 0
5d :4 0 168 291
293 :3 0 5a :2 0
16 :3 0 16b 295
297 :3 0 5a :2 0
5d :4 0 16e 299
29b :3 0 5a :2 0
5e :4 0 171 29d
29f :3 0 5a :2 0
5d :4 0 174 2a1
2a3 :3 0 5a :2 0
17 :3 0 177 2a5
2a7 :3 0 5a :2 0
5d :4 0 17a 2a9
2ab :3 0 5a :2 0
62 :4 0 17d 2ad
2af :3 0 180 19d
2b1 :2 0 2b3 185
2b4 19a 2b3 0
2b5 187 0 aeb
52 :3 0 53 :3 0
2b6 2b7 0 52
:3 0 63 :3 0 2b9
2ba 0 31 :2 0
2 :4 0 64 :2 0
65 :2 0 31 :2 0
189 2bf 2c1 :3 0
18c 2bb 2c3 2b8
2c5 2c4 :2 0 55
:3 0 66 :3 0 2c7
2c8 0 57 :4 0
67 :4 0 5a :2 0
5b :3 0 190 2cc
2ce :3 0 193 2c9
2d0 :2 0 2d2 196
2d3 2c6 2d2 0
2d4 198 0 aeb
5f :3 0 1f :3 0
37 :2 0 19a 2d5
2d8 68 :3 0 69
:2 0 6a :3 0 2da
2dc 0 19f 2db
2de :3 0 3c :3 0
6b :3 0 6c :3 0
2e1 2e2 0 6d
:3 0 5f :3 0 1f
:3 0 37 :2 0 1a2
2e5 2e8 68 :3 0
6e :3 0 2ea 2eb
0 1a5 2e4 2ed
2ee :2 0 6f :2 0
1a8 2e3 2f1 2e0
2f2 0 308 3a
:3 0 6d :3 0 5f
:3 0 1f :3 0 37
:2 0 1ab 2f6 2f9
68 :3 0 70 :3 0
2fb 2fc 0 1ae
2f5 2fe 2f4 2ff
0 308 1f :3 0
37 :2 0 301 302
0 308 3b :3 0
37 :2 0 304 305
0 308 71 :3 0
1b1 343 5f :3 0
1f :3 0 37 :2 0
1b6 309 30c 68
:3 0 69 :2 0 72
:3 0 30e 310 0
1bb 30f 312 :3 0
3b :3 0 6d :3 0
5f :3 0 1f :3 0
37 :2 0 1be 316
319 68 :3 0 72
:3 0 31b 31c 0
1c1 315 31e 31f
:2 0 314 320 0
333 1f :3 0 6d
:3 0 5f :3 0 1f
:3 0 37 :2 0 1c4
324 327 68 :3 0
73 :3 0 329 32a
0 1c7 323 32c
32d :2 0 322 32e
0 333 3a :3 0
37 :2 0 330 331
0 333 1ca 334
313 333 0 345
3a :3 0 5f :3 0
1f :3 0 37 :2 0
1ce 336 339 335
33a 0 342 1f
:3 0 37 :2 0 33c
33d 0 342 3b
:3 0 37 :2 0 33f
340 0 342 1d1
344 2df 308 0
345 0 342 0
345 1d5 0 aeb
4b :3 0 37 :2 0
346 347 0 aeb
30 :3 0 37 :4 0
349 34a 0 aeb
3f :3 0 37 :2 0
34c 34d 0 aeb
2b :4 0 34f 350
0 aeb 43 :4 0
352 353 0 aeb
44 :4 0 355 356
0 aeb 35 :4 0
358 359 0 aeb
51 :3 0 74 :2 0
35b 35c 0 aeb
5f :3 0 1f :3 0
37 :2 0 1d9 35e
361 75 :2 0 31
:2 0 1de 363 365
:3 0 2c :3 0 3
:3 0 367 368 0
415 76 :3 0 77
:3 0 78 :3 0 79
:3 0 7a :3 0 7b
:3 0 7c :3 0 7d
:3 0 7e :3 0 7c
:3 0 7d :3 0 7f
:3 0 80 :3 0 81
:3 0 82 :3 0 83
:3 0 2d :3 0 23
:3 0 25 :3 0 30
:3 0 2b :3 0 3f
:3 0 43 :3 0 44
:3 0 48 :3 0 49
:3 0 45 :3 0 47
:3 0 84 :3 0 85
:3 0 2c :4 0 86
1 :8 0 38f 87
:3 0 88 :3 0 38a
38b 0 89 :3 0
38c 38d 0 38f
1e1 3e2 8a :3 0
87 :3 0 88 :3 0
391 392 0 89
:3 0 393 394 0
396 1e4 398 1e6
397 396 :2 0 3e0
8b :3 0 87 :3 0
88 :3 0 39b 39c
0 89 :3 0 39d
39e 0 3d8 52
:3 0 53 :3 0 3a0
3a1 0 52 :3 0
63 :3 0 3a3 3a4
0 8c :2 0 2
:4 0 8d :2 0 65
:2 0 31 :2 0 1e8
3a9 3ab :3 0 1eb
3a5 3ad 3a2 3af
3ae :2 0 55 :3 0
66 :3 0 3b1 3b2
0 57 :4 0 8e
:4 0 5a :2 0 5b
:3 0 1ef 3b6 3b8
:3 0 5a :2 0 8f
:4 0 1f2 3ba 3bc
:3 0 5a :2 0 90
:4 0 1f5 3be 3c0
:3 0 5a :2 0 89
:3 0 1f8 3c2 3c4
:3 0 5a :2 0 91
:4 0 1fb 3c6 3c8
:3 0 5a :2 0 7d
:3 0 92 :3 0 31
:2 0 93 :2 0 1fe
3cb 3cf 202 3ca
3d1 :3 0 205 3b3
3d3 :2 0 3d5 208
3d6 3b0 3d5 0
3d7 20a 0 3d8
20c 3db :3 0 3db
0 3db 3da 3d8
3d9 :6 0 3dd 2
:3 0 20f 3df 211
3de 3dd :2 0 3e0
213 :2 0 3e2 0
3e2 3e1 38f 3e0
:6 0 415 1 :3 0
87 :3 0 88 :3 0
3e4 3e5 0 87
:3 0 75 :2 0 94
:3 0 3e7 3e9 0
218 3e8 3eb :3 0
3ec :2 0 52 :3 0
53 :3 0 3ee 3ef
0 52 :3 0 63
:3 0 3f1 3f2 0
31 :2 0 2 :4 0
95 :2 0 65 :2 0
31 :2 0 21b 3f7
3f9 :3 0 21e 3f3
3fb 3f0 3fd 3fc
:2 0 55 :3 0 66
:3 0 3ff 400 0
57 :4 0 96 :4 0
5a :2 0 5b :3 0
222 404 406 :3 0
225 401 408 :2 0
40a 228 40b 3fe
40a 0 40c 22a
0 412 18 :3 0
68 :3 0 97 :3 0
40e 40f 0 410
:2 0 412 22c 413
3ed 412 0 414
22f 0 415 231
601 76 :3 0 98
:3 0 78 :3 0 99
:3 0 79 :3 0 9a
:3 0 9b :3 0 2d
:3 0 23 :3 0 25
:3 0 38 :3 0 30
:3 0 2f :3 0 3e
:3 0 9c :3 0 9d
:3 0 3 :4 0 9e
1 :8 0 42d 87
:3 0 88 :3 0 428
429 0 89 :3 0
42a 42b 0 42d
235 480 8a :3 0
87 :3 0 88 :3 0
42f 430 0 89
:3 0 431 432 0
434 238 436 23a
435 434 :2 0 47e
8b :3 0 87 :3 0
88 :3 0 439 43a
0 89 :3 0 43b
43c 0 476 52
:3 0 53 :3 0 43e
43f 0 52 :3 0
63 :3 0 441 442
0 8c :2 0 2
:4 0 9f :2 0 65
:2 0 31 :2 0 23c
447 449 :3 0 23f
443 44b 440 44d
44c :2 0 55 :3 0
66 :3 0 44f 450
0 57 :4 0 a0
:4 0 5a :2 0 5b
:3 0 243 454 456
:3 0 5a :2 0 8f
:4 0 246 458 45a
:3 0 5a :2 0 90
:4 0 249 45c 45e
:3 0 5a :2 0 89
:3 0 24c 460 462
:3 0 5a :2 0 91
:4 0 24f 464 466
:3 0 5a :2 0 7d
:3 0 92 :3 0 31
:2 0 93 :2 0 252
469 46d 256 468
46f :3 0 259 451
471 :2 0 473 25c
474 44e 473 0
475 25e 0 476
260 479 :3 0 479
0 479 478 476
477 :6 0 47b 4
:3 0 263 47d 265
47c 47b :2 0 47e
267 :2 0 480 0
480 47f 42d 47e
:6 0 600 1 :3 0
87 :3 0 88 :3 0
482 483 0 87
:3 0 75 :2 0 94
:3 0 485 487 0
26c 486 489 :3 0
48a :2 0 52 :3 0
53 :3 0 48c 48d
0 52 :3 0 63
:3 0 48f 490 0
31 :2 0 2 :4 0
a1 :2 0 65 :2 0
31 :2 0 26f 495
497 :3 0 272 491
499 48e 49b 49a
:2 0 55 :3 0 66
:3 0 49d 49e 0
57 :4 0 a2 :4 0
5a :2 0 5b :3 0
276 4a2 4a4 :3 0
279 49f 4a6 :2 0
4a8 27c 4a9 49c
4a8 0 4aa 27e
0 4b1 18 :3 0
68 :3 0 97 :3 0
4ac 4ad 0 4ae
:2 0 4b1 71 :3 0
280 4e4 a3 :3 0
5f :3 0 38 :3 0
37 :2 0 283 4b3
4b6 286 4b2 4b8
a4 :2 0 37 :2 0
28a 4ba 4bc :3 0
52 :3 0 53 :3 0
4be 4bf 0 52
:3 0 63 :3 0 4c1
4c2 0 31 :2 0
2 :4 0 a5 :2 0
65 :2 0 31 :2 0
28d 4c7 4c9 :3 0
290 4c3 4cb 4c0
4cd 4cc :2 0 55
:3 0 66 :3 0 4cf
4d0 0 57 :4 0
a6 :4 0 5a :2 0
5b :3 0 294 4d4
4d6 :3 0 297 4d1
4d8 :2 0 4da 29a
4db 4ce 4da 0
4dc 29c 0 4e2
18 :3 0 68 :3 0
a7 :3 0 4de 4df
0 4e0 :2 0 4e2
29e 4e3 4bd 4e2
0 4e5 48b 4b1
0 4e5 2a1 0
600 9c :3 0 a8
:3 0 19 :3 0 9d
:3 0 3 :4 0 a9
1 :8 0 501 aa
:4 0 4ec :3 0 ab
:3 0 75 :2 0 2a6
4ef 4f0 :3 0 87
:3 0 88 :3 0 4f2
4f3 0 37 :2 0
4f4 4f5 0 4f7
2a9 4fe 87 :3 0
88 :3 0 4f8 4f9
0 ac :2 0 4fa
4fb 0 4fd 2ab
4ff 4f1 4f7 0
500 0 4fd 0
500 2ad 0 501
2b0 554 8a :3 0
87 :3 0 88 :3 0
503 504 0 89
:3 0 505 506 0
508 2b3 50a 2b5
509 508 :2 0 552
8b :3 0 87 :3 0
88 :3 0 50d 50e
0 89 :3 0 50f
510 0 54a 52
:3 0 53 :3 0 512
513 0 52 :3 0
63 :3 0 515 516
0 8c :2 0 2
:4 0 ad :2 0 65
:2 0 31 :2 0 2b7
51b 51d :3 0 2ba
517 51f 514 521
520 :2 0 55 :3 0
66 :3 0 523 524
0 57 :4 0 ae
:4 0 5a :2 0 5b
:3 0 2be 528 52a
:3 0 5a :2 0 8f
:4 0 2c1 52c 52e
:3 0 5a :2 0 90
:4 0 2c4 530 532
:3 0 5a :2 0 89
:3 0 2c7 534 536
:3 0 5a :2 0 91
:4 0 2ca 538 53a
:3 0 5a :2 0 7d
:3 0 92 :3 0 31
:2 0 93 :2 0 2cd
53d 541 2d1 53c
543 :3 0 2d4 525
545 :2 0 547 2d7
548 522 547 0
549 2d9 0 54a
2db 54d :3 0 54d
0 54d 54c 54a
54b :6 0 54f 6
:3 0 2de 551 2e0
550 54f :2 0 552
2e2 :2 0 554 0
554 553 501 552
:6 0 600 1 :3 0
af :3 0 5f :3 0
38 :3 0 37 :2 0
2e5 557 55a 2e8
556 55c 55d :2 0
a4 :2 0 37 :2 0
2ec 55f 561 :3 0
b0 :2 0 2ef 563
564 :3 0 85 :3 0
2c :3 0 84 :3 0
9d :3 0 3 :4 0
b1 1 :8 0 571
87 :3 0 88 :3 0
56c 56d 0 89
:3 0 56e 56f 0
571 2f1 5c4 8a
:3 0 87 :3 0 88
:3 0 573 574 0
89 :3 0 575 576
0 578 2f4 57a
2f6 579 578 :2 0
5c2 8b :3 0 87
:3 0 88 :3 0 57d
57e 0 89 :3 0
57f 580 0 5ba
52 :3 0 53 :3 0
582 583 0 52
:3 0 63 :3 0 585
586 0 8c :2 0
2 :4 0 b2 :2 0
65 :2 0 31 :2 0
2f8 58b 58d :3 0
2fb 587 58f 584
591 590 :2 0 55
:3 0 66 :3 0 593
594 0 57 :4 0
b3 :4 0 5a :2 0
5b :3 0 2ff 598
59a :3 0 5a :2 0
8f :4 0 302 59c
59e :3 0 5a :2 0
90 :4 0 305 5a0
5a2 :3 0 5a :2 0
89 :3 0 308 5a4
5a6 :3 0 5a :2 0
91 :4 0 30b 5a8
5aa :3 0 5a :2 0
7d :3 0 92 :3 0
31 :2 0 93 :2 0
30e 5ad 5b1 312
5ac 5b3 :3 0 315
595 5b5 :2 0 5b7
318 5b8 592 5b7
0 5b9 31a 0
5ba 31c 5bd :3 0
5bd 0 5bd 5bc
5ba 5bb :6 0 5bf
8 :3 0 31f 5c1
321 5c0 5bf :2 0
5c2 323 :2 0 5c4
0 5c4 5c3 571
5c2 :6 0 5f7 1
:3 0 87 :3 0 88
:3 0 5c6 5c7 0
87 :3 0 75 :2 0
b4 :3 0 5c9 5cb
0 328 5ca 5cd
:3 0 5ce :2 0 52
:3 0 53 :3 0 5d0
5d1 0 52 :3 0
63 :3 0 5d3 5d4
0 31 :2 0 2
:4 0 b5 :2 0 65
:2 0 31 :2 0 32b
5d9 5db :3 0 32e
5d5 5dd 5d2 5df
5de :2 0 55 :3 0
66 :3 0 5e1 5e2
0 57 :4 0 b6
:4 0 5a :2 0 5b
:3 0 332 5e6 5e8
:3 0 335 5e3 5ea
:2 0 5ec 338 5ed
5e0 5ec 0 5ee
33a 0 5f4 18
:3 0 68 :3 0 b7
:3 0 5f0 5f1 0
5f2 :2 0 5f4 33c
5f5 5cf 5f4 0
5f6 33f 0 5f7
341 5f8 565 5f7
0 5f9 344 0
600 3d :3 0 b8
:3 0 3 :3 0 346
5fb 5fd 5fa 5fe
0 600 348 602
366 415 0 603
0 600 0 603
34e 0 aeb 5f
:3 0 b9 :3 0 5f
:3 0 ba :3 0 bb
:3 0 bc :3 0 36
:3 0 39 :3 0 2e
:3 0 4e :3 0 bd
:3 0 98 :3 0 2d
:4 0 be 1 :8 0
617 87 :3 0 88
:3 0 612 613 0
89 :3 0 614 615
0 617 351 66a
8a :3 0 87 :3 0
88 :3 0 619 61a
0 89 :3 0 61b
61c 0 61e 354
620 356 61f 61e
:2 0 668 8b :3 0
87 :3 0 88 :3 0
623 624 0 89
:3 0 625 626 0
660 52 :3 0 53
:3 0 628 629 0
52 :3 0 63 :3 0
62b 62c 0 8c
:2 0 2 :4 0 bf
:2 0 65 :2 0 31
:2 0 358 631 633
:3 0 35b 62d 635
62a 637 636 :2 0
55 :3 0 66 :3 0
639 63a 0 57
:4 0 c0 :4 0 5a
:2 0 5b :3 0 35f
63e 640 :3 0 5a
:2 0 8f :4 0 362
642 644 :3 0 5a
:2 0 90 :4 0 365
646 648 :3 0 5a
:2 0 89 :3 0 368
64a 64c :3 0 5a
:2 0 91 :4 0 36b
64e 650 :3 0 5a
:2 0 7d :3 0 92
:3 0 31 :2 0 93
:2 0 36e 653 657
372 652 659 :3 0
375 63b 65b :2 0
65d 378 65e 638
65d 0 65f 37a
0 660 37c 663
:3 0 663 0 663
662 660 661 :6 0
665 a :3 0 37f
667 381 666 665
:2 0 668 383 :2 0
66a 0 66a 669
617 668 :6 0 aeb
1 :3 0 5f :3 0
3b :3 0 37 :2 0
386 66c 66f 75
:2 0 37 :2 0 38b
671 673 :3 0 5f
:3 0 1b :3 0 37
:2 0 38e 675 678
c1 :2 0 37 :2 0
393 67a 67c :3 0
67d :2 0 5f :3 0
1d :3 0 37 :2 0
396 67f 682 75
:2 0 c2 :2 0 39b
684 686 :3 0 687
:2 0 67e 689 688
:2 0 1b :3 0 5f
:3 0 36 :3 0 37
:2 0 39e 68c 68f
c3 :2 0 5f :3 0
1b :3 0 37 :2 0
3a1 692 695 3a4
691 697 :3 0 68b
698 0 69a 3a7
69b 68a 69a 0
69c 3a9 0 7b5
5f :3 0 1a :3 0
37 :2 0 3ab 69d
6a0 75 :2 0 37
:2 0 3b0 6a2 6a4
:3 0 c :3 0 c4
:2 0 3b3 6a7 6a8
:3 0 6a9 :2 0 5f
:3 0 1b :3 0 37
:2 0 3b5 6ab 6ae
c1 :2 0 37 :2 0
3ba 6b0 6b2 :3 0
1a :3 0 5f :3 0
22 :3 0 37 :2 0
3bd 6b5 6b8 c3
:2 0 5f :3 0 1b
:3 0 37 :2 0 3c0
6bb 6be 3c3 6ba
6c0 :3 0 6b4 6c1
0 6c3 3c6 6c4
6b3 6c3 0 6c5
3c8 0 6c6 3ca
730 c5 :3 0 c6
:3 0 1a :3 0 c7
:3 0 98 :3 0 2d
:3 0 c8 :3 0 7c
:3 0 7d :3 0 b
:3 0 7c :3 0 7d
:3 0 c :4 0 c9
1 :8 0 6da 87
:3 0 88 :3 0 6d5
6d6 0 89 :3 0
6d7 6d8 0 6da
3cc 72d 8a :3 0
87 :3 0 88 :3 0
6dc 6dd 0 89
:3 0 6de 6df 0
6e1 3cf 6e3 3d1
6e2 6e1 :2 0 72b
8b :3 0 87 :3 0
88 :3 0 6e6 6e7
0 89 :3 0 6e8
6e9 0 723 52
:3 0 53 :3 0 6eb
6ec 0 52 :3 0
63 :3 0 6ee 6ef
0 8c :2 0 2
:4 0 ca :2 0 65
:2 0 31 :2 0 3d3
6f4 6f6 :3 0 3d6
6f0 6f8 6ed 6fa
6f9 :2 0 55 :3 0
66 :3 0 6fc 6fd
0 57 :4 0 cb
:4 0 5a :2 0 5b
:3 0 3da 701 703
:3 0 5a :2 0 8f
:4 0 3dd 705 707
:3 0 5a :2 0 90
:4 0 3e0 709 70b
:3 0 5a :2 0 89
:3 0 3e3 70d 70f
:3 0 5a :2 0 91
:4 0 3e6 711 713
:3 0 5a :2 0 7d
:3 0 92 :3 0 31
:2 0 93 :2 0 3e9
716 71a 3ed 715
71c :3 0 3f0 6fe
71e :2 0 720 3f3
721 6fb 720 0
722 3f5 0 723
3f7 726 :3 0 726
0 726 725 723
724 :6 0 728 c
:3 0 3fa 72a 3fc
729 728 :2 0 72b
3fe :2 0 72d 0
72d 72c 6da 72b
:6 0 72f 1 :3 0
401 731 6aa 6c6
0 732 0 72f
0 732 403 0
733 406 782 5f
:3 0 1c :3 0 37
:2 0 408 734 737
75 :2 0 31 :2 0
40d 739 73b :3 0
1a :3 0 5f :3 0
1a :3 0 37 :2 0
410 73e 741 c3
:2 0 cc :2 0 413
743 745 :3 0 73d
746 0 749 71
:3 0 416 77f 5f
:3 0 1c :3 0 37
:2 0 418 74a 74d
75 :2 0 cd :2 0
41d 74f 751 :3 0
1a :3 0 5f :3 0
36 :3 0 37 :2 0
420 754 757 c3
:2 0 5f :3 0 1a
:3 0 37 :2 0 423
75a 75d 426 759
75f :3 0 753 760
0 763 71 :3 0
429 764 752 763
0 780 5f :3 0
1c :3 0 37 :2 0
42b 765 768 75
:2 0 ce :2 0 430
76a 76c :3 0 1a
:3 0 5f :3 0 39
:3 0 37 :2 0 433
76f 772 c3 :2 0
5f :3 0 1a :3 0
37 :2 0 436 775
778 439 774 77a
:3 0 76e 77b 0
77d 43c 77e 76d
77d 0 780 73c
749 0 780 43e
0 781 442 783
6a5 733 0 784
0 781 0 784
444 0 7b5 5f
:3 0 1a :3 0 37
:2 0 447 785 788
75 :2 0 37 :2 0
44c 78a 78c :3 0
52 :3 0 53 :3 0
78e 78f 0 52
:3 0 63 :3 0 791
792 0 31 :2 0
2 :4 0 cf :2 0
65 :2 0 31 :2 0
44f 797 799 :3 0
452 793 79b 790
79d 79c :2 0 55
:3 0 66 :3 0 79f
7a0 0 57 :4 0
d0 :4 0 5a :2 0
5b :3 0 456 7a4
7a6 :3 0 459 7a1
7a8 :2 0 7aa 45c
7ab 79e 7aa 0
7ac 45e 0 7b2
18 :3 0 68 :3 0
a7 :3 0 7ae 7af
0 7b0 :2 0 7b2
460 7b3 78d 7b2
0 7b4 463 0
7b5 465 7b6 674
7b5 0 7b7 469
0 aeb 5f :3 0
1f :3 0 37 :2 0
46b 7b8 7bb 75
:2 0 cd :2 0 470
7bd 7bf :3 0 1f
:3 0 6d :3 0 5f
:3 0 1f :3 0 37
:2 0 473 7c3 7c6
68 :3 0 d1 :3 0
7c8 7c9 0 476
7c2 7cb 7cc :2 0
7c1 7cd 0 7d0
71 :3 0 479 9d6
7d :3 0 30 :3 0
31 :2 0 31 :2 0
47b 7d1 7d5 75
:2 0 37 :4 0 481
7d7 7d9 :3 0 7da
:2 0 5f :3 0 1e
:3 0 37 :2 0 484
7dc 7df 75 :2 0
37 :2 0 489 7e1
7e3 :3 0 7e4 :2 0
7db 7e6 7e5 :2 0
85 :3 0 d2 :3 0
d3 :3 0 d4 :3 0
d5 :3 0 d6 :3 0
2c :3 0 26 :3 0
28 :3 0 4d :3 0
32 :3 0 84 :3 0
76 :3 0 2d :3 0
77 :3 0 2d :3 0
78 :3 0 25 :4 0
d7 1 :8 0 800
87 :3 0 88 :3 0
7fb 7fc 0 89
:3 0 7fd 7fe 0
800 48c 853 8a
:3 0 87 :3 0 88
:3 0 802 803 0
89 :3 0 804 805
0 807 48f 809
491 808 807 :2 0
851 8b :3 0 87
:3 0 88 :3 0 80c
80d 0 89 :3 0
80e 80f 0 849
52 :3 0 53 :3 0
811 812 0 52
:3 0 63 :3 0 814
815 0 8c :2 0
2 :4 0 d8 :2 0
65 :2 0 31 :2 0
493 81a 81c :3 0
496 816 81e 813
820 81f :2 0 55
:3 0 66 :3 0 822
823 0 57 :4 0
d9 :4 0 5a :2 0
5b :3 0 49a 827
829 :3 0 5a :2 0
8f :4 0 49d 82b
82d :3 0 5a :2 0
90 :4 0 4a0 82f
831 :3 0 5a :2 0
89 :3 0 4a3 833
835 :3 0 5a :2 0
91 :4 0 4a6 837
839 :3 0 5a :2 0
7d :3 0 92 :3 0
31 :2 0 93 :2 0
4a9 83c 840 4ad
83b 842 :3 0 4b0
824 844 :2 0 846
4b3 847 821 846
0 848 4b5 0
849 4b7 84c :3 0
84c 0 84c 84b
849 84a :6 0 84e
e :3 0 4ba 850
4bc 84f 84e :2 0
851 4be :2 0 853
0 853 852 800
851 :6 0 9d4 1
:3 0 87 :3 0 88
:3 0 855 856 0
87 :3 0 75 :2 0
b4 :3 0 858 85a
0 4c3 859 85c
:3 0 85d :2 0 2c
:3 0 da :2 0 4c6
860 861 :3 0 862
:2 0 85e 864 863
:2 0 1f :3 0 6d
:3 0 5f :3 0 1f
:3 0 37 :2 0 4c8
868 86b 68 :3 0
d1 :3 0 86d 86e
0 4cb 867 870
871 :2 0 866 872
0 9d1 db :3 0
dc :3 0 874 875
0 b :3 0 26
:3 0 dd :2 0 4ce
876 87a 69 :2 0
37 :2 0 4d4 87c
87e :3 0 87f :2 0
db :3 0 dc :3 0
881 882 0 28
:3 0 c :3 0 dd
:2 0 4d7 883 887
69 :2 0 37 :2 0
4dd 889 88b :3 0
88c :2 0 880 88e
88d :2 0 7d :3 0
32 :3 0 31 :2 0
31 :2 0 4e0 890
894 75 :2 0 cd
:4 0 4e6 896 898
:3 0 5f :3 0 3b
:3 0 37 :2 0 4e9
89a 89d 75 :2 0
37 :2 0 4ee 89f
8a1 :3 0 1f :3 0
cd :2 0 8a3 8a4
0 8a6 4f1 8a7
8a2 8a6 0 8a8
4f3 0 8ac 1e
:3 0 cd :2 0 8a9
8aa 0 8ac 4f5
8ad 899 8ac 0
8ae 4f8 0 8af
4fa 9ce 5f :3 0
1f :3 0 37 :2 0
4fc 8b0 8b3 75
:2 0 31 :2 0 501
8b5 8b7 :3 0 3a
:3 0 6b :3 0 de
:3 0 8ba 8bb 0
5f :3 0 3a :3 0
37 :2 0 504 8bd
8c0 68 :3 0 6a
:3 0 8c2 8c3 0
507 8bc 8c5 8c6
:2 0 8b9 8c7 0
8c9 50a 8ca 8b8
8c9 0 8cb 50c
0 9cd 5f :3 0
4d :3 0 37 :2 0
50e 8cc 8cf 5f
:3 0 df :2 0 1a
:3 0 37 :2 0 511
8d1 8d5 516 8d2
8d7 :3 0 5f :3 0
4d :3 0 37 :2 0
519 8d9 8dc c1
:2 0 37 :2 0 51e
8de 8e0 :3 0 db
:3 0 dc :3 0 8e2
8e3 0 b :3 0
28 :3 0 dd :2 0
521 8e4 8e8 69
:2 0 37 :2 0 527
8ea 8ec :3 0 8e1
8ee 8ed :2 0 7d
:3 0 32 :3 0 31
:2 0 31 :2 0 52a
8f0 8f4 75 :2 0
37 :4 0 530 8f6
8f8 :3 0 4f :3 0
ce :2 0 8fa 8fb
0 8fd 533 8fe
8f9 8fd 0 8ff
535 0 935 3d
:3 0 e0 :4 0 901
902 :3 0 900 903
0 935 3a :3 0
68 :3 0 e1 :3 0
906 907 0 905
908 0 935 3d
:3 0 e2 :3 0 3
:3 0 2d :3 0 23
:3 0 25 :3 0 51
:3 0 38 :3 0 7
:3 0 8 :3 0 35
:3 0 35 :3 0 b
:3 0 28 :3 0 50
:3 0 4d :3 0 1b
:3 0 1c :3 0 1d
:3 0 50 :3 0 3a
:3 0 30 :3 0 1e
:3 0 1f :3 0 20
:3 0 22 :3 0 4f
:3 0 36 :3 0 4e
:3 0 17 :3 0 5f
:3 0 36 :3 0 37
:2 0 537 928 92b
37 :2 0 74 :2 0
74 :2 0 37 :2 0
37 :2 0 53a 90b
932 90a 933 0
935 55d 936 8ef
935 0 937 562
0 9ca 84 :3 0
e3 :3 0 1a :3 0
9d :3 0 3 :4 0
e4 1 :8 0 953
aa :4 0 93e :3 0
ab :3 0 75 :2 0
566 941 942 :3 0
87 :3 0 88 :3 0
944 945 0 37
:2 0 946 947 0
949 569 950 87
:3 0 88 :3 0 94a
94b 0 ac :2 0
94c 94d 0 94f
56b 951 943 949
0 952 0 94f
0 952 56d 0
953 570 9a6 8a
:3 0 87 :3 0 88
:3 0 955 956 0
89 :3 0 957 958
0 95a 573 95c
575 95b 95a :2 0
9a4 8b :3 0 87
:3 0 88 :3 0 95f
960 0 89 :3 0
961 962 0 99c
52 :3 0 53 :3 0
964 965 0 52
:3 0 63 :3 0 967
968 0 8c :2 0
2 :4 0 e5 :2 0
65 :2 0 31 :2 0
577 96d 96f :3 0
57a 969 971 966
973 972 :2 0 55
:3 0 66 :3 0 975
976 0 57 :4 0
e6 :4 0 5a :2 0
5b :3 0 57e 97a
97c :3 0 5a :2 0
8f :4 0 581 97e
980 :3 0 5a :2 0
90 :4 0 584 982
984 :3 0 5a :2 0
89 :3 0 587 986
988 :3 0 5a :2 0
91 :4 0 58a 98a
98c :3 0 5a :2 0
7d :3 0 92 :3 0
31 :2 0 93 :2 0
58d 98f 993 591
98e 995 :3 0 594
977 997 :2 0 999
597 99a 974 999
0 99b 599 0
99c 59b 99f :3 0
99f 0 99f 99e
99c 99d :6 0 9a1
10 :3 0 59e 9a3
5a0 9a2 9a1 :2 0
9a4 5a2 :2 0 9a6
0 9a6 9a5 953
9a4 :6 0 9ca 1
:3 0 52 :3 0 53
:3 0 9a8 9a9 0
52 :3 0 63 :3 0
9ab 9ac 0 31
:2 0 2 :4 0 e7
:2 0 65 :2 0 31
:2 0 5a5 9b1 9b3
:3 0 5a8 9ad 9b5
9aa 9b7 9b6 :2 0
55 :3 0 66 :3 0
9b9 9ba 0 57
:4 0 e8 :4 0 5a
:2 0 5b :3 0 5ac
9be 9c0 :3 0 5af
9bb 9c2 :2 0 9c4
5b2 9c5 9b8 9c4
0 9c6 5b4 0
9ca 18 :3 0 37
:2 0 9c8 :2 0 9ca
5b6 9cb 8d8 9ca
0 9cc 5bb 0
9cd 5bd 9cf 88f
8af 0 9d0 0
9cd 0 9d0 5c0
0 9d1 5c3 9d2
865 9d1 0 9d3
5c6 0 9d4 5c8
9d5 7e7 9d4 0
9d7 7c0 7d0 0
9d7 5cb 0 aeb
5f :3 0 1f :3 0
37 :2 0 5ce 9d8
9db 75 :2 0 37
:2 0 5d3 9dd 9df
:3 0 9e0 :2 0 5f
:3 0 22 :3 0 37
:2 0 5d6 9e2 9e5
5f :3 0 75 :2 0
3f :3 0 37 :2 0
5d9 9e7 9eb 5de
9e8 9ed :3 0 9ee
:2 0 9e1 9f0 9ef
:2 0 5f :3 0 3b
:3 0 37 :2 0 5e1
9f2 9f5 a4 :2 0
37 :2 0 5e6 9f7
9f9 :3 0 1f :3 0
6b :3 0 de :3 0
9fc 9fd 0 5f
:3 0 1f :3 0 37
:2 0 5e9 9ff a02
5f :3 0 3b :3 0
37 :2 0 5ec a04
a07 5ef 9fe a09
a0a :2 0 9fb a0b
0 a0d 5f2 a0e
9fa a0d 0 a0f
5f4 0 a2f 3d
:3 0 e9 :3 0 3
:3 0 2d :3 0 23
:3 0 25 :3 0 7
:3 0 8 :3 0 b
:3 0 c :3 0 1a
:3 0 1b :3 0 1c
:3 0 1d :3 0 30
:3 0 1e :3 0 1f
:3 0 20 :3 0 21
:3 0 22 :3 0 3a
:3 0 16 :3 0 17
:3 0 36 :3 0 74
:2 0 74 :2 0 37
:2 0 5f6 a11 a2b
a10 a2c 0 a2f
71 :3 0 610 a77
5f :3 0 1f :3 0
37 :2 0 613 a30
a33 75 :2 0 31
:2 0 618 a35 a37
:3 0 5f :3 0 3b
:3 0 37 :2 0 61b
a39 a3c a4 :2 0
37 :2 0 620 a3e
a40 :3 0 1f :3 0
6b :3 0 de :3 0
a43 a44 0 5f
:3 0 1f :3 0 37
:2 0 623 a46 a49
5f :3 0 3b :3 0
37 :2 0 626 a4b
a4e 629 a45 a50
a51 :2 0 a42 a52
0 a54 62c a55
a41 a54 0 a56
62e 0 a75 3d
:3 0 e9 :3 0 2c
:3 0 2d :3 0 23
:3 0 25 :3 0 7
:3 0 8 :3 0 b
:3 0 c :3 0 1a
:3 0 1b :3 0 1c
:3 0 1d :3 0 30
:3 0 1e :3 0 1f
:3 0 20 :3 0 21
:3 0 22 :3 0 3a
:3 0 16 :3 0 17
:3 0 36 :3 0 74
:2 0 74 :2 0 37
:2 0 630 a58 a72
a57 a73 0 a75
64a a76 a38 a75
0 a78 9f1 a2f
0 a78 64d 0
aeb 5f :3 0 3d
:3 0 37 :2 0 650
a79 a7c 75 :2 0
ea :2 0 655 a7e
a80 :3 0 87 :3 0
88 :3 0 a82 a83
0 68 :3 0 eb
:3 0 a85 a86 0
a84 a87 0 a8a
71 :3 0 658 aa8
5f :3 0 3d :3 0
37 :2 0 65a a8b
a8e a4 :2 0 37
:2 0 65f a90 a92
:3 0 5f :3 0 3d
:3 0 37 :2 0 662
a94 a97 a4 :2 0
ac :2 0 667 a99
a9b :3 0 a93 a9d
a9c :2 0 87 :3 0
88 :3 0 a9f aa0
0 68 :3 0 a7
:3 0 aa2 aa3 0
aa1 aa4 0 aa6
66a aa7 a9e aa6
0 aa9 a81 a8a
0 aa9 66c 0
aeb 87 :3 0 88
:3 0 aaa aab 0
75 :2 0 ac :2 0
671 aad aaf :3 0
87 :3 0 88 :3 0
ab1 ab2 0 37
:2 0 ab3 ab4 0
ab6 674 ab7 ab0
ab6 0 ab8 676
0 aeb 52 :3 0
53 :3 0 ab9 aba
0 52 :3 0 63
:3 0 abc abd 0
31 :2 0 2 :4 0
ec :2 0 65 :2 0
31 :2 0 678 ac2
ac4 :3 0 67b abe
ac6 abb ac8 ac7
:2 0 55 :3 0 66
:3 0 aca acb 0
57 :4 0 ed :4 0
5a :2 0 5b :3 0
67f acf ad1 :3 0
5a :2 0 8f :4 0
682 ad3 ad5 :3 0
5a :2 0 ee :4 0
685 ad7 ad9 :3 0
5a :2 0 87 :3 0
88 :3 0 adc add
0 688 adb adf
:3 0 68b acc ae1
:2 0 ae3 68e ae4
ac9 ae3 0 ae5
690 0 aeb 18
:3 0 87 :3 0 88
:3 0 ae7 ae8 0
ae9 :2 0 aeb 692
aee :3 0 aee 6a7
aee aed aeb aec
:6 0 aef :2 0 2
58 aee af2 :3 0
af1 aef af3 :8 0

6da
4
:3 0 1 3 1
9 1 f 1
15 1 19 1
1f 1 25 1
29 1 2d 1
31 1 35 1
39 1 3d 1
41 1 45 1
49 1 4f 11
8 e 14 18
1e 24 28 2c
30 34 38 3c
40 44 48 4e
54 1 5a 1
60 1 66 1
6c 1 72 1
78 1 7e 1
84 1 8a 1
90 1 98 1
96 1 9f 1
9d 1 a6 1
a4 1 ad 1
ab 1 b2 1
b7 1 be 1
bc 1 c5 1
c3 1 cc 1
ca 1 d3 1
d1 1 da 1
d8 1 e1 1
df 1 e8 1
e6 1 ef 1
ed 1 f4 1
fa 1 100 1
106 1 10c 1
112 1 118 1
11e 1 124 1
12a 1 132 1
130 1 139 1
137 1 13e 1
143 1 148 1
14e 1 154 1
15a 1 160 1
166 1 16c 1
172 1 178 1
17e 1 184 1
18a 1 196 1
1a2 2 1a5 1a7
2 1aa 1ac 2
1ae 1b0 2 1b2
1b4 2 1b6 1b8
2 1ba 1bc 2
1be 1c0 2 1c2
1c4 2 1c6 1c8
2 1ca 1cc 2
1ce 1d0 2 1d2
1d4 2 1d6 1d8
1 1de 2 1e0
1e1 2 1da 1e3
2 1e5 1e7 2
1e9 1eb 2 1ed
1ef 2 1f1 1f3
2 1f5 1f7 2
1f9 1fb 2 1fd
1ff 2 201 203
2 205 207 1
20d 2 20f 210
2 209 212 2
214 216 1 21c
2 21e 21f 2
218 221 2 223
225 1 22b 2
22d 22e 2 227
230 2 232 234
1 23a 2 23c
23d 2 236 23f
2 241 243 1
249 2 24b 24c
2 245 24e 2
250 252 1 258
2 25a 25b 2
254 25d 2 25f
261 1 267 2
269 26a 2 263
26c 2 26e 270
1 276 2 278
279 2 272 27b
2 27d 27f 1
285 2 287 288
2 281 28a 2
28c 28e 2 290
292 2 294 296
2 298 29a 2
29c 29e 2 2a0
2a2 2 2a4 2a6
2 2a8 2aa 2
2ac 2ae 4 19e
1a4 1a9 2b0 1
2b2 1 2b4 2
2be 2c0 3 2bc
2bd 2c2 2 2cb
2cd 2 2ca 2cf
1 2d1 1 2d3
2 2d6 2d7 1
2dd 2 2d9 2dd
2 2e6 2e7 2
2e9 2ec 2 2ef
2f0 2 2f7 2f8
2 2fa 2fd 4
2f3 300 303 306
2 30a 30b 1
311 2 30d 311
2 317 318 2
31a 31d 2 325
326 2 328 32b
3 321 32f 332
2 337 338 3
33b 33e 341 3
343 334 344 2
35f 360 1 364
2 362 364 2
389 38e 1 395
1 390 2 3a8
3aa 3 3a6 3a7
3ac 2 3b5 3b7
2 3b9 3bb 2
3bd 3bf 2 3c1
3c3 2 3c5 3c7
3 3cc 3cd 3ce
2 3c9 3d0 2
3b4 3d2 1 3d4
1 3d6 2 39f
3d7 1 3db 1
39a 2 398 3df
1 3ea 2 3e6
3ea 2 3f6 3f8
3 3f4 3f5 3fa
2 403 405 2
402 407 1 409
1 40b 2 40c
411 1 413 3
369 3e2 414 2
427 42c 1 433
1 42e 2 446
448 3 444 445
44a 2 453 455
2 457 459 2
45b 45d 2 45f
461 2 463 465
3 46a 46b 46c
2 467 46e 2
452 470 1 472
1 474 2 43d
475 1 479 1
438 2 436 47d
1 488 2 484
488 2 494 496
3 492 493 498
2 4a1 4a3 2
4a0 4a5 1 4a7
1 4a9 2 4aa
4af 2 4b4 4b5
1 4b7 1 4bb
2 4b9 4bb 2
4c6 4c8 3 4c4
4c5 4ca 2 4d3
4d5 2 4d2 4d7
1 4d9 1 4db
2 4dc 4e1 2
4e4 4e3 1 4ee
2 4ed 4ee 1
4f6 1 4fc 2
4fe 4ff 2 4eb
500 1 507 1
502 2 51a 51c
3 518 519 51e
2 527 529 2
52b 52d 2 52f
531 2 533 535
2 537 539 3
53e 53f 540 2
53b 542 2 526
544 1 546 1
548 2 511 549
1 54d 1 50c
2 50a 551 2
558 559 1 55b
1 560 2 55e
560 1 562 2
56b 570 1 577
1 572 2 58a
58c 3 588 589
58e 2 597 599
2 59b 59d 2
59f 5a1 2 5a3
5a5 2 5a7 5a9
3 5ae 5af 5b0
2 5ab 5b2 2
596 5b4 1 5b6
1 5b8 2 581
5b9 1 5bd 1
57c 2 57a 5c1
1 5cc 2 5c8
5cc 2 5d8 5da
3 5d6 5d7 5dc
2 5e5 5e7 2
5e4 5e9 1 5eb
1 5ed 2 5ee
5f3 1 5f5 2
5c4 5f6 1 5f8
1 5fc 5 480
4e5 554 5f9 5ff
2 601 602 2
611 616 1 61d
1 618 2 630
632 3 62e 62f
634 2 63d 63f
2 641 643 2
645 647 2 649
64b 2 64d 64f
3 654 655 656
2 651 658 2
63c 65a 1 65c
1 65e 2 627
65f 1 663 1
622 2 620 667
2 66d 66e 1
672 2 670 672
2 676 677 1
67b 2 679 67b
2 680 681 1
685 2 683 685
2 68d 68e 2
693 694 2 690
696 1 699 1
69b 2 69e 69f
1 6a3 2 6a1
6a3 1 6a6 2
6ac 6ad 1 6b1
2 6af 6b1 2
6b6 6b7 2 6bc
6bd 2 6b9 6bf
1 6c2 1 6c4
1 6c5 2 6d4
6d9 1 6e0 1
6db 2 6f3 6f5
3 6f1 6f2 6f7
2 700 702 2
704 706 2 708
70a 2 70c 70e
2 710 712 3
717 718 719 2
714 71b 2 6ff
71d 1 71f 1
721 2 6ea 722
1 726 1 6e5
2 6e3 72a 1
72d 2 730 731
1 732 2 735
736 1 73a 2
738 73a 2 73f
740 2 742 744
1 747 2 74b
74c 1 750 2
74e 750 2 755
756 2 75b 75c
2 758 75e 1
761 2 766 767
1 76b 2 769
76b 2 770 771
2 776 777 2
773 779 1 77c
3 77f 764 77e
1 780 2 782
783 2 786 787
1 78b 2 789
78b 2 796 798
3 794 795 79a
2 7a3 7a5 2
7a2 7a7 1 7a9
1 7ab 2 7ac
7b1 1 7b3 3
69c 784 7b4 1
7b6 2 7b9 7ba
1 7be 2 7bc
7be 2 7c4 7c5
2 7c7 7ca 1
7ce 3 7d2 7d3
7d4 1 7d8 2
7d6 7d8 2 7dd
7de 1 7e2 2
7e0 7e2 2 7fa
7ff 1 806 1
801 2 819 81b
3 817 818 81d
2 826 828 2
82a 82c 2 82e
830 2 832 834
2 836 838 3
83d 83e 83f 2
83a 841 2 825
843 1 845 1
847 2 810 848
1 84c 1 80b
2 809 850 1
85b 2 857 85b
1 85f 2 869
86a 2 86c 86f
3 877 878 879
1 87d 2 87b
87d 3 884 885
886 1 88a 2
888 88a 3 891
892 893 1 897
2 895 897 2
89b 89c 1 8a0
2 89e 8a0 1
8a5 1 8a7 2
8a8 8ab 1 8ad
1 8ae 2 8b1
8b2 1 8b6 2
8b4 8b6 2 8be
8bf 2 8c1 8c4
1 8c8 1 8ca
2 8cd 8ce 2
8d3 8d4 1 8d6
2 8d0 8d6 2
8da 8db 1 8df
2 8dd 8df 3
8e5 8e6 8e7 1
8eb 2 8e9 8eb
3 8f1 8f2 8f3
1 8f7 2 8f5
8f7 1 8fc 1
8fe 2 929 92a
22 90c 90d 90e
90f 910 911 912
913 914 915 916
917 918 919 91a
91b 91c 91d 91e
91f 920 921 922
923 924 925 926
927 92c 92d 92e
92f 930 931 4
8ff 904 909 934
1 936 1 940
2 93f 940 1
948 1 94e 2
950 951 2 93d
952 1 959 1
954 2 96c 96e
3 96a 96b 970
2 979 97b 2
97d 97f 2 981
983 2 985 987
2 989 98b 3
990 991 992 2
98d 994 2 978
996 1 998 1
99a 2 963 99b
1 99f 1 95e
2 95c 9a3 2
9b0 9b2 3 9ae
9af 9b4 2 9bd
9bf 2 9bc 9c1
1 9c3 1 9c5
4 937 9a6 9c6
9c9 1 9cb 2
8cb 9cc 2 9ce
9cf 2 873 9d0
1 9d2 2 853
9d3 2 9d6 9d5
2 9d9 9da 1
9de 2 9dc 9de
2 9e3 9e4 2
9e9 9ea 1 9ec
2 9e6 9ec 2
9f3 9f4 1 9f8
2 9f6 9f8 2
a00 a01 2 a05
a06 2 a03 a08
1 a0c 1 a0e
19 a12 a13 a14
a15 a16 a17 a18
a19 a1a a1b a1c
a1d a1e a1f a20
a21 a22 a23 a24
a25 a26 a27 a28
a29 a2a 2 a0f
a2d 2 a31 a32
1 a36 2 a34
a36 2 a3a a3b
1 a3f 2 a3d
a3f 2 a47 a48
2 a4c a4d 2
a4a a4f 1 a53
1 a55 19 a59
a5a a5b a5c a5d
a5e a5f a60 a61
a62 a63 a64 a65
a66 a67 a68 a69
a6a a6b a6c a6d
a6e a6f a70 a71
2 a56 a74 2
a77 a76 2 a7a
a7b 1 a7f 2
a7d a7f 1 a88
2 a8c a8d 1
a91 2 a8f a91
2 a95 a96 1
a9a 2 a98 a9a
1 aa5 2 aa8
aa7 1 aae 2
aac aae 1 ab5
1 ab7 2 ac1
ac3 3 abf ac0
ac5 2 ace ad0
2 ad2 ad4 2
ad6 ad8 2 ada
ade 2 acd ae0
1 ae2 1 ae4
14 2b5 2d4 345
348 34b 34e 351
354 357 35a 35d
603 66a 7b7 9d7
a78 aa9 ab8 ae5
aea 32 5e 64
6a 70 76 7c
82 88 8e 94
9b a2 a9 b0
b5 ba c1 c8
cf d6 dd e4
eb f2 f8 fe
104 10a 110 116
11c 122 128 12e
135 13c 141 146
14c 152 158 15e
164 16a 170 176
17c 182 188 18e

1
4
0 
af2
0
1
14
11
44
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 0 0 0 
ca 1 0
2 0 1
12a 1 0
41 1 0
39 1 0
f4 1 0
106 1 0
15 1 0
112 1 0
1f 1 0
bc 1 0
29 1 0
160 1 0
130 1 0
25 1 0
d8 1 0
14e 1 0
3 1 0
17e 1 0
b2 1 0
118 1 0
16c 1 0
10c 1 0
b7 1 0
72 1 0
f 1 0
a4 1 0
60 1 0
3d 1 0
8a 1 0
19 1 0
9 1 0
90 1 0
154 1 0
11e 1 0
d1 1 0
7e 1 0
2d 1 0
184 1 0
172 1 0
143 1 0
ab 1 0
15a 1 0
100 1 0
96 1 0
45 1 0
124 1 0
18a 1 0
6c 1 0
66 1 0
178 1 0
df 1 0
78 1 0
fa 1 0
c3 1 0
9d 1 0
35 1 0
5a 1 0
148 1 0
13e 1 0
31 1 0
e6 1 0
166 1 0
4f 1 0
49 1 0
84 1 0
137 1 0
ed 1 0
0

/
SHOW ERRORS FUNCTION FC_U_TSKRES2;
ALTER FUNCTION FC_U_TSKRES2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_TSKRES2
#Short Description :Update resource/profile assignment
#Description       :Gets call from FC_SEARCH_2
#Table Name        :
#Parameters        :
 $$if bitflag  = 0 then insert new assignment (assign_id = RES_ASSIGNMENT_ID)
               = 1 then update an existing assignment (assign_id = TSK_ASSIGNMENT_ID)
               = 2 then insert new assignment using project assignment (assign_id = RES_ASSIGNMENT_ID)
               = 3 then reject a profile replacement, uncommit everything
               = 9 MSP
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_TSKRES2 ==
CREATE OR REPLACE FUNCTION SP_U_TSKRES2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
71
2 :e:
1FUNCTION:
1SP_U_TSKRES2:
1ASSIGN_ID:
1VARCHAR2:
1AND_ROLES:
1AND_SKILLS:
1WORK_LOCATION001:
1PLS_INTEGER:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1WORK001:
1EUNIT:
1UNIT:
1WORK_TYPE:
1BITFLAG001:
1CONTOUR001:
1CONTOUR_TYPE001:
1OCCURRENCE:
1ASSIGN_STRING001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ASSIGN_ID:
132:
1H_AND_ROLES:
18000:
1H_AND_SKILLS:
1H_WORK_LOCATION:
10:
1H_START_DATE:
126:
1H_FINISH_DATE:
1H_EFFORT:
1H_WORK:
1H_EUNIT:
1H_UNIT:
1H_WORK_TYPE:
1H_BITFLAG:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_OCCURRENCE:
1H_ASSIGN_STRING:
18192:
1H_REC_USER:
1H_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_TSKRES2(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
164:
1+:
1FPUT:
1               ENTER:: SP_U_TSKRES2(65) :: cplan.sql(7943) :: :
1IS NULL:
18:
172:
1      RETURN_INVALID:: SP_U_TSKRES2(73) :: cplan.sql(7951) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
175:
1                EXIT:: SP_U_TSKRES2(76) :: cplan.sql(7954) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1SC_STATE:
1FC_U_TSKRES2:
14:
1105:
1       RETURN_STATUS:: SP_U_TSKRES2(106) :: cplan.sql(7984) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
116:
1113:
1           EXCEPTION:: SP_U_TSKRES2(114) :: cplan.sql(7992) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
1125:
1           EXCEPTION:: SP_U_TSKRES2(126) :: cplan.sql(8004) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
3ca
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e :2 5a a0 7e b4 2e :2 5a
52 10 a0 7e b4 2e :2 5a 52
10 a0 7e b4 2e :2 5a 52 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :12 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
3ca
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 13a
160 164 168 16c 16f 173 190 17b
17f 182 183 18b 17a 1ad 19b 177
19f 1a0 1a8 19a 1ca 1b8 197 1bc
1bd 1c5 1b7 1e6 1d5 1d9 1b4 1e1
1d4 203 1f1 1d1 1f5 1f6 1fe 1f0
220 20e 1ed 212 213 21b 20d 23c
22b 22f 20a 237 22a 258 247 24b
227 253 246 274 263 267 243 26f
262 290 27f 283 25f 28b 27e 2ac
29b 29f 27b 2a7 29a 2c8 2b7 2bb
297 2c3 2b6 2e4 2d3 2d7 2b3 2df
2d2 300 2ef 2f3 2cf 2fb 2ee 31c
30b 30f 2eb 317 30a 339 327 307
32b 32c 334 326 356 344 323 348
349 351 343 372 361 365 340 36d
360 392 37d 381 35d 385 38d 37c
399 39d 379 3a1 3a5 3a9 3ac 3b1
3b2 1 3b4 3b9 3bd 3c1 3c4 3c9
3cd 3d1 3d4 3d9 3da 3dc 3e1 3e4
3e8 3e9 3ee 3f3 3f6 3fb 3fc 401
404 408 409 40e 411 416 417 41c
41f 424 425 42a 42d 432 433 438
43b 43f 440 445 448 44d 44e 453
456 45b 45c 461 464 469 46a 46f
472 476 477 47c 47f 484 485 48a
48d 492 493 498 49b 49f 4a3 4a7
4a8 4aa 4af 4b0 4b2 4b3 4b8 4bb
4c0 4c1 4c6 4c9 4ce 4cf 4d4 4d7
4db 4dc 4e1 4e4 4e9 4ea 4ef 4f2
4f7 4f8 4fd 500 505 506 50b 50e
512 513 518 51b 520 521 526 529
52e 52f 534 537 53b 53f 543 544
546 54b 54c 54e 54f 554 557 55c
55d 562 565 569 56d 571 572 574
579 57a 57c 57d 582 585 58a 58b
590 593 597 59b 59f 5a0 5a2 5a7
5a8 5aa 5ab 5b0 5b3 5b8 5b9 5be
5c1 5c5 5c9 5cd 5ce 5d0 5d5 5d6
5d8 5d9 5de 5e1 5e6 5e7 5ec 5ef
5f3 5f7 5fb 5fc 5fe 603 604 606
607 60c 60f 614 615 61a 61d 621
625 629 62a 62c 631 632 634 635
63a 63d 642 643 648 64b 64f 653
657 658 65a 65f 660 662 663 668
66b 670 671 676 679 67d 681 685
686 688 68d 68e 690 691 696 699
69e 69f 6a4 6a7 6ab 6af 6b3 6b4
6b6 6bb 6bc 6be 6bf 6c4 6c7 6cc
6cd 6d2 6d5 6da 6db 6e0 6e3 6e7
6e8 6ed 6f0 6f5 6f6 6fb 6fe 703
704 709 70c 711 712 717 71a 71e
71f 724 727 72c 72d 732 735 73a
73b 740 741 746 748 74c 74f 753
757 75a 75e 762 765 768 76d 770
773 776 777 77c 77d 1 77f 784
788 78c 78f 794 799 79c 7a0 7a1
7a6 7a7 7ac 7ae 7b2 7b5 7b9 7bc
7bd 7c2 7c5 7c8 7cc 7cf 7d0 7d5
7d8 1 7db 7e0 7e4 7e7 7e8 7ed
7f0 1 7f3 7f8 7fc 7ff 800 805
808 1 80b 810 814 818 81b 81f
823 826 829 82e 831 834 837 838
83d 83e 1 840 845 849 84d 850
855 85a 85d 861 862 867 86a 86f
870 875 878 87d 87e 883 886 88a
88e 892 896 899 89a 89c 8a1 8a2
8a4 8a5 8aa 8ab 8b0 8b2 8b6 8b9
8bd 8c1 8c4 8c8 8cc 8cf 8d2 8d7
8da 8dd 8e0 8e1 8e6 8e7 1 8e9
8ee 8f2 8f6 8f9 8fe 903 906 90a
90b 910 911 916 918 91c 91f 923
927 92a 92e 932 935 939 93a 93f
941 945 948 94c 950 954 958 95c
960 964 968 96c 970 974 978 97c
980 984 988 98c 990 994 998 99c
9a0 9a4 9a8 9ac 9b0 9b4 9b8 9bc
9c0 9c4 9c8 9cc 9d0 9d4 9d8 9dc
9e0 9e4 9e8 9ec 9f0 9f4 9f8 9fc
a00 a04 a08 a0c a10 a14 a18 a1c
a1f a23 a27 a2b a2f a33 a37 a3b
a3f a43 a47 a4b a4f a53 a57 a5b
a5f a63 a67 a68 a6a a6e a72 a76
a79 a7d a81 a84 a87 a8c a8f a92
a95 a96 a9b a9c 1 a9e aa3 aa7
aab aae ab3 ab8 abb abf ac0 ac5
ac8 acd ace ad3 ad6 adb adc ae1
ae4 ae8 aec af0 af4 af7 af8 afa
aff b00 b02 b03 b08 b0b b10 b11
b16 b19 b1e b1f b24 b27 b2b b2c
b31 b34 b39 b3a b3f b40 b45 b47
b4b b4e b52 b56 b59 b5d b61 b64
b68 b6c b6d b72 b74 b78 b7c b7f
b83 b87 b8a b8e b92 b95 b98 b9d
ba0 ba3 ba6 ba7 bac bad 1 baf
bb4 bb8 bbc bbf bc4 bc9 bcc bd0
bd1 bd6 bd7 bdc be0 be4 be7 bec
bf1 bf4 bf8 bfc bff c00 c05 c08
c0d c0e c13 c16 c1a c1e c21 c22
c27 c28 c2d c2f c33 c36 c3a c3e
c42 c46 c4a c4e c52 c56 c5a c66
c6b c6f c73 c77 c7b c7d c7e c83
1 c87 c8b c8f c92 c96 c9a c9e
ca2 ca5 ca9 cad cb0 cb3 cb8 cbb
cbe cc1 cc2 cc7 cc8 1 cca ccf
cd3 cd7 cda cdf ce4 ce7 ceb cec
cf1 cf2 cf7 cfb cff d02 d07 d0c
d0f d13 d14 d19 d1c d21 d22 d27
d2a d2e d32 d35 d38 d39 d3b d3c
d41 d42 d47 d49 d4d d50 d54 d58
d5c d60 d64 d68 d6c d78 d7d d81
d85 d89 d8d d8f d93 d95 da1 da3
da5 da6 dab daf db1 dbd dc1 dc3
dc4 dcd 
3ca
2
0 1 a 6 10 :3 6 10 :3 6
11 :3 6 17 :3 6 14 :3 6 15 :3 6
10 :3 6 e :3 6 c :3 6 b :3 6
10 :3 6 11 :3 6 11 :3 6 16 :3 6
11 :3 6 17 :3 6 12 :2 6 1 3
a 13 a :2 1 4 10 19 18
:2 10 :2 4 10 19 18 :2 10 :2 4 11
1a 19 :2 11 :2 4 :2 14 23 14 :2 4
11 1a 19 :2 11 :2 4 12 1b 1a
:2 12 :2 4 :2 d 1c d :2 4 :2 b 1a
b :2 4 :2 c 1b c :2 4 :2 b 1a
b :2 4 :2 10 1f 10 :2 4 :2 e 1d
e :2 4 :2 e 1d e :2 4 :2 13 22
13 :2 4 :2 11 20 11 :2 4 14 1d
1c :2 14 :2 4 f 18 17 :2 f :2 4
:2 14 23 14 :2 4 e 17 :3 e 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 54 5a 5d
:2 54 6b 81 8 :2 6b d 10 :2 6b
1a 1d :2 6b b e :2 6b 13 16
:2 6b 1b 1e :2 6b 28 2b :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
29 2c :2 6b b e :2 6b 13 16
1f 27 :2 1f 3a :2 16 :2 6b b e
:2 6b 13 16 :2 6b 1b 1e :2 6b 2c
2f :2 6b b e :2 6b 13 16 :2 6b
1b 1e :2 6b 2d 30 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 33 :2 16
:2 6b b e :2 6b 13 16 1f 27
:2 1f 31 :2 16 :2 6b b e :2 6b 13
16 1f 27 :2 1f 2f :2 16 :2 6b b
e :2 6b 13 16 1f 27 :2 1f 2e
:2 16 :2 6b b e :2 6b 13 16 1f
27 :2 1f 33 :2 16 :2 6b b e :2 6b
13 16 1f 27 :2 1f 34 :2 16 :2 6b
b e :2 6b 13 16 1f 27 :2 1f
34 :2 16 :2 6b b e :2 6b 13 16
1f 27 :2 1f 39 :2 16 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 34 :2 16
:2 6b b e :2 6b 13 16 :2 6b 1b
1e :2 6b 2f 32 :2 6b b e :2 6b
13 16 :2 6b 1b 1e :2 6b 2a 2d
:2 6b 32 35 :2 6b :2 7 4a :2 4 7
:2 11 23 :2 2d 39 3c 4c 4e 4f
:2 4c :2 23 :3 7 :2 d 12 1e 5c 5f
:2 1e :2 7 52 :2 4 :4 9 8 7 :4 22
21 20 :2 7 :4 3f 3e 3d :2 7 :4 f
e d :2 7 a :2 14 26 :2 30 3c
3f 4f 51 52 :2 4f :2 26 :3 a :2 10
15 21 5f 62 :2 21 6f 72 :2 21
76 79 :2 21 83 86 8f 97 :2 a0
:2 8f b1 :2 86 :2 21 :2 a 55 :2 7 a
:2 14 26 :2 30 3c 3f 4f 51 52
:2 4f :2 26 :3 a :2 10 15 21 5f 62
:2 21 :2 a 55 :3 7 :2 12 28 :2 31 41
:2 7 2a :3 4 13 :2 4 13 :2 4 14
:2 4 14 :2 4 15 :2 4 17 :2 4 12
:2 4 17 :2 4 10 :2 4 e :2 4 f
:2 4 e :2 4 13 :2 4 11 :2 4 11
:2 4 16 :2 4 14 :2 4 :2 d 19 26
33 40 4e 25 33 42 4c 54
5d 25 32 3d 48 58 25 36
:2 19 4 7 :2 11 23 :2 2d 39 3c
4c 4f 50 :2 4c :2 23 :3 7 :2 d 12
1e 5d 60 :2 1e 6d 70 :2 1e 74
77 :2 1e 81 84 8d 95 :2 9e :2 8d
a9 :2 84 :2 1e b1 b4 :2 1e bc bf
:2 1e c4 c7 :2 1e d3 d6 :2 1e :2 7
53 :3 4 :2 f 21 :2 2a 34 41 :2 4
1 9 12 9 a :2 14 26 :2 30
3c 40 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 60 63 :2 21 :3 a :2 10
15 39 5c 5f :2 68 :2 39 76 79
:2 39 81 84 :2 8d :2 39 :2 a 57 :3 7
c 15 1e 2c a 13 1e f
e 7 e 7 e 7 29 :2 4
:2 9 7 :2 10 1c :2 7 :2 11 23 :2 2d
39 3d 4d 50 51 :2 4d :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :3 7 :2 d
12 36 42 45 :2 36 4d 50 :2 36
5c 5f 66 6f 72 :2 5f :2 36 :2 7
54 :2 4 7 c 1b a 13 1e
f e 7 e 7 e 7 :2 4
:4 10 :2 4 :8 1 
3ca
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 2
:4 14 :2 1 :7 16 :7 17
:7 18 :6 19 :7 1a :7 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :7 25 :7 26 :6 27
:7 29 :b 2b :11 2c 2d
:2 2c :2 2d :2 2c :2 2d
:2 2c :2 2e :2 2c :2 2e
:2 2c :2 2e :2 2c :2 2e
:2 2c :2 2f :2 2c :2 2f
:2 2c :2 2f :2 2c :2 2f
:2 2c :2 30 :2 2c :9 30
:2 2c :2 31 :2 2c :2 31
:2 2c :2 31 :2 2c :2 31
:2 2c :2 32 :2 2c :2 32
:2 2c :2 32 :2 2c :2 32
:2 2c :2 33 :2 2c :9 33
:2 2c :2 34 :2 2c :9 34
:2 2c :2 35 :2 2c :9 35
:2 2c :2 36 :2 2c :9 36
:2 2c :2 37 :2 2c :9 37
:2 2c :2 38 :2 2c :9 38
:2 2c :2 39 :2 2c :9 39
:2 2c :2 3a :2 2c :9 3a
:2 2c :2 3b :2 2c :9 3b
:2 2c :2 3c :2 2c :2 3c
:2 2c :2 3c :2 2c :2 3c
:2 2c :2 3d :2 2c :2 3d
:2 2c :2 3d :2 2c :2 3d
:2 2c :2 3d :4 2c :3 2b
:11 40 :b 41 :3 40 :16 46
:6 47 :2 46 :11 48 :20 49
:3 48 :11 4b :b 4c :3 4b
:9 4e 47 :2 46 :3 51
:3 52 :3 53 :3 54 :3 55
:3 56 :3 57 :3 59 :3 5a
:3 5b :3 5c :3 5d :3 5e
:3 5f :3 60 :3 61 :3 62
:8 64 :6 65 :5 66 :2 67
:3 64 :11 69 :30 6a :3 69
:a 6c 2a :3 70 :11 71
:b 72 :17 73 :3 71 :2 75
:3 76 :3 77 78 76
75 76 :3 79 :3 70
:2 7a :5 7c :11 7d :b 7e
:18 7f :3 7d :2 81 82
:3 83 84 82 81
82 :3 85 :2 7b :6 7a
6f :7 1 
dcf
4
:3 0 1 :3 0 2
:a 0 3c5 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 8 :3 0 7
:7 0 11 10 :3 0
4 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 4
:3 0 a :7 0 19
18 :3 0 8 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 8 :3 0 c
:7 0 21 20 :3 0
8 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 8
:3 0 e :7 0 29
28 :3 0 8 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 8 :3 0 10
:7 0 31 30 :3 0
8 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 8
:3 0 12 :7 0 39
38 :3 0 8 :3 0
13 :7 0 3d 3c
:3 0 25 :2 0 23
4 :3 0 14 :7 0
41 40 :3 0 4
:3 0 15 :7 0 45
44 :3 0 16 :3 0
17 :3 0 18 :2 0
4 49 4a 0
47 4b 0 3c5
2 4c :2 0 1c
:2 0 39 4 :3 0
1a :2 0 37 4f
51 :6 0 54 52
0 3c3 0 19
:6 0 1c :2 0 3d
4 :3 0 3b 56
58 :6 0 5b 59
0 3c3 0 1b
:6 0 1f :2 0 41
4 :3 0 3f 5d
5f :6 0 62 60
0 3c3 0 1d
:6 0 21 :2 0 43
8 :3 0 64 :7 0
68 65 66 3c3
0 1e :6 0 21
:2 0 47 4 :3 0
45 6a 6c :6 0
6f 6d 0 3c3
0 20 :6 0 1f
:2 0 4b 4 :3 0
49 71 73 :6 0
76 74 0 3c3
0 22 :6 0 1f
:2 0 4d 8 :3 0
78 :7 0 7c 79
7a 3c3 0 23
:6 0 1f :2 0 4f
8 :3 0 7e :7 0
82 7f 80 3c3
0 24 :6 0 1f
:2 0 51 8 :3 0
84 :7 0 88 85
86 3c3 0 25
:6 0 1f :2 0 53
8 :3 0 8a :7 0
8e 8b 8c 3c3
0 26 :6 0 1f
:2 0 55 8 :3 0
90 :7 0 94 91
92 3c3 0 27
:6 0 1f :2 0 57
8 :3 0 96 :7 0
9a 97 98 3c3
0 28 :6 0 1f
:2 0 59 8 :3 0
9c :7 0 a0 9d
9e 3c3 0 29
:6 0 1f :2 0 5b
8 :3 0 a2 :7 0
a6 a3 a4 3c3
0 2a :6 0 2d
:2 0 5d 8 :3 0
a8 :7 0 ac a9
aa 3c3 0 2b
:6 0 1a :2 0 61
4 :3 0 5f ae
b0 :6 0 b3 b1
0 3c3 0 2c
:6 0 1f :2 0 65
4 :3 0 63 b5
b7 :6 0 ba b8
0 3c3 0 2e
:6 0 c2 c3 0
67 8 :3 0 bc
:7 0 c0 bd be
3c3 0 2f :6 0
c8 c9 0 69
17 :3 0 18 :2 0
4 c4 :7 0 c7
c5 0 3c3 0
30 :6 0 31 :3 0
32 :3 0 31 :3 0
33 :3 0 cb cc
0 2 :4 0 6b
cd cf ca d1
d0 :2 0 34 :3 0
35 :3 0 d3 d4
0 36 :4 0 31
:3 0 37 :3 0 d7
d8 0 2 :4 0
6d d9 db 38
:4 0 39 :2 0 3a
:3 0 6f de e0
:3 0 3b :4 0 39
:2 0 3c :4 0 72
e3 e5 :3 0 39
:2 0 3 :3 0 75
e7 e9 :3 0 39
:2 0 3c :4 0 78
eb ed :3 0 39
:2 0 3d :4 0 7b
ef f1 :3 0 39
:2 0 3c :4 0 7e
f3 f5 :3 0 39
:2 0 5 :3 0 81
f7 f9 :3 0 39
:2 0 3c :4 0 84
fb fd :3 0 39
:2 0 3d :4 0 87
ff 101 :3 0 39
:2 0 3c :4 0 8a
103 105 :3 0 39
:2 0 6 :3 0 8d
107 109 :3 0 39
:2 0 3c :4 0 90
10b 10d :3 0 39
:2 0 3d :4 0 93
10f 111 :3 0 39
:2 0 3e :3 0 3f
:3 0 7 :3 0 96
115 117 40 :4 0
98 114 11a 9b
113 11c :3 0 39
:2 0 3d :4 0 9e
11e 120 :3 0 39
:2 0 3c :4 0 a1
122 124 :3 0 39
:2 0 9 :3 0 a4
126 128 :3 0 39
:2 0 3c :4 0 a7
12a 12c :3 0 39
:2 0 3d :4 0 aa
12e 130 :3 0 39
:2 0 3c :4 0 ad
132 134 :3 0 39
:2 0 a :3 0 b0
136 138 :3 0 39
:2 0 3c :4 0 b3
13a 13c :3 0 39
:2 0 3d :4 0 b6
13e 140 :3 0 39
:2 0 3e :3 0 3f
:3 0 b :3 0 b9
144 146 40 :4 0
bb 143 149 be
142 14b :3 0 39
:2 0 3d :4 0 c1
14d 14f :3 0 39
:2 0 3e :3 0 3f
:3 0 c :3 0 c4
153 155 40 :4 0
c6 152 158 c9
151 15a :3 0 39
:2 0 3d :4 0 cc
15c 15e :3 0 39
:2 0 3e :3 0 3f
:3 0 d :3 0 cf
162 164 40 :4 0
d1 161 167 d4
160 169 :3 0 39
:2 0 3d :4 0 d7
16b 16d :3 0 39
:2 0 3e :3 0 3f
:3 0 e :3 0 da
171 173 40 :4 0
dc 170 176 df
16f 178 :3 0 39
:2 0 3d :4 0 e2
17a 17c :3 0 39
:2 0 3e :3 0 3f
:3 0 f :3 0 e5
180 182 40 :4 0
e7 17f 185 ea
17e 187 :3 0 39
:2 0 3d :4 0 ed
189 18b :3 0 39
:2 0 3e :3 0 3f
:3 0 10 :3 0 f0
18f 191 40 :4 0
f2 18e 194 f5
18d 196 :3 0 39
:2 0 3d :4 0 f8
198 19a :3 0 39
:2 0 3e :3 0 3f
:3 0 11 :3 0 fb
19e 1a0 40 :4 0
fd 19d 1a3 100
19c 1a5 :3 0 39
:2 0 3d :4 0 103
1a7 1a9 :3 0 39
:2 0 3e :3 0 3f
:3 0 12 :3 0 106
1ad 1af 40 :4 0
108 1ac 1b2 10b
1ab 1b4 :3 0 39
:2 0 3d :4 0 10e
1b6 1b8 :3 0 39
:2 0 3e :3 0 3f
:3 0 13 :3 0 111
1bc 1be 40 :4 0
113 1bb 1c1 116
1ba 1c3 :3 0 39
:2 0 3d :4 0 119
1c5 1c7 :3 0 39
:2 0 3c :4 0 11c
1c9 1cb :3 0 39
:2 0 14 :3 0 11f
1cd 1cf :3 0 39
:2 0 3c :4 0 122
1d1 1d3 :3 0 39
:2 0 3d :4 0 125
1d5 1d7 :3 0 39
:2 0 3c :4 0 128
1d9 1db :3 0 39
:2 0 15 :3 0 12b
1dd 1df :3 0 39
:2 0 3c :4 0 12e
1e1 1e3 :3 0 39
:2 0 41 :4 0 131
1e5 1e7 :3 0 134
d5 1e9 :2 0 1eb
139 1ec d2 1eb
0 1ed 13b 0
323 31 :3 0 32
:3 0 1ee 1ef 0
31 :3 0 42 :3 0
1f1 1f2 0 43
:2 0 2 :4 0 44
:2 0 45 :2 0 43
:2 0 13d 1f7 1f9
:3 0 140 1f3 1fb
1f0 1fd 1fc :2 0
34 :3 0 46 :3 0
1ff 200 0 36
:4 0 47 :4 0 39
:2 0 3a :3 0 144
204 206 :3 0 147
201 208 :2 0 20a
14a 20b 1fe 20a
0 20c 14c 0
323 3 :3 0 48
:2 0 14e 20e 20f
:3 0 210 :2 0 211
:2 0 9 :3 0 48
:2 0 150 214 215
:3 0 216 :2 0 217
:2 0 212 219 218
:2 0 a :3 0 48
:2 0 152 21c 21d
:3 0 21e :2 0 21f
:2 0 21a 221 220
:2 0 14 :3 0 48
:2 0 154 224 225
:3 0 226 :2 0 227
:2 0 222 229 228
:2 0 31 :3 0 32
:3 0 22b 22c 0
31 :3 0 42 :3 0
22e 22f 0 49
:2 0 2 :4 0 4a
:2 0 45 :2 0 43
:2 0 156 234 236
:3 0 159 230 238
22d 23a 239 :2 0
34 :3 0 46 :3 0
23c 23d 0 36
:4 0 4b :4 0 39
:2 0 3a :3 0 15d
241 243 :3 0 39
:2 0 4c :4 0 160
245 247 :3 0 39
:2 0 4d :4 0 163
249 24b :3 0 39
:2 0 3e :3 0 3f
:3 0 4e :3 0 4f
:3 0 250 251 0
166 24f 253 40
:4 0 168 24e 256
16b 24d 258 :3 0
16e 23e 25a :2 0
25c 171 25d 23b
25c 0 25e 173
0 287 31 :3 0
32 :3 0 25f 260
0 31 :3 0 42
:3 0 262 263 0
43 :2 0 2 :4 0
50 :2 0 45 :2 0
43 :2 0 175 268
26a :3 0 178 264
26c 261 26e 26d
:2 0 34 :3 0 46
:3 0 270 271 0
36 :4 0 51 :4 0
39 :2 0 3a :3 0
17c 275 277 :3 0
17f 272 279 :2 0
27b 182 27c 26f
27b 0 27d 184
0 287 52 :3 0
53 :3 0 27e 27f
0 4e :3 0 4f
:3 0 281 282 0
54 :3 0 186 280
285 :2 0 287 189
288 22a 287 0
289 18d 0 323
19 :3 0 3 :3 0
28a 28b 0 323
1b :3 0 5 :3 0
28d 28e 0 323
1d :3 0 6 :3 0
290 291 0 323
20 :3 0 9 :3 0
293 294 0 323
22 :3 0 a :3 0
296 297 0 323
2c :3 0 14 :3 0
299 29a 0 323
2e :3 0 15 :3 0
29c 29d 0 323
1e :3 0 7 :3 0
29f 2a0 0 323
23 :3 0 b :3 0
2a2 2a3 0 323
24 :3 0 c :3 0
2a5 2a6 0 323
25 :3 0 d :3 0
2a8 2a9 0 323
26 :3 0 e :3 0
2ab 2ac 0 323
27 :3 0 f :3 0
2ae 2af 0 323
28 :3 0 10 :3 0
2b1 2b2 0 323
29 :3 0 11 :3 0
2b4 2b5 0 323
2a :3 0 12 :3 0
2b7 2b8 0 323
2b :3 0 13 :3 0
2ba 2bb 0 323
17 :3 0 55 :3 0
2bd 2be 0 56
:3 0 19 :3 0 1b
:3 0 1d :3 0 1e
:3 0 20 :3 0 22
:3 0 23 :3 0 24
:3 0 25 :3 0 26
:3 0 27 :3 0 28
:3 0 29 :3 0 2a
:3 0 2b :3 0 2c
:3 0 2e :3 0 18f
2c0 2d2 2bf 2d3
0 323 31 :3 0
32 :3 0 2d5 2d6
0 31 :3 0 42
:3 0 2d8 2d9 0
57 :2 0 2 :4 0
58 :2 0 45 :2 0
43 :2 0 1a1 2de
2e0 :3 0 1a4 2da
2e2 2d7 2e4 2e3
:2 0 34 :3 0 46
:3 0 2e6 2e7 0
36 :4 0 59 :4 0
39 :2 0 3a :3 0
1a8 2eb 2ed :3 0
39 :2 0 4c :4 0
1ab 2ef 2f1 :3 0
39 :2 0 4d :4 0
1ae 2f3 2f5 :3 0
39 :2 0 3e :3 0
3f :3 0 17 :3 0
55 :3 0 2fa 2fb
0 1b1 2f9 2fd
40 :4 0 1b3 2f8
300 1b6 2f7 302
:3 0 39 :2 0 5a
:4 0 1b9 304 306
:3 0 39 :2 0 3c
:4 0 1bc 308 30a
:3 0 39 :2 0 19
:3 0 1bf 30c 30e
:3 0 39 :2 0 3c
:4 0 1c2 310 312
:3 0 1c5 2e8 314
:2 0 316 1c8 317
2e5 316 0 318
1ca 0 323 52
:3 0 5b :3 0 319
31a 0 17 :3 0
55 :3 0 31c 31d
0 19 :3 0 54
:3 0 1cc 31b 321
:2 0 323 1d0 3c4
17 :3 0 5c :2 0
4 324 325 0
31 :3 0 32 :3 0
327 328 0 31
:3 0 42 :3 0 32a
32b 0 5d :2 0
2 :4 0 5e :2 0
45 :2 0 43 :2 0
1e8 330 332 :3 0
1eb 32c 334 329
336 335 :2 0 34
:3 0 46 :3 0 338
339 0 36 :4 0
5f :4 0 39 :2 0
3a :3 0 1ef 33d
33f :3 0 1f2 33a
341 :2 0 35a 34
:3 0 46 :3 0 343
344 0 36 :4 0
60 :4 0 39 :2 0
17 :3 0 61 :3 0
349 34a 0 1f5
348 34c :3 0 39
:2 0 5a :4 0 1f8
34e 350 :3 0 39
:2 0 17 :3 0 62
:3 0 353 354 0
1fb 352 356 :3 0
1fe 345 358 :2 0
35a 201 35b 337
35a 0 35c 204
0 36c 63 :3 0
30 :3 0 17 :3 0
61 :3 0 64 :3 0
17 :3 0 62 :3 0
65 :3 0 66 :4 0
67 1 :a 0 368
:2 0 36c 35e 366
:2 0 16 :3 0 30
:3 0 36a :2 0 36c
206 36e 20a 36d
36c :2 0 3c2 68
:3 0 17 :3 0 55
:3 0 371 372 0
69 :3 0 373 374
0 3ba 31 :3 0
32 :3 0 376 377
0 31 :3 0 42
:3 0 379 37a 0
5d :2 0 2 :4 0
6a :2 0 45 :2 0
43 :2 0 20c 37f
381 :3 0 20f 37b
383 378 385 384
:2 0 34 :3 0 46
:3 0 387 388 0
36 :4 0 6b :4 0
39 :2 0 3a :3 0
213 38c 38e :3 0
216 389 390 :2 0
3aa 34 :3 0 46
:3 0 392 393 0
36 :4 0 6c :4 0
39 :2 0 69 :3 0
219 397 399 :3 0
39 :2 0 6d :4 0
21c 39b 39d :3 0
39 :2 0 6e :3 0
6f :3 0 43 :2 0
70 :2 0 21f 3a0
3a4 223 39f 3a6
:3 0 226 394 3a8
:2 0 3aa 229 3ab
386 3aa 0 3ac
22c 0 3ba 63
:3 0 30 :3 0 64
:3 0 17 :3 0 62
:3 0 65 :3 0 66
:4 0 71 1 :a 0
3b6 :2 0 3ba 3ae
3b4 :2 0 16 :3 0
30 :3 0 3b8 :2 0
3ba 22e 3bd :3 0
3bd 0 3bd 3bc
3ba 3bb :6 0 3bf
1 :3 0 233 3c1
235 3c0 3bf :2 0
3c2 237 :2 0 3c4
23a 3c4 3c3 323
3c2 :6 0 3c5 :2 0
2 4c 3c4 3c8
:3 0 3c7 3c5 3c9
:8 0 
24e
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 11
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 1 50 1
4e 1 57 1
55 1 5e 1
5c 1 63 1
6b 1 69 1
72 1 70 1
77 1 7d 1
83 1 89 1
8f 1 95 1
9b 1 a1 1
a7 1 af 1
ad 1 b6 1
b4 1 bb 1
c1 1 ce 1
da 2 dd df
2 e2 e4 2
e6 e8 2 ea
ec 2 ee f0
2 f2 f4 2
f6 f8 2 fa
fc 2 fe 100
2 102 104 2
106 108 2 10a
10c 2 10e 110
1 116 2 118
119 2 112 11b
2 11d 11f 2
121 123 2 125
127 2 129 12b
2 12d 12f 2
131 133 2 135
137 2 139 13b
2 13d 13f 1
145 2 147 148
2 141 14a 2
14c 14e 1 154
2 156 157 2
150 159 2 15b
15d 1 163 2
165 166 2 15f
168 2 16a 16c
1 172 2 174
175 2 16e 177
2 179 17b 1
181 2 183 184
2 17d 186 2
188 18a 1 190
2 192 193 2
18c 195 2 197
199 1 19f 2
1a1 1a2 2 19b
1a4 2 1a6 1a8
1 1ae 2 1b0
1b1 2 1aa 1b3
2 1b5 1b7 1
1bd 2 1bf 1c0
2 1b9 1c2 2
1c4 1c6 2 1c8
1ca 2 1cc 1ce
2 1d0 1d2 2
1d4 1d6 2 1d8
1da 2 1dc 1de
2 1e0 1e2 2
1e4 1e6 4 d6
dc e1 1e8 1
1ea 1 1ec 2
1f6 1f8 3 1f4
1f5 1fa 2 203
205 2 202 207
1 209 1 20b
1 20d 1 213
1 21b 1 223
2 233 235 3
231 232 237 2
240 242 2 244
246 2 248 24a
1 252 2 254
255 2 24c 257
2 23f 259 1
25b 1 25d 2
267 269 3 265
266 26b 2 274
276 2 273 278
1 27a 1 27c
2 283 284 3
25e 27d 286 1
288 11 2c1 2c2
2c3 2c4 2c5 2c6
2c7 2c8 2c9 2ca
2cb 2cc 2cd 2ce
2cf 2d0 2d1 2
2dd 2df 3 2db
2dc 2e1 2 2ea
2ec 2 2ee 2f0
2 2f2 2f4 1
2fc 2 2fe 2ff
2 2f6 301 2
303 305 2 307
309 2 30b 30d
2 30f 311 2
2e9 313 1 315
1 317 3 31e
31f 320 17 1ed
20c 289 28c 28f
292 295 298 29b
29e 2a1 2a4 2a7
2aa 2ad 2b0 2b3
2b6 2b9 2bc 2d4
318 322 2 32f
331 3 32d 32e
333 2 33c 33e
2 33b 340 2
347 34b 2 34d
34f 2 351 355
2 346 357 2
342 359 1 35b
3 35c 367 36b
1 326 2 37e
380 3 37c 37d
382 2 38b 38d
2 38a 38f 2
396 398 2 39a
39c 3 3a1 3a2
3a3 2 39e 3a5
2 395 3a7 2
391 3a9 1 3ab
4 375 3ac 3b5
3b9 1 3bd 1
370 2 36e 3c1
13 53 5a 61
67 6e 75 7b
81 87 8d 93
99 9f a5 ab
b2 b9 bf c6

1
4
0 
3c8
0
1
14
2
25
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
43 1 0
2b 1 0
b 1 0
70 1 0
3b 1 0
27 1 0
23 1 0
4e 1 0
f 1 0
bb 1 0
2 0 1
1f 1 0
89 1 0
5c 1 0
77 1 0
a1 1 0
69 1 0
55 1 0
1b 1 0
a7 1 0
95 1 0
3 1 0
33 1 0
13 1 0
83 1 0
7d 1 0
8f 1 0
37 1 0
7 1 0
63 1 0
2f 1 0
b4 1 0
3f 1 0
ad 1 0
9b 1 0
17 1 0
c1 1 0
0

/
SHOW ERRORS FUNCTION SP_U_TSKRES2;
ALTER FUNCTION SP_U_TSKRES2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_ASSIGN_MSP
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_ASSIGN_MSP ==
CREATE OR REPLACE FUNCTION SP_ASSIGN_MSP wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1a3
2 :e:
1FUNCTION:
1SP_ASSIGN_MSP:
1ID001:
1VARCHAR2:
1ACTION_TYPE001:
1PLS_INTEGER:
1TASK_ID001:
1START_DT001:
1FINISH_DT001:
1EFFORT001:
1ASSIGN_STRING001:
1WORK_TODATE001:
1PERCENT_COMPLETE001:
1EETC:
1DATA_FLAG:
1UNITS:
1CONTOUR_TYPE001:
1BASELINE_START001:
1BASELINE_FINISH001:
1BASELINE_DURATION001:
1BASELINE_WORK001:
1ACTUAL_START001:
1ACTUAL_FINISH001:
1ACTUAL_EFFORT001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ELEMENT_NAME:
1255:
1H_FULL_NAME:
1H_MESSAGE:
18192:
1H_SUBJECT:
12048:
1H_REVISION:
116:
1H_TEMP_ID:
132:
1H_TEMP_ID2:
1H_WKF_DEF_ID:
1H_UNIQUEID:
1H_RA_ID:
1H_RESOURCE_ID:
1H_PROJECT_ID:
1H_TASK_ID:
1H_REC_USER:
1H_TYPE_ID:
10:
1H_WORK_LOCATION:
1H_ZERO:
1H_TWO:
12:
1H_WORK:
1H_CONTOUR:
1H_CONTOUR_TYPE:
1H_UNITS:
1H_PER_DAY:
1480:
1H_IMPEX_ROLLUP:
1H_EFFORT:
1H_COUNT:
1H_TOTAL:
1H_MINUTES:
1H_DATA_FLAG:
1H_WORK_TODATE:
1H_DAYOFYEAR:
1DATE:
1H_FINISH_D:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_NULL_STR:
11:
1H_START_DATE:
1TIMESTAMP:
1H_START_DT:
1H_ACTUAL_START:
1H_FINISH_DT:
1H_REC_DT:
1H_LOCK_DT:
1H_ASSIGN_STRING:
1H_TABLE_TYPE:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_OCCURRENCE:
1H_BIT_MINUTES:
1H_ACTION_TYPE:
1H_ETC:
1H_SD:
1H_FD:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_PERCENT_UNITS:
1CURSOR:
1C_H_WBS:
1ELEMENT_NAME:
1RTRIM:
1TO_CHAR:
1MAJOR_REVISION:
1MINOR_REVISION:
1TMT_WBS:
1PROJECT_ID:
1ELEMENT_ID:
1REC_DATETIME:
1ROWNUM:
1SELECT * FROM (SELECT ELEMENT_NAME,RTRIM(TO_CHAR(MAJOR_REVISION)) || '.' || R+
1TRIM(TO_CHAR(MINOR_REVISION)):n         FROM TMT_WBS:n         WHERE PROJECT_+
1ID = h_project_id AND ELEMENT_ID = h_task_id:n         ORDER BY REC_DATETIME +
1DESC ) WHERE ROWNUM<=1:
1CAF:
1SCHED_MIN:
1DAY_YEAR:
1ACTUAL_FLAG:
1TASK_DAY_OF_YEAR:
1TSK_ASSIGNMENT_ID:
1ACTUAL_MIN:
1SELECT SCHED_MIN, DAY_YEAR, ACTUAL_FLAG:n         FROM TASK_DAY_OF_YEAR:n    +
1     WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id:n         FOR UPDATE OF ACTUAL_MIN,ACTUAL_FLAG:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ASSIGN_MSP(:
1':
1, :
1COALESCE:
1NULL:
1);:
1CHECK_TRACE:
1123:
1+:
1FPUT:
1               ENTER:: SP_ASSIGN_MSP(124) :: cplan.sql(8152) :: :
1IS NULL:
1<:
1>:
13:
18:
1129:
1      RETURN_INVALID:: SP_ASSIGN_MSP(130) :: cplan.sql(8158) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1132:
1                EXIT:: SP_ASSIGN_MSP(133) :: cplan.sql(8161) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1139:
1      RETURN_INVALID:: SP_ASSIGN_MSP(140) :: cplan.sql(8168) :: :
1142:
1                EXIT:: SP_ASSIGN_MSP(143) :: cplan.sql(8171) :: :
1265:
1LENGTH:
1SC_ASSIGN_STRING_LENGTH:
1=:
1171:
1      RETURN_INVALID:: SP_ASSIGN_MSP(172) :: cplan.sql(8200) :: :
1174:
1                EXIT:: SP_ASSIGN_MSP(175) :: cplan.sql(8203) :: :
1TYPE_ID:
1SELECT PROJECT_ID, TYPE_ID INTO h_project_id, h_type_id:n            FROM TMT+
1_WBS WHERE ELEMENT_ID = h_task_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
1194:
1           EXCEPTION:: SP_ASSIGN_MSP(195) :: cplan.sql(8223) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1COUNT:
1DUAL:
1PROFILES:
1PROFILE_ID:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL:n            WHERE EXISTS (SELECT+
1 'X' FROM PROFILES:n            WHERE PROJECT_ID = h_project_id AND PROFILE_I+
1D = h_resource_id):
1212:
1           EXCEPTION:: SP_ASSIGN_MSP(213) :: cplan.sql(8241) :: :
1!=:
1221:
1        RETURN_ERROR:: SP_ASSIGN_MSP(222) :: cplan.sql(8250) :: :
1 ID:: :
1224:
1                EXIT:: SP_ASSIGN_MSP(225) :: cplan.sql(8253) :: :
1PMO_RETURN_ERROR_SP:
1SYS_GUID:
1GETTABLE:
1ASSIGNRESOURCE:
1ISWBSDELIV:
1TASK_ID:
1RESOURCE_ID:
1WORK_TODATE:
1PROJECT_ASSIGNMENT_ID:
1UNITS_MSP:
1C_EFFORT:
1C_CONTOUR:
1CONTOUR_TYPE:
1TASK_ASSIGNMENTS:
1SELECT PROJECT_ID, TASK_ID, RESOURCE_ID, WORK_TODATE, PROJECT_ASSIGNMENT_ID,+
1:n            UNITS_MSP, C_EFFORT, C_CONTOUR, CONTOUR_TYPE, REC_DATETIME:n   +
1         INTO h_project_id, h_task_id, h_resource_id, h_work_todate, h_prj_as+
1signment_id,:n            h_percent_units, h_work, h_contour, h_contour_type,+
1 h_rec_DT:n            FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_ra_i+
1d:
1256:
1           EXCEPTION:: SP_ASSIGN_MSP(257) :: cplan.sql(8285) :: :
1SC_SQL_SUCCESS:
1267:
1        RETURN_ERROR:: SP_ASSIGN_MSP(268) :: cplan.sql(8296) :: :
1270:
1                EXIT:: SP_ASSIGN_MSP(271) :: cplan.sql(8299) :: :
1280:
1        RETURN_ERROR:: SP_ASSIGN_MSP(281) :: cplan.sql(8309) :: :
1283:
1                EXIT:: SP_ASSIGN_MSP(284) :: cplan.sql(8312) :: :
1292:
1      RETURN_INVALID:: SP_ASSIGN_MSP(293) :: cplan.sql(8321) :: :
1295:
1                EXIT:: SP_ASSIGN_MSP(296) :: cplan.sql(8324) :: :
1SC_BIT_28:
1103079040:
1MINUTE_PER_DAY:
1SELECT COALESCE(MINUTE_PER_DAY, 480) INTO h_per_day FROM TMT_WBS WHERE ELEMEN+
1T_ID = h_task_id:
1320:
1           EXCEPTION:: SP_ASSIGN_MSP(321) :: cplan.sql(8349) :: :
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000:
10.49:
1BITAND:
1FC_U_TSKRES2:
1ETC:
1PROPOSED_START:
1SCHED_START:
1PROPOSED_FINISH:
1SCHED_FINISH:
1PROPOSED_WORK:
1SCHED_WORK:
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                        PROPOSED_STA+
1RT = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n +
1                       WHERE PROJECT_ID = h_project_id AND TASK_ID = h_task_i+
1d AND RESOURCE_ID = h_resource_id:
1FOUND:
1100:
1391:
1           EXCEPTION:: SP_ASSIGN_MSP(392) :: cplan.sql(8420) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                        PROPOSED_STA+
1RT = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n +
1                       WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1429:
1           EXCEPTION:: SP_ASSIGN_MSP(430) :: cplan.sql(8458) :: :
1MILESTONE_PERCENT:
1ACTUAL_START:
1ACTUAL_FINISH:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1              UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n          +
1           PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOS+
1ED_WORK = SCHED_WORK,:n                     ACTUAL_START = h_start_DT, ACTUAL+
1_FINISH = h_finish_DT,:n                     WORK_TODATE = work_todate001,:n +
1                    ETC = eetc:n                     WHERE TSK_ASSIGNMENT_ID +
1= h_ra_id:
1466:
1           EXCEPTION:: SP_ASSIGN_MSP(467) :: cplan.sql(8495) :: :
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = SCHED_MIN, ACTUAL_FLAG = 1:n        +
1             WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_ra_id:
1486:
1           EXCEPTION:: SP_ASSIGN_MSP(487) :: cplan.sql(8515) :: :
1LAST_SUBMITTED:
1UPDATE TASK_ASSIGNMENTS SET LAST_SUBMITTED = h_finish_DT:n                   +
1  WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1506:
1           EXCEPTION:: SP_ASSIGN_MSP(507) :: cplan.sql(8535) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                     PROPOSED_START +
1= SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n    +
1                 WHERE TSK_ASSIGNMENT_ID = h_ra_id:
1527:
1           EXCEPTION:: SP_ASSIGN_MSP(528) :: cplan.sql(8556) :: :
1SC_NOT_32:
1UPDATE TASK_ASSIGNMENTS SET ETC = eetc,:n                     PROPOSED_START +
1= SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSED_WORK = SCHED_WORK:n    +
1                 WHERE PROJECT_ID = h_project_id AND TASK_ID = h_task_id AND +
1RESOURCE_ID = h_resource_id:
1560:
1           EXCEPTION:: SP_ASSIGN_MSP(561) :: cplan.sql(8589) :: :
1IS NOT NULL:
1SELECT SUBSTR(h_lock_DT,1,10) || '-' || SUBSTR(h_lock_DT,12,2) || '.' || SUBS+
1TR(h_lock_DT,15,2) || '.' || SUBSTR(h_lock_DT,18,9) INTO h_lock_DT FROM DUAL:
1582:
1           EXCEPTION:: SP_ASSIGN_MSP(583) :: cplan.sql(8611) :: :
1PMO_ORASTD:
1STRNCMP:
119:
1SC_TASK:
1TMT_WORKFLOW_CYCLES:
1PARENT_ID:
1SELECT ELEMENT_ID INTO h_wkf_def_id:n                        FROM TMT_WORKFLO+
1W_CYCLES:n                        WHERE PARENT_ID = 'NOTIFICATION':
1603:
1           EXCEPTION:: SP_ASSIGN_MSP(604) :: cplan.sql(8632) :: :
1FC_A_NOTIFICATION:
1OPEN:
1CLOSE:
1637:
1           EXCEPTION:: SP_ASSIGN_MSP(638) :: cplan.sql(8666) :: :
1FULL_NAME:
1RESOURCES:
1SELECT FULL_NAME INTO h_full_name FROM RESOURCES:n                           +
1WHERE RESOURCE_ID = h_resource_id:
1653:
1           EXCEPTION:: SP_ASSIGN_MSP(654) :: cplan.sql(8682) :: :
1Import of assignment failed.:
1Import cannot modify assignment for resource:: :
1 on the task:::
1. Assignment was modified in Timesheets during the time of export of the proj+
1ect.:
1FC_U_WORKFLOW:
1674:
1        RETURN_ERROR:: SP_ASSIGN_MSP(675) :: cplan.sql(8703) :: :
1677:
1                EXIT:: SP_ASSIGN_MSP(678) :: cplan.sql(8706) :: :
1709:
1           EXCEPTION:: SP_ASSIGN_MSP(710) :: cplan.sql(8738) :: :
1720:
1        RETURN_ERROR:: SP_ASSIGN_MSP(721) :: cplan.sql(8749) :: :
1723:
1                EXIT:: SP_ASSIGN_MSP(724) :: cplan.sql(8752) :: :
1RES_ASSIGNMENT_ID:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,+
1PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actual_st+
1art001,:n                        ACTUAL_FINISH = actual_finish001,:n         +
1               WORK_TODATE = actual_effort001:n                        WHERE +
1RES_ASSIGNMENT_ID = h_ra_id:
1758:
1           EXCEPTION:: SP_ASSIGN_MSP(759) :: cplan.sql(8787) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units,:n                        CONTOUR_TYPE =+
1 h_contour_type:n                        WHERE RES_ASSIGNMENT_ID = h_ra_id:
1780:
1           EXCEPTION:: SP_ASSIGN_MSP(781) :: cplan.sql(8809) :: :
1BASELINE3_START:
1BASELINE3_SCH_FLAG:
1TO_TIMESTAMP:
1BASELINE3_FINISH:
1BASELINE3_DURATION:
1BASELINE3_WORK:
1BASELINE2_START:
1BASELINE1_START:
1BASELINE2_FINISH:
1BASELINE1_FINISH:
1BASELINE2_DURATION:
1BASELINE1_DURATION:
1BASELINE2_WORK:
1BASELINE1_WORK:
1BASELINE1_LABOR_COST:
1REGULAR_COST:
1BASELINE1_LABOR_REVENUE:
1BILLABLE:
1REGULAR_RATE:
1B_REGULAR_COST:
1B_REGULAR_RATE:
1B_SPECIAL_COST:
1SPECIAL_COST:
1B_SPECIAL_RATE:
1SPECIAL_RATE:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        BASELINE1_LABOR_COST = (baseline_work001/60.0) * +
1REGULAR_COST,:n                        BASELINE1_LABOR_REVENUE = CASE WHEN BI+
1LLABLE > 0 THEN ((baseline_work001/60.0) * REGULAR_RATE) ELSE 0 END,:n       +
1                 B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = REGULAR_RATE+
1, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n            +
1            :n                        BASELINE3_SCH_FLAG = 1,:n              +
1          PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSE+
1D_WORK = SCHED_WORK,:n                        ACTUAL_START = actual_start001,+
1:n                        ACTUAL_FINISH = actual_finish001,:n                +
1        WORK_TODATE = actual_effort001:n                        WHERE RES_ASS+
1IGNMENT_ID = h_ra_id:
1827:
1           EXCEPTION:: SP_ASSIGN_MSP(828) :: cplan.sql(8856) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        BASELINE1_LABOR_COST = (baseline_work001/60.0) * +
1REGULAR_COST,:n                        BASELINE1_LABOR_REVENUE = CASE WHEN BI+
1LLABLE > 0 THEN ((baseline_work001/60.0) * REGULAR_RATE) ELSE 0 END,:n       +
1                 B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = REGULAR_RATE+
1, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n            +
1            :n                        BASELINE3_SCH_FLAG = 1:n               +
1         WHERE RES_ASSIGNMENT_ID = h_ra_id:
1868:
1           EXCEPTION:: SP_ASSIGN_MSP(869) :: cplan.sql(8897) :: :
1ELSIF:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1           UNITS_MSP = h_units,:n                  CONTOUR_TYPE = h_contour_t+
1ype:n                  WHERE RES_ASSIGNMENT_ID = h_ra_id:
1892:
1           EXCEPTION:: SP_ASSIGN_MSP(893) :: cplan.sql(8921) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,+
1PROPOSED_WORK = SCHED_WORK,:n                        ACTUAL_START = actual_st+
1art001,:n                        ACTUAL_FINISH = actual_finish001,:n         +
1               WORK_TODATE = actual_effort001:n                        WHERE +
1TSK_ASSIGNMENT_ID = h_ra_id:
1922:
1           EXCEPTION:: SP_ASSIGN_MSP(923) :: cplan.sql(8951) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001:n                        WHERE +
1TSK_ASSIGNMENT_ID = h_ra_id:
1944:
1           EXCEPTION:: SP_ASSIGN_MSP(945) :: cplan.sql(8973) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 BASELINE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_T+
1IMESTAMP(baseline_start001) ELSE BASELINE3_START END,:n                      +
1  BASELINE3_FINISH = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(basel+
1ine_finish001) ELSE BASELINE3_FINISH END,:n                        BASELINE3_+
1DURATION = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BA+
1SELINE3_DURATION END,:n                        BASELINE3_WORK = CASE WHEN BAS+
1ELINE3_SCH_FLAG = 0 THEN baseline_work001 ELSE BASELINE3_WORK END,:n         +
1               :n                        BASELINE2_START = BASELINE1_START,:n+
1                        BASELINE2_FINISH = BASELINE1_FINISH,:n               +
1         BASELINE2_DURATION = BASELINE1_DURATION,:n                        BA+
1SELINE2_WORK = BASELINE1_WORK,:n                        :n                   +
1     BASELINE1_START = baseline_start001,:n                        BASELINE1_+
1FINISH = baseline_finish001,:n                        BASELINE1_DURATION = ba+
1seline_duration001,:n                        BASELINE1_WORK = baseline_work00+
11,:n                        BASELINE1_LABOR_COST = (baseline_work001/60.0) * +
1REGULAR_COST,:n                        BASELINE1_LABOR_REVENUE = CASE WHEN BI+
1LLABLE > 0 THEN ((baseline_work001/60.0) * REGULAR_RATE) ELSE 0 END,:n       +
1                 B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = REGULAR_RATE+
1, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n            +
1            :n                        BASELINE3_SCH_FLAG = 1,:n              +
1          PROPOSED_START = SCHED_START,PROPOSED_FINISH = SCHED_FINISH,PROPOSE+
1D_WORK = SCHED_WORK,:n                        ACTUAL_START = actual_start001,+
1:n                        ACTUAL_FINISH = actual_finish001,:n                +
1        WORK_TODATE = actual_effort001:n                        WHERE TSK_ASS+
1IGNMENT_ID = h_ra_id:
1991:
1           EXCEPTION:: SP_ASSIGN_MSP(992) :: cplan.sql(9020) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001,:n                        BASEL+
1INE3_START = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(baseline_star+
1t001) ELSE BASELINE3_START END,:n                        BASELINE3_FINISH = C+
1ASE WHEN BASELINE3_SCH_FLAG = 0 THEN TO_TIMESTAMP(baseline_finish001) ELSE BA+
1SELINE3_FINISH END,:n                        BASELINE3_DURATION = CASE WHEN B+
1ASELINE3_SCH_FLAG = 0 THEN baseline_duration001 ELSE BASELINE3_DURATION END,+
1:n                        BASELINE3_WORK = CASE WHEN BASELINE3_SCH_FLAG = 0 T+
1HEN baseline_work001 ELSE BASELINE3_WORK END,:n                        :n    +
1                    BASELINE2_START = BASELINE1_START,:n                     +
1   BASELINE2_FINISH = BASELINE1_FINISH,:n                        BASELINE2_DU+
1RATION = BASELINE1_DURATION,:n                        BASELINE2_WORK = BASELI+
1NE1_WORK,:n                        :n                        BASELINE1_START +
1= baseline_start001,:n                        BASELINE1_FINISH = baseline_fin+
1ish001,:n                        BASELINE1_DURATION = baseline_duration001,:n+
1                        BASELINE1_WORK = baseline_work001,:n                 +
1       BASELINE1_LABOR_COST = (baseline_work001/60.0) * REGULAR_COST,:n      +
1                  BASELINE1_LABOR_REVENUE = CASE WHEN BILLABLE > 0 THEN ((bas+
1eline_work001/60.0) * REGULAR_RATE) ELSE 0 END,:n                        B_RE+
1GULAR_COST = REGULAR_COST, B_REGULAR_RATE = REGULAR_RATE, B_SPECIAL_COST = SP+
1ECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE,:n                        :n       +
1                 BASELINE3_SCH_FLAG = 1:n                        WHERE TSK_AS+
1SIGNMENT_ID = h_ra_id:
11032:
1           EXCEPTION:: SP_ASSIGN_MSP(1033) :: cplan.sql(9061) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1                 UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n       +
1                 WORK_TODATE = work_todate001,:n                        ETC =+
1 h_effort - work_todate001:n                        WHERE TSK_ASSIGNMENT_ID =+
1 h_ra_id:
11059:
1           EXCEPTION:: SP_ASSIGN_MSP(1060) :: cplan.sql(9088) :: :
11081:
1           EXCEPTION:: SP_ASSIGN_MSP(1082) :: cplan.sql(9110) :: :
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = percent_complete001,:n       +
1              UNITS_MSP = h_units, CONTOUR_TYPE = h_contour_type,:n          +
1           WORK_TODATE = work_todate001:n                     WHERE TSK_ASSIG+
1NMENT_ID = h_ra_id:
11104:
1           EXCEPTION:: SP_ASSIGN_MSP(1105) :: cplan.sql(9133) :: :
1:
1TO_DATE:
1CAPITAL_EXPENSE:
1SELECT TSK_ASSIGNMENT_ID, SCHED_WORK, TASK_ID, TO_DATE(SubStr(SCHED_START, 1,+
1 10)), TO_DATE(SubStr(SCHED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGUL+
1AR_COST, REGULAR_RATE:n                  INTO h_tsk_assignment_id, h_effort, +
1h_task_id, h_SD, h_FD, h_billable, h_capital_expense, h_reg_cost, h_reg_sale+
1:n                  FROM TASK_ASSIGNMENTS:n                  WHERE RES_ASSIGN+
1MENT_ID = h_ra_id:
11135:
1           EXCEPTION:: SP_ASSIGN_MSP(1136) :: cplan.sql(9164) :: :
1SELECT SCHED_WORK, TASK_ID, TO_DATE(SubStr(SCHED_START, 1, 10)), TO_DATE(SubS+
1tr(SCHED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RA+
1TE:n                  INTO h_effort, h_task_id, h_SD, h_FD, h_billable, h_cap+
1ital_expense, h_reg_cost, h_reg_sale:n                  FROM TASK_ASSIGNMENTS+
1:n                  WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11154:
1           EXCEPTION:: SP_ASSIGN_MSP(1155) :: cplan.sql(9183) :: :
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = SCHED_MIN, ACTUAL_FLAG = 1:n        +
1             WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_as+
1signment_id:
11179:
1           EXCEPTION:: SP_ASSIGN_MSP(1180) :: cplan.sql(9208) :: :
1MAX:
1UPDATE TASK_ASSIGNMENTS SET WORK_TODATE = SCHED_WORK,:n                     L+
1AST_SUBMITTED = (SELECT MAX(DAY_YEAR) FROM TASK_DAY_OF_YEAR:n                +
1     WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id):n                     WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11201:
1           EXCEPTION:: SP_ASSIGN_MSP(1202) :: cplan.sql(9230) :: :
1LOOP:
1EXIT:
1>=:
1-:
1UPDATE TASK_DAY_OF_YEAR SET ACTUAL_MIN = h_minutes, ACTUAL_FLAG = 1 WHERE CUR+
1RENT OF CAF:
11245:
1           EXCEPTION:: SP_ASSIGN_MSP(1246) :: cplan.sql(9274) :: :
11268:
1           EXCEPTION:: SP_ASSIGN_MSP(1269) :: cplan.sql(9297) :: :
1UPDATE TASK_ASSIGNMENTS SET LAST_SUBMITTED = h_finish_D WHERE TSK_ASSIGNMENT_+
1ID = h_tsk_assignment_id:
11289:
1           EXCEPTION:: SP_ASSIGN_MSP(1290) :: cplan.sql(9318) :: :
1FC_GENERATE_TS_ALL:
1FC_GENERATE_TS_MSP:
14:
11316:
1       RETURN_STATUS:: SP_ASSIGN_MSP(1317) :: cplan.sql(9345) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
11324:
1           EXCEPTION:: SP_ASSIGN_MSP(1325) :: cplan.sql(9353) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11336:
1           EXCEPTION:: SP_ASSIGN_MSP(1337) :: cplan.sql(9365) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
1e78
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a0 f4 b4 bf c8 :e a0
12a bd b7 11 a4 b1 a0 f4
b4 bf c8 :a a0 12a bd b7 11
a4 b1 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 7e
b4 2e :2 5a :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 5a
52 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a 52 10
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c a0 4d d a0 4d d a0
51 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d a0 51
d :3 a0 a5 b 51 a5 b a0
7e a0 6b b4 2e :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 a0 7e b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b a0 a5 57 b7 19 3c
:2 a0 d :2 a0 d :2 a0 d :7 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 51 d :8 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :2 a0 51 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b 51 :2 a0
a5 57 b7 :2 a0 b4 2e d :4 a0
51 a5 b a5 b d :8 a0 a5
b d :2 a0 51 a5 b 7e 51
b4 2e 5a :3 a0 51 a5 b a5
b 5a 7e 51 b4 2e a 10
a0 51 d b7 19 3c b7 :2 19
3c b7 :2 a0 d :17 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e 5a a 10 :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :2 a0 51 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
51 :2 a0 a5 57 b7 19 3c b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c a0 7e b4 2e 5a a0
7e b4 2e 5a 52 10 a0 7e
b4 2e 5a 52 10 a0 7e b4
2e 5a 52 10 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
a0 a5 57 b7 19 3c :3 a0 6b
d :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 19 3c :6 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :5 a0 a5 b 51 a5 b 7e
:3 a0 a5 b 51 a5 b b4 2e
5a 7e 51 b4 2e 5a 7e 51
b4 2e a5 b d :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e a0 51 d a0 51 d b7
a0 51 d b7 :2 19 3c b7 19
3c a0 4d d :3 a0 51 a5 b
51 a5 b 5a 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b :12 a0 a5 b d :2 a0 6b
7e 51 b4 2e :f a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
:2 a0 6b :12 a0 a5 b d b7 :2 19
3c b7 :3 a0 51 a5 b 7e 51
b4 2e d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :12 a0 a5 b
d :2 a0 6b 7e 51 b4 2e :b a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c b7 :2 a0 6b :12 a0 a5 b
d b7 :2 19 3c b7 :2 19 3c :2 a0
6b 7e 51 b4 2e 5a :3 a0 51
a5 b 51 a5 b 5a 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:17 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:5 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 19 3c b7
:4 a0 51 a5 b :2 a0 6b a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :12 a0 a5 b d :2 a0
6b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :f a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
a0 7e b4 2e 5a :2 a0 d :a a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e :3 a0 6b d a0 51
d :4 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :8 a0 a5 b d :2 a0
51 a5 b 7e 51 b4 2e a0
4d d a0 4d d a0 4d d
a0 4d d a0 4d d :2 a0 e9
dd b3 :3 a0 e9 d3 5 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 6e d a0 6e d :3 a0
7e a0 b4 2e :2 51 a5 b d
:3 a0 7e 6e b4 2e :2 51 a5 b
d :3 a0 7e a0 b4 2e :2 51 a5
b d :3 a0 7e 6e b4 2e :2 51
a5 b d :11 a0 a5 b d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :2 a0 51
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b 51 :2 a0 a5 57 b7 19 3c
b7 19 3c b7 19 3c :3 a0 51
a5 b 7e 51 b4 2e d :2 a0
6b :12 a0 a5 b d :2 a0 6b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 :2 19 3c
b7 :2 19 3c :2 a0 6b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :2 a0 d :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 a0 51 d b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b 51 a5 b 5a 7e
51 b4 2e a0 7e b4 2e 5a
a0 7e b4 2e 5a :15 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 a0 7e b4 2e 5a :47 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:3b a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :3 a0 51 a5 b
51 a5 b 5a 7e 51 b4 2e
a0 7e b4 2e 5a a0 7e b4
2e 5a :15 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :b a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 a0
7e b4 2e 5a :47 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :3d a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :2 19 3c a0 b7 :2 a0 51 a5
b 7e 51 b4 2e a0 7e b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e :e a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :b a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :b a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :2 19 3c b7 :2 19 3c
a0 7e b4 2e 5a :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
5a :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 a0 6e d a0
4d d a0 51 d a0 51 d
:2 a0 51 a5 b 7e 51 b4 2e
:19 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 a0 d :17 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :8 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :d a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 a0
e9 dd b3 :5 a0 e9 d3 5 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c :2 a0 6b 7e
51 b4 2e a0 2b b7 19 3c
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e :3 a0 51 a5 b
d b7 :3 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e 7e :2 a0 51
a5 b b4 2e d b7 :2 19 3c
b7 19 3c :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 d b7 19 3c
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e a0 2b b7 19
3c b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
a0 7e b4 2e :2 5a a 10 :5 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b 51 a5 b 5a 7e 51 b4
2e :4 a0 a5 b d b7 :4 a0 a5
b d b7 :2 19 3c b7 19 3c
b7 19 3c b7 19 3c b7 19
3c :2 a0 6b 7e 51 b4 2e :2 a0
6b 51 d b7 19 3c b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 a0 6b
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e a5 57 b7 19 3c :9 a0 12a
e9 dd :2 a0 65 b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c :7 a0 12a e9 dd
:2 a0 65 b7 a4 b1 11 4f b7
a6 9 a4 b1 11 68 4f 1d
17 b5 
1e78
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 142
13e 114 14a 153 14f 13d 15b 168
164 13a 170 179 175 163 181 18e
18a 160 196 19f 19b 189 1a7 186
1ac 1b0 1b4 1b8 1bb 1bf 1dc 1c7
1cb 1ce 1cf 1d7 1c6 1f9 1e7 1c3
1eb 1ec 1f4 1e6 216 204 1e3 208
209 211 203 233 221 200 225 226
22e 220 250 23e 21d 242 243 24b
23d 26d 25b 23a 25f 260 268 25a
28a 278 257 27c 27d 285 277 2a7
295 274 299 29a 2a2 294 2c4 2b2
291 2b6 2b7 2bf 2b1 2e1 2cf 2ae
2d3 2d4 2dc 2ce 2fe 2ec 2cb 2f0
2f1 2f9 2eb 31b 309 2e8 30d 30e
316 308 338 326 305 32a 32b 333
325 355 343 322 347 348 350 342
371 360 364 33f 36c 35f 38d 37c
380 35c 388 37b 3a9 398 39c 378
3a4 397 3c5 3b4 3b8 394 3c0 3b3
3e1 3d0 3d4 3b0 3dc 3cf 3fd 3ec
3f0 3cc 3f8 3eb 419 408 40c 3e8
414 407 435 424 428 404 430 423
451 440 444 420 44c 43f 46d 45c
460 43c 468 45b 489 478 47c 458
484 477 4a5 494 498 474 4a0 493
4c1 4b0 4b4 490 4bc 4af 4dd 4cc
4d0 4ac 4d8 4cb 4f9 4e8 4ec 4c8
4f4 4e7 515 504 508 4e4 510 503
531 520 524 52c 500 549 538 53c
544 51f 566 554 51c 558 559 561
553 583 571 550 575 576 57e 570
5a0 58e 56d 592 593 59b 58d 5bc
5ab 5af 5b7 58a 5d4 5c3 5c7 5cf
5aa 5f0 5df 5e3 5eb 5a7 608 5f7
5fb 603 5de 624 613 617 61f 5db
63c 62b 62f 637 612 659 647 60f
64b 64c 654 646 675 664 668 643
670 663 691 680 684 660 68c 67f
6ad 69c 6a0 67c 6a8 69b 6c9 6b8
6bc 698 6c4 6b7 6e5 6d4 6d8 6b4
6e0 6d3 701 6f0 6f4 6d0 6fc 6ef
71d 70c 710 6ec 718 70b 739 728
72c 734 708 751 740 744 74c 727
76d 75c 760 724 768 75b 789 778
77c 758 784 777 7a5 794 798 774
7a0 793 7c1 7b0 7b4 790 7bc 7af
7dd 7cc 7d0 7ac 7d8 7cb 7f9 7e8
7ec 7c8 7f4 7e7 800 804 7e4 815
818 81c 820 824 828 82c 830 834
838 83c 840 844 848 84c 850 854
860 865 867 873 877 879 87d 88e
88f 892 896 89a 89e 8a2 8a6 8aa
8ae 8b2 8b6 8ba 8be 8ca 8cf 8d1
8dd 8e1 8ff 8e7 8eb 8ef 8f2 8fa
8e6 906 90a 8e3 90e 912 916 919
91e 91f 1 921 926 92a 92e 931
936 93a 93e 941 946 947 949 94e
951 955 956 95b 960 963 968 969
96e 971 975 976 97b 97e 983 984
989 98c 991 992 997 99a 99e 9a2
9a6 9a7 9a9 9ae 9af 9b1 9b2 9b7
9ba 9bf 9c0 9c5 9c8 9cd 9ce 9d3
9d6 9da 9db 9e0 9e3 9e8 9e9 9ee
9f1 9f6 9f7 9fc 9ff a04 a05 a0a
a0d a11 a12 a17 a1a a1f a20 a25
a28 a2d a2e a33 a36 a3b a3c a41
a44 a48 a49 a4e a51 a56 a57 a5c
a5f a64 a65 a6a a6d a71 a75 a79
a7a a7c a81 a82 a84 a85 a8a a8d
a92 a93 a98 a9b aa0 aa1 aa6 aa9
aad aae ab3 ab6 abb abc ac1 ac4
ac9 aca acf ad2 ad6 ada ade adf
ae1 ae6 ae7 ae9 aea aef af2 af7
af8 afd b00 b04 b08 b0c b0d b0f
b14 b15 b17 b18 b1d b20 b25 b26
b2b b2e b32 b36 b3a b3b b3d b42
b43 b45 b46 b4b b4e b53 b54 b59
b5c b60 b64 b68 b69 b6b b70 b71
b73 b74 b79 b7c b81 b82 b87 b8a
b8e b92 b96 b97 b99 b9e b9f ba1
ba2 ba7 baa baf bb0 bb5 bb8 bbc
bc0 bc4 bc5 bc7 bcc bcd bcf bd0
bd5 bd8 bdd bde be3 be6 beb bec
bf1 bf4 bf8 bf9 bfe c01 c06 c07
c0c c0f c14 c15 c1a c1d c22 c23
c28 c2b c2f c30 c35 c38 c3d c3e
c43 c46 c4b c4c c51 c54 c58 c5c
c60 c61 c63 c68 c69 c6b c6c c71
c74 c79 c7a c7f c82 c86 c8a c8e
c8f c91 c96 c97 c99 c9a c9f ca2
ca7 ca8 cad cb0 cb5 cb6 cbb cbe
cc2 cc3 cc8 ccb cd0 cd1 cd6 cd9
cde cdf ce4 ce7 cec ced cf2 cf5
cf9 cfa cff d02 d07 d08 d0d d10
d15 d16 d1b d1e d22 d26 d2a d2b
d2d d32 d33 d35 d36 d3b d3e d43
d44 d49 d4c d51 d52 d57 d5a d5e
d5f d64 d67 d6c d6d d72 d75 d7a
d7b d80 d81 d86 d88 d8c d8f d93
d97 d9a d9e da2 da5 da8 dad db0
db3 db6 db7 dbc dbd 1 dbf dc4
dc8 dcc dcf dd4 dd9 ddc de0 de1
de6 de7 dec dee df2 df5 df9 dfc
dfd e02 e05 e08 e0c e10 e13 e14
e16 e19 e1c e1d e22 e25 e29 e2d
e30 e31 e33 e36 e39 e3a e3f 1
e42 e47 1 e4a e4f e53 e57 e5a
e5e e62 e65 e68 e6d e70 e73 e76
e77 e7c e7d 1 e7f e84 e88 e8c
e8f e94 e99 e9c ea0 ea1 ea6 ea9
eae eaf eb4 eb7 ebc ebd ec2 ec5
ec9 ecd ed1 ed5 ed8 ed9 edb ee0
ee1 ee3 ee4 ee9 eea eef ef1 ef5
ef8 efc f00 f03 f07 f0b f0e f11
f16 f19 f1c f1f f20 f25 f26 1
f28 f2d f31 f35 f38 f3d f42 f45
f49 f4a f4f f50 f55 f57 f5b f5e
f62 f66 f69 f6d f71 f74 f78 f79
f7e f80 f84 f87 f8b f8e f8f f94
f97 f9a f9e fa1 fa2 fa7 faa 1
fad fb2 fb6 fb9 fba fbf fc2 1
fc5 fca fce fd2 fd5 fd9 fdd fe0
fe3 fe8 feb fee ff1 ff2 ff7 ff8
1 ffa fff 1003 1007 100a 100f 1014
1017 101b 101c 1021 1024 1029 102a 102f
1032 1037 1038 103d 1040 1044 1048 104c
1050 1053 1054 1056 105b 105c 105e 105f
1064 1065 106a 106c 1070 1073 1077 107b
107e 1082 1086 1089 108c 1091 1094 1097
109a 109b 10a0 10a1 1 10a3 10a8 10ac
10b0 10b3 10b8 10bd 10c0 10c4 10c5 10ca
10cb 10d0 10d2 10d6 10d9 10dd 10e1 10e4
10e8 10ec 10ef 10f3 10f4 10f9 10fb 10ff
1102 1106 1107 110b 110f 1110 1114 1118
111b 111f 1123 1127 112b 112f 1133 1137
113b 113f 1143 1147 114b 114f 1153 1157
115b 115f 1163 1167 116b 116f 1173 1177
117b 117f 1183 1187 118b 118f 1193 1197
119b 119e 11a2 11a6 11aa 11ae 11af 11b1
11b4 11b5 11b7 11bb 11be 11c2 11c5 11c6
11cb 11cf 11d3 11d6 11d7 11d9 11dc 11df
11e0 11e5 11e8 11ec 11f0 11f3 11f4 11f6
11f9 11fc 11fd 1202 1 1205 120a 120e
1211 1212 1217 121a 121e 1222 1225 1229
122d 1230 1233 1238 123b 123e 1241 1242
1247 1248 1 124a 124f 1253 1257 125a
125f 1264 1267 126b 126c 1271 1274 1279
127a 127f 1282 1287 1288 128d 1290 1294
1298 129c 12a0 12a3 12a4 12a6 12ab 12ac
12ae 12af 12b4 12b5 12ba 12bc 12c0 12c3
12c7 12cb 12ce 12d2 12d6 12d9 12dc 12e1
12e4 12e7 12ea 12eb 12f0 12f1 1 12f3
12f8 12fc 1300 1303 1308 130d 1310 1314
1315 131a 131b 1320 1322 1326 1329 132d
1331 1334 1338 133c 133f 1343 1344 1349
134b 134f 1352 1356 135a 135e 1362 1366
136a 136e 1372 1376 137a 137e 1382 1386
138a 138e 1392 139e 13a2 13a6 13a9 13ad
13b1 13b3 13b7 13bb 13bf 13c2 13c6 13ca
13cc 13cd 13d2 1 13d6 13da 13de 13e1
13e5 13e9 13ed 13f1 13f4 13f8 13fc 13ff
1402 1407 140a 140d 1410 1411 1416 1417
1 1419 141e 1422 1426 1429 142e 1433
1436 143a 143b 1440 1443 1448 1449 144e
1451 1456 1457 145c 145f 1463 1464 1469
146c 1471 1472 1477 147a 147e 1482 1485
1488 1489 148b 148c 1491 1492 1497 1499
149d 14a0 14a2 14a6 14a8 14b4 14b6 14b8
14b9 14be 14c2 14c4 14d0 14d2 14d6 14d9
14dd 14e1 14e5 14e9 14ed 14f1 14f5 14f9
14fd 1509 150d 1511 1514 1518 151c 151e
1522 1526 152a 152d 1531 1535 1537 1538
153d 1 1541 1545 1549 154c 1550 1554
1558 155c 155f 1563 1567 156a 156d 1572
1575 1578 157b 157c 1581 1582 1 1584
1589 158d 1591 1594 1599 159e 15a1 15a5
15a6 15ab 15ae 15b3 15b4 15b9 15bc 15c1
15c2 15c7 15ca 15ce 15cf 15d4 15d7 15dc
15dd 15e2 15e5 15e9 15ed 15f0 15f3 15f4
15f6 15f7 15fc 15fd 1602 1604 1608 160b
160d 1611 1613 161f 1621 1623 1624 1629
162d 162f 163b 163d 1641 1645 1648 1649
164b 164e 1651 1652 1657 165a 165e 1662
1665 1666 1668 166b 166e 166f 1674 1
1677 167c 1680 1684 1687 1688 168a 168d
1690 1691 1696 1 1699 169e 16a2 16a6
16a9 16ad 16b1 16b4 16b7 16bc 16bf 16c2
16c5 16c6 16cb 16cc 1 16ce 16d3 16d7
16db 16de 16e3 16e8 16eb 16ef 16f0 16f5
16f8 16fd 16fe 1703 1706 170b 170c 1711
1714 1718 171c 171f 1720 1722 1727 1728
172a 172b 1730 1733 1738 1739 173e 1741
1746 1747 174c 174f 1753 1754 1759 175c
1761 1762 1767 1768 176d 176f 1773 1776
177a 177e 1781 1785 1789 178c 178f 1794
1797 179a 179d 179e 17a3 17a4 1 17a6
17ab 17af 17b3 17b6 17bb 17c0 17c3 17c7
17c8 17cd 17ce 17d3 17d5 17d9 17dc 17e0
17e4 17e7 17ea 17ee 17f2 17f3 17f8 17fa
17fe 1802 1803 1808 180c 1810 1814 1818
181c 181f 1820 1822 1823 1825 1829 182d
1831 1835 1839 183d 1841 1845 1849 184a
184c 1850 1854 1858 185b 185c 185e 1861
1864 1865 186a 186d 1871 1875 1879 187c
187d 187f 1880 1882 1885 1888 188b 188c
1 1891 1896 189a 189d 18a1 18a3 18a7
18aa 18ac 18b0 18b4 18b7 18b9 18bd 18c1
18c5 18c9 18cd 18d1 18d5 18d9 18dd 18e1
18e5 18e9 18ed 18f1 18f5 18f9 18fd 1901
1905 1909 190d 1911 1915 1919 191d 1921
192d 1931 1935 1938 193c 1940 1942 1946
194a 194e 1951 1955 1959 195b 195c 1961
1 1965 1969 196d 1970 1974 1978 197c
1980 1983 1987 198b 198e 1991 1996 1999
199c 199f 19a0 19a5 19a6 1 19a8 19ad
19b1 19b5 19b8 19bd 19c2 19c5 19c9 19ca
19cf 19d2 19d7 19d8 19dd 19e0 19e5 19e6
19eb 19ee 19f2 19f3 19f8 19fb 1a00 1a01
1a06 1a09 1a0d 1a11 1a14 1a17 1a18 1a1a
1a1b 1a20 1a21 1a26 1a28 1a2c 1a2f 1a31
1a35 1a37 1a43 1a45 1a47 1a48 1a4d 1a51
1a53 1a5f 1a61 1a65 1a69 1a6c 1a70 1a73
1a77 1a7a 1a7b 1a80 1a83 1a87 1a8b 1a8e
1a8f 1a91 1a95 1a98 1a9c 1a9f 1aa0 1aa2
1aa3 1aa8 1 1aab 1ab0 1ab4 1ab8 1abb
1abf 1ac3 1ac6 1ac9 1ace 1ad1 1ad4 1ad7
1ad8 1add 1ade 1 1ae0 1ae5 1ae9 1aed
1af0 1af5 1afa 1afd 1b01 1b02 1b07 1b0a
1b0f 1b10 1b15 1b18 1b1d 1b1e 1b23 1b26
1b2a 1b2e 1b31 1b32 1b34 1b39 1b3a 1b3c
1b3d 1b42 1b45 1b4a 1b4b 1b50 1b53 1b58
1b59 1b5e 1b61 1b65 1b66 1b6b 1b6e 1b73
1b74 1b79 1b7a 1b7f 1b81 1b85 1b88 1b8c
1b90 1b93 1b97 1b9b 1b9e 1ba1 1ba6 1ba9
1bac 1baf 1bb0 1bb5 1bb6 1 1bb8 1bbd
1bc1 1bc5 1bc8 1bcd 1bd2 1bd5 1bd9 1bda
1bdf 1be0 1be5 1be7 1beb 1bee 1bf2 1bf6
1bf9 1bfc 1c00 1c04 1c05 1c0a 1c0c 1c10
1c13 1c15 1c19 1c1d 1c20 1c24 1c28 1c2b
1c2c 1c2e 1c31 1c34 1c35 1c3a 1c3e 1c42
1c45 1c48 1c4b 1c4c 1c51 1c55 1c59 1c5c
1c60 1c64 1c67 1c6a 1c6f 1c72 1c75 1c78
1c79 1c7e 1c7f 1 1c81 1c86 1c8a 1c8e
1c91 1c96 1c9b 1c9e 1ca2 1ca3 1ca8 1cab
1cb0 1cb1 1cb6 1cb9 1cbe 1cbf 1cc4 1cc7
1ccb 1ccf 1cd3 1cd7 1cda 1cdb 1cdd 1ce2
1ce3 1ce5 1ce6 1ceb 1cee 1cf3 1cf4 1cf9
1cfc 1d01 1d02 1d07 1d0a 1d0e 1d0f 1d14
1d17 1d1c 1d1d 1d22 1d23 1d28 1d2a 1d2e
1d31 1d35 1d39 1d3c 1d40 1d44 1d47 1d4a
1d4f 1d52 1d55 1d58 1d59 1d5e 1d5f 1
1d61 1d66 1d6a 1d6e 1d71 1d76 1d7b 1d7e
1d82 1d83 1d88 1d89 1d8e 1d90 1d94 1d97
1d9b 1d9f 1da2 1da6 1daa 1dad 1db1 1db5
1db6 1dbb 1dbd 1dc1 1dc4 1dc8 1dcb 1dcc
1dd1 1dd4 1dd8 1ddb 1ddc 1de1 1 1de4
1de9 1ded 1df0 1df1 1df6 1 1df9 1dfe
1e02 1e05 1e06 1e0b 1 1e0e 1e13 1e17
1e1b 1e1e 1e22 1e26 1e29 1e2c 1e31 1e34
1e37 1e3a 1e3b 1e40 1e41 1 1e43 1e48
1e4c 1e50 1e53 1e58 1e5d 1e60 1e64 1e65
1e6a 1e6d 1e72 1e73 1e78 1e7b 1e80 1e81
1e86 1e89 1e8d 1e91 1e95 1e99 1e9c 1e9d
1e9f 1ea4 1ea5 1ea7 1ea8 1ead 1eae 1eb3
1eb5 1eb9 1ebc 1ec0 1ec4 1ec7 1ecb 1ecf
1ed2 1ed5 1eda 1edd 1ee0 1ee3 1ee4 1ee9
1eea 1 1eec 1ef1 1ef5 1ef9 1efc 1f01
1f06 1f09 1f0d 1f0e 1f13 1f14 1f19 1f1b
1f1f 1f22 1f26 1f2a 1f2d 1f31 1f35 1f38
1f3c 1f3d 1f42 1f44 1f48 1f4b 1f4f 1f53
1f57 1f5a 1f5e 1f62 1f66 1f69 1f6a 1f6c
1f6f 1f72 1f73 1f78 1f7c 1f7f 1f83 1f85
1f89 1f8c 1f90 1f94 1f98 1f9c 1fa0 1fa4
1fb0 1fb4 1fb8 1fbb 1fbf 1fc3 1fc5 1fc9
1fcd 1fd1 1fd4 1fd8 1fdc 1fde 1fdf 1fe4
1 1fe8 1fec 1ff0 1ff3 1ff7 1ffb 1fff
2003 2006 200a 200e 2011 2014 2019 201c
201f 2022 2023 2028 2029 1 202b 2030
2034 2038 203b 2040 2045 2048 204c 204d
2052 2055 205a 205b 2060 2063 2068 2069
206e 2071 2075 2076 207b 207e 2083 2084
2089 208c 2090 2094 2097 209a 209b 209d
209e 20a3 20a4 20a9 20ab 20af 20b2 20b4
20b8 20ba 20c6 20c8 20ca 20cb 20d0 20d4
20d6 20e2 20e4 20e8 20ec 20ef 20f0 20f2
20f5 20f8 20f9 20fe 2102 2106 210a 210e
2112 2113 2115 2118 2119 211b 211e 2122
2126 212a 212b 212d 2130 2131 2133 2134
2139 213c 213f 2142 2143 2148 214b 214e
2151 2152 2157 2158 215a 215e 2162 2166
2169 216a 216c 2170 2173 2177 217a 217b
217d 217e 2183 2187 218a 218e 2192 2195
2199 219b 219f 21a2 21a6 21a8 21ac 21b0
21b3 21b5 21b9 21bc 21c0 21c1 21c5 21c9
21cd 21d1 21d4 21d5 21d7 21da 21db 21dd
21e0 21e3 21e6 21e7 21ec 21f0 21f4 21f7
21f8 21fa 21fd 2200 2201 2206 220a 220e
2211 2212 2214 2217 221a 221b 2220 2224
2228 222b 222f 2233 2237 223b 223f 2243
2247 224b 224f 2253 2257 225b 225f 2263
2267 226b 226f 2273 2274 2276 227a 227e
2282 2285 2288 228b 228c 2291 2295 2299
229d 22a1 22a5 22a9 22ad 22b1 22b5 22b9
22bd 22c1 22c5 22c9 22cd 22d9 22dd 22e2
22e6 22e9 22ea 22ef 22f3 22f7 22fa 22fd
2301 2303 2307 230b 230e 2311 2315 2317
231b 231f 2322 2324 2328 232c 2330 2333
2337 233b 233d 233e 2343 1 2347 234b
234f 2352 2356 235a 235e 2362 2365 2369
236d 2370 2373 2378 237b 237e 2381 2382
2387 2388 1 238a 238f 2393 2397 239a
239f 23a4 23a7 23ab 23ac 23b1 23b4 23b9
23ba 23bf 23c2 23c7 23c8 23cd 23d0 23d4
23d5 23da 23dd 23e2 23e3 23e8 23eb 23ef
23f3 23f6 23f9 23fa 23fc 23fd 2402 2403
2408 240a 240e 2411 2413 2417 2419 2425
2427 2429 242a 242f 2433 2435 2441 2443
2445 2449 244c 244e 2452 2456 2459 245d
2461 2465 2469 246d 2471 2475 2479 247d
2481 2485 2489 248d 2491 2495 2499 249d
24a1 24a2 24a4 24a8 24aa 24ae 24b2 24b5
24b7 24bb 24bf 24c3 24c6 24c7 24c9 24cc
24cf 24d0 24d5 24d9 24dd 24e1 24e4 24e5
24e7 24ea 24ed 24ee 24f3 24f7 24fb 24fe
2502 2506 250a 250e 2512 2516 251a 251e
2522 2526 252a 252e 2532 2536 253a 253e
2542 2546 2547 2549 254d 2551 2555 2558
255b 255e 255f 2564 2568 256c 2570 2574
2578 257c 2580 2584 2588 258c 2590 259c
25a0 25a5 25a9 25ac 25ad 25b2 25b6 25ba
25bd 25c0 25c4 25c6 25ca 25ce 25d1 25d4
25d8 25da 25de 25e2 25e5 25e7 25eb 25ef
25f3 25f6 25fa 25fe 2600 2601 2606 1
260a 260e 2612 2615 2619 261d 2621 2625
2628 262c 2630 2633 2636 263b 263e 2641
2644 2645 264a 264b 1 264d 2652 2656
265a 265d 2662 2667 266a 266e 266f 2674
2677 267c 267d 2682 2685 268a 268b 2690
2693 2697 2698 269d 26a0 26a5 26a6 26ab
26ae 26b2 26b6 26b9 26bc 26bd 26bf 26c0
26c5 26c6 26cb 26cd 26d1 26d4 26d6 26da
26dc 26e8 26ea 26ec 26ed 26f2 26f6 26f8
2704 2706 2708 270c 270f 2711 2715 2719
271c 2720 2724 2728 272c 2730 2734 2738
273c 2740 2744 2748 274c 2750 2754 2758
275c 2760 2764 2765 2767 276b 276d 2771
2775 2778 277a 277e 2782 2785 2789 278d
2790 2793 2796 2797 279c 279f 27a3 27a7
27ab 27ae 27af 27b1 27b4 27b5 27b7 27ba
27bd 27c0 27c1 27c6 1 27c9 27ce 27d2
27d6 27d9 27da 27dc 27e0 27e3 27e7 27ea
27eb 27ed 27ee 27f3 27f6 27fa 27fe 2801
2802 2804 2807 280a 280b 2810 1 2813
2818 281c 2820 2823 2824 2826 2829 282c
282d 2832 1 2835 283a 283e 2842 2846
284a 284e 2852 2856 285a 285e 2862 2866
286a 286e 2872 2876 287a 287e 2882 2886
288a 288e 2892 2896 28a2 28a6 28ab 28af
28b2 28b3 28b8 28bc 28c0 28c3 28c6 28ca
28cc 28d0 28d4 28d7 28da 28de 28e0 28e4
28e8 28eb 28ed 28f1 28f5 28f9 28fc 2900
2904 2906 2907 290c 1 2910 2914 2918
291b 291f 2923 2927 292b 292e 2932 2936
2939 293c 2941 2944 2947 294a 294b 2950
2951 1 2953 2958 295c 2960 2963 2968
296d 2970 2974 2975 297a 297d 2982 2983
2988 298b 2990 2991 2996 2999 299d 299e
29a3 29a6 29ab 29ac 29b1 29b4 29b8 29bc
29bf 29c2 29c3 29c5 29c6 29cb 29cc 29d1
29d3 29d7 29da 29dc 29e0 29e2 29ee 29f0
29f2 29f3 29f8 29fc 29fe 2a0a 2a0c 2a10
2a14 2a18 2a1c 2a20 2a24 2a28 2a2c 2a38
2a3c 2a41 2a45 2a48 2a49 2a4e 2a52 2a56
2a59 2a5c 2a60 2a62 2a66 2a6a 2a6d 2a70
2a74 2a76 2a7a 2a7e 2a81 2a83 2a87 2a8b
2a8f 2a92 2a96 2a9a 2a9c 2a9d 2aa2 1
2aa6 2aaa 2aae 2ab1 2ab5 2ab9 2abd 2ac1
2ac4 2ac8 2acc 2acf 2ad2 2ad7 2ada 2add
2ae0 2ae1 2ae6 2ae7 1 2ae9 2aee 2af2
2af6 2af9 2afe 2b03 2b06 2b0a 2b0b 2b10
2b13 2b18 2b19 2b1e 2b21 2b26 2b27 2b2c
2b2f 2b33 2b34 2b39 2b3c 2b41 2b42 2b47
2b4a 2b4e 2b52 2b55 2b58 2b59 2b5b 2b5c
2b61 2b62 2b67 2b69 2b6d 2b70 2b72 2b76
2b78 2b84 2b86 2b88 2b89 2b8e 2b92 2b94
2ba0 2ba2 2ba6 2baa 2bae 2bb2 2bb6 2bc2
2bc6 2bcb 2bcf 2bd2 2bd3 2bd8 2bdc 2be0
2be3 2be6 2bea 2bec 2bf0 2bf4 2bf7 2bfa
2bfe 2c00 2c04 2c08 2c0b 2c0d 2c11 2c15
2c19 2c1c 2c20 2c24 2c26 2c27 2c2c 1
2c30 2c34 2c38 2c3b 2c3f 2c43 2c47 2c4b
2c4e 2c52 2c56 2c59 2c5c 2c61 2c64 2c67
2c6a 2c6b 2c70 2c71 1 2c73 2c78 2c7c
2c80 2c83 2c88 2c8d 2c90 2c94 2c95 2c9a
2c9d 2ca2 2ca3 2ca8 2cab 2cb0 2cb1 2cb6
2cb9 2cbd 2cbe 2cc3 2cc6 2ccb 2ccc 2cd1
2cd4 2cd8 2cdc 2cdf 2ce2 2ce3 2ce5 2ce6
2ceb 2cec 2cf1 2cf3 2cf7 2cfa 2cfc 2d00
2d02 2d0e 2d10 2d12 2d13 2d18 2d1c 2d1e
2d2a 2d2c 2d2e 2d32 2d36 2d3a 2d3e 2d42
2d46 2d4a 2d4e 2d52 2d56 2d5a 2d66 2d6a
2d6f 2d73 2d76 2d77 2d7c 2d80 2d84 2d87
2d8a 2d8e 2d90 2d94 2d98 2d9b 2d9e 2da2
2da4 2da8 2dac 2daf 2db1 2db5 2db9 2dbd
2dc0 2dc4 2dc8 2dca 2dcb 2dd0 1 2dd4
2dd8 2ddc 2ddf 2de3 2de7 2deb 2def 2df2
2df6 2dfa 2dfd 2e00 2e05 2e08 2e0b 2e0e
2e0f 2e14 2e15 1 2e17 2e1c 2e20 2e24
2e27 2e2c 2e31 2e34 2e38 2e39 2e3e 2e41
2e46 2e47 2e4c 2e4f 2e54 2e55 2e5a 2e5d
2e61 2e62 2e67 2e6a 2e6f 2e70 2e75 2e78
2e7c 2e80 2e83 2e86 2e87 2e89 2e8a 2e8f
2e90 2e95 2e97 2e9b 2e9e 2ea0 2ea4 2ea6
2eb2 2eb4 2eb6 2eb7 2ebc 2ec0 2ec2 2ece
2ed0 2ed2 2ed6 2eda 2edd 2edf 2ee3 2ee6
2ee8 2eec 2ef0 2ef4 2ef8 2efb 2efc 2efe
2f02 2f06 2f09 2f0a 2f0c 2f10 2f14 2f18
2f1b 2f1c 2f1e 2f21 2f24 2f25 2f2a 2f2e
2f32 2f35 2f39 2f3d 2f41 2f45 2f49 2f4d
2f51 2f55 2f59 2f5d 2f61 2f65 2f69 2f6d
2f71 2f75 2f79 2f7d 2f7e 2f80 2f84 2f88
2f8c 2f8f 2f92 2f95 2f96 2f9b 2f9e 2fa2
2fa6 2fa9 2faa 2fac 2faf 2fb2 2fb3 2fb8
1 2fbb 2fc0 2fc4 2fc8 2fcb 2fcc 2fce
2fd1 2fd4 2fd5 2fda 1 2fdd 2fe2 2fe6
2fea 2fee 2ff2 2ff6 2ffa 2ffe 3002 3006
300a 300e 3012 3016 301a 301e 302a 302e
3033 3037 303a 303b 3040 3044 3048 304b
304e 3052 3054 3058 305c 305f 3062 3066
3068 306c 3070 3073 3075 3079 307d 3081
3084 3088 308c 308e 308f 3094 1 3098
309c 30a0 30a3 30a7 30ab 30af 30b3 30b6
30ba 30be 30c1 30c4 30c9 30cc 30cf 30d2
30d3 30d8 30d9 1 30db 30e0 30e4 30e8
30eb 30f0 30f5 30f8 30fc 30fd 3102 3105
310a 310b 3110 3113 3118 3119 311e 3121
3125 3126 312b 312e 3133 3134 3139 313c
3140 3144 3147 314a 314b 314d 314e 3153
3154 3159 315b 315f 3162 3164 3168 316a
3176 3178 317a 317b 3180 3184 3186 3192
3194 3196 319a 319d 319f 31a3 31a6 31a7
31ac 31af 31b3 31b7 31bb 31bf 31c3 31c7
31cb 31cf 31d3 31d7 31db 31df 31e3 31ef
31f3 31f7 31fa 31fe 3202 3204 3208 320c
3210 3213 3217 321b 321d 321e 3223 1
3227 322b 322f 3232 3236 323a 323e 3242
3245 3249 324d 3250 3253 3258 325b 325e
3261 3262 3267 3268 1 326a 326f 3273
3277 327a 327f 3284 3287 328b 328c 3291
3294 3299 329a 329f 32a2 32a7 32a8 32ad
32b0 32b4 32b5 32ba 32bd 32c2 32c3 32c8
32cb 32cf 32d3 32d6 32d9 32da 32dc 32dd
32e2 32e3 32e8 32ea 32ee 32f1 32f3 32f7
32f9 3305 3307 3309 330a 330f 3313 3315
3321 3323 3327 332b 332e 3332 3336 3339
333a 333c 333f 3342 3343 3348 334c 3350
3354 3357 335b 335f 3362 3366 336a 336e
3372 3376 3382 3386 338a 338d 3391 3395
3397 339b 339f 33a3 33a6 33aa 33ae 33b0
33b1 33b6 1 33ba 33be 33c2 33c5 33c9
33cd 33d1 33d5 33d8 33dc 33e0 33e3 33e6
33eb 33ee 33f1 33f4 33f5 33fa 33fb 1
33fd 3402 3406 340a 340d 3412 3417 341a
341e 341f 3424 3427 342c 342d 3432 3435
343a 343b 3440 3443 3447 3448 344d 3450
3455 3456 345b 345e 3462 3466 3469 346c
346d 346f 3470 3475 3476 347b 347d 3481
3484 3486 348a 348c 3498 349a 349c 349d
34a2 34a6 34a8 34b4 34b6 34ba 34be 34c2
34c6 34ca 34ce 34d2 34d6 34d7 34d9 34dd
34e1 34e5 34e8 34e9 34eb 34ee 34f1 34f2
34f7 34fb 34fc 3500 3504 3505 3509 350d
350e 3512 3516 3517 351b 351f 3520 3524
3528 352c 3531 3535 3536 353a 353e 3542
3547 354c 3550 3554 3558 355d 3561 3565
3568 356b 356f 3571 3575 3579 357c 357f
3583 3585 3589 358d 3590 3594 3598 359d
359f 35a3 35a7 35aa 35ae 35b2 35b4 35b8
35bc 35c0 35c3 35c7 35cb 35cd 35ce 35d3
1 35d7 35db 35df 35e2 35e6 35ea 35ee
35f2 35f5 35f9 35fd 3600 3603 3608 360b
360e 3611 3612 3617 3618 1 361a 361f
3623 3627 362a 362f 3634 3637 363b 363c
3641 3644 3649 364a 364f 3652 3657 3658
365d 3660 3664 3665 366a 366d 3672 3673
3678 367b 367f 3683 3686 3689 368a 368c
368d 3692 3693 3698 369a 369e 36a1 36a3
36a7 36a9 36b5 36b7 36b9 36ba 36bf 36c3
36c5 36d1 36d3 36d7 36db 36df 36e3 36e7
36f3 36f7 36fb 36fe 3702 3706 3708 370c
3710 3714 3717 371b 371f 3721 3722 3727
1 372b 372f 3733 3736 373a 373e 3742
3746 3749 374d 3751 3754 3757 375c 375f
3762 3765 3766 376b 376c 1 376e 3773
3777 377b 377e 3783 3788 378b 378f 3790
3795 3798 379d 379e 37a3 37a6 37ab 37ac
37b1 37b4 37b8 37b9 37be 37c1 37c6 37c7
37cc 37cf 37d3 37d7 37da 37dd 37de 37e0
37e1 37e6 37e7 37ec 37ee 37f2 37f5 37f7
37fb 37fd 3809 380b 380d 380e 3813 3817
3819 3825 3827 382b 3830 3834 3838 383d
3841 3845 3849 384d 3850 3854 3855 385a
385d 3860 3861 3863 3867 386b 386f 3873
3876 387b 387c 3881 3884 3887 3888 388a
388e 3892 3896 389a 389d 38a1 38a2 38a7
38aa 38ad 38ae 38b0 38b4 38b8 38bc 38c0
38c3 38c8 38c9 38ce 38d1 38d4 38d5 38d7
38db 38df 38e3 38e7 38eb 38ef 38f3 38f7
38fb 38ff 3903 3907 390b 390f 3913 3917
391b 391f 3920 3922 3926 392a 392e 3931
3935 3939 393c 393f 3944 3947 394a 394d
394e 3953 3954 1 3956 395b 395f 3963
3966 396b 3970 3973 3977 3978 397d 3980
3985 3986 398b 398e 3993 3994 3999 399c
39a0 39a4 39a7 39a8 39aa 39af 39b0 39b2
39b3 39b8 39bb 39c0 39c1 39c6 39c9 39ce
39cf 39d4 39d7 39db 39dc 39e1 39e4 39e9
39ea 39ef 39f0 39f5 39f7 39fb 39fe 3a02
3a06 3a09 3a0d 3a11 3a14 3a17 3a1c 3a1f
3a22 3a25 3a26 3a2b 3a2c 1 3a2e 3a33
3a37 3a3b 3a3e 3a43 3a48 3a4b 3a4f 3a50
3a55 3a56 3a5b 3a5d 3a61 3a64 3a68 3a6c
3a6f 3a72 3a76 3a7a 3a7b 3a80 3a82 3a86
3a89 3a8b 3a8f 3a92 3a94 3a98 3a9b 3a9f
3aa3 3aa7 3aaa 3aab 3aad 3ab0 3ab3 3ab4
3ab9 3abd 3ac1 3ac5 3ac8 3acc 3ad0 3ad4
3ad8 3adc 3ae0 3ae4 3ae8 3aec 3af0 3af4
3af8 3afc 3b00 3b04 3b08 3b0c 3b10 3b11
3b13 3b17 3b1b 3b1f 3b22 3b25 3b28 3b29
3b2e 3b31 3b35 3b39 3b3c 3b3d 3b3f 3b42
3b45 3b46 3b4b 1 3b4e 3b53 3b57 3b5b
3b5e 3b5f 3b61 3b64 3b67 3b68 3b6d 1
3b70 3b75 3b79 3b7d 3b81 3b85 3b89 3b8d
3b91 3b95 3b99 3b9d 3ba1 3bad 3bb1 3bb6
3bba 3bbd 3bbe 3bc3 3bc7 3bcb 3bce 3bd1
3bd5 3bd7 3bdb 3bdf 3be2 3be5 3be9 3beb
3bef 3bf3 3bf6 3bf8 3bfc 3c00 3c04 3c07
3c0b 3c0f 3c11 3c12 3c17 1 3c1b 3c1f
3c23 3c26 3c2a 3c2e 3c32 3c36 3c39 3c3d
3c41 3c44 3c47 3c4c 3c4f 3c52 3c55 3c56
3c5b 3c5c 1 3c5e 3c63 3c67 3c6b 3c6e
3c73 3c78 3c7b 3c7f 3c80 3c85 3c88 3c8d
3c8e 3c93 3c96 3c9b 3c9c 3ca1 3ca4 3ca8
3ca9 3cae 3cb1 3cb6 3cb7 3cbc 3cbf 3cc3
3cc7 3cca 3ccd 3cce 3cd0 3cd1 3cd6 3cd7
3cdc 3cde 3ce2 3ce5 3ce7 3ceb 3ced 3cf9
3cfb 3cfd 3cfe 3d03 3d07 3d09 3d15 3d17
3d19 3d1d 3d20 3d22 3d26 3d2a 3d2d 3d2f
3d33 3d37 3d3a 3d3e 3d42 3d45 3d48 3d4b
3d4c 3d51 3d55 3d59 3d5c 3d60 3d64 3d67
3d6a 3d6f 3d72 3d75 3d78 3d79 3d7e 3d7f
1 3d81 3d86 3d8a 3d8e 3d91 3d96 3d9b
3d9e 3da2 3da3 3da8 3dab 3db0 3db1 3db6
3db9 3dbe 3dbf 3dc4 3dc7 3dcb 3dcf 3dd3
3dd7 3dda 3ddb 3ddd 3de2 3de3 3de5 3de6
3deb 3dee 3df3 3df4 3df9 3dfc 3e01 3e02
3e07 3e0a 3e0e 3e0f 3e14 3e17 3e1c 3e1d
3e22 3e23 3e28 3e2a 3e2e 3e31 3e35 3e39
3e3c 3e40 3e44 3e47 3e4a 3e4f 3e52 3e55
3e58 3e59 3e5e 3e5f 1 3e61 3e66 3e6a
3e6e 3e71 3e76 3e7b 3e7e 3e82 3e83 3e88
3e89 3e8e 3e90 3e94 3e97 3e9b 3e9f 3ea2
3ea6 3eaa 3ead 3eb1 3eb5 3eb6 3ebb 3ebd
3ec1 3ec4 3ec8 3ecc 3ed0 3ed4 3ed8 3edb
3edc 3ede 3ee1 3ee4 3ee5 3eea 3eed 3ef1
3ef5 3ef8 3ef9 3efb 3efe 3f01 3f02 3f07
1 3f0a 3f0f 3f13 3f16 3f1a 3f1c 3f20
3f23 3f27 3f2b 3f2e 3f2f 3f31 3f34 3f37
3f38 3f3d 3f41 3f45 3f49 3f4c 3f4d 3f4f
3f52 3f53 3f55 3f58 3f5b 3f5e 3f5f 3f64
3f68 3f6b 3f6c 3f71 3f74 3f78 3f7b 3f7c
3f81 3f84 3f88 3f8c 3f90 3f94 3f98 3f9c
3fa0 3fa4 3fa8 3fac 3fb0 3fb4 3fb8 3fbc
3fc0 3fc4 3fc8 3fcc 3fd0 3fd4 3fd8 3fe4
3fe8 3fed 3ff1 3ff4 3ff5 3ffa 3ffe 4002
4005 4008 400c 400e 4012 4016 4019 401c
4020 4022 4026 402a 402d 402f 4033 4037
403b 403e 4042 4046 4048 4049 404e 1
4052 4056 405a 405d 4061 4065 4069 406d
4070 4074 4078 407b 407e 4083 4086 4089
408c 408d 4092 4093 1 4095 409a 409e
40a2 40a5 40aa 40af 40b2 40b6 40b7 40bc
40bf 40c4 40c5 40ca 40cd 40d2 40d3 40d8
40db 40df 40e0 40e5 40e8 40ed 40ee 40f3
40f6 40fa 40fe 4101 4104 4105 4107 4108
410d 410e 4113 4115 4119 411c 411e 4122
4124 4130 4132 4134 4135 413a 413e 4140
414c 414e 4150 4154 4158 415c 4160 4164
4168 416c 4170 4174 4180 4184 4189 418d
4190 4191 4196 419a 419e 41a1 41a4 41a8
41aa 41ae 41b2 41b5 41b8 41bc 41be 41c2
41c6 41c9 41cb 41cf 41d3 41d7 41da 41de
41e2 41e4 41e5 41ea 1 41ee 41f2 41f6
41f9 41fd 4201 4205 4209 420c 4210 4214
4217 421a 421f 4222 4225 4228 4229 422e
422f 1 4231 4236 423a 423e 4241 4246
424b 424e 4252 4253 4258 425b 4260 4261
4266 4269 426e 426f 4274 4277 427b 427c
4281 4284 4289 428a 428f 4292 4296 429a
429d 42a0 42a1 42a3 42a4 42a9 42aa 42af
42b1 42b5 42b8 42ba 42be 42c0 42cc 42ce
42d0 42d1 42d6 42da 42dc 42e8 42ea 42ec
42f0 42f4 42f7 42f9 42fd 4300 4301 4306
4309 430d 4311 4315 4319 431d 4321 4325
4329 432d 4331 4335 4339 433d 4341 4345
4349 434d 4351 4355 4359 435d 4361 4365
4369 436d 4371 4375 4379 437d 4381 4385
4389 438d 4391 4395 4399 439d 43a1 43a5
43a9 43ad 43b1 43b5 43b9 43bd 43c1 43c5
43c9 43cd 43d1 43d5 43d9 43dd 43e1 43e5
43e9 43ed 43f1 43f5 43f9 43fd 4401 4405
4409 440d 4411 4415 4419 441d 4421 4425
4431 4435 443a 443e 4441 4442 4447 444b
444f 4452 4455 4459 445b 445f 4463 4466
4469 446d 446f 4473 4477 447a 447c 4480
4484 4488 448b 448f 4493 4495 4496 449b
1 449f 44a3 44a7 44aa 44ae 44b2 44b6
44ba 44bd 44c1 44c5 44c8 44cb 44d0 44d3
44d6 44d9 44da 44df 44e0 1 44e2 44e7
44eb 44ef 44f2 44f7 44fc 44ff 4503 4504
4509 450c 4511 4512 4517 451a 451f 4520
4525 4528 452c 452d 4532 4535 453a 453b
4540 4543 4547 454b 454e 4551 4552 4554
4555 455a 455b 4560 4562 4566 4569 456b
456f 4571 457d 457f 4581 4582 4587 458b
458d 4599 459b 459d 45a1 45a5 45a9 45ad
45b1 45b5 45b9 45bd 45c1 45c5 45c9 45cd
45d1 45d5 45d9 45dd 45e1 45e5 45e9 45ed
45f1 45f5 45f9 45fd 4601 4605 4609 460d
4611 4615 4619 461d 4621 4625 4629 462d
4631 4635 4639 463d 4641 4645 4649 464d
4651 4655 4659 465d 4661 4665 4669 466d
4671 4675 4679 467d 4681 4685 4689 4695
4699 469e 46a2 46a5 46a6 46ab 46af 46b3
46b6 46b9 46bd 46bf 46c3 46c7 46ca 46cd
46d1 46d3 46d7 46db 46de 46e0 46e4 46e8
46ec 46ef 46f3 46f7 46f9 46fa 46ff 1
4703 4707 470b 470e 4712 4716 471a 471e
4721 4725 4729 472c 472f 4734 4737 473a
473d 473e 4743 4744 1 4746 474b 474f
4753 4756 475b 4760 4763 4767 4768 476d
4770 4775 4776 477b 477e 4783 4784 4789
478c 4790 4791 4796 4799 479e 479f 47a4
47a7 47ab 47af 47b2 47b5 47b6 47b8 47b9
47be 47bf 47c4 47c6 47ca 47cd 47cf 47d3
47d5 47e1 47e3 47e5 47e6 47eb 47ef 47f1
47fd 47ff 4801 4805 4809 480c 480e 4812
4816 4819 481d 481f 4823 4827 482a 482b
482d 4830 4833 4834 4839 483d 4841 4845
4849 484d 4851 4855 4859 485d 4869 486d
4872 4876 4879 487a 487f 4883 4887 488a
488d 4891 4893 4897 489b 489e 48a1 48a5
48a7 48ab 48af 48b2 48b4 48b8 48bc 48c0
48c3 48c7 48cb 48cd 48ce 48d3 1 48d7
48db 48df 48e2 48e6 48ea 48ee 48f2 48f5
48f9 48fd 4900 4903 4908 490b 490e 4911
4912 4917 4918 1 491a 491f 4923 4927
492a 492f 4934 4937 493b 493c 4941 4944
4949 494a 494f 4952 4957 4958 495d 4960
4964 4965 496a 496d 4972 4973 4978 497b
497f 4983 4986 4989 498a 498c 498d 4992
4993 4998 499a 499e 49a1 49a3 49a7 49a9
49b5 49b7 49b9 49ba 49bf 49c3 49c5 49d1
49d3 49d5 49d9 49dd 49e0 49e2 49e6 49ea
49ee 49f1 49f2 49f4 49f7 49f8 49fa 49fd
4a00 4a03 4a04 4a09 4a0d 4a10 4a11 4a16
4a19 4a1d 4a20 4a21 4a26 4a29 4a2d 4a31
4a35 4a39 4a3d 4a41 4a45 4a49 4a4d 4a51
4a55 4a59 4a5d 4a61 4a65 4a69 4a6d 4a71
4a75 4a79 4a7d 4a89 4a8d 4a92 4a96 4a99
4a9a 4a9f 4aa3 4aa7 4aaa 4aad 4ab1 4ab3
4ab7 4abb 4abe 4ac1 4ac5 4ac7 4acb 4acf
4ad2 4ad4 4ad8 4adc 4ae0 4ae3 4ae7 4aeb
4aed 4aee 4af3 1 4af7 4afb 4aff 4b02
4b06 4b0a 4b0e 4b12 4b15 4b19 4b1d 4b20
4b23 4b28 4b2b 4b2e 4b31 4b32 4b37 4b38
1 4b3a 4b3f 4b43 4b47 4b4a 4b4f 4b54
4b57 4b5b 4b5c 4b61 4b64 4b69 4b6a 4b6f
4b72 4b77 4b78 4b7d 4b80 4b84 4b85 4b8a
4b8d 4b92 4b93 4b98 4b9b 4b9f 4ba3 4ba6
4ba9 4baa 4bac 4bad 4bb2 4bb3 4bb8 4bba
4bbe 4bc1 4bc3 4bc7 4bc9 4bd5 4bd7 4bd9
4bda 4bdf 4be3 4be5 4bf1 4bf3 4bf5 4bf9
4bfd 4c01 4c05 4c09 4c0d 4c11 4c15 4c19
4c1d 4c21 4c2d 4c31 4c36 4c3a 4c3d 4c3e
4c43 4c47 4c4b 4c4e 4c51 4c55 4c57 4c5b
4c5f 4c62 4c65 4c69 4c6b 4c6f 4c73 4c76
4c78 4c7c 4c80 4c84 4c87 4c8b 4c8f 4c91
4c92 4c97 1 4c9b 4c9f 4ca3 4ca6 4caa
4cae 4cb2 4cb6 4cb9 4cbd 4cc1 4cc4 4cc7
4ccc 4ccf 4cd2 4cd5 4cd6 4cdb 4cdc 1
4cde 4ce3 4ce7 4ceb 4cee 4cf3 4cf8 4cfb
4cff 4d00 4d05 4d08 4d0d 4d0e 4d13 4d16
4d1b 4d1c 4d21 4d24 4d28 4d29 4d2e 4d31
4d36 4d37 4d3c 4d3f 4d43 4d47 4d4a 4d4d
4d4e 4d50 4d51 4d56 4d57 4d5c 4d5e 4d62
4d65 4d67 4d6b 4d6d 4d79 4d7b 4d7d 4d7e
4d83 4d87 4d89 4d95 4d97 4d99 4d9d 4da1
4da4 4da6 4daa 4dad 4dae 4db3 4db6 4dba
4dbe 4dc2 4dc6 4dca 4dce 4dd2 4dd6 4dda
4dde 4de2 4de6 4dea 4dee 4df2 4df6 4dfa
4dfe 4e02 4e06 4e0a 4e0e 4e12 4e16 4e1a
4e1e 4e22 4e26 4e2a 4e2e 4e32 4e36 4e3a
4e3e 4e42 4e46 4e4a 4e4e 4e52 4e56 4e5a
4e5e 4e62 4e66 4e6a 4e6e 4e72 4e76 4e7a
4e7e 4e82 4e86 4e8a 4e8e 4e92 4e96 4e9a
4e9e 4ea2 4ea6 4eaa 4eae 4eb2 4eb6 4eba
4ebe 4ec2 4ec6 4eca 4ece 4ed2 4ede 4ee2
4ee7 4eeb 4eee 4eef 4ef4 4ef8 4efc 4eff
4f02 4f06 4f08 4f0c 4f10 4f13 4f16 4f1a
4f1c 4f20 4f24 4f27 4f29 4f2d 4f31 4f35
4f38 4f3c 4f40 4f42 4f43 4f48 1 4f4c
4f50 4f54 4f57 4f5b 4f5f 4f63 4f67 4f6a
4f6e 4f72 4f75 4f78 4f7d 4f80 4f83 4f86
4f87 4f8c 4f8d 1 4f8f 4f94 4f98 4f9c
4f9f 4fa4 4fa9 4fac 4fb0 4fb1 4fb6 4fb9
4fbe 4fbf 4fc4 4fc7 4fcc 4fcd 4fd2 4fd5
4fd9 4fda 4fdf 4fe2 4fe7 4fe8 4fed 4ff0
4ff4 4ff8 4ffb 4ffe 4fff 5001 5002 5007
5008 500d 500f 5013 5016 5018 501c 501e
502a 502c 502e 502f 5034 5038 503a 5046
5048 504a 504e 5052 5056 505a 505e 5062
5066 506a 506e 5072 5076 507a 507e 5082
5086 508a 508e 5092 5096 509a 509e 50a2
50a6 50aa 50ae 50b2 50b6 50ba 50be 50c2
50c6 50ca 50ce 50d2 50d6 50da 50de 50e2
50e6 50ea 50ee 50f2 50f6 50fa 50fe 5102
5106 510a 510e 5112 5116 511a 511e 5122
5126 512a 512e 5132 5136 513a 513e 514a
514e 5153 5157 515a 515b 5160 5164 5168
516b 516e 5172 5174 5178 517c 517f 5182
5186 5188 518c 5190 5193 5195 5199 519d
51a1 51a4 51a8 51ac 51ae 51af 51b4 1
51b8 51bc 51c0 51c3 51c7 51cb 51cf 51d3
51d6 51da 51de 51e1 51e4 51e9 51ec 51ef
51f2 51f3 51f8 51f9 1 51fb 5200 5204
5208 520b 5210 5215 5218 521c 521d 5222
5225 522a 522b 5230 5233 5238 5239 523e
5241 5245 5246 524b 524e 5253 5254 5259
525c 5260 5264 5267 526a 526b 526d 526e
5273 5274 5279 527b 527f 5282 5284 5288
528a 5296 5298 529a 529b 52a0 52a4 52a6
52b2 52b4 52b6 52ba 52be 52c1 52c3 52c7
52cb 52ce 52d2 52d4 52d8 52dc 52df 52e0
52e2 52e5 52e8 52e9 52ee 52f2 52f5 52f6
52fb 52fe 5302 5306 5309 530a 530c 530f
5312 5313 5318 531c 5320 5324 5328 532c
5330 5334 5338 533c 5340 5344 5348 534c
5350 535c 5360 5365 5369 536c 536d 5372
5376 537a 537d 5380 5384 5386 538a 538e
5391 5394 5398 539a 539e 53a2 53a5 53a7
53ab 53af 53b3 53b6 53ba 53be 53c0 53c1
53c6 1 53ca 53ce 53d2 53d5 53d9 53dd
53e1 53e5 53e8 53ec 53f0 53f3 53f6 53fb
53fe 5401 5404 5405 540a 540b 1 540d
5412 5416 541a 541d 5422 5427 542a 542e
542f 5434 5437 543c 543d 5442 5445 544a
544b 5450 5453 5457 5458 545d 5460 5465
5466 546b 546e 5472 5476 5479 547c 547d
547f 5480 5485 5486 548b 548d 5491 5494
5496 549a 549c 54a8 54aa 54ac 54ad 54b2
54b6 54b8 54c4 54c6 54c8 54cc 54d0 54d4
54d8 54dc 54e0 54e4 54e8 54ec 54f0 54f4
5500 5504 5509 550d 5510 5511 5516 551a
551e 5521 5524 5528 552a 552e 5532 5535
5538 553c 553e 5542 5546 5549 554b 554f
5553 5557 555a 555e 5562 5564 5565 556a
1 556e 5572 5576 5579 557d 5581 5585
5589 558c 5590 5594 5597 559a 559f 55a2
55a5 55a8 55a9 55ae 55af 1 55b1 55b6
55ba 55be 55c1 55c6 55cb 55ce 55d2 55d3
55d8 55db 55e0 55e1 55e6 55e9 55ee 55ef
55f4 55f7 55fb 55fc 5601 5604 5609 560a
560f 5612 5616 561a 561d 5620 5621 5623
5624 5629 562a 562f 5631 5635 5638 563a
563e 5640 564c 564e 5650 5651 5656 565a
565c 5668 566a 566c 5670 5674 5677 5679
567d 5681 5685 5689 568d 5691 5695 5699
569d 56a1 56a5 56b1 56b5 56ba 56be 56c1
56c2 56c7 56cb 56cf 56d2 56d5 56d9 56db
56df 56e3 56e6 56e9 56ed 56ef 56f3 56f7
56fa 56fc 5700 5704 5708 570b 570f 5713
5715 5716 571b 1 571f 5723 5727 572a
572e 5732 5736 573a 573d 5741 5745 5748
574b 5750 5753 5756 5759 575a 575f 5760
1 5762 5767 576b 576f 5772 5777 577c
577f 5783 5784 5789 578c 5791 5792 5797
579a 579f 57a0 57a5 57a8 57ac 57ad 57b2
57b5 57ba 57bb 57c0 57c3 57c7 57cb 57ce
57d1 57d2 57d4 57d5 57da 57db 57e0 57e2
57e6 57e9 57eb 57ef 57f1 57fd 57ff 5801
5802 5807 580b 580d 5819 581b 581d 5821
5825 5828 582a 582e 5832 5835 5837 583b
583f 5842 5846 5849 584a 584f 5852 5856
585a 585d 585e 5860 5863 5866 5867 586c
1 586f 5874 5877 587b 587f 5882 5883
5885 5888 588b 588c 5891 1 5894 5899
589d 58a2 58a6 58aa 58ab 58af 58b3 58b6
58ba 58be 58c1 58c5 58c9 58cd 58d0 58d1
58d3 58d6 58d9 58da 58df 58e3 58e7 58eb
58ef 58f3 58f7 58fb 58ff 5903 5907 590b
590f 5913 5917 591b 591f 5923 5927 592b
592f 5933 5937 593b 593f 5943 594f 5953
5957 595a 595e 5962 5964 5968 596c 5970
5973 5977 597b 597d 597e 5983 1 5987
598b 598f 5992 5996 599a 599e 59a2 59a5
59a9 59ad 59b0 59b3 59b8 59bb 59be 59c1
59c2 59c7 59c8 1 59ca 59cf 59d3 59d7
59da 59df 59e4 59e7 59eb 59ec 59f1 59f4
59f9 59fa 59ff 5a02 5a07 5a08 5a0d 5a10
5a14 5a15 5a1a 5a1d 5a22 5a23 5a28 5a2b
5a2f 5a33 5a36 5a39 5a3a 5a3c 5a3d 5a42
5a43 5a48 5a4a 5a4e 5a51 5a53 5a57 5a59
5a65 5a67 5a69 5a6a 5a6f 5a73 5a75 5a81
5a83 5a85 5a89 5a8d 5a91 5a95 5a99 5a9d
5aa1 5aa5 5aa9 5aad 5ab1 5ab5 5ab9 5abd
5ac1 5ac5 5ac9 5acd 5ad1 5ad5 5ad9 5add
5ae1 5ae5 5ae9 5aed 5af9 5afd 5b01 5b04
5b08 5b0c 5b0e 5b12 5b16 5b1a 5b1d 5b21
5b25 5b27 5b28 5b2d 1 5b31 5b35 5b39
5b3c 5b40 5b44 5b48 5b4c 5b4f 5b53 5b57
5b5a 5b5d 5b62 5b65 5b68 5b6b 5b6c 5b71
5b72 1 5b74 5b79 5b7d 5b81 5b84 5b89
5b8e 5b91 5b95 5b96 5b9b 5b9e 5ba3 5ba4
5ba9 5bac 5bb1 5bb2 5bb7 5bba 5bbe 5bbf
5bc4 5bc7 5bcc 5bcd 5bd2 5bd5 5bd9 5bdd
5be0 5be3 5be4 5be6 5be7 5bec 5bed 5bf2
5bf4 5bf8 5bfb 5bfd 5c01 5c03 5c0f 5c11
5c13 5c14 5c19 5c1d 5c1f 5c2b 5c2d 5c2f
5c33 5c37 5c3a 5c3e 5c42 5c45 5c49 5c4c
5c50 5c53 5c54 5c59 5c5c 5c60 5c64 5c67
5c68 5c6a 5c6e 5c71 5c75 5c78 5c79 5c7b
5c7c 5c81 5c84 5c88 5c8c 5c8f 5c90 5c92
5c95 5c98 5c99 5c9e 1 5ca1 5ca6 5caa
5cae 5cb1 5cb2 5cb4 5cb7 5cba 5cbb 5cc0
1 5cc3 5cc8 5ccc 5cd0 5cd4 5cd8 5cdc
5ce0 5ce4 5ce8 5cf4 5cf8 5cfd 5d01 5d04
5d05 5d0a 5d0e 5d12 5d15 5d18 5d1c 5d1e
5d22 5d26 5d29 5d2c 5d30 5d32 5d36 5d3a
5d3d 5d3f 5d43 5d47 5d4b 5d4e 5d52 5d56
5d58 5d59 5d5e 1 5d62 5d66 5d6a 5d6d
5d71 5d75 5d79 5d7d 5d80 5d84 5d88 5d8b
5d8e 5d93 5d96 5d99 5d9c 5d9d 5da2 5da3
1 5da5 5daa 5dae 5db2 5db5 5dba 5dbf
5dc2 5dc6 5dc7 5dcc 5dcf 5dd4 5dd5 5dda
5ddd 5de2 5de3 5de8 5deb 5def 5df0 5df5
5df8 5dfd 5dfe 5e03 5e06 5e0a 5e0e 5e11
5e14 5e15 5e17 5e18 5e1d 5e1e 5e23 5e25
5e29 5e2c 5e2e 5e32 5e34 5e40 5e42 5e44
5e45 5e4a 5e4e 5e50 5e5c 5e5e 5e62 5e66
5e6a 5e6e 5e72 5e76 5e7a 5e7e 5e82 5e86
5e8a 5e8e 5e92 5e9e 5ea2 5ea7 5eab 5eae
5eaf 5eb4 5eb8 5ebc 5ebf 5ec2 5ec6 5ec8
5ecc 5ed0 5ed3 5ed6 5eda 5edc 5ee0 5ee4
5ee7 5ee9 5eed 5ef1 5ef5 5ef8 5efc 5f00
5f02 5f03 5f08 1 5f0c 5f10 5f14 5f17
5f1b 5f1f 5f23 5f27 5f2a 5f2e 5f32 5f35
5f38 5f3d 5f40 5f43 5f46 5f47 5f4c 5f4d
1 5f4f 5f54 5f58 5f5c 5f5f 5f64 5f69
5f6c 5f70 5f71 5f76 5f79 5f7e 5f7f 5f84
5f87 5f8c 5f8d 5f92 5f95 5f99 5f9a 5f9f
5fa2 5fa7 5fa8 5fad 5fb0 5fb4 5fb8 5fbb
5fbe 5fbf 5fc1 5fc2 5fc7 5fc8 5fcd 5fcf
5fd3 5fd6 5fd8 5fdc 5fde 5fea 5fec 5fee
5fef 5ff4 5ff8 5ffa 6006 6008 600a 600e
6012 6017 601b 601c 6020 6024 6028 602c
6030 6035 603a 603e 6042 6046 604b 604f
6053 6056 6059 605d 605f 6063 6067 606a
606d 6071 6073 6077 607b 607e 6082 6086
6089 608c 608f 6090 6095 6099 609f 60a1
60a5 60a8 60ac 60b0 60b4 60b7 60b8 60ba
60bd 60c1 60c5 60c8 60c9 60cb 60cc 60d1
60d5 60d9 60dd 60e0 60e1 60e3 60e6 60e9
60ea 60ef 60f3 60f7 60fa 60fb 60fd 6101
6104 6108 610b 610c 610e 610f 6114 6118
611c 611f 6120 6122 6126 6129 612d 6130
6131 6133 6134 6139 613d 6141 6145 6148
6149 614b 614f 6151 6155 6159 615d 6160
6161 6163 6166 616a 616e 6171 6172 6174
6175 617a 617d 6181 6185 6188 6189 618b
618c 6191 6195 6197 619b 619f 61a2 61a4
61a8 61ab 61af 61b3 61b7 61bb 61bf 61cb
61cf 61d4 61d8 61db 61dc 61e1 61e5 61e9
61ec 61ef 61f3 61f5 61f9 61fd 6200 6203
6207 6209 620d 6211 6214 6216 621a 621e
6222 6225 6229 622d 622f 6230 6235 1
6239 623d 6241 6244 6248 624c 6250 6254
6257 625b 625f 6262 6265 626a 626d 6270
6273 6274 6279 627a 1 627c 6281 6285
6289 628c 6291 6296 6299 629d 629e 62a3
62a6 62ab 62ac 62b1 62b4 62b9 62ba 62bf
62c2 62c6 62c7 62cc 62cf 62d4 62d5 62da
62dd 62e1 62e5 62e8 62eb 62ec 62ee 62ef
62f4 62f5 62fa 62fc 6300 6303 6305 6309
630b 6317 6319 631b 631c 6321 6325 6327
6333 6335 6339 633d 6341 6343 6347 634a
634e 6352 6355 6356 6358 635c 635f 6363
6366 6367 6369 636a 636f 6373 6379 637b
637f 6382 6384 6388 638f 6393 6397 639c
639e 63a2 63a6 63a9 63ad 63b1 63b3 63b7
63bb 63bf 63c2 63c6 63ca 63cc 63cd 63d2
1 63d6 63da 63de 63e1 63e5 63e9 63ed
63f1 63f4 63f8 63fc 63ff 6402 6407 640a
640d 6410 6411 6416 6417 1 6419 641e
6422 6426 6429 642e 6433 6436 643a 643b
6440 6443 6448 6449 644e 6451 6456 6457
645c 645f 6463 6464 6469 646c 6471 6472
6477 647a 647e 6482 6485 6488 6489 648b
648c 6491 6492 6497 6499 649d 64a0 64a2
64a6 64a8 64b4 64b6 64b8 64b9 64be 64c2
64c4 64d0 64d2 64d6 64da 64dd 64de 64e0
64e3 64e6 64e7 64ec 64ef 64f3 64f6 64f7
64fc 64ff 1 6502 6507 650b 650f 6513
6517 651b 6527 652b 6530 6534 6537 6538
653d 6541 6545 6548 654b 654f 6551 6555
6559 655c 655f 6563 6565 6569 656d 6570
6572 6576 657a 657e 6581 6585 6589 658b
658c 6591 1 6595 6599 659d 65a0 65a4
65a8 65ac 65b0 65b3 65b7 65bb 65be 65c1
65c6 65c9 65cc 65cf 65d0 65d5 65d6 1
65d8 65dd 65e1 65e5 65e8 65ed 65f2 65f5
65f9 65fa 65ff 6602 6607 6608 660d 6610
6615 6616 661b 661e 6622 6623 6628 662b
6630 6631 6636 6639 663d 6641 6644 6647
6648 664a 664b 6650 6651 6656 6658 665c
665f 6661 6665 6667 6673 6675 6677 6678
667d 6681 6683 668f 6691 6693 6697 669a
669c 66a0 66a4 66a7 66ab 66af 66b2 66b3
66b5 66b8 66bb 66bc 66c1 66c5 66c9 66cd
66d0 66d1 66d3 66d6 66d7 66d9 66dc 66df
66e2 66e3 66e8 66ec 66f0 66f4 66f8 66f9
66fb 66ff 6701 6705 6709 670d 6711 6712
6714 6718 671a 671e 6722 6725 6727 672b
672e 6730 6734 6737 6739 673d 6740 6742
6746 6749 674d 6751 6754 6757 675a 675b
6760 6764 6768 676b 676e 6772 6774 6778
677b 677d 6781 6784 6788 678c 678f 6793
6797 679a 679d 67a2 67a5 67a8 67ab 67ac
67b1 67b2 1 67b4 67b9 67bd 67c1 67c4
67c9 67ce 67d1 67d5 67d6 67db 67de 67e3
67e4 67e9 67ec 67f1 67f2 67f7 67fa 67fe
6802 6806 680a 680d 680e 6810 6815 6816
6818 6819 681e 6821 6826 6827 682c 682f
6834 6835 683a 683d 6841 6842 6847 684a
684f 6850 6855 6856 685b 685d 6861 6864
6868 686c 686f 6873 6877 687a 687e 6882
6883 6888 688a 688e 6892 6895 6899 689d
68a0 68a4 68a8 68ab 68ae 68b3 68b6 68b9
68bc 68bd 68c2 68c3 1 68c5 68ca 68ce
68d2 68d5 68da 68df 68e2 68e6 68e7 68ec
68ed 68f2 68f6 68fa 68fd 6902 6907 690a
690e 6912 6915 6916 691b 691e 6923 6924
6929 692c 6930 6934 6937 6938 693d 693e
6943 6945 6949 694c 6950 6954 6958 695c
6960 6964 6968 696c 6970 697c 6981 6985
6989 698d 6991 6993 6994 6999 1 699d
69a1 69a5 69a8 69ac 69b0 69b4 69b8 69bb
69bf 69c3 69c6 69c9 69ce 69d1 69d4 69d7
69d8 69dd 69de 1 69e0 69e5 69e9 69ed
69f0 69f5 69fa 69fd 6a01 6a02 6a07 6a08
6a0d 6a11 6a15 6a18 6a1d 6a22 6a25 6a29
6a2a 6a2f 6a32 6a37 6a38 6a3d 6a40 6a44
6a48 6a4b 6a4e 6a4f 6a51 6a52 6a57 6a58
6a5d 6a5f 6a63 6a66 6a6a 6a6e 6a72 6a76
6a7a 6a7e 6a82 6a8e 6a93 6a97 6a9b 6a9f
6aa3 6aa5 6aa9 6aab 6ab7 6ab9 6abb 6abc
6ac1 6ac5 6ac7 6ad3 6ad7 6ad9 6ada 6ae3 
1e78
2
0 1 a 6 c :3 6 15 :3 6
11 :3 6 12 :3 6 13 :3 6 10 :3 6
17 :3 6 15 :3 6 1a :3 6 b :3 6
10 :3 6 c :3 6 16 :3 6 18 :3 6
19 :3 6 1b :3 6 17 :3 6 16 :3 6
17 :3 6 17 :3 6 12 :2 6 1 3
a 13 a :2 1 4 13 1c 1b
:2 13 :2 4 10 19 18 :2 10 :2 4 e
17 16 :2 e :2 4 e 17 16 :2 e
:2 4 f 18 17 :2 f :2 4 e 17
16 :2 e :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 f 18 17
:2 f :2 4 c 15 14 :2 c :2 4 12
1b 1a :2 12 :2 4 11 1a 19 :2 11
:2 4 e 17 16 :2 e :2 4 f 18
17 :2 f :2 4 :2 e 1d e :2 4 :2 14
23 14 :2 4 :2 b 1a b :2 4 :2 a
19 a :2 4 :2 b 1a b :2 4 :2 e
1d e :2 4 :2 13 22 13 :2 4 :2 c
1b c :2 4 :2 e 1d e :2 4 :2 13
22 13 :2 4 :2 d 1c d :2 4 :2 c
1b c :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 10 1f 10 :2 4 :2 12
21 12 :2 4 :3 10 :2 4 :3 f :2 4 18
21 20 :2 18 :2 4 18 21 20 :2 18
:2 4 f 18 17 :2 f :2 4 :3 11 :2 4
:3 f :2 4 :3 13 :2 4 :3 10 :2 4 :3 d :2 4
:3 e :2 4 14 1d 1c :2 14 :2 4 :2 11
20 11 :2 4 :2 f 1e f :2 4 :2 14
23 14 :2 4 :2 11 20 11 :2 4 :2 12
21 12 :2 4 :2 12 21 12 :2 4 :2 a
19 a :2 4 :3 9 :2 4 :3 9 :2 4 :2 f
19 f :2 4 :2 f 19 f :2 4 :2 f
1e f :2 4 :2 16 25 16 :2 4 :2 11
20 11 :2 4 :2 14 23 14 4 7
e 0 :2 7 20 2d 33 3b 56
5c 64 f 10 1d 2e 3b 13
2d a :6 7 e 0 :2 7 11 1c
26 f 10 1d 2e 42 18 23
a :5 7 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 55 5b 5e :2 55
6c 83 8 :2 6c d 10 :2 6c 16
19 :2 6c b e :2 6c 13 16 1f
27 :2 1f 38 :2 16 :2 6c b e :2 6c
13 16 :2 6c 1b 1e :2 6c 29 2c
:2 6c b e :2 6c 13 16 :2 6c 1b
1e :2 6c 2a 2d :2 6c b e :2 6c
13 16 :2 6c 1b 1e :2 6c 2b 2e
:2 6c b e :2 6c 13 16 1f 27
:2 1f 33 :2 16 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 2f 32 :2 6c
b e :2 6c 13 16 1f 27 :2 1f
38 :2 16 :2 6c b e :2 6c 13 16
1f 27 :2 1f 3d :2 16 :2 6c b e
:2 6c 13 16 1f 27 :2 1f 2e :2 16
:2 6c b e :2 6c 13 16 1f 27
:2 1f 33 :2 16 :2 6c b e :2 6c 13
16 1f 27 :2 1f 2f :2 16 :2 6c b
e :2 6c 13 16 1f 27 :2 1f 39
:2 16 :2 6c b e :2 6c 13 16 :2 6c
1b 1e :2 6c 30 33 :2 6c b e
:2 6c 13 16 :2 6c 1b 1e :2 6c 31
34 :2 6c b e :2 6c 13 16 1f
27 :2 1f 3e :2 16 :2 6c b e :2 6c
13 16 1f 27 :2 1f 3a :2 16 :2 6c
b e :2 6c 13 16 :2 6c 1b 1e
:2 6c 2e 31 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 2f 32 :2 6c
b e :2 6c 13 16 1f 27 :2 1f
3a :2 16 :2 6c b e :2 6c 13 16
:2 6c 1b 1e :2 6c 2a 2d :2 6c 32
35 :2 6c :2 7 4b :2 4 7 :2 11 23
:2 2d 39 3c 4d 50 51 :2 4d :2 23
:3 7 :2 d 12 1e 5e 61 :2 1e :2 7
54 :2 4 :4 9 8 7 27 30 40
:2 27 43 45 :2 43 26 4c a 1a
:2 4c 1d 1f :2 1d 4b :2 26 25 :2 7
a :2 14 26 :2 30 3c 3f 50 53
54 :2 50 :2 26 :3 a :2 10 15 21 61
64 :2 21 71 74 :2 21 78 7b :2 21
85 88 91 99 :2 a2 :2 91 b3 :2 88
:2 21 :2 a 57 :2 7 a :2 14 26 :2 30
3c 3f 50 53 54 :2 50 :2 26 :3 a
:2 10 15 21 61 64 :2 21 :2 a 57
:3 7 :2 12 28 :2 31 41 :2 7 23 :2 4
:4 9 8 7 :4 1e 1d 1c :2 7 :4 37
36 35 :2 7 a :2 14 26 :2 30 3c
3f 50 53 54 :2 50 :2 26 :3 a :2 10
15 21 61 64 :2 21 71 74 :2 21
78 7b :2 21 85 88 91 99 :2 a2
:2 91 b3 :2 88 :2 21 :2 a 57 :2 7 a
:2 14 26 :2 30 3c 3f 50 53 54
:2 50 :2 26 :3 a :2 10 15 21 61 64
:2 21 :2 a 57 :3 7 :2 12 28 :2 31 41
:2 7 4d :3 4 16 :2 4 10 :2 4 17
:2 4 12 :2 4 13 :2 4 17 :2 4 12
:2 4 10 :2 4 13 :2 4 15 :2 4 f
:2 4 16 :2 4 15 :2 4 14 4 7
10 17 :2 10 29 :2 7 2e 2c :2 37
:2 2c b 14 23 :2 b 26 28 :2 26
a 2f 38 47 :2 2f 4a 4c :2 4a
2e :2 a :4 e d 10 :2 1a 2c :2 36
42 45 56 59 5a :2 56 :2 2c :3 10
:2 16 1b 27 67 6a :2 27 77 7a
:2 27 7e 81 :2 27 8b 8e 97 9f
:2 a8 :2 97 b9 :2 8e :2 27 :2 10 5d :2 d
10 :2 1a 2c :2 36 42 45 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 :2 10 5d :3 d :2 18 2e :2 37
47 :2 d 22 :3 a 1b :2 a 17 :2 a
18 a 14 20 2d 3b 12 20
2d :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5a 5d 5e :2 5a :2 2f :3 13 :2 19 1e
2a 6a 6d :2 2a 7a 7d :2 2a 81
84 :2 2a 90 93 :2 2a 9b 9e :2 2a
aa ad b4 bd c0 :2 ad :2 2a :2 13
61 :2 10 :2 d :4 19 :2 d a :3 4f a
18 a 14 24 34 2b 13 20
31 3e :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5a 5d 5e :2 5a :2 2f :3 13 :2 19
1e 2a 6a 6d :2 2a 7a 7d :2 2a
81 84 :2 2a 90 93 :2 2a 9b 9e
:2 2a aa ad b4 bd c0 :2 ad :2 2a
:2 13 61 :2 10 :2 d :4 19 :2 d a :3 4f
e 17 23 :2 e 26 29 :2 26 d
31 3a 49 :2 31 4c 4e :2 4c 30
:2 d 56 10 1a :2 56 1d 1f :2 1d
55 :2 d 10 :2 1a 2c :2 36 42 46
57 5a 5b :2 57 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 77 7a :2 27 7e
81 :2 27 8b 8e 97 9f :2 97 a3
:2 8e :2 27 ab ae :2 27 b6 b9 :2 27
be c1 :2 27 cf d2 :2 27 :2 10 5e
:2 d 10 :2 1a 2c :2 36 42 45 56
59 5a :2 56 :2 2c :3 10 :2 16 1b 27
67 6a :2 27 :2 10 5d :3 d :2 18 2c
2f 3e :2 d 22 d :3 18 :2 d 1d
26 2f 3a :2 26 :2 1d :2 d 20 2f
3d 48 53 62 25 :2 20 d 11
1a 29 :2 11 2c 2e :2 2c 10 36
41 4a 55 :2 41 :2 36 35 5a 5d
:2 5a :3 10 21 10 5f :2 d :4 a 4f
a 15 a 14 20 29 36 43
d 18 22 2d 3b 12 20 2b
3a 49 d 1e 26 31 41 12
29 3d :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5a 5d 5e :2 5a :2 2f :3 13 :2 19
1e 2a 6a 6d :2 2a 7a 7d :2 2a
81 84 :2 2a 90 93 :2 2a 9b 9e
:2 2a aa ad b4 bd c0 :2 ad :2 2a
:2 13 61 :2 10 :2 d :4 19 :2 d a :3 7
e :2 17 22 20 :2 2b :2 20 d 40
49 59 :2 40 5f 5c 10 1f :2 5f
:2 5c 3f :2 d 10 :2 1a 2c :2 36 42
46 57 5a 5b :2 57 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8b 8e 97 9f :2 97
a3 :2 8e :2 27 ab ae :2 27 b6 b9
:2 27 be c1 :2 27 c9 cc :2 27 :2 10
5e :2 d 10 :2 1a 2c :2 36 42 45
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 :2 10 5d :3 d :2 18
2c 2f 38 :2 d 23 :2 a :4 7 a
13 22 :2 a 25 28 :2 25 d :2 16
1f 22 :2 1f 10 :2 1a 2c :2 36 42
46 57 5a 5b :2 57 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8b 8e 97 9f :2 a8
:2 97 b3 :2 8e :2 27 bb be :2 27 c6
c9 :2 27 ce d1 :2 27 d9 dc :2 27
:2 10 5e :2 d 10 :2 1a 2c :2 36 42
45 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 :2 10 5d :3 d
:2 18 2c :2 35 3f 48 :2 d 24 :2 a
:4 e d :4 26 25 :2 d :4 3f 3e :2 d
:4 14 13 :2 d 10 :2 1a 2c :2 36 42
45 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8b 8e 97 9f :2 a8
:2 97 b9 :2 8e :2 27 :2 10 5d :2 d 10
:2 1a 2c :2 36 42 45 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 :2 10 5d :3 d :2 18 2e :2 37 47
:2 d 2d :3 a 1c :2 25 a d 16
1f :2 d 22 24 :2 22 d 18 d
2e :2 a 14 1d 37 46 54 61
:2 d :2 16 22 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5a
5d 5e :2 5a :2 2f :3 13 :2 19 1e 2a
6a 6d :2 2a 7a 7d :2 2a 81 84
:2 2a 90 93 :2 2a 9b 9e :2 2a aa
ad b4 bd c0 :2 ad :2 2a :2 13 61
:2 10 :2 d :4 19 :2 d a :3 2a d 16
1e :2 d 21 23 :2 21 d 1b 23
2c 36 :2 2c 3f :2 23 42 44 4d
57 :2 4d 63 :2 44 :2 23 22 67 69
:2 22 21 20 22 :2 21 :2 1b d 10
19 22 :2 10 28 25 31 3d :2 28
:2 25 10 1a :2 10 1d 10 40 10
1b 10 :4 d 25 :3 a 18 a e
15 1e 29 :2 15 2d :2 e d 32
34 :2 32 10 19 28 :2 10 2b 2d
:2 2b 13 1c 2c :2 13 2f 31 :2 2f
13 :2 1c 28 35 3e 4a 56 67
25 32 3c 44 4c 54 25 35
40 50 25 36 :2 28 13 16 :2 1f
28 2a :2 28 20 35 3b 19 2a
36 48 55 65 1f 2c 3d 47
55 63 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 66 69 6a :2 66
:2 3b :3 1f :2 25 2a 36 76 79 :2 36
86 89 :2 36 8d 90 :2 36 9c 9f
:2 36 a7 aa :2 36 b6 b9 c0 c9
cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19 :4 25
:2 19 16 :4 2c :2 13 33 13 :2 1c 28
35 3e 4a 56 67 25 32 3c
44 4c 54 25 35 40 50 25
36 :2 28 13 :4 10 2f 10 22 2b
3b :2 22 3e 40 :2 22 10 13 1c
2c :2 13 2f 31 :2 2f 13 :2 1c 28
35 3e 4a 56 67 25 32 3c
44 4c 54 25 35 40 50 25
36 :2 28 13 16 :2 1f 28 2a :2 28
20 35 3b 19 2a 36 48 55
65 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 66 69 6a
:2 66 :2 3b :3 1f :2 25 2a 36 76 79
:2 36 86 89 :2 36 8d 90 :2 36 9c
9f :2 36 a7 aa :2 36 b6 b9 c0
c9 cc :2 b9 :2 36 :2 1f 6d :2 1c :2 19
:4 25 :2 19 16 :4 2c :2 13 33 13 :2 1c
28 35 3e 4a 56 67 25 32
3c 44 4c 54 25 35 40 50
25 36 :2 28 13 :4 10 :4 d 11 :2 1a
23 25 :2 23 10 2e 35 3e 49
:2 35 4d :2 2e 2d 51 53 :2 51 2c
:2 10 14 1d 2d :2 14 32 30 3b
46 :2 32 :2 30 13 4f 58 5e :2 4f
61 63 :2 61 4e :2 13 6b 2c 41
:2 6b 44 46 :2 44 6a :2 13 1d 32
46 16 22 2b 3a 16 27 33
45 52 62 16 25 31 41 16
24 16 :2 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 63 66
67 :2 63 :2 38 :3 1c :2 22 27 33 73
76 :2 33 83 86 :2 33 8a 8d :2 33
99 9c :2 33 a4 a7 :2 33 b3 b6
bd c6 c9 :2 b6 :2 33 :2 1c 6a :2 19
:2 16 :4 22 :2 16 13 :3 4d 1d 32 3f
4a 1c 29 3a 4e 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 63
66 67 :2 63 :2 38 :3 1c :2 22 27 33
73 76 :2 33 83 86 :2 33 8a 8d
:2 33 99 9c :2 33 a4 a7 :2 33 b3
b6 bd c6 c9 :2 b6 :2 33 :2 1c 6a
:2 19 :2 16 :4 22 :2 16 13 :3 4d 1d 32
43 1c 30 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 63 66 67
:2 63 :2 38 :3 1c :2 22 27 33 73 76
:2 33 83 86 :2 33 8a 8d :2 33 99
9c :2 33 a4 a7 :2 33 b3 b6 bd
c6 c9 :2 b6 :2 33 :2 1c 6a :2 19 :2 16
:4 22 :2 16 13 :4 4d 1d 32 38 16
27 33 45 52 62 1c 30 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 63 66 67 :2 63 :2 38 :3 1c :2 22
27 33 73 76 :2 33 83 86 :2 33
8a 8d :2 33 99 9c :2 33 a4 a7
:2 33 b3 b6 bd c6 c9 :2 b6 :2 33
:2 1c 6a :2 19 :2 16 :4 22 :2 16 13 :7 10
56 :2 d 37 d 1c 23 2c 39
:2 23 3d :2 46 :2 1c d 10 19 28
:2 10 2b 2d :2 2b 10 :2 19 25 32
3b 47 53 64 25 32 3c 44
4c 54 25 35 40 50 25 36
:2 25 10 14 :2 1d 26 28 :2 26 13
30 39 44 :2 30 47 49 :2 47 2f
:2 13 51 5a 63 :2 51 66 68 :2 66
50 :2 13 1d 32 38 16 27 33
45 52 62 1c 29 3a 44 52
60 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 63 66 67 :2 63 :2 38
:3 1c :2 22 27 33 73 76 :2 33 83
86 :2 33 8a 8d :2 33 99 9c :2 33
a4 a7 :2 33 b3 b6 bd c6 c9
:2 b6 :2 33 :2 1c 6a :2 19 :2 16 :4 22 :2 16
13 :4 6b :2 10 2f :4 14 :2 13 20 13
1d 24 3e 45 5f 66 80 87
9c ab :2 16 :2 1f 2b 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 63 66 67 :2 63 :2 38 :3 1c :2 22
27 33 73 76 :2 33 83 86 :2 33
8a 8d :2 33 99 9c :2 33 a4 a7
:2 33 b3 b6 bd c6 c9 :2 b6 :2 33
:2 1c 6a :2 19 :2 16 :4 22 :2 16 13 :3 33
16 :2 21 29 34 3e :2 16 42 44
:2 42 16 23 :2 2c :2 16 26 16 20
30 1e 1f :2 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 66 69 6a :2 66 :2 3b :3 1f
:2 25 2a 36 76 79 :2 36 86 89
:2 36 8d 90 :2 36 9c 9f :2 36 a7
aa :2 36 b6 b9 c0 c9 cc :2 b9
:2 36 :2 1f 6d :2 1c :2 19 :4 25 :2 19 16
:3 46 16 29 3b 49 54 62 6d
28 :2 29 16 19 22 33 :2 19 36
38 :2 36 19 26 :2 19 27 :2 19 2b
:2 19 27 :2 19 28 :2 19 1e :3 19 1f
2c 3c :3 19 1c 24 :2 1c :2 25 31
1c 2a 1c :2 25 31 1c :4 19 1c
22 :3 1c :2 25 31 1c 19 21 1f
:2 28 34 1f 2f :2 1c :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
69 6c 6d :2 69 :2 3e :3 22 :2 28 2d
39 79 7c :2 39 89 8c :2 39 90
93 :2 39 9f a2 :2 39 aa ad :2 39
b9 bc c3 cc cf :2 bc :2 39 :2 22
70 :2 1f :2 1c :4 28 :2 1c 19 :3 3a 23
32 43 22 30 :2 1c :2 25 31 1c
19 21 1f :2 28 34 1f 2f :2 1c
:2 21 1f :2 28 34 1f 22 :2 2c 3e
:2 48 54 58 69 6c 6d :2 69 :2 3e
:3 22 :2 28 2d 39 79 7c :2 39 89
8c :2 39 90 93 :2 39 9f a2 :2 39
aa ad :2 39 b9 bc c3 cc cf
:2 bc :2 39 :2 22 70 :2 1f :2 1c :4 28 :2 1c
19 :3 3a 19 26 :2 19 26 :2 19 26
2d 37 3a :2 2d 47 4a :2 26 :2 19
26 2d 37 3a :2 2d 4b 4e :2 26
:2 19 26 2d 37 3a :2 2d 4a 4d
:2 26 :2 19 26 2d 37 22 :2 2d 24
27 :2 26 :2 19 2c 3a 46 52 5a
62 6e 24 2f 3a 46 52 5e
24 2f 3b :2 2c 19 1c :2 26 38
:2 42 4e 52 63 66 67 :2 63 :2 38
:3 1c :2 22 27 33 73 76 :2 33 83
86 :2 33 8a 8d :2 33 97 9a a3
ab :2 a3 af :2 9a :2 33 b7 ba :2 33
c2 c5 :2 33 ca cd :2 33 d5 d8
:2 33 :2 1c 6a :2 19 1c :2 26 38 :2 42
4e 51 62 65 66 :2 62 :2 38 :3 1c
:2 22 27 33 73 76 :2 33 :2 1c 69
:3 19 :2 24 38 3b 44 :2 19 3a :2 16
46 :2 13 33 :3 10 22 2b 3b :2 22
3e 40 :2 22 :2 10 :2 19 25 32 3b
47 53 64 25 32 3c 44 4c
54 25 35 40 50 25 36 :2 25
10 14 :2 1d 26 28 :2 26 13 30
39 44 :2 30 47 49 :2 47 2f :2 13
51 5a 63 :2 51 66 68 :2 66 50
:2 13 1d 32 38 16 27 33 45
52 62 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 63 66
67 :2 63 :2 38 :3 1c :2 22 27 33 73
76 :2 33 83 86 :2 33 8a 8d :2 33
99 9c :2 33 a4 a7 :2 33 b3 b6
bd c6 c9 :2 b6 :2 33 :2 1c 6a :2 19
:2 16 :4 22 :2 16 13 :4 6b :2 10 :4 d :4 a
d :2 16 1f 22 :2 1f 10 :2 1a 2c
:2 36 42 46 57 5a 5b :2 57 :2 2c
:3 10 :2 16 1b 27 67 6a :2 27 77
7a :2 27 7e 81 :2 27 8b 8e 97
9f :2 a8 :2 97 b3 :2 8e :2 27 bb be
:2 27 c6 c9 :2 27 ce d1 :2 27 d9
dc :2 27 :2 10 5e :2 d 10 :2 1a 2c
:2 36 42 45 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 67 6a :2 27 :2 10
5d :3 d :2 18 2c :2 35 3f 48 :2 d
24 :3 a 1c a e 17 20 :2 e
23 26 :2 23 d 32 3b 4b :2 32
4e 50 :2 4e 31 :3 d 1f d 53
:2 a d 16 25 :2 d 28 2a :2 28
11 18 21 2c :2 18 30 :2 11 10
35 37 :2 35 :4 14 13 :4 17 16 20
35 49 19 25 2e 3d 19 2a
36 48 55 65 19 28 19 29
19 27 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 66 69
6a :2 66 :2 3b :3 1f :2 25 2a 36 76
79 :2 36 86 89 :2 36 8d 90 :2 36
9c 9f :2 36 a7 aa :2 36 b6 b9
c0 c9 cc :2 b9 :2 36 :2 1f 6d :2 1c
:2 19 :4 25 :2 19 16 :4 33 20 35 49
19 25 19 28 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
66 69 6a :2 66 :2 3b :3 1f :2 25 2a
36 76 79 :2 36 86 89 :2 36 8d
90 :2 36 9c 9f :2 36 a7 aa :2 36
b6 b9 c0 c9 cc :2 b9 :2 36 :2 1f
6d :2 1c :2 19 :4 25 :2 19 16 :7 13 2f
:4 17 16 20 35 49 19 25 2e
3d 19 35 51 5e 76 19 36
52 5f 78 19 38 54 6e 19
34 50 66 19 2b 19 2c 19
2e 19 2a 19 2b 19 2c 19
2e 19 2a 19 31 4a 19 3d
51 6a 19 2a 38 49 57 68
76 87 :2 19 2a 36 48 55 65
19 28 19 29 19 27 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 66 69 6a :2 66 :2 3b :3 1f
:2 25 2a 36 76 79 :2 36 86 89
:2 36 8d 90 :2 36 9c 9f :2 36 a7
aa :2 36 b6 b9 c0 c9 cc :2 b9
:2 36 :2 1f 6d :2 1c :2 19 :4 25 :2 19 16
:4 33 20 35 49 19 25 2e 3d
19 35 51 5e 76 19 36 52
5f 78 19 38 54 6e 19 34
50 66 19 2b 19 2c 19 2e
19 2a 19 2b 19 2c 19 2e
19 2a 19 31 4a 19 3d 51
6a 19 2a 38 49 57 68 76
87 19 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 66 69
6a :2 66 :2 3b :3 1f :2 25 2a 36 76
79 :2 36 86 89 :2 36 8d 90 :2 36
9c 9f :2 36 a7 aa :2 36 b6 b9
c0 c9 cc :2 b9 :2 36 :2 1f 6d :2 1c
:2 19 :4 25 :2 19 16 :7 13 :4 10 d 3a
13 1c 25 :2 13 28 2a :2 28 1a
2f 43 13 1f 13 22 19 2d
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 60 63 64 :2 60 :2 35 :3 19
:2 1f 24 30 70 73 :2 30 80 83
:2 30 87 8a :2 30 96 99 :2 30 a1
a4 :2 30 b0 b3 ba c3 c6 :2 b3
:2 30 :2 19 67 :2 16 :2 13 :4 1f :2 13 10
:4 2c 3a :2 d 2c 11 18 21 2c
:2 18 30 :2 11 10 35 37 :2 35 :4 14
13 :4 17 16 20 35 49 19 25
2e 3d 19 2a 36 48 55 65
19 28 19 29 19 27 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 66 69 6a :2 66 :2 3b :3 1f
:2 25 2a 36 76 79 :2 36 86 89
:2 36 8d 90 :2 36 9c 9f :2 36 a7
aa :2 36 b6 b9 c0 c9 cc :2 b9
:2 36 :2 1f 6d :2 1c :2 19 :4 25 :2 19 16
:4 33 20 35 49 19 25 2e 3d
19 27 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 66 69
6a :2 66 :2 3b :3 1f :2 25 2a 36 76
79 :2 36 86 89 :2 36 8d 90 :2 36
9c 9f :2 36 a7 aa :2 36 b6 b9
c0 c9 cc :2 b9 :2 36 :2 1f 6d :2 1c
:2 19 :4 25 :2 19 16 :7 13 2f :4 17 16
20 35 49 19 25 2e 3d 19
35 51 5e 76 19 36 52 5f
78 19 38 54 6e 19 34 50
66 19 2b 19 2c 19 2e 19
2a 19 2b 19 2c 19 2e 19
2a 19 31 4a 19 3d 51 6a
19 2a 38 49 57 68 76 87
:2 19 2a 36 48 55 65 19 28
19 29 19 27 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
66 69 6a :2 66 :2 3b :3 1f :2 25 2a
36 76 79 :2 36 86 89 :2 36 8d
90 :2 36 9c 9f :2 36 a7 aa :2 36
b6 b9 c0 c9 cc :2 b9 :2 36 :2 1f
6d :2 1c :2 19 :4 25 :2 19 16 :4 33 20
35 49 19 25 2e 3d 19 27
19 35 51 5e 76 19 36 52
5f 78 19 38 54 6e 19 34
50 66 19 2b 19 2c 19 2e
19 2a 19 2b 19 2c 19 2e
19 2a 19 31 4a 19 3d 51
6a 19 2a 38 49 57 68 76
87 19 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 66 6a
6b :2 66 :2 3b :3 1f :2 25 2a 36 77
7a :2 36 87 8a :2 36 8e 91 :2 36
9d a0 :2 36 a8 ab :2 36 b7 ba
c1 ca cd :2 ba :2 36 :2 1f 6e :2 1c
:2 19 :4 25 :2 19 16 :7 13 :4 10 d 3a
13 1c 25 :2 13 28 2a :2 28 :4 14
13 16 1f 25 :2 16 28 2a :2 28
20 35 49 19 25 2e 3d 19
27 19 1f 2a 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
66 6a 6b :2 66 :2 3b :3 1f :2 25 2a
36 77 7a :2 36 87 8a :2 36 8e
91 :2 36 9d a0 :2 36 a8 ab :2 36
b7 ba c1 ca cd :2 ba :2 36 :2 1f
6e :2 1c :2 19 :4 25 :2 19 16 :4 2c 20
35 49 19 25 2e 3d 19 27
1f 33 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 66 6a 6b :2 66
:2 3b :3 1f :2 25 2a 36 77 7a :2 36
87 8a :2 36 8e 91 :2 36 9d a0
:2 36 a8 ab :2 36 b7 ba c1 ca
cd :2 ba :2 36 :2 1f 6e :2 1c :2 19 :4 25
:2 19 16 :7 13 31 1d 32 46 16
22 2b 3a 16 24 1c 30 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 63 67 68 :2 63 :2 38 :3 1c :2 22
27 33 74 77 :2 33 84 87 :2 33
8b 8e :2 33 9a 9d :2 33 a5 a8
:2 33 b4 b7 be c7 ca :2 b7 :2 33
:2 1c 6b :2 19 :2 16 :4 22 :2 16 13 :7 10
2c 3a :2 d :4 a :4 f e 30 39
4b :2 30 4e 50 :2 4e 2f :2 e d
58 10 20 :2 58 23 25 :2 23 57
:3 d 1b :2 d 1b :2 d 18 :2 d 18
d 10 19 28 :2 10 2b 2d :2 2b
1a 2d 39 42 4a 51 67 6f
76 8d 97 a8 b6 18 2d 37
42 48 4e 5a 6d 79 18 19
2d :2 13 :2 1c 28 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
60 64 65 :2 60 :2 35 :3 19 :2 1f 24
30 71 74 :2 30 81 84 :2 30 88
8b :2 30 97 9a :2 30 a2 a5 :2 30
b1 b4 bb c4 c7 :2 b4 :2 30 :2 19
68 :2 16 :2 13 :4 1f :2 13 10 :4 2f 10
27 10 1a 26 2f 37 3e 54
5c 63 7a 84 95 a3 18 22
2d 33 39 45 58 64 18 19
2d :2 13 :2 1c 28 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
60 64 65 :2 60 :2 35 :3 19 :2 1f 24
30 71 74 :2 30 81 84 :2 30 88
8b :2 30 97 9a :2 30 a2 a5 :2 30
b1 b4 bb c4 c7 :2 b4 :2 30 :2 19
68 :2 16 :2 13 :4 1f :2 13 10 :7 d 11
:2 1a 25 23 :2 2e :2 23 10 14 1d
2d :2 14 32 30 3b 46 :2 32 :2 30
13 4f 58 5e :2 4f 61 63 :2 61
4e :2 13 6b 2c 41 :2 6b 44 46
:2 44 6a :2 13 1d 32 3f 4a 1c
29 3a 4e 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 63 67 68
:2 63 :2 38 :3 1c :2 22 27 33 74 77
:2 33 84 87 :2 33 8b 8e :2 33 9a
9d :2 33 a5 a8 :2 33 b4 b7 be
c7 ca :2 b7 :2 33 :2 1c 6b :2 19 :2 16
:4 22 :2 16 13 :3 4d 1d 32 40 16
2f 33 42 1c 29 3a 4e 1c
30 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 63 67 68 :2 63 :2 38
:3 1c :2 22 27 33 74 77 :2 33 84
87 :2 33 8b 8e :2 33 9a 9d :2 33
a5 a8 :2 33 b4 b7 be c7 ca
:2 b7 :2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16
13 :4 4d 13 18 :4 13 1c 25 30
3d :3 16 19 1d :2 19 :2 22 2e 19
23 19 :2 22 2e 19 :4 16 19 :2 22
2b 2e :2 2b :2 19 30 :3 16 21 2a
33 :2 21 36 38 41 4c :2 38 :2 21
16 19 22 2b :2 19 2e 30 :2 2e
1c 25 2e :2 1c 33 31 3c 4b
:2 33 :2 31 1f 28 33 :2 1f 39 36
42 51 :2 39 :2 36 1f 2c 35 44
:2 2c 1f 54 1f 2c 35 44 :2 2c
47 49 52 5b :2 49 :2 2c 5e 60
69 74 :2 60 :2 2c 1f :4 1c 4e :2 19
23 38 45 50 71 1c 23 1f
2b :3 29 1f :2 28 34 1f 30 1f
:2 28 34 1f :4 1c 19 21 1f :2 28
34 1f 2f :2 1c :2 21 1f :2 28 34
1f 22 :2 2c 3e :2 48 54 58 69
6d 6e :2 69 :2 3e :3 22 :2 28 2d 39
7a 7d :2 39 8a 8d :2 39 91 94
:2 39 a0 a3 :2 39 ab ae :2 39 ba
bd c4 cd d0 :2 bd :2 39 :2 22 71
:2 1f :2 1c :4 28 :2 1c 19 :3 32 19 27
19 32 :2 16 19 22 2b :2 19 31
2e 3a 49 :2 31 :2 2e :2 19 4c :2 16
13 17 10 16 1c :3 16 :2 1f 2b
16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 63 67 68 :2 63
:2 38 :3 1c :2 22 27 33 74 77 :2 33
84 87 :2 33 8b 8e :2 33 9a 9d
:2 33 a5 a8 :2 33 b4 b7 be c7
ca :2 b7 :2 33 :2 1c 6b :2 19 :2 16 :4 22
:2 16 13 :3 10 17 20 29 :2 17 2c
2e :2 2c 16 :4 37 36 35 :2 16 20
35 46 57 6b 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 66 6a
6b :2 66 :2 3b :3 1f :2 25 2a 36 77
7a :2 36 87 8a :2 36 8e 91 :2 36
9d a0 :2 36 a8 ab :2 36 b7 ba
c1 ca cd :2 ba :2 36 :2 1f 6e :2 1c
:2 19 :4 25 :2 19 16 :4 50 :2 13 :4 10 13
1c 2b :2 13 2e 30 :2 2e 17 1e
27 32 :2 1e 36 :2 17 16 3b 3d
:2 3b 16 29 3c 51 :2 29 16 40
16 29 3c 51 :2 29 16 :4 13 32
:2 10 3e :2 d 28 :2 a 2a :2 7 a
:2 13 1c 1e :2 1c a :2 13 1f a
22 :2 7 4f :2 4 7 :2 11 23 :2 2d
39 3c 4d 51 52 :2 4d :2 23 :3 7
:2 d 12 1e 5f 62 :2 1e 6f 72
:2 1e 76 79 :2 1e 83 86 8f 97
:2 a0 :2 8f ab :2 86 :2 1e b3 b6 :2 1e
be c1 :2 1e c6 c9 :2 1e cf d2
:2 1e :2 7 55 :3 4 :2 f 21 :2 2a 34
3b :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 51 55 56 :2 51
:2 26 :3 a :2 10 15 21 62 65 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
59 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4e 52 53 :2 4e
:2 23 :3 7 :2 d 12 1e 5f 62 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 56 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
1e78
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 :4 12 :4 13 :4 14
:4 15 :4 16 :4 17 2
:4 18 :2 1 :7 1a :7 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :7 21 :7 22 :7 23
:7 24 :7 25 :7 26 :7 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:5 38 :5 39 :7 3a :7 3b
:7 3c :5 3d :5 3e :5 3f
:5 40 :5 41 :5 42 :7 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :5 4b
:5 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :2 54
0 :2 54 :7 55 56
:4 57 :2 58 55 :5 54
:2 5a 0 :2 5a :3 5b
5c :4 5d :2 5e 5b
:5 5a :7 60 :b 62 :11 63
64 :2 63 :2 64 :2 63
:2 64 :2 63 :2 65 :2 63
:9 65 :2 63 :2 66 :2 63
:2 66 :2 63 :2 66 :2 63
:2 66 :2 63 :2 67 :2 63
:2 67 :2 63 :2 67 :2 63
:2 67 :2 63 :2 68 :2 63
:2 68 :2 63 :2 68 :2 63
:2 68 :2 63 :2 69 :2 63
:9 69 :2 63 :2 6a :2 63
:2 6a :2 63 :2 6a :2 63
:2 6a :2 63 :2 6b :2 63
:9 6b :2 63 :2 6c :2 63
:9 6c :2 63 :2 6d :2 63
:9 6d :2 63 :2 6e :2 63
:9 6e :2 63 :2 6f :2 63
:9 6f :2 63 :2 70 :2 63
:9 70 :2 63 :2 71 :2 63
:2 71 :2 63 :2 71 :2 63
:2 71 :2 63 :2 72 :2 63
:2 72 :2 63 :2 72 :2 63
:2 72 :2 63 :2 73 :2 63
:9 73 :2 63 :2 74 :2 63
:9 74 :2 63 :2 75 :2 63
:2 75 :2 63 :2 75 :2 63
:2 75 :2 63 :2 76 :2 63
:2 76 :2 63 :2 76 :2 63
:2 76 :2 63 :2 77 :2 63
:9 77 :2 63 :2 78 :2 63
:2 78 :2 63 :2 78 :2 63
:2 78 :2 63 :2 78 :4 63
:3 62 :11 7b :b 7c :3 7b
:11 7f :2 80 :2 7f :4 80
:6 7f :11 81 :20 82 :3 81
:11 84 :b 85 :3 84 :9 87
80 :2 7f :16 8a :11 8b
:20 8c :3 8b :11 8e :b 8f
:3 8e :9 91 :3 8a :3 96
:3 97 :3 98 :3 99 :3 9a
:3 9b :3 9c :3 9d :3 9e
:3 9f :3 a0 :3 a1 :3 a2
:3 a3 :e a7 :16 a8 :5 aa
:11 ab :20 ac :3 ab :11 ae
:b af :3 ae :9 b1 :3 aa
:3 b4 :3 b5 :3 b6 :4 b9
:3 ba b9 :5 bb b8
bd :5 be :3 bd :2 bf
:5 c1 :11 c2 :24 c3 :3 c2
:2 c0 :6 bf bc :3 a8
:3 c8 :3 ca cb :4 cc
ca :5 cd c9 cf
:5 d0 :3 cf :2 d1 :5 d3
:11 d4 :24 d5 :3 d4 :2 d2
:6 d1 ce :3 a8 :17 db
:2 dc :2 db :4 dc :3 db
:11 dd :2e de :3 dd :11 e0
:b e1 :3 e0 :8 e3 dc
:5 e5 :a e6 :7 e8 e9
:3 e8 :19 ec :3 ed :3 ec
e4 :3 db a8 :3 f1
:5 f4 :5 f5 :5 f6 :5 f7
:3 f8 f4 :5 f9 f3
fb :5 fc :3 fb :2 fd
:5 ff :11 100 :24 101 :3 100
:2 fe :6 fd fa :3 f0
:11 107 :2 108 :7 107 :11 10b
:2e 10c :3 10b :11 10e :b 10f
:3 10e :8 111 108 :2 107
f0 :3 a8 :9 116 :7 117
:11 118 :30 119 :3 118 :11 11b
:b 11c :3 11b :a 11e :3 117
:13 122 :5 123 :2 122 :11 124
:20 125 :3 124 :11 127 :b 128
:3 127 :9 12a 123 :2 122
:5 12d :9 130 :3 131 :3 130
:7 138 :5 139 137 13b
:5 13c :3 13b :2 13d :5 13f
:11 140 :24 141 :3 140 :2 13e
:6 13d 13a :3 116 :9 146
:1b 148 :2 149 :5 148 :d 14b
:3 14c :3 14d 14b :3 14f
14e :3 14b :3 146 :3 16c
:e 16e :9 16f :9 170 :9 171
:6 172 :4 173 :2 174 :3 171
:7 177 :3 179 :6 17a :6 17b
179 :6 17c :5 17d 17c
:5 17f 17e :3 17c 178
182 :5 183 :3 182 :2 184
:5 186 :11 187 :24 188 :3 187
:2 185 :6 184 181 :6 177
170 :9 18e :6 18f :4 190
:2 191 :3 18e 18d :3 170
16f :b 195 :9 196 :9 197
:6 198 :4 199 :2 19a :3 197
:7 19d :3 19f :6 1a0 :2 1a1
19f :6 1a2 :5 1a3 1a2
:5 1a5 1a4 :3 1a2 19e
1a8 :5 1a9 :3 1a8 :2 1aa
:5 1ac :11 1ad :24 1ae :3 1ad
:2 1ab :6 1aa 1a7 :6 19d
196 :9 1b4 :6 1b5 :4 1b6
:2 1b7 :3 1b4 1b3 :3 196
194 :3 16f :19 1bc :1b 1bd
:2 1be :2 1bd :4 1be :3 1bd
:3 1c0 :4 1c1 :6 1c2 :4 1c3
:2 1c4 :2 1c5 :2 1c6 1c0
:6 1c7 :5 1c8 1c7 :5 1ca
1c9 :3 1c7 1bf 1cd
:5 1ce :3 1cd :2 1cf :5 1d1
:11 1d2 :24 1d3 :3 1d2 :2 1d0
:6 1cf 1cc :3 1be :4 1d9
:4 1da 1d9 :6 1db :5 1dc
1db :5 1de 1dd :3 1db
1d8 1e1 :5 1e2 :3 1e1
:2 1e3 :5 1e5 :11 1e6 :24 1e7
:3 1e6 :2 1e4 :6 1e3 1e0
:3 1be :3 1ed :2 1ee 1ed
:6 1ef :5 1f0 1ef :5 1f2
1f1 :3 1ef 1ec 1f5
:5 1f6 :3 1f5 :2 1f7 :5 1f9
:11 1fa :24 1fb :3 1fa :2 1f8
:6 1f7 1f4 :4 1be :3 201
:6 202 :2 203 201 :6 204
:5 205 204 :5 207 206
:3 204 200 20a :5 20b
:3 20a :2 20c :5 20e :11 20f
:24 210 :3 20f :2 20d :6 20c
209 :4 1ff :3 1bd :3 1bc
16e :d 217 :9 219 :9 21a
:6 21b :4 21c :2 21d :3 21a
:20 220 :3 222 :6 223 :6 224
222 :6 225 :5 226 225
:5 228 227 :3 225 221
22b :5 22c :3 22b :2 22d
:5 22f :11 230 :24 231 :3 230
:2 22e :6 22d 22a :6 220
219 :5 237 :3 238 :b 23e
:5 23f 23d 241 :5 242
:3 241 :2 243 :5 245 :11 246
:24 247 :3 246 :2 244 :6 243
240 :3 237 :c 24c :5 24d
:3 24e :2 251 252 253
251 :5 254 250 256
:5 257 :3 256 :2 258 :5 25a
:11 25b :24 25c :3 25b :2 259
:6 258 255 :3 24c :7 261
262 :3 261 :9 264 :3 265
:3 266 :3 267 :3 268 :3 269
:5 26b :6 26d :3 26e :5 26f
26e :5 271 270 :3 26e
:4 275 :5 276 274 278
:5 279 :3 278 :2 27a :5 27c
:11 27d :24 27e :3 27d :2 27b
:6 27a 277 :3 264 :3 284
:2 285 284 :5 286 283
288 :5 289 :3 288 :2 28a
:5 28c :11 28d :24 28e :3 28d
:2 28b :6 28a 287 :3 264
:3 294 :3 296 :c 297 :c 298
:c 299 :4 29a 29b :2 29a
:2 29c :3 29a :8 29e :6 29f
:3 2a0 :3 29e :11 2a2 :2e 2a3
:3 2a2 :11 2a5 :b 2a6 :3 2a5
:8 2a8 :3 264 :3 24c :3 237
:b 2ad :9 2ae :6 2af :4 2b0
:2 2b1 :3 2ae :20 2b5 :3 2b7
:6 2b8 :2 2b9 2b7 :6 2ba
:5 2bb 2ba :5 2bd 2bc
:3 2ba 2b6 2c0 :5 2c1
:3 2c0 :2 2c2 :5 2c4 :11 2c5
:24 2c6 :3 2c5 :2 2c3 :6 2c2
2bf :6 2b5 236 :3 219
216 :3 16e :7 2cf :11 2d0
:30 2d1 :3 2d0 :11 2d3 :b 2d4
:3 2d3 :a 2d6 :3 2cf :3 2d9
:16 2da :3 2db :3 2da :9 2de
:e 2df :5 2e0 :5 2e2 :3 2e4
:4 2e5 :6 2e6 :2 2e7 :2 2e8
:2 2e9 :2 2ea 2e4 :6 2eb
:5 2ec 2eb :5 2ee 2ed
:3 2eb 2e3 2f1 :5 2f2
:3 2f1 :2 2f3 :5 2f5 :11 2f6
:24 2f7 :3 2f6 :2 2f4 :6 2f3
2f0 :4 2e2 :3 2fd :2 2fe
:2 2ff :2 300 2fd :6 301
:5 302 301 :5 304 303
:3 301 2fc 307 :5 308
:3 307 :2 309 :5 30b :11 30c
:24 30d :3 30c :2 30a :6 309
306 :4 2fb :3 2e2 2e0
:5 314 :3 316 :4 317 :5 318
:5 319 :4 31a :4 31b :2 31d
:2 31e :2 31f :2 320 :2 322
:2 323 :2 324 :2 325 :3 326
:4 327 :8 328 32a :6 32b
:2 32c :2 32d :2 32e :2 32f
316 :6 330 :5 331 330
:5 333 332 :3 330 315
336 :5 337 :3 336 :2 338
:5 33a :11 33b :24 33c :3 33b
:2 339 :6 338 335 :4 314
:3 343 :4 344 :5 345 :5 346
:4 347 :4 348 :2 34a :2 34b
:2 34c :2 34d :2 34f :2 350
:2 351 :2 352 :3 353 :4 354
:8 355 357 :2 358 343
:6 359 :5 35a 359 :5 35c
35b :3 359 342 35f
:5 360 :3 35f :2 361 :5 363
:11 364 :24 365 :3 364 :2 362
:6 361 35e :4 341 :3 314
312 :3 2e0 36b 2df
:9 36b :3 36d :2 36e :2 36f
:2 370 36d :6 371 :5 372
371 :5 374 373 :3 371
36c 377 :5 378 :3 377
:2 379 :5 37b :11 37c :24 37d
:3 37c :2 37a :6 379 376
:4 36b :3 2df 2de :e 383
:5 384 :5 386 :3 388 :4 389
:6 38a :2 38b :2 38c :2 38d
:2 38e 388 :6 38f :5 390
38f :5 392 391 :3 38f
387 395 :5 396 :3 395
:2 397 :5 399 :11 39a :24 39b
:3 39a :2 398 :6 397 394
:4 386 :3 3a1 :4 3a2 :2 3a3
:2 3a4 3a1 :6 3a5 :5 3a6
3a5 :5 3a8 3a7 :3 3a5
3a0 3ab :5 3ac :3 3ab
:2 3ad :5 3af :11 3b0 :24 3b1
:3 3b0 :2 3ae :6 3ad 3aa
:4 39f :3 386 384 :5 3b8
:3 3ba :4 3bb :5 3bc :5 3bd
:4 3be :4 3bf :2 3c1 :2 3c2
:2 3c3 :2 3c4 :2 3c6 :2 3c7
:2 3c8 :2 3c9 :3 3ca :4 3cb
:8 3cc 3ce :6 3cf :2 3d0
:2 3d1 :2 3d2 :2 3d3 3ba
:6 3d4 :5 3d5 3d4 :5 3d7
3d6 :3 3d4 3b9 3da
:5 3db :3 3da :2 3dc :5 3de
:11 3df :24 3e0 :3 3df :2 3dd
:6 3dc 3d9 :4 3b8 :3 3e6
:4 3e7 :2 3e8 :5 3e9 :5 3ea
:4 3eb :4 3ec :2 3ee :2 3ef
:2 3f0 :2 3f1 :2 3f3 :2 3f4
:2 3f5 :2 3f6 :3 3f7 :4 3f8
:8 3f9 3fb :2 3fc 3e6
:6 3fd :5 3fe 3fd :5 400
3ff :3 3fd 3e5 403
:5 404 :3 403 :2 405 :5 407
:11 408 :24 409 :3 408 :2 406
:6 405 402 :4 3e4 :3 3b8
3b6 :3 384 40f 383
:9 40f :5 410 :9 411 :3 413
:4 414 :2 415 :3 416 :2 417
413 :6 418 :5 419 418
:5 41b 41a :3 418 412
41e :5 41f :3 41e :2 420
:5 422 :11 423 :24 424 :3 423
:2 421 :6 420 41d :4 411
:3 42a :4 42b :2 42c :2 42d
42a :6 42e :5 42f 42e
:5 431 430 :3 42e 429
434 :5 435 :3 434 :2 436
:5 438 :11 439 :24 43a :3 439
:2 437 :6 436 433 :4 428
:3 411 410 :3 441 :4 442
:2 443 :2 444 441 :6 445
:5 446 445 :5 448 447
:3 445 440 44b :5 44c
:3 44b :2 44d :5 44f :11 450
:24 451 :3 450 :2 44e :6 44d
44a :4 43f :3 410 40f
:3 383 382 :3 2de :13 45b
:2 45c :2 45b :4 45c :3 45b
:3 45d :3 45e :3 45f :3 460
:9 462 :d 464 :9 465 466
:2 467 464 :5 468 463
46a :5 46b :3 46a :2 46c
:5 46e :11 46f :24 470 :3 46f
:2 46d :6 46c 469 :4 462
:3 475 :c 477 :8 478 479
:2 47a 477 :5 47b 476
47d :5 47e :3 47d :2 47f
:5 481 :11 482 :24 483 :3 482
:2 480 :6 47f 47c :4 474
:3 462 :a 48a :1b 48b :2 48c
:2 48b :4 48c :3 48b :4 48e
:4 48f 48e :6 490 :5 491
490 :5 493 492 :3 490
48d 496 :5 497 :3 496
:2 498 :5 49a :11 49b :24 49c
:3 49b :2 499 :6 498 495
:3 48c :3 4a2 :4 4a3 :4 4a4
:2 4a5 4a2 :6 4a6 :5 4a7
4a6 :5 4a9 4a8 :3 4a6
4a1 4ac :5 4ad :3 4ac
:2 4ae :5 4b0 :11 4b1 :24 4b2
:3 4b1 :2 4af :6 4ae 4ab
:4 48c :5 4b7 4b9 :7 4ba
:3 4bb :5 4bc 4bb :5 4be
4bd :3 4bb :7 4c0 :2 4c1
:3 4c0 :f 4c5 :9 4c7 :d 4c8
:d 4c9 :7 4ca 4c9 :17 4cc
4cb :3 4c9 :3 4c8 :6 4d1
:6 4d2 :5 4d3 4d2 :5 4d5
4d4 :3 4d2 4d0 4d8
:5 4d9 :3 4d8 :2 4da :5 4dc
:11 4dd :24 4de :3 4dd :2 4db
:6 4da 4d7 :3 4c7 :3 4e3
:3 4c7 :d 4e6 :2 4e7 :3 4e6
4b9 4e9 4b6 :4 4ec
:5 4ed 4eb 4ef :5 4f0
:3 4ef :2 4f1 :5 4f3 :11 4f4
:24 4f5 :3 4f4 :2 4f2 :6 4f1
4ee :3 4b6 :12 4fb :6 4fd
:6 4fe :5 4ff 4fe :5 501
500 :3 4fe 4fc 504
:5 505 :3 504 :2 506 :5 508
:11 509 :24 50a :3 509 :2 507
:6 506 503 :6 4fb 4b6
:3 48b :9 512 :e 513 :7 514
513 :7 516 515 :3 513
:3 512 :3 48a 45c :2 45b
:3 116 :7 51d :5 51e :3 51d
:3 a7 :11 524 :30 525 :3 524
:a 527 61 :3 52b :11 52c
:b 52d :17 52e :3 52c :2 530
:3 531 :3 532 533 531
530 531 :3 534 :3 52b
:2 535 :5 537 :11 538 :b 539
:18 53a :3 538 :2 53c 53d
:3 53e 53f 53d 53c
53d :3 540 :2 536 :6 535
52a :7 1 
6ae5
4
:3 0 1 :3 0 2
:a 0 1e73 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 4 :3 0
7 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 8
:7 0 11 10 :3 0
4 :3 0 9 :7 0
15 14 :3 0 11
a2 0 f 6
:3 0 a :7 0 19
18 :3 0 4 :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 6 :3 0 c
:7 0 21 20 :3 0
6 :3 0 d :7 0
25 24 :3 0 19
ee 0 17 6
:3 0 e :7 0 29
28 :3 0 6 :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b 6 :3 0 10
:7 0 31 30 :3 0
6 :3 0 11 :7 0
35 34 :3 0 21
13a 0 1f 4
:3 0 12 :7 0 39
38 :3 0 4 :3 0
13 :7 0 3d 3c
:3 0 25 160 0
23 6 :3 0 14
:7 0 41 40 :3 0
6 :3 0 15 :7 0
45 44 :3 0 29
186 0 27 4
:3 0 16 :7 0 49
48 :3 0 4 :3 0
17 :7 0 4d 4c
:3 0 2d :2 0 2b
6 :3 0 18 :7 0
51 50 :3 0 4
:3 0 19 :7 0 55
54 :3 0 1a :3 0
1b :3 0 1c :2 0
4 59 5a 0
57 5b 0 1e73
2 5c :2 0 1e
:2 0 45 4 :3 0
1e :2 0 43 5f
61 :6 0 64 62
0 1e71 0 1d
:6 0 21 :2 0 49
4 :3 0 47 66
68 :6 0 6b 69
0 1e71 0 1f
:6 0 23 :2 0 4d
4 :3 0 4b 6d
6f :6 0 72 70
0 1e71 0 20
:6 0 25 :2 0 51
4 :3 0 4f 74
76 :6 0 79 77
0 1e71 0 22
:6 0 27 :2 0 55
4 :3 0 53 7b
7d :6 0 80 7e
0 1e71 0 24
:6 0 27 :2 0 59
4 :3 0 57 82
84 :6 0 87 85
0 1e71 0 26
:6 0 27 :2 0 5d
4 :3 0 5b 89
8b :6 0 8e 8c
0 1e71 0 28
:6 0 27 :2 0 61
4 :3 0 5f 90
92 :6 0 95 93
0 1e71 0 29
:6 0 27 :2 0 65
4 :3 0 63 97
99 :6 0 9c 9a
0 1e71 0 2a
:6 0 27 :2 0 69
4 :3 0 67 9e
a0 :6 0 a3 a1
0 1e71 0 2b
:6 0 27 :2 0 6d
4 :3 0 6b a5
a7 :6 0 aa a8
0 1e71 0 2c
:6 0 27 :2 0 71
4 :3 0 6f ac
ae :6 0 b1 af
0 1e71 0 2d
:6 0 27 :2 0 75
4 :3 0 73 b3
b5 :6 0 b8 b6
0 1e71 0 2e
:6 0 31 :2 0 79
4 :3 0 77 ba
bc :6 0 bf bd
0 1e71 0 2f
:6 0 31 :2 0 7b
6 :3 0 c1 :7 0
c5 c2 c3 1e71
0 30 :6 0 31
:2 0 7d 6 :3 0
c7 :7 0 cb c8
c9 1e71 0 32
:6 0 35 :2 0 7f
6 :3 0 cd :7 0
d1 ce cf 1e71
0 33 :6 0 31
:2 0 81 6 :3 0
d3 :7 0 d7 d4
d5 1e71 0 34
:6 0 31 :2 0 83
6 :3 0 d9 :7 0
dd da db 1e71
0 36 :6 0 31
:2 0 85 6 :3 0
df :7 0 e3 e0
e1 1e71 0 37
:6 0 31 :2 0 87
6 :3 0 e5 :7 0
e9 e6 e7 1e71
0 38 :6 0 3b
:2 0 89 6 :3 0
eb :7 0 ef ec
ed 1e71 0 39
:6 0 31 :2 0 8b
6 :3 0 f1 :7 0
f5 f2 f3 1e71
0 3a :6 0 31
:2 0 8d 6 :3 0
f7 :7 0 fb f8
f9 1e71 0 3c
:6 0 31 :2 0 8f
6 :3 0 fd :7 0
101 fe ff 1e71
0 3d :6 0 31
:2 0 91 6 :3 0
103 :7 0 107 104
105 1e71 0 3e
:6 0 31 :2 0 93
6 :3 0 109 :7 0
10d 10a 10b 1e71
0 3f :6 0 31
:2 0 95 6 :3 0
10f :7 0 113 110
111 1e71 0 40
:6 0 31 :2 0 97
6 :3 0 115 :7 0
119 116 117 1e71
0 41 :6 0 9b
51c 0 99 6
:3 0 11b :7 0 11f
11c 11d 1e71 0
42 :6 0 27 :2 0
9d 44 :3 0 121
:7 0 124 122 0
1e71 0 43 :6 0
44 :3 0 126 :7 0
129 127 0 1e71
0 45 :6 0 27
:2 0 a1 4 :3 0
9f 12b 12d :6 0
130 12e 0 1e71
0 46 :6 0 49
:2 0 a5 4 :3 0
a3 132 134 :6 0
137 135 0 1e71
0 47 :6 0 ab
5a7 0 a9 4
:3 0 a7 139 13b
:6 0 13e 13c 0
1e71 0 48 :6 0
af 5db 0 ad
4b :3 0 140 :7 0
143 141 0 1e71
0 4a :6 0 4b
:3 0 145 :7 0 148
146 0 1e71 0
4c :6 0 b3 60f
0 b1 4b :3 0
14a :7 0 14d 14b
0 1e71 0 4d
:6 0 4b :3 0 14f
:7 0 152 150 0
1e71 0 4e :6 0
21 :2 0 b5 4b
:3 0 154 :7 0 157
155 0 1e71 0
4f :6 0 4b :3 0
159 :7 0 15c 15a
0 1e71 0 50
:6 0 31 :2 0 b9
4 :3 0 b7 15e
160 :6 0 163 161
0 1e71 0 51
:6 0 31 :2 0 bb
6 :3 0 165 :7 0
169 166 167 1e71
0 52 :6 0 31
:2 0 bd 6 :3 0
16b :7 0 16f 16c
16d 1e71 0 53
:6 0 31 :2 0 bf
6 :3 0 171 :7 0
175 172 173 1e71
0 54 :6 0 31
:2 0 c1 6 :3 0
177 :7 0 17b 178
179 1e71 0 55
:6 0 31 :2 0 c3
6 :3 0 17d :7 0
181 17e 17f 1e71
0 56 :6 0 31
:2 0 c5 6 :3 0
183 :7 0 187 184
185 1e71 0 57
:6 0 c9 724 0
c7 6 :3 0 189
:7 0 18d 18a 18b
1e71 0 58 :6 0
31 :2 0 cb 44
:3 0 18f :7 0 192
190 0 1e71 0
59 :6 0 44 :3 0
194 :7 0 197 195
0 1e71 0 5a
:6 0 31 :2 0 cd
5c :3 0 199 :7 0
19d 19a 19b 1e71
0 5b :6 0 31
:2 0 cf 5c :3 0
19f :7 0 1a3 1a0
1a1 1e71 0 5d
:6 0 31 :2 0 d1
6 :3 0 1a5 :7 0
1a9 1a6 1a7 1e71
0 5e :6 0 31
:2 0 d3 6 :3 0
1ab :7 0 1af 1ac
1ad 1e71 0 5f
:6 0 31 :2 0 d5
6 :3 0 1b1 :7 0
1b5 1b2 1b3 1e71
0 60 :9 0 d7
6 :3 0 1b7 :7 0
1bb 1b8 1b9 1e71
0 61 :6 0 62
:3 0 63 :a 0 2
1d0 :4 0 1bd 1c0
0 1be :3 0 64
:3 0 65 :3 0 66
:3 0 67 :3 0 65
:3 0 66 :3 0 68
:3 0 69 :3 0 6a
:3 0 2d :3 0 6b
:3 0 2e :3 0 6c
:3 0 6d :4 0 6e
1 :8 0 1d1 1bd
1c0 1d2 0 1e71
d9 1d2 1d4 1d1
1d3 :6 0 1d0 :7 0
1d2 62 :3 0 6f
:a 0 3 1e5 :5 0
1d6 1d9 0 1d7
:3 0 70 :3 0 71
:3 0 72 :3 0 73
:3 0 6a :3 0 2d
:3 0 74 :3 0 46
:3 0 75 :3 0 72
:4 0 76 1 :8 0
1e6 1d6 1d9 1e7
0 1e71 db 1e7
1e9 1e6 1e8 :6 0
1e5 :7 0 1e7 1f1
1f2 0 dd 1b
:3 0 1c :2 0 4
1eb 1ec 0 1ed
:7 0 1f0 1ee 0
1e71 0 77 :6 0
78 :3 0 79 :3 0
78 :3 0 7a :3 0
1f4 1f5 0 2
:4 0 df 1f6 1f8
1f3 1fa 1f9 :2 0
7b :3 0 7c :3 0
1fc 1fd 0 7d
:4 0 78 :3 0 7e
:3 0 200 201 0
2 :4 0 e1 202
204 7f :4 0 80
:2 0 81 :3 0 e3
207 209 :3 0 82
:4 0 80 :2 0 83
:4 0 e6 20c 20e
:3 0 80 :2 0 3
:3 0 e9 210 212
:3 0 80 :2 0 83
:4 0 ec 214 216
:3 0 80 :2 0 84
:4 0 ef 218 21a
:3 0 80 :2 0 85
:3 0 66 :3 0 5
:3 0 f2 21e 220
86 :4 0 f4 21d
223 f7 21c 225
:3 0 80 :2 0 84
:4 0 fa 227 229
:3 0 80 :2 0 83
:4 0 fd 22b 22d
:3 0 80 :2 0 7
:3 0 100 22f 231
:3 0 80 :2 0 83
:4 0 103 233 235
:3 0 80 :2 0 84
:4 0 106 237 239
:3 0 80 :2 0 83
:4 0 109 23b 23d
:3 0 80 :2 0 8
:3 0 10c 23f 241
:3 0 80 :2 0 83
:4 0 10f 243 245
:3 0 80 :2 0 84
:4 0 112 247 249
:3 0 80 :2 0 83
:4 0 115 24b 24d
:3 0 80 :2 0 9
:3 0 118 24f 251
:3 0 80 :2 0 83
:4 0 11b 253 255
:3 0 80 :2 0 84
:4 0 11e 257 259
:3 0 80 :2 0 85
:3 0 66 :3 0 a
:3 0 121 25d 25f
86 :4 0 123 25c
262 126 25b 264
:3 0 80 :2 0 84
:4 0 129 266 268
:3 0 80 :2 0 83
:4 0 12c 26a 26c
:3 0 80 :2 0 b
:3 0 12f 26e 270
:3 0 80 :2 0 83
:4 0 132 272 274
:3 0 80 :2 0 84
:4 0 135 276 278
:3 0 80 :2 0 85
:3 0 66 :3 0 c
:3 0 138 27c 27e
86 :4 0 13a 27b
281 13d 27a 283
:3 0 80 :2 0 84
:4 0 140 285 287
:3 0 80 :2 0 85
:3 0 66 :3 0 d
:3 0 143 28b 28d
86 :4 0 145 28a
290 148 289 292
:3 0 80 :2 0 84
:4 0 14b 294 296
:3 0 80 :2 0 85
:3 0 66 :3 0 e
:3 0 14e 29a 29c
86 :4 0 150 299
29f 153 298 2a1
:3 0 80 :2 0 84
:4 0 156 2a3 2a5
:3 0 80 :2 0 85
:3 0 66 :3 0 f
:3 0 159 2a9 2ab
86 :4 0 15b 2a8
2ae 15e 2a7 2b0
:3 0 80 :2 0 84
:4 0 161 2b2 2b4
:3 0 80 :2 0 85
:3 0 66 :3 0 10
:3 0 164 2b8 2ba
86 :4 0 166 2b7
2bd 169 2b6 2bf
:3 0 80 :2 0 84
:4 0 16c 2c1 2c3
:3 0 80 :2 0 85
:3 0 66 :3 0 11
:3 0 16f 2c7 2c9
86 :4 0 171 2c6
2cc 174 2c5 2ce
:3 0 80 :2 0 84
:4 0 177 2d0 2d2
:3 0 80 :2 0 83
:4 0 17a 2d4 2d6
:3 0 80 :2 0 12
:3 0 17d 2d8 2da
:3 0 80 :2 0 83
:4 0 180 2dc 2de
:3 0 80 :2 0 84
:4 0 183 2e0 2e2
:3 0 80 :2 0 83
:4 0 186 2e4 2e6
:3 0 80 :2 0 13
:3 0 189 2e8 2ea
:3 0 80 :2 0 83
:4 0 18c 2ec 2ee
:3 0 80 :2 0 84
:4 0 18f 2f0 2f2
:3 0 80 :2 0 85
:3 0 66 :3 0 14
:3 0 192 2f6 2f8
86 :4 0 194 2f5
2fb 197 2f4 2fd
:3 0 80 :2 0 84
:4 0 19a 2ff 301
:3 0 80 :2 0 85
:3 0 66 :3 0 15
:3 0 19d 305 307
86 :4 0 19f 304
30a 1a2 303 30c
:3 0 80 :2 0 84
:4 0 1a5 30e 310
:3 0 80 :2 0 83
:4 0 1a8 312 314
:3 0 80 :2 0 16
:3 0 1ab 316 318
:3 0 80 :2 0 83
:4 0 1ae 31a 31c
:3 0 80 :2 0 84
:4 0 1b1 31e 320
:3 0 80 :2 0 83
:4 0 1b4 322 324
:3 0 80 :2 0 17
:3 0 1b7 326 328
:3 0 80 :2 0 83
:4 0 1ba 32a 32c
:3 0 80 :2 0 84
:4 0 1bd 32e 330
:3 0 80 :2 0 85
:3 0 66 :3 0 18
:3 0 1c0 334 336
86 :4 0 1c2 333
339 1c5 332 33b
:3 0 80 :2 0 84
:4 0 1c8 33d 33f
:3 0 80 :2 0 83
:4 0 1cb 341 343
:3 0 80 :2 0 19
:3 0 1ce 345 347
:3 0 80 :2 0 83
:4 0 1d1 349 34b
:3 0 80 :2 0 87
:4 0 1d4 34d 34f
:3 0 1d7 1fe 351
:2 0 353 1dc 354
1fb 353 0 355
1de 0 1dd1 78
:3 0 79 :3 0 356
357 0 78 :3 0
88 :3 0 359 35a
0 49 :2 0 2
:4 0 89 :2 0 8a
:2 0 49 :2 0 1e0
35f 361 :3 0 1e3
35b 363 358 365
364 :2 0 7b :3 0
8b :3 0 367 368
0 7d :4 0 8c
:4 0 80 :2 0 81
:3 0 1e7 36c 36e
:3 0 1ea 369 370
:2 0 372 1ed 373
366 372 0 374
1ef 0 1dd1 5
:3 0 8d :2 0 1f1
376 377 :3 0 378
:2 0 379 :2 0 85
:3 0 5 :3 0 31
:2 0 1f3 37b 37e
8e :2 0 49 :2 0
1f8 380 382 :3 0
383 :2 0 85 :3 0
5 :3 0 31 :2 0
1fb 385 388 8f
:2 0 90 :2 0 200
38a 38c :3 0 38d
:2 0 384 38f 38e
:2 0 390 :2 0 37a
392 391 :2 0 78
:3 0 79 :3 0 394
395 0 78 :3 0
88 :3 0 397 398
0 91 :2 0 2
:4 0 92 :2 0 8a
:2 0 49 :2 0 203
39d 39f :3 0 206
399 3a1 396 3a3
3a2 :2 0 7b :3 0
8b :3 0 3a5 3a6
0 7d :4 0 93
:4 0 80 :2 0 81
:3 0 20a 3aa 3ac
:3 0 80 :2 0 94
:4 0 20d 3ae 3b0
:3 0 80 :2 0 95
:4 0 210 3b2 3b4
:3 0 80 :2 0 85
:3 0 66 :3 0 96
:3 0 97 :3 0 3b9
3ba 0 213 3b8
3bc 86 :4 0 215
3b7 3bf 218 3b6
3c1 :3 0 21b 3a7
3c3 :2 0 3c5 21e
3c6 3a4 3c5 0
3c7 220 0 3f0
78 :3 0 79 :3 0
3c8 3c9 0 78
:3 0 88 :3 0 3cb
3cc 0 49 :2 0
2 :4 0 98 :2 0
8a :2 0 49 :2 0
222 3d1 3d3 :3 0
225 3cd 3d5 3ca
3d7 3d6 :2 0 7b
:3 0 8b :3 0 3d9
3da 0 7d :4 0
99 :4 0 80 :2 0
81 :3 0 229 3de
3e0 :3 0 22c 3db
3e2 :2 0 3e4 22f
3e5 3d8 3e4 0
3e6 231 0 3f0
9a :3 0 9b :3 0
3e7 3e8 0 96
:3 0 97 :3 0 3ea
3eb 0 9c :3 0
233 3e9 3ee :2 0
3f0 236 3f1 393
3f0 0 3f2 23a
0 1dd1 3 :3 0
8d :2 0 23c 3f4
3f5 :3 0 3f6 :2 0
3f7 :2 0 f :3 0
8d :2 0 23e 3fa
3fb :3 0 3fc :2 0
3fd :2 0 3f8 3ff
3fe :2 0 19 :3 0
8d :2 0 240 402
403 :3 0 404 :2 0
405 :2 0 400 407
406 :2 0 78 :3 0
79 :3 0 409 40a
0 78 :3 0 88
:3 0 40c 40d 0
91 :2 0 2 :4 0
9d :2 0 8a :2 0
49 :2 0 242 412
414 :3 0 245 40e
416 40b 418 417
:2 0 7b :3 0 8b
:3 0 41a 41b 0
7d :4 0 9e :4 0
80 :2 0 81 :3 0
249 41f 421 :3 0
80 :2 0 94 :4 0
24c 423 425 :3 0
80 :2 0 95 :4 0
24f 427 429 :3 0
80 :2 0 85 :3 0
66 :3 0 96 :3 0
97 :3 0 42e 42f
0 252 42d 431
86 :4 0 254 42c
434 257 42b 436
:3 0 25a 41c 438
:2 0 43a 25d 43b
419 43a 0 43c
25f 0 465 78
:3 0 79 :3 0 43d
43e 0 78 :3 0
88 :3 0 440 441
0 49 :2 0 2
:4 0 9f :2 0 8a
:2 0 49 :2 0 261
446 448 :3 0 264
442 44a 43f 44c
44b :2 0 7b :3 0
8b :3 0 44e 44f
0 7d :4 0 a0
:4 0 80 :2 0 81
:3 0 268 453 455
:3 0 26b 450 457
:2 0 459 26e 45a
44d 459 0 45b
270 0 465 9a
:3 0 9b :3 0 45c
45d 0 96 :3 0
97 :3 0 45f 460
0 9c :3 0 272
45e 463 :2 0 465
275 466 408 465
0 467 279 0
1dd1 4d :4 0 468
469 0 1dd1 4f
:4 0 46b 46c 0
1dd1 32 :3 0 a1
:2 0 46e 46f 0
1dd1 4c :3 0 8
:3 0 471 472 0
1dd1 4e :3 0 9
:3 0 474 475 0
1dd1 51 :3 0 b
:3 0 477 478 0
1dd1 2f :3 0 19
:3 0 47a 47b 0
1dd1 3d :3 0 a
:3 0 47d 47e 0
1dd1 41 :3 0 f
:3 0 480 481 0
1dd1 57 :3 0 5
:3 0 483 484 0
1dd1 39 :3 0 10
:3 0 486 487 0
1dd1 4d :3 0 16
:3 0 489 48a 0
1dd1 42 :3 0 c
:3 0 48c 48d 0
1dd1 55 :3 0 31
:2 0 48f 490 0
1dd1 85 :3 0 a2
:3 0 51 :3 0 27b
493 495 31 :2 0
27d 492 498 96
:3 0 8e :2 0 a3
:3 0 49a 49c 0
282 49b 49e :3 0
85 :3 0 57 :3 0
31 :2 0 285 4a0
4a3 a4 :2 0 49
:2 0 28a 4a5 4a7
:3 0 4a8 :2 0 85
:3 0 57 :3 0 31
:2 0 28d 4aa 4ad
a4 :2 0 90 :2 0
292 4af 4b1 :3 0
4b2 :2 0 4a9 4b4
4b3 :2 0 7 :3 0
8d :2 0 295 4b7
4b8 :3 0 4b9 :2 0
78 :3 0 79 :3 0
4bb 4bc 0 78
:3 0 88 :3 0 4be
4bf 0 91 :2 0
2 :4 0 a5 :2 0
8a :2 0 49 :2 0
297 4c4 4c6 :3 0
29a 4c0 4c8 4bd
4ca 4c9 :2 0 7b
:3 0 8b :3 0 4cc
4cd 0 7d :4 0
a6 :4 0 80 :2 0
81 :3 0 29e 4d1
4d3 :3 0 80 :2 0
94 :4 0 2a1 4d5
4d7 :3 0 80 :2 0
95 :4 0 2a4 4d9
4db :3 0 80 :2 0
85 :3 0 66 :3 0
96 :3 0 97 :3 0
4e0 4e1 0 2a7
4df 4e3 86 :4 0
2a9 4de 4e6 2ac
4dd 4e8 :3 0 2af
4ce 4ea :2 0 4ec
2b2 4ed 4cb 4ec
0 4ee 2b4 0
517 78 :3 0 79
:3 0 4ef 4f0 0
78 :3 0 88 :3 0
4f2 4f3 0 49
:2 0 2 :4 0 a7
:2 0 8a :2 0 49
:2 0 2b6 4f8 4fa
:3 0 2b9 4f4 4fc
4f1 4fe 4fd :2 0
7b :3 0 8b :3 0
500 501 0 7d
:4 0 a8 :4 0 80
:2 0 81 :3 0 2bd
505 507 :3 0 2c0
502 509 :2 0 50b
2c3 50c 4ff 50b
0 50d 2c5 0
517 9a :3 0 9b
:3 0 50e 50f 0
96 :3 0 97 :3 0
511 512 0 9c
:3 0 2c7 510 515
:2 0 517 2ca 518
4ba 517 0 519
2ce 0 6b4 2c
:3 0 3 :3 0 51a
51b 0 6b4 2e
:3 0 7 :3 0 51d
51e 0 6b4 2f
:3 0 19 :3 0 520
521 0 6b4 6a
:3 0 a9 :3 0 2d
:3 0 30 :3 0 69
:3 0 6b :3 0 2e
:4 0 aa 1 :8 0
530 1b :3 0 ab
:3 0 52b 52c 0
ac :3 0 52d 52e
0 530 2d0 583
ad :3 0 1b :3 0
ab :3 0 532 533
0 ac :3 0 534
535 0 537 2d3
539 2d5 538 537
:2 0 581 ae :3 0
1b :3 0 ab :3 0
53c 53d 0 ac
:3 0 53e 53f 0
579 78 :3 0 79
:3 0 541 542 0
78 :3 0 88 :3 0
544 545 0 25
:2 0 2 :4 0 af
:2 0 8a :2 0 49
:2 0 2d7 54a 54c
:3 0 2da 546 54e
543 550 54f :2 0
7b :3 0 8b :3 0
552 553 0 7d
:4 0 b0 :4 0 80
:2 0 81 :3 0 2de
557 559 :3 0 80
:2 0 94 :4 0 2e1
55b 55d :3 0 80
:2 0 b1 :4 0 2e4
55f 561 :3 0 80
:2 0 ac :3 0 2e7
563 565 :3 0 80
:2 0 b2 :4 0 2ea
567 569 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 2ed 56c 570
2f1 56b 572 :3 0
2f4 554 574 :2 0
576 2f7 577 551
576 0 578 2f9
0 579 2fb 57c
:3 0 57c 0 57c
57b 579 57a :6 0
57e 4 :3 0 2fe
580 300 57f 57e
:2 0 581 302 :2 0
583 0 583 582
530 581 :6 0 6b4
1 :3 0 53 :3 0
31 :2 0 585 586
0 6b4 b6 :3 0
53 :3 0 b7 :3 0
b8 :3 0 6a :3 0
2d :3 0 b9 :3 0
2c :4 0 ba 1
:8 0 596 1b :3 0
ab :3 0 591 592
0 ac :3 0 593
594 0 596 305
5e9 ad :3 0 1b
:3 0 ab :3 0 598
599 0 ac :3 0
59a 59b 0 59d
308 59f 30a 59e
59d :2 0 5e7 ae
:3 0 1b :3 0 ab
:3 0 5a2 5a3 0
ac :3 0 5a4 5a5
0 5df 78 :3 0
79 :3 0 5a7 5a8
0 78 :3 0 88
:3 0 5aa 5ab 0
25 :2 0 2 :4 0
bb :2 0 8a :2 0
49 :2 0 30c 5b0
5b2 :3 0 30f 5ac
5b4 5a9 5b6 5b5
:2 0 7b :3 0 8b
:3 0 5b8 5b9 0
7d :4 0 bc :4 0
80 :2 0 81 :3 0
313 5bd 5bf :3 0
80 :2 0 94 :4 0
316 5c1 5c3 :3 0
80 :2 0 b1 :4 0
319 5c5 5c7 :3 0
80 :2 0 ac :3 0
31c 5c9 5cb :3 0
80 :2 0 b2 :4 0
31f 5cd 5cf :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 322 5d2
5d6 326 5d1 5d8
:3 0 329 5ba 5da
:2 0 5dc 32c 5dd
5b7 5dc 0 5de
32e 0 5df 330
5e2 :3 0 5e2 0
5e2 5e1 5df 5e0
:6 0 5e4 6 :3 0
333 5e6 335 5e5
5e4 :2 0 5e7 337
:2 0 5e9 0 5e9
5e8 596 5e7 :6 0
6b4 1 :3 0 85
:3 0 53 :3 0 31
:2 0 33a 5eb 5ee
bd :2 0 31 :2 0
33f 5f0 5f2 :3 0
5f3 :2 0 85 :3 0
57 :3 0 31 :2 0
342 5f5 5f8 a4
:2 0 90 :2 0 347
5fa 5fc :3 0 5fd
:2 0 5f4 5ff 5fe
:2 0 85 :3 0 3d
:3 0 31 :2 0 34a
601 604 a4 :2 0
31 :2 0 34f 606
608 :3 0 609 :2 0
600 60b 60a :2 0
78 :3 0 79 :3 0
60d 60e 0 78
:3 0 88 :3 0 610
611 0 27 :2 0
2 :4 0 be :2 0
8a :2 0 49 :2 0
352 616 618 :3 0
355 612 61a 60f
61c 61b :2 0 7b
:3 0 8b :3 0 61e
61f 0 7d :4 0
bf :4 0 80 :2 0
81 :3 0 359 623
625 :3 0 80 :2 0
94 :4 0 35c 627
629 :3 0 80 :2 0
95 :4 0 35f 62b
62d :3 0 80 :2 0
85 :3 0 66 :3 0
31 :2 0 362 631
633 86 :4 0 364
630 636 367 62f
638 :3 0 80 :2 0
c0 :4 0 36a 63a
63c :3 0 80 :2 0
83 :4 0 36d 63e
640 :3 0 80 :2 0
2c :3 0 370 642
644 :3 0 80 :2 0
83 :4 0 373 646
648 :3 0 376 620
64a :2 0 64c 379
64d 61d 64c 0
64e 37b 0 676
78 :3 0 79 :3 0
64f 650 0 78
:3 0 88 :3 0 652
653 0 49 :2 0
2 :4 0 c1 :2 0
8a :2 0 49 :2 0
37d 658 65a :3 0
380 654 65c 651
65e 65d :2 0 7b
:3 0 8b :3 0 660
661 0 7d :4 0
c2 :4 0 80 :2 0
81 :3 0 384 665
667 :3 0 387 662
669 :2 0 66b 38a
66c 65f 66b 0
66d 38c 0 676
9a :3 0 c3 :3 0
66e 66f 0 31
:2 0 2c :3 0 9c
:3 0 38e 670 674
:2 0 676 392 6b1
2b :3 0 c4 :4 0
678 679 :3 0 677
67a 0 6b0 52
:3 0 c5 :3 0 85
:3 0 30 :3 0 31
:2 0 396 67e 681
399 67d 683 67c
684 0 6b0 54
:3 0 c6 :3 0 52
:3 0 30 :3 0 2e
:3 0 2c :3 0 2f
:3 0 2b :3 0 39b
687 68e 686 68f
0 6b0 85 :3 0
57 :3 0 31 :2 0
3a2 691 694 a4
:2 0 49 :2 0 3a7
696 698 :3 0 699
:2 0 c7 :3 0 85
:3 0 30 :3 0 31
:2 0 3aa 69c 69f
3ad 69b 6a1 6a2
:2 0 bd :2 0 31
:2 0 3b1 6a4 6a6
:3 0 69a 6a8 6a7
:2 0 57 :3 0 90
:2 0 6aa 6ab 0
6ad 3b4 6ae 6a9
6ad 0 6af 3b6
0 6b0 3b8 6b2
60c 676 0 6b3
0 6b0 0 6b3
3bd 0 6b4 3c0
7b1 2b :3 0 3
:3 0 6b5 6b6 0
7b0 6a :3 0 c8
:3 0 c9 :3 0 ca
:3 0 cb :3 0 cc
:3 0 cd :3 0 ce
:3 0 cf :3 0 6c
:3 0 2d :3 0 2e
:3 0 2c :3 0 42
:3 0 47 :3 0 61
:3 0 36 :3 0 37
:3 0 38 :3 0 4f
:3 0 d0 :3 0 74
:3 0 2b :4 0 d1
1 :8 0 6d5 1b
:3 0 ab :3 0 6d0
6d1 0 ac :3 0
6d2 6d3 0 6d5
3c9 728 ad :3 0
1b :3 0 ab :3 0
6d7 6d8 0 ac
:3 0 6d9 6da 0
6dc 3cc 6de 3ce
6dd 6dc :2 0 726
ae :3 0 1b :3 0
ab :3 0 6e1 6e2
0 ac :3 0 6e3
6e4 0 71e 78
:3 0 79 :3 0 6e6
6e7 0 78 :3 0
88 :3 0 6e9 6ea
0 25 :2 0 2
:4 0 d2 :2 0 8a
:2 0 49 :2 0 3d0
6ef 6f1 :3 0 3d3
6eb 6f3 6e8 6f5
6f4 :2 0 7b :3 0
8b :3 0 6f7 6f8
0 7d :4 0 d3
:4 0 80 :2 0 81
:3 0 3d7 6fc 6fe
:3 0 80 :2 0 94
:4 0 3da 700 702
:3 0 80 :2 0 b1
:4 0 3dd 704 706
:3 0 80 :2 0 ac
:3 0 3e0 708 70a
:3 0 80 :2 0 b2
:4 0 3e3 70c 70e
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 3e6
711 715 3ea 710
717 :3 0 3ed 6f9
719 :2 0 71b 3f0
71c 6f6 71b 0
71d 3f2 0 71e
3f4 721 :3 0 721
0 721 720 71e
71f :6 0 723 8
:3 0 3f7 725 3f9
724 723 :2 0 726
3fb :2 0 728 0
728 727 6d5 726
:6 0 7b0 1 :3 0
1b :3 0 ab :3 0
72a 72b 0 1b
:3 0 a4 :2 0 d4
:3 0 72d 72f 0
400 72e 731 :3 0
732 :2 0 85 :3 0
c :3 0 31 :2 0
403 734 737 85
:3 0 bd :2 0 42
:3 0 31 :2 0 406
739 73d 40b 73a
73f :3 0 740 :2 0
733 742 741 :2 0
78 :3 0 79 :3 0
744 745 0 78
:3 0 88 :3 0 747
748 0 27 :2 0
2 :4 0 d5 :2 0
8a :2 0 49 :2 0
40e 74d 74f :3 0
411 749 751 746
753 752 :2 0 7b
:3 0 8b :3 0 755
756 0 7d :4 0
d6 :4 0 80 :2 0
81 :3 0 415 75a
75c :3 0 80 :2 0
94 :4 0 418 75e
760 :3 0 80 :2 0
95 :4 0 41b 762
764 :3 0 80 :2 0
85 :3 0 66 :3 0
31 :2 0 41e 768
76a 86 :4 0 420
767 76d 423 766
76f :3 0 80 :2 0
c0 :4 0 426 771
773 :3 0 80 :2 0
83 :4 0 429 775
777 :3 0 80 :2 0
2b :3 0 42c 779
77b :3 0 80 :2 0
83 :4 0 42f 77d
77f :3 0 432 757
781 :2 0 783 435
784 754 783 0
785 437 0 7ad
78 :3 0 79 :3 0
786 787 0 78
:3 0 88 :3 0 789
78a 0 49 :2 0
2 :4 0 d7 :2 0
8a :2 0 49 :2 0
439 78f 791 :3 0
43c 78b 793 788
795 794 :2 0 7b
:3 0 8b :3 0 797
798 0 7d :4 0
d8 :4 0 80 :2 0
81 :3 0 440 79c
79e :3 0 443 799
7a0 :2 0 7a2 446
7a3 796 7a2 0
7a4 448 0 7ad
9a :3 0 c3 :3 0
7a5 7a6 0 31
:2 0 2b :3 0 9c
:3 0 44a 7a7 7ab
:2 0 7ad 44e 7ae
743 7ad 0 7af
452 0 7b0 454
7b2 4b5 6b4 0
7b3 0 7b0 0
7b3 458 0 1d80
85 :3 0 57 :3 0
31 :2 0 45b 7b4
7b7 bd :2 0 90
:2 0 460 7b9 7bb
:3 0 1b :3 0 ab
:3 0 7bd 7be 0
bd :2 0 31 :2 0
465 7c0 7c2 :3 0
78 :3 0 79 :3 0
7c4 7c5 0 78
:3 0 88 :3 0 7c7
7c8 0 27 :2 0
2 :4 0 d9 :2 0
8a :2 0 49 :2 0
468 7cd 7cf :3 0
46b 7c9 7d1 7c6
7d3 7d2 :2 0 7b
:3 0 8b :3 0 7d5
7d6 0 7d :4 0
da :4 0 80 :2 0
81 :3 0 46f 7da
7dc :3 0 80 :2 0
94 :4 0 472 7de
7e0 :3 0 80 :2 0
95 :4 0 475 7e2
7e4 :3 0 80 :2 0
85 :3 0 66 :3 0
1b :3 0 ab :3 0
7e9 7ea 0 478
7e8 7ec 86 :4 0
47a 7e7 7ef 47d
7e6 7f1 :3 0 80
:2 0 c0 :4 0 480
7f3 7f5 :3 0 80
:2 0 83 :4 0 483
7f7 7f9 :3 0 80
:2 0 2b :3 0 486
7fb 7fd :3 0 80
:2 0 83 :4 0 489
7ff 801 :3 0 48c
7d7 803 :2 0 805
48f 806 7d4 805
0 807 491 0
831 78 :3 0 79
:3 0 808 809 0
78 :3 0 88 :3 0
80b 80c 0 49
:2 0 2 :4 0 db
:2 0 8a :2 0 49
:2 0 493 811 813
:3 0 496 80d 815
80a 817 816 :2 0
7b :3 0 8b :3 0
819 81a 0 7d
:4 0 dc :4 0 80
:2 0 81 :3 0 49a
81e 820 :3 0 49d
81b 822 :2 0 824
4a0 825 818 824
0 826 4a2 0
831 9a :3 0 c3
:3 0 827 828 0
1b :3 0 ab :3 0
82a 82b 0 2b
:3 0 9c :3 0 4a4
829 82f :2 0 831
4a8 832 7c3 831
0 833 4ac 0
1d6e 4c :3 0 8d
:2 0 4ae 835 836
:3 0 837 :2 0 4e
:3 0 8d :2 0 4b0
83a 83b :3 0 83c
:2 0 838 83e 83d
:2 0 3d :3 0 8d
:2 0 4b2 841 842
:3 0 843 :2 0 83f
845 844 :2 0 51
:3 0 8d :2 0 4b4
848 849 :3 0 84a
:2 0 846 84c 84b
:2 0 78 :3 0 79
:3 0 84e 84f 0
78 :3 0 88 :3 0
851 852 0 91
:2 0 2 :4 0 dd
:2 0 8a :2 0 49
:2 0 4b6 857 859
:3 0 4b9 853 85b
850 85d 85c :2 0
7b :3 0 8b :3 0
85f 860 0 7d
:4 0 de :4 0 80
:2 0 81 :3 0 4bd
864 866 :3 0 80
:2 0 94 :4 0 4c0
868 86a :3 0 80
:2 0 95 :4 0 4c3
86c 86e :3 0 80
:2 0 85 :3 0 66
:3 0 96 :3 0 97
:3 0 873 874 0
4c6 872 876 86
:4 0 4c8 871 879
4cb 870 87b :3 0
4ce 861 87d :2 0
87f 4d1 880 85e
87f 0 881 4d3
0 8aa 78 :3 0
79 :3 0 882 883
0 78 :3 0 88
:3 0 885 886 0
49 :2 0 2 :4 0
df :2 0 8a :2 0
49 :2 0 4d5 88b
88d :3 0 4d8 887
88f 884 891 890
:2 0 7b :3 0 8b
:3 0 893 894 0
7d :4 0 e0 :4 0
80 :2 0 81 :3 0
4dc 898 89a :3 0
4df 895 89c :2 0
89e 4e2 89f 892
89e 0 8a0 4e4
0 8aa 9a :3 0
9b :3 0 8a1 8a2
0 96 :3 0 97
:3 0 8a4 8a5 0
9c :3 0 4e6 8a3
8a8 :2 0 8aa 4e9
8ab 84d 8aa 0
8ac 4ed 0 1d6e
3c :3 0 96 :3 0
e1 :3 0 8ae 8af
0 8ad 8b0 0
1d6e 85 :3 0 39
:3 0 31 :2 0 4ef
8b2 8b5 8f :2 0
e2 :2 0 4f4 8b7
8b9 :3 0 39 :3 0
e2 :2 0 8bb 8bc
0 8be 4f7 8bf
8ba 8be 0 8c0
4f9 0 1d6e 85
:3 0 e3 :3 0 3a
:3 0 69 :3 0 6b
:3 0 2e :4 0 e4
1 :8 0 8cd 1b
:3 0 ab :3 0 8c8
8c9 0 ac :3 0
8ca 8cb 0 8cd
4fb 920 ad :3 0
1b :3 0 ab :3 0
8cf 8d0 0 ac
:3 0 8d1 8d2 0
8d4 4fe 8d6 500
8d5 8d4 :2 0 91e
ae :3 0 1b :3 0
ab :3 0 8d9 8da
0 ac :3 0 8db
8dc 0 916 78
:3 0 79 :3 0 8de
8df 0 78 :3 0
88 :3 0 8e1 8e2
0 25 :2 0 2
:4 0 e5 :2 0 8a
:2 0 49 :2 0 502
8e7 8e9 :3 0 505
8e3 8eb 8e0 8ed
8ec :2 0 7b :3 0
8b :3 0 8ef 8f0
0 7d :4 0 e6
:4 0 80 :2 0 81
:3 0 509 8f4 8f6
:3 0 80 :2 0 94
:4 0 50c 8f8 8fa
:3 0 80 :2 0 b1
:4 0 50f 8fc 8fe
:3 0 80 :2 0 ac
:3 0 512 900 902
:3 0 80 :2 0 b2
:4 0 515 904 906
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 518
909 90d 51c 908
90f :3 0 51f 8f1
911 :2 0 913 522
914 8ee 913 0
915 524 0 916
526 919 :3 0 919
0 919 918 916
917 :6 0 91b a
:3 0 529 91d 52b
91c 91b :2 0 91e
52d :2 0 920 0
920 91f 8cd 91e
:6 0 1d6e 1 :3 0
85 :3 0 36 :3 0
31 :2 0 530 922
925 8f :2 0 31
:2 0 535 927 929
:3 0 53 :3 0 e7
:3 0 85 :3 0 e8
:3 0 36 :3 0 538
92e 930 31 :2 0
53a 92d 933 e9
:2 0 85 :3 0 e8
:3 0 3a :3 0 53d
937 939 31 :2 0
53f 936 93c 542
935 93e :3 0 93f
:2 0 ea :2 0 eb
:2 0 545 941 943
:3 0 944 :2 0 8a
:2 0 ec :2 0 548
946 948 :3 0 54b
92c 94a 92b 94b
0 968 85 :3 0
39 :3 0 31 :2 0
54d 94d 950 85
:3 0 bd :2 0 53
:3 0 31 :2 0 550
952 956 555 953
958 :3 0 36 :3 0
31 :2 0 95a 95b
0 960 37 :3 0
31 :2 0 95d 95e
0 960 558 965
39 :3 0 31 :2 0
961 962 0 964
55b 966 959 960
0 967 0 964
0 967 55d 0
968 560 969 92a
968 0 96a 563
0 1d6e 48 :4 0
96b 96c 0 1d6e
ed :3 0 85 :3 0
f :3 0 31 :2 0
565 96f 972 25
:2 0 568 96e 975
976 :2 0 a4 :2 0
25 :2 0 56d 978
97a :3 0 85 :3 0
57 :3 0 31 :2 0
570 97c 97f a4
:2 0 49 :2 0 575
981 983 :3 0 85
:3 0 c :3 0 31
:2 0 578 985 988
8f :2 0 31 :2 0
57d 98a 98c :3 0
1b :3 0 ab :3 0
98e 98f 0 ee
:3 0 2b :3 0 48
:3 0 48 :3 0 32
:3 0 4c :3 0 4e
:3 0 3d :3 0 36
:3 0 33 :3 0 33
:3 0 34 :3 0 3c
:3 0 37 :3 0 38
:3 0 55 :3 0 51
:3 0 2f :3 0 580
991 9a3 990 9a4
0 a2a 1b :3 0
ab :3 0 9a6 9a7
0 a4 :2 0 31
:2 0 594 9a9 9ab
:3 0 d0 :3 0 ef
:3 0 e :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 f4
:3 0 f5 :3 0 6a
:3 0 2d :3 0 c8
:3 0 2e :3 0 c9
:3 0 2c :4 0 f6
1 :8 0 9d2 f7
:4 0 9bd :3 0 9c
:3 0 a4 :2 0 599
9c0 9c1 :3 0 1b
:3 0 ab :3 0 9c3
9c4 0 31 :2 0
9c5 9c6 0 9c8
59c 9cf 1b :3 0
ab :3 0 9c9 9ca
0 f8 :2 0 9cb
9cc 0 9ce 59e
9d0 9c2 9c8 0
9d1 0 9ce 0
9d1 5a0 0 9d2
5a3 a25 ad :3 0
1b :3 0 ab :3 0
9d4 9d5 0 ac
:3 0 9d6 9d7 0
9d9 5a6 9db 5a8
9da 9d9 :2 0 a23
ae :3 0 1b :3 0
ab :3 0 9de 9df
0 ac :3 0 9e0
9e1 0 a1b 78
:3 0 79 :3 0 9e3
9e4 0 78 :3 0
88 :3 0 9e6 9e7
0 25 :2 0 2
:4 0 f9 :2 0 8a
:2 0 49 :2 0 5aa
9ec 9ee :3 0 5ad
9e8 9f0 9e5 9f2
9f1 :2 0 7b :3 0
8b :3 0 9f4 9f5
0 7d :4 0 fa
:4 0 80 :2 0 81
:3 0 5b1 9f9 9fb
:3 0 80 :2 0 94
:4 0 5b4 9fd 9ff
:3 0 80 :2 0 b1
:4 0 5b7 a01 a03
:3 0 80 :2 0 ac
:3 0 5ba a05 a07
:3 0 80 :2 0 b2
:4 0 5bd a09 a0b
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 5c0
a0e a12 5c4 a0d
a14 :3 0 5c7 9f6
a16 :2 0 a18 5ca
a19 9f3 a18 0
a1a 5cc 0 a1b
5ce a1e :3 0 a1e
0 a1e a1d a1b
a1c :6 0 a20 c
:3 0 5d1 a22 5d3
a21 a20 :2 0 a23
5d5 :2 0 a25 0
a25 a24 9d2 a23
:6 0 a27 1 :3 0
5d8 a28 9ac a27
0 a29 5da 0
a2a 5dc a44 1b
:3 0 ab :3 0 a2b
a2c 0 ee :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
33 :3 0 3c :3 0
37 :3 0 38 :3 0
55 :3 0 51 :3 0
2f :3 0 5df a2e
a40 a2d a41 0
a43 5f1 a45 98d
a2a 0 a46 0
a43 0 a46 5f3
0 a47 5f6 b12
3c :3 0 85 :3 0
3c :3 0 31 :2 0
5f8 a49 a4c 8a
:2 0 49 :2 0 5fb
a4e a50 :3 0 a48
a51 0 b11 85
:3 0 c :3 0 31
:2 0 5fe a53 a56
8f :2 0 31 :2 0
603 a58 a5a :3 0
1b :3 0 ab :3 0
a5c a5d 0 ee
:3 0 2b :3 0 48
:3 0 48 :3 0 32
:3 0 4c :3 0 4e
:3 0 3d :3 0 36
:3 0 33 :3 0 33
:3 0 34 :3 0 3c
:3 0 37 :3 0 38
:3 0 55 :3 0 51
:3 0 2f :3 0 606
a5f a71 a5e a72
0 af4 1b :3 0
ab :3 0 a74 a75
0 a4 :2 0 31
:2 0 61a a77 a79
:3 0 d0 :3 0 ef
:3 0 e :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 f4
:3 0 f5 :3 0 74
:3 0 2b :4 0 fb
1 :8 0 a9c f7
:4 0 a87 :3 0 9c
:3 0 a4 :2 0 61f
a8a a8b :3 0 1b
:3 0 ab :3 0 a8d
a8e 0 31 :2 0
a8f a90 0 a92
622 a99 1b :3 0
ab :3 0 a93 a94
0 f8 :2 0 a95
a96 0 a98 624
a9a a8c a92 0
a9b 0 a98 0
a9b 626 0 a9c
629 aef ad :3 0
1b :3 0 ab :3 0
a9e a9f 0 ac
:3 0 aa0 aa1 0
aa3 62c aa5 62e
aa4 aa3 :2 0 aed
ae :3 0 1b :3 0
ab :3 0 aa8 aa9
0 ac :3 0 aaa
aab 0 ae5 78
:3 0 79 :3 0 aad
aae 0 78 :3 0
88 :3 0 ab0 ab1
0 25 :2 0 2
:4 0 fc :2 0 8a
:2 0 49 :2 0 630
ab6 ab8 :3 0 633
ab2 aba aaf abc
abb :2 0 7b :3 0
8b :3 0 abe abf
0 7d :4 0 fd
:4 0 80 :2 0 81
:3 0 637 ac3 ac5
:3 0 80 :2 0 94
:4 0 63a ac7 ac9
:3 0 80 :2 0 b1
:4 0 63d acb acd
:3 0 80 :2 0 ac
:3 0 640 acf ad1
:3 0 80 :2 0 b2
:4 0 643 ad3 ad5
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 646
ad8 adc 64a ad7
ade :3 0 64d ac0
ae0 :2 0 ae2 650
ae3 abd ae2 0
ae4 652 0 ae5
654 ae8 :3 0 ae8
0 ae8 ae7 ae5
ae6 :6 0 aea e
:3 0 657 aec 659
aeb aea :2 0 aed
65b :2 0 aef 0
aef aee a9c aed
:6 0 af1 1 :3 0
65e af2 a7a af1
0 af3 660 0
af4 662 b0e 1b
:3 0 ab :3 0 af5
af6 0 ee :3 0
2b :3 0 48 :3 0
48 :3 0 32 :3 0
4c :3 0 4e :3 0
3d :3 0 36 :3 0
33 :3 0 33 :3 0
33 :3 0 3c :3 0
37 :3 0 38 :3 0
55 :3 0 51 :3 0
2f :3 0 665 af8
b0a af7 b0b 0
b0d 677 b0f a5b
af4 0 b10 0
b0d 0 b10 679
0 b11 67c b13
984 a47 0 b14
0 b11 0 b14
67f 0 d37 1b
:3 0 ab :3 0 b15
b16 0 a4 :2 0
31 :2 0 684 b18
b1a :3 0 b1b :2 0
ed :3 0 85 :3 0
f :3 0 31 :2 0
687 b1e b21 35
:2 0 68a b1d b24
b25 :2 0 a4 :2 0
35 :2 0 68f b27
b29 :3 0 b2a :2 0
b1c b2c b2b :2 0
85 :3 0 c :3 0
31 :2 0 692 b2e
b31 85 :3 0 a4
:2 0 a :3 0 31
:2 0 695 b33 b37
69a b34 b39 :3 0
b3a :2 0 85 :3 0
e :3 0 31 :2 0
69d b3c b3f a4
:2 0 31 :2 0 6a2
b41 b43 :3 0 b44
:2 0 b3b b46 b45
:2 0 85 :3 0 d
:3 0 31 :2 0 6a5
b48 b4b a4 :2 0
eb :2 0 6aa b4d
b4f :3 0 b50 :2 0
b47 b52 b51 :2 0
d0 :3 0 fe :3 0
d :3 0 cc :3 0
39 :3 0 cf :3 0
38 :3 0 f0 :3 0
f1 :3 0 f2 :3 0
f3 :3 0 f4 :3 0
f5 :3 0 ff :3 0
4c :3 0 100 :3 0
4e :3 0 ca :3 0
c :3 0 ef :3 0
e :3 0 74 :3 0
2b :4 0 101 1
:8 0 b81 f7 :4 0
b6c :3 0 9c :3 0
a4 :2 0 6af b6f
b70 :3 0 1b :3 0
ab :3 0 b72 b73
0 31 :2 0 b74
b75 0 b77 6b2
b7e 1b :3 0 ab
:3 0 b78 b79 0
f8 :2 0 b7a b7b
0 b7d 6b4 b7f
b71 b77 0 b80
0 b7d 0 b80
6b6 0 b81 6b9
bd4 ad :3 0 1b
:3 0 ab :3 0 b83
b84 0 ac :3 0
b85 b86 0 b88
6bc b8a 6be b89
b88 :2 0 bd2 ae
:3 0 1b :3 0 ab
:3 0 b8d b8e 0
ac :3 0 b8f b90
0 bca 78 :3 0
79 :3 0 b92 b93
0 78 :3 0 88
:3 0 b95 b96 0
25 :2 0 2 :4 0
102 :2 0 8a :2 0
49 :2 0 6c0 b9b
b9d :3 0 6c3 b97
b9f b94 ba1 ba0
:2 0 7b :3 0 8b
:3 0 ba3 ba4 0
7d :4 0 103 :4 0
80 :2 0 81 :3 0
6c7 ba8 baa :3 0
80 :2 0 94 :4 0
6ca bac bae :3 0
80 :2 0 b1 :4 0
6cd bb0 bb2 :3 0
80 :2 0 ac :3 0
6d0 bb4 bb6 :3 0
80 :2 0 b2 :4 0
6d3 bb8 bba :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 6d6 bbd
bc1 6da bbc bc3
:3 0 6dd ba5 bc5
:2 0 bc7 6e0 bc8
ba2 bc7 0 bc9
6e2 0 bca 6e4
bcd :3 0 bcd 0
bcd bcc bca bcb
:6 0 bcf 10 :3 0
6e7 bd1 6e9 bd0
bcf :2 0 bd2 6eb
:2 0 bd4 0 bd4
bd3 b81 bd2 :6 0
cb9 1 :3 0 73
:3 0 75 :3 0 70
:3 0 72 :3 0 6a
:3 0 2d :3 0 74
:3 0 2b :4 0 104
1 :8 0 bf4 f7
:4 0 bdf :3 0 9c
:3 0 a4 :2 0 6f0
be2 be3 :3 0 1b
:3 0 ab :3 0 be5
be6 0 31 :2 0
be7 be8 0 bea
6f3 bf1 1b :3 0
ab :3 0 beb bec
0 f8 :2 0 bed
bee 0 bf0 6f5
bf2 be4 bea 0
bf3 0 bf0 0
bf3 6f7 0 bf4
6fa c47 ad :3 0
1b :3 0 ab :3 0
bf6 bf7 0 ac
:3 0 bf8 bf9 0
bfb 6fd bfd 6ff
bfc bfb :2 0 c45
ae :3 0 1b :3 0
ab :3 0 c00 c01
0 ac :3 0 c02
c03 0 c3d 78
:3 0 79 :3 0 c05
c06 0 78 :3 0
88 :3 0 c08 c09
0 25 :2 0 2
:4 0 105 :2 0 8a
:2 0 49 :2 0 701
c0e c10 :3 0 704
c0a c12 c07 c14
c13 :2 0 7b :3 0
8b :3 0 c16 c17
0 7d :4 0 106
:4 0 80 :2 0 81
:3 0 708 c1b c1d
:3 0 80 :2 0 94
:4 0 70b c1f c21
:3 0 80 :2 0 b1
:4 0 70e c23 c25
:3 0 80 :2 0 ac
:3 0 711 c27 c29
:3 0 80 :2 0 b2
:4 0 714 c2b c2d
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 717
c30 c34 71b c2f
c36 :3 0 71e c18
c38 :2 0 c3a 721
c3b c15 c3a 0
c3c 723 0 c3d
725 c40 :3 0 c40
0 c40 c3f c3d
c3e :6 0 c42 12
:3 0 728 c44 72a
c43 c42 :2 0 c45
72c :2 0 c47 0
c47 c46 bf4 c45
:6 0 cb9 1 :3 0
d0 :3 0 107 :3 0
4e :3 0 74 :3 0
2b :4 0 108 1
:8 0 c64 f7 :4 0
c4f :3 0 9c :3 0
a4 :2 0 731 c52
c53 :3 0 1b :3 0
ab :3 0 c55 c56
0 31 :2 0 c57
c58 0 c5a 734
c61 1b :3 0 ab
:3 0 c5b c5c 0
f8 :2 0 c5d c5e
0 c60 736 c62
c54 c5a 0 c63
0 c60 0 c63
738 0 c64 73b
cb7 ad :3 0 1b
:3 0 ab :3 0 c66
c67 0 ac :3 0
c68 c69 0 c6b
73e c6d 740 c6c
c6b :2 0 cb5 ae
:3 0 1b :3 0 ab
:3 0 c70 c71 0
ac :3 0 c72 c73
0 cad 78 :3 0
79 :3 0 c75 c76
0 78 :3 0 88
:3 0 c78 c79 0
25 :2 0 2 :4 0
109 :2 0 8a :2 0
49 :2 0 742 c7e
c80 :3 0 745 c7a
c82 c77 c84 c83
:2 0 7b :3 0 8b
:3 0 c86 c87 0
7d :4 0 10a :4 0
80 :2 0 81 :3 0
749 c8b c8d :3 0
80 :2 0 94 :4 0
74c c8f c91 :3 0
80 :2 0 b1 :4 0
74f c93 c95 :3 0
80 :2 0 ac :3 0
752 c97 c99 :3 0
80 :2 0 b2 :4 0
755 c9b c9d :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 758 ca0
ca4 75c c9f ca6
:3 0 75f c88 ca8
:2 0 caa 762 cab
c85 caa 0 cac
764 0 cad 766
cb0 :3 0 cb0 0
cb0 caf cad cae
:6 0 cb2 14 :3 0
769 cb4 76b cb3
cb2 :2 0 cb5 76d
:2 0 cb7 0 cb7
cb6 c64 cb5 :6 0
cb9 1 :3 0 770
d31 d0 :3 0 ef
:3 0 e :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 f4
:3 0 f5 :3 0 74
:3 0 2b :4 0 10b
1 :8 0 cdb f7
:4 0 cc6 :3 0 9c
:3 0 a4 :2 0 776
cc9 cca :3 0 1b
:3 0 ab :3 0 ccc
ccd 0 31 :2 0
cce ccf 0 cd1
779 cd8 1b :3 0
ab :3 0 cd2 cd3
0 f8 :2 0 cd4
cd5 0 cd7 77b
cd9 ccb cd1 0
cda 0 cd7 0
cda 77d 0 cdb
780 d2e ad :3 0
1b :3 0 ab :3 0
cdd cde 0 ac
:3 0 cdf ce0 0
ce2 783 ce4 785
ce3 ce2 :2 0 d2c
ae :3 0 1b :3 0
ab :3 0 ce7 ce8
0 ac :3 0 ce9
cea 0 d24 78
:3 0 79 :3 0 cec
ced 0 78 :3 0
88 :3 0 cef cf0
0 25 :2 0 2
:4 0 10c :2 0 8a
:2 0 49 :2 0 787
cf5 cf7 :3 0 78a
cf1 cf9 cee cfb
cfa :2 0 7b :3 0
8b :3 0 cfd cfe
0 7d :4 0 10d
:4 0 80 :2 0 81
:3 0 78e d02 d04
:3 0 80 :2 0 94
:4 0 791 d06 d08
:3 0 80 :2 0 b1
:4 0 794 d0a d0c
:3 0 80 :2 0 ac
:3 0 797 d0e d10
:3 0 80 :2 0 b2
:4 0 79a d12 d14
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 79d
d17 d1b 7a1 d16
d1d :3 0 7a4 cff
d1f :2 0 d21 7a7
d22 cfc d21 0
d23 7a9 0 d24
7ab d27 :3 0 d27
0 d27 d26 d24
d25 :6 0 d29 16
:3 0 7ae d2b 7b0
d2a d29 :2 0 d2c
7b2 :2 0 d2e 0
d2e d2d cdb d2c
:6 0 d30 1 :3 0
7b5 d32 b53 cb9
0 d33 0 d30
0 d33 7b7 0
d34 7ba d35 b2d
d34 0 d36 7bc
0 d37 7be 115f
41 :3 0 ed :3 0
85 :3 0 41 :3 0
31 :2 0 7c1 d3a
d3d 96 :3 0 10e
:3 0 d3f d40 0
7c4 d39 d42 d38
d43 0 115e 85
:3 0 57 :3 0 31
:2 0 7c7 d45 d48
a4 :2 0 49 :2 0
7cc d4a d4c :3 0
1b :3 0 ab :3 0
d4e d4f 0 ee
:3 0 2b :3 0 48
:3 0 48 :3 0 32
:3 0 4c :3 0 4e
:3 0 3d :3 0 36
:3 0 33 :3 0 33
:3 0 41 :3 0 3c
:3 0 37 :3 0 38
:3 0 55 :3 0 51
:3 0 2f :3 0 7cf
d51 d63 d50 d64
0 e03 1b :3 0
ab :3 0 d66 d67
0 a4 :2 0 31
:2 0 7e3 d69 d6b
:3 0 d6c :2 0 85
:3 0 f :3 0 31
:2 0 7e6 d6e d71
a4 :2 0 35 :2 0
7eb d73 d75 :3 0
d76 :2 0 d6d d78
d77 :2 0 85 :3 0
3e :3 0 31 :2 0
7ee d7a d7d a4
:2 0 31 :2 0 7f3
d7f d81 :3 0 d82
:2 0 d79 d84 d83
:2 0 d0 :3 0 ef
:3 0 e :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 f4
:3 0 f5 :3 0 6a
:3 0 2d :3 0 c8
:3 0 2e :3 0 c9
:3 0 2c :4 0 10f
1 :8 0 dab f7
:4 0 d96 :3 0 9c
:3 0 a4 :2 0 7f8
d99 d9a :3 0 1b
:3 0 ab :3 0 d9c
d9d 0 31 :2 0
d9e d9f 0 da1
7fb da8 1b :3 0
ab :3 0 da2 da3
0 f8 :2 0 da4
da5 0 da7 7fd
da9 d9b da1 0
daa 0 da7 0
daa 7ff 0 dab
802 dfe ad :3 0
1b :3 0 ab :3 0
dad dae 0 ac
:3 0 daf db0 0
db2 805 db4 807
db3 db2 :2 0 dfc
ae :3 0 1b :3 0
ab :3 0 db7 db8
0 ac :3 0 db9
dba 0 df4 78
:3 0 79 :3 0 dbc
dbd 0 78 :3 0
88 :3 0 dbf dc0
0 25 :2 0 2
:4 0 110 :2 0 8a
:2 0 49 :2 0 809
dc5 dc7 :3 0 80c
dc1 dc9 dbe dcb
dca :2 0 7b :3 0
8b :3 0 dcd dce
0 7d :4 0 111
:4 0 80 :2 0 81
:3 0 810 dd2 dd4
:3 0 80 :2 0 94
:4 0 813 dd6 dd8
:3 0 80 :2 0 b1
:4 0 816 dda ddc
:3 0 80 :2 0 ac
:3 0 819 dde de0
:3 0 80 :2 0 b2
:4 0 81c de2 de4
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 81f
de7 deb 823 de6
ded :3 0 826 dcf
def :2 0 df1 829
df2 dcc df1 0
df3 82b 0 df4
82d df7 :3 0 df7
0 df7 df6 df4
df5 :6 0 df9 18
:3 0 830 dfb 832
dfa df9 :2 0 dfc
834 :2 0 dfe 0
dfe dfd dab dfc
:6 0 e00 1 :3 0
837 e01 d85 e00
0 e02 839 0
e03 83b 115b 12
:3 0 112 :2 0 83e
e05 e06 :3 0 e07
:2 0 50 :3 0 12
:3 0 e09 e0a 0
109b b3 :3 0 50
:3 0 b3 :3 0 50
:3 0 b3 :3 0 50
:3 0 b3 :3 0 50
:3 0 50 :3 0 b7
:4 0 113 1 :8 0
e1c 1b :3 0 ab
:3 0 e17 e18 0
ac :3 0 e19 e1a
0 e1c 840 e6f
ad :3 0 1b :3 0
ab :3 0 e1e e1f
0 ac :3 0 e20
e21 0 e23 843
e25 845 e24 e23
:2 0 e6d ae :3 0
1b :3 0 ab :3 0
e28 e29 0 ac
:3 0 e2a e2b 0
e65 78 :3 0 79
:3 0 e2d e2e 0
78 :3 0 88 :3 0
e30 e31 0 25
:2 0 2 :4 0 114
:2 0 8a :2 0 49
:2 0 847 e36 e38
:3 0 84a e32 e3a
e2f e3c e3b :2 0
7b :3 0 8b :3 0
e3e e3f 0 7d
:4 0 115 :4 0 80
:2 0 81 :3 0 84e
e43 e45 :3 0 80
:2 0 94 :4 0 851
e47 e49 :3 0 80
:2 0 b1 :4 0 854
e4b e4d :3 0 80
:2 0 ac :3 0 857
e4f e51 :3 0 80
:2 0 b2 :4 0 85a
e53 e55 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 85d e58 e5c
861 e57 e5e :3 0
864 e40 e60 :2 0
e62 867 e63 e3d
e62 0 e64 869
0 e65 86b e68
:3 0 e68 0 e68
e67 e65 e66 :6 0
e6a 1a :3 0 86e
e6c 870 e6b e6a
:2 0 e6d 872 :2 0
e6f 0 e6f e6e
e1c e6d :6 0 109b
1 :3 0 116 :3 0
117 :3 0 e71 e72
0 50 :3 0 4f
:3 0 118 :2 0 875
e73 e77 8e :2 0
31 :2 0 87b e79
e7b :3 0 30 :3 0
96 :3 0 119 :3 0
e7e e7f 0 e7d
e80 0 1098 52
:3 0 49 :2 0 e82
e83 0 1098 6b
:3 0 29 :3 0 11a
:3 0 11b :4 0 11c
1 :8 0 e8f 1b
:3 0 ab :3 0 e8a
e8b 0 ac :3 0
e8c e8d 0 e8f
87e ee2 ad :3 0
1b :3 0 ab :3 0
e91 e92 0 ac
:3 0 e93 e94 0
e96 881 e98 883
e97 e96 :2 0 ee0
ae :3 0 1b :3 0
ab :3 0 e9b e9c
0 ac :3 0 e9d
e9e 0 ed8 78
:3 0 79 :3 0 ea0
ea1 0 78 :3 0
88 :3 0 ea3 ea4
0 25 :2 0 2
:4 0 11d :2 0 8a
:2 0 49 :2 0 885
ea9 eab :3 0 888
ea5 ead ea2 eaf
eae :2 0 7b :3 0
8b :3 0 eb1 eb2
0 7d :4 0 11e
:4 0 80 :2 0 81
:3 0 88c eb6 eb8
:3 0 80 :2 0 94
:4 0 88f eba ebc
:3 0 80 :2 0 b1
:4 0 892 ebe ec0
:3 0 80 :2 0 ac
:3 0 895 ec2 ec4
:3 0 80 :2 0 b2
:4 0 898 ec6 ec8
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 89b
ecb ecf 89f eca
ed1 :3 0 8a2 eb3
ed3 :2 0 ed5 8a5
ed6 eb0 ed5 0
ed7 8a7 0 ed8
8a9 edb :3 0 edb
0 edb eda ed8
ed9 :6 0 edd 1c
:3 0 8ac edf 8ae
ede edd :2 0 ee0
8b0 :2 0 ee2 0
ee2 ee1 e8f ee0
:6 0 1098 1 :3 0
54 :3 0 11f :3 0
52 :3 0 2e :3 0
29 :3 0 30 :3 0
2f :3 0 2a :3 0
8b3 ee5 eec ee4
eed 0 1098 85
:3 0 54 :3 0 31
:2 0 8ba eef ef2
a4 :2 0 31 :2 0
8bf ef4 ef6 :3 0
26 :4 0 ef8 ef9
0 1095 28 :4 0
efb efc 0 1095
1d :4 0 efe eff
0 1095 24 :4 0
f01 f02 0 1095
1f :4 0 f04 f05
0 1095 120 :3 0
63 :4 0 f0a :2 0
1095 f08 f0b :3 0
63 :3 0 1d :3 0
24 :4 0 f10 :2 0
1095 f0c f11 :3 0
8c2 :3 0 63 :3 0
f7 :3 0 f12 f13
:3 0 1b :3 0 ab
:3 0 f15 f16 0
31 :2 0 f17 f18
0 f1a 8c5 f21
1b :3 0 ab :3 0
f1b f1c 0 f8
:2 0 f1d f1e 0
f20 8c7 f22 f14
f1a 0 f23 0
f20 0 f23 8c9
0 1095 121 :3 0
63 :4 0 f27 :2 0
f2d f25 0 1b
:3 0 ab :3 0 f28
f29 0 ac :3 0
f2a f2b 0 f2d
8cc f80 ad :3 0
1b :3 0 ab :3 0
f2f f30 0 ac
:3 0 f31 f32 0
f34 8cf f36 8d1
f35 f34 :2 0 f7e
ae :3 0 1b :3 0
ab :3 0 f39 f3a
0 ac :3 0 f3b
f3c 0 f76 78
:3 0 79 :3 0 f3e
f3f 0 78 :3 0
88 :3 0 f41 f42
0 25 :2 0 2
:4 0 122 :2 0 8a
:2 0 49 :2 0 8d3
f47 f49 :3 0 8d6
f43 f4b f40 f4d
f4c :2 0 7b :3 0
8b :3 0 f4f f50
0 7d :4 0 123
:4 0 80 :2 0 81
:3 0 8da f54 f56
:3 0 80 :2 0 94
:4 0 8dd f58 f5a
:3 0 80 :2 0 b1
:4 0 8e0 f5c f5e
:3 0 80 :2 0 ac
:3 0 8e3 f60 f62
:3 0 80 :2 0 b2
:4 0 8e6 f64 f66
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 8e9
f69 f6d 8ed f68
f6f :3 0 8f0 f51
f71 :2 0 f73 8f3
f74 f4e f73 0
f75 8f5 0 f76
8f7 f79 :3 0 f79
0 f79 f78 f76
f77 :6 0 f7b 1e
:3 0 8fa f7d 8fc
f7c f7b :2 0 f7e
8fe :2 0 f80 0
f80 f7f f2d f7e
:6 0 1095 1 :3 0
124 :3 0 1f :3 0
125 :3 0 c9 :3 0
2c :4 0 126 1
:8 0 f8d 1b :3 0
ab :3 0 f88 f89
0 ac :3 0 f8a
f8b 0 f8d 901
fe0 ad :3 0 1b
:3 0 ab :3 0 f8f
f90 0 ac :3 0
f91 f92 0 f94
904 f96 906 f95
f94 :2 0 fde ae
:3 0 1b :3 0 ab
:3 0 f99 f9a 0
ac :3 0 f9b f9c
0 fd6 78 :3 0
79 :3 0 f9e f9f
0 78 :3 0 88
:3 0 fa1 fa2 0
25 :2 0 2 :4 0
127 :2 0 8a :2 0
49 :2 0 908 fa7
fa9 :3 0 90b fa3
fab fa0 fad fac
:2 0 7b :3 0 8b
:3 0 faf fb0 0
7d :4 0 128 :4 0
80 :2 0 81 :3 0
90f fb4 fb6 :3 0
80 :2 0 94 :4 0
912 fb8 fba :3 0
80 :2 0 b1 :4 0
915 fbc fbe :3 0
80 :2 0 ac :3 0
918 fc0 fc2 :3 0
80 :2 0 b2 :4 0
91b fc4 fc6 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 91e fc9
fcd 922 fc8 fcf
:3 0 925 fb1 fd1
:2 0 fd3 928 fd4
fae fd3 0 fd5
92a 0 fd6 92c
fd9 :3 0 fd9 0
fd9 fd8 fd6 fd7
:6 0 fdb 20 :3 0
92f fdd 931 fdc
fdb :2 0 fde 933
:2 0 fe0 0 fe0
fdf f8d fde :6 0
1095 1 :3 0 22
:3 0 129 :4 0 fe2
fe3 0 1095 20
:3 0 12a :4 0 fe5
fe6 0 1095 20
:3 0 b3 :3 0 20
:3 0 80 :2 0 1f
:3 0 936 feb fed
:3 0 49 :2 0 21
:2 0 939 fe9 ff1
fe8 ff2 0 1095
20 :3 0 b3 :3 0
20 :3 0 80 :2 0
12b :4 0 93d ff7
ff9 :3 0 49 :2 0
21 :2 0 940 ff5
ffd ff4 ffe 0
1095 20 :3 0 b3
:3 0 20 :3 0 80
:2 0 1d :3 0 944
1003 1005 :3 0 49
:2 0 21 :2 0 947
1001 1009 1000 100a
0 1095 20 :3 0
b3 :3 0 20 :3 0
80 :2 0 12c :4 0
94b 100f 1011 :3 0
49 :2 0 21 :2 0
94e 100d 1015 100c
1016 0 1095 54
:3 0 12d :3 0 2a
:3 0 24 :3 0 33
:3 0 33 :3 0 48
:3 0 33 :3 0 22
:3 0 20 :3 0 2f
:3 0 48 :3 0 48
:3 0 33 :3 0 26
:3 0 28 :3 0 2f
:3 0 952 1019 1029
1018 102a 0 1095
78 :3 0 79 :3 0
102c 102d 0 78
:3 0 88 :3 0 102f
1030 0 27 :2 0
2 :4 0 12e :2 0
8a :2 0 49 :2 0
962 1035 1037 :3 0
965 1031 1039 102e
103b 103a :2 0 7b
:3 0 8b :3 0 103d
103e 0 7d :4 0
12f :4 0 80 :2 0
81 :3 0 969 1042
1044 :3 0 80 :2 0
94 :4 0 96c 1046
1048 :3 0 80 :2 0
95 :4 0 96f 104a
104c :3 0 80 :2 0
85 :3 0 66 :3 0
31 :2 0 972 1050
1052 86 :4 0 974
104f 1055 977 104e
1057 :3 0 80 :2 0
c0 :4 0 97a 1059
105b :3 0 80 :2 0
83 :4 0 97d 105d
105f :3 0 80 :2 0
2b :3 0 980 1061
1063 :3 0 80 :2 0
83 :4 0 983 1065
1067 :3 0 986 103f
1069 :2 0 106b 989
106c 103c 106b 0
106d 98b 0 1095
78 :3 0 79 :3 0
106e 106f 0 78
:3 0 88 :3 0 1071
1072 0 49 :2 0
2 :4 0 130 :2 0
8a :2 0 49 :2 0
98d 1077 1079 :3 0
990 1073 107b 1070
107d 107c :2 0 7b
:3 0 8b :3 0 107f
1080 0 7d :4 0
131 :4 0 80 :2 0
81 :3 0 994 1084
1086 :3 0 997 1081
1088 :2 0 108a 99a
108b 107e 108a 0
108c 99c 0 1095
9a :3 0 c3 :3 0
108d 108e 0 31
:2 0 2b :3 0 9c
:3 0 99e 108f 1093
:2 0 1095 9a2 1096
ef7 1095 0 1097
9b7 0 1098 9b9
1099 e7c 1098 0
109a 9bf 0 109b
9c1 109c e08 109b
0 109d 9c5 0
115a 3c :3 0 85
:3 0 3c :3 0 31
:2 0 9c7 109f 10a2
8a :2 0 49 :2 0
9ca 10a4 10a6 :3 0
109e 10a7 0 115a
1b :3 0 ab :3 0
10a9 10aa 0 ee
:3 0 2b :3 0 48
:3 0 48 :3 0 32
:3 0 4c :3 0 4e
:3 0 3d :3 0 36
:3 0 33 :3 0 33
:3 0 41 :3 0 3c
:3 0 37 :3 0 38
:3 0 55 :3 0 51
:3 0 2f :3 0 9cd
10ac 10be 10ab 10bf
0 115a 1b :3 0
ab :3 0 10c1 10c2
0 a4 :2 0 31
:2 0 9e1 10c4 10c6
:3 0 10c7 :2 0 85
:3 0 f :3 0 31
:2 0 9e4 10c9 10cc
a4 :2 0 35 :2 0
9e9 10ce 10d0 :3 0
10d1 :2 0 10c8 10d3
10d2 :2 0 85 :3 0
3e :3 0 31 :2 0
9ec 10d5 10d8 a4
:2 0 31 :2 0 9f1
10da 10dc :3 0 10dd
:2 0 10d4 10df 10de
:2 0 d0 :3 0 ef
:3 0 e :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 f4
:3 0 f5 :3 0 74
:3 0 2b :4 0 10b
1 :8 0 1102 f7
:4 0 10ed :3 0 9c
:3 0 a4 :2 0 9f6
10f0 10f1 :3 0 1b
:3 0 ab :3 0 10f3
10f4 0 31 :2 0
10f5 10f6 0 10f8
9f9 10ff 1b :3 0
ab :3 0 10f9 10fa
0 f8 :2 0 10fb
10fc 0 10fe 9fb
1100 10f2 10f8 0
1101 0 10fe 0
1101 9fd 0 1102
a00 1155 ad :3 0
1b :3 0 ab :3 0
1104 1105 0 ac
:3 0 1106 1107 0
1109 a03 110b a05
110a 1109 :2 0 1153
ae :3 0 1b :3 0
ab :3 0 110e 110f
0 ac :3 0 1110
1111 0 114b 78
:3 0 79 :3 0 1113
1114 0 78 :3 0
88 :3 0 1116 1117
0 25 :2 0 2
:4 0 132 :2 0 8a
:2 0 49 :2 0 a07
111c 111e :3 0 a0a
1118 1120 1115 1122
1121 :2 0 7b :3 0
8b :3 0 1124 1125
0 7d :4 0 133
:4 0 80 :2 0 81
:3 0 a0e 1129 112b
:3 0 80 :2 0 94
:4 0 a11 112d 112f
:3 0 80 :2 0 b1
:4 0 a14 1131 1133
:3 0 80 :2 0 ac
:3 0 a17 1135 1137
:3 0 80 :2 0 b2
:4 0 a1a 1139 113b
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 a1d
113e 1142 a21 113d
1144 :3 0 a24 1126
1146 :2 0 1148 a27
1149 1123 1148 0
114a a29 0 114b
a2b 114e :3 0 114e
0 114e 114d 114b
114c :6 0 1150 22
:3 0 a2e 1152 a30
1151 1150 :2 0 1153
a32 :2 0 1155 0
1155 1154 1102 1153
:6 0 1157 1 :3 0
a35 1158 10e0 1157
0 1159 a37 0
115a a39 115c d4d
e03 0 115d 0
115a 0 115d a3e
0 115e a41 1160
97b d37 0 1161
0 115e 0 1161
a44 0 1d6e 1b
:3 0 ab :3 0 1162
1163 0 bd :2 0
31 :2 0 a49 1165
1167 :3 0 78 :3 0
79 :3 0 1169 116a
0 78 :3 0 88
:3 0 116c 116d 0
27 :2 0 2 :4 0
134 :2 0 8a :2 0
49 :2 0 a4c 1172
1174 :3 0 a4f 116e
1176 116b 1178 1177
:2 0 7b :3 0 8b
:3 0 117a 117b 0
7d :4 0 135 :4 0
80 :2 0 81 :3 0
a53 117f 1181 :3 0
80 :2 0 94 :4 0
a56 1183 1185 :3 0
80 :2 0 95 :4 0
a59 1187 1189 :3 0
80 :2 0 85 :3 0
66 :3 0 1b :3 0
ab :3 0 118e 118f
0 a5c 118d 1191
86 :4 0 a5e 118c
1194 a61 118b 1196
:3 0 80 :2 0 c0
:4 0 a64 1198 119a
:3 0 80 :2 0 83
:4 0 a67 119c 119e
:3 0 80 :2 0 2b
:3 0 a6a 11a0 11a2
:3 0 80 :2 0 83
:4 0 a6d 11a4 11a6
:3 0 a70 117c 11a8
:2 0 11aa a73 11ab
1179 11aa 0 11ac
a75 0 11d6 78
:3 0 79 :3 0 11ad
11ae 0 78 :3 0
88 :3 0 11b0 11b1
0 49 :2 0 2
:4 0 136 :2 0 8a
:2 0 49 :2 0 a77
11b6 11b8 :3 0 a7a
11b2 11ba 11af 11bc
11bb :2 0 7b :3 0
8b :3 0 11be 11bf
0 7d :4 0 137
:4 0 80 :2 0 81
:3 0 a7e 11c3 11c5
:3 0 a81 11c0 11c7
:2 0 11c9 a84 11ca
11bd 11c9 0 11cb
a86 0 11d6 9a
:3 0 c3 :3 0 11cc
11cd 0 1b :3 0
ab :3 0 11cf 11d0
0 2b :3 0 9c
:3 0 a88 11ce 11d4
:2 0 11d6 a8c 11d7
1168 11d6 0 11d8
a90 0 1d6e 38
:3 0 11 :3 0 11d9
11da 0 1d6e 85
:3 0 39 :3 0 31
:2 0 a92 11dc 11df
bd :2 0 eb :2 0
a97 11e1 11e3 :3 0
11e4 :2 0 85 :3 0
38 :3 0 31 :2 0
a9a 11e6 11e9 a4
:2 0 31 :2 0 a9f
11eb 11ed :3 0 11ee
:2 0 11e5 11f0 11ef
:2 0 38 :3 0 49
:2 0 11f2 11f3 0
11f5 aa2 11f6 11f1
11f5 0 11f7 aa4
0 1d6e 85 :3 0
57 :3 0 31 :2 0
aa6 11f8 11fb a4
:2 0 49 :2 0 aab
11fd 11ff :3 0 ed
:3 0 85 :3 0 f
:3 0 31 :2 0 aae
1202 1205 25 :2 0
ab1 1201 1208 1209
:2 0 a4 :2 0 25
:2 0 ab6 120b 120d
:3 0 12 :3 0 8d
:2 0 ab9 1210 1211
:3 0 1212 :2 0 4d
:3 0 112 :2 0 abb
1215 1216 :3 0 1217
:2 0 d0 :3 0 fe
:3 0 d :3 0 cc
:3 0 39 :3 0 cf
:3 0 38 :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 f4
:3 0 f5 :3 0 ff
:3 0 16 :3 0 100
:3 0 17 :3 0 ca
:3 0 18 :3 0 138
:3 0 2b :4 0 139
1 :8 0 1244 f7
:4 0 122f :3 0 9c
:3 0 a4 :2 0 abf
1232 1233 :3 0 1b
:3 0 ab :3 0 1235
1236 0 31 :2 0
1237 1238 0 123a
ac2 1241 1b :3 0
ab :3 0 123b 123c
0 f8 :2 0 123d
123e 0 1240 ac4
1242 1234 123a 0
1243 0 1240 0
1243 ac6 0 1244
ac9 1297 ad :3 0
1b :3 0 ab :3 0
1246 1247 0 ac
:3 0 1248 1249 0
124b acc 124d ace
124c 124b :2 0 1295
ae :3 0 1b :3 0
ab :3 0 1250 1251
0 ac :3 0 1252
1253 0 128d 78
:3 0 79 :3 0 1255
1256 0 78 :3 0
88 :3 0 1258 1259
0 25 :2 0 2
:4 0 13a :2 0 8a
:2 0 49 :2 0 ad0
125e 1260 :3 0 ad3
125a 1262 1257 1264
1263 :2 0 7b :3 0
8b :3 0 1266 1267
0 7d :4 0 13b
:4 0 80 :2 0 81
:3 0 ad7 126b 126d
:3 0 80 :2 0 94
:4 0 ada 126f 1271
:3 0 80 :2 0 b1
:4 0 add 1273 1275
:3 0 80 :2 0 ac
:3 0 ae0 1277 1279
:3 0 80 :2 0 b2
:4 0 ae3 127b 127d
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 ae6
1280 1284 aea 127f
1286 :3 0 aed 1268
1288 :2 0 128a af0
128b 1265 128a 0
128c af2 0 128d
af4 1290 :3 0 1290
0 1290 128f 128d
128e :6 0 1292 24
:3 0 af7 1294 af9
1293 1292 :2 0 1295
afb :2 0 1297 0
1297 1296 1244 1295
:6 0 1299 1 :3 0
afe 130f d0 :3 0
fe :3 0 d :3 0
cc :3 0 39 :3 0
cf :3 0 38 :3 0
138 :3 0 2b :4 0
13c 1 :8 0 12b9
f7 :4 0 12a4 :3 0
9c :3 0 a4 :2 0
b02 12a7 12a8 :3 0
1b :3 0 ab :3 0
12aa 12ab 0 31
:2 0 12ac 12ad 0
12af b05 12b6 1b
:3 0 ab :3 0 12b0
12b1 0 f8 :2 0
12b2 12b3 0 12b5
b07 12b7 12a9 12af
0 12b8 0 12b5
0 12b8 b09 0
12b9 b0c 130c ad
:3 0 1b :3 0 ab
:3 0 12bb 12bc 0
ac :3 0 12bd 12be
0 12c0 b0f 12c2
b11 12c1 12c0 :2 0
130a ae :3 0 1b
:3 0 ab :3 0 12c5
12c6 0 ac :3 0
12c7 12c8 0 1302
78 :3 0 79 :3 0
12ca 12cb 0 78
:3 0 88 :3 0 12cd
12ce 0 25 :2 0
2 :4 0 13d :2 0
8a :2 0 49 :2 0
b13 12d3 12d5 :3 0
b16 12cf 12d7 12cc
12d9 12d8 :2 0 7b
:3 0 8b :3 0 12db
12dc 0 7d :4 0
13e :4 0 80 :2 0
81 :3 0 b1a 12e0
12e2 :3 0 80 :2 0
94 :4 0 b1d 12e4
12e6 :3 0 80 :2 0
b1 :4 0 b20 12e8
12ea :3 0 80 :2 0
ac :3 0 b23 12ec
12ee :3 0 80 :2 0
b2 :4 0 b26 12f0
12f2 :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
b29 12f5 12f9 b2d
12f4 12fb :3 0 b30
12dd 12fd :2 0 12ff
b33 1300 12da 12ff
0 1301 b35 0
1302 b37 1305 :3 0
1305 0 1305 1304
1302 1303 :6 0 1307
26 :3 0 b3a 1309
b3c 1308 1307 :2 0
130a b3e :2 0 130c
0 130c 130b 12b9
130a :6 0 130e 1
:3 0 b41 1310 1218
1299 0 1311 0
130e 0 1311 b43
0 1312 b46 1476
4d :3 0 112 :2 0
b48 1314 1315 :3 0
1316 :2 0 d0 :3 0
fe :3 0 d :3 0
cc :3 0 39 :3 0
cf :3 0 38 :3 0
13f :3 0 140 :3 0
141 :3 0 12 :3 0
13f :3 0 142 :3 0
140 :3 0 141 :3 0
13 :3 0 142 :3 0
143 :3 0 140 :3 0
14 :3 0 143 :3 0
144 :3 0 140 :3 0
15 :3 0 144 :3 0
145 :3 0 146 :3 0
147 :3 0 148 :3 0
149 :3 0 14a :3 0
14b :3 0 14c :3 0
146 :3 0 12 :3 0
148 :3 0 13 :3 0
14a :3 0 14 :3 0
14c :3 0 15 :3 0
14d :3 0 15 :3 0
14e :3 0 14f :3 0
150 :3 0 15 :3 0
151 :3 0 152 :3 0
14e :3 0 153 :3 0
151 :3 0 154 :3 0
155 :3 0 156 :3 0
157 :3 0 140 :3 0
f0 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
f4 :3 0 f5 :3 0
ff :3 0 16 :3 0
100 :3 0 17 :3 0
ca :3 0 18 :3 0
138 :3 0 2b :4 0
158 1 :8 0 1375
f7 :4 0 1360 :3 0
9c :3 0 a4 :2 0
b4c 1363 1364 :3 0
1b :3 0 ab :3 0
1366 1367 0 31
:2 0 1368 1369 0
136b b4f 1372 1b
:3 0 ab :3 0 136c
136d 0 f8 :2 0
136e 136f 0 1371
b51 1373 1365 136b
0 1374 0 1371
0 1374 b53 0
1375 b56 13c8 ad
:3 0 1b :3 0 ab
:3 0 1377 1378 0
ac :3 0 1379 137a
0 137c b59 137e
b5b 137d 137c :2 0
13c6 ae :3 0 1b
:3 0 ab :3 0 1381
1382 0 ac :3 0
1383 1384 0 13be
78 :3 0 79 :3 0
1386 1387 0 78
:3 0 88 :3 0 1389
138a 0 25 :2 0
2 :4 0 159 :2 0
8a :2 0 49 :2 0
b5d 138f 1391 :3 0
b60 138b 1393 1388
1395 1394 :2 0 7b
:3 0 8b :3 0 1397
1398 0 7d :4 0
15a :4 0 80 :2 0
81 :3 0 b64 139c
139e :3 0 80 :2 0
94 :4 0 b67 13a0
13a2 :3 0 80 :2 0
b1 :4 0 b6a 13a4
13a6 :3 0 80 :2 0
ac :3 0 b6d 13a8
13aa :3 0 80 :2 0
b2 :4 0 b70 13ac
13ae :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
b73 13b1 13b5 b77
13b0 13b7 :3 0 b7a
1399 13b9 :2 0 13bb
b7d 13bc 1396 13bb
0 13bd b7f 0
13be b81 13c1 :3 0
13c1 0 13c1 13c0
13be 13bf :6 0 13c3
28 :3 0 b84 13c5
b86 13c4 13c3 :2 0
13c6 b88 :2 0 13c8
0 13c8 13c7 1375
13c6 :6 0 13ca 1
:3 0 b8b 1472 d0
:3 0 fe :3 0 d
:3 0 cc :3 0 39
:3 0 cf :3 0 38
:3 0 13f :3 0 140
:3 0 141 :3 0 12
:3 0 13f :3 0 142
:3 0 140 :3 0 141
:3 0 13 :3 0 142
:3 0 143 :3 0 140
:3 0 14 :3 0 143
:3 0 144 :3 0 140
:3 0 15 :3 0 144
:3 0 145 :3 0 146
:3 0 147 :3 0 148
:3 0 149 :3 0 14a
:3 0 14b :3 0 14c
:3 0 146 :3 0 12
:3 0 148 :3 0 13
:3 0 14a :3 0 14
:3 0 14c :3 0 15
:3 0 14d :3 0 15
:3 0 14e :3 0 14f
:3 0 150 :3 0 15
:3 0 151 :3 0 152
:3 0 14e :3 0 153
:3 0 151 :3 0 154
:3 0 155 :3 0 156
:3 0 157 :3 0 140
:3 0 138 :3 0 2b
:4 0 15b 1 :8 0
141c f7 :4 0 1407
:3 0 9c :3 0 a4
:2 0 b8f 140a 140b
:3 0 1b :3 0 ab
:3 0 140d 140e 0
31 :2 0 140f 1410
0 1412 b92 1419
1b :3 0 ab :3 0
1413 1414 0 f8
:2 0 1415 1416 0
1418 b94 141a 140c
1412 0 141b 0
1418 0 141b b96
0 141c b99 146f
ad :3 0 1b :3 0
ab :3 0 141e 141f
0 ac :3 0 1420
1421 0 1423 b9c
1425 b9e 1424 1423
:2 0 146d ae :3 0
1b :3 0 ab :3 0
1428 1429 0 ac
:3 0 142a 142b 0
1465 78 :3 0 79
:3 0 142d 142e 0
78 :3 0 88 :3 0
1430 1431 0 25
:2 0 2 :4 0 15c
:2 0 8a :2 0 49
:2 0 ba0 1436 1438
:3 0 ba3 1432 143a
142f 143c 143b :2 0
7b :3 0 8b :3 0
143e 143f 0 7d
:4 0 15d :4 0 80
:2 0 81 :3 0 ba7
1443 1445 :3 0 80
:2 0 94 :4 0 baa
1447 1449 :3 0 80
:2 0 b1 :4 0 bad
144b 144d :3 0 80
:2 0 ac :3 0 bb0
144f 1451 :3 0 80
:2 0 b2 :4 0 bb3
1453 1455 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 bb6 1458 145c
bba 1457 145e :3 0
bbd 1440 1460 :2 0
1462 bc0 1463 143d
1462 0 1464 bc2
0 1465 bc4 1468
:3 0 1468 0 1468
1467 1465 1466 :6 0
146a 2a :3 0 bc7
146c bc9 146b 146a
:2 0 146d bcb :2 0
146f 0 146f 146e
141c 146d :6 0 1471
1 :3 0 bce 1473
1317 13ca 0 1474
0 1471 0 1474
bd0 0 1475 bd3
1477 1213 1312 0
1478 0 1475 0
1478 bd5 0 147a
15e :3 0 bd8 14fa
85 :3 0 3e :3 0
31 :2 0 bda 147b
147e a4 :2 0 31
:2 0 bdf 1480 1482
:3 0 d0 :3 0 fe
:3 0 d :3 0 cc
:3 0 39 :3 0 cf
:3 0 38 :3 0 138
:3 0 2b :4 0 15f
1 :8 0 14a3 f7
:4 0 148e :3 0 9c
:3 0 a4 :2 0 be4
1491 1492 :3 0 1b
:3 0 ab :3 0 1494
1495 0 31 :2 0
1496 1497 0 1499
be7 14a0 1b :3 0
ab :3 0 149a 149b
0 f8 :2 0 149c
149d 0 149f be9
14a1 1493 1499 0
14a2 0 149f 0
14a2 beb 0 14a3
bee 14f6 ad :3 0
1b :3 0 ab :3 0
14a5 14a6 0 ac
:3 0 14a7 14a8 0
14aa bf1 14ac bf3
14ab 14aa :2 0 14f4
ae :3 0 1b :3 0
ab :3 0 14af 14b0
0 ac :3 0 14b1
14b2 0 14ec 78
:3 0 79 :3 0 14b4
14b5 0 78 :3 0
88 :3 0 14b7 14b8
0 25 :2 0 2
:4 0 160 :2 0 8a
:2 0 49 :2 0 bf5
14bd 14bf :3 0 bf8
14b9 14c1 14b6 14c3
14c2 :2 0 7b :3 0
8b :3 0 14c5 14c6
0 7d :4 0 161
:4 0 80 :2 0 81
:3 0 bfc 14ca 14cc
:3 0 80 :2 0 94
:4 0 bff 14ce 14d0
:3 0 80 :2 0 b1
:4 0 c02 14d2 14d4
:3 0 80 :2 0 ac
:3 0 c05 14d6 14d8
:3 0 80 :2 0 b2
:4 0 c08 14da 14dc
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 c0b
14df 14e3 c0f 14de
14e5 :3 0 c12 14c7
14e7 :2 0 14e9 c15
14ea 14c4 14e9 0
14eb c17 0 14ec
c19 14ef :3 0 14ef
0 14ef 14ee 14ec
14ed :6 0 14f1 2c
:3 0 c1c 14f3 c1e
14f2 14f1 :2 0 14f4
c20 :2 0 14f6 0
14f6 14f5 14a3 14f4
:6 0 14f8 1 :3 0
c23 14f9 1483 14f8
0 14fb 120e 147a
0 14fb c25 0
14fc c28 1906 ed
:3 0 85 :3 0 f
:3 0 31 :2 0 c2a
14fe 1501 25 :2 0
c2d 14fd 1504 1505
:2 0 a4 :2 0 25
:2 0 c32 1507 1509
:3 0 12 :3 0 8d
:2 0 c35 150c 150d
:3 0 150e :2 0 4d
:3 0 112 :2 0 c37
1511 1512 :3 0 1513
:2 0 d0 :3 0 fe
:3 0 d :3 0 cc
:3 0 39 :3 0 cf
:3 0 38 :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 f4
:3 0 f5 :3 0 ff
:3 0 16 :3 0 100
:3 0 17 :3 0 ca
:3 0 18 :3 0 74
:3 0 2b :4 0 162
1 :8 0 1540 f7
:4 0 152b :3 0 9c
:3 0 a4 :2 0 c3b
152e 152f :3 0 1b
:3 0 ab :3 0 1531
1532 0 31 :2 0
1533 1534 0 1536
c3e 153d 1b :3 0
ab :3 0 1537 1538
0 f8 :2 0 1539
153a 0 153c c40
153e 1530 1536 0
153f 0 153c 0
153f c42 0 1540
c45 1593 ad :3 0
1b :3 0 ab :3 0
1542 1543 0 ac
:3 0 1544 1545 0
1547 c48 1549 c4a
1548 1547 :2 0 1591
ae :3 0 1b :3 0
ab :3 0 154c 154d
0 ac :3 0 154e
154f 0 1589 78
:3 0 79 :3 0 1551
1552 0 78 :3 0
88 :3 0 1554 1555
0 25 :2 0 2
:4 0 163 :2 0 8a
:2 0 49 :2 0 c4c
155a 155c :3 0 c4f
1556 155e 1553 1560
155f :2 0 7b :3 0
8b :3 0 1562 1563
0 7d :4 0 164
:4 0 80 :2 0 81
:3 0 c53 1567 1569
:3 0 80 :2 0 94
:4 0 c56 156b 156d
:3 0 80 :2 0 b1
:4 0 c59 156f 1571
:3 0 80 :2 0 ac
:3 0 c5c 1573 1575
:3 0 80 :2 0 b2
:4 0 c5f 1577 1579
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 c62
157c 1580 c66 157b
1582 :3 0 c69 1564
1584 :2 0 1586 c6c
1587 1561 1586 0
1588 c6e 0 1589
c70 158c :3 0 158c
0 158c 158b 1589
158a :6 0 158e 2e
:3 0 c73 1590 c75
158f 158e :2 0 1591
c77 :2 0 1593 0
1593 1592 1540 1591
:6 0 1595 1 :3 0
c7a 160d d0 :3 0
fe :3 0 d :3 0
cc :3 0 39 :3 0
cf :3 0 38 :3 0
ca :3 0 c :3 0
74 :3 0 2b :4 0
165 1 :8 0 15b7
f7 :4 0 15a2 :3 0
9c :3 0 a4 :2 0
c7e 15a5 15a6 :3 0
1b :3 0 ab :3 0
15a8 15a9 0 31
:2 0 15aa 15ab 0
15ad c81 15b4 1b
:3 0 ab :3 0 15ae
15af 0 f8 :2 0
15b0 15b1 0 15b3
c83 15b5 15a7 15ad
0 15b6 0 15b3
0 15b6 c85 0
15b7 c88 160a ad
:3 0 1b :3 0 ab
:3 0 15b9 15ba 0
ac :3 0 15bb 15bc
0 15be c8b 15c0
c8d 15bf 15be :2 0
1608 ae :3 0 1b
:3 0 ab :3 0 15c3
15c4 0 ac :3 0
15c5 15c6 0 1600
78 :3 0 79 :3 0
15c8 15c9 0 78
:3 0 88 :3 0 15cb
15cc 0 25 :2 0
2 :4 0 166 :2 0
8a :2 0 49 :2 0
c8f 15d1 15d3 :3 0
c92 15cd 15d5 15ca
15d7 15d6 :2 0 7b
:3 0 8b :3 0 15d9
15da 0 7d :4 0
167 :4 0 80 :2 0
81 :3 0 c96 15de
15e0 :3 0 80 :2 0
94 :4 0 c99 15e2
15e4 :3 0 80 :2 0
b1 :4 0 c9c 15e6
15e8 :3 0 80 :2 0
ac :3 0 c9f 15ea
15ec :3 0 80 :2 0
b2 :4 0 ca2 15ee
15f0 :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
ca5 15f3 15f7 ca9
15f2 15f9 :3 0 cac
15db 15fb :2 0 15fd
caf 15fe 15d8 15fd
0 15ff cb1 0
1600 cb3 1603 :3 0
1603 0 1603 1602
1600 1601 :6 0 1605
30 :3 0 cb6 1607
cb8 1606 1605 :2 0
1608 cba :2 0 160a
0 160a 1609 15b7
1608 :6 0 160c 1
:3 0 cbd 160e 1514
1595 0 160f 0
160c 0 160f cbf
0 1610 cc2 1776
4d :3 0 112 :2 0
cc4 1612 1613 :3 0
1614 :2 0 d0 :3 0
fe :3 0 d :3 0
cc :3 0 39 :3 0
cf :3 0 38 :3 0
13f :3 0 140 :3 0
141 :3 0 12 :3 0
13f :3 0 142 :3 0
140 :3 0 141 :3 0
13 :3 0 142 :3 0
143 :3 0 140 :3 0
14 :3 0 143 :3 0
144 :3 0 140 :3 0
15 :3 0 144 :3 0
145 :3 0 146 :3 0
147 :3 0 148 :3 0
149 :3 0 14a :3 0
14b :3 0 14c :3 0
146 :3 0 12 :3 0
148 :3 0 13 :3 0
14a :3 0 14 :3 0
14c :3 0 15 :3 0
14d :3 0 15 :3 0
14e :3 0 14f :3 0
150 :3 0 15 :3 0
151 :3 0 152 :3 0
14e :3 0 153 :3 0
151 :3 0 154 :3 0
155 :3 0 156 :3 0
157 :3 0 140 :3 0
f0 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
f4 :3 0 f5 :3 0
ff :3 0 16 :3 0
100 :3 0 17 :3 0
ca :3 0 18 :3 0
74 :3 0 2b :4 0
168 1 :8 0 1673
f7 :4 0 165e :3 0
9c :3 0 a4 :2 0
cc8 1661 1662 :3 0
1b :3 0 ab :3 0
1664 1665 0 31
:2 0 1666 1667 0
1669 ccb 1670 1b
:3 0 ab :3 0 166a
166b 0 f8 :2 0
166c 166d 0 166f
ccd 1671 1663 1669
0 1672 0 166f
0 1672 ccf 0
1673 cd2 16c6 ad
:3 0 1b :3 0 ab
:3 0 1675 1676 0
ac :3 0 1677 1678
0 167a cd5 167c
cd7 167b 167a :2 0
16c4 ae :3 0 1b
:3 0 ab :3 0 167f
1680 0 ac :3 0
1681 1682 0 16bc
78 :3 0 79 :3 0
1684 1685 0 78
:3 0 88 :3 0 1687
1688 0 25 :2 0
2 :4 0 169 :2 0
8a :2 0 49 :2 0
cd9 168d 168f :3 0
cdc 1689 1691 1686
1693 1692 :2 0 7b
:3 0 8b :3 0 1695
1696 0 7d :4 0
16a :4 0 80 :2 0
81 :3 0 ce0 169a
169c :3 0 80 :2 0
94 :4 0 ce3 169e
16a0 :3 0 80 :2 0
b1 :4 0 ce6 16a2
16a4 :3 0 80 :2 0
ac :3 0 ce9 16a6
16a8 :3 0 80 :2 0
b2 :4 0 cec 16aa
16ac :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
cef 16af 16b3 cf3
16ae 16b5 :3 0 cf6
1697 16b7 :2 0 16b9
cf9 16ba 1694 16b9
0 16bb cfb 0
16bc cfd 16bf :3 0
16bf 0 16bf 16be
16bc 16bd :6 0 16c1
32 :3 0 d00 16c3
d02 16c2 16c1 :2 0
16c4 d04 :2 0 16c6
0 16c6 16c5 1673
16c4 :6 0 16c8 1
:3 0 d07 1772 d0
:3 0 fe :3 0 d
:3 0 cc :3 0 39
:3 0 cf :3 0 38
:3 0 ca :3 0 c
:3 0 13f :3 0 140
:3 0 141 :3 0 12
:3 0 13f :3 0 142
:3 0 140 :3 0 141
:3 0 13 :3 0 142
:3 0 143 :3 0 140
:3 0 14 :3 0 143
:3 0 144 :3 0 140
:3 0 15 :3 0 144
:3 0 145 :3 0 146
:3 0 147 :3 0 148
:3 0 149 :3 0 14a
:3 0 14b :3 0 14c
:3 0 146 :3 0 12
:3 0 148 :3 0 13
:3 0 14a :3 0 14
:3 0 14c :3 0 15
:3 0 14d :3 0 15
:3 0 14e :3 0 14f
:3 0 150 :3 0 15
:3 0 151 :3 0 152
:3 0 14e :3 0 153
:3 0 151 :3 0 154
:3 0 155 :3 0 156
:3 0 157 :3 0 140
:3 0 74 :3 0 2b
:4 0 16b 1 :8 0
171c f7 :4 0 1707
:3 0 9c :3 0 a4
:2 0 d0b 170a 170b
:3 0 1b :3 0 ab
:3 0 170d 170e 0
31 :2 0 170f 1710
0 1712 d0e 1719
1b :3 0 ab :3 0
1713 1714 0 f8
:2 0 1715 1716 0
1718 d10 171a 170c
1712 0 171b 0
1718 0 171b d12
0 171c d15 176f
ad :3 0 1b :3 0
ab :3 0 171e 171f
0 ac :3 0 1720
1721 0 1723 d18
1725 d1a 1724 1723
:2 0 176d ae :3 0
1b :3 0 ab :3 0
1728 1729 0 ac
:3 0 172a 172b 0
1765 78 :3 0 79
:3 0 172d 172e 0
78 :3 0 88 :3 0
1730 1731 0 25
:2 0 2 :4 0 16c
:2 0 8a :2 0 49
:2 0 d1c 1736 1738
:3 0 d1f 1732 173a
172f 173c 173b :2 0
7b :3 0 8b :3 0
173e 173f 0 7d
:4 0 16d :4 0 80
:2 0 81 :3 0 d23
1743 1745 :3 0 80
:2 0 94 :4 0 d26
1747 1749 :3 0 80
:2 0 b1 :4 0 d29
174b 174d :3 0 80
:2 0 ac :3 0 d2c
174f 1751 :3 0 80
:2 0 b2 :4 0 d2f
1753 1755 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 d32 1758 175c
d36 1757 175e :3 0
d39 1740 1760 :2 0
1762 d3c 1763 173d
1762 0 1764 d3e
0 1765 d40 1768
:3 0 1768 0 1768
1767 1765 1766 :6 0
176a 34 :3 0 d43
176c d45 176b 176a
:2 0 176d d47 :2 0
176f 0 176f 176e
171c 176d :6 0 1771
1 :3 0 d4a 1773
1615 16c8 0 1774
0 1771 0 1774
d4c 0 1775 d4f
1777 150f 1610 0
1778 0 1775 0
1778 d51 0 177a
15e :3 0 d54 1903
85 :3 0 3e :3 0
31 :2 0 d56 177b
177e a4 :2 0 31
:2 0 d5b 1780 1782
:3 0 47 :3 0 8d
:2 0 d5e 1785 1786
:3 0 1787 :2 0 85
:3 0 e :3 0 31
:2 0 d60 1789 178c
a4 :2 0 31 :2 0
d65 178e 1790 :3 0
d0 :3 0 fe :3 0
d :3 0 cc :3 0
39 :3 0 cf :3 0
38 :3 0 ca :3 0
c :3 0 ef :3 0
3d :3 0 c :3 0
74 :3 0 2b :4 0
16e 1 :8 0 17b6
f7 :4 0 17a1 :3 0
9c :3 0 a4 :2 0
d6a 17a4 17a5 :3 0
1b :3 0 ab :3 0
17a7 17a8 0 31
:2 0 17a9 17aa 0
17ac d6d 17b3 1b
:3 0 ab :3 0 17ad
17ae 0 f8 :2 0
17af 17b0 0 17b2
d6f 17b4 17a6 17ac
0 17b5 0 17b2
0 17b5 d71 0
17b6 d74 1809 ad
:3 0 1b :3 0 ab
:3 0 17b8 17b9 0
ac :3 0 17ba 17bb
0 17bd d77 17bf
d79 17be 17bd :2 0
1807 ae :3 0 1b
:3 0 ab :3 0 17c2
17c3 0 ac :3 0
17c4 17c5 0 17ff
78 :3 0 79 :3 0
17c7 17c8 0 78
:3 0 88 :3 0 17ca
17cb 0 25 :2 0
2 :4 0 16f :2 0
8a :2 0 49 :2 0
d7b 17d0 17d2 :3 0
d7e 17cc 17d4 17c9
17d6 17d5 :2 0 7b
:3 0 8b :3 0 17d8
17d9 0 7d :4 0
170 :4 0 80 :2 0
81 :3 0 d82 17dd
17df :3 0 80 :2 0
94 :4 0 d85 17e1
17e3 :3 0 80 :2 0
b1 :4 0 d88 17e5
17e7 :3 0 80 :2 0
ac :3 0 d8b 17e9
17eb :3 0 80 :2 0
b2 :4 0 d8e 17ed
17ef :3 0 80 :2 0
b3 :3 0 b4 :3 0
49 :2 0 b5 :2 0
d91 17f2 17f6 d95
17f1 17f8 :3 0 d98
17da 17fa :2 0 17fc
d9b 17fd 17d7 17fc
0 17fe d9d 0
17ff d9f 1802 :3 0
1802 0 1802 1801
17ff 1800 :6 0 1804
36 :3 0 da2 1806
da4 1805 1804 :2 0
1807 da6 :2 0 1809
0 1809 1808 17b6
1807 :6 0 180b 1
:3 0 da9 1883 d0
:3 0 fe :3 0 d
:3 0 cc :3 0 39
:3 0 cf :3 0 38
:3 0 ca :3 0 c
:3 0 74 :3 0 2b
:4 0 165 1 :8 0
182d f7 :4 0 1818
:3 0 9c :3 0 a4
:2 0 dad 181b 181c
:3 0 1b :3 0 ab
:3 0 181e 181f 0
31 :2 0 1820 1821
0 1823 db0 182a
1b :3 0 ab :3 0
1824 1825 0 f8
:2 0 1826 1827 0
1829 db2 182b 181d
1823 0 182c 0
1829 0 182c db4
0 182d db7 1880
ad :3 0 1b :3 0
ab :3 0 182f 1830
0 ac :3 0 1831
1832 0 1834 dba
1836 dbc 1835 1834
:2 0 187e ae :3 0
1b :3 0 ab :3 0
1839 183a 0 ac
:3 0 183b 183c 0
1876 78 :3 0 79
:3 0 183e 183f 0
78 :3 0 88 :3 0
1841 1842 0 25
:2 0 2 :4 0 171
:2 0 8a :2 0 49
:2 0 dbe 1847 1849
:3 0 dc1 1843 184b
1840 184d 184c :2 0
7b :3 0 8b :3 0
184f 1850 0 7d
:4 0 172 :4 0 80
:2 0 81 :3 0 dc5
1854 1856 :3 0 80
:2 0 94 :4 0 dc8
1858 185a :3 0 80
:2 0 b1 :4 0 dcb
185c 185e :3 0 80
:2 0 ac :3 0 dce
1860 1862 :3 0 80
:2 0 b2 :4 0 dd1
1864 1866 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 dd4 1869 186d
dd8 1868 186f :3 0
ddb 1851 1871 :2 0
1873 dde 1874 184e
1873 0 1875 de0
0 1876 de2 1879
:3 0 1879 0 1879
1878 1876 1877 :6 0
187b 38 :3 0 de5
187d de7 187c 187b
:2 0 187e de9 :2 0
1880 0 1880 187f
182d 187e :6 0 1882
1 :3 0 dec 1884
1791 180b 0 1885
0 1882 0 1885
dee 0 1886 df1
18fe d0 :3 0 fe
:3 0 d :3 0 cc
:3 0 39 :3 0 cf
:3 0 38 :3 0 ca
:3 0 c :3 0 74
:3 0 2b :4 0 173
1 :8 0 18a8 f7
:4 0 1893 :3 0 9c
:3 0 a4 :2 0 df5
1896 1897 :3 0 1b
:3 0 ab :3 0 1899
189a 0 31 :2 0
189b 189c 0 189e
df8 18a5 1b :3 0
ab :3 0 189f 18a0
0 f8 :2 0 18a1
18a2 0 18a4 dfa
18a6 1898 189e 0
18a7 0 18a4 0
18a7 dfc 0 18a8
dff 18fb ad :3 0
1b :3 0 ab :3 0
18aa 18ab 0 ac
:3 0 18ac 18ad 0
18af e02 18b1 e04
18b0 18af :2 0 18f9
ae :3 0 1b :3 0
ab :3 0 18b4 18b5
0 ac :3 0 18b6
18b7 0 18f1 78
:3 0 79 :3 0 18b9
18ba 0 78 :3 0
88 :3 0 18bc 18bd
0 25 :2 0 2
:4 0 174 :2 0 8a
:2 0 49 :2 0 e06
18c2 18c4 :3 0 e09
18be 18c6 18bb 18c8
18c7 :2 0 7b :3 0
8b :3 0 18ca 18cb
0 7d :4 0 175
:4 0 80 :2 0 81
:3 0 e0d 18cf 18d1
:3 0 80 :2 0 94
:4 0 e10 18d3 18d5
:3 0 80 :2 0 b1
:4 0 e13 18d7 18d9
:3 0 80 :2 0 ac
:3 0 e16 18db 18dd
:3 0 80 :2 0 b2
:4 0 e19 18df 18e1
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 e1c
18e4 18e8 e20 18e3
18ea :3 0 e23 18cc
18ec :2 0 18ee e26
18ef 18c9 18ee 0
18f0 e28 0 18f1
e2a 18f4 :3 0 18f4
0 18f4 18f3 18f1
18f2 :6 0 18f6 3a
:3 0 e2d 18f8 e2f
18f7 18f6 :2 0 18f9
e31 :2 0 18fb 0
18fb 18fa 18a8 18f9
:6 0 18fd 1 :3 0
e34 18ff 1788 1886
0 1900 0 18fd
0 1900 e36 0
1901 e39 1902 1783
1901 0 1904 150a
177a 0 1904 e3b
0 1905 e3e 1907
1200 14fc 0 1908
0 1905 0 1908
e40 0 1d6e 4d
:3 0 112 :2 0 e43
190a 190b :3 0 190c
:2 0 85 :3 0 18
:3 0 31 :2 0 e45
190e 1911 8f :2 0
31 :2 0 e4a 1913
1915 :3 0 1916 :2 0
190d 1918 1917 :2 0
1919 :2 0 85 :3 0
c :3 0 31 :2 0
e4d 191b 191e 8f
:2 0 31 :2 0 e52
1920 1922 :3 0 1923
:2 0 191a 1925 1924
:2 0 45 :3 0 176
:4 0 1927 1928 0
1d6b 45 :4 0 192a
192b 0 1d6b 3f
:3 0 31 :2 0 192d
192e 0 1d6b 3e
:3 0 31 :2 0 1930
1931 0 1d6b 85
:3 0 57 :3 0 31
:2 0 e55 1933 1936
a4 :2 0 49 :2 0
e5a 1938 193a :3 0
74 :3 0 f5 :3 0
c8 :3 0 177 :3 0
b3 :3 0 f1 :3 0
177 :3 0 b3 :3 0
f3 :3 0 150 :3 0
178 :3 0 14e :3 0
151 :3 0 46 :3 0
3d :3 0 2e :3 0
59 :3 0 5a :3 0
5e :3 0 5f :3 0
5b :3 0 5d :3 0
d0 :3 0 138 :3 0
2b :4 0 179 1
:8 0 195b 1b :3 0
ab :3 0 1956 1957
0 ac :3 0 1958
1959 0 195b e5d
19ae ad :3 0 1b
:3 0 ab :3 0 195d
195e 0 ac :3 0
195f 1960 0 1962
e60 1964 e62 1963
1962 :2 0 19ac ae
:3 0 1b :3 0 ab
:3 0 1967 1968 0
ac :3 0 1969 196a
0 19a4 78 :3 0
79 :3 0 196c 196d
0 78 :3 0 88
:3 0 196f 1970 0
25 :2 0 2 :4 0
17a :2 0 8a :2 0
49 :2 0 e64 1975
1977 :3 0 e67 1971
1979 196e 197b 197a
:2 0 7b :3 0 8b
:3 0 197d 197e 0
7d :4 0 17b :4 0
80 :2 0 81 :3 0
e6b 1982 1984 :3 0
80 :2 0 94 :4 0
e6e 1986 1988 :3 0
80 :2 0 b1 :4 0
e71 198a 198c :3 0
80 :2 0 ac :3 0
e74 198e 1990 :3 0
80 :2 0 b2 :4 0
e77 1992 1994 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 e7a 1997
199b e7e 1996 199d
:3 0 e81 197f 199f
:2 0 19a1 e84 19a2
197c 19a1 0 19a3
e86 0 19a4 e88
19a7 :3 0 19a7 0
19a7 19a6 19a4 19a5
:6 0 19a9 3c :3 0
e8b 19ab e8d 19aa
19a9 :2 0 19ac e8f
:2 0 19ae 0 19ae
19ad 195b 19ac :6 0
19b0 1 :3 0 e92
1a27 46 :3 0 2b
:3 0 19b1 19b2 0
1a26 f5 :3 0 c8
:3 0 177 :3 0 b3
:3 0 f1 :3 0 177
:3 0 b3 :3 0 f3
:3 0 150 :3 0 178
:3 0 14e :3 0 151
:3 0 3d :3 0 2e
:3 0 59 :3 0 5a
:3 0 5e :3 0 5f
:3 0 5b :3 0 5d
:3 0 d0 :3 0 74
:3 0 46 :4 0 17c
1 :8 0 19d1 1b
:3 0 ab :3 0 19cc
19cd 0 ac :3 0
19ce 19cf 0 19d1
e94 1a24 ad :3 0
1b :3 0 ab :3 0
19d3 19d4 0 ac
:3 0 19d5 19d6 0
19d8 e97 19da e99
19d9 19d8 :2 0 1a22
ae :3 0 1b :3 0
ab :3 0 19dd 19de
0 ac :3 0 19df
19e0 0 1a1a 78
:3 0 79 :3 0 19e2
19e3 0 78 :3 0
88 :3 0 19e5 19e6
0 25 :2 0 2
:4 0 17d :2 0 8a
:2 0 49 :2 0 e9b
19eb 19ed :3 0 e9e
19e7 19ef 19e4 19f1
19f0 :2 0 7b :3 0
8b :3 0 19f3 19f4
0 7d :4 0 17e
:4 0 80 :2 0 81
:3 0 ea2 19f8 19fa
:3 0 80 :2 0 94
:4 0 ea5 19fc 19fe
:3 0 80 :2 0 b1
:4 0 ea8 1a00 1a02
:3 0 80 :2 0 ac
:3 0 eab 1a04 1a06
:3 0 80 :2 0 b2
:4 0 eae 1a08 1a0a
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 eb1
1a0d 1a11 eb5 1a0c
1a13 :3 0 eb8 19f5
1a15 :2 0 1a17 ebb
1a18 19f2 1a17 0
1a19 ebd 0 1a1a
ebf 1a1d :3 0 1a1d
0 1a1d 1a1c 1a1a
1a1b :6 0 1a1f 3e
:3 0 ec2 1a21 ec4
1a20 1a1f :2 0 1a22
ec6 :2 0 1a24 0
1a24 1a23 19d1 1a22
:6 0 1a26 1 :3 0
ec9 1a28 193b 19b0
0 1a29 0 1a26
0 1a29 ecc 0
1d6b 1b :3 0 ab
:3 0 1a2a 1a2b 0
1b :3 0 a4 :2 0
d4 :3 0 1a2d 1a2f
0 ed1 1a2e 1a31
:3 0 1a32 :2 0 85
:3 0 c :3 0 31
:2 0 ed4 1a34 1a37
85 :3 0 a4 :2 0
a :3 0 31 :2 0
ed7 1a39 1a3d edc
1a3a 1a3f :3 0 1a40
:2 0 85 :3 0 e
:3 0 31 :2 0 edf
1a42 1a45 a4 :2 0
31 :2 0 ee4 1a47
1a49 :3 0 1a4a :2 0
1a41 1a4c 1a4b :2 0
85 :3 0 d :3 0
31 :2 0 ee7 1a4e
1a51 a4 :2 0 eb
:2 0 eec 1a53 1a55
:3 0 1a56 :2 0 1a4d
1a58 1a57 :2 0 73
:3 0 75 :3 0 70
:3 0 72 :3 0 6a
:3 0 2d :3 0 74
:3 0 46 :4 0 17f
1 :8 0 1a78 f7
:4 0 1a63 :3 0 9c
:3 0 a4 :2 0 ef1
1a66 1a67 :3 0 1b
:3 0 ab :3 0 1a69
1a6a 0 31 :2 0
1a6b 1a6c 0 1a6e
ef4 1a75 1b :3 0
ab :3 0 1a6f 1a70
0 f8 :2 0 1a71
1a72 0 1a74 ef6
1a76 1a68 1a6e 0
1a77 0 1a74 0
1a77 ef8 0 1a78
efb 1acb ad :3 0
1b :3 0 ab :3 0
1a7a 1a7b 0 ac
:3 0 1a7c 1a7d 0
1a7f efe 1a81 f00
1a80 1a7f :2 0 1ac9
ae :3 0 1b :3 0
ab :3 0 1a84 1a85
0 ac :3 0 1a86
1a87 0 1ac1 78
:3 0 79 :3 0 1a89
1a8a 0 78 :3 0
88 :3 0 1a8c 1a8d
0 25 :2 0 2
:4 0 180 :2 0 8a
:2 0 49 :2 0 f02
1a92 1a94 :3 0 f05
1a8e 1a96 1a8b 1a98
1a97 :2 0 7b :3 0
8b :3 0 1a9a 1a9b
0 7d :4 0 181
:4 0 80 :2 0 81
:3 0 f09 1a9f 1aa1
:3 0 80 :2 0 94
:4 0 f0c 1aa3 1aa5
:3 0 80 :2 0 b1
:4 0 f0f 1aa7 1aa9
:3 0 80 :2 0 ac
:3 0 f12 1aab 1aad
:3 0 80 :2 0 b2
:4 0 f15 1aaf 1ab1
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 f18
1ab4 1ab8 f1c 1ab3
1aba :3 0 f1f 1a9c
1abc :2 0 1abe f22
1abf 1a99 1abe 0
1ac0 f24 0 1ac1
f26 1ac4 :3 0 1ac4
0 1ac4 1ac3 1ac1
1ac2 :6 0 1ac6 40
:3 0 f29 1ac8 f2b
1ac7 1ac6 :2 0 1ac9
f2d :2 0 1acb 0
1acb 1aca 1a78 1ac9
:6 0 1b45 1 :3 0
d0 :3 0 ca :3 0
f5 :3 0 107 :3 0
182 :3 0 71 :3 0
73 :3 0 6a :3 0
2d :3 0 74 :3 0
46 :3 0 74 :3 0
46 :4 0 183 1
:8 0 1af0 f7 :4 0
1adb :3 0 9c :3 0
a4 :2 0 f32 1ade
1adf :3 0 1b :3 0
ab :3 0 1ae1 1ae2
0 31 :2 0 1ae3
1ae4 0 1ae6 f35
1aed 1b :3 0 ab
:3 0 1ae7 1ae8 0
f8 :2 0 1ae9 1aea
0 1aec f37 1aee
1ae0 1ae6 0 1aef
0 1aec 0 1aef
f39 0 1af0 f3c
1b43 ad :3 0 1b
:3 0 ab :3 0 1af2
1af3 0 ac :3 0
1af4 1af5 0 1af7
f3f 1af9 f41 1af8
1af7 :2 0 1b41 ae
:3 0 1b :3 0 ab
:3 0 1afc 1afd 0
ac :3 0 1afe 1aff
0 1b39 78 :3 0
79 :3 0 1b01 1b02
0 78 :3 0 88
:3 0 1b04 1b05 0
25 :2 0 2 :4 0
184 :2 0 8a :2 0
49 :2 0 f43 1b0a
1b0c :3 0 f46 1b06
1b0e 1b03 1b10 1b0f
:2 0 7b :3 0 8b
:3 0 1b12 1b13 0
7d :4 0 185 :4 0
80 :2 0 81 :3 0
f4a 1b17 1b19 :3 0
80 :2 0 94 :4 0
f4d 1b1b 1b1d :3 0
80 :2 0 b1 :4 0
f50 1b1f 1b21 :3 0
80 :2 0 ac :3 0
f53 1b23 1b25 :3 0
80 :2 0 b2 :4 0
f56 1b27 1b29 :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 f59 1b2c
1b30 f5d 1b2b 1b32
:3 0 f60 1b14 1b34
:2 0 1b36 f63 1b37
1b11 1b36 0 1b38
f65 0 1b39 f67
1b3c :3 0 1b3c 0
1b3c 1b3b 1b39 1b3a
:6 0 1b3e 42 :3 0
f6a 1b40 f6c 1b3f
1b3e :2 0 1b41 f6e
:2 0 1b43 0 1b43
1b42 1af0 1b41 :6 0
1b45 1 :3 0 f71
1d38 120 :3 0 6f
:4 0 1b49 :2 0 1d37
1b47 1b4a :3 0 186
:3 0 6f :3 0 40
:3 0 43 :3 0 3e
:4 0 1b51 :2 0 1c51
1b4c 1b52 :3 0 f74
:3 0 6f :3 0 f7
:3 0 1b53 1b54 :3 0
1b :3 0 ab :3 0
1b56 1b57 0 31
:2 0 1b58 1b59 0
1b5b f78 1b62 1b
:3 0 ab :3 0 1b5c
1b5d 0 f8 :2 0
1b5e 1b5f 0 1b61
f7a 1b63 1b55 1b5b
0 1b64 0 1b61
0 1b64 f7c 0
1c51 1b :3 0 ab
:3 0 1b65 1b66 0
bd :2 0 31 :2 0
f81 1b68 1b6a :3 0
187 :8 0 1b6e f84
1b6f 1b6b 1b6e 0
1b70 f86 0 1c51
3f :3 0 85 :3 0
3f :3 0 31 :2 0
f88 1b72 1b75 8a
:2 0 85 :3 0 40
:3 0 31 :2 0 f8b
1b78 1b7b f8e 1b77
1b7d :3 0 1b71 1b7e
0 1c51 85 :3 0
3e :3 0 31 :2 0
f91 1b80 1b83 a4
:2 0 31 :2 0 f96
1b85 1b87 :3 0 85
:3 0 3f :3 0 31
:2 0 f99 1b89 1b8c
85 :3 0 8f :2 0
42 :3 0 31 :2 0
f9c 1b8e 1b92 fa1
1b8f 1b94 :3 0 85
:3 0 40 :3 0 31
:2 0 fa4 1b96 1b99
85 :3 0 188 :2 0
42 :3 0 31 :2 0
fa7 1b9b 1b9f fac
1b9c 1ba1 :3 0 40
:3 0 85 :3 0 42
:3 0 31 :2 0 faf
1ba4 1ba7 1ba3 1ba8
0 1baa fb2 1bc3
40 :3 0 85 :3 0
42 :3 0 31 :2 0
fb4 1bac 1baf 189
:2 0 85 :3 0 3f
:3 0 31 :2 0 fb7
1bb2 1bb5 fba 1bb1
1bb7 :3 0 8a :2 0
85 :3 0 40 :3 0
31 :2 0 fbd 1bba
1bbd fc0 1bb9 1bbf
:3 0 1bab 1bc0 0
1bc2 fc3 1bc4 1ba2
1baa 0 1bc5 0
1bc2 0 1bc5 fc5
0 1bc6 fc8 1bc7
1b95 1bc6 0 1bc8
fca 0 1c3c 73
:3 0 75 :3 0 40
:3 0 72 :3 0 6f
:4 0 18a 1 :8 0
1be4 f7 :4 0 1bcf
:3 0 9c :3 0 a4
:2 0 fce 1bd2 1bd3
:3 0 1b :3 0 ab
:3 0 1bd5 1bd6 0
31 :2 0 1bd7 1bd8
0 1bda fd1 1be1
1b :3 0 ab :3 0
1bdb 1bdc 0 f8
:2 0 1bdd 1bde 0
1be0 fd3 1be2 1bd4
1bda 0 1be3 0
1be0 0 1be3 fd5
0 1be4 fd8 1c37
ad :3 0 1b :3 0
ab :3 0 1be6 1be7
0 ac :3 0 1be8
1be9 0 1beb fdb
1bed fdd 1bec 1beb
:2 0 1c35 ae :3 0
1b :3 0 ab :3 0
1bf0 1bf1 0 ac
:3 0 1bf2 1bf3 0
1c2d 78 :3 0 79
:3 0 1bf5 1bf6 0
78 :3 0 88 :3 0
1bf8 1bf9 0 25
:2 0 2 :4 0 18b
:2 0 8a :2 0 49
:2 0 fdf 1bfe 1c00
:3 0 fe2 1bfa 1c02
1bf7 1c04 1c03 :2 0
7b :3 0 8b :3 0
1c06 1c07 0 7d
:4 0 18c :4 0 80
:2 0 81 :3 0 fe6
1c0b 1c0d :3 0 80
:2 0 94 :4 0 fe9
1c0f 1c11 :3 0 80
:2 0 b1 :4 0 fec
1c13 1c15 :3 0 80
:2 0 ac :3 0 fef
1c17 1c19 :3 0 80
:2 0 b2 :4 0 ff2
1c1b 1c1d :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 ff5 1c20 1c24
ff9 1c1f 1c26 :3 0
ffc 1c08 1c28 :2 0
1c2a fff 1c2b 1c05
1c2a 0 1c2c 1001
0 1c2d 1003 1c30
:3 0 1c30 0 1c30
1c2f 1c2d 1c2e :6 0
1c32 45 :3 0 1006
1c34 1008 1c33 1c32
:2 0 1c35 100a :2 0
1c37 0 1c37 1c36
1be4 1c35 :6 0 1c3c
44 :3 0 45 :3 0
43 :3 0 1c39 1c3a
0 1c3c 100d 1c3d
1b88 1c3c 0 1c3e
1011 0 1c51 85
:3 0 3f :3 0 31
:2 0 1013 1c3f 1c42
85 :3 0 188 :2 0
42 :3 0 31 :2 0
1016 1c44 1c48 101b
1c45 1c4a :3 0 187
:8 0 1c4e 101e 1c4f
1c4b 1c4e 0 1c50
1020 0 1c51 1022
1c53 186 :4 0 1c51
:4 0 1d37 121 :3 0
6f :4 0 1c57 :2 0
1c5d 1c55 0 1b
:3 0 ab :3 0 1c58
1c59 0 ac :3 0
1c5a 1c5b 0 1c5d
1029 1cb0 ad :3 0
1b :3 0 ab :3 0
1c5f 1c60 0 ac
:3 0 1c61 1c62 0
1c64 102c 1c66 102e
1c65 1c64 :2 0 1cae
ae :3 0 1b :3 0
ab :3 0 1c69 1c6a
0 ac :3 0 1c6b
1c6c 0 1ca6 78
:3 0 79 :3 0 1c6e
1c6f 0 78 :3 0
88 :3 0 1c71 1c72
0 25 :2 0 2
:4 0 18d :2 0 8a
:2 0 49 :2 0 1030
1c77 1c79 :3 0 1033
1c73 1c7b 1c70 1c7d
1c7c :2 0 7b :3 0
8b :3 0 1c7f 1c80
0 7d :4 0 18e
:4 0 80 :2 0 81
:3 0 1037 1c84 1c86
:3 0 80 :2 0 94
:4 0 103a 1c88 1c8a
:3 0 80 :2 0 b1
:4 0 103d 1c8c 1c8e
:3 0 80 :2 0 ac
:3 0 1040 1c90 1c92
:3 0 80 :2 0 b2
:4 0 1043 1c94 1c96
:3 0 80 :2 0 b3
:3 0 b4 :3 0 49
:2 0 b5 :2 0 1046
1c99 1c9d 104a 1c98
1c9f :3 0 104d 1c81
1ca1 :2 0 1ca3 1050
1ca4 1c7e 1ca3 0
1ca5 1052 0 1ca6
1054 1ca9 :3 0 1ca9
0 1ca9 1ca8 1ca6
1ca7 :6 0 1cab 47
:3 0 1057 1cad 1059
1cac 1cab :2 0 1cae
105b :2 0 1cb0 0
1cb0 1caf 1c5d 1cae
:6 0 1d37 1 :3 0
85 :3 0 3f :3 0
31 :2 0 105e 1cb2
1cb5 8f :2 0 31
:2 0 1063 1cb7 1cb9
:3 0 1cba :2 0 45
:3 0 112 :2 0 1066
1cbd 1cbe :3 0 1cbf
:2 0 1cc0 :2 0 1cbb
1cc2 1cc1 :2 0 d0
:3 0 107 :3 0 45
:3 0 74 :3 0 46
:4 0 18f 1 :8 0
1cdf f7 :4 0 1cca
:3 0 9c :3 0 a4
:2 0 106a 1ccd 1cce
:3 0 1b :3 0 ab
:3 0 1cd0 1cd1 0
31 :2 0 1cd2 1cd3
0 1cd5 106d 1cdc
1b :3 0 ab :3 0
1cd6 1cd7 0 f8
:2 0 1cd8 1cd9 0
1cdb 106f 1cdd 1ccf
1cd5 0 1cde 0
1cdb 0 1cde 1071
0 1cdf 1074 1d32
ad :3 0 1b :3 0
ab :3 0 1ce1 1ce2
0 ac :3 0 1ce3
1ce4 0 1ce6 1077
1ce8 1079 1ce7 1ce6
:2 0 1d30 ae :3 0
1b :3 0 ab :3 0
1ceb 1cec 0 ac
:3 0 1ced 1cee 0
1d28 78 :3 0 79
:3 0 1cf0 1cf1 0
78 :3 0 88 :3 0
1cf3 1cf4 0 25
:2 0 2 :4 0 190
:2 0 8a :2 0 49
:2 0 107b 1cf9 1cfb
:3 0 107e 1cf5 1cfd
1cf2 1cff 1cfe :2 0
7b :3 0 8b :3 0
1d01 1d02 0 7d
:4 0 191 :4 0 80
:2 0 81 :3 0 1082
1d06 1d08 :3 0 80
:2 0 94 :4 0 1085
1d0a 1d0c :3 0 80
:2 0 b1 :4 0 1088
1d0e 1d10 :3 0 80
:2 0 ac :3 0 108b
1d12 1d14 :3 0 80
:2 0 b2 :4 0 108e
1d16 1d18 :3 0 80
:2 0 b3 :3 0 b4
:3 0 49 :2 0 b5
:2 0 1091 1d1b 1d1f
1095 1d1a 1d21 :3 0
1098 1d03 1d23 :2 0
1d25 109b 1d26 1d00
1d25 0 1d27 109d
0 1d28 109f 1d2b
:3 0 1d2b 0 1d2b
1d2a 1d28 1d29 :6 0
1d2d 49 :3 0 10a2
1d2f 10a4 1d2e 1d2d
:2 0 1d30 10a6 :2 0
1d32 0 1d32 1d31
1cdf 1d30 :6 0 1d34
1 :3 0 10a9 1d35
1cc3 1d34 0 1d36
10ab 0 1d37 10ad
1d39 1a59 1b45 0
1d3a 0 1d37 0
1d3a 10b2 0 1d68
85 :3 0 57 :3 0
31 :2 0 10b5 1d3b
1d3e a4 :2 0 49
:2 0 10ba 1d40 1d42
:3 0 ed :3 0 85
:3 0 f :3 0 31
:2 0 10bd 1d45 1d48
27 :2 0 10c0 1d44
1d4b 1d4c :2 0 a4
:2 0 27 :2 0 10c5
1d4e 1d50 :3 0 54
:3 0 192 :3 0 46
:3 0 2f :3 0 10c8
1d53 1d56 1d52 1d57
0 1d59 10cb 1d62
54 :3 0 193 :3 0
46 :3 0 2f :3 0
10cd 1d5b 1d5e 1d5a
1d5f 0 1d61 10d0
1d63 1d51 1d59 0
1d64 0 1d61 0
1d64 10d2 0 1d65
10d5 1d66 1d43 1d65
0 1d67 10d7 0
1d68 10d9 1d69 1a33
1d68 0 1d6a 10dc
0 1d6b 10de 1d6c
1926 1d6b 0 1d6d
10e5 0 1d6e 10e7
1d6f 7bc 1d6e 0
1d70 10f5 0 1d80
1b :3 0 ab :3 0
1d71 1d72 0 a4
:2 0 f8 :2 0 10f9
1d74 1d76 :3 0 1b
:3 0 ab :3 0 1d78
1d79 0 31 :2 0
1d7a 1d7b 0 1d7d
10fc 1d7e 1d77 1d7d
0 1d7f 10fe 0
1d80 1100 1d81 49f
1d80 0 1d82 1104
0 1dd1 78 :3 0
79 :3 0 1d83 1d84
0 78 :3 0 88
:3 0 1d86 1d87 0
194 :2 0 2 :4 0
195 :2 0 8a :2 0
49 :2 0 1106 1d8c
1d8e :3 0 1109 1d88
1d90 1d85 1d92 1d91
:2 0 7b :3 0 8b
:3 0 1d94 1d95 0
7d :4 0 196 :4 0
80 :2 0 81 :3 0
110d 1d99 1d9b :3 0
80 :2 0 94 :4 0
1110 1d9d 1d9f :3 0
80 :2 0 95 :4 0
1113 1da1 1da3 :3 0
80 :2 0 85 :3 0
66 :3 0 1b :3 0
ab :3 0 1da8 1da9
0 1116 1da7 1dab
86 :4 0 1118 1da6
1dae 111b 1da5 1db0
:3 0 80 :2 0 c0
:4 0 111e 1db2 1db4
:3 0 80 :2 0 83
:4 0 1121 1db6 1db8
:3 0 80 :2 0 3
:3 0 1124 1dba 1dbc
:3 0 80 :2 0 83
:4 0 1127 1dbe 1dc0
:3 0 112a 1d96 1dc2
:2 0 1dc4 112d 1dc5
1d93 1dc4 0 1dc6
112f 0 1dd1 9a
:3 0 197 :3 0 1dc7
1dc8 0 1b :3 0
ab :3 0 1dca 1dcb
0 3 :3 0 9c
:3 0 1131 1dc9 1dcf
:2 0 1dd1 1135 1e72
1b :3 0 198 :2 0
4 1dd2 1dd3 0
78 :3 0 79 :3 0
1dd5 1dd6 0 78
:3 0 88 :3 0 1dd8
1dd9 0 25 :2 0
2 :4 0 199 :2 0
8a :2 0 49 :2 0
114b 1dde 1de0 :3 0
114e 1dda 1de2 1dd7
1de4 1de3 :2 0 7b
:3 0 8b :3 0 1de6
1de7 0 7d :4 0
19a :4 0 80 :2 0
81 :3 0 1152 1deb
1ded :3 0 1155 1de8
1def :2 0 1e08 7b
:3 0 8b :3 0 1df1
1df2 0 7d :4 0
19b :4 0 80 :2 0
1b :3 0 19c :3 0
1df7 1df8 0 1158
1df6 1dfa :3 0 80
:2 0 c0 :4 0 115b
1dfc 1dfe :3 0 80
:2 0 1b :3 0 19d
:3 0 1e01 1e02 0
115e 1e00 1e04 :3 0
1161 1df3 1e06 :2 0
1e08 1164 1e09 1de5
1e08 0 1e0a 1167
0 1e1a 120 :3 0
77 :3 0 1b :3 0
19c :3 0 19e :3 0
1b :3 0 19d :3 0
19f :3 0 b7 :4 0
1a0 1 :a 0 1e16
:2 0 1e1a 1e0c 1e14
:2 0 1a :3 0 77
:3 0 1e18 :2 0 1e1a
1169 1e1c 116d 1e1b
1e1a :2 0 1e70 ae
:3 0 1b :3 0 ab
:3 0 1e1f 1e20 0
ac :3 0 1e21 1e22
0 1e68 78 :3 0
79 :3 0 1e24 1e25
0 78 :3 0 88
:3 0 1e27 1e28 0
25 :2 0 2 :4 0
1a1 :2 0 8a :2 0
49 :2 0 116f 1e2d
1e2f :3 0 1172 1e29
1e31 1e26 1e33 1e32
:2 0 7b :3 0 8b
:3 0 1e35 1e36 0
7d :4 0 1a2 :4 0
80 :2 0 81 :3 0
1176 1e3a 1e3c :3 0
1179 1e37 1e3e :2 0
1e58 7b :3 0 8b
:3 0 1e40 1e41 0
7d :4 0 b1 :4 0
80 :2 0 ac :3 0
117c 1e45 1e47 :3 0
80 :2 0 b2 :4 0
117f 1e49 1e4b :3 0
80 :2 0 b3 :3 0
b4 :3 0 49 :2 0
b5 :2 0 1182 1e4e
1e52 1186 1e4d 1e54
:3 0 1189 1e42 1e56
:2 0 1e58 118c 1e59
1e34 1e58 0 1e5a
118f 0 1e68 120
:3 0 77 :3 0 19e
:3 0 1b :3 0 19d
:3 0 19f :3 0 b7
:4 0 1a3 1 :a 0
1e64 :2 0 1e68 1e5c
1e62 :2 0 1a :3 0
77 :3 0 1e66 :2 0
1e68 1191 1e6b :3 0
1e6b 0 1e6b 1e6a
1e68 1e69 :6 0 1e6d
1 :3 0 1196 1e6f
1198 1e6e 1e6d :2 0
1e70 119a :2 0 1e72
119d 1e72 1e71 1dd1
1e70 :6 0 1e73 :2 0
2 5c 1e72 1e76
:3 0 1e75 1e73 1e77
:8 0 
11da
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b 1
3f 1 43 1
47 1 4b 1
4f 1 53 15
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 42
46 4a 4e 52
56 1 60 1
5e 1 67 1
65 1 6e 1
6c 1 75 1
73 1 7c 1
7a 1 83 1
81 1 8a 1
88 1 91 1
8f 1 98 1
96 1 9f 1
9d 1 a6 1
a4 1 ad 1
ab 1 b4 1
b2 1 bb 1
b9 1 c0 1
c6 1 cc 1
d2 1 d8 1
de 1 e4 1
ea 1 f0 1
f6 1 fc 1
102 1 108 1
10e 1 114 1
11a 1 120 1
125 1 12c 1
12a 1 133 1
131 1 13a 1
138 1 13f 1
144 1 149 1
14e 1 153 1
158 1 15f 1
15d 1 164 1
16a 1 170 1
176 1 17c 1
182 1 188 1
18e 1 193 1
198 1 19e 1
1a4 1 1aa 1
1b0 1 1b6 1
1cf 1 1e4 1
1ea 1 1f7 1
203 2 206 208
2 20b 20d 2
20f 211 2 213
215 2 217 219
1 21f 2 221
222 2 21b 224
2 226 228 2
22a 22c 2 22e
230 2 232 234
2 236 238 2
23a 23c 2 23e
240 2 242 244
2 246 248 2
24a 24c 2 24e
250 2 252 254
2 256 258 1
25e 2 260 261
2 25a 263 2
265 267 2 269
26b 2 26d 26f
2 271 273 2
275 277 1 27d
2 27f 280 2
279 282 2 284
286 1 28c 2
28e 28f 2 288
291 2 293 295
1 29b 2 29d
29e 2 297 2a0
2 2a2 2a4 1
2aa 2 2ac 2ad
2 2a6 2af 2
2b1 2b3 1 2b9
2 2bb 2bc 2
2b5 2be 2 2c0
2c2 1 2c8 2
2ca 2cb 2 2c4
2cd 2 2cf 2d1
2 2d3 2d5 2
2d7 2d9 2 2db
2dd 2 2df 2e1
2 2e3 2e5 2
2e7 2e9 2 2eb
2ed 2 2ef 2f1
1 2f7 2 2f9
2fa 2 2f3 2fc
2 2fe 300 1
306 2 308 309
2 302 30b 2
30d 30f 2 311
313 2 315 317
2 319 31b 2
31d 31f 2 321
323 2 325 327
2 329 32b 2
32d 32f 1 335
2 337 338 2
331 33a 2 33c
33e 2 340 342
2 344 346 2
348 34a 2 34c
34e 4 1ff 205
20a 350 1 352
1 354 2 35e
360 3 35c 35d
362 2 36b 36d
2 36a 36f 1
371 1 373 1
375 2 37c 37d
1 381 2 37f
381 2 386 387
1 38b 2 389
38b 2 39c 39e
3 39a 39b 3a0
2 3a9 3ab 2
3ad 3af 2 3b1
3b3 1 3bb 2
3bd 3be 2 3b5
3c0 2 3a8 3c2
1 3c4 1 3c6
2 3d0 3d2 3
3ce 3cf 3d4 2
3dd 3df 2 3dc
3e1 1 3e3 1
3e5 2 3ec 3ed
3 3c7 3e6 3ef
1 3f1 1 3f3
1 3f9 1 401
2 411 413 3
40f 410 415 2
41e 420 2 422
424 2 426 428
1 430 2 432
433 2 42a 435
2 41d 437 1
439 1 43b 2
445 447 3 443
444 449 2 452
454 2 451 456
1 458 1 45a
2 461 462 3
43c 45b 464 1
466 1 494 2
496 497 1 49d
2 499 49d 2
4a1 4a2 1 4a6
2 4a4 4a6 2
4ab 4ac 1 4b0
2 4ae 4b0 1
4b6 2 4c3 4c5
3 4c1 4c2 4c7
2 4d0 4d2 2
4d4 4d6 2 4d8
4da 1 4e2 2
4e4 4e5 2 4dc
4e7 2 4cf 4e9
1 4eb 1 4ed
2 4f7 4f9 3
4f5 4f6 4fb 2
504 506 2 503
508 1 50a 1
50c 2 513 514
3 4ee 50d 516
1 518 2 52a
52f 1 536 1
531 2 549 54b
3 547 548 54d
2 556 558 2
55a 55c 2 55e
560 2 562 564
2 566 568 3
56d 56e 56f 2
56a 571 2 555
573 1 575 1
577 2 540 578
1 57c 1 53b
2 539 580 2
590 595 1 59c
1 597 2 5af
5b1 3 5ad 5ae
5b3 2 5bc 5be
2 5c0 5c2 2
5c4 5c6 2 5c8
5ca 2 5cc 5ce
3 5d3 5d4 5d5
2 5d0 5d7 2
5bb 5d9 1 5db
1 5dd 2 5a6
5de 1 5e2 1
5a1 2 59f 5e6
2 5ec 5ed 1
5f1 2 5ef 5f1
2 5f6 5f7 1
5fb 2 5f9 5fb
2 602 603 1
607 2 605 607
2 615 617 3
613 614 619 2
622 624 2 626
628 2 62a 62c
1 632 2 634
635 2 62e 637
2 639 63b 2
63d 63f 2 641
643 2 645 647
2 621 649 1
64b 1 64d 2
657 659 3 655
656 65b 2 664
666 2 663 668
1 66a 1 66c
3 671 672 673
3 64e 66d 675
2 67f 680 1
682 6 688 689
68a 68b 68c 68d
2 692 693 1
697 2 695 697
2 69d 69e 1
6a0 1 6a5 2
6a3 6a5 1 6ac
1 6ae 4 67b
685 690 6af 2
6b1 6b2 8 519
51c 51f 522 583
587 5e9 6b3 2
6cf 6d4 1 6db
1 6d6 2 6ee
6f0 3 6ec 6ed
6f2 2 6fb 6fd
2 6ff 701 2
703 705 2 707
709 2 70b 70d
3 712 713 714
2 70f 716 2
6fa 718 1 71a
1 71c 2 6e5
71d 1 721 1
6e0 2 6de 725
1 730 2 72c
730 2 735 736
2 73b 73c 1
73e 2 738 73e
2 74c 74e 3
74a 74b 750 2
759 75b 2 75d
75f 2 761 763
1 769 2 76b
76c 2 765 76e
2 770 772 2
774 776 2 778
77a 2 77c 77e
2 758 780 1
782 1 784 2
78e 790 3 78c
78d 792 2 79b
79d 2 79a 79f
1 7a1 1 7a3
3 7a8 7a9 7aa
3 785 7a4 7ac
1 7ae 3 6b7
728 7af 2 7b1
7b2 2 7b5 7b6
1 7ba 2 7b8
7ba 1 7c1 2
7bf 7c1 2 7cc
7ce 3 7ca 7cb
7d0 2 7d9 7db
2 7dd 7df 2
7e1 7e3 1 7eb
2 7ed 7ee 2
7e5 7f0 2 7f2
7f4 2 7f6 7f8
2 7fa 7fc 2
7fe 800 2 7d8
802 1 804 1
806 2 810 812
3 80e 80f 814
2 81d 81f 2
81c 821 1 823
1 825 3 82c
82d 82e 3 807
826 830 1 832
1 834 1 839
1 840 1 847
2 856 858 3
854 855 85a 2
863 865 2 867
869 2 86b 86d
1 875 2 877
878 2 86f 87a
2 862 87c 1
87e 1 880 2
88a 88c 3 888
889 88e 2 897
899 2 896 89b
1 89d 1 89f
2 8a6 8a7 3
881 8a0 8a9 1
8ab 2 8b3 8b4
1 8b8 2 8b6
8b8 1 8bd 1
8bf 2 8c7 8cc
1 8d3 1 8ce
2 8e6 8e8 3
8e4 8e5 8ea 2
8f3 8f5 2 8f7
8f9 2 8fb 8fd
2 8ff 901 2
903 905 3 90a
90b 90c 2 907
90e 2 8f2 910
1 912 1 914
2 8dd 915 1
919 1 8d8 2
8d6 91d 2 923
924 1 928 2
926 928 1 92f
2 931 932 1
938 2 93a 93b
2 934 93d 2
940 942 2 945
947 1 949 2
94e 94f 2 954
955 1 957 2
951 957 2 95c
95f 1 963 2
965 966 2 94c
967 1 969 2
970 971 2 973
974 1 979 2
977 979 2 97d
97e 1 982 2
980 982 2 986
987 1 98b 2
989 98b 11 992
993 994 995 996
997 998 999 99a
99b 99c 99d 99e
99f 9a0 9a1 9a2
1 9aa 2 9a8
9aa 1 9bf 2
9be 9bf 1 9c7
1 9cd 2 9cf
9d0 2 9bc 9d1
1 9d8 1 9d3
2 9eb 9ed 3
9e9 9ea 9ef 2
9f8 9fa 2 9fc
9fe 2 a00 a02
2 a04 a06 2
a08 a0a 3 a0f
a10 a11 2 a0c
a13 2 9f7 a15
1 a17 1 a19
2 9e2 a1a 1
a1e 1 9dd 2
9db a22 1 a25
1 a28 2 9a5
a29 11 a2f a30
a31 a32 a33 a34
a35 a36 a37 a38
a39 a3a a3b a3c
a3d a3e a3f 1
a42 2 a44 a45
1 a46 2 a4a
a4b 2 a4d a4f
2 a54 a55 1
a59 2 a57 a59
11 a60 a61 a62
a63 a64 a65 a66
a67 a68 a69 a6a
a6b a6c a6d a6e
a6f a70 1 a78
2 a76 a78 1
a89 2 a88 a89
1 a91 1 a97
2 a99 a9a 2
a86 a9b 1 aa2
1 a9d 2 ab5
ab7 3 ab3 ab4
ab9 2 ac2 ac4
2 ac6 ac8 2
aca acc 2 ace
ad0 2 ad2 ad4
3 ad9 ada adb
2 ad6 add 2
ac1 adf 1 ae1
1 ae3 2 aac
ae4 1 ae8 1
aa7 2 aa5 aec
1 aef 1 af2
2 a73 af3 11
af9 afa afb afc
afd afe aff b00
b01 b02 b03 b04
b05 b06 b07 b08
b09 1 b0c 2
b0e b0f 2 a52
b10 2 b12 b13
1 b19 2 b17
b19 2 b1f b20
2 b22 b23 1
b28 2 b26 b28
2 b2f b30 2
b35 b36 1 b38
2 b32 b38 2
b3d b3e 1 b42
2 b40 b42 2
b49 b4a 1 b4e
2 b4c b4e 1
b6e 2 b6d b6e
1 b76 1 b7c
2 b7e b7f 2
b6b b80 1 b87
1 b82 2 b9a
b9c 3 b98 b99
b9e 2 ba7 ba9
2 bab bad 2
baf bb1 2 bb3
bb5 2 bb7 bb9
3 bbe bbf bc0
2 bbb bc2 2
ba6 bc4 1 bc6
1 bc8 2 b91
bc9 1 bcd 1
b8c 2 b8a bd1
1 be1 2 be0
be1 1 be9 1
bef 2 bf1 bf2
2 bde bf3 1
bfa 1 bf5 2
c0d c0f 3 c0b
c0c c11 2 c1a
c1c 2 c1e c20
2 c22 c24 2
c26 c28 2 c2a
c2c 3 c31 c32
c33 2 c2e c35
2 c19 c37 1
c39 1 c3b 2
c04 c3c 1 c40
1 bff 2 bfd
c44 1 c51 2
c50 c51 1 c59
1 c5f 2 c61
c62 2 c4e c63
1 c6a 1 c65
2 c7d c7f 3
c7b c7c c81 2
c8a c8c 2 c8e
c90 2 c92 c94
2 c96 c98 2
c9a c9c 3 ca1
ca2 ca3 2 c9e
ca5 2 c89 ca7
1 ca9 1 cab
2 c74 cac 1
cb0 1 c6f 2
c6d cb4 3 bd4
c47 cb7 1 cc8
2 cc7 cc8 1
cd0 1 cd6 2
cd8 cd9 2 cc5
cda 1 ce1 1
cdc 2 cf4 cf6
3 cf2 cf3 cf8
2 d01 d03 2
d05 d07 2 d09
d0b 2 d0d d0f
2 d11 d13 3
d18 d19 d1a 2
d15 d1c 2 d00
d1e 1 d20 1
d22 2 ceb d23
1 d27 1 ce6
2 ce4 d2b 1
d2e 2 d31 d32
1 d33 1 d35
2 b14 d36 2
d3b d3c 2 d3e
d41 2 d46 d47
1 d4b 2 d49
d4b 11 d52 d53
d54 d55 d56 d57
d58 d59 d5a d5b
d5c d5d d5e d5f
d60 d61 d62 1
d6a 2 d68 d6a
2 d6f d70 1
d74 2 d72 d74
2 d7b d7c 1
d80 2 d7e d80
1 d98 2 d97
d98 1 da0 1
da6 2 da8 da9
2 d95 daa 1
db1 1 dac 2
dc4 dc6 3 dc2
dc3 dc8 2 dd1
dd3 2 dd5 dd7
2 dd9 ddb 2
ddd ddf 2 de1
de3 3 de8 de9
dea 2 de5 dec
2 dd0 dee 1
df0 1 df2 2
dbb df3 1 df7
1 db6 2 db4
dfb 1 dfe 1
e01 2 d65 e02
1 e04 2 e16
e1b 1 e22 1
e1d 2 e35 e37
3 e33 e34 e39
2 e42 e44 2
e46 e48 2 e4a
e4c 2 e4e e50
2 e52 e54 3
e59 e5a e5b 2
e56 e5d 2 e41
e5f 1 e61 1
e63 2 e2c e64
1 e68 1 e27
2 e25 e6c 3
e74 e75 e76 1
e7a 2 e78 e7a
2 e89 e8e 1
e95 1 e90 2
ea8 eaa 3 ea6
ea7 eac 2 eb5
eb7 2 eb9 ebb
2 ebd ebf 2
ec1 ec3 2 ec5
ec7 3 ecc ecd
ece 2 ec9 ed0
2 eb4 ed2 1
ed4 1 ed6 2
e9f ed7 1 edb
1 e9a 2 e98
edf 6 ee6 ee7
ee8 ee9 eea eeb
2 ef0 ef1 1
ef5 2 ef3 ef5
2 f0d f0e 1
f19 1 f1f 2
f21 f22 2 f26
f2c 1 f33 1
f2e 2 f46 f48
3 f44 f45 f4a
2 f53 f55 2
f57 f59 2 f5b
f5d 2 f5f f61
2 f63 f65 3
f6a f6b f6c 2
f67 f6e 2 f52
f70 1 f72 1
f74 2 f3d f75
1 f79 1 f38
2 f36 f7d 2
f87 f8c 1 f93
1 f8e 2 fa6
fa8 3 fa4 fa5
faa 2 fb3 fb5
2 fb7 fb9 2
fbb fbd 2 fbf
fc1 2 fc3 fc5
3 fca fcb fcc
2 fc7 fce 2
fb2 fd0 1 fd2
1 fd4 2 f9d
fd5 1 fd9 1
f98 2 f96 fdd
2 fea fec 3
fee fef ff0 2
ff6 ff8 3 ffa
ffb ffc 2 1002
1004 3 1006 1007
1008 2 100e 1010
3 1012 1013 1014
f 101a 101b 101c
101d 101e 101f 1020
1021 1022 1023 1024
1025 1026 1027 1028
2 1034 1036 3
1032 1033 1038 2
1041 1043 2 1045
1047 2 1049 104b
1 1051 2 1053
1054 2 104d 1056
2 1058 105a 2
105c 105e 2 1060
1062 2 1064 1066
2 1040 1068 1
106a 1 106c 2
1076 1078 3 1074
1075 107a 2 1083
1085 2 1082 1087
1 1089 1 108b
3 1090 1091 1092
14 efa efd f00
f03 f06 f09 f0f
f23 f80 fe0 fe4
fe7 ff3 fff 100b
1017 102b 106d 108c
1094 1 1096 5
e81 e84 ee2 eee
1097 1 1099 3
e0b e6f 109a 1
109c 2 10a0 10a1
2 10a3 10a5 11
10ad 10ae 10af 10b0
10b1 10b2 10b3 10b4
10b5 10b6 10b7 10b8
10b9 10ba 10bb 10bc
10bd 1 10c5 2
10c3 10c5 2 10ca
10cb 1 10cf 2
10cd 10cf 2 10d6
10d7 1 10db 2
10d9 10db 1 10ef
2 10ee 10ef 1
10f7 1 10fd 2
10ff 1100 2 10ec
1101 1 1108 1
1103 2 111b 111d
3 1119 111a 111f
2 1128 112a 2
112c 112e 2 1130
1132 2 1134 1136
2 1138 113a 3
113f 1140 1141 2
113c 1143 2 1127
1145 1 1147 1
1149 2 1112 114a
1 114e 1 110d
2 110b 1152 1
1155 1 1158 4
109d 10a8 10c0 1159
2 115b 115c 2
d44 115d 2 115f
1160 1 1166 2
1164 1166 2 1171
1173 3 116f 1170
1175 2 117e 1180
2 1182 1184 2
1186 1188 1 1190
2 1192 1193 2
118a 1195 2 1197
1199 2 119b 119d
2 119f 11a1 2
11a3 11a5 2 117d
11a7 1 11a9 1
11ab 2 11b5 11b7
3 11b3 11b4 11b9
2 11c2 11c4 2
11c1 11c6 1 11c8
1 11ca 3 11d1
11d2 11d3 3 11ac
11cb 11d5 1 11d7
2 11dd 11de 1
11e2 2 11e0 11e2
2 11e7 11e8 1
11ec 2 11ea 11ec
1 11f4 1 11f6
2 11f9 11fa 1
11fe 2 11fc 11fe
2 1203 1204 2
1206 1207 1 120c
2 120a 120c 1
120f 1 1214 1
1231 2 1230 1231
1 1239 1 123f
2 1241 1242 2
122e 1243 1 124a
1 1245 2 125d
125f 3 125b 125c
1261 2 126a 126c
2 126e 1270 2
1272 1274 2 1276
1278 2 127a 127c
3 1281 1282 1283
2 127e 1285 2
1269 1287 1 1289
1 128b 2 1254
128c 1 1290 1
124f 2 124d 1294
1 1297 1 12a6
2 12a5 12a6 1
12ae 1 12b4 2
12b6 12b7 2 12a3
12b8 1 12bf 1
12ba 2 12d2 12d4
3 12d0 12d1 12d6
2 12df 12e1 2
12e3 12e5 2 12e7
12e9 2 12eb 12ed
2 12ef 12f1 3
12f6 12f7 12f8 2
12f3 12fa 2 12de
12fc 1 12fe 1
1300 2 12c9 1301
1 1305 1 12c4
2 12c2 1309 1
130c 2 130f 1310
1 1311 1 1313
1 1362 2 1361
1362 1 136a 1
1370 2 1372 1373
2 135f 1374 1
137b 1 1376 2
138e 1390 3 138c
138d 1392 2 139b
139d 2 139f 13a1
2 13a3 13a5 2
13a7 13a9 2 13ab
13ad 3 13b2 13b3
13b4 2 13af 13b6
2 139a 13b8 1
13ba 1 13bc 2
1385 13bd 1 13c1
1 1380 2 137e
13c5 1 13c8 1
1409 2 1408 1409
1 1411 1 1417
2 1419 141a 2
1406 141b 1 1422
1 141d 2 1435
1437 3 1433 1434
1439 2 1442 1444
2 1446 1448 2
144a 144c 2 144e
1450 2 1452 1454
3 1459 145a 145b
2 1456 145d 2
1441 145f 1 1461
1 1463 2 142c
1464 1 1468 1
1427 2 1425 146c
1 146f 2 1472
1473 1 1474 2
1476 1477 1 1478
2 147c 147d 1
1481 2 147f 1481
1 1490 2 148f
1490 1 1498 1
149e 2 14a0 14a1
2 148d 14a2 1
14a9 1 14a4 2
14bc 14be 3 14ba
14bb 14c0 2 14c9
14cb 2 14cd 14cf
2 14d1 14d3 2
14d5 14d7 2 14d9
14db 3 14e0 14e1
14e2 2 14dd 14e4
2 14c8 14e6 1
14e8 1 14ea 2
14b3 14eb 1 14ef
1 14ae 2 14ac
14f3 1 14f6 2
14fa 14f9 1 14fb
2 14ff 1500 2
1502 1503 1 1508
2 1506 1508 1
150b 1 1510 1
152d 2 152c 152d
1 1535 1 153b
2 153d 153e 2
152a 153f 1 1546
1 1541 2 1559
155b 3 1557 1558
155d 2 1566 1568
2 156a 156c 2
156e 1570 2 1572
1574 2 1576 1578
3 157d 157e 157f
2 157a 1581 2
1565 1583 1 1585
1 1587 2 1550
1588 1 158c 1
154b 2 1549 1590
1 1593 1 15a4
2 15a3 15a4 1
15ac 1 15b2 2
15b4 15b5 2 15a1
15b6 1 15bd 1
15b8 2 15d0 15d2
3 15ce 15cf 15d4
2 15dd 15df 2
15e1 15e3 2 15e5
15e7 2 15e9 15eb
2 15ed 15ef 3
15f4 15f5 15f6 2
15f1 15f8 2 15dc
15fa 1 15fc 1
15fe 2 15c7 15ff
1 1603 1 15c2
2 15c0 1607 1
160a 2 160d 160e
1 160f 1 1611
1 1660 2 165f
1660 1 1668 1
166e 2 1670 1671
2 165d 1672 1
1679 1 1674 2
168c 168e 3 168a
168b 1690 2 1699
169b 2 169d 169f
2 16a1 16a3 2
16a5 16a7 2 16a9
16ab 3 16b0 16b1
16b2 2 16ad 16b4
2 1698 16b6 1
16b8 1 16ba 2
1683 16bb 1 16bf
1 167e 2 167c
16c3 1 16c6 1
1709 2 1708 1709
1 1711 1 1717
2 1719 171a 2
1706 171b 1 1722
1 171d 2 1735
1737 3 1733 1734
1739 2 1742 1744
2 1746 1748 2
174a 174c 2 174e
1750 2 1752 1754
3 1759 175a 175b
2 1756 175d 2
1741 175f 1 1761
1 1763 2 172c
1764 1 1768 1
1727 2 1725 176c
1 176f 2 1772
1773 1 1774 2
1776 1777 1 1778
2 177c 177d 1
1781 2 177f 1781
1 1784 2 178a
178b 1 178f 2
178d 178f 1 17a3
2 17a2 17a3 1
17ab 1 17b1 2
17b3 17b4 2 17a0
17b5 1 17bc 1
17b7 2 17cf 17d1
3 17cd 17ce 17d3
2 17dc 17de 2
17e0 17e2 2 17e4
17e6 2 17e8 17ea
2 17ec 17ee 3
17f3 17f4 17f5 2
17f0 17f7 2 17db
17f9 1 17fb 1
17fd 2 17c6 17fe
1 1802 1 17c1
2 17bf 1806 1
1809 1 181a 2
1819 181a 1 1822
1 1828 2 182a
182b 2 1817 182c
1 1833 1 182e
2 1846 1848 3
1844 1845 184a 2
1853 1855 2 1857
1859 2 185b 185d
2 185f 1861 2
1863 1865 3 186a
186b 186c 2 1867
186e 2 1852 1870
1 1872 1 1874
2 183d 1875 1
1879 1 1838 2
1836 187d 1 1880
2 1883 1884 1
1885 1 1895 2
1894 1895 1 189d
1 18a3 2 18a5
18a6 2 1892 18a7
1 18ae 1 18a9
2 18c1 18c3 3
18bf 18c0 18c5 2
18ce 18d0 2 18d2
18d4 2 18d6 18d8
2 18da 18dc 2
18de 18e0 3 18e5
18e6 18e7 2 18e2
18e9 2 18cd 18eb
1 18ed 1 18ef
2 18b8 18f0 1
18f4 1 18b3 2
18b1 18f8 1 18fb
2 18fe 18ff 1
1900 2 1903 1902
1 1904 2 1906
1907 1 1909 2
190f 1910 1 1914
2 1912 1914 2
191c 191d 1 1921
2 191f 1921 2
1934 1935 1 1939
2 1937 1939 2
1955 195a 1 1961
1 195c 2 1974
1976 3 1972 1973
1978 2 1981 1983
2 1985 1987 2
1989 198b 2 198d
198f 2 1991 1993
3 1998 1999 199a
2 1995 199c 2
1980 199e 1 19a0
1 19a2 2 196b
19a3 1 19a7 1
1966 2 1964 19ab
1 19ae 2 19cb
19d0 1 19d7 1
19d2 2 19ea 19ec
3 19e8 19e9 19ee
2 19f7 19f9 2
19fb 19fd 2 19ff
1a01 2 1a03 1a05
2 1a07 1a09 3
1a0e 1a0f 1a10 2
1a0b 1a12 2 19f6
1a14 1 1a16 1
1a18 2 19e1 1a19
1 1a1d 1 19dc
2 19da 1a21 2
19b3 1a24 2 1a27
1a28 1 1a30 2
1a2c 1a30 2 1a35
1a36 2 1a3b 1a3c
1 1a3e 2 1a38
1a3e 2 1a43 1a44
1 1a48 2 1a46
1a48 2 1a4f 1a50
1 1a54 2 1a52
1a54 1 1a65 2
1a64 1a65 1 1a6d
1 1a73 2 1a75
1a76 2 1a62 1a77
1 1a7e 1 1a79
2 1a91 1a93 3
1a8f 1a90 1a95 2
1a9e 1aa0 2 1aa2
1aa4 2 1aa6 1aa8
2 1aaa 1aac 2
1aae 1ab0 3 1ab5
1ab6 1ab7 2 1ab2
1ab9 2 1a9d 1abb
1 1abd 1 1abf
2 1a88 1ac0 1
1ac4 1 1a83 2
1a81 1ac8 1 1add
2 1adc 1add 1
1ae5 1 1aeb 2
1aed 1aee 2 1ada
1aef 1 1af6 1
1af1 2 1b09 1b0b
3 1b07 1b08 1b0d
2 1b16 1b18 2
1b1a 1b1c 2 1b1e
1b20 2 1b22 1b24
2 1b26 1b28 3
1b2d 1b2e 1b2f 2
1b2a 1b31 2 1b15
1b33 1 1b35 1
1b37 2 1b00 1b38
1 1b3c 1 1afb
2 1af9 1b40 2
1acb 1b43 3 1b4d
1b4e 1b4f 1 1b5a
1 1b60 2 1b62
1b63 1 1b69 2
1b67 1b69 1 1b6d
1 1b6f 2 1b73
1b74 2 1b79 1b7a
2 1b76 1b7c 2
1b81 1b82 1 1b86
2 1b84 1b86 2
1b8a 1b8b 2 1b90
1b91 1 1b93 2
1b8d 1b93 2 1b97
1b98 2 1b9d 1b9e
1 1ba0 2 1b9a
1ba0 2 1ba5 1ba6
1 1ba9 2 1bad
1bae 2 1bb3 1bb4
2 1bb0 1bb6 2
1bbb 1bbc 2 1bb8
1bbe 1 1bc1 2
1bc3 1bc4 1 1bc5
1 1bc7 1 1bd1
2 1bd0 1bd1 1
1bd9 1 1bdf 2
1be1 1be2 2 1bce
1be3 1 1bea 1
1be5 2 1bfd 1bff
3 1bfb 1bfc 1c01
2 1c0a 1c0c 2
1c0e 1c10 2 1c12
1c14 2 1c16 1c18
2 1c1a 1c1c 3
1c21 1c22 1c23 2
1c1e 1c25 2 1c09
1c27 1 1c29 1
1c2b 2 1bf4 1c2c
1 1c30 1 1bef
2 1bed 1c34 3
1bc8 1c37 1c3b 1
1c3d 2 1c40 1c41
2 1c46 1c47 1
1c49 2 1c43 1c49
1 1c4d 1 1c4f
6 1b50 1b64 1b70
1b7f 1c3e 1c50 2
1c56 1c5c 1 1c63
1 1c5e 2 1c76
1c78 3 1c74 1c75
1c7a 2 1c83 1c85
2 1c87 1c89 2
1c8b 1c8d 2 1c8f
1c91 2 1c93 1c95
3 1c9a 1c9b 1c9c
2 1c97 1c9e 2
1c82 1ca0 1 1ca2
1 1ca4 2 1c6d
1ca5 1 1ca9 1
1c68 2 1c66 1cad
2 1cb3 1cb4 1
1cb8 2 1cb6 1cb8
1 1cbc 1 1ccc
2 1ccb 1ccc 1
1cd4 1 1cda 2
1cdc 1cdd 2 1cc9
1cde 1 1ce5 1
1ce0 2 1cf8 1cfa
3 1cf6 1cf7 1cfc
2 1d05 1d07 2
1d09 1d0b 2 1d0d
1d0f 2 1d11 1d13
2 1d15 1d17 3
1d1c 1d1d 1d1e 2
1d19 1d20 2 1d04
1d22 1 1d24 1
1d26 2 1cef 1d27
1 1d2b 1 1cea
2 1ce8 1d2f 1
1d32 1 1d35 4
1b48 1c53 1cb0 1d36
2 1d38 1d39 2
1d3c 1d3d 1 1d41
2 1d3f 1d41 2
1d46 1d47 2 1d49
1d4a 1 1d4f 2
1d4d 1d4f 2 1d54
1d55 1 1d58 2
1d5c 1d5d 1 1d60
2 1d62 1d63 1
1d64 1 1d66 2
1d3a 1d67 1 1d69
6 1929 192c 192f
1932 1a29 1d6a 1
1d6c d 833 8ac
8b1 8c0 920 96a
96d 1161 11d8 11db
11f7 1908 1d6d 1
1d6f 1 1d75 2
1d73 1d75 1 1d7c
1 1d7e 3 7b3
1d70 1d7f 1 1d81
2 1d8b 1d8d 3
1d89 1d8a 1d8f 2
1d98 1d9a 2 1d9c
1d9e 2 1da0 1da2
1 1daa 2 1dac
1dad 2 1da4 1daf
2 1db1 1db3 2
1db5 1db7 2 1db9
1dbb 2 1dbd 1dbf
2 1d97 1dc1 1
1dc3 1 1dc5 3
1dcc 1dcd 1dce 15
355 374 3f2 467
46a 46d 470 473
476 479 47c 47f
482 485 488 48b
48e 491 1d82 1dc6
1dd0 2 1ddd 1ddf
3 1ddb 1ddc 1de1
2 1dea 1dec 2
1de9 1dee 2 1df5
1df9 2 1dfb 1dfd
2 1dff 1e03 2
1df4 1e05 2 1df0
1e07 1 1e09 3
1e0a 1e15 1e19 1
1dd4 2 1e2c 1e2e
3 1e2a 1e2b 1e30
2 1e39 1e3b 2
1e38 1e3d 2 1e44
1e46 2 1e48 1e4a
3 1e4f 1e50 1e51
2 1e4c 1e53 2
1e43 1e55 2 1e3f
1e57 1 1e59 4
1e23 1e5a 1e63 1e67
1 1e6b 1 1e1e
2 1e1c 1e6f 3c
63 6a 71 78
7f 86 8d 94
9b a2 a9 b0
b7 be c4 ca
d0 d6 dc e2
e8 ee f4 fa
100 106 10c 112
118 11e 123 128
12f 136 13d 142
147 14c 151 156
15b 162 168 16e
174 17a 180 186
18c 191 196 19c
1a2 1a8 1ae 1b4
1ba 1d0 1e5 1ef

1
4
0 
1e76
0
1
50
4b
52
0 1 1 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 1 36 1
38 1 3a 1 3c 1 3e 1
40 1 42 1 44 45 1 47
1 49 1 0 0 0 0 0

d2 1 0
53 1 0
1bd 1 2
3b 1 0
23 1 0
13 1 0
7a 1 0
a4 1 0
16a 1 0
182 1 0
43 1 0
f6 1 0
12a 1 0
1b0 1 0
131 1 0
188 1 0
2f 1 0
102 1 0
19e 1 0
88 1 0
114 1 0
37 1 0
120 1 0
170 1 0
10e 1 0
c0 1 0
81 1 0
1b6 1 0
17c 1 0
1f 1 0
2 0 1
144 1 0
fc 1 0
e4 1 0
f 1 0
3 1 0
13f 1 0
4b 1 0
17 1 0
8f 1 0
176 1 0
158 1 0
1a4 1 0
96 1 0
5e 1 0
153 1 0
47 1 0
b 1 0
cc 1 0
27 1 0
193 1 0
14e 1 0
7 1 0
108 1 0
73 1 0
1aa 1 0
1d6 1 3
2b 1 0
b2 1 0
149 1 0
11a 1 0
4f 1 0
9d 1 0
ea 1 0
d8 1 0
33 1 0
164 1 0
ab 1 0
f0 1 0
c6 1 0
3f 1 0
198 1 0
18e 1 0
125 1 0
6c 1 0
65 1 0
b9 1 0
1b 1 0
15d 1 0
de 1 0
1ea 1 0
138 1 0
0

/
SHOW ERRORS FUNCTION SP_ASSIGN_MSP;
ALTER FUNCTION SP_ASSIGN_MSP COMPILE DEBUG;
/*
#Stored Procedure  :SP_A_RESTOPROF
#Short Description :Replace a profile with a resource
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_A_RESTOPROF ==
CREATE OR REPLACE FUNCTION SP_A_RESTOPROF wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
41c
2 :e:
1FUNCTION:
1SP_A_RESTOPROF:
1PRJ_ID:
1VARCHAR2:
1PROFILE_ID001:
1RES_ID001:
1START_DATE001:
1FINISH_DATE001:
1EFFORT001:
1PLS_INTEGER:
1WORK001:
1BITFLAG001:
1EUNIT:
1UNIT:
1CONTOUR001:
1OCCURRENCE:
1CONSIDER_PLANNED_SCHED:
1WORK_TYPE:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_BITID:
1RAW:
136:
1PMO_CNST:
1SC_ZERO_BIT:
1H_BITID1:
1H_RESOURCE_ID:
132:
1H_ID:
1H_SECURITY_ID:
1H_REC_USER:
1H_ASSIGN_ID:
1H_PRJ_ASSIGN_ID:
1H_TSK_ASSIGNMENT_ID:
1H_NEW_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_TMP_ASSIGNMENT_ID:
1H_CUR_PRJ_ASSIGN_ID:
1H_TASK_ID:
1H_RES_ID:
1H_PROJECT_ID:
1H_PROFILE_ID:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_BIT_FLAG:
11:
1H_NULL_STR:
1H_DAYOFYEAR:
1DATE:
1H_START_D:
1H_FINISH_D:
1H_RES_TYPE:
1H_RANK:
1200:
1H_START_DT:
1H_FINISH_DT:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_ROLE_ID:
1H_FULL_NAME:
1255:
1H_IN:
1H_PROFILE_NAME:
1H_LABOR_CODE:
150:
1H_RES_AVAILABLE:
10:
1H_PARTICIPANT:
1H_EVERY:
1H_EFFORT:
1H_CRI:
1H_TYPE:
1H_TYPE_ID:
1H_TOTAL:
1H_WORK:
1H_OCCURRENCE:
1H_EUNIT:
1H_UNIT:
1H_CONTOUR:
1H_DURATION:
1H_WORK_TYPE:
1H_PASSED:
1H_ASSIGNED:
1H_REMAINING:
1H_BITFLAG:
1H_PER_DAY:
1H_PER_WEEK:
1H_UPDATE:
1H_CONSIDER:
1H_PRIORITY:
1H_DAYS:
1H_OWNER:
1H_COUNT:
1H_AVAILABLE:
1H_CONTOUR_CHANGED:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_RATE_ECHANGE:
1H_CURRENCY_ID:
1H_DONOT_REPLACE_BITS:
1H_DONOT_REPLACE_RATE:
1H_DONOT_REPLACE_COST:
1H_FROM_PRJ:
1H_SAME_LABOR:
1H_FS_PROJECT:
1H_MINUTES:
1H_TA_EXISTS:
1H_AND_ROLES:
14000:
1H_AND_SKILLS:
1H_TEMP_RES_COST:
1H_TEMP_VAR:
1H_TEMP_RES_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_PA_TIMEPHASE:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_OLD_REG_COST:
1H_OLD_SPEC_COST:
1H_OLD_REG_SALE:
1H_OLD_SPEC_SALE:
1H_PA_COUNT:
1H_TA_COUNT:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_TABLE_TYPE:
1H_PLANNED_EFFORT:
1H_TASK_TYPE:
1H_PERCENT_UNITS:
1H_TIMECODE_1_ID:
1H_TIMECODE_2_ID:
1H_OLD_PRJ_ASSIGN_ID:
1H_LAST_DAY:
1H_ERROR_ID:
1H_ERROR_CODE:
1H_BASELINE_INITIAL:
1H_TEMP_REM:
1H_TEMP_MIN:
1I_ISTASK:
1I_RETURN:
1L_DATA_FLAG:
1PA_MERGE:
1I_PA_BASELINE:
1I_NEW_PA:
1I_MANY:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
1CURSOR:
1CRCAL1:
1AVAILABLE_MIN:
1CALENDAR_DAY_OF_YEAR:
1ROWNUM:
1ELEMENT_ID:
1SELECT AVAILABLE_MIN FROM CALENDAR_DAY_OF_YEAR:n         WHERE  ROWNUM <= 1 A+
1ND  ELEMENT_ID = h_res_id:
1CSA1:
1BAK_WORK:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1PROJECT_ASSIGNMENT_ID:
1SELECT BAK_WORK FROM TASK_ASSIGNMENTS:n         WHERE  ROWNUM <= 1 AND  PROJE+
1CT_ID = h_project_id AND RESOURCE_ID = h_res_id AND RESOURCE_TYPE = '0' AND:n+
1         PROJECT_ASSIGNMENT_ID IS NuLL:
1C6A:
1R:
1RES_ASSIGNMENT_ID:
1T:
1TSK_ASSIGNMENT_ID:
1TASK_ID:
1ELEMENT_TYPE:
1PLANNED_WORK:
1UNITS_MSP:
1PLANNED_START:
1PLANNED_FINISH:
1W:
1TASK_TYPE:
1PLANNED_DURATION:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1C_CONTOUR:
1CONTOUR_TYPE:
1TMT_WBS:
1RESOURCE_ASSIGNMENTS:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1RANK:
1SELECT r.RES_ASSIGNMENT_ID, t.TSK_ASSIGNMENT_ID, t.TASK_ID, r.ELEMENT_TYPE, t+
1.PLANNED_WORK, t.UNITS_MSP,:n         t.PLANNED_START, t.PLANNED_START, t.PLA+
1NNED_FINISH, w.TASK_TYPE, CASE WHEN t.PLANNED_DURATION = 0 THEN w.PLANNED_DUR+
1ATION ELSE t.PLANNED_DURATION END,:n         t.PROJECT_ASSIGNMENT_ID, t.BILLA+
1BLE, t.CAPITAL_EXPENSE, t.REGULAR_COST, t.SPECIAL_COST, t.REGULAR_RATE, t.SPE+
1CIAL_RATE, :n         t.C_EFFORT, t.T_UNIT, t.C_UNIT, t.C_CONTOUR, t.CONTOUR_+
1TYPE:n         FROM TMT_WBS w, RESOURCE_ASSIGNMENTS r, TASK_ASSIGNMENTS t:n  +
1       WHERE r.PROJECT_ID = h_project_id AND r.RESOURCE_ID = h_profile_id AND+
1 r.RESOURCE_TYPE = '1' :n         AND t.RES_ASSIGNMENT_ID = r.RES_ASSIGNMENT_+
1ID AND r.ELEMENT_ID = w.ELEMENT_ID :n         AND r.ELEMENT_TYPE IN (pmo_cnst+
1.SC_TASK,pmo_cnst.SC_TASK_TYPE1,pmo_cnst.SC_TASK_TYPE2,pmo_cnst.SC_TASK_TYPE3+
1,pmo_cnst.SC_MILESTONE,pmo_cnst.SC_PERSONAL_TASK,pmo_cnst.SC_ACTIVE_ADM_TASK,+
1pmo_cnst.SC_INACTIVE_ADM_TASK,pmo_cnst.SC_WBS_CHANGE_REQUEST_TASK,pmo_cnst.SC+
1_WBS_ACTION_ITEM_TASK,pmo_cnst.SC_WBS_RISK_TASK,pmo_cnst.SC_WBS_ISSUE_TASK,pm+
1o_cnst.SC_WBS_REQUIREMENT_TASK,pmo_cnst.SC_WBS_DEFECT_TASK,pmo_cnst.SC_WBS_SE+
1RVICE_REQUEST_TASK) AND w.RANK LIKE h_rank:n         ORDER BY t.PLANNED_START:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_RESTOPROF(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1183:
1+:
1FPUT:
1               ENTER:: SP_A_RESTOPROF(184) :: cplan.sql(9573) :: :
1BITAND:
1SC_1FFFFFFF:
1=:
1SC_SRCH_PROFILE:
1SC_SRCH_FROM_PROJECT:
14:
1:
1OPEN:
1FOUND:
1SC_STATE:
1100:
1CLOSE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1229:
1           EXCEPTION:: SP_A_RESTOPROF(230) :: cplan.sql(9619) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1236:
1        RETURN_ERROR:: SP_A_RESTOPROF(237) :: cplan.sql(9626) :: :
1STATE:: :
1RECORD_NOT_FOUND:
1 ID:: :
1239:
1                EXIT:: SP_A_RESTOPROF(240) :: cplan.sql(9629) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1TYPE_ID:
1TIMECODE_1_ID:
1TIMECODE_2_ID:
1UNRESOLVED_DURATION:
1SELECT TYPE_ID, RANK, PROJECT_ID, TIMECODE_1_ID, TIMECODE_2_ID, UNRESOLVED_DU+
1RATION:n      INTO h_type_id, h_rank, h_project_id, h_timecode_1_id, h_timeco+
1de_2_id, h_duration:n      FROM TMT_WBS WHERE ELEMENT_ID = h_task_id:
1256:
1           EXCEPTION:: SP_A_RESTOPROF(257) :: cplan.sql(9646) :: :
1SC_SQL_NO_DATA:
1264:
1        RETURN_ERROR:: SP_A_RESTOPROF(265) :: cplan.sql(9654) :: :
1267:
1                EXIT:: SP_A_RESTOPROF(268) :: cplan.sql(9657) :: :
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK INTO h_temp_var:n      FROM PROJECT_DETAILS:n      WHERE PR+
1OJECT_ID = h_project_id:
1285:
1           EXCEPTION:: SP_A_RESTOPROF(286) :: cplan.sql(9675) :: :
1>:
1292:
1        RETURN_ERROR:: SP_A_RESTOPROF(293) :: cplan.sql(9682) :: :
1LEV_LOCKED_BY_LEVEL:
1295:
1                EXIT:: SP_A_RESTOPROF(296) :: cplan.sql(9685) :: :
1TW:
1FS_CODE:
1MINUTE_PER_DAY:
1MINUTE_PER_WEEK:
1PRIORITY:
1CURRENCY_ID:
1PMO_ORASTD:
1TODECIMAL:
1TD:
1ELEMENT_NAME:
1JOIN:
1TMT_DATAFIELDS:
1SELECT tw.TYPE_ID, CASE WHEN tw.FS_CODE IS NuLL THEN 0 ELSE 1 END, COALESCE(t+
1w.MINUTE_PER_DAY, 480), COALESCE(tw.MINUTE_PER_WEEK, 2400), tw.PRIORITY, tw.C+
1URRENCY_ID, PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4):n      INTO h_type, h_+
1fs_project, h_per_day, h_per_week, h_priority, h_currency_id, h_rate_echange+
1:n      FROM TMT_WBS tw JOIN TMT_DATAFIELDS td on tw.CURRENCY_ID = td.ELEMENT+
1_ID WHERE tw.ELEMENT_ID = h_project_id:
1312:
1           EXCEPTION:: SP_A_RESTOPROF(313) :: cplan.sql(9702) :: :
1319:
1        RETURN_ERROR:: SP_A_RESTOPROF(320) :: cplan.sql(9709) :: :
1322:
1                EXIT:: SP_A_RESTOPROF(323) :: cplan.sql(9712) :: :
1NICK_NAME:
1FS_LABOR_CODE:
1RESOURCES:
1SELECT NICK_NAME,FS_LABOR_CODE INTO h_full_name,h_labor_code FROM RESOURCES W+
1HERE RESOURCE_ID = h_res_id:
1337:
1           EXCEPTION:: SP_A_RESTOPROF(338) :: cplan.sql(9727) :: :
1344:
1        RETURN_ERROR:: SP_A_RESTOPROF(345) :: cplan.sql(9734) :: :
1347:
1                EXIT:: SP_A_RESTOPROF(348) :: cplan.sql(9737) :: :
1ROLE_ID:
1PROFILES:
1PROFILE_ID:
1SELECT ROLE_ID INTO h_role_id FROM PROFILES WHERE PROFILE_ID = h_profile_id:
1362:
1           EXCEPTION:: SP_A_RESTOPROF(363) :: cplan.sql(9752) :: :
1STRCMP:
1DEFAULTLEVEL:
1373:
1        RETURN_ERROR:: SP_A_RESTOPROF(374) :: cplan.sql(9763) :: :
1376:
1                EXIT:: SP_A_RESTOPROF(377) :: cplan.sql(9766) :: :
12:
1COUNT:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_ta_count :n      FROM TASK_ASSIGNMENTS+
1:n      WHERE PROJECT_ID = h_project_id AND PROJECT_ID <> TASK_ID AND RESOURC+
1E_ID = h_profile_id :n      AND RESOURCE_TYPE = '1' AND PLANNED_WORK > 0:
1411:
1           EXCEPTION:: SP_A_RESTOPROF(412) :: cplan.sql(9801) :: :
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_pa_count :n      FROM TASK_ASSIGNMENTS+
1:n      WHERE PROJECT_ID = h_project_id AND TASK_ID = h_project_id AND RESOUR+
1CE_ID = h_profile_id AND RESOURCE_TYPE = '1':
1428:
1           EXCEPTION:: SP_A_RESTOPROF(429) :: cplan.sql(9818) :: :
1ISWBSTASK:
1!=:
1DUAL:
1SELECT COUNT('X') INTO h_ta_exists FROM DUAL WHERE EXISTS (SELECT 'X' FROM TA+
1SK_ASSIGNMENTS  :n            WHERE PROJECT_ID = h_project_id AND TASK_ID = h+
1_project_id AND RESOURCE_ID = h_res_id):
1449:
1           EXCEPTION:: SP_A_RESTOPROF(450) :: cplan.sql(9839) :: :
1NOT:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (SELECT 'X' FROM TAS+
1K_ASSIGNMENTS  :n               WHERE PROJECT_ID = h_project_id AND TASK_ID <+
1> PROJECT_ID AND RESOURCE_ID = h_res_id):
1468:
1           EXCEPTION:: SP_A_RESTOPROF(469) :: cplan.sql(9858) :: :
1475:
1        RETURN_ERROR:: SP_A_RESTOPROF(476) :: cplan.sql(9865) :: :
1CHILD_TASK_ASSIGNMENT_ALREADY_:
1478:
1                EXIT:: SP_A_RESTOPROF(479) :: cplan.sql(9868) :: :
1ELSIF:
1ISPROJECTTYPE:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (SELECT 'X' FROM TAS+
1K_ASSIGNMENTS  :n         WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h+
1_res_id AND RESOURCE_TYPE = '0':n         AND PROJECT_ASSIGNMENT_ID IS NuLL):
1501:
1           EXCEPTION:: SP_A_RESTOPROF(502) :: cplan.sql(9891) :: :
1508:
1        RETURN_ERROR:: SP_A_RESTOPROF(509) :: cplan.sql(9898) :: :
1511:
1                EXIT:: SP_A_RESTOPROF(512) :: cplan.sql(9901) :: :
1SC_SQL_SUCCESS:
1552:
1           EXCEPTION:: SP_A_RESTOPROF(553) :: cplan.sql(9942) :: :
1558:
1        RETURN_ERROR:: SP_A_RESTOPROF(559) :: cplan.sql(9948) :: :
1561:
1                EXIT:: SP_A_RESTOPROF(562) :: cplan.sql(9951) :: :
1583:
1           EXCEPTION:: SP_A_RESTOPROF(584) :: cplan.sql(9973) :: :
1PROFILE_NAME:
1SELECT PROFILE_NAME INTO h_profile_name FROM PROFILES WHERE PROFILE_ID = h_pr+
1ofile_id:
1598:
1           EXCEPTION:: SP_A_RESTOPROF(599) :: cplan.sql(9988) :: :
1PARTICIPANT:
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT INTO h_prj_assign_id, h_owner:n      FR+
1OM RESOURCE_ASSIGNMENTS:n      WHERE ELEMENT_ID = h_project_id :n      AND RE+
1SOURCE_TYPE = h_res_type :n      AND RESOURCE_ID = h_res_id:
1617:
1           EXCEPTION:: SP_A_RESTOPROF(618) :: cplan.sql(10007) :: :
1SYS_GUID:
1SECURITY_ID:
1SELECT PARTICIPANT, SECURITY_ID INTO h_owner, h_temp_security_id:n         FR+
1OM RESOURCE_ASSIGNMENTS:n         WHERE ELEMENT_ID = h_project_id :n         +
1AND RESOURCE_TYPE = '1' :n         AND RESOURCE_ID = h_profile_id:
1640:
1           EXCEPTION:: SP_A_RESTOPROF(641) :: cplan.sql(10030) :: :
1SC_AFFECTED:
1GETSECURITYID:
1SC_TEAMMEMBER_GROUP:
1FC_BEFORE_I_RES_ASSIGN:
1GETTABLE:
1TABLE_TYPE:
1REC_USER:
1REC_DATETIME:
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE,:n         RESOURCE_TYPE, RESOURCE_ID, PROFILE_ID, PARTICIPANT, S+
1ECURITY_ID, TABLE_TYPE,:n         REC_USER, REC_DATETIME):n         VALUES (h+
1_prj_assign_id, h_project_id, h_project_id, h_type,:n         h_res_type, h_r+
1es_id, h_profile_id, h_temp_participant, h_temp_security_id, h_table_type,:n +
1        rec_user001, SYSTIMESTAMP):
1678:
1           EXCEPTION:: SP_A_RESTOPROF(679) :: cplan.sql(10068) :: :
1BIT_FLAG:
1SELECT COUNT(TSK_ASSIGNMENT_ID) INTO h_total FROM TASK_ASSIGNMENTS:n         +
1   WHERE PROJECT_ID = h_project_id AND TASK_ID <> h_task_id :n            AND+
1 RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1' AND BIT_FLAG = '0':
1698:
1           EXCEPTION:: SP_A_RESTOPROF(699) :: cplan.sql(10088) :: :
1ASSIGN_NAMES:
1REPLACE:
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_profile_name, h_fu+
1ll_name):n            WHERE ELEMENT_ID = h_project_id AND PROJECT_ID = h_proj+
1ect_id:
1721:
1           EXCEPTION:: SP_A_RESTOPROF(722) :: cplan.sql(10111) :: :
1INSTR:
1LENGTH:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0 THEN ASSIGN_NAMES:n            ELSE:n  +
1          CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) >+
1 2040 THEN ASSIGN_NAMES:n            ELSE ASSIGN_NAMES || h_full_name || ';'+
1:n            END:n            END:n            WHERE PROJECT_ID = h_project_+
1id AND ELEMENT_ID = h_project_id:
1751:
1           EXCEPTION:: SP_A_RESTOPROF(752) :: cplan.sql(10141) :: :
1LOCATE:
1UPDATE TMT_WBS SET ASSIGN_NAMES = CASE WHEN PMO_ORASTD.LOCATE(h_full_name, AS+
1SIGN_NAMES) > 0 THEN REPLACE(ASSIGN_NAMES, h_profile_name || ';', '') ELSE RE+
1PLACE (ASSIGN_NAMES, h_profile_name, h_full_name) END:n         WHERE ELEMENT+
1_ID = h_project_id AND PROJECT_ID = h_project_id:
1773:
1           EXCEPTION:: SP_A_RESTOPROF(774) :: cplan.sql(10163) :: :
1SELECT TSK_ASSIGNMENT_ID INTO h_prj_assignment_id  :n         FROM TASK_ASSIG+
1NMENTS:n         WHERE RES_ASSIGNMENT_ID = h_prj_assign_id AND BIT_FLAG = '0':
1791:
1           EXCEPTION:: SP_A_RESTOPROF(792) :: cplan.sql(10181) :: :
1SELECT TSK_ASSIGNMENT_ID INTO h_prj_assignment_id  :n            FROM TASK_AS+
1SIGNMENTS:n            WHERE RES_ASSIGNMENT_ID = h_prj_assign_id AND BIT_FLAG+
1 = '2':
1809:
1           EXCEPTION:: SP_A_RESTOPROF(810) :: cplan.sql(10199) :: :
1SC_PARTICIPANT:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n               PA+
1RTICIPANT = pmo_cnst.SC_AFFECTED, SECURITY_ID = h_temp_security_id:n         +
1      WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1838:
1           EXCEPTION:: SP_A_RESTOPROF(839) :: cplan.sql(10228) :: :
1FC_AFTER_U_RES_ASSIGN:
1PMO_STPU:
1BIT_OR:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n               PA+
1RTICIPANT=PMO_STPU.BIT_OR(PARTICIPANT, pmo_cnst.SC_AFFECTED):n               +
1WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1861:
1           EXCEPTION:: SP_A_RESTOPROF(862) :: cplan.sql(10251) :: :
1SC_TEAMMEMBER:
1UPDATE RESOURCE_ASSIGNMENTS SET PROFILE_ID = h_profile_id,:n               PA+
1RTICIPANT=PMO_STPU.BIT_OR(PARTICIPANT, pmo_cnst.SC_TEAMMEMBER):n             +
1  WHERE RES_ASSIGNMENT_ID = h_prj_assign_id:
1884:
1           EXCEPTION:: SP_A_RESTOPROF(885) :: cplan.sql(10274) :: :
1RS:
1SELECT CASE WHEN h_currency_id = rs.CURRENCY_ID THEN 1:n      ELSE h_rate_ech+
1ange / PMO_ORASTD.TODECIMAL(td.ELEMENT_NAME,20,4) END:n      INTO h_rate_echa+
1nge:n      FROM RESOURCES rs JOIN TMT_DATAFIELDS td ON rs.CURRENCY_ID = td.EL+
1EMENT_ID AND rs.CURRENCY_ID > 0:n      WHERE RESOURCE_ID=h_res_id:
1908:
1           EXCEPTION:: SP_A_RESTOPROF(909) :: cplan.sql(10298) :: :
11.00:
1FC_DECLARE_PMO_TMP_SEARCH:
1FC_GET_RES_RATES:
1*:
1MAX:
1SELECT MAX(AVAILABLE_MIN) INTO h_res_available:n      FROM CALENDAR_DAY_OF_YE+
1AR:n      WHERE ELEMENT_ID = h_res_id:
1952:
1           EXCEPTION:: SP_A_RESTOPROF(953) :: cplan.sql(10342) :: :
1SELECT TSK_ASSIGNMENT_ID, BILLABLE :n      INTO h_old_prj_assign_id, h_billab+
1le:n      FROM TASK_ASSIGNMENTS:n      WHERE PROJECT_ID = h_project_id AND TA+
1SK_ID = h_project_id :n      AND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE+
1 = '1':
1973:
1           EXCEPTION:: SP_A_RESTOPROF(974) :: cplan.sql(10363) :: :
1ASSIGNMENT_BILLABLE_FLAG:
1TIMEPHASE_PROJECT_ASSIGNMENT:
1SELECT ASSIGNMENT_BILLABLE_FLAG, TIMEPHASE_PROJECT_ASSIGNMENT INTO h_billable+
1, h_pa_timephase:n      FROM PROJECT_DETAILS WHERE PROJECT_ID = h_project_id:
1989:
1           EXCEPTION:: SP_A_RESTOPROF(990) :: cplan.sql(10379) :: :
1IS NOT NULL:
1TO_DATE:
1SELECT RES_ASSIGNMENT_ID,PLANNED_WORK, TO_DATE(SubStr(PLANNED_START, 1, 10)),+
1 TO_DATE(SubStr(PLANNED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n        +
1    REGULAR_COST, SPECIAL_COST, REGULAR_RATE, SPECIAL_RATE, TASK_ID, UNITS_MS+
1P, C_EFFORT, T_UNIT, C_UNIT, C_CONTOUR:n            INTO h_id, h_planned_effo+
1rt, h_start_DT, h_finish_DT, h_billable, h_capital_expense,:n            h_ol+
1d_reg_cost, h_old_spec_cost, h_old_reg_sale, h_old_spec_sale, h_task_id, h_pe+
1rcent_units, h_work, h_eunit, h_unit, h_contour:n            FROM TASK_ASSIGN+
1MENTS:n            WHERE TSK_ASSIGNMENT_ID = h_old_prj_assign_id:
11014:
1           EXCEPTION:: SP_A_RESTOPROF(1015) :: cplan.sql(10404) :: :
11022:
1        RETURN_ERROR:: SP_A_RESTOPROF(1023) :: cplan.sql(10412) :: :
1TASK_ASSIGNMENT_ERROR:
11025:
1                EXIT:: SP_A_RESTOPROF(1026) :: cplan.sql(10415) :: :
1Y:
1FC_TPHASE_ASSIGN:
1-:
1TASK_DAY_OF_YEAR:
1DELETE FROM TASK_DAY_OF_YEAR:n               WHERE PROJECT_ID = h_project_id +
1:n               AND TSK_ASSIGNMENT_ID = h_old_prj_assign_id:
11055:
1           EXCEPTION:: SP_A_RESTOPROF(1056) :: cplan.sql(10445) :: :
1DELETE FROM TASK_ASSIGNMENTS:n               WHERE TSK_ASSIGNMENT_ID = h_old_+
1prj_assign_id:
11075:
1           EXCEPTION:: SP_A_RESTOPROF(1076) :: cplan.sql(10465) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS:n               WHERE RES_ASSIGNMENT_ID = h_+
1id:
11095:
1           EXCEPTION:: SP_A_RESTOPROF(1096) :: cplan.sql(10485) :: :
1UNRESOLVED_FINISH:
1SELECT RES_ASSIGNMENT_ID, C_EFFORT, C_UNIT, C_CONTOUR, TABLE_TYPE, TO_DATE(Su+
1bStr(UNRESOLVED_FINISH, 1, 10)):n                     INTO h_assign_id, h_wor+
1k, h_unit, h_contour, h_table_type, h_finish_D:n                     FROM TAS+
1K_ASSIGNMENTS:n                     WHERE TSK_ASSIGNMENT_ID = h_prj_assignmen+
1t_id:
11137:
1           EXCEPTION:: SP_A_RESTOPROF(1138) :: cplan.sql(10527) :: :
1STRNCMP:
110:
1<:
11149:
1        RETURN_ERROR:: SP_A_RESTOPROF(1150) :: cplan.sql(10539) :: :
11152:
1                EXIT:: SP_A_RESTOPROF(1153) :: cplan.sql(10542) :: :
1SCHED_MIN:
1DAY_YEAR:
1SELECT SCHED_MIN INTO h_last_day FROM TASK_DAY_OF_YEAR:n                     +
1      WHERE PROJECT_ID = h_project_id :n                           AND TSK_AS+
1SIGNMENT_ID = h_prj_assignment_id:n                           AND DAY_YEAR		 +
1 = h_finish_D:
11169:
1           EXCEPTION:: SP_A_RESTOPROF(1170) :: cplan.sql(10559) :: :
1DELETE FROM TASK_DAY_OF_YEAR:n                              WHERE PROJECT_ID +
1= h_project_id :n                              AND TSK_ASSIGNMENT_ID = h_prj_+
1assignment_id:n                              AND DAY_YEAR		  = h_finish_D:
11193:
1           EXCEPTION:: SP_A_RESTOPROF(1194) :: cplan.sql(10583) :: :
1FC_CALC_DURATION:
1INVALID_PARAMS:
18:
11221:
1      RETURN_INVALID:: SP_A_RESTOPROF(1222) :: cplan.sql(10611) :: :
11224:
1                EXIT:: SP_A_RESTOPROF(1225) :: cplan.sql(10614) :: :
1PMO_RETURN_INVALID_SP:
11229:
1        RETURN_ERROR:: SP_A_RESTOPROF(1230) :: cplan.sql(10619) :: :
11232:
1                EXIT:: SP_A_RESTOPROF(1233) :: cplan.sql(10622) :: :
1SC_SRCH_PARTICIPANT:
1RA:
1TA:
1SELECT 1 INTO h_baseline_initial :n                  FROM DUAL :n            +
1      WHERE EXISTS (:n                  SELECT ra.RES_ASSIGNMENT_ID FROM RESO+
1URCE_ASSIGNMENTS ra, TASK_ASSIGNMENTS ta:n                  WHERE ta.PROJECT_+
1ID = h_project_id AND ra.RES_ASSIGNMENT_ID = ta.RES_ASSIGNMENT_ID :n         +
1         AND ra.PROFILE_ID = h_profile_id AND ra.RESOURCE_TYPE = '0'):
11258:
1           EXCEPTION:: SP_A_RESTOPROF(1259) :: cplan.sql(10648) :: :
1SC_BIT_27:
1PMO_FUNC:
1SC_BIT_28:
1BASELINE3_START:
1BASELINE3_FINISH:
1BASELINE3_DURATION:
1BASELINE3_WORK:
1BASELINE3_LABOR_COST:
1PLANNED_LABOR_COST:
1BASELINE3_LABOR_REVENUE:
1PLANNED_LABOR_REVENUE:
1B_REGULAR_COST:
1B_REGULAR_RATE:
1B_SPECIAL_COST:
1B_SPECIAL_RATE:
1BASELINE3_SCH_FLAG:
1UPDATE TASK_ASSIGNMENTS SET:n                     BASELINE3_START = PLANNED_S+
1TART, BASELINE3_FINISH = PLANNED_FINISH, BASELINE3_DURATION = PLANNED_DURATIO+
1N, BASELINE3_WORK = PLANNED_WORK,:n                     BASELINE3_LABOR_COST +
1= PLANNED_LABOR_COST, BASELINE3_LABOR_REVENUE = PLANNED_LABOR_REVENUE,:n     +
1                B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = REGULAR_RATE,+
1 B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE, :n            +
1         BASELINE3_SCH_FLAG = 1:n                     WHERE TSK_ASSIGNMENT_ID+
1 = h_old_prj_assign_id:
11300:
1           EXCEPTION:: SP_A_RESTOPROF(1301) :: cplan.sql(10690) :: :
1PROJECT_ASSIGNMENTS:
1ESTIMATED_BASELINE3_START:
1ESTIMATED_PLANNED_START:
1ESTIMATED_BASELINE3_FINISH:
1ESTIMATED_PLANNED_FINISH:
1ESTIMATED_BASELINE3_EFFORT:
1ESTIMATED_PLANNED_EFFORT:
1ESTIMATED_BASELINE3_COST:
1ESTIMATED_PLANNED_COST:
1ESTIMATED_BASELINE3_REVENUE:
1ESTIMATED_PLANNED_REVENUE:
1UPDATE PROJECT_ASSIGNMENTS SET:n                     ESTIMATED_BASELINE3_STAR+
1T	= ESTIMATED_PLANNED_START, :n                     ESTIMATED_BASELINE3_FINIS+
1H	= ESTIMATED_PLANNED_FINISH, :n                     ESTIMATED_BASELINE3_EFFO+
1RT	= ESTIMATED_PLANNED_EFFORT, :n                     ESTIMATED_BASELINE3_COS+
1T	= ESTIMATED_PLANNED_COST, :n                     ESTIMATED_BASELINE3_REVENU+
1E = ESTIMATED_PLANNED_REVENUE :n                     WHERE PROJECT_ID = h_pro+
1ject_id AND RESOURCE_ID = h_profile_id:
11324:
1           EXCEPTION:: SP_A_RESTOPROF(1325) :: cplan.sql(10714) :: :
10.00:
1FC_SEARCH_2:
1TO_NUMBER:
10.0:
1110:
11341:
1        RETURN_ERROR:: SP_A_RESTOPROF(1342) :: cplan.sql(10731) :: :
1RESOURCE_UNAVAILABLE:
11344:
1                EXIT:: SP_A_RESTOPROF(1345) :: cplan.sql(10734) :: :
11349:
1        RETURN_ERROR:: SP_A_RESTOPROF(1350) :: cplan.sql(10739) :: :
11352:
1                EXIT:: SP_A_RESTOPROF(1353) :: cplan.sql(10742) :: :
1IS NULL:
1SELECT TSK_ASSIGNMENT_ID, PLANNED_START, PLANNED_FINISH, PLANNED_WORK :n     +
1                   INTO h_prj_assignment_id, h_start_date, h_finish_date, h_e+
1ffort:n                        FROM TASK_ASSIGNMENTS:n                       +
1 WHERE PROJECT_ID = h_project_id AND TASK_ID = h_project_id AND RESOURCE_ID =+
1 h_res_id AND BIT_FLAG = '0':
11371:
1           EXCEPTION:: SP_A_RESTOPROF(1372) :: cplan.sql(10761) :: :
1SUM:
1SELECT MAX(DAY_YEAR), SUM(SCHED_MIN) :n                                 INTO +
1h_finish_date, h_effort :n                                 FROM TASK_DAY_OF_Y+
1EAR:n                                 WHERE PROJECT_ID = h_project_id :n     +
1                            AND TSK_ASSIGNMENT_ID = h_prj_assignment_id:n    +
1                             AND DAY_YEAR		  >= h_finish_D:
11395:
1           EXCEPTION:: SP_A_RESTOPROF(1396) :: cplan.sql(10785) :: :
1MIN:
1SELECT MIN(DAY_YEAR), MAX(DAY_YEAR), SUM(SCHED_MIN) :n                       +
1          INTO h_start_date, h_finish_date, h_effort :n                      +
1           FROM TASK_DAY_OF_YEAR:n                                 WHERE PROJ+
1ECT_ID = h_project_id :n                                 AND TSK_ASSIGNMENT_I+
1D = h_prj_assignment_id:n                                 AND DAY_YEAR		  > h+
1_finish_D:
11415:
1           EXCEPTION:: SP_A_RESTOPROF(1416) :: cplan.sql(10805) :: :
1SELECT MAX(DAY_YEAR) INTO h_finish_date :n                                 FR+
1OM TASK_DAY_OF_YEAR:n                                 WHERE PROJECT_ID = h_pr+
1oject_id :n                                 AND TSK_ASSIGNMENT_ID = h_prj_ass+
1ignment_id:n                                 AND DAY_YEAR		  >= h_finish_D:
11437:
1           EXCEPTION:: SP_A_RESTOPROF(1438) :: cplan.sql(10827) :: :
1SELECT MIN(DAY_YEAR), MAX(DAY_YEAR) INTO h_start_date, h_finish_date :n      +
1                           FROM TASK_DAY_OF_YEAR:n                           +
1      WHERE PROJECT_ID = h_project_id :n                                 AND +
1TSK_ASSIGNMENT_ID = h_prj_assignment_id:n                                 AND+
1 DAY_YEAR		  > h_finish_D:
11456:
1           EXCEPTION:: SP_A_RESTOPROF(1457) :: cplan.sql(10846) :: :
13:
1U_ASSIGN_STRING:
1SCHED_START:
1SCHED_FINISH:
1SELECT COALESCE(PLANNED_START,SCHED_START), COALESCE(PLANNED_FINISH,SCHED_FIN+
1ISH) :n                           INTO h_start_date, h_finish_date:n         +
1                  FROM TASK_ASSIGNMENTS:n                           WHERE TSK+
1_ASSIGNMENT_ID = h_prj_assignment_id:
11479:
1           EXCEPTION:: SP_A_RESTOPROF(1480) :: cplan.sql(10869) :: :
11491:
1        RETURN_ERROR:: SP_A_RESTOPROF(1492) :: cplan.sql(10881) :: :
11494:
1                EXIT:: SP_A_RESTOPROF(1495) :: cplan.sql(10884) :: :
1ESTIMATION_LABOR_COST:
1ESTIMATION_LABOR_REVENUE:
1ROLLUP_BITS:
1SC_SET_ALL_BITS:
1TIMEPHASED_BITS:
1SC_SCHED_DELTA_BIT:
1UPDATE TASK_ASSIGNMENTS :n                  SET REGULAR_COST = CASE WHEN h_do+
1not_replace_cost = 0 THEN h_reg_cost  ELSE h_old_reg_cost END,:n             +
1     SPECIAL_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_cost ELSE +
1h_old_spec_cost END,:n                  REGULAR_RATE = CASE WHEN h_donot_repl+
1ace_rate = 0 THEN h_reg_sale  ELSE h_old_reg_sale END,:n                  SPE+
1CIAL_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE h_old_sp+
1ec_sale END,:n                  ESTIMATION_LABOR_COST = (PLANNED_WORK/60.00) +
1* (CASE WHEN h_donot_replace_cost = 0 THEN h_reg_cost ELSE h_old_reg_cost END+
1),:n                  ESTIMATION_LABOR_REVENUE = (PLANNED_WORK/60.00) * (CASE+
1 WHEN h_donot_replace_cost = 0 THEN h_reg_sale ELSE h_old_reg_sale END),:n   +
1               ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_AL+
1L_BITS), :n                  TIMEPHASED_BITS = PMO_STPU.BIT_OR(TIMEPHASED_BIT+
1S, pmo_cnst.SC_SCHED_DELTA_BIT):n                  WHERE TSK_ASSIGNMENT_ID = +
1h_prj_assignment_id:
11524:
1           EXCEPTION:: SP_A_RESTOPROF(1525) :: cplan.sql(10914) :: :
1FC_FIX_ORIGINAL_PROFASS:
1DELETE FROM TASK_DAY_OF_YEAR:n                     WHERE PROJECT_ID = h_proje+
1ct_id :n                     AND TSK_ASSIGNMENT_ID = h_old_prj_assign_id:
11552:
1           EXCEPTION:: SP_A_RESTOPROF(1553) :: cplan.sql(10942) :: :
1START_DT:
1FINISH_DT:
1DURATION:
1PROPOSED_START:
1PROPOSED_FINISH:
1PROPOSED_DURATION:
1PROPOSED_WORK:
1ETC:
1BEST:
1UNRESOLVED_START:
1ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET	:n                     START_DT = h_start_date,:n+
1                     FINISH_DT = h_start_date, :n                     DURATIO+
1N = 0,:n                     PROPOSED_START = NULL,:n                     PRO+
1POSED_FINISH = NULL,:n                     PROPOSED_DURATION = 0,:n          +
1           PROPOSED_WORK = 0,:n                     PLANNED_START = NULL,:n  +
1                   PLANNED_FINISH = NULL,:n                     PLANNED_DURAT+
1ION = 0,:n                     PLANNED_WORK = 0,:n                     ETC = +
10,:n                     BEST = 0,:n                     UNRESOLVED_START = N+
1ULL,:n                     UNRESOLVED_FINISH = NULL,:n                     UN+
1RESOLVED_DURATION = 0,:n                     ASSIGN_STRING = NULL :n         +
1            WHERE TSK_ASSIGNMENT_ID = h_old_prj_assign_id:
11589:
1           EXCEPTION:: SP_A_RESTOPROF(1590) :: cplan.sql(10979) :: :
1SD:
1FD:
1BAK_START_DT:
1BAK_FINISH_DT:
1SC_NS:
1SC_NF:
1INSERT INTO TASK_ASSIGNMENTS(TSK_ASSIGNMENT_ID,RES_ASSIGNMENT_ID,TASK_ID,PROJ+
1ECT_ID,SD,FD,START_DT,FINISH_DT,:n               PLANNED_START, PLANNED_FINIS+
1H, BIT_FLAG, BAK_START_DT, BAK_FINISH_DT, RESOURCE_ID,RESOURCE_TYPE,PROJECT_A+
1SSIGNMENT_ID,:n               BILLABLE, CAPITAL_EXPENSE, REGULAR_COST,SPECIAL+
1_COST,REGULAR_RATE,SPECIAL_RATE, TIMECODE_1_ID, TIMECODE_2_ID, TABLE_TYPE):n +
1              VALUES(h_prj_assignment_id, h_prj_assign_id, h_project_id, h_pr+
1oject_id, pmo_cnst.SC_NS,pmo_cnst.SC_NF,h_sched_start, h_sched_finish,:n     +
1          h_sched_start, h_sched_finish, '0', h_sched_start, h_sched_finish, +
1h_res_id,h_res_type, h_prj_assignment_id,:n               h_billable, h_capit+
1al_expense,h_reg_cost,h_spec_cost,h_reg_sale,h_spec_sale,h_timecode_1_id, h_t+
1imecode_2_id, h_table_type):
11632:
1           EXCEPTION:: SP_A_RESTOPROF(1633) :: cplan.sql(11022) :: :
1INSERT INTO TASK_ASSIGNMENTS(TSK_ASSIGNMENT_ID,RES_ASSIGNMENT_ID,TASK_ID,PROJ+
1ECT_ID,SD,FD,START_DT,FINISH_DT,:n               PLANNED_START, PLANNED_FINIS+
1H, BIT_FLAG, BAK_START_DT, BAK_FINISH_DT, RESOURCE_ID,RESOURCE_TYPE,PROJECT_A+
1SSIGNMENT_ID,:n               BILLABLE, CAPITAL_EXPENSE, REGULAR_COST,SPECIAL+
1_COST,REGULAR_RATE,SPECIAL_RATE, TIMECODE_1_ID, TIMECODE_2_ID, TABLE_TYPE):n +
1              VALUES(h_prj_assignment_id, h_prj_assign_id, h_project_id, h_pr+
1oject_id, pmo_cnst.SC_NS,pmo_cnst.SC_NF,h_sched_start, h_sched_finish,:n     +
1          h_sched_start, h_sched_finish, '0', h_sched_start, h_sched_finish, +
1h_res_id,h_res_type, h_prj_assignment_id,:n               h_billable, h_capit+
1al_expense,h_reg_cost,h_spec_cost,h_reg_sale,h_spec_sale, h_timecode_1_id, h_+
1timecode_2_id, h_table_type):
11656:
1           EXCEPTION:: SP_A_RESTOPROF(1657) :: cplan.sql(11046) :: :
11680:
1           EXCEPTION:: SP_A_RESTOPROF(1681) :: cplan.sql(11070) :: :
1INSERT INTO TASK_ASSIGNMENTS(TSK_ASSIGNMENT_ID,RES_ASSIGNMENT_ID,TASK_ID,PROJ+
1ECT_ID,SD,FD,START_DT,FINISH_DT,:n            PLANNED_START,PLANNED_FINISH,BI+
1T_FLAG,BAK_START_DT,BAK_FINISH_DT,RESOURCE_ID,RESOURCE_TYPE,PROJECT_ASSIGNMEN+
1T_ID,:n            BILLABLE, CAPITAL_EXPENSE, REGULAR_COST,SPECIAL_COST,REGUL+
1AR_RATE,SPECIAL_RATE, TIMECODE_1_ID, TIMECODE_2_ID, TABLE_TYPE):n            +
1VALUES(h_prj_assignment_id, h_prj_assign_id, h_project_id, h_project_id, pmo_+
1cnst.SC_NS,pmo_cnst.SC_NF,h_sched_start, h_sched_finish,:n            h_sched+
1_start, h_sched_finish, '0', h_sched_start, h_sched_finish, h_res_id,h_res_ty+
1pe, h_prj_assignment_id,:n            h_billable, h_capital_expense,h_reg_cos+
1t,h_spec_cost,h_reg_sale,h_spec_sale, h_timecode_1_id, h_timecode_2_id, h_tab+
1le_type):
11705:
1           EXCEPTION:: SP_A_RESTOPROF(1706) :: cplan.sql(11095) :: :
1%:
1LOOP:
1EXIT:
1SELECT  TO_DATE(SubStr(h_start_DT, 1, 10))  INTO  h_start_D FROM DUAL:
11753:
1           EXCEPTION:: SP_A_RESTOPROF(1754) :: cplan.sql(11143) :: :
1SELECT  TO_DATE(SubStr(h_finish_DT, 1, 10))  INTO  h_finish_D FROM DUAL:
11767:
1           EXCEPTION:: SP_A_RESTOPROF(1768) :: cplan.sql(11157) :: :
1SELECT TSK_ASSIGNMENT_ID, BIT_FLAG, C_EFFORT, C_UNIT, C_CONTOUR, CONTOUR_TYPE+
1, TABLE_TYPE, TO_DATE(SubStr(UNRESOLVED_FINISH, 1, 10)) :n               INTO+
1 h_tmp_assignment_id, h_bit_flag, h_work, h_unit, h_contour, h_bitflag, h_tab+
1le_type, h_finish_D :n               FROM TASK_ASSIGNMENTS:n               WH+
1ERE PROJECT_ID = h_project_id AND TASK_ID = h_task_id AND RESOURCE_ID = h_res+
1_id:n               AND RESOURCE_TYPE ='0':
11791:
1           EXCEPTION:: SP_A_RESTOPROF(1792) :: cplan.sql(11181) :: :
1SELECT RES_ASSIGNMENT_ID, PARTICIPANT, SECURITY_ID INTO h_id, h_participant, +
1h_security_id:n                  FROM RESOURCE_ASSIGNMENTS :n                +
1  WHERE ELEMENT_ID = h_task_id AND RESOURCE_ID = h_res_id AND RESOURCE_TYPE='+
10':
11814:
1           EXCEPTION:: SP_A_RESTOPROF(1815) :: cplan.sql(11204) :: :
1CREATED_BY:
1SELECT ra.RES_ASSIGNMENT_ID, ra.RESOURCE_ID, SUBSTR(tw.ASSIGN_NAMES,1,InStr(t+
1w.ASSIGN_NAMES, ';') - 1):n                     INTO h_id, h_resource_id, h_i+
1n :n                     FROM TMT_WBS tw, RESOURCE_ASSIGNMENTS ra:n          +
1           WHERE tw.ELEMENT_ID = h_task_id AND tw.ELEMENT_ID = ra.ELEMENT_ID +
1AND ra.PARTICIPANT = 32 :n                     AND ra.RESOURCE_ID = tw.CREATE+
1D_BY AND NOT EXISTS(:n                     SELECT TSK_ASSIGNMENT_ID FROM TASK+
1_ASSIGNMENTS ta WHERE ta.RES_ASSIGNMENT_ID = ra.RES_ASSIGNMENT_ID):
11835:
1           EXCEPTION:: SP_A_RESTOPROF(1836) :: cplan.sql(11225) :: :
1SC_RESPONSIBLE_GROUP:
1UPDATE RESOURCE_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE='0',:n +
1                       PROFILE_ID = h_profile_id, PARTICIPANT = 48, SECURITY_+
1ID=h_temp_security_id:n                        WHERE RES_ASSIGNMENT_ID = h_id:
11860:
1           EXCEPTION:: SP_A_RESTOPROF(1861) :: cplan.sql(11250) :: :
1FC_AFTER_REPLACE_RES_ASSIGN:
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_in, h_full_name) +
1:n                        WHERE ELEMENT_ID = h_task_id:
11886:
1           EXCEPTION:: SP_A_RESTOPROF(1887) :: cplan.sql(11276) :: :
1SC_FD_EFFORT_DRIVEN:
1DELETE FROM RESOURCE_ASSIGNMENTS :n                           WHERE RES_ASSIG+
1NMENT_ID = h_assign_id:
11907:
1           EXCEPTION:: SP_A_RESTOPROF(1908) :: cplan.sql(11297) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0',+
1:n                        PROFILE_ID = h_profile_id, PARTICIPANT = pmo_cnst.S+
1C_TEAMMEMBER, SECURITY_ID=h_temp_security_id:n                        WHERE R+
1ES_ASSIGNMENT_ID = h_assign_id:
11936:
1           EXCEPTION:: SP_A_RESTOPROF(1937) :: cplan.sql(11326) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_profile_name, h_fu+
1ll_name) :n                        WHERE ELEMENT_ID = h_task_id:
11961:
1           EXCEPTION:: SP_A_RESTOPROF(1962) :: cplan.sql(11351) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = :n                        CASE:n           +
1             WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2040 THEN ASSI+
1GN_NAMES:n                        ELSE ASSIGN_NAMES || h_full_name || ';':n  +
1                      END :n                        WHERE ELEMENT_ID = h_task+
1_id:
11985:
1           EXCEPTION:: SP_A_RESTOPROF(1986) :: cplan.sql(11375) :: :
1INSERT INTO RESOURCE_ASSIGNMENTS(RES_ASSIGNMENT_ID, PROJECT_ID, ELEMENT_ID, E+
1LEMENT_TYPE,:n                        RESOURCE_TYPE, RESOURCE_ID, PROFILE_ID,+
1 PARTICIPANT, SECURITY_ID, TABLE_TYPE,:n                        REC_USER, REC+
1_DATETIME):n                        VALUES (h_assign_id, h_project_id, h_task+
1_id, h_type,:n                        h_temp_res_type, h_res_id, h_profile_id+
1, h_temp_participant, h_temp_security_id, h_table_type,:n                    +
1    rec_user001, SYSTIMESTAMP):
12022:
1           EXCEPTION:: SP_A_RESTOPROF(2023) :: cplan.sql(11412) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                        PROFILE_ID		= h_pro+
1file_id,:n                        RESOURCE_ID		= h_res_id, :n                +
1        RESOURCE_TYPE	= '0':n                        WHERE RES_ASSIGNMENT_ID +
1= h_assign_id:
12048:
1           EXCEPTION:: SP_A_RESTOPROF(2049) :: cplan.sql(11438) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                        PARTICIPANT		= pmo_+
1cnst.SC_TEAMMEMBER, :n                        SECURITY_ID		= h_temp_security_+
1id, :n                        PROFILE_ID		= h_profile_id,:n                  +
1      RESOURCE_ID		= h_res_id, :n                        RESOURCE_TYPE	= '0'+
1:n                        WHERE RES_ASSIGNMENT_ID = h_assign_id:
12076:
1           EXCEPTION:: SP_A_RESTOPROF(2077) :: cplan.sql(11466) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET :n                        PARTICIPANT		= PMO_+
1STPU.BIT_OR(h_participant,pmo_cnst.SC_TEAMMEMBER), :n                        +
1SECURITY_ID		= h_security_id, :n                        PROFILE_ID		= h_profi+
1le_id,:n                        RESOURCE_ID		= h_res_id, :n                  +
1      RESOURCE_TYPE	= '0':n                        WHERE RES_ASSIGNMENT_ID = +
1h_assign_id:
12101:
1           EXCEPTION:: SP_A_RESTOPROF(2102) :: cplan.sql(11491) :: :
1SELECT CASE WHEN FS_LABOR_CODE IS NuLL THEN 0 WHEN FS_LABOR_CODE = h_labor_co+
1de THEN 1 ELSE 2 END:n                  INTO h_same_labor FROM TMT_WBS WHERE +
1ELEMENT_ID=h_task_id:
12130:
1           EXCEPTION:: SP_A_RESTOPROF(2131) :: cplan.sql(11520) :: :
1UPDATE TMT_WBS SET FS_LABOR_CODE = h_labor_code WHERE ELEMENT_ID=h_task_id:
12150:
1           EXCEPTION:: SP_A_RESTOPROF(2151) :: cplan.sql(11540) :: :
1CANNOT_ASSIGN_LABOR_CODE:
1SELECT 1 INTO h_baseline_initial :n               FROM DUAL :n               +
1WHERE EXISTS (:n               SELECT ra.RES_ASSIGNMENT_ID FROM RESOURCE_ASSI+
1GNMENTS ra, TASK_ASSIGNMENTS ta:n               WHERE ta.PROJECT_ID = h_proje+
1ct_id AND ta.TASK_ID = h_task_id AND ra.RES_ASSIGNMENT_ID = ta.RES_ASSIGNMENT+
1_ID :n               AND ra.PROFILE_ID = h_profile_id AND ra.RESOURCE_TYPE = +
1'0'):
12178:
1           EXCEPTION:: SP_A_RESTOPROF(2179) :: cplan.sql(11568) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                  BASELINE3_START = PLANNED_STAR+
1T, BASELINE3_FINISH = PLANNED_FINISH, BASELINE3_DURATION = PLANNED_DURATION, +
1BASELINE3_WORK = PLANNED_WORK,:n                  BASELINE3_LABOR_COST = PLAN+
1NED_LABOR_COST, BASELINE3_LABOR_REVENUE = PLANNED_LABOR_REVENUE,:n           +
1       B_REGULAR_COST = REGULAR_COST, B_REGULAR_RATE = REGULAR_RATE, B_SPECIA+
1L_COST = SPECIAL_COST, B_SPECIAL_RATE = SPECIAL_RATE, :n                  BAS+
1ELINE3_SCH_FLAG = 1:n                  WHERE TSK_ASSIGNMENT_ID = h_tsk_assign+
1ment_id:
12203:
1           EXCEPTION:: SP_A_RESTOPROF(2204) :: cplan.sql(11593) :: :
1PA:
1BIT_SCHED:
1A:
1UTL_RAW:
1UPDATE TASK_DAY_OF_YEAR pa SET :n                     (pa.SCHED_MIN, pa.BIT_S+
1CHED) = (SELECT a.SCHED_MIN, UTL_RAW.BIT_OR(pa.BIT_SCHED, a.BIT_SCHED) :n    +
1                 FROM TASK_DAY_OF_YEAR a :n                     WHERE a.PROJE+
1CT_ID = h_project_id AND a.TSK_ASSIGNMENT_ID = h_tsk_assignment_id AND a.DAY_+
1YEAR = pa.DAY_YEAR):n                     WHERE pa.PROJECT_ID = h_project_id +
1AND pa.TSK_ASSIGNMENT_ID = h_prj_assignment_id:
12230:
1           EXCEPTION:: SP_A_RESTOPROF(2231) :: cplan.sql(11620) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_CPLNF_0001:
1PMO_TMP_CPLNF_0001:
1INSERT INTO PMO_TMP_CPLNF_0001:n                     SELECT r.DAY_YEAR, 0 :n +
1                    FROM CALENDAR_DAY_OF_YEAR r :n                     WHERE +
1r.ELEMENT_ID = h_res_id AND r.DAY_YEAR BETWEEN TO_DATE(SubStr(h_start_D, 1, 1+
10)) AND TO_DATE(SubStr(h_finish_D, 1, 10)):
12258:
1           EXCEPTION:: SP_A_RESTOPROF(2259) :: cplan.sql(11648) :: :
1TDY:
1INSERT INTO PMO_TMP_CPLNF_0001 :n                     SELECT r.DAY_YEAR, 0 :n+
1                     FROM CALENDAR_DAY_OF_YEAR r, TASK_DAY_OF_YEAR tdy :n    +
1                 WHERE r.ELEMENT_ID = h_res_id AND r.DAY_YEAR BETWEEN TO_DATE+
1(SubStr(h_start_D, 1, 10)) AND TO_DATE(SubStr(h_finish_D, 1, 10)) :n         +
1            AND tdy.PROJECT_ID = h_project_id AND tdy.TSK_ASSIGNMENT_ID = h_t+
1sk_assignment_id:n                     AND r.DAY_YEAR = tdy.DAY_YEAR:
12282:
1           EXCEPTION:: SP_A_RESTOPROF(2283) :: cplan.sql(11672) :: :
1SELECT COUNT(DAY_YEAR), MIN(DAY_YEAR) INTO h_temp_var, h_dayofyear :n        +
1             FROM PMO_TMP_CPLNF_0001:
12301:
1           EXCEPTION:: SP_A_RESTOPROF(2302) :: cplan.sql(11691) :: :
1CONTINUE0000:
1DELETE FROM TASK_DAY_OF_YEAR :n                     WHERE PROJECT_ID = h_proj+
1ect_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12325:
1           EXCEPTION:: SP_A_RESTOPROF(2326) :: cplan.sql(11715) :: :
1TRUNC:
1/:
10.49:
1SELECT AVAILABLE_MIN, BIT_SCHED INTO h_available, h_bitID:n                  +
1   FROM CALENDAR_DAY_OF_YEAR:n                     WHERE ELEMENT_ID = h_proje+
1ct_id AND DAY_YEAR = h_dayofyear:
12345:
1           EXCEPTION:: SP_A_RESTOPROF(2346) :: cplan.sql(11735) :: :
1SKIPFIRSTBITSCLEARTOLAST:
1PARENT_ID:
1ACTUAL_FLAG:
1INSERT INTO TASK_DAY_OF_YEAR (:n                     PROJECT_ID,:n           +
1          RESOURCE_ID,:n                     TSK_ASSIGNMENT_ID,:n            +
1         DAY_YEAR,:n                     BIT_FLAG,:n                     SCHE+
1D_MIN,:n                     BIT_SCHED,:n                     PARENT_ID,:n   +
1                  ACTUAL_FLAG,:n                     TASK_ID ):n             +
1        SELECT:n                     h_project_id,:n                     h_re+
1s_id,:n                     h_tsk_assignment_id,:n                     DAY_YE+
1AR,:n                     '0',:n                     h_minutes,:n            +
1         h_bitID,:n                     CASE WHEN h_assigned = 0 THEN h_tsk_a+
1ssignment_id ELSE h_prj_assignment_id END,:n                     0,:n        +
1             h_task_id:n                     FROM PMO_TMP_CPLNF_0001:
12390:
1           EXCEPTION:: SP_A_RESTOPROF(2391) :: cplan.sql(11780) :: :
1UPDATE TASK_ASSIGNMENTS SET :n                     RES_ASSIGNMENT_ID = h_assi+
1gn_id, RESOURCE_ID = h_res_id, RESOURCE_TYPE='0', :n                     PROJ+
1ECT_ASSIGNMENT_ID = CASE WHEN h_assigned = 0 THEN NuLL ELSE h_prj_assignment_+
1id END,:n                     REGULAR_COST = CASE WHEN h_donot_replace_cost =+
1 0 THEN h_reg_cost  ELSE h_old_reg_cost END,:n                     SPECIAL_CO+
1ST = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_cost ELSE h_old_spec_cost+
1 END,:n                     REGULAR_RATE = CASE WHEN h_donot_replace_rate = 0+
1 THEN h_reg_sale  ELSE h_old_reg_sale END,:n                     SPECIAL_RATE+
1 = CASE WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE h_old_spec_sale E+
1ND,:n                     ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cns+
1t.SC_SET_ALL_BITS),:n                     TIMEPHASED_BITS = PMO_STPU.BIT_OR(T+
1IMEPHASED_BITS, pmo_cnst.SC_SCHED_DELTA_BIT):n                     WHERE TSK_+
1ASSIGNMENT_ID = h_tsk_assignment_id:
12417:
1           EXCEPTION:: SP_A_RESTOPROF(2418) :: cplan.sql(11807) :: :
110000.00:
1SC_BIT_30:
1SELECT SCHED_MIN INTO h_last_day FROM TASK_DAY_OF_YEAR:n                     +
1   WHERE PROJECT_ID = h_project_id :n                        AND TSK_ASSIGNME+
1NT_ID = h_tmp_assignment_id:n                        AND DAY_YEAR		  = h_fini+
1sh_D:
12456:
1           EXCEPTION:: SP_A_RESTOPROF(2457) :: cplan.sql(11846) :: :
1DELETE FROM TASK_DAY_OF_YEAR:n                           WHERE PROJECT_ID = h+
1_project_id :n                           AND TSK_ASSIGNMENT_ID = h_tmp_assign+
1ment_id:n                           AND DAY_YEAR		  = h_finish_D:
12480:
1           EXCEPTION:: SP_A_RESTOPROF(2481) :: cplan.sql(11870) :: :
12532:
1           EXCEPTION:: SP_A_RESTOPROF(2533) :: cplan.sql(11922) :: :
12538:
1      RETURN_INVALID:: SP_A_RESTOPROF(2539) :: cplan.sql(11928) :: :
12541:
1                EXIT:: SP_A_RESTOPROF(2542) :: cplan.sql(11931) :: :
1SC_BIT_29_30:
1SCHED_WORK:
1SELECT TSK_ASSIGNMENT_ID, SCHED_START, SCHED_FINISH, SCHED_WORK :n           +
1                INTO h_new_assignment_id, h_start_date, h_finish_date, h_effo+
1rt :n                           FROM TASK_ASSIGNMENTS:n                      +
1     WHERE PROJECT_ID = h_project_id AND TASK_ID = h_task_id AND RESOURCE_ID +
1= h_res_id:
12608:
1           EXCEPTION:: SP_A_RESTOPROF(2609) :: cplan.sql(11998) :: :
1SELECT TSK_ASSIGNMENT_ID, PLANNED_START, PLANNED_FINISH, PLANNED_WORK :n     +
1                      INTO h_new_assignment_id, h_start_date, h_finish_date, +
1h_effort :n                           FROM TASK_ASSIGNMENTS:n                +
1           WHERE PROJECT_ID = h_project_id AND TASK_ID = h_task_id AND RESOUR+
1CE_ID = h_res_id:
12626:
1           EXCEPTION:: SP_A_RESTOPROF(2627) :: cplan.sql(12016) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = SCHED_WORK:n                           WHER+
1E TSK_ASSIGNMENT_ID = h_new_assignment_id:
12648:
1           EXCEPTION:: SP_A_RESTOPROF(2649) :: cplan.sql(12038) :: :
1SELECT SCHED_START, SCHED_FINISH :n                           INTO h_start_da+
1te, h_finish_date:n                           FROM TASK_ASSIGNMENTS:n        +
1                   WHERE TSK_ASSIGNMENT_ID = h_new_assignment_id:
12669:
1           EXCEPTION:: SP_A_RESTOPROF(2670) :: cplan.sql(12059) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = PLANNED_WORK:n                           WH+
1ERE TSK_ASSIGNMENT_ID = h_new_assignment_id:
12689:
1           EXCEPTION:: SP_A_RESTOPROF(2690) :: cplan.sql(12079) :: :
1SELECT PLANNED_START, PLANNED_FINISH :n                           INTO h_star+
1t_date, h_finish_date:n                           FROM TASK_ASSIGNMENTS:n    +
1                       WHERE TSK_ASSIGNMENT_ID = h_new_assignment_id:
12710:
1           EXCEPTION:: SP_A_RESTOPROF(2711) :: cplan.sql(12100) :: :
1UPDATE TASK_ASSIGNMENTS SET :n                     ETC				= CASE WHEN PLANNED+
1_WORK = 0 THEN SCHED_WORK ELSE PLANNED_WORK END,:n                     TIMEPH+
1ASED_BITS = PMO_STPU.BIT_OR(TIMEPHASED_BITS, pmo_cnst.SC_SCHED_DELTA_BIT),:n +
1                    ROLLUP_BITS		= PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_S+
1ET_ALL_BITS):n                     WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id:
12746:
1           EXCEPTION:: SP_A_RESTOPROF(2747) :: cplan.sql(12136) :: :
1UPDATE TASK_ASSIGNMENTS SET :n                     REGULAR_COST = CASE WHEN h+
1_donot_replace_cost = 0 THEN h_reg_cost  ELSE h_old_reg_cost  END,:n         +
1            SPECIAL_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_cos+
1t ELSE h_old_spec_cost END,:n                     REGULAR_RATE = CASE WHEN h_+
1donot_replace_rate = 0 THEN h_reg_sale  ELSE h_old_reg_sale  END,:n          +
1           SPECIAL_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_spec_sale+
1 ELSE h_old_spec_sale END,:n                     ROLLUP_BITS  = PMO_STPU.BIT_+
1OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS), :n                     TIMEPHASED_+
1BITS = PMO_STPU.BIT_OR(TIMEPHASED_BITS, pmo_cnst.SC_SCHED_DELTA_BIT):n       +
1              WHERE TSK_ASSIGNMENT_ID = h_new_assignment_id:
12772:
1           EXCEPTION:: SP_A_RESTOPROF(2773) :: cplan.sql(12162) :: :
1DELETE FROM TASK_DAY_OF_YEAR:n                     WHERE PROJECT_ID = h_proje+
1ct_id :n                     AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12805:
1           EXCEPTION:: SP_A_RESTOPROF(2806) :: cplan.sql(12195) :: :
1DELETE FROM TASK_ASSIGNMENTS:n                        WHERE TSK_ASSIGNMENT_ID+
1 = h_tsk_assignment_id:
12826:
1           EXCEPTION:: SP_A_RESTOPROF(2827) :: cplan.sql(12216) :: :
1FC_BEFORE_D_RES_ASSIGN:
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_assign_id:
12848:
1           EXCEPTION:: SP_A_RESTOPROF(2849) :: cplan.sql(12238) :: :
1UPDATE TASK_ASSIGNMENTS SET	:n                        START_DT = h_start_date+
1,:n                        FINISH_DT = h_start_date,:n                       +
1 DURATION = 0,:n                        PROPOSED_START = NULL,:n             +
1           PROPOSED_FINISH = NULL,:n                        PROPOSED_DURATION+
1 = 0,:n                        PROPOSED_WORK = 0,:n                        PL+
1ANNED_START = NULL,:n                        PLANNED_FINISH = NULL,:n        +
1                PLANNED_DURATION = 0,:n                        PLANNED_WORK =+
1 0,:n                        ETC = 0,:n                        UNRESOLVED_STA+
1RT = NULL,:n                        UNRESOLVED_FINISH = NULL,:n              +
1          UNRESOLVED_DURATION = 0,:n                        ASSIGN_STRING = N+
1ULL :n                        WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
12884:
1           EXCEPTION:: SP_A_RESTOPROF(2885) :: cplan.sql(12274) :: :
1RESOURCE_ASSIGN_ROLES:
1C:
1PROFICIENCY_LEVEL_ID:
1EXPERIENCE_ID:
1PREFERENCE_LEVEL_ID:
1LAST_USED_DATETIME:
1TMT_COMPETENCIES:
1P:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n                  SELECT h_new_assignment_+
1id, c.ELEMENT_ID, c.PROFICIENCY_LEVEL_ID, c.EXPERIENCE_ID, c.PREFERENCE_LEVEL+
1_ID, c.LAST_USED_DATETIME, '0':n                  FROM TMT_COMPETENCIES c JOI+
1N PROFILES p ON c.ELEMENT_ID = p.ROLE_ID WHERE p.PROFILE_ID = h_profile_id:
12913:
1           EXCEPTION:: SP_A_RESTOPROF(2914) :: cplan.sql(12303) :: :
1PRIMARY_ROLE:
1INSERT INTO RESOURCE_ASSIGN_ROLES:n                  SELECT h_new_assignment_+
1id, ROLE_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, LAST_U+
1SED_DATETIME, PRIMARY_ROLE:n                  FROM RESOURCE_ASSIGN_ROLES WHER+
1E RES_ASSIGNMENT_ID = h_profile_id:
12934:
1           EXCEPTION:: SP_A_RESTOPROF(2935) :: cplan.sql(12324) :: :
1RESOURCE_ASSIGN_SKILLS:
1SKILL_ID:
1PRIMARY_SKILL:
1INSERT INTO RESOURCE_ASSIGN_SKILLS:n                  SELECT h_new_assignment+
1_id, SKILL_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, LAST+
1_USED_DATETIME, PRIMARY_SKILL:n                  FROM RESOURCE_ASSIGN_SKILLS +
1WHERE RES_ASSIGNMENT_ID = h_profile_id:
12955:
1           EXCEPTION:: SP_A_RESTOPROF(2956) :: cplan.sql(12345) :: :
12981:
1           EXCEPTION:: SP_A_RESTOPROF(2982) :: cplan.sql(12371) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
13000:
1           EXCEPTION:: SP_A_RESTOPROF(3001) :: cplan.sql(12390) :: :
1EFFORT_WEEK:
1DELETE FROM EFFORT_WEEK WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
13019:
1           EXCEPTION:: SP_A_RESTOPROF(3020) :: cplan.sql(12409) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_tsk_assignment_id:
13038:
1           EXCEPTION:: SP_A_RESTOPROF(3039) :: cplan.sql(12428) :: :
1DELETE FROM RESOURCE_ASSIGN_ROLES WHERE RES_ASSIGNMENT_ID = h_tsk_assignment_+
1id:
13057:
1           EXCEPTION:: SP_A_RESTOPROF(3058) :: cplan.sql(12447) :: :
1DELETE FROM RESOURCE_ASSIGN_SKILLS WHERE RES_ASSIGNMENT_ID = h_tsk_assignment+
1_id:
13076:
1           EXCEPTION:: SP_A_RESTOPROF(3077) :: cplan.sql(12466) :: :
1SUMMARY_TIMESHEETS:
1UPDATE SUMMARY_TIMESHEETS :n               SET RESOURCE_ID = h_res_id :n     +
1          WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id :n               AND +
1PROJECT_ID = h_project_id :n               AND RESOURCE_ID = h_profile_id:
13102:
1           EXCEPTION:: SP_A_RESTOPROF(3103) :: cplan.sql(12492) :: :
1SELECT TSK_ASSIGNMENT_ID, BIT_FLAG INTO h_tmp_assignment_id, h_bit_flag :n   +
1            FROM TASK_ASSIGNMENTS:n               WHERE PROJECT_ID = h_projec+
1t_id AND TASK_ID = h_task_id AND RESOURCE_ID = h_res_id:n               AND R+
1ESOURCE_TYPE ='0':
13120:
1           EXCEPTION:: SP_A_RESTOPROF(3121) :: cplan.sql(12510) :: :
13141:
1           EXCEPTION:: SP_A_RESTOPROF(3142) :: cplan.sql(12531) :: :
13167:
1           EXCEPTION:: SP_A_RESTOPROF(3168) :: cplan.sql(12557) :: :
13195:
1           EXCEPTION:: SP_A_RESTOPROF(3196) :: cplan.sql(12585) :: :
13220:
1           EXCEPTION:: SP_A_RESTOPROF(3221) :: cplan.sql(12610) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_id:
13241:
1           EXCEPTION:: SP_A_RESTOPROF(3242) :: cplan.sql(12631) :: :
1SELECT ra.RES_ASSIGNMENT_ID, SUBSTR(tw.ASSIGN_NAMES,1,InStr(tw.ASSIGN_NAMES, +
1';') - 1):n                     INTO h_id,h_in :n                     FROM TM+
1T_WBS tw, RESOURCE_ASSIGNMENTS ra:n                     WHERE tw.ELEMENT_ID =+
1 h_task_id AND tw.ELEMENT_ID = ra.ELEMENT_ID AND ra.PARTICIPANT = 32 :n      +
1               AND ra.RESOURCE_ID = tw.CREATED_BY AND NOT EXISTS(:n          +
1           SELECT TSK_ASSIGNMENT_ID FROM TASK_ASSIGNMENTS ta WHERE ta.RES_ASS+
1IGNMENT_ID = ra.RES_ASSIGNMENT_ID):
13262:
1           EXCEPTION:: SP_A_RESTOPROF(3263) :: cplan.sql(12652) :: :
13285:
1           EXCEPTION:: SP_A_RESTOPROF(3286) :: cplan.sql(12675) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE='0',:n +
1                       PROFILE_ID = h_profile_id, PARTICIPANT = 48, SECURITY_+
1ID=h_temp_security_id:n                        WHERE RES_ASSIGNMENT_ID = h_as+
1sign_id:
13306:
1           EXCEPTION:: SP_A_RESTOPROF(3307) :: cplan.sql(12696) :: :
13326:
1           EXCEPTION:: SP_A_RESTOPROF(3327) :: cplan.sql(12716) :: :
13350:
1           EXCEPTION:: SP_A_RESTOPROF(3351) :: cplan.sql(12740) :: :
1UPDATE RESOURCE_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE = '0' +
1:n                        WHERE RES_ASSIGNMENT_ID = h_assign_id:
13370:
1           EXCEPTION:: SP_A_RESTOPROF(3371) :: cplan.sql(12760) :: :
1SC_FIXED_DURATION:
13393:
1           EXCEPTION:: SP_A_RESTOPROF(3394) :: cplan.sql(12783) :: :
13417:
1           EXCEPTION:: SP_A_RESTOPROF(3418) :: cplan.sql(12807) :: :
13436:
1           EXCEPTION:: SP_A_RESTOPROF(3437) :: cplan.sql(12826) :: :
13462:
1           EXCEPTION:: SP_A_RESTOPROF(3463) :: cplan.sql(12852) :: :
1SELECT CASE WHEN FS_LABOR_CODE IS NuLL THEN 0 WHEN FS_LABOR_CODE = h_labor_co+
1de THEN 1 ELSE 2 END:n                     INTO h_same_labor FROM TMT_WBS WHE+
1RE ELEMENT_ID=h_task_id:
13483:
1           EXCEPTION:: SP_A_RESTOPROF(3484) :: cplan.sql(12873) :: :
13503:
1           EXCEPTION:: SP_A_RESTOPROF(3504) :: cplan.sql(12893) :: :
1INSERT INTO PMO_TMP_CPLNF_0001:n                        SELECT r.DAY_YEAR, 0 +
1:n                        FROM CALENDAR_DAY_OF_YEAR r :n                     +
1   WHERE r.ELEMENT_ID = h_res_id AND r.DAY_YEAR BETWEEN TO_DATE(SubStr(h_star+
1t_D, 1, 10)) AND TO_DATE(SubStr(h_finish_D, 1, 10)):
13538:
1           EXCEPTION:: SP_A_RESTOPROF(3539) :: cplan.sql(12928) :: :
1INSERT INTO PMO_TMP_CPLNF_0001 :n                        SELECT r.DAY_YEAR, 0+
1 :n                        FROM CALENDAR_DAY_OF_YEAR r, TASK_DAY_OF_YEAR tdy +
1:n                        WHERE r.ELEMENT_ID = h_res_id AND r.DAY_YEAR BETWEE+
1N TO_DATE(SubStr(h_start_D, 1, 10)) AND TO_DATE(SubStr(h_finish_D, 1, 10)) :n+
1                        AND tdy.PROJECT_ID = h_project_id AND tdy.TSK_ASSIGNM+
1ENT_ID = h_tsk_assignment_id:n                        AND r.DAY_YEAR = tdy.DA+
1Y_YEAR:
13562:
1           EXCEPTION:: SP_A_RESTOPROF(3563) :: cplan.sql(12952) :: :
1SELECT COUNT(DAY_YEAR), MIN(DAY_YEAR), MAX(DAY_YEAR) INTO h_count, h_dayofyea+
1r , h_finish_D:n                        FROM PMO_TMP_CPLNF_0001:
13581:
1           EXCEPTION:: SP_A_RESTOPROF(3582) :: cplan.sql(12971) :: :
1DELETE FROM TASK_DAY_OF_YEAR :n                           WHERE PROJECT_ID = +
1h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
13604:
1           EXCEPTION:: SP_A_RESTOPROF(3605) :: cplan.sql(12994) :: :
1SELECT AVAILABLE_MIN, BIT_SCHED INTO h_available, h_bitID:n                  +
1         FROM CALENDAR_DAY_OF_YEAR:n                           WHERE ELEMENT_+
1ID = h_project_id AND DAY_YEAR = h_dayofyear:
13628:
1           EXCEPTION:: SP_A_RESTOPROF(3629) :: cplan.sql(13018) :: :
1SELECT SCHED_MIN INTO h_temp_min :n                           FROM TASK_DAY_O+
1F_YEAR tdy :n                           WHERE  ROWNUM <= 1 AND  tdy.PROJECT_I+
1D = h_project_id AND tdy.TSK_ASSIGNMENT_ID = h_tsk_assignment_id :n          +
1                 AND tdy.RESOURCE_ID = h_res_id AND tdy.BIT_FLAG = '0' AND td+
1y.DAY_YEAR IN (:n                           select t.DAY_YEAR FROM PMO_TMP_CP+
1LNF_0001 t where t.DAY_YEAR = tdy.DAY_YEAR):n                           :
13649:
1           EXCEPTION:: SP_A_RESTOPROF(3650) :: cplan.sql(13039) :: :
1SKIPLASTBITSCLEARTOFIRST:
1UPDATE TASK_DAY_OF_YEAR tdy SET :n                              tdy.SCHED_MIN+
1 = tdy.SCHED_MIN + h_minutes, :n                              tdy.BIT_SCHED =+
1 UTL_RAW.BIT_OR(tdy.BIT_SCHED,h_bitID1) :n                              WHERE+
1 tdy.PROJECT_ID = h_project_id AND tdy.TSK_ASSIGNMENT_ID = h_tsk_assignment_i+
1d :n                              AND tdy.RESOURCE_ID = h_res_id AND tdy.BIT_+
1FLAG = '0' AND tdy.DAY_YEAR IN (:n                              select t.DAY_+
1YEAR FROM PMO_TMP_CPLNF_0001 t where t.DAY_YEAR = tdy.DAY_YEAR):
13682:
1           EXCEPTION:: SP_A_RESTOPROF(3683) :: cplan.sql(13072) :: :
1INSERT INTO TASK_DAY_OF_YEAR (:n                           PROJECT_ID,:n     +
1                      RESOURCE_ID,:n                           TSK_ASSIGNMENT+
1_ID,:n                           DAY_YEAR,:n                           BIT_FL+
1AG,:n                           SCHED_MIN,:n                           BIT_SC+
1HED,:n                           PARENT_ID,:n                           ACTUA+
1L_FLAG,:n                           TASK_ID ):n                           SEL+
1ECT:n                           h_project_id,:n                           h_r+
1es_id,:n                           h_tsk_assignment_id,:n                    +
1       t.DAY_YEAR,:n                           '0',:n                        +
1   h_minutes,:n                           h_bitID,:n                         +
1  CASE WHEN h_assigned = 0 THEN h_tsk_assignment_id ELSE h_prj_assignment_id +
1END,:n                           0,:n                           h_task_id:n  +
1                         FROM PMO_TMP_CPLNF_0001 t WHERE t.DAY_YEAR NOT IN (s+
1elect tdy.DAY_YEAR from TASK_DAY_OF_YEAR tdy :n                           whe+
1re tdy.PROJECT_ID = h_project_id AND tdy.TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id :n                           AND tdy.RESOURCE_ID = h_res_id AND tdy.BIT_F+
1LAG = '0' AND t.DAY_YEAR = tdy.DAY_YEAR):
13729:
1           EXCEPTION:: SP_A_RESTOPROF(3730) :: cplan.sql(13119) :: :
1UPDATE TASK_DAY_OF_YEAR SET :n                                    SCHED_MIN =+
1 SCHED_MIN + h_minutes:n                                    WHERE PROJECT_ID +
1= h_project_id :n                                    AND TSK_ASSIGNMENT_ID = +
1h_tsk_assignment_id :n                                    AND DAY_YEAR = h_fi+
1nish_D:
13758:
1           EXCEPTION:: SP_A_RESTOPROF(3759) :: cplan.sql(13148) :: :
1SELECT MAX(SCHED_MIN) INTO h_minutes:n                              FROM TASK+
1_DAY_OF_YEAR:n                              WHERE TSK_ASSIGNMENT_ID = h_tsk_a+
1ssignment_id:
13777:
1           EXCEPTION:: SP_A_RESTOPROF(3778) :: cplan.sql(13167) :: :
1UPDATE TASK_DAY_OF_YEAR SET :n                                    SCHED_MIN =+
1 h_temp_min:n                                    WHERE PROJECT_ID = h_project+
1_id :n                                    AND TSK_ASSIGNMENT_ID = h_tsk_assig+
1nment_id :n                                    AND DAY_YEAR = h_finish_D:
13804:
1           EXCEPTION:: SP_A_RESTOPROF(3805) :: cplan.sql(13194) :: :
1UPDATE TASK_ASSIGNMENTS SET RESOURCE_ID = h_res_id, RESOURCE_TYPE='0', :n    +
1                    PROJECT_ASSIGNMENT_ID = CASE WHEN h_assigned = 0 THEN NuL+
1L ELSE h_prj_assignment_id END,:n                        REGULAR_COST = CASE +
1WHEN h_donot_replace_cost = 0 THEN h_reg_cost  ELSE REGULAR_COST END,:n      +
1                  SPECIAL_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_sp+
1ec_cost ELSE SPECIAL_COST END,:n                        REGULAR_RATE = CASE W+
1HEN h_donot_replace_rate = 0 THEN h_reg_sale  ELSE REGULAR_RATE END,:n       +
1                 SPECIAL_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_spe+
1c_sale ELSE SPECIAL_RATE END,:n                        ROLLUP_BITS  = PMO_STP+
1U.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS),:n                        TIM+
1EPHASED_BITS = PMO_STPU.BIT_OR(TIMEPHASED_BITS, pmo_cnst.SC_SCHED_DELTA_BIT)+
1:n                        WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
13835:
1           EXCEPTION:: SP_A_RESTOPROF(3836) :: cplan.sql(13225) :: :
1SC_BIT_29:
110000:
130:
11.5:
1UPDATE TASK_ASSIGNMENTS :n                        SET	TIMEPHASED_BITS = PMO_S+
1TPU.BIT_OR(TIMEPHASED_BITS, pmo_cnst.SC_SCHED_DELTA_BIT),:n                  +
1      ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS), +
1:n                        ETC = ETC + h_effort:n                        WHERE+
1 TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
13888:
1           EXCEPTION:: SP_A_RESTOPROF(3889) :: cplan.sql(13278) :: :
1UPDATE TASK_ASSIGNMENTS :n                        SET RESOURCE_ID = h_res_id,+
1 :n                        RESOURCE_TYPE = '0', :n                        PRO+
1JECT_ASSIGNMENT_ID = CASE WHEN h_assigned = 0 THEN NuLL ELSE h_prj_assignment+
1_id END,:n                        REGULAR_COST = CASE WHEN h_donot_replace_co+
1st = 0 THEN h_reg_cost  ELSE REGULAR_COST END,:n                        SPECI+
1AL_COST = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_cost ELSE SPECIAL_CO+
1ST END,:n                        REGULAR_RATE = CASE WHEN h_donot_replace_rat+
1e = 0 THEN h_reg_sale  ELSE REGULAR_RATE END,:n                        SPECIA+
1L_RATE = CASE WHEN h_donot_replace_rate = 0 THEN h_spec_sale ELSE SPECIAL_RAT+
1E END,:n                        ETC = h_effort,:n                        ROLL+
1UP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS), :n        +
1                TIMEPHASED_BITS = PMO_STPU.BIT_OR(TIMEPHASED_BITS, pmo_cnst.S+
1C_SCHED_DELTA_BIT):n                        WHERE TSK_ASSIGNMENT_ID = h_tsk_a+
1ssignment_id:
13918:
1           EXCEPTION:: SP_A_RESTOPROF(3919) :: cplan.sql(13308) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE(ASSIGN_NAMES,h_profile_name || ';',+
1'') WHERE ELEMENT_ID=h_task_id:
1           EXCEPTION:: SP_A_RESTOPROF(4001) :: cplan.sql(13390) :: :
1INSERT INTO RESOURCE_ASSIGN_ROLES:n                     SELECT h_tsk_assignme+
1nt_id, c.ELEMENT_ID, c.PROFICIENCY_LEVEL_ID, c.EXPERIENCE_ID, c.PREFERENCE_LE+
1VEL_ID, c.LAST_USED_DATETIME, '0':n                     FROM TMT_COMPETENCIES+
1 c JOIN PROFILES p ON c.ELEMENT_ID = p.ROLE_ID WHERE p.PROFILE_ID = h_profile+
1_id:
14024:
1           EXCEPTION:: SP_A_RESTOPROF(4025) :: cplan.sql(13414) :: :
1INSERT INTO RESOURCE_ASSIGN_ROLES:n                     SELECT h_tsk_assignme+
1nt_id, ROLE_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, LAS+
1T_USED_DATETIME, PRIMARY_ROLE:n                     FROM RESOURCE_ASSIGN_ROLE+
1S WHERE RES_ASSIGNMENT_ID = h_profile_id:
14046:
1           EXCEPTION:: SP_A_RESTOPROF(4047) :: cplan.sql(13436) :: :
1INSERT INTO RESOURCE_ASSIGN_SKILLS:n                     SELECT h_tsk_assignm+
1ent_id, SKILL_ID, PROFICIENCY_LEVEL_ID, EXPERIENCE_ID, PREFERENCE_LEVEL_ID, L+
1AST_USED_DATETIME, PRIMARY_SKILL:n                     FROM RESOURCE_ASSIGN_S+
1KILLS WHERE RES_ASSIGNMENT_ID = h_profile_id:
14067:
1           EXCEPTION:: SP_A_RESTOPROF(4068) :: cplan.sql(13457) :: :
1UPDATE EFFORT_WEEK SET RESOURCE_ID = h_res_id:n                  WHERE PROJEC+
1T_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
14096:
1           EXCEPTION:: SP_A_RESTOPROF(4097) :: cplan.sql(13486) :: :
1ACTUAL_REGULAR_COST:
1ACTUAL_SPECIAL_COST:
1ACTUAL_REGULAR_RATE:
1ACTUAL_SPECIAL_RATE:
1UPDATE SUMMARY_TIMESHEETS :n                     SET RESOURCE_ID = h_res_id,+
1:n                     ACTUAL_REGULAR_COST = h_reg_cost  ,:n                 +
1    ACTUAL_SPECIAL_COST = h_spec_cost ,:n                     ACTUAL_REGULAR_+
1RATE = h_reg_sale  ,:n                     ACTUAL_SPECIAL_RATE = h_spec_sale +
1,:n                     REC_USER = h_rec_user, :n                     REC_DAT+
1ETIME = SYSTIMESTAMP:n                     WHERE TSK_ASSIGNMENT_ID = h_id:
14125:
1           EXCEPTION:: SP_A_RESTOPROF(4126) :: cplan.sql(13515) :: :
1UPDATE SUMMARY_TIMESHEETS :n                     SET RESOURCE_ID = h_res_id,+
1:n                     ACTUAL_REGULAR_COST = h_reg_cost  ,:n                 +
1    ACTUAL_SPECIAL_COST = h_spec_cost ,:n                     REC_USER = h_re+
1c_user, :n                     REC_DATETIME = SYSTIMESTAMP:n                 +
1    WHERE TSK_ASSIGNMENT_ID = h_id:
14150:
1           EXCEPTION:: SP_A_RESTOPROF(4151) :: cplan.sql(13540) :: :
1UPDATE SUMMARY_TIMESHEETS :n                     SET RESOURCE_ID = h_res_id,+
1:n                     ACTUAL_REGULAR_RATE = h_reg_sale  ,:n                 +
1    ACTUAL_SPECIAL_RATE = h_spec_sale ,:n                     REC_USER = h_re+
1c_user, :n                     REC_DATETIME = SYSTIMESTAMP:n                 +
1    WHERE TSK_ASSIGNMENT_ID = h_id:
14177:
1           EXCEPTION:: SP_A_RESTOPROF(4178) :: cplan.sql(13567) :: :
1UPDATE SUMMARY_TIMESHEETS :n                     SET RESOURCE_ID = h_res_id,+
1:n                     REC_USER = h_rec_user, :n                     REC_DATE+
1TIME = SYSTIMESTAMP:n                     WHERE TSK_ASSIGNMENT_ID = h_id:
14202:
1           EXCEPTION:: SP_A_RESTOPROF(4203) :: cplan.sql(13592) :: :
1FC_D_RA_AFTER_REPLACE:
14232:
1           EXCEPTION:: SP_A_RESTOPROF(4233) :: cplan.sql(13622) :: :
14239:
1        RETURN_ERROR:: SP_A_RESTOPROF(4240) :: cplan.sql(13629) :: :
14242:
1                EXIT:: SP_A_RESTOPROF(4243) :: cplan.sql(13632) :: :
1>=:
14280:
1      RETURN_INVALID:: SP_A_RESTOPROF(4281) :: cplan.sql(13670) :: :
14283:
1                EXIT:: SP_A_RESTOPROF(4284) :: cplan.sql(13673) :: :
14288:
1        RETURN_ERROR:: SP_A_RESTOPROF(4289) :: cplan.sql(13678) :: :
14291:
1                EXIT:: SP_A_RESTOPROF(4292) :: cplan.sql(13681) :: :
1DELETE FROM PMO_TMP_PA_SUM:
1PMO_TMP_PA_SUM:
1INSERT INTO PMO_TMP_PA_SUM SELECT DAY_YEAR, SUM(SCHED_MIN):n               FR+
1OM TASK_DAY_OF_YEAR:n               WHERE PROJECT_ID = h_project_id AND PAREN+
1T_ID = h_prj_assignment_id:n               GROUP BY DAY_YEAR:
14317:
1           EXCEPTION:: SP_A_RESTOPROF(4318) :: cplan.sql(13707) :: :
14347:
1        RETURN_ERROR:: SP_A_RESTOPROF(4348) :: cplan.sql(13737) :: :
14350:
1                EXIT:: SP_A_RESTOPROF(4351) :: cplan.sql(13740) :: :
14355:
1        RETURN_ERROR:: SP_A_RESTOPROF(4356) :: cplan.sql(13745) :: :
14358:
1                EXIT:: SP_A_RESTOPROF(4359) :: cplan.sql(13748) :: :
1UPDATE TASK_ASSIGNMENTS:n                  SET RES_ASSIGNMENT_ID = h_prj_assi+
1gn_id,:n                  RESOURCE_ID  = h_res_id, RESOURCE_TYPE = '0',:n    +
1              REGULAR_COST = CASE WHEN h_donot_replace_rate = 0 THEN h_reg_co+
1st  * h_rate_echange ELSE REGULAR_COST END,:n                  SPECIAL_COST =+
1 CASE WHEN h_donot_replace_rate = 0 THEN h_spec_cost * h_rate_echange ELSE SP+
1ECIAL_COST END,:n                  REGULAR_RATE = CASE WHEN h_donot_replace_c+
1ost = 0 THEN h_reg_sale  * h_rate_echange ELSE REGULAR_RATE END,:n           +
1       SPECIAL_RATE = CASE WHEN h_donot_replace_cost = 0 THEN h_spec_sale * h+
1_rate_echange ELSE SPECIAL_RATE END,:n                  TIMEPHASED_BITS = PMO+
1_STPU.BIT_OR(TIMEPHASED_BITS, pmo_cnst.SC_SCHED_DELTA_BIT),:n                +
1  ROLLUP_BITS  = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SET_ALL_BITS):n    +
1              WHERE TSK_ASSIGNMENT_ID = h_prj_assignment_id:
14386:
1           EXCEPTION:: SP_A_RESTOPROF(4387) :: cplan.sql(13776) :: :
1UPDATE TASK_DAY_OF_YEAR:n            SET PARENT_ID = h_prj_assignment_id:n   +
1         WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assign+
1ment_id:
14409:
1           EXCEPTION:: SP_A_RESTOPROF(4410) :: cplan.sql(13799) :: :
1SELECT COUNT(*) INTO h_count FROM RESOURCE_ASSIGNMENTS:n         WHERE ELEMEN+
1T_ID = h_project_id AND RESOURCE_ID = h_profile_id AND RESOURCE_TYPE = '1':
14426:
1           EXCEPTION:: SP_A_RESTOPROF(4427) :: cplan.sql(13816) :: :
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE(ASSIGN_NAMES,h_profile_name || ';',+
1''):n            WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_project_i+
1d:
14448:
1           EXCEPTION:: SP_A_RESTOPROF(4449) :: cplan.sql(13838) :: :
1UPDATE TMT_WBS :n         SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_+
1cnst.SC_SET_ALL_BITS),:n         TIMEPHASED_BITS = PMO_STPU.BIT_OR(TIMEPHASED+
1_BITS, pmo_cnst.SC_SCHED_DELTA_BIT):n         WHERE ELEMENT_ID = h_project_id:
14476:
1           EXCEPTION:: SP_A_RESTOPROF(4477) :: cplan.sql(13866) :: :
1SELECT COUNT(*) INTO h_count FROM TASK_ASSIGNMENTS:n            WHERE PROJECT+
1_ID = h_project_id AND PROJECT_ASSIGNMENT_ID = h_old_prj_assign_id:
14494:
1           EXCEPTION:: SP_A_RESTOPROF(4495) :: cplan.sql(13884) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND:n       +
1        ELEMENT_ID = h_project_id AND RESOURCE_ID = h_profile_id AND RESOURCE+
1_TYPE = '1':
14516:
1           EXCEPTION:: SP_A_RESTOPROF(4517) :: cplan.sql(13906) :: :
1DELETE FROM PROJECT_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND RESOURCE_+
1ID = h_profile_id:
14535:
1           EXCEPTION:: SP_A_RESTOPROF(4536) :: cplan.sql(13925) :: :
1SELECT PLANNED_START, PLANNED_FINISH, BEST, TO_DATE(SubStr(BAK_START_DT, 1, 1+
10)), TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULA+
1R_COST, REGULAR_RATE:n         INTO h_start_DT, h_finish_DT, h_effort, h_star+
1t_D, h_finish_D, h_billable, h_capital_expense, h_old_reg_cost, h_old_reg_sal+
1e:n         FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_old_prj_assign_+
1id:
14558:
1           EXCEPTION:: SP_A_RESTOPROF(4559) :: cplan.sql(13948) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n               ESTIMATED_PLANNED_START = h_st+
1art_DT,:n               ESTIMATED_PLANNED_FINISH = h_finish_DT,:n            +
1   ESTIMATED_PLANNED_EFFORT = h_effort,:n               ESTIMATED_PLANNED_COS+
1T = (h_effort/60.00) * h_old_reg_cost,:n               ESTIMATED_PLANNED_REVE+
1NUE = 0.00:n               WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = +
1h_profile_id:
14587:
1           EXCEPTION:: SP_A_RESTOPROF(4588) :: cplan.sql(13977) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n               ESTIMATED_PLANNED_START = h_st+
1art_DT,:n               ESTIMATED_PLANNED_FINISH = h_finish_DT,:n            +
1   ESTIMATED_PLANNED_EFFORT = h_effort,:n               ESTIMATED_PLANNED_COS+
1T = (h_effort/60.00) * h_old_reg_cost,:n               ESTIMATED_PLANNED_REVE+
1NUE = (h_effort/60.00) * h_old_reg_sale:n               WHERE PROJECT_ID = h_+
1project_id AND RESOURCE_ID = h_profile_id:
14612:
1           EXCEPTION:: SP_A_RESTOPROF(4613) :: cplan.sql(14002) :: :
1SELECT PLANNED_START, PLANNED_FINISH, BEST, TO_DATE(SubStr(BAK_START_DT, 1, 1+
10)), TO_DATE(SubStr(BAK_FINISH_DT, 1, 10)), BILLABLE, CAPITAL_EXPENSE, REGULA+
1R_COST, REGULAR_RATE:n         INTO h_start_DT, h_finish_DT, h_effort, h_star+
1t_D, h_finish_D, h_billable, h_capital_expense, h_reg_cost, h_reg_sale:n     +
1    FROM TASK_ASSIGNMENTS :n         WHERE TSK_ASSIGNMENT_ID = h_prj_assignme+
1nt_id:
14647:
1           EXCEPTION:: SP_A_RESTOPROF(4648) :: cplan.sql(14037) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n            ESTIMATED_PLANNED_START  = h_star+
1t_DT,:n            ESTIMATED_PLANNED_FINISH = h_finish_DT,:n            ESTIM+
1ATED_PLANNED_EFFORT = h_effort,:n            ESTIMATED_PLANNED_COST   = (h_ef+
1fort/60.00) * h_reg_cost,:n            ESTIMATED_PLANNED_REVENUE = 0.00:n    +
1        WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h_res_id:
14673:
1           EXCEPTION:: SP_A_RESTOPROF(4674) :: cplan.sql(14063) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n            ESTIMATED_PLANNED_START  = h_star+
1t_DT,:n            ESTIMATED_PLANNED_FINISH = h_finish_DT,:n            ESTIM+
1ATED_PLANNED_EFFORT = h_effort,:n            ESTIMATED_PLANNED_COST   = (h_ef+
1fort/60.00) * h_reg_cost,:n            ESTIMATED_PLANNED_REVENUE = (h_effort/+
160.00) * h_reg_sale:n            WHERE PROJECT_ID = h_project_id AND RESOURCE+
1_ID = h_res_id:
14698:
1           EXCEPTION:: SP_A_RESTOPROF(4699) :: cplan.sql(14088) :: :
1FC_ROLLUP:
1UPDATE PROJECT_ASSIGNMENTS SET:n         ESTIMATED_BASELINE3_START	= ESTIMATE+
1D_PLANNED_START, :n         ESTIMATED_BASELINE3_FINISH	= ESTIMATED_PLANNED_FI+
1NISH, :n         ESTIMATED_BASELINE3_EFFORT	= ESTIMATED_PLANNED_EFFORT, :n   +
1      ESTIMATED_BASELINE3_COST	= ESTIMATED_PLANNED_COST, :n         ESTIMATED+
1_BASELINE3_REVENUE = ESTIMATED_PLANNED_REVENUE :n         WHERE PROJECT_ID = +
1h_project_id AND RESOURCE_ID = h_profile_id:
14733:
1           EXCEPTION:: SP_A_RESTOPROF(4734) :: cplan.sql(14123) :: :
14744:
1       RETURN_STATUS:: SP_A_RESTOPROF(4745) :: cplan.sql(14134) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
14751:
1           EXCEPTION:: SP_A_RESTOPROF(4752) :: cplan.sql(14141) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
14763:
1           EXCEPTION:: SP_A_RESTOPROF(4764) :: cplan.sql(14153) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
6dca
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c :2 a0 6b 81 b0 a3 a0 51
a5 1c :2 a0 6b 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a3 a0 1c
51 81 b0 a0 f4 b4 bf c8
:5 a0 12a bd b7 11 a4 b1 a0
f4 b4 bf c8 :9 a0 12a bd b7
11 a4 b1 a0 f4 b4 bf c8
:6d a0 12a bd b7 11 a4 b1 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :4 a0 51 a5 b :2 a0
6b a5 b d :2 a0 51 a5 b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b a0 7e a0 6b b4
2e 5a 52 10 a0 51 d b7
19 3c a0 6e d a0 6e d
a0 51 d a0 6e d :2 a0 e9
dd b3 :2 a0 e9 d3 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :3 a0 6b d :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :f a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
a0 51 d :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :25 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c :7 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 6e a5
b 7e 51 b4 2e a0 6e d
b7 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c :2 a0 d
:4 a0 51 a5 b 51 a5 b d
:4 a0 51 a5 b 51 a5 b d
:4 a0 51 a5 b 51 a5 b d
:c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :b a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 51 d :4 a0
51 a5 b a5 b 5a d a0
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e :a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e 7e b4
2e a0 51 d :a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 19 3c b7 19 3c a0 b7
:3 a0 51 a5 b a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e 52 10 5a a 10 a0
51 d :a a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 19 3c b7 :2 19
3c a0 6e d a0 6e d a0
6e d a0 4d d a0 4d d
a0 4d d :2 a0 e9 dd b3 :2 a0
e9 d3 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 a5 b 7e 51
b4 2e 7e b4 2e :2 a0 51 a5
b 7e 51 b4 2e 7e b4 2e
a 10 :2 a0 e9 c1 :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c a0
51 d a0 b7 :2 a0 51 a5 b
7e 51 b4 2e a0 51 d b7
19 a0 51 d b7 :2 19 3c :2 a0
e9 c1 :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :b a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 7e
b4 2e a 10 a0 6e d :2 a0
b4 2e d :a a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :3 a0 6b
d b7 :2 a0 51 :2 a0 51 a5 b
:2 a0 6b a0 a5 b d :3 a0 6b
d b7 :2 19 3c a0 6e d a0
51 d :9 a0 a5 b d :4 a0 51
a5 b a5 b d :19 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b :2 a0
a5 b 7e 51 b4 2e 7e b4
2e a0 51 d b7 :c a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e 7e b4 2e :a a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :11 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c a0 b7 :2 a0 6b a0 7e a0
6b b4 2e 5a :11 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 6e d :6 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :6 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 6e d
b7 19 3c b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e 7e b4
2e :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 51 :2 a0 51 a5
b :2 a0 6b a0 a5 b d :a a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
a5 b d a0 b7 :3 a0 51 a5
b :2 a0 6b a5 b 5a a0 7e
a0 6b b4 2e :b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 a5 b d
a0 b7 19 :3 a0 51 a5 b :2 a0
6b a5 b 5a a0 7e a0 6b
b4 2e :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 a5 b d b7 :2 19
3c b7 19 3c b7 :2 19 3c :16 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 51 d b7 19 3c
a0 6e d a0 6e d a0 6e
d :2 a0 b4 2e d :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :c a0 a5 b d :2 a0 51 a5
b 7e 51 b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
b7 19 3c b7 19 3c a0 51
d a0 51 d :6 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 4d
d :c a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :7 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b :2 a0
a5 b 7e 51 b4 2e 7e b4
2e :2 a0 51 a5 b 7e 51 b4
2e a 10 a0 7e b4 2e 5a
a0 51 d a0 51 d :27 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 7e b4 2e :2 a0 51 a5 b
7e 51 b4 2e 7e b4 2e a
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :2 a0 :2 51 a5 b 7e
6e b4 2e :3 a0 6b d :5 a0 7e
51 b4 2e a5 b d :2 a0 6b
a0 d b7 19 3c b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:5 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 51 d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 52 10 a0 51
d b7 19 3c :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d b7 19
3c :3 a0 :2 51 a5 b 7e 6e b4
2e 51 a6 122 51 122 124 d
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e 5a :11 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 51 d :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e 52 10 :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a 52 10 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 a0 b7 :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e :9 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d :7 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 :2 19 3c b7 19 3c b7 19
3c a0 51 d a0 51 d a0
7e 51 b4 2e a0 51 d b7
a0 51 d b7 :2 19 3c :2 a0 51
a5 b 7e 51 b4 2e a0 51
d b7 19 3c :6 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :2 a0 51 a5 b
:2 a0 51 a5 b :3 a0 a5 b d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b a0 a5
57 a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
:2 a0 a5 57 b7 :2 19 3c :2 a0 51
a5 b a0 7e a0 6b b4 2e
a0 51 d b7 19 3c a0 51
d :14 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
a0 51 d b7 19 3c :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
d b7 :3 a0 6b :2 a0 51 a5 b
:2 a0 6b a5 b d b7 :2 19 3c
b7 :2 a0 51 a5 b 7e 51 b4
2e :3 a0 6b d b7 :3 a0 6b :2 a0
51 a5 b :2 a0 6b a5 b d
b7 :2 19 3c b7 :2 19 3c :2 a0 51
a5 b 7e 51 b4 2e 7e b4
2e :18 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :f a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 51 d b7 19 3c a0
51 d :1e a0 :2 51 a0 51 a5 b
a0 51 a5 b :2 51 a5 b d
a0 7e 51 b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 a0 b7 a0 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 a0 7e b4 2e
5a :10 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a0 7e 51 b4
2e :2 a0 51 a5 b 7e 51 b4
2e 7e b4 2e 52 10 :2 a0 51
a5 b 7e 51 b4 2e 7e b4
2e :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :d a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :10 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 d :a a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :d a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :2 19
3c b7 a0 51 d :7 a0 51 a5
b :2 51 a5 b d :b a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e :3 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e d b7 19
3c b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c b7
:2 19 3c :29 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :b a0 51
a5 b :2 a0 51 a5 b 51 :2 a0
51 a5 b a5 b d b7 :5 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :16 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 19 3c b7 :2 19 3c
b7 19 3c b7 19 3c a0 7e
b4 2e :2 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 a0 51 d :2 a0 d :2 a0 d
a0 6e d :2 a0 b4 2e d :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b d b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a 52 10 :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :34 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :34 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 :34 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :34 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 19 3c :3 a0 7e 6e
b4 2e :2 51 a5 b d a0 6e
d :2 a0 d a0 51 d a0 51
d a0 51 d :2 a0 d a0 51
d a0 4d d :2 a0 e9 dd b3
:19 a0 e9 d3 5 :2 a0 f :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 2b b7 19 3c
a0 51 d :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :5 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e :3 a0 6b d :5 a0
7e 51 b4 2e a5 b d :2 a0
6b a0 d :1a a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a a0 51
d a0 6e d :c a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :25 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 7e b4 2e 5a a
10 :2 a0 51 :2 a0 51 a5 b :2 a0
6b a0 a5 b d :b a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 6e d
:5 a0 a5 b d a0 6e d :5 a0
a5 b d :8 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b a0
7e a0 6b b4 2e :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 d a0
6e d :5 a0 a5 b d b7 19
3c a0 b7 :2 a0 51 a5 b a0
7e a0 6b b4 2e :2 a0 51 :2 a0
51 a5 b :2 a0 6b a0 a5 b
d :d a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 6e d :5 a0 a5 b d
a0 6e d :5 a0 a5 b d :8 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 :2 a0 51 a5 b :2 a0
6b a0 a5 b d :3 a0 6b d
a0 6e d a0 51 d :9 a0 a5
b d :4 a0 51 a5 b a5 b
d :2 a0 b4 2e d :19 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
a0 b7 :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 d :3 a0 51 a5
b :2 a0 6b a5 b 5a a0 7e
a0 6b b4 2e :8 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f a0 b7 :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 51 :2 a0 51 a5 b :2 a0 6b
a0 a5 b d :d a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 :10 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :2 19 3c b7 a0 51 d
:2 a0 d :2 a0 :2 51 a5 b 7e 6e
b4 2e a0 51 d b7 19 3c
b7 :2 19 3c :2 a0 51 a5 b 7e
51 b4 2e 5a a0 7e b4 2e
:2 5a a 10 :7 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 b7 :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :3 a0
6b d :2 a0 d a0 2b b7 :2 19
3c b7 19 3c a0 51 d :17 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e 7e b4 2e :18 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 d a0 7e b4 2e 5a
:20 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c :2 a0 6e 11e 11d :2 a0
6b 51 d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e a 10 :10 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :1c a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a a0 51 d :7 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e a0
3b b7 19 3c :5 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :5 a0 a5 b 51
a5 b 7e :3 a0 a5 b 51 a5
b b4 2e 5a 7e 51 b4 2e
a5 b d :9 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :2 a0 6b :2 a0 51 a5 b a0
a5 57 b7 19 3c :16 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :27 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :5 a0 a5 b
51 a5 b 7e :3 a0 a5 b 51
a5 b b4 2e 5a 7e 51 b4
2e a5 b d :3 a0 6b :2 a0 51
a5 b :2 a0 6b a5 b d :7 a0
51 a5 b :2 a0 51 a5 b 51
a5 b d b7 a0 3b b7 :2 19
3c b7 :2 a0 d :2 a0 d a0 6e
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e 52 10 :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e 5a 52 10
:3 a0 6b d :2 a0 d a0 2b a0
b7 :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e :9 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d :7 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 :2 19 3c
b7 a0 7e 51 b4 2e 7e b4
2e a0 7e b4 2e 5a a 10
:3 a0 6b d b7 19 3c :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e 52 10
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e a0 51 d b7 19
3c b7 19 3c :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 a0 51
d a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :3 a0 51 a5 b d
b7 :2 19 3c b7 :2 19 3c :6 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :2 a0 51
a5 b :2 a0 51 a5 b :3 a0 a5
b d :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b d :2 a0 d a0
2b b7 :2 19 3c a0 51 d :2 a0
51 a5 b 7e 51 b4 2e a0
51 d :2 a0 51 a5 b 7e 51
b4 2e :3 a0 6b d b7 :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
d b7 :2 19 3c a0 b7 :2 a0 51
a5 b a0 7e a0 6b b4 2e
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e :3 a0 6b d b7 :3 a0
6b :2 a0 51 a5 b :2 a0 6b a5
b d b7 :2 19 3c b7 19 a0
51 d :2 a0 51 a5 b 7e 51
b4 2e :3 a0 6b d b7 :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
d b7 :2 19 3c b7 :2 19 3c a0
51 d :1e a0 :6 51 a5 b d a0
7e 51 b4 2e :3 a0 6b d :2 a0
d a0 2b a0 b7 a0 7e 51
b4 2e :3 a0 6b d :2 a0 d a0
2b b7 19 a0 7e b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
:f a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :f a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :2 a0 51 a5 b 7e 51 b4
2e :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 51 d :7 a0 51 a5 b
:2 51 a5 b d :7 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :5 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
51 d :7 a0 51 a5 b :2 51 a5
b d :7 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d b7 19 3c b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a :3 a0 6b d :2 a0 d a0
2b b7 19 3c b7 :2 19 3c :2 a0
51 a5 b 7e 51 b4 2e :13 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:1f a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :b a0
51 a5 b :2 a0 51 a5 b 51
:2 a0 51 a5 b a5 b d :3 a0
6b d :5 a0 51 a5 b d :2 a0
6b a0 d b7 :5 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :3 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :3 a0 6b d :3 a0
51 a5 b d :2 a0 6b a0 d
:3 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :15 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :2 19 3c a0
51 d :7 a0 51 a5 b :2 51 a5
b d b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e 7e b4 2e
:18 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:b a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:b a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c b7 19 3c b7 :3 a0
51 a5 b d :2 a0 51 a5 b
7e 51 b4 2e :3 a0 51 a5 b
d :3 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d b7 19 3c :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :c a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 51 d :c a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:3 a0 51 a5 b :2 a0 6b a5 b
5a a0 7e a0 6b b4 2e a0
51 d :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 b7 :2 a0 51 a5 b
a0 7e a0 6b b4 2e :2 a0 51
:2 a0 51 a5 b :2 a0 6b a0 a5
b d :d a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 :10 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :3 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c b7 :22 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a a0 7e b4 2e :2 5a a
10 :2 a0 51 :2 a0 51 a5 b :2 a0
6b a0 a5 b d :3 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :b a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :b a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :6 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 :2 19 3c :2 a0 51 a5 b
a0 7e a0 6b b4 2e :2 a0 51
a5 b a0 7e a0 6b b4 2e
a 10 :5 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c b7 a0 51
d :3 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 :2 51 a5 b 7e 6e b4
2e a0 51 d b7 19 3c :2 a0
51 a5 b a0 7e a0 6b b4
2e :2 a0 51 a5 b a0 7e a0
6b b4 2e a 10 :5 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 d b7
19 3c b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 51 a5
b 7e 51 b4 2e 5a a0 7e
b4 2e :2 5a a 10 :7 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :3 a0 6b d :2 a0 d a0 2b
b7 :2 19 3c b7 19 3c :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 52 10 :2 a0 6e 11e 11d
:2 a0 6b 51 d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e a 10 :10 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :1c a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 51 d :a a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
a0 3b b7 :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e a0 7e b4 2e 5a
a 10 a0 7e b4 2e 5a a
10 :2 a0 d b7 19 3c :5 a0 a5
b 51 a5 b 7e :3 a0 a5 b
51 a5 b b4 2e 5a 7e 51
b4 2e a5 b d :9 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
51 d :1a a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
:2 a0 d :2 a0 6b :2 a0 51 a5 b
a0 a5 57 :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :2 a0
6b :2 a0 51 a5 b a0 a5 57
b7 19 3c :23 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 6b :2 a0 51 a5 b
a0 a5 57 b7 19 3c :2d a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e 7e :2 a0 51 a5 b 7e :2 a0
51 a5 b 7e 51 b4 2e 5a
b4 2e 5a b4 2e d :2 a0 51
a5 b 7e 51 b4 2e :a a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c b7 19 3c :6 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
7e :2 a0 51 a5 b 7e 51 b4
2e 5a b4 2e 5a b4 2e d
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
19 3c b7 :2 19 3c b7 :2 19 3c
:25 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:5 a0 a5 b 51 a5 b 7e :3 a0
a5 b 51 a5 b b4 2e 5a
7e 51 b4 2e a5 b d :3 a0
6b :2 a0 51 a5 b :2 a0 6b a5
b d :7 a0 51 a5 b :2 a0 51
a5 b 51 a5 b d b7 a0
3b b7 :2 19 3c b7 a0 6e d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
a 10 :2 a0 51 a5 b 7e 51
b4 2e a 10 :2 a0 51 a5 b
7e 51 b4 2e a 10 a0 51
d :3 a0 51 a5 b d b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e 5a 52
10 :3 a0 51 a5 b d b7 :4 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e a5 b d b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e 51 b4 2e
d b7 :5 a0 51 a5 b a5 b
7e 51 b4 2e a5 b d b7
:2 19 3c :2 a0 51 a5 b 7e 51
b4 2e :12 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :27 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c a0 51
d :2 a0 51 a5 b a0 7e a0
6b b4 2e a0 51 d b7 a0
51 d b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e :3 a0 6b d
b7 :3 a0 6b :2 a0 51 a5 b :2 a0
6b a5 b d b7 :2 19 3c a0
51 d :1e a0 :6 51 a5 b d a0
7e 51 b4 2e :3 a0 6b d :2 a0
d a0 2b a0 b7 a0 7e 51
b4 2e :3 a0 6b d :2 a0 d a0
2b b7 :2 19 3c b7 :2 19 3c :7 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 7e
b4 2e :18 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c a0 6e d
:5 a0 a5 b d a0 6e d :5 a0
a5 b d :7 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :11 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
b7 :2 a0 51 a5 b 7e 51 b4
2e :d a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b d a0 b7
19 :2 a0 51 a5 b 7e 51 b4
2e :d a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b d b7 19
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 51 a5 b d :3 a0 51 a5
b d b7 :2 19 3c b7 19 3c
:3 a0 51 a5 b 7e 51 b4 2e
d :3 a0 51 a5 b 7e :2 a0 51
a5 b b4 2e d b7 :2 19 3c
:2 a0 6b :4 a0 a5 b d b7 :2 19
3c 93 4f b0 46 b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 51 a5 b
:2 a0 a5 57 b7 19 3c a0 51
d :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 a0
7e b4 2e :2 5a a 10 :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
a 10 a0 51 d a0 b7 :2 a0
51 a5 b 7e 51 b4 2e :3 a0
51 a5 b d b7 :2 19 3c :6 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b :2 a0 51 a5 b :3 a0
a5 b d :2 a0 51 a5 b a0
7e a0 6b b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b a0 a5 57 a0 b7 :2 a0 51
a5 b 7e 51 b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
51 a5 b :2 a0 a5 57 b7 :2 19
3c :2 a0 6e 11e 11d :2 a0 6b 51
d :a a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 6e d a0 51 d a0
51 d a0 51 d a0 51 d
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 6b :2 a0 51 a5 b :2 a0 6b
a5 b d a0 51 d b7 a0
51 d b7 :2 19 3c a0 51 d
:1e a0 :6 51 a5 b d a0 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 a0 b7 a0 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 :28 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 19 3c a0
b7 :2 a0 51 a5 b 7e 51 b4
2e a0 7e b4 2e 5a a 10
:7 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :8 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 19 3c a0 51 d a0 7e
b4 2e 5a :f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e :7 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 51 a5
b 7e 51 b4 2e :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :5 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 19 3c
b7 19 3c a0 51 d :5 a0 :3 51
a5 b d :19 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a a0 7e
b4 2e 5a a0 51 d b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e :f a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :11 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :2 a0 :2 51 a5
b 7e 6e b4 2e 5a :2 a0 6b
:4 a0 51 a5 b d b7 19 3c
b7 19 3c a0 7e b4 2e :2 5a
:2 a0 6b :2 a0 a5 b 7e 51 b4
2e 5a a 10 a0 51 d b7
19 3c b7 19 3c a0 7e b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e a 10 a0 51 d :5 a0
:3 51 a5 b d :19 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :f a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :11 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :2 a0 :2 51 a5 b 7e 6e
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 6b
:4 a0 51 a5 b d b7 19 3c
b7 19 3c :3 a0 a5 b d a0
7e 51 b4 2e :f a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c :2 a0
6b 7e 51 b4 2e :2 a0 6b 51
d b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
6dca
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 d0
cc a2 d8 e1 dd cb e9 f6
f2 c8 fe 107 103 f1 10f 11c
118 ee 124 12d 129 117 135 114
13a 13e 142 146 149 14d 175 155
159 15c 15d 165 169 16d 170 154
19d 180 151 184 185 18d 191 195
198 17f 1ba 1a8 17c 1ac 1ad 1b5
1a7 1d7 1c5 1a4 1c9 1ca 1d2 1c4
1f4 1e2 1c1 1e6 1e7 1ef 1e1 211
1ff 1de 203 204 20c 1fe 22e 21c
1fb 220 221 229 21b 24b 239 218
23d 23e 246 238 268 256 235 25a
25b 263 255 285 273 252 277 278
280 272 2a2 290 26f 294 295 29d
28f 2bf 2ad 28c 2b1 2b2 2ba 2ac
2dc 2ca 2a9 2ce 2cf 2d7 2c9 2f9
2e7 2c6 2eb 2ec 2f4 2e6 316 304
2e3 308 309 311 303 333 321 300
325 326 32e 320 350 33e 31d 342
343 34b 33d 36c 35b 35f 367 33a
384 373 377 37f 35a 3a0 38f 393
39b 357 3b8 3a7 3ab 3b3 38e 3d5
3c3 38b 3c7 3c8 3d0 3c2 3f2 3e0
3bf 3e4 3e5 3ed 3df 40e 3fd 401
409 3dc 426 415 419 421 3fc 442
431 435 43d 3f9 45e 449 44d 450
451 459 430 47b 469 42d 46d 46e
476 468 497 486 48a 492 465 4af
49e 4a2 4aa 485 4cb 4ba 4be 4c6
482 4e3 4d2 4d6 4de 4b9 500 4ee
4b6 4f2 4f3 4fb 4ed 51d 50b 4ea
50f 510 518 50a 53a 528 507 52c
52d 535 527 557 545 524 549 54a
552 544 574 562 541 566 567 56f
561 590 57f 583 55e 58b 57e 5ac
59b 59f 57b 5a7 59a 5c8 5b7 5bb
597 5c3 5b6 5e4 5d3 5d7 5b3 5df
5d2 600 5ef 5f3 5cf 5fb 5ee 61c
60b 60f 5eb 617 60a 638 627 62b
607 633 626 654 643 647 623 64f
642 670 65f 663 63f 66b 65e 68c
67b 67f 65b 687 67a 6a8 697 69b
677 6a3 696 6c4 6b3 6b7 693 6bf
6b2 6e0 6cf 6d3 6af 6db 6ce 6fc
6eb 6ef 6cb 6f7 6ea 718 707 70b
6e7 713 706 734 723 727 703 72f
722 750 73f 743 71f 74b 73e 76c
75b 75f 73b 767 75a 788 777 77b
757 783 776 7a4 793 797 773 79f
792 7c0 7af 7b3 78f 7bb 7ae 7dc
7cb 7cf 7ab 7d7 7ca 7f8 7e7 7eb
7c7 7f3 7e6 814 803 807 7e3 80f
802 830 81f 823 7ff 82b 81e 84c
83b 83f 81b 847 83a 868 857 85b
837 863 856 884 873 877 853 87f
872 8a0 88f 893 86f 89b 88e 8bc
8ab 8af 88b 8b7 8aa 8d8 8c7 8cb
8a7 8d3 8c6 8f4 8e3 8e7 8c3 8ef
8e2 910 8ff 903 8df 90b 8fe 92c
91b 91f 8fb 927 91a 948 937 93b
917 943 936 964 953 957 933 95f
952 980 96f 973 94f 97b 96e 99c
98b 98f 96b 997 98a 9b8 9a7 9ab
987 9b3 9a6 9d4 9c3 9c7 9a3 9cf
9c2 9f0 9df 9e3 9bf 9eb 9de a0c
9fb 9ff 9db a07 9fa a28 a17 a1b
9f7 a23 a16 a45 a33 a13 a37 a38
a40 a32 a62 a50 a2f a54 a55 a5d
a4f a7e a6d a71 a4c a79 a6c a9a
a89 a8d a69 a95 a88 ab7 aa5 a85
aa9 aaa ab2 aa4 ad3 ac2 ac6 aa1
ace ac1 af0 ade abe ae2 ae3 aeb
add b0d afb ada aff b00 b08 afa
b29 b18 b1c af7 b24 b17 b45 b34
b38 b14 b40 b33 b61 b50 b54 b30
b5c b4f b7d b6c b70 b4c b78 b6b
b99 b88 b8c b68 b94 b87 bb5 ba4
ba8 b84 bb0 ba3 bd1 bc0 bc4 ba0
bcc bbf bed bdc be0 bbc be8 bdb
c09 bf8 bfc bd8 c04 bf7 c25 c14
c18 bf4 c20 c13 c41 c30 c34 c10
c3c c2f c5d c4c c50 c2c c58 c4b
c79 c68 c6c c48 c74 c67 c95 c84
c88 c64 c90 c83 cb1 ca0 ca4 c80
cac c9f cce cbc c9c cc0 cc1 cc9
cbb ceb cd9 cb8 cdd cde ce6 cd8
d08 cf6 cd5 cfa cfb d03 cf5 d24
d13 d17 cf2 d1f d12 d41 d2f d0f
d33 d34 d3c d2e d5d d4c d50 d2b
d58 d4b d79 d68 d6c d48 d74 d67
d95 d84 d88 d64 d90 d83 db1 da0
da4 d80 dac d9f dcd dbc dc0 dc8
d9c de5 dd4 dd8 de0 dbb e01 df0
df4 db8 dfc def e1d e0c e10 dec
e18 e0b e39 e28 e2c e08 e34 e27
e55 e44 e48 e24 e50 e43 e71 e60
e64 e40 e6c e5f e8d e7c e80 e88
e5c ea8 e94 e98 ea0 ea3 e7b eaf
eb3 e78 ec4 ec7 ecb ecf ed3 ed7
edb edf eeb ef0 ef2 efe f02 f04
f08 f19 f1a f1d f21 f25 f29 f2d
f31 f35 f39 f3d f41 f45 f51 f56
f58 f64 f68 f6a f6e f7f f80 f83
f87 f8b f8f f93 f97 f9b f9f fa3
fa7 fab faf fb3 fb7 fbb fbf fc3
fc7 fcb fcf fd3 fd7 fdb fdf fe3
fe7 feb fef ff3 ff7 ffb fff 1003
1007 100b 100f 1013 1017 101b 101f 1023
1027 102b 102f 1033 1037 103b 103f 1043
1047 104b 104f 1053 1057 105b 105f 1063
1067 106b 106f 1073 1077 107b 107f 1083
1087 108b 108f 1093 1097 109b 109f 10a3
10a7 10ab 10af 10b3 10b7 10bb 10bf 10c3
10c7 10cb 10cf 10d3 10d7 10db 10df 10e3
10e7 10eb 10ef 10f3 10f7 10fb 10ff 1103
1107 110b 110f 1113 1117 111b 111f 1123
1127 112b 112f 1133 1137 113b 1147 114c
114e 115a 115e 117c 1164 1168 116c 116f
1177 1163 1183 1187 1160 118b 118f 1193
1196 119b 119c 1 119e 11a3 11a7 11ab
11ae 11b3 11b7 11bb 11be 11c3 11c4 11c6
11cb 11ce 11d2 11d3 11d8 11dd 11e0 11e5
11e6 11eb 11ee 11f2 11f3 11f8 11fb 1200
1201 1206 1209 120e 120f 1214 1217 121c
121d 1222 1225 1229 122a 122f 1232 1237
1238 123d 1240 1245 1246 124b 124e 1253
1254 1259 125c 1260 1261 1266 1269 126e
126f 1274 1277 127c 127d 1282 1285 128a
128b 1290 1293 1297 1298 129d 12a0 12a5
12a6 12ab 12ae 12b3 12b4 12b9 12bc 12c1
12c2 12c7 12ca 12ce 12cf 12d4 12d7 12dc
12dd 12e2 12e5 12ea 12eb 12f0 12f3 12f7
12fb 12ff 1300 1302 1307 1308 130a 130b
1310 1313 1318 1319 131e 1321 1325 1329
132d 132e 1330 1335 1336 1338 1339 133e
1341 1346 1347 134c 134f 1353 1357 135b
135c 135e 1363 1364 1366 1367 136c 136f
1374 1375 137a 137d 1381 1385 1389 138a
138c 1391 1392 1394 1395 139a 139d 13a2
13a3 13a8 13ab 13af 13b3 13b7 13b8 13ba
13bf 13c0 13c2 13c3 13c8 13cb 13d0 13d1
13d6 13d9 13dd 13e1 13e5 13e6 13e8 13ed
13ee 13f0 13f1 13f6 13f9 13fe 13ff 1404
1407 140b 140f 1413 1414 1416 141b 141c
141e 141f 1424 1427 142c 142d 1432 1435
1439 143d 1441 1442 1444 1449 144a 144c
144d 1452 1455 145a 145b 1460 1463 1467
146b 146f 1470 1472 1477 1478 147a 147b
1480 1483 1488 1489 148e 1491 1496 1497
149c 149f 14a3 14a4 14a9 14ac 14b1 14b2
14b7 14ba 14bf 14c0 14c5 14c6 14cb 14cd
14d1 14d4 14d8 14dc 14df 14e3 14e7 14ea
14ed 14f2 14f5 14f8 14fb 14fc 1501 1502
1 1504 1509 150d 1511 1514 1519 151e
1521 1525 1526 152b 152c 1531 1533 1537
153a 153e 1542 1546 154a 154e 1552 1556
155a 155e 1562 1566 156a 156e 1572 1576
157a 157e 1582 1586 1589 158a 158c 1590
1594 1597 1598 159a 159e 15a2 15a6 15a9
15aa 15ac 15b0 15b3 15b7 15ba 15bb 15c0
15c3 15c7 15cb 15ce 15cf 15d1 15d5 15d8
15dc 15df 15e0 15e5 1 15e8 15ed 15f1
15f4 15f8 15fa 15fe 1601 1605 160a 160e
1612 1617 161b 161f 1622 1626 162a 162f
1633 1637 163b 1640 1644 1645 1649 164d
1652 1657 165b 165f 1664 1668 166c 166f
1672 1676 1678 167c 1680 1683 1686 168a
168c 1690 1694 1697 169b 169f 16a3 16a6
16aa 16ae 16b2 16b7 16b9 16bd 16c1 16c4
16c8 16cc 16ce 16d2 16d6 16da 16dd 16e1
16e5 16e7 16e8 16ed 1 16f1 16f5 16f9
16fc 1700 1704 1708 170c 170f 1713 1717
171a 171d 1722 1725 1728 172b 172c 1731
1732 1 1734 1739 173d 1741 1744 1749
174e 1751 1755 1756 175b 175e 1763 1764
1769 176c 1771 1772 1777 177a 177e 177f
1784 1787 178c 178d 1792 1795 1799 179d
17a0 17a3 17a4 17a6 17a7 17ac 17ad 17b2
17b4 17b8 17bb 17bd 17c1 17c3 17cf 17d1
17d3 17d4 17d9 17dd 17df 17eb 17ed 17f1
17f5 17f8 17f9 17fb 17fe 1801 1802 1807
180b 180f 1812 1816 181a 181d 1820 1825
1828 182b 182e 182f 1834 1835 1 1837
183c 1840 1844 1847 184c 1851 1854 1858
1859 185e 1861 1866 1867 186c 186f 1874
1875 187a 187d 1881 1885 1889 188d 1890
1891 1893 1898 1899 189b 189c 18a1 18a4
18a9 18aa 18af 18b2 18b7 18b8 18bd 18c0
18c4 18c5 18ca 18cd 18d2 18d3 18d8 18d9
18de 18e0 18e4 18e7 18eb 18ef 18f2 18f6
18fa 18fd 1900 1905 1908 190b 190e 190f
1914 1915 1 1917 191c 1920 1924 1927
192c 1931 1934 1938 1939 193e 193f 1944
1946 194a 194d 1951 1955 1958 195c 1960
1963 1967 196b 196c 1971 1973 1977 197a
197e 1982 1986 198a 198e 1992 1996 199a
199e 19a2 19a6 19aa 19ae 19b2 19b6 19c2
19c6 19ca 19cd 19d1 19d5 19d7 19db 19df
19e3 19e6 19ea 19ee 19f0 19f1 19f6 1
19fa 19fe 1a02 1a05 1a09 1a0d 1a11 1a15
1a18 1a1c 1a20 1a23 1a26 1a2b 1a2e 1a31
1a34 1a35 1a3a 1a3b 1 1a3d 1a42 1a46
1a4a 1a4d 1a52 1a57 1a5a 1a5e 1a5f 1a64
1a67 1a6c 1a6d 1a72 1a75 1a7a 1a7b 1a80
1a83 1a87 1a88 1a8d 1a90 1a95 1a96 1a9b
1a9e 1aa2 1aa6 1aa9 1aac 1aad 1aaf 1ab0
1ab5 1ab6 1abb 1abd 1ac1 1ac4 1ac6 1aca
1acc 1ad8 1ada 1adc 1add 1ae2 1ae6 1ae8
1af4 1af6 1afa 1afe 1b01 1b05 1b08 1b0c
1b0f 1b10 1b15 1b18 1b1c 1b20 1b23 1b27
1b2b 1b2e 1b31 1b36 1b39 1b3c 1b3f 1b40
1b45 1b46 1 1b48 1b4d 1b51 1b55 1b58
1b5d 1b62 1b65 1b69 1b6a 1b6f 1b72 1b77
1b78 1b7d 1b80 1b85 1b86 1b8b 1b8e 1b92
1b96 1b9a 1b9e 1ba1 1ba2 1ba4 1ba9 1baa
1bac 1bad 1bb2 1bb5 1bba 1bbb 1bc0 1bc3
1bc8 1bc9 1bce 1bd1 1bd5 1bd6 1bdb 1bde
1be3 1be4 1be9 1bea 1bef 1bf1 1bf5 1bf8
1bfc 1c00 1c03 1c07 1c0b 1c0e 1c11 1c16
1c19 1c1c 1c1f 1c20 1c25 1c26 1 1c28
1c2d 1c31 1c35 1c38 1c3d 1c42 1c45 1c49
1c4a 1c4f 1c50 1c55 1c57 1c5b 1c5e 1c62
1c66 1c69 1c6d 1c71 1c74 1c78 1c7c 1c7d
1c82 1c84 1c88 1c8b 1c8f 1c92 1c96 1c9a
1c9e 1ca2 1ca6 1caa 1cb6 1cba 1cbe 1cc1
1cc5 1cc9 1ccb 1ccf 1cd3 1cd7 1cda 1cde
1ce2 1ce4 1ce5 1cea 1 1cee 1cf2 1cf6
1cf9 1cfd 1d01 1d05 1d09 1d0c 1d10 1d14
1d17 1d1a 1d1f 1d22 1d25 1d28 1d29 1d2e
1d2f 1 1d31 1d36 1d3a 1d3e 1d41 1d46
1d4b 1d4e 1d52 1d53 1d58 1d5b 1d60 1d61
1d66 1d69 1d6e 1d6f 1d74 1d77 1d7b 1d7c
1d81 1d84 1d89 1d8a 1d8f 1d92 1d96 1d9a
1d9d 1da0 1da1 1da3 1da4 1da9 1daa 1daf
1db1 1db5 1db8 1dba 1dbe 1dc0 1dcc 1dce
1dd0 1dd1 1dd6 1dda 1ddc 1de8 1dea 1dee
1df2 1df5 1df6 1df8 1dfb 1dfe 1dff 1e04
1e08 1e0c 1e0f 1e13 1e17 1e1a 1e1d 1e22
1e25 1e28 1e2b 1e2c 1e31 1e32 1 1e34
1e39 1e3d 1e41 1e44 1e49 1e4e 1e51 1e55
1e56 1e5b 1e5e 1e63 1e64 1e69 1e6c 1e71
1e72 1e77 1e7a 1e7e 1e82 1e86 1e8a 1e8d
1e8e 1e90 1e95 1e96 1e98 1e99 1e9e 1ea1
1ea6 1ea7 1eac 1eaf 1eb4 1eb5 1eba 1ebd
1ec1 1ec2 1ec7 1eca 1ecf 1ed0 1ed5 1ed6
1edb 1edd 1ee1 1ee4 1ee8 1eec 1eef 1ef3
1ef7 1efa 1efd 1f02 1f05 1f08 1f0b 1f0c
1f11 1f12 1 1f14 1f19 1f1d 1f21 1f24
1f29 1f2e 1f31 1f35 1f36 1f3b 1f3c 1f41
1f43 1f47 1f4a 1f4e 1f52 1f55 1f59 1f5d
1f60 1f64 1f68 1f69 1f6e 1f70 1f74 1f77
1f7b 1f7f 1f83 1f87 1f8b 1f8f 1f93 1f97
1f9b 1f9f 1fa3 1fa7 1fab 1faf 1fb3 1fb7
1fbb 1fbf 1fc3 1fc7 1fcb 1fcf 1fd3 1fd7
1fdb 1fdf 1fe3 1fe7 1feb 1fef 1ff3 1ff7
1ffb 1fff 2003 2007 200b 2017 201b 201f
2022 2026 202a 202c 2030 2034 2038 203b
203f 2043 2045 2046 204b 1 204f 2053
2057 205a 205e 2062 2066 206a 206d 2071
2075 2078 207b 2080 2083 2086 2089 208a
208f 2090 1 2092 2097 209b 209f 20a2
20a7 20ac 20af 20b3 20b4 20b9 20bc 20c1
20c2 20c7 20ca 20cf 20d0 20d5 20d8 20dc
20dd 20e2 20e5 20ea 20eb 20f0 20f3 20f7
20fb 20fe 2101 2102 2104 2105 210a 210b
2110 2112 2116 2119 211b 211f 2121 212d
212f 2131 2132 2137 213b 213d 2149 214b
214f 2153 2156 215a 215d 2161 2164 2165
216a 216d 2171 2175 2178 217c 2180 2183
2186 218b 218e 2191 2194 2195 219a 219b
1 219d 21a2 21a6 21aa 21ad 21b2 21b7
21ba 21be 21bf 21c4 21c7 21cc 21cd 21d2
21d5 21da 21db 21e0 21e3 21e7 21eb 21ef
21f3 21f6 21f7 21f9 21fe 21ff 2201 2202
2207 220a 220f 2210 2215 2218 221d 221e
2223 2226 222a 222b 2230 2233 2238 2239
223e 223f 2244 2246 224a 224d 2251 2255
2258 225c 2260 2263 2266 226b 226e 2271
2274 2275 227a 227b 1 227d 2282 2286
228a 228d 2292 2297 229a 229e 229f 22a4
22a5 22aa 22ac 22b0 22b3 22b7 22bb 22be
22c2 22c6 22c9 22cd 22d1 22d2 22d7 22d9
22dd 22e0 22e4 22e8 22ec 22f0 22f4 22f8
22fc 2308 230c 2310 2313 2317 231b 231d
2321 2325 2329 232c 2330 2334 2336 2337
233c 1 2340 2344 2348 234b 234f 2353
2357 235b 235e 2362 2366 2369 236c 2371
2374 2377 237a 237b 2380 2381 1 2383
2388 238c 2390 2393 2398 239d 23a0 23a4
23a5 23aa 23ad 23b2 23b3 23b8 23bb 23c0
23c1 23c6 23c9 23cd 23ce 23d3 23d6 23db
23dc 23e1 23e4 23e8 23ec 23ef 23f2 23f3
23f5 23f6 23fb 23fc 2401 2403 2407 240a
240c 2410 2412 241e 2420 2422 2423 2428
242c 242e 243a 243c 2440 2444 2447 244b
244e 2452 2455 2456 245b 245e 2462 2466
2469 246d 2471 2474 2477 247c 247f 2482
2485 2486 248b 248c 1 248e 2493 2497
249b 249e 24a3 24a8 24ab 24af 24b0 24b5
24b8 24bd 24be 24c3 24c6 24cb 24cc 24d1
24d4 24d8 24dc 24e0 24e4 24e7 24e8 24ea
24ef 24f0 24f2 24f3 24f8 24fb 2500 2501
2506 2509 250e 250f 2514 2517 251b 251c
2521 2524 2529 252a 252f 2530 2535 2537
253b 253e 2542 2546 2549 254d 2551 2554
2557 255c 255f 2562 2565 2566 256b 256c
1 256e 2573 2577 257b 257e 2583 2588
258b 258f 2590 2595 2596 259b 259d 25a1
25a4 25a8 25ac 25af 25b3 25b7 25ba 25be
25c2 25c3 25c8 25ca 25ce 25d1 25d5 25d9
25dd 25e1 25e5 25f1 25f5 25f9 25fc 2600
2604 2606 260a 260e 2612 2615 2619 261d
261f 2620 2625 1 2629 262d 2631 2634
2638 263c 2640 2644 2647 264b 264f 2652
2655 265a 265d 2660 2663 2664 2669 266a
1 266c 2671 2675 2679 267c 2681 2686
2689 268d 268e 2693 2696 269b 269c 26a1
26a4 26a9 26aa 26af 26b2 26b6 26b7 26bc
26bf 26c4 26c5 26ca 26cd 26d1 26d5 26d8
26db 26dc 26de 26df 26e4 26e5 26ea 26ec
26f0 26f3 26f5 26f9 26fb 2707 2709 270b
270c 2711 2715 2717 2723 2725 2729 272d
2730 2734 2739 273a 273c 273f 2742 2743
2748 274c 2751 2755 2757 275b 275e 2762
2766 2769 276d 2770 2774 2777 2778 277d
2780 2784 2788 278b 278f 2793 2796 2799
279e 27a1 27a4 27a7 27a8 27ad 27ae 1
27b0 27b5 27b9 27bd 27c0 27c5 27ca 27cd
27d1 27d2 27d7 27da 27df 27e0 27e5 27e8
27ed 27ee 27f3 27f6 27fa 27fe 2802 2806
2809 280a 280c 2811 2812 2814 2815 281a
281d 2822 2823 2828 282b 2830 2831 2836
2839 283d 283e 2843 2846 284b 284c 2851
2852 2857 2859 285d 2860 2864 2868 286b
286f 2873 2876 2879 287e 2881 2884 2887
2888 288d 288e 1 2890 2895 2899 289d
28a0 28a5 28aa 28ad 28b1 28b2 28b7 28b8
28bd 28bf 28c3 28c6 28ca 28ce 28d1 28d5
28d9 28dc 28e0 28e4 28e5 28ea 28ec 28f0
28f3 28f7 28fb 28ff 2903 2907 290b 290f
2912 2913 2915 2918 2919 291b 291f 2923
2927 292b 292f 2932 2933 2935 2938 2939
293b 293f 2943 2947 294b 294f 2952 2953
2955 2958 2959 295b 295f 2963 2967 296b
296f 2973 2977 297b 297f 2983 2987 298b
298f 299b 299f 29a3 29a6 29aa 29ae 29b0
29b4 29b8 29bc 29bf 29c3 29c7 29c9 29ca
29cf 1 29d3 29d7 29db 29de 29e2 29e6
29ea 29ee 29f1 29f5 29f9 29fc 29ff 2a04
2a07 2a0a 2a0d 2a0e 2a13 2a14 1 2a16
2a1b 2a1f 2a23 2a26 2a2b 2a30 2a33 2a37
2a38 2a3d 2a40 2a45 2a46 2a4b 2a4e 2a53
2a54 2a59 2a5c 2a60 2a61 2a66 2a69 2a6e
2a6f 2a74 2a77 2a7b 2a7f 2a82 2a85 2a86
2a88 2a89 2a8e 2a8f 2a94 2a96 2a9a 2a9d
2a9f 2aa3 2aa5 2ab1 2ab3 2ab5 2ab6 2abb
2abf 2ac1 2acd 2acf 2ad3 2ad7 2adb 2adf
2ae3 2ae7 2aeb 2aef 2af3 2af7 2afb 2b07
2b0b 2b0f 2b12 2b16 2b1a 2b1c 2b20 2b24
2b28 2b2b 2b2f 2b33 2b35 2b36 2b3b 1
2b3f 2b43 2b47 2b4a 2b4e 2b52 2b56 2b5a
2b5d 2b61 2b65 2b68 2b6b 2b70 2b73 2b76
2b79 2b7a 2b7f 2b80 1 2b82 2b87 2b8b
2b8f 2b92 2b97 2b9c 2b9f 2ba3 2ba4 2ba9
2bac 2bb1 2bb2 2bb7 2bba 2bbf 2bc0 2bc5
2bc8 2bcc 2bcd 2bd2 2bd5 2bda 2bdb 2be0
2be3 2be7 2beb 2bee 2bf1 2bf2 2bf4 2bf5
2bfa 2bfb 2c00 2c02 2c06 2c09 2c0b 2c0f
2c11 2c1d 2c1f 2c21 2c22 2c27 2c2b 2c2d
2c39 2c3b 2c3f 2c42 2c46 2c4a 2c4e 2c52
2c56 2c59 2c5a 2c5c 2c5d 2c5f 2c62 2c66
2c6a 2c6d 2c70 2c71 2c76 2c7a 2c7e 2c81
2c82 2c84 2c87 2c8a 2c8b 2c90 2c94 2c98
2c9c 2ca0 2ca4 2ca8 2cac 2cb0 2cb4 2cb8
2cc4 2cc8 2ccc 2ccf 2cd3 2cd7 2cd9 2cdd
2ce1 2ce5 2ce8 2cec 2cf0 2cf2 2cf3 2cf8
1 2cfc 2d00 2d04 2d07 2d0b 2d0f 2d13
2d17 2d1a 2d1e 2d22 2d25 2d28 2d2d 2d30
2d33 2d36 2d37 2d3c 2d3d 1 2d3f 2d44
2d48 2d4c 2d4f 2d54 2d59 2d5c 2d60 2d61
2d66 2d69 2d6e 2d6f 2d74 2d77 2d7c 2d7d
2d82 2d85 2d89 2d8a 2d8f 2d92 2d97 2d98
2d9d 2da0 2da4 2da8 2dab 2dae 2daf 2db1
2db2 2db7 2db8 2dbd 2dbf 2dc3 2dc6 2dc8
2dcc 2dce 2dda 2ddc 2dde 2ddf 2de4 2de8
2dea 2df6 2df8 2dfc 2e00 2e03 2e04 2e06
2e09 2e0c 2e0d 2e12 2e15 2e16 2e1b 2e1f
2e22 2e26 2e2a 2e2e 2e32 2e36 2e3a 2e3e
2e42 2e46 2e4a 2e4e 2e5a 2e5e 2e62 2e65
2e69 2e6d 2e6f 2e73 2e77 2e7b 2e7e 2e82
2e86 2e88 2e89 2e8e 1 2e92 2e96 2e9a
2e9d 2ea1 2ea5 2ea9 2ead 2eb0 2eb4 2eb8
2ebb 2ebe 2ec3 2ec6 2ec9 2ecc 2ecd 2ed2
2ed3 1 2ed5 2eda 2ede 2ee2 2ee5 2eea
2eef 2ef2 2ef6 2ef7 2efc 2eff 2f04 2f05
2f0a 2f0d 2f12 2f13 2f18 2f1b 2f1f 2f20
2f25 2f28 2f2d 2f2e 2f33 2f36 2f3a 2f3e
2f41 2f44 2f45 2f47 2f48 2f4d 2f4e 2f53
2f55 2f59 2f5c 2f5e 2f62 2f64 2f70 2f72
2f74 2f75 2f7a 2f7e 2f80 2f8c 2f8e 2f92
2f96 2f99 2f9a 2f9c 2f9f 2fa2 2fa3 2fa8
2fac 2fb0 2fb3 2fb7 2fbb 2fbe 2fc1 2fc6
2fc9 2fcc 2fcf 2fd0 2fd5 2fd6 1 2fd8
2fdd 2fe1 2fe5 2fe8 2fed 2ff2 2ff5 2ff9
2ffa 2fff 3002 3007 3008 300d 3010 3015
3016 301b 301e 3022 3026 302a 302e 3031
3032 3034 3039 303a 303c 303d 3042 3045
304a 304b 3050 3053 3058 3059 305e 3061
3065 3066 306b 306e 3073 3074 3079 307a
307f 3081 3085 3088 308c 3090 3093 3097
309b 309e 30a1 30a6 30a9 30ac 30af 30b0
30b5 30b6 1 30b8 30bd 30c1 30c5 30c8
30cd 30d2 30d5 30d9 30da 30df 30e0 30e5
30e7 30eb 30ee 30f2 30f6 30f9 30fd 3101
3104 3108 310c 310d 3112 3114 3118 311b
311d 3121 3124 3126 312a 312d 3131 3133
3137 313b 313f 3142 3143 3145 3146 3148
314b 314e 314f 3154 3158 315c 315f 3160
3162 3165 3168 3169 316e 3172 3176 3179
317a 317c 317f 3182 3183 1 3188 318d
1 3190 3195 3199 319c 31a0 31a4 31a8
31ac 31b0 31b4 31b8 31bc 31c0 31c4 31c8
31d4 31d8 31dc 31df 31e3 31e7 31e9 31ed
31f1 31f5 31f8 31fc 3200 3202 3203 3208
1 320c 3210 3214 3217 321b 321f 3223
3227 322a 322e 3232 3235 3238 323d 3240
3243 3246 3247 324c 324d 1 324f 3254
3258 325c 325f 3264 3269 326c 3270 3271
3276 3279 327e 327f 3284 3287 328c 328d
3292 3295 3299 329a 329f 32a2 32a7 32a8
32ad 32b0 32b4 32b8 32bb 32be 32bf 32c1
32c2 32c7 32c8 32cd 32cf 32d3 32d6 32d8
32dc 32de 32ea 32ec 32ee 32ef 32f4 32f8
32fa 3306 3308 330c 3310 3313 3314 3316
3319 331c 331d 3322 3326 332a 332d 3331
3335 3338 333b 3340 3343 3346 3349 334a
334f 3350 1 3352 3357 335b 335f 3362
3367 336c 336f 3373 3374 3379 337c 3381
3382 3387 338a 338f 3390 3395 3398 339c
33a0 33a4 33a8 33ab 33ac 33ae 33b3 33b4
33b6 33b7 33bc 33bf 33c4 33c5 33ca 33cd
33d2 33d3 33d8 33db 33df 33e0 33e5 33e8
33ed 33ee 33f3 33f4 33f9 33fb 33ff 3402
3406 340a 340d 3411 3415 3418 341b 3420
3423 3426 3429 342a 342f 3430 1 3432
3437 343b 343f 3442 3447 344c 344f 3453
3454 3459 345a 345f 3461 3465 3468 346c
3470 3473 3477 347b 347e 3482 3486 3487
348c 348e 3492 3495 3497 349b 349f 34a2
34a6 34ab 34af 34b3 34b8 34bc 34c0 34c5
34c9 34cd 34ce 34d2 34d6 34d7 34db 34df
34e0 34e4 34e8 34ec 34f1 34f5 34f6 34fa
34fe 3503 3508 350c 3510 3515 3519 351d
3520 3523 3527 3529 352d 3531 3534 3537
353b 353d 3541 3545 3548 354c 3550 3553
3557 355a 355e 3561 3562 3567 356a 356e
3572 3575 3579 357d 357e 3580 3583 3586
3587 358c 358f 3590 3595 3599 359d 35a0
35a1 35a3 35a6 35a9 35aa 35af 35b2 35b3
1 35b8 35bd 35c1 35c5 35ca 35cc 35d0
35d4 35d7 35db 35df 35e1 35e5 35e9 35ed
35f0 35f4 35f8 35fa 35fb 3600 1 3604
3608 360c 360f 3613 3617 361b 361f 3622
3626 362a 362d 3630 3635 3638 363b 363e
363f 3644 3645 1 3647 364c 3650 3654
3657 365c 3661 3664 3668 3669 366e 3671
3676 3677 367c 367f 3684 3685 368a 368d
3691 3692 3697 369a 369f 36a0 36a5 36a8
36ac 36b0 36b3 36b6 36b7 36b9 36ba 36bf
36c0 36c5 36c7 36cb 36ce 36d0 36d4 36d6
36e2 36e4 36e6 36e7 36ec 36f0 36f2 36fe
3700 3704 3708 370b 370f 3713 3716 3719
371e 3721 3724 3727 3728 372d 372e 1
3730 3735 3739 373d 3740 3745 374a 374d
3751 3752 3757 375a 375f 3760 3765 3768
376d 376e 3773 3776 377a 377e 3782 3786
3789 378a 378c 3791 3792 3794 3795 379a
379d 37a2 37a3 37a8 37ab 37b0 37b1 37b6
37b9 37bd 37be 37c3 37c6 37cb 37cc 37d1
37d2 37d7 37d9 37dd 37e0 37e4 37e8 37eb
37ef 37f3 37f6 37f9 37fe 3801 3804 3807
3808 380d 380e 1 3810 3815 3819 381d
3820 3825 382a 382d 3831 3832 3837 3838
383d 383f 3843 3846 384a 384e 3851 3855
3859 385c 3860 3864 3865 386a 386c 3870
3873 3877 387a 387e 3882 3884 3888 388c
388f 3890 3892 3895 3898 3899 389e 38a2
38a5 38a9 38ab 38af 38b3 38b6 38ba 38bc
38c0 38c4 38c7 38cb 38cf 38d4 38d6 38da
38de 38e1 38e5 38e9 38eb 38ef 38f3 38f7
38fa 38fe 3902 3904 3905 390a 1 390e
3912 3916 3919 391d 3921 3925 3929 392c
3930 3934 3937 393a 393f 3942 3945 3948
3949 394e 394f 1 3951 3956 395a 395e
3961 3966 396b 396e 3972 3973 3978 397b
3980 3981 3986 3989 398e 398f 3994 3997
399b 399c 39a1 39a4 39a9 39aa 39af 39b2
39b6 39ba 39bd 39c0 39c1 39c3 39c4 39c9
39ca 39cf 39d1 39d5 39d8 39da 39de 39e0
39ec 39ee 39f0 39f1 39f6 39fa 39fc 3a08
3a0a 3a0e 3a12 3a16 3a1a 3a1e 3a2a 3a2e
3a32 3a35 3a39 3a3d 3a3f 3a43 3a47 3a4b
3a4e 3a52 3a56 3a58 3a59 3a5e 1 3a62
3a66 3a6a 3a6d 3a71 3a75 3a79 3a7d 3a80
3a84 3a88 3a8b 3a8e 3a93 3a96 3a99 3a9c
3a9d 3aa2 3aa3 1 3aa5 3aaa 3aae 3ab2
3ab5 3aba 3abf 3ac2 3ac6 3ac7 3acc 3acf
3ad4 3ad5 3ada 3add 3ae2 3ae3 3ae8 3aeb
3aef 3af0 3af5 3af8 3afd 3afe 3b03 3b06
3b0a 3b0e 3b11 3b14 3b15 3b17 3b18 3b1d
3b1e 3b23 3b25 3b29 3b2c 3b2e 3b32 3b34
3b40 3b42 3b44 3b45 3b4a 3b4e 3b50 3b5c
3b5e 3b62 3b66 3b6a 3b6e 3b72 3b76 3b7a
3b7e 3b82 3b86 3b8a 3b96 3b9a 3b9e 3ba1
3ba5 3ba9 3bab 3baf 3bb3 3bb7 3bba 3bbe
3bc2 3bc4 3bc5 3bca 1 3bce 3bd2 3bd6
3bd9 3bdd 3be1 3be5 3be9 3bec 3bf0 3bf4
3bf7 3bfa 3bff 3c02 3c05 3c08 3c09 3c0e
3c0f 1 3c11 3c16 3c1a 3c1e 3c21 3c26
3c2b 3c2e 3c32 3c33 3c38 3c3b 3c40 3c41
3c46 3c49 3c4e 3c4f 3c54 3c57 3c5b 3c5c
3c61 3c64 3c69 3c6a 3c6f 3c72 3c76 3c7a
3c7d 3c80 3c81 3c83 3c84 3c89 3c8a 3c8f
3c91 3c95 3c98 3c9a 3c9e 3ca0 3cac 3cae
3cb0 3cb1 3cb6 3cba 3cbc 3cc8 3cca 3cce
3cd2 3cd5 3cd9 3cdc 3ce0 3ce3 3ce4 3ce9
3cec 3cf0 3cf4 3cf7 3cf8 3cfa 3cfd 3d00
3d01 3d06 3d09 3d0a 1 3d0f 3d14 3d18
3d1d 3d21 3d25 3d29 3d2a 3d2f 3d33 3d37
3d3b 3d3f 3d43 3d47 3d4b 3d4f 3d53 3d57
3d5b 3d67 3d6b 3d6f 3d72 3d76 3d7a 3d7c
3d80 3d84 3d88 3d8b 3d8f 3d93 3d95 3d96
3d9b 1 3d9f 3da3 3da7 3daa 3dae 3db2
3db6 3dba 3dbd 3dc1 3dc5 3dc8 3dcb 3dd0
3dd3 3dd6 3dd9 3dda 3ddf 3de0 1 3de2
3de7 3deb 3def 3df2 3df7 3dfc 3dff 3e03
3e04 3e09 3e0c 3e11 3e12 3e17 3e1a 3e1f
3e20 3e25 3e28 3e2c 3e2d 3e32 3e35 3e3a
3e3b 3e40 3e43 3e47 3e4b 3e4e 3e51 3e52
3e54 3e55 3e5a 3e5b 3e60 3e62 3e66 3e69
3e6b 3e6f 3e71 3e7d 3e7f 3e81 3e82 3e87
3e8b 3e8d 3e99 3e9b 3e9f 3ea3 3ea6 3eaa
3ead 3eb1 3eb4 3eb5 3eba 3ebd 3ec1 3ec5
3ec9 3ecc 3ed0 3ed2 3ed6 3eda 3edd 3ee1
3ee5 3ee8 3ee9 3eeb 3eef 3ef3 3ef6 3efa
3efb 3efd 3f01 3f05 3f09 3f0d 3f10 3f14
3f16 3f1a 3f1e 3f21 3f25 3f2a 3f2e 3f32
3f35 3f39 3f3d 3f41 3f45 3f49 3f4d 3f51
3f55 3f59 3f5d 3f5e 3f60 3f64 3f68 3f6c
3f70 3f74 3f77 3f78 3f7a 3f7b 3f7d 3f81
3f85 3f89 3f8d 3f91 3f95 3f99 3f9d 3fa1
3fa5 3fa9 3fad 3fb1 3fb5 3fb9 3fbd 3fc1
3fc5 3fc9 3fcd 3fd1 3fd5 3fd9 3fdd 3fe1
3fe5 3ff1 3ff5 3ffa 3ffe 4001 4002 4007
400b 400f 4012 4015 4019 401b 401f 4023
4026 4029 402d 402f 4033 4037 403a 403c
4040 4044 4048 404b 404f 4053 4055 4056
405b 1 405f 4063 4067 406a 406e 4072
4076 407a 407d 4081 4085 4088 408b 4090
4093 4096 4099 409a 409f 40a0 1 40a2
40a7 40ab 40af 40b2 40b7 40bc 40bf 40c3
40c4 40c9 40cc 40d1 40d2 40d7 40da 40df
40e0 40e5 40e8 40ec 40ed 40f2 40f5 40fa
40fb 4100 4103 4107 410b 410e 4111 4112
4114 4115 411a 411b 4120 4122 4126 4129
412b 412f 4131 413d 413f 4141 4142 4147
414b 414d 4159 415b 415f 4163 4166 416a
416e 416f 4171 4174 4177 4178 417d 4180
4181 4186 418a 418d 4191 4193 4197 419b
419f 41a3 41a7 41ab 41af 41b3 41b7 41bb
41bf 41c3 41cf 41d3 41d7 41da 41de 41e2
41e4 41e8 41ec 41f0 41f3 41f7 41fb 41fd
41fe 4203 1 4207 420b 420f 4212 4216
421a 421e 4222 4225 4229 422d 4230 4233
4238 423b 423e 4241 4242 4247 4248 1
424a 424f 4253 4257 425a 425f 4264 4267
426b 426c 4271 4274 4279 427a 427f 4282
4287 4288 428d 4290 4294 4295 429a 429d
42a2 42a3 42a8 42ab 42af 42b3 42b6 42b9
42ba 42bc 42bd 42c2 42c3 42c8 42ca 42ce
42d1 42d3 42d7 42d9 42e5 42e7 42e9 42ea
42ef 42f3 42f5 4301 4303 4305 4309 430d
4310 4314 4318 431b 431c 431e 4321 4324
4325 432a 432d 432e 4333 4337 433b 433f
4343 4347 434b 434f 4353 4357 435b 4367
436b 4370 4374 4377 4378 437d 4381 4385
4388 438b 438f 4391 4395 4399 439c 439f
43a3 43a5 43a9 43ad 43b0 43b2 43b6 43ba
43be 43c1 43c5 43c9 43cb 43cc 43d1 1
43d5 43d9 43dd 43e0 43e4 43e8 43ec 43f0
43f3 43f7 43fb 43fe 4401 4406 4409 440c
440f 4410 4415 4416 1 4418 441d 4421
4425 4428 442d 4432 4435 4439 443a 443f
4442 4447 4448 444d 4450 4455 4456 445b
445e 4462 4463 4468 446b 4470 4471 4476
4479 447d 4481 4484 4487 4488 448a 448b
4490 4491 4496 4498 449c 449f 44a1 44a5
44a7 44b3 44b5 44b7 44b8 44bd 44c1 44c3
44cf 44d1 44d3 44d7 44db 44df 44e3 44e7
44eb 44ef 44f3 44f7 44fb 44ff 4503 4507
450b 450f 4513 4517 4523 4527 452c 4530
4533 4534 4539 453d 4541 4544 4547 454b
454d 4551 4555 4558 455b 455f 4561 4565
4569 456c 456e 4572 4576 457a 457d 4581
4585 4587 4588 458d 1 4591 4595 4599
459c 45a0 45a4 45a8 45ac 45af 45b3 45b7
45ba 45bd 45c2 45c5 45c8 45cb 45cc 45d1
45d2 1 45d4 45d9 45dd 45e1 45e4 45e9
45ee 45f1 45f5 45f6 45fb 45fe 4603 4604
4609 460c 4611 4612 4617 461a 461e 461f
4624 4627 462c 462d 4632 4635 4639 463d
4640 4643 4644 4646 4647 464c 464d 4652
4654 4658 465b 465d 4661 4663 466f 4671
4673 4674 4679 467d 467f 468b 468d 468f
4693 4697 469a 469e 46a0 46a4 46a8 46ab
46af 46b2 46b6 46b9 46ba 46bf 46c2 46c6
46ca 46ce 46d2 46d6 46da 46de 46e2 46e6
46ea 46ee 46f2 46f6 46fa 46fe 4702 4706
4712 4716 471b 471f 4722 4723 4728 472c
4730 4733 4736 473a 473c 4740 4744 4747
474a 474e 4750 4754 4758 475b 475d 4761
4765 4769 476c 4770 4774 4776 4777 477c
1 4780 4784 4788 478b 478f 4793 4797
479b 479e 47a2 47a6 47a9 47ac 47b1 47b4
47b7 47ba 47bb 47c0 47c1 1 47c3 47c8
47cc 47d0 47d3 47d8 47dd 47e0 47e4 47e5
47ea 47ed 47f2 47f3 47f8 47fb 4800 4801
4806 4809 480d 480e 4813 4816 481b 481c
4821 4824 4828 482c 482f 4832 4833 4835
4836 483b 483c 4841 4843 4847 484a 484c
4850 4852 485e 4860 4862 4863 4868 486c
486e 487a 487c 4880 4885 4889 488d 4891
4895 4899 489d 48a1 48ad 48b1 48b5 48b8
48bc 48c0 48c2 48c6 48ca 48ce 48d1 48d5
48d9 48db 48dc 48e1 1 48e5 48e9 48ed
48f0 48f4 48f8 48fc 4900 4903 4907 490b
490e 4911 4916 4919 491c 491f 4920 4925
4926 1 4928 492d 4931 4935 4938 493d
4942 4945 4949 494a 494f 4952 4957 4958
495d 4960 4965 4966 496b 496e 4972 4973
4978 497b 4980 4981 4986 4989 498d 4991
4994 4997 4998 499a 499b 49a0 49a1 49a6
49a8 49ac 49af 49b1 49b5 49b7 49c3 49c5
49c7 49c8 49cd 49d1 49d3 49df 49e1 49e5
49e9 49ec 49f0 49f3 49f7 49fa 49fb 4a00
4a03 4a07 4a0b 4a0f 4a13 4a17 4a1b 4a27
4a2b 4a2f 4a32 4a36 4a3a 4a3c 4a40 4a44
4a48 4a4b 4a4f 4a53 4a55 4a56 4a5b 1
4a5f 4a63 4a67 4a6a 4a6e 4a72 4a76 4a7a
4a7d 4a81 4a85 4a88 4a8b 4a90 4a93 4a96
4a99 4a9a 4a9f 4aa0 1 4aa2 4aa7 4aab
4aaf 4ab2 4ab7 4abc 4abf 4ac3 4ac4 4ac9
4acc 4ad1 4ad2 4ad7 4ada 4adf 4ae0 4ae5
4ae8 4aec 4aed 4af2 4af5 4afa 4afb 4b00
4b03 4b07 4b0b 4b0e 4b11 4b12 4b14 4b15
4b1a 4b1b 4b20 4b22 4b26 4b29 4b2b 4b2f
4b31 4b3d 4b3f 4b41 4b42 4b47 4b4b 4b4d
4b59 4b5b 4b5f 4b63 4b66 4b6a 4b6d 4b71
4b74 4b75 4b7a 4b7d 4b81 4b86 4b8a 4b8c
4b90 4b93 4b95 4b99 4b9c 4ba0 4ba4 4ba7
4ba8 4baa 4bad 4bb0 4bb1 4bb6 4bb9 4bba
4bbf 4bc3 4bc7 4bca 4bcb 4bcd 4bd1 4bd4
4bd8 4bdb 4bdc 4be1 4be5 4be9 4bec 4bf0
4bf4 4bf7 4bf8 4bfa 4bfe 4c02 4c05 4c09
4c0a 4c0c 4c10 4c14 4c18 4c1c 4c20 4c24
4c28 4c2c 4c30 4c34 4c38 4c44 4c48 4c4d
4c51 4c54 4c55 4c5a 4c5e 4c62 4c65 4c68
4c6c 4c6e 4c72 4c76 4c79 4c7c 4c80 4c82
4c86 4c8a 4c8d 4c8f 4c93 4c97 4c9b 4c9e
4ca2 4ca6 4ca8 4ca9 4cae 1 4cb2 4cb6
4cba 4cbd 4cc1 4cc5 4cc9 4ccd 4cd0 4cd4
4cd8 4cdb 4cde 4ce3 4ce6 4ce9 4cec 4ced
4cf2 4cf3 1 4cf5 4cfa 4cfe 4d02 4d05
4d0a 4d0f 4d12 4d16 4d17 4d1c 4d1f 4d24
4d25 4d2a 4d2d 4d32 4d33 4d38 4d3b 4d3f
4d40 4d45 4d48 4d4d 4d4e 4d53 4d56 4d5a
4d5e 4d61 4d64 4d65 4d67 4d68 4d6d 4d6e
4d73 4d75 4d79 4d7c 4d7e 4d82 4d84 4d90
4d92 4d94 4d95 4d9a 4d9e 4da0 4dac 4dae
4db2 4db6 4dba 4dbb 4dbd 4dc1 4dc5 4dc7
4dcb 4dcf 4dd3 4dd6 4dd7 4dd9 4ddd 4de1
4de4 4de5 4de7 4dea 4dee 4df1 4df5 4df8
4df9 4dfe 4e02 4e06 4e0a 4e0e 4e12 4e16
4e1a 4e1e 4e22 4e26 4e2a 4e36 4e3a 4e3f
4e43 4e46 4e47 4e4c 4e50 4e54 4e57 4e5a
4e5e 4e60 4e64 4e68 4e6b 4e6e 4e72 4e74
4e78 4e7c 4e7f 4e81 4e85 4e89 4e8d 4e90
4e94 4e98 4e9a 4e9b 4ea0 1 4ea4 4ea8
4eac 4eaf 4eb3 4eb7 4ebb 4ebf 4ec2 4ec6
4eca 4ecd 4ed0 4ed5 4ed8 4edb 4ede 4edf
4ee4 4ee5 1 4ee7 4eec 4ef0 4ef4 4ef7
4efc 4f01 4f04 4f08 4f09 4f0e 4f11 4f16
4f17 4f1c 4f1f 4f24 4f25 4f2a 4f2d 4f31
4f32 4f37 4f3a 4f3f 4f40 4f45 4f48 4f4c
4f50 4f53 4f56 4f57 4f59 4f5a 4f5f 4f60
4f65 4f67 4f6b 4f6e 4f70 4f74 4f76 4f82
4f84 4f86 4f87 4f8c 4f90 4f92 4f9e 4fa0
4fa4 4fa8 4fac 4fad 4faf 4fb3 4fb7 4fb9
4fbd 4fc1 4fc5 4fc9 4fcc 4fcd 4fcf 4fd3
4fd7 4fda 4fdb 4fdd 4fe0 4fe4 4fe7 4feb
4fee 4fef 4ff4 4ff8 4ffc 5000 5004 5008
500c 5010 5014 5018 501c 5020 502c 5030
5035 5039 503c 503d 5042 5046 504a 504d
5050 5054 5056 505a 505e 5061 5064 5068
506a 506e 5072 5075 5077 507b 507f 5083
5086 508a 508e 5090 5091 5096 1 509a
509e 50a2 50a5 50a9 50ad 50b1 50b5 50b8
50bc 50c0 50c3 50c6 50cb 50ce 50d1 50d4
50d5 50da 50db 1 50dd 50e2 50e6 50ea
50ed 50f2 50f7 50fa 50fe 50ff 5104 5107
510c 510d 5112 5115 511a 511b 5120 5123
5127 5128 512d 5130 5135 5136 513b 513e
5142 5146 5149 514c 514d 514f 5150 5155
5156 515b 515d 5161 5164 5166 516a 516c
5178 517a 517c 517d 5182 5186 5188 5194
5196 519a 519e 51a2 51a3 51a5 51a9 51ab
51af 51b3 51b6 51b8 51bc 51bf 51c1 51c5
51c9 51cc 51d0 51d4 51d8 51dc 51e0 51e4
51e8 51ec 51f0 51f4 51f8 51fc 5200 5204
5208 520c 5210 5214 5218 521c 5220 5224
5230 5234 5238 523b 523f 5243 5245 5249
524d 5251 5254 5258 525c 525e 525f 5264
1 5268 526c 5270 5273 5277 527b 527f
5283 5286 528a 528e 5291 5294 5299 529c
529f 52a2 52a3 52a8 52a9 1 52ab 52b0
52b4 52b8 52bb 52c0 52c5 52c8 52cc 52cd
52d2 52d5 52da 52db 52e0 52e3 52e8 52e9
52ee 52f1 52f5 52f6 52fb 52fe 5303 5304
5309 530c 5310 5314 5317 531a 531b 531d
531e 5323 5324 5329 532b 532f 5332 5334
5338 533a 5346 5348 534a 534b 5350 5354
5356 5362 5364 5368 536c 536f 5373 5376
537a 537d 537e 5383 5386 538a 538d 5391
5393 5397 539a 539e 53a3 53a7 53ab 53b0
53b4 53b8 53bd 53c1 53c5 53c9 53ca 53cf
53d3 53d7 53db 53de 53df 53e1 53e4 53e7
53e8 53ed 53f0 53f4 53f8 53fb 53fc 53fe
5401 5404 5405 540a 1 540d 5412 5416
541a 541e 5422 5426 542a 542e 5432 5436
543a 543e 5442 5443 5445 5449 544d 5451
5454 5455 5457 545a 545d 545e 5463 5467
546b 546f 5472 5473 5475 5478 547c 5480
5483 5484 5486 5487 548c 5490 5494 5498
549c 549f 54a0 54a2 54a5 54a9 54ad 54b0
54b1 54b3 54b4 54b9 54bd 54bf 54c3 54c6
54ca 54ce 54d1 54d2 54d4 54d7 54da 54db
54e0 54e4 54e8 54ec 54ef 54f0 54f2 54f5
54f9 54fd 5500 5501 5503 5504 5509 550d
5511 5515 5519 551c 551d 551f 5522 5526
552a 552d 552e 5530 5531 5536 553a 553c
5540 5543 5545 5549 554c 5550 5553 5557
555b 555e 5562 5566 556a 556e 5572 5576
557a 5586 558a 558e 5591 5595 5599 559b
559f 55a3 55a7 55aa 55ae 55b2 55b4 55b5
55ba 1 55be 55c2 55c6 55c9 55cd 55d1
55d5 55d9 55dc 55e0 55e4 55e7 55ea 55ef
55f2 55f5 55f8 55f9 55fe 55ff 1 5601
5606 560a 560e 5611 5616 561b 561e 5622
5623 5628 562b 5630 5631 5636 5639 563e
563f 5644 5647 564b 564c 5651 5654 5659
565a 565f 5662 5666 566a 566d 5670 5671
5673 5674 5679 567a 567f 5681 5685 5688
568a 568e 5690 569c 569e 56a0 56a1 56a6
56aa 56ac 56b8 56ba 56be 56bf 56c3 56c7
56cb 56cf 56d3 56d7 56db 56df 56e3 56e7
56eb 56ef 56f3 56ff 5703 5707 570a 570e
5712 5714 5718 571c 5720 5723 5727 572b
572d 572e 5733 1 5737 573b 573f 5742
5746 574a 574e 5752 5755 5759 575d 5760
5763 5768 576b 576e 5771 5772 5777 5778
1 577a 577f 5783 5787 578a 578f 5794
5797 579b 579c 57a1 57a4 57a9 57aa 57af
57b2 57b7 57b8 57bd 57c0 57c4 57c5 57ca
57cd 57d2 57d3 57d8 57db 57df 57e3 57e6
57e9 57ea 57ec 57ed 57f2 57f3 57f8 57fa
57fe 5801 5803 5807 5809 5815 5817 5819
581a 581f 5823 5825 5831 5833 5837 583b
583f 5843 5847 584b 584f 585b 585f 5863
5866 586a 586e 5870 5874 5878 587c 587f
5883 5887 5889 588a 588f 1 5893 5897
589b 589e 58a2 58a6 58aa 58ae 58b1 58b5
58b9 58bc 58bf 58c4 58c7 58ca 58cd 58ce
58d3 58d4 1 58d6 58db 58df 58e3 58e6
58eb 58f0 58f3 58f7 58f8 58fd 5900 5905
5906 590b 590e 5913 5914 5919 591c 5920
5921 5926 5929 592e 592f 5934 5937 593b
593f 5942 5945 5946 5948 5949 594e 594f
5954 5956 595a 595d 595f 5963 5965 5971
5973 5975 5976 597b 597f 5981 598d 598f
5993 5997 599a 599e 59a2 59a3 59a5 59a8
59ab 59ac 59b1 59b4 59b5 59ba 59be 59c2
59c5 59c6 59c8 59cb 59ce 59cf 1 59d4
59d9 59dd 59e0 59e1 59e6 59e9 59ed 59f0
59f4 59f8 59fb 59ff 5a03 5a07 5a0b 5a0f
5a13 5a17 5a1b 5a1f 5a23 5a27 5a2b 5a2f
5a33 5a37 5a3b 5a3f 5a43 5a47 5a4b 5a4f
5a53 5a57 5a5b 5a5f 5a63 5a67 5a6b 5a6f
5a73 5a77 5a7b 5a7f 5a83 5a87 5a8b 5a8f
5a93 5a97 5a9b 5aa7 5aab 5aaf 5ab2 5ab6
5aba 5abc 5ac0 5ac4 5ac8 5acb 5acf 5ad3
5ad5 5ad6 5adb 1 5adf 5ae3 5ae7 5aea
5aee 5af2 5af6 5afa 5afd 5b01 5b05 5b08
5b0b 5b10 5b13 5b16 5b19 5b1a 5b1f 5b20
1 5b22 5b27 5b2b 5b2f 5b32 5b37 5b3c
5b3f 5b43 5b44 5b49 5b4c 5b51 5b52 5b57
5b5a 5b5f 5b60 5b65 5b68 5b6c 5b6d 5b72
5b75 5b7a 5b7b 5b80 5b83 5b87 5b8b 5b8e
5b91 5b92 5b94 5b95 5b9a 5b9b 5ba0 5ba2
5ba6 5ba9 5bab 5baf 5bb1 5bbd 5bbf 5bc1
5bc2 5bc7 5bcb 5bcd 5bd9 5bdb 5bdf 5be3
5be6 5bea 5bed 5bf1 5bf4 5bf5 5bfa 5bfd
5c01 5c05 5c08 5c09 5c0b 5c0e 5c11 5c12
5c17 5c1a 5c1b 5c20 5c24 5c28 5c2b 5c2c
5c2e 5c31 5c34 5c35 5c3a 5c3d 5c3e 1
5c43 5c48 5c4c 5c50 5c53 5c57 5c5b 5c5e
5c61 5c66 5c69 5c6c 5c6f 5c70 5c75 5c76
1 5c78 5c7d 5c81 5c85 5c88 5c8d 5c92
5c95 5c99 5c9a 5c9f 5ca2 5ca7 5ca8 5cad
5cb0 5cb5 5cb6 5cbb 5cbe 5cc2 5cc6 5cca
5cce 5cd1 5cd2 5cd4 5cd9 5cda 5cdc 5cdd
5ce2 5ce5 5cea 5ceb 5cf0 5cf3 5cf8 5cf9
5cfe 5d01 5d05 5d06 5d0b 5d0e 5d13 5d14
5d19 5d1a 5d1f 5d21 5d25 5d28 5d2c 5d30
5d33 5d37 5d3b 5d3e 5d41 5d46 5d49 5d4c
5d4f 5d50 5d55 5d56 1 5d58 5d5d 5d61
5d65 5d68 5d6d 5d72 5d75 5d79 5d7a 5d7f
5d80 5d85 5d87 5d8b 5d8e 5d92 5d96 5d99
5d9d 5da1 5da4 5da8 5dac 5dad 5db2 5db4
5db8 5dbb 5dbf 5dc3 5dc6 5dc9 5dca 5dcc
5dcf 5dd4 5dd5 5dda 5dde 5de2 5de6 5de9
5ded 5df1 5df5 5df9 5dfd 5e01 5e04 5e07
5e08 5e0d 5e0e 5e10 5e14 5e18 5e1c 5e1f
5e23 5e27 5e29 5e2d 5e30 5e32 5e36 5e39
5e3d 5e41 5e44 5e45 5e47 5e4a 5e4d 5e4e
5e53 5e57 5e5b 5e5f 5e63 5e67 5e73 5e77
5e7c 5e80 5e83 5e84 5e89 5e8d 5e91 5e94
5e97 5e9b 5e9d 5ea1 5ea5 5ea8 5eab 5eaf
5eb1 5eb5 5eb9 5ebc 5ebe 5ec2 5ec6 5eca
5ecd 5ed1 5ed5 5ed7 5ed8 5edd 1 5ee1
5ee5 5ee9 5eec 5ef0 5ef4 5ef8 5efc 5eff
5f03 5f07 5f0a 5f0d 5f12 5f15 5f18 5f1b
5f1c 5f21 5f22 1 5f24 5f29 5f2d 5f31
5f34 5f39 5f3e 5f41 5f45 5f46 5f4b 5f4e
5f53 5f54 5f59 5f5c 5f61 5f62 5f67 5f6a
5f6e 5f6f 5f74 5f77 5f7c 5f7d 5f82 5f85
5f89 5f8d 5f90 5f93 5f94 5f96 5f97 5f9c
5f9d 5fa2 5fa4 5fa8 5fab 5fad 5fb1 5fb3
5fbf 5fc1 5fc3 5fc4 5fc9 5fcd 5fcf 5fdb
5fdd 5fe1 5fe5 5fe9 5ff5 5ff9 5ffe 6002
6005 6006 600b 600f 6013 6016 6019 601d
601f 6023 6027 602a 602d 6031 6033 6037
603b 603e 6040 6044 6048 604c 604f 6053
6057 6059 605a 605f 1 6063 6067 606b
606e 6072 6076 607a 607e 6081 6085 6089
608c 608f 6094 6097 609a 609d 609e 60a3
60a4 1 60a6 60ab 60af 60b3 60b6 60bb
60c0 60c3 60c7 60c8 60cd 60d0 60d5 60d6
60db 60de 60e3 60e4 60e9 60ec 60f0 60f1
60f6 60f9 60fe 60ff 6104 6107 610b 610f
6112 6115 6116 6118 6119 611e 611f 6124
6126 612a 612d 612f 6133 6135 6141 6143
6145 6146 614b 614f 6151 615d 615f 6163
6167 616b 6177 617b 6180 6184 6187 6188
618d 6191 6195 6198 619b 619f 61a1 61a5
61a9 61ac 61af 61b3 61b5 61b9 61bd 61c0
61c2 61c6 61ca 61ce 61d1 61d5 61d9 61db
61dc 61e1 1 61e5 61e9 61ed 61f0 61f4
61f8 61fc 6200 6203 6207 620b 620e 6211
6216 6219 621c 621f 6220 6225 6226 1
6228 622d 6231 6235 6238 623d 6242 6245
6249 624a 624f 6252 6257 6258 625d 6260
6265 6266 626b 626e 6272 6273 6278 627b
6280 6281 6286 6289 628d 6291 6294 6297
6298 629a 629b 62a0 62a1 62a6 62a8 62ac
62af 62b1 62b5 62b7 62c3 62c5 62c7 62c8
62cd 62d1 62d3 62df 62e1 62e3 62e7 62ea
62ee 62f2 62f6 62f9 62fa 62fc 62ff 6302
6303 6308 630c 6310 6313 6314 6316 631a
631d 6321 6324 6325 6327 6328 632d 6331
6335 6338 6339 633b 633f 6342 6346 6349
634a 634c 634d 1 6352 6357 635b 635e
6362 6364 6368 636b 636f 6373 6377 637b
637f 6383 6387 638b 638f 6393 6397 639b
639f 63a3 63a7 63ab 63af 63b3 63b7 63bb
63bf 63c3 63c7 63cb 63cf 63d3 63d7 63d9
63dd 63e0 63e4 63e8 63ec 63ef 63f2 63f3
63f5 63f8 63fd 63fe 6403 6406 6407 6409
640c 640e 6412 6416 641a 641e 6421 6425
6428 642c 642f 6430 6435 6438 643c 643f
6440 6445 6448 644c 6450 6454 6458 645c
6460 6464 6468 646c 6470 6474 6478 647c
6480 6484 6488 648c 6498 649c 64a0 64a3
64a7 64ab 64ad 64b1 64b5 64b9 64bc 64c0
64c4 64c6 64c7 64cc 1 64d0 64d4 64d8
64db 64df 64e3 64e7 64eb 64ee 64f2 64f6
64f9 64fc 6501 6504 6507 650a 650b 6510
6511 1 6513 6518 651c 6520 6523 6528
652d 6530 6534 6535 653a 653d 6542 6543
6548 654b 6550 6551 6556 6559 655d 655e
6563 6566 656b 656c 6571 6574 6578 657c
657f 6582 6583 6585 6586 658b 658c 6591
6593 6597 659a 659c 65a0 65a2 65ae 65b0
65b2 65b3 65b8 65bc 65be 65ca 65cc 65d0
65d4 65d7 65db 65de 65e2 65e5 65e6 65eb
65ee 65f2 65f5 65f9 65fd 6601 6604 6605
6607 660b 660e 6612 6615 6616 6618 6619
661e 6622 6626 6629 662a 662c 6630 6633
6637 663a 663b 663d 663e 1 6643 6648
664c 6650 6653 6657 665b 665e 665f 6661
6664 6667 6668 666d 1 6670 6675 6679
667d 6680 6684 6688 668b 668e 6693 6696
6699 669c 669d 66a2 66a3 1 66a5 66aa
66ae 66b2 66b5 66ba 66bf 66c2 66c6 66c7
66cc 66cf 66d4 66d5 66da 66dd 66e2 66e3
66e8 66eb 66ef 66f3 66f7 66fb 66fe 66ff
6701 6706 6707 6709 670a 670f 6712 6717
6718 671d 6720 6725 6726 672b 672e 6732
6733 6738 673b 6740 6741 6746 6747 674c
674e 6752 6755 6759 675d 6760 6764 6768
676b 676e 6773 6776 6779 677c 677d 6782
6783 1 6785 678a 678e 6792 6795 679a
679f 67a2 67a6 67a7 67ac 67ad 67b2 67b4
67b8 67bb 67bf 67c3 67c6 67ca 67ce 67d1
67d5 67d9 67da 67df 67e3 67e5 67e9 67ed
67f0 67f4 67f8 67fb 67fc 67fe 6801 6804
6805 680a 680e 6812 6816 681a 681e 6822
6826 682a 682e 683a 683e 6842 6845 6849
684d 684f 6853 6857 685b 685e 6862 6866
6868 6869 686e 1 6872 6876 687a 687d
6881 6885 6889 688d 6890 6894 6898 689b
689e 68a3 68a6 68a9 68ac 68ad 68b2 68b3
1 68b5 68ba 68be 68c2 68c5 68ca 68cf
68d2 68d6 68d7 68dc 68df 68e4 68e5 68ea
68ed 68f2 68f3 68f8 68fb 68ff 6900 6905
6908 690d 690e 6913 6916 691a 691e 6921
6924 6925 6927 6928 692d 692e 6933 6935
6939 693c 693e 6942 6944 6950 6952 6954
6955 695a 695e 6960 696c 696e 6972 6976
6979 697d 6980 6984 6987 6988 698d 6990
6994 6998 699c 699f 69a0 69a2 69a5 69a9
69ad 69b0 69b1 69b3 69b4 69b9 69bd 69c1
69c5 69c9 69cd 69d1 69d5 69d9 69e5 69e9
69ee 69f2 69f5 69f6 69fb 69ff 6a03 6a06
6a09 6a0d 6a0f 6a13 6a17 6a1a 6a1d 6a21
6a23 6a27 6a2b 6a2e 6a30 6a34 6a38 6a3c
6a3f 6a43 6a47 6a49 6a4a 6a4f 1 6a53
6a57 6a5b 6a5e 6a62 6a66 6a6a 6a6e 6a71
6a75 6a79 6a7c 6a7f 6a84 6a87 6a8a 6a8d
6a8e 6a93 6a94 1 6a96 6a9b 6a9f 6aa3
6aa6 6aab 6ab0 6ab3 6ab7 6ab8 6abd 6ac0
6ac5 6ac6 6acb 6ace 6ad3 6ad4 6ad9 6adc
6ae0 6ae1 6ae6 6ae9 6aee 6aef 6af4 6af7
6afb 6aff 6b02 6b05 6b06 6b08 6b09 6b0e
6b0f 6b14 6b16 6b1a 6b1d 6b1f 6b23 6b25
6b31 6b33 6b35 6b36 6b3b 6b3f 6b41 6b4d
6b4f 6b51 6b55 6b58 6b5a 6b5e 6b62 6b65
6b67 6b6b 6b6e 6b70 6b74 6b77 6b7b 6b7e
6b82 6b86 6b89 6b8d 6b91 6b94 6b97 6b98
6b9d 6ba1 6ba4 6ba8 6baa 6bae 6bb1 6bb5
6bb7 6bbb 6bbf 6bc2 6bc6 6bca 6bcd 6bce
6bd0 6bd3 6bd6 6bd7 6bdc 6be0 6be3 6be7
6be9 6bed 6bf0 6bf4 6bf8 6bfc 6c00 6c04
6c08 6c0b 6c0c 6c0e 6c12 6c16 6c19 6c1a
6c1c 6c20 6c24 6c27 6c28 6c2a 6c2e 6c32
6c35 6c36 6c38 6c3c 6c40 6c43 6c44 6c46
6c4a 6c4e 6c51 6c52 6c54 6c58 6c5c 6c5f
6c60 6c62 6c66 6c6a 6c6d 6c6e 6c70 6c74
6c78 6c7c 6c7d 6c7f 6c83 6c87 6c8b 6c8e
6c8f 6c91 6c95 6c98 6c9c 6c9f 6ca0 6ca5
6ca9 6cad 6cb0 6cb4 6cb8 6cbb 6cbe 6cc3
6cc6 6cc9 6ccc 6ccd 6cd2 6cd3 1 6cd5
6cda 6cde 6ce2 6ce5 6cea 6cef 6cf2 6cf6
6cf7 6cfc 6cff 6d04 6d05 6d0a 6d0d 6d12
6d13 6d18 6d1b 6d1f 6d23 6d27 6d2b 6d2e
6d2f 6d31 6d36 6d37 6d39 6d3a 6d3f 6d40
6d45 6d47 6d4b 6d4e 6d52 6d56 6d59 6d5d
6d61 6d64 6d67 6d6c 6d6f 6d72 6d75 6d76
6d7b 6d7c 1 6d7e 6d83 6d87 6d8b 6d8e
6d93 6d98 6d9b 6d9f 6da0 6da5 6da6 6dab
6dad 6db1 6db4 6db8 6dbc 6dbf 6dc3 6dc7
6dca 6dce 6dcf 6dd4 6dd8 6dda 6dde 6de2
6de5 6de6 6de8 6deb 6dee 6def 6df4 6df8
6dfc 6dff 6e03 6e07 6e0a 6e0d 6e12 6e15
6e18 6e1b 6e1c 6e21 6e22 1 6e24 6e29
6e2d 6e31 6e34 6e39 6e3e 6e41 6e45 6e46
6e4b 6e4e 6e53 6e54 6e59 6e5c 6e61 6e62
6e67 6e6a 6e6e 6e72 6e76 6e77 6e79 6e7e
6e7f 6e81 6e82 6e87 6e8a 6e8f 6e90 6e95
6e98 6e9d 6e9e 6ea3 6ea6 6eaa 6eab 6eb0
6eb3 6eb8 6eb9 6ebe 6ebf 6ec4 6ec6 6eca
6ecd 6ed1 6ed5 6ed8 6edc 6ee0 6ee3 6ee6
6eeb 6eee 6ef1 6ef4 6ef5 6efa 6efb 1
6efd 6f02 6f06 6f0a 6f0d 6f12 6f17 6f1a
6f1e 6f1f 6f24 6f25 6f2a 6f2c 6f30 6f33
6f37 6f3b 6f3e 6f42 6f46 6f49 6f4a 6f4c
6f50 6f54 6f55 6f5a 6f5c 6f60 6f64 6f67
6f6b 6f6f 6f72 6f73 6f75 6f79 6f7c 6f80
6f83 6f84 6f89 6f8d 6f90 6f94 6f96 6f9a
6f9d 6fa1 6fa4 6fa8 6fac 6fb0 6fb4 6fb8
6fbc 6fc0 6fc4 6fc8 6fcc 6fd0 6fd4 6fd8
6fdc 6fe0 6fe4 6fe8 6fec 6ff0 6ff4 6ff8
7004 7008 700c 700f 7013 7017 7019 701d
7021 7025 7028 702c 7030 7032 7033 7038
1 703c 7040 7044 7047 704b 704f 7053
7057 705a 705e 7062 7065 7068 706d 7070
7073 7076 7077 707c 707d 1 707f 7084
7088 708c 708f 7094 7099 709c 70a0 70a1
70a6 70a9 70ae 70af 70b4 70b7 70bc 70bd
70c2 70c5 70c9 70ca 70cf 70d2 70d7 70d8
70dd 70e0 70e4 70e8 70eb 70ee 70ef 70f1
70f2 70f7 70f8 70fd 70ff 7103 7106 7108
710c 710e 711a 711c 711e 711f 7124 7128
712a 7136 7138 713c 713f 7142 7143 7148
714c 7150 7153 7154 7156 7159 715c 715d
7162 7166 7169 716d 716f 7173 7176 717a
717e 7181 7182 7184 7187 718a 718b 7190
7194 7198 719c 719f 71a3 71a5 71a9 71ad
71b1 71b4 71b8 71bc 71bf 71c0 71c2 71c6
71ca 71cd 71ce 71d0 71d4 71d6 71da 71de
71e1 71e3 71e7 71eb 71ee 71ef 71f1 71f4
71f7 71f8 71fd 7201 7205 7209 720c 7210
7212 7216 721a 721e 7221 7225 7229 722c
722d 722f 7233 7237 723a 723b 723d 7241
7243 7247 724b 724e 7250 7254 7258 725b
725f 7263 7266 7267 7269 726c 726f 7270
7275 7278 7279 727e 7282 7286 728a 728e
7292 7296 729a 729e 72a2 72a6 72aa 72ae
72b2 72b6 72ba 72be 72c2 72c6 72ca 72ce
72d2 72d6 72da 72de 72ea 72ee 72f3 72f7
72fa 72fb 7300 7304 7308 730b 730e 7312
7314 7318 731c 731f 7322 7326 7328 732c
7330 7333 7335 7339 733d 7341 7344 7348
734c 734e 734f 7354 1 7358 735c 7360
7363 7367 736b 736f 7373 7376 737a 737e
7381 7384 7389 738c 738f 7392 7393 7398
7399 1 739b 73a0 73a4 73a8 73ab 73b0
73b5 73b8 73bc 73bd 73c2 73c5 73ca 73cb
73d0 73d3 73d8 73d9 73de 73e1 73e5 73e6
73eb 73ee 73f3 73f4 73f9 73fc 7400 7404
7407 740a 740b 740d 740e 7413 7414 7419
741b 741f 7422 7424 7428 742a 7436 7438
743a 743b 7440 7444 7446 7452 7454 7458
745c 7460 7464 7468 746c 7470 7474 7478
747c 7480 7484 7488 748c 7490 749c 74a0
74a5 74a9 74ac 74ad 74b2 74b6 74ba 74bd
74c0 74c4 74c6 74ca 74ce 74d1 74d4 74d8
74da 74de 74e2 74e5 74e7 74eb 74ef 74f3
74f6 74fa 74fe 7500 7501 7506 1 750a
750e 7512 7515 7519 751d 7521 7525 7528
752c 7530 7533 7536 753b 753e 7541 7544
7545 754a 754b 1 754d 7552 7556 755a
755d 7562 7567 756a 756e 756f 7574 7577
757c 757d 7582 7585 758a 758b 7590 7593
7597 7598 759d 75a0 75a5 75a6 75ab 75ae
75b2 75b6 75b9 75bc 75bd 75bf 75c0 75c5
75c6 75cb 75cd 75d1 75d4 75d6 75da 75dc
75e8 75ea 75ec 75ed 75f2 75f6 75f8 7604
7606 760a 760d 7611 7613 7617 761a 761e
7621 7625 7629 762d 7631 7635 7639 763d
7641 7645 7649 764d 7651 7655 7659 765d
7661 7665 7669 766d 7671 7675 7679 767d
7681 7685 7689 768d 7691 7695 7699 769d
76a0 76a3 76a7 76aa 76ab 76ad 76b1 76b4
76b5 76b7 76ba 76bd 76be 76c0 76c4 76c8
76cb 76ce 76cf 76d4 76d8 76dc 76df 76e3
76e7 76ea 76ed 76f2 76f5 76f8 76fb 76fc
7701 7702 1 7704 7709 770d 7711 7714
7719 771e 7721 7725 7726 772b 772e 7733
7734 7739 773c 7741 7742 7747 774a 774e
7752 7756 775a 775d 775e 7760 7765 7766
7768 7769 776e 7771 7776 7777 777c 777f
7784 7785 778a 778d 7791 7792 7797 779a
779f 77a0 77a5 77a6 77ab 77ad 77b1 77b4
77b8 77bc 77bf 77c3 77c7 77ca 77cd 77d2
77d5 77d8 77db 77dc 77e1 77e2 1 77e4
77e9 77ed 77f1 77f4 77f9 77fe 7801 7805
7806 780b 780c 7811 7813 7817 781a 781e
7822 7825 7829 782d 7830 7834 7838 7839
783e 7842 7844 7848 784b 784e 784f 7854
7858 785c 785f 7863 7867 786a 786d 7872
7875 7878 787b 787c 7881 7882 1 7884
7889 788d 7891 7894 7899 789e 78a1 78a5
78a6 78ab 78ae 78b3 78b4 78b9 78bc 78c1
78c2 78c7 78ca 78ce 78d2 78d6 78da 78dd
78de 78e0 78e5 78e6 78e8 78e9 78ee 78f1
78f6 78f7 78fc 78ff 7904 7905 790a 790d
7911 7912 7917 791a 791f 7920 7925 7926
792b 792d 7931 7934 7938 793c 793f 7943
7947 794a 794d 7952 7955 7958 795b 795c
7961 7962 1 7964 7969 796d 7971 7974
7979 797e 7981 7985 7986 798b 798c 7991
7993 7997 799a 799e 79a2 79a5 79a9 79ad
79b0 79b4 79b8 79b9 79be 79c0 79c4 79c8
79cb 79cc 79d1 79d4 79d8 79dc 79e0 79e4
79e8 79ec 79f0 79f4 79f8 79fc 7a00 7a04
7a08 7a0c 7a10 7a14 7a20 7a24 7a28 7a2b
7a2f 7a33 7a35 7a39 7a3d 7a41 7a44 7a48
7a4c 7a4e 7a4f 7a54 1 7a58 7a5c 7a60
7a63 7a67 7a6b 7a6f 7a73 7a76 7a7a 7a7e
7a81 7a84 7a89 7a8c 7a8f 7a92 7a93 7a98
7a99 1 7a9b 7aa0 7aa4 7aa8 7aab 7ab0
7ab5 7ab8 7abc 7abd 7ac2 7ac5 7aca 7acb
7ad0 7ad3 7ad8 7ad9 7ade 7ae1 7ae5 7ae6
7aeb 7aee 7af3 7af4 7af9 7afc 7b00 7b04
7b07 7b0a 7b0b 7b0d 7b0e 7b13 7b14 7b19
7b1b 7b1f 7b22 7b24 7b28 7b2a 7b36 7b38
7b3a 7b3b 7b40 7b44 7b46 7b52 7b54 7b56
7b5a 7b5d 7b60 7b61 7b66 7b6a 7b6e 7b71
7b72 7b74 7b77 7b7a 7b7b 7b80 7b83 7b84
1 7b89 7b8e 7b92 7b96 7b99 7b9a 7b9c
7b9f 7ba2 7ba3 7ba8 7bab 7bac 7bb1 7bb5
7bb9 7bbc 7bbd 7bbf 7bc2 7bc5 7bc6 7bcb
7bcf 7bd3 7bd7 7bdb 7bdf 7be3 7be7 7beb
7bef 7bf3 7bf7 7bfb 7bff 7c03 7c07 7c0b
7c17 7c1b 7c1f 7c22 7c26 7c2a 7c2c 7c30
7c34 7c38 7c3b 7c3f 7c43 7c45 7c46 7c4b
1 7c4f 7c53 7c57 7c5a 7c5e 7c62 7c66
7c6a 7c6d 7c71 7c75 7c78 7c7b 7c80 7c83
7c86 7c89 7c8a 7c8f 7c90 1 7c92 7c97
7c9b 7c9f 7ca2 7ca7 7cac 7caf 7cb3 7cb4
7cb9 7cbc 7cc1 7cc2 7cc7 7cca 7ccf 7cd0
7cd5 7cd8 7cdc 7cdd 7ce2 7ce5 7cea 7ceb
7cf0 7cf3 7cf7 7cfb 7cfe 7d01 7d02 7d04
7d05 7d0a 7d0b 7d10 7d12 7d16 7d19 7d1b
7d1f 7d21 7d2d 7d2f 7d31 7d32 7d37 7d3b
7d3d 7d49 7d4b 7d4d 7d51 7d55 7d59 7d5d
7d61 7d65 7d69 7d6d 7d71 7d75 7d79 7d7d
7d81 7d85 7d89 7d8d 7d99 7d9d 7da1 7da4
7da8 7dac 7dae 7db2 7db6 7dba 7dbd 7dc1
7dc5 7dc7 7dc8 7dcd 1 7dd1 7dd5 7dd9
7ddc 7de0 7de4 7de8 7dec 7def 7df3 7df7
7dfa 7dfd 7e02 7e05 7e08 7e0b 7e0c 7e11
7e12 1 7e14 7e19 7e1d 7e21 7e24 7e29
7e2e 7e31 7e35 7e36 7e3b 7e3e 7e43 7e44
7e49 7e4c 7e51 7e52 7e57 7e5a 7e5e 7e5f
7e64 7e67 7e6c 7e6d 7e72 7e75 7e79 7e7d
7e80 7e83 7e84 7e86 7e87 7e8c 7e8d 7e92
7e94 7e98 7e9b 7e9d 7ea1 7ea3 7eaf 7eb1
7eb3 7eb4 7eb9 7ebd 7ebf 7ecb 7ecd 7ecf
7ed3 7ed7 7eda 7edc 7ee0 7ee4 7ee7 7ee8
7eea 7eed 7ef0 7ef1 7ef6 7efa 7efe 7f02
7f06 7f0a 7f0e 7f12 7f16 7f1a 7f1e 7f22
7f26 7f2a 7f36 7f3a 7f3e 7f41 7f45 7f49
7f4b 7f4f 7f53 7f57 7f5a 7f5e 7f62 7f64
7f65 7f6a 1 7f6e 7f72 7f76 7f79 7f7d
7f81 7f85 7f89 7f8c 7f90 7f94 7f97 7f9a
7f9f 7fa2 7fa5 7fa8 7fa9 7fae 7faf 1
7fb1 7fb6 7fba 7fbe 7fc1 7fc6 7fcb 7fce
7fd2 7fd3 7fd8 7fdb 7fe0 7fe1 7fe6 7fe9
7fee 7fef 7ff4 7ff7 7ffb 7ffc 8001 8004
8009 800a 800f 8012 8016 801a 801d 8020
8021 8023 8024 8029 802a 802f 8031 8035
8038 803a 803e 8040 804c 804e 8050 8051
8056 805a 805c 8068 806a 806c 8070 8074
8078 807c 8080 8084 8088 808c 8090 8094
8098 809c 80a0 80ac 80b0 80b4 80b7 80bb
80bf 80c1 80c5 80c9 80cd 80d0 80d4 80d8
80da 80db 80e0 1 80e4 80e8 80ec 80ef
80f3 80f7 80fb 80ff 8102 8106 810a 810d
8110 8115 8118 811b 811e 811f 8124 8125
1 8127 812c 8130 8134 8137 813c 8141
8144 8148 8149 814e 8151 8156 8157 815c
815f 8164 8165 816a 816d 8171 8172 8177
817a 817f 8180 8185 8188 818c 8190 8193
8196 8197 8199 819a 819f 81a0 81a5 81a7
81ab 81ae 81b0 81b4 81b6 81c2 81c4 81c6
81c7 81cc 81d0 81d2 81de 81e0 81e2 81e6
81ea 81ed 81ef 81f3 81f7 81fa 81fc 8200
8203 8207 820b 820f 8213 8217 821b 821f
8223 8226 8227 8229 822c 822f 8230 8232
8236 823a 823e 8242 8246 824a 824e 8252
8256 825a 825e 8262 826e 8272 8276 8279
827d 8281 8283 8287 828b 828f 8292 8296
829a 829c 829d 82a2 1 82a6 82aa 82ae
82b1 82b5 82b9 82bd 82c1 82c4 82c8 82cc
82cf 82d2 82d7 82da 82dd 82e0 82e1 82e6
82e7 1 82e9 82ee 82f2 82f6 82f9 82fe
8303 8306 830a 830b 8310 8313 8318 8319
831e 8321 8326 8327 832c 832f 8333 8334
8339 833c 8341 8342 8347 834a 834e 8352
8355 8358 8359 835b 835c 8361 8362 8367
8369 836d 8370 8372 8376 8378 8384 8386
8388 8389 838e 8392 8394 83a0 83a2 83a4
83a8 83ac 83af 83b3 83b7 83ba 83bb 83bd
83c0 83c3 83c4 83c9 83cd 83d1 83d5 83d8
83d9 83db 83de 83e2 83e6 83e9 83ea 83ec
83ed 83f2 83f6 83f8 83fc 83ff 8401 8405
8409 840c 8410 8414 8417 841b 841e 8422
8425 8426 842b 842e 8432 8436 8439 843d
8441 8444 8447 844c 844f 8452 8455 8456
845b 845c 1 845e 8463 8467 846b 846e
8473 8478 847b 847f 8480 8485 8488 848d
848e 8493 8496 849b 849c 84a1 84a4 84a8
84ac 84b0 84b4 84b7 84b8 84ba 84bf 84c0
84c2 84c3 84c8 84cb 84d0 84d1 84d6 84d9
84de 84df 84e4 84e7 84eb 84ec 84f1 84f4
84f9 84fa 84ff 8500 8505 8507 850b 850e
8512 8516 8519 851d 8521 8524 8527 852c
852f 8532 8535 8536 853b 853c 1 853e
8543 8547 854b 854e 8553 8558 855b 855f
8560 8565 8566 856b 856d 8571 8574 8578
857c 857f 8583 8587 858a 858e 8592 8593
8598 859a 859e 85a1 85a3 85a7 85ab 85ae
85b2 85b6 85ba 85be 85c2 85c6 85ca 85ce
85d2 85d6 85da 85de 85e2 85e6 85ea 85ee
85f2 85f6 85fa 85fe 8602 8606 860a 860e
8612 8616 861a 861e 8622 8626 862a 862e
8632 8636 863a 863e 8642 8646 864a 864e
8652 865e 8662 8667 866b 866e 866f 8674
8678 867c 867f 8682 8686 8688 868c 8690
8693 8696 869a 869c 86a0 86a4 86a7 86a9
86ad 86b1 86b5 86b8 86bc 86c0 86c2 86c3
86c8 1 86cc 86d0 86d4 86d7 86db 86df
86e3 86e7 86ea 86ee 86f2 86f5 86f8 86fd
8700 8703 8706 8707 870c 870d 1 870f
8714 8718 871c 871f 8724 8729 872c 8730
8731 8736 8739 873e 873f 8744 8747 874c
874d 8752 8755 8759 875a 875f 8762 8767
8768 876d 8770 8774 8778 877b 877e 877f
8781 8782 8787 8788 878d 878f 8793 8796
8798 879c 879e 87aa 87ac 87ae 87af 87b4
87b8 87ba 87c6 87c8 87cc 87d0 87d3 87d4
87d6 87da 87dd 87e1 87e4 87e5 87e7 87e8
87ed 87f1 87f5 87f9 87fd 8801 8805 8809
880d 8811 8815 8819 881c 881d 881f 8823
8827 882a 882b 882d 8830 8834 8838 883b
883c 883e 883f 8841 8845 8847 884b 884f
8853 8857 885b 8867 886b 8870 8874 8877
8878 887d 8881 8885 8888 888b 888f 8891
8895 8899 889c 889f 88a3 88a5 88a9 88ad
88b0 88b2 88b6 88ba 88be 88c1 88c5 88c9
88cb 88cc 88d1 1 88d5 88d9 88dd 88e0
88e4 88e8 88ec 88f0 88f3 88f7 88fb 88fe
8901 8906 8909 890c 890f 8910 8915 8916
1 8918 891d 8921 8925 8928 892d 8932
8935 8939 893a 893f 8942 8947 8948 894d
8950 8955 8956 895b 895e 8962 8963 8968
896b 8970 8971 8976 8979 897d 8981 8984
8987 8988 898a 898b 8990 8991 8996 8998
899c 899f 89a1 89a5 89a7 89b3 89b5 89b7
89b8 89bd 89c1 89c3 89cf 89d1 89d5 89d9
89dd 89e1 89e5 89e9 89ed 89f1 89f5 89f9
89fd 8a01 8a05 8a09 8a0d 8a11 8a15 8a19
8a1d 8a21 8a25 8a29 8a35 8a39 8a3e 8a42
8a45 8a46 8a4b 8a4f 8a53 8a56 8a59 8a5d
8a5f 8a63 8a67 8a6a 8a6d 8a71 8a73 8a77
8a7b 8a7e 8a80 8a84 8a88 8a8c 8a8f 8a93
8a97 8a99 8a9a 8a9f 1 8aa3 8aa7 8aab
8aae 8ab2 8ab6 8aba 8abe 8ac1 8ac5 8ac9
8acc 8acf 8ad4 8ad7 8ada 8add 8ade 8ae3
8ae4 1 8ae6 8aeb 8aef 8af3 8af6 8afb
8b00 8b03 8b07 8b08 8b0d 8b10 8b15 8b16
8b1b 8b1e 8b23 8b24 8b29 8b2c 8b30 8b31
8b36 8b39 8b3e 8b3f 8b44 8b47 8b4b 8b4f
8b52 8b55 8b56 8b58 8b59 8b5e 8b5f 8b64
8b66 8b6a 8b6d 8b6f 8b73 8b75 8b81 8b83
8b85 8b86 8b8b 8b8f 8b91 8b9d 8b9f 8ba1
8ba5 8ba9 8bac 8bae 8bb2 8bb5 8bb7 8bbb
8bbf 8bc2 8bc4 8bc8 8bcb 8bcd 8bd1 8bd4
8bd8 8bdb 8bdc 8be1 8be4 8be7 8beb 8bef
8bf2 8bf3 8bf5 8bf8 8bfb 8bfc 8c01 1
8c04 8c09 8c0d 8c11 8c14 8c15 8c17 8c1a
8c1d 8c1e 8c23 1 8c26 8c2b 8c2f 8c32
8c36 8c3a 8c3e 8c42 8c46 8c4a 8c4e 8c52
8c57 8c5b 8c5f 8c63 8c64 8c69 8c6d 8c71
8c75 8c78 8c79 8c7b 8c7e 8c81 8c82 8c87
8c8b 8c8f 8c93 8c96 8c97 8c99 8c9d 8c9f
8ca3 8ca6 8caa 8cae 8cb1 8cb2 8cb4 8cb7
8cba 8cbb 8cc0 8cc3 8cc7 8ccb 8cce 8ccf
8cd1 8cd4 8cd7 8cd8 8cdd 1 8ce0 8ce5
8ce9 8ced 8cf0 8cf1 8cf3 8cf6 8cf9 8cfa
8cff 8d02 8d06 8d0a 8d0d 8d0e 8d10 8d13
8d16 8d17 8d1c 1 8d1f 8d24 8d28 8d2c
8d30 8d34 8d38 8d3c 8d40 8d44 8d48 8d4c
8d50 8d54 8d58 8d5c 8d60 8d64 8d68 8d6c
8d70 8d74 8d78 8d7c 8d80 8d84 8d88 8d8c
8d90 8d94 8d98 8d9c 8da0 8da4 8da8 8dac
8db0 8db4 8db8 8dbc 8dc0 8dc4 8dc8 8dcc
8dd0 8dd4 8dd8 8ddc 8de0 8de4 8de8 8dec
8df0 8df4 8e00 8e04 8e09 8e0d 8e10 8e11
8e16 8e1a 8e1e 8e21 8e24 8e28 8e2a 8e2e
8e32 8e35 8e38 8e3c 8e3e 8e42 8e46 8e49
8e4b 8e4f 8e53 8e57 8e5a 8e5e 8e62 8e64
8e65 8e6a 1 8e6e 8e72 8e76 8e79 8e7d
8e81 8e85 8e89 8e8c 8e90 8e94 8e97 8e9a
8e9f 8ea2 8ea5 8ea8 8ea9 8eae 8eaf 1
8eb1 8eb6 8eba 8ebe 8ec1 8ec6 8ecb 8ece
8ed2 8ed3 8ed8 8edb 8ee0 8ee1 8ee6 8ee9
8eee 8eef 8ef4 8ef7 8efb 8efc 8f01 8f04
8f09 8f0a 8f0f 8f12 8f16 8f1a 8f1d 8f20
8f21 8f23 8f24 8f29 8f2a 8f2f 8f31 8f35
8f38 8f3a 8f3e 8f40 8f4c 8f4e 8f50 8f51
8f56 8f5a 8f5c 8f68 8f6a 8f6e 8f70 8f74
8f78 8f7b 8f7c 8f7e 8f81 8f84 8f85 8f8a
8f8e 8f92 8f96 8f9a 8f9e 8fa2 8fa6 8faa
8fae 8fb2 8fb6 8fba 8fbe 8fc2 8fc6 8fca
8fce 8fd2 8fd6 8fda 8fde 8fe2 8fe6 8fea
8fee 8ff2 8ff6 8ffa 8ffe 9002 9006 900a
900e 9012 9016 901a 901e 9022 9026 902a
902e 9032 9036 903a 903e 9042 9046 904a
904e 9052 9056 905a 9066 906a 906f 9073
9076 9077 907c 9080 9084 9087 908a 908e
9090 9094 9098 909b 909e 90a2 90a4 90a8
90ac 90af 90b1 90b5 90b9 90bd 90c0 90c4
90c8 90ca 90cb 90d0 1 90d4 90d8 90dc
90df 90e3 90e7 90eb 90ef 90f2 90f6 90fa
90fd 9100 9105 9108 910b 910e 910f 9114
9115 1 9117 911c 9120 9124 9127 912c
9131 9134 9138 9139 913e 9141 9146 9147
914c 914f 9154 9155 915a 915d 9161 9162
9167 916a 916f 9170 9175 9178 917c 9180
9183 9186 9187 9189 918a 918f 9190 9195
9197 919b 919e 91a0 91a4 91a6 91b2 91b4
91b6 91b7 91bc 91c0 91c2 91ce 91d0 91d2
91d6 91da 91de 91e2 91e6 91ea 91ee 91f2
91f6 91fa 91fe 9202 9206 920a 920e 9212
9216 921a 921e 9222 9226 922a 922e 9232
9236 923a 923e 9242 9246 924a 924e 9252
9256 925a 925e 9262 9266 926a 926e 9272
9276 927a 927e 9282 9286 928a 928e 9292
9296 929a 929e 92a2 92a6 92b2 92b6 92bb
92bf 92c2 92c3 92c8 92cc 92d0 92d3 92d6
92da 92dc 92e0 92e4 92e7 92ea 92ee 92f0
92f4 92f8 92fb 92fd 9301 9305 9309 930c
9310 9314 9316 9317 931c 1 9320 9324
9328 932b 932f 9333 9337 933b 933e 9342
9346 9349 934c 9351 9354 9357 935a 935b
9360 9361 1 9363 9368 936c 9370 9373
9378 937d 9380 9384 9385 938a 938d 9392
9393 9398 939b 93a0 93a1 93a6 93a9 93ad
93ae 93b3 93b6 93bb 93bc 93c1 93c4 93c8
93cc 93cf 93d2 93d3 93d5 93d6 93db 93dc
93e1 93e3 93e7 93ea 93ec 93f0 93f2 93fe
9400 9402 9403 9408 940c 940e 941a 941c
941e 9422 9426 9429 942b 942f 9433 9437
943b 943f 9443 9447 944b 944f 9453 9457
945b 945f 9463 9467 946b 946f 9473 9477
947b 947f 9483 9487 948b 948f 9493 9497
949b 949f 94a3 94a7 94ab 94af 94b3 94b7
94bb 94bf 94c3 94c7 94cb 94cf 94d3 94d7
94db 94df 94e3 94e7 94eb 94ef 94f3 94f7
94fb 9507 950b 9510 9514 9517 9518 951d
9521 9525 9528 952b 952f 9531 9535 9539
953c 953f 9543 9545 9549 954d 9550 9552
9556 955a 955e 9561 9565 9569 956b 956c
9571 1 9575 9579 957d 9580 9584 9588
958c 9590 9593 9597 959b 959e 95a1 95a6
95a9 95ac 95af 95b0 95b5 95b6 1 95b8
95bd 95c1 95c5 95c8 95cd 95d2 95d5 95d9
95da 95df 95e2 95e7 95e8 95ed 95f0 95f5
95f6 95fb 95fe 9602 9603 9608 960b 9610
9611 9616 9619 961d 9621 9624 9627 9628
962a 962b 9630 9631 9636 9638 963c 963f
9641 9645 9647 9653 9655 9657 9658 965d
9661 9663 966f 9671 9673 9677 967b 967e
9680 9684 9687 968b 968f 9693 9696 969b
969c 96a1 96a4 96a7 96a8 96aa 96ae 96b2
96b7 96bb 96bf 96c3 96c7 96cb 96ce 96d2
96d6 96d9 96dd 96e1 96e4 96e8 96ec 96f0
96f4 96f8 96fb 96ff 9703 9704 9708 970c
9710 9715 9719 971a 971e 9722 9726 972a
972e 9732 9736 973a 973e 9742 9746 974a
974e 9752 9756 975a 975e 9762 9766 976a
976e 9772 9776 977a 977e 9783 9788 978c
9790 9794 9799 979d 97a1 97a4 97a7 97ab
97ad 97b1 97b5 97b8 97bb 97bf 97c1 97c5
97c9 97cc 97d0 97d4 97d7 97db 97de 97e2
97e5 97e6 97eb 97ee 97f2 97f8 97fa 97fe
9801 9805 9808 980c 9810 9814 9818 981c
9820 982c 9830 9834 9837 983b 983f 9841
9845 9849 984d 9850 9854 9858 985a 985b
9860 1 9864 9868 986c 986f 9873 9877
987b 987f 9882 9886 988a 988d 9890 9895
9898 989b 989e 989f 98a4 98a5 1 98a7
98ac 98b0 98b4 98b7 98bc 98c1 98c4 98c8
98c9 98ce 98d1 98d6 98d7 98dc 98df 98e4
98e5 98ea 98ed 98f1 98f2 98f7 98fa 98ff
9900 9905 9908 990c 9910 9913 9916 9917
9919 991a 991f 9920 9925 9927 992b 992e
9930 9934 9936 9942 9944 9946 9947 994c
9950 9952 995e 9960 9964 9968 996c 9970
9974 9980 9984 9988 998b 998f 9993 9995
9999 999d 99a1 99a4 99a8 99ac 99ae 99af
99b4 1 99b8 99bc 99c0 99c3 99c7 99cb
99cf 99d3 99d6 99da 99de 99e1 99e4 99e9
99ec 99ef 99f2 99f3 99f8 99f9 1 99fb
9a00 9a04 9a08 9a0b 9a10 9a15 9a18 9a1c
9a1d 9a22 9a25 9a2a 9a2b 9a30 9a33 9a38
9a39 9a3e 9a41 9a45 9a46 9a4b 9a4e 9a53
9a54 9a59 9a5c 9a60 9a64 9a67 9a6a 9a6b
9a6d 9a6e 9a73 9a74 9a79 9a7b 9a7f 9a82
9a84 9a88 9a8a 9a96 9a98 9a9a 9a9b 9aa0
9aa4 9aa6 9ab2 9ab4 9ab8 9abb 9abe 9abf
9ac4 9ac8 9acc 9acf 9ad0 9ad2 9ad5 9ad8
9ad9 9ade 9ae2 9ae6 9aea 9aed 9af1 9af5
9af9 9afd 9b01 9b05 9b08 9b0b 9b0c 9b11
9b12 9b14 9b18 9b1c 9b20 9b23 9b27 9b2b
9b2f 9b33 9b37 9b3b 9b3f 9b43 9b47 9b4b
9b4f 9b53 9b57 9b5b 9b5f 9b63 9b67 9b6b
9b6f 9b73 9b77 9b7b 9b7f 9b83 9b87 9b8b
9b8f 9b93 9b9f 9ba3 9ba7 9baa 9bae 9bb2
9bb4 9bb8 9bbc 9bc0 9bc3 9bc7 9bcb 9bcd
9bce 9bd3 1 9bd7 9bdb 9bdf 9be2 9be6
9bea 9bee 9bf2 9bf5 9bf9 9bfd 9c00 9c03
9c08 9c0b 9c0e 9c11 9c12 9c17 9c18 1
9c1a 9c1f 9c23 9c27 9c2a 9c2f 9c34 9c37
9c3b 9c3c 9c41 9c44 9c49 9c4a 9c4f 9c52
9c57 9c58 9c5d 9c60 9c64 9c65 9c6a 9c6d
9c72 9c73 9c78 9c7b 9c7f 9c83 9c86 9c89
9c8a 9c8c 9c8d 9c92 9c93 9c98 9c9a 9c9e
9ca1 9ca3 9ca7 9ca9 9cb5 9cb7 9cb9 9cba
9cbf 9cc3 9cc5 9cd1 9cd3 9cd7 9cdb 9cde
9ce2 9ce5 9ce9 9cec 9ced 9cf2 9cf5 9cf9
9cfc 9d00 9d04 9d09 9d0d 9d11 9d15 9d19
9d1d 9d21 9d25 9d29 9d2d 9d31 9d35 9d39
9d3d 9d49 9d4d 9d51 9d54 9d58 9d5c 9d5e
9d62 9d66 9d6a 9d6d 9d71 9d75 9d77 9d78
9d7d 1 9d81 9d85 9d89 9d8c 9d90 9d94
9d98 9d9c 9d9f 9da3 9da7 9daa 9dad 9db2
9db5 9db8 9dbb 9dbc 9dc1 9dc2 1 9dc4
9dc9 9dcd 9dd1 9dd4 9dd9 9dde 9de1 9de5
9de6 9deb 9dee 9df3 9df4 9df9 9dfc 9e01
9e02 9e07 9e0a 9e0e 9e0f 9e14 9e17 9e1c
9e1d 9e22 9e25 9e29 9e2d 9e30 9e33 9e34
9e36 9e37 9e3c 9e3d 9e42 9e44 9e48 9e4b
9e4d 9e51 9e53 9e5f 9e61 9e63 9e64 9e69
9e6d 9e6f 9e7b 9e7d 9e81 9e85 9e88 9e8c
9e8f 9e93 9e96 9e97 9e9c 9e9f 9ea3 9ea7
9eab 9eaf 9eb3 9eb7 9ebb 9ebf 9ec3 9ec7
9ecb 9ecf 9ed3 9ed7 9edb 9edf 9ee3 9ee7
9eeb 9eef 9ef3 9ef7 9efb 9eff 9f03 9f07
9f0b 9f0f 9f13 9f17 9f1b 9f1f 9f23 9f27
9f2b 9f2f 9f33 9f3f 9f43 9f47 9f4a 9f4e
9f52 9f54 9f58 9f5c 9f60 9f63 9f67 9f6b
9f6d 9f6e 9f73 1 9f77 9f7b 9f7f 9f82
9f86 9f8a 9f8e 9f92 9f95 9f99 9f9d 9fa0
9fa3 9fa8 9fab 9fae 9fb1 9fb2 9fb7 9fb8
1 9fba 9fbf 9fc3 9fc7 9fca 9fcf 9fd4
9fd7 9fdb 9fdc 9fe1 9fe4 9fe9 9fea 9fef
9ff2 9ff7 9ff8 9ffd a000 a004 a005 a00a
a00d a012 a013 a018 a01b a01f a023 a026
a029 a02a a02c a02d a032 a033 a038 a03a
a03e a041 a043 a047 a049 a055 a057 a059
a05a a05f a063 a065 a071 a073 a077 a07b
a07e a082 a085 a089 a08c a08d a092 a095
a099 a09c a09d a0a2 1 a0a5 a0aa a0ae
a0b2 a0b5 a0b9 a0bd a0c0 a0c1 a0c3 a0c7
a0cb a0ce a0d2 a0d3 a0d5 a0d9 a0dd a0e1
a0e5 a0e9 a0ed a0f1 a0f5 a0f9 a0fd a101
a105 a111 a115 a11a a11e a121 a122 a127
a12b a12f a132 a135 a139 a13b a13f a143
a146 a149 a14d a14f a153 a157 a15a a15c
a160 a164 a168 a16b a16f a173 a175 a176
a17b 1 a17f a183 a187 a18a a18e a192
a196 a19a a19d a1a1 a1a5 a1a8 a1ab a1b0
a1b3 a1b6 a1b9 a1ba a1bf a1c0 1 a1c2
a1c7 a1cb a1cf a1d2 a1d7 a1dc a1df a1e3
a1e4 a1e9 a1ec a1f1 a1f2 a1f7 a1fa a1ff
a200 a205 a208 a20c a20d a212 a215 a21a
a21b a220 a223 a227 a22b a22e a231 a232
a234 a235 a23a a23b a240 a242 a246 a249
a24b a24f a251 a25d a25f a261 a262 a267
a26b a26d a279 a27b a27f a284 a288 a28c
a290 a294 a298 a29c a29d a29f a2a3 a2a7
a2ac a2b0 a2b4 a2b8 a2bc a2c0 a2c4 a2c5
a2c7 a2cb a2cf a2d3 a2d7 a2db a2df a2e3
a2e7 a2eb a2f7 a2fb a300 a304 a307 a308
a30d a311 a315 a318 a31b a31f a321 a325
a329 a32c a32f a333 a335 a339 a33d a340
a342 a346 a34a a34e a351 a355 a359 a35b
a35c a361 1 a365 a369 a36d a370 a374
a378 a37c a380 a383 a387 a38b a38e a391
a396 a399 a39c a39f a3a0 a3a5 a3a6 1
a3a8 a3ad a3b1 a3b5 a3b8 a3bd a3c2 a3c5
a3c9 a3ca a3cf a3d2 a3d7 a3d8 a3dd a3e0
a3e5 a3e6 a3eb a3ee a3f2 a3f3 a3f8 a3fb
a400 a401 a406 a409 a40d a411 a414 a417
a418 a41a a41b a420 a421 a426 a428 a42c
a42f a431 a435 a437 a443 a445 a447 a448
a44d a451 a453 a45f a461 a465 a469 a46c
a46d a46f a473 a476 a47a a47d a47e a483
a487 a48b a48f a49b a49f a4a4 a4a8 a4ab
a4ac a4b1 a4b5 a4b9 a4bc a4bf a4c3 a4c5
a4c9 a4cd a4d0 a4d3 a4d7 a4d9 a4dd a4e1
a4e4 a4e6 a4ea a4ee a4f2 a4f5 a4f9 a4fd
a4ff a500 a505 1 a509 a50d a511 a514
a518 a51c a520 a524 a527 a52b a52f a532
a535 a53a a53d a540 a543 a544 a549 a54a
1 a54c a551 a555 a559 a55c a561 a566
a569 a56d a56e a573 a576 a57b a57c a581
a584 a589 a58a a58f a592 a596 a597 a59c
a59f a5a4 a5a5 a5aa a5ad a5b1 a5b5 a5b8
a5bb a5bc a5be a5bf a5c4 a5c5 a5ca a5cc
a5d0 a5d3 a5d5 a5d9 a5db a5e7 a5e9 a5eb
a5ec a5f1 a5f5 a5f7 a603 a605 a609 a60d
a611 a615 a61a a61e a622 a626 a62a a62e
a632 a633 a635 a639 a63b a63f a642 a646
a648 a64c a650 a653 a654 a656 a65a a65d
a661 a664 a665 a66a a66e a672 a675 a679
a67d a680 a681 a683 a687 a68b a68e a692
a693 a695 a699 a69d a6a1 a6a5 a6a9 a6ad
a6b1 a6b5 a6b9 a6bd a6c1 a6c5 a6c9 a6cd
a6d9 a6dd a6e2 a6e6 a6e9 a6ea a6ef a6f3
a6f7 a6fa a6fd a701 a703 a707 a70b a70e
a711 a715 a717 a71b a71f a722 a724 a728
a72c a730 a733 a737 a73b a73d a73e a743
1 a747 a74b a74f a752 a756 a75a a75e
a762 a765 a769 a76d a770 a773 a778 a77b
a77e a781 a782 a787 a788 1 a78a a78f
a793 a797 a79a a79f a7a4 a7a7 a7ab a7ac
a7b1 a7b4 a7b9 a7ba a7bf a7c2 a7c7 a7c8
a7cd a7d0 a7d4 a7d5 a7da a7dd a7e2 a7e3
a7e8 a7eb a7ef a7f3 a7f6 a7f9 a7fa a7fc
a7fd a802 a803 a808 a80a a80e a811 a813
a817 a819 a825 a827 a829 a82a a82f a833
a835 a841 a843 a847 a84c a850 a854 a858
a85c a860 a864 a865 a867 a86b a86f a874
a878 a87c a880 a884 a888 a88c a88d a88f
a893 a897 a89b a89f a8a3 a8a7 a8ab a8af
a8b3 a8bf a8c3 a8c8 a8cc a8cf a8d0 a8d5
a8d9 a8dd a8e0 a8e3 a8e7 a8e9 a8ed a8f1
a8f4 a8f7 a8fb a8fd a901 a905 a908 a90a
a90e a912 a916 a919 a91d a921 a923 a924
a929 1 a92d a931 a935 a938 a93c a940
a944 a948 a94b a94f a953 a956 a959 a95e
a961 a964 a967 a968 a96d a96e 1 a970
a975 a979 a97d a980 a985 a98a a98d a991
a992 a997 a99a a99f a9a0 a9a5 a9a8 a9ad
a9ae a9b3 a9b6 a9ba a9bb a9c0 a9c3 a9c8
a9c9 a9ce a9d1 a9d5 a9d9 a9dc a9df a9e0
a9e2 a9e3 a9e8 a9e9 a9ee a9f0 a9f4 a9f7
a9f9 a9fd a9ff aa0b aa0d aa0f aa10 aa15
aa19 aa1b aa27 aa29 aa2b aa2f aa33 aa37
aa3b aa3f aa43 aa47 aa4b aa4f aa53 aa57
aa5b aa67 aa6b aa70 aa74 aa77 aa78 aa7d
aa81 aa85 aa88 aa8b aa8f aa91 aa95 aa99
aa9c aa9f aaa3 aaa5 aaa9 aaad aab0 aab2
aab6 aaba aabe aac1 aac5 aac9 aacb aacc
aad1 1 aad5 aad9 aadd aae0 aae4 aae8
aaec aaf0 aaf3 aaf7 aafb aafe ab01 ab06
ab09 ab0c ab0f ab10 ab15 ab16 1 ab18
ab1d ab21 ab25 ab28 ab2d ab32 ab35 ab39
ab3a ab3f ab42 ab47 ab48 ab4d ab50 ab55
ab56 ab5b ab5e ab62 ab63 ab68 ab6b ab70
ab71 ab76 ab79 ab7d ab81 ab84 ab87 ab88
ab8a ab8b ab90 ab91 ab96 ab98 ab9c ab9f
aba1 aba5 aba7 abb3 abb5 abb7 abb8 abbd
abc1 abc3 abcf abd1 abd5 abd9 abdc abe0
abe4 abe7 abe8 abea abee abf2 abf5 abf9
abfa abfc ac00 ac04 ac08 ac0c ac0f ac13
ac17 ac1c ac20 ac24 ac27 ac2b ac2f ac33
ac37 ac3b ac3f ac43 ac47 ac4b ac4f ac50
ac52 ac56 ac5a ac5e ac62 ac66 ac69 ac6a
ac6c ac6d ac6f ac73 ac77 ac7b ac7c ac81
ac85 ac89 ac8d ac91 ac95 ac99 ac9d aca1
aca5 aca9 acad acb1 acb5 acb9 acbd acc1
acc5 acc9 accd acd1 acd5 acd9 acdd ace1
ace5 ace9 acf5 acf9 acfe ad02 ad05 ad06
ad0b ad0f ad13 ad16 ad19 ad1d ad1f ad23
ad27 ad2a ad2d ad31 ad33 ad37 ad3b ad3e
ad40 ad44 ad48 ad4c ad4f ad53 ad57 ad59
ad5a ad5f 1 ad63 ad67 ad6b ad6e ad72
ad76 ad7a ad7e ad81 ad85 ad89 ad8c ad8f
ad94 ad97 ad9a ad9d ad9e ada3 ada4 1
ada6 adab adaf adb3 adb6 adbb adc0 adc3
adc7 adc8 adcd add0 add5 add6 addb adde
ade3 ade4 ade9 adec adf0 adf1 adf6 adf9
adfe adff ae04 ae07 ae0b ae0f ae12 ae15
ae16 ae18 ae19 ae1e ae1f ae24 ae26 ae2a
ae2d ae2f ae33 ae35 ae41 ae43 ae45 ae46
ae4b ae4f ae51 ae5d ae5f ae61 ae65 ae69
ae6c ae70 ae72 ae76 ae7a ae7d ae81 ae84
ae88 ae8b ae8c ae91 ae94 ae98 ae9c aea0
aea4 aea8 aeac aeaf aeb0 aeb2 aeb6 aeba
aebd aebe aec0 aec3 aec7 aeca aece aed1
aed2 aed7 aedb aedf aee3 aee7 aeeb aeef
aef3 aef7 af03 af07 af0c af10 af13 af14
af19 af1d af21 af24 af27 af2b af2d af31
af35 af38 af3b af3f af41 af45 af49 af4c
af4e af52 af56 af5a af5d af61 af65 af67
af68 af6d 1 af71 af75 af79 af7c af80
af84 af88 af8c af8f af93 af97 af9a af9d
afa2 afa5 afa8 afab afac afb1 afb2 1
afb4 afb9 afbd afc1 afc4 afc9 afce afd1
afd5 afd6 afdb afde afe3 afe4 afe9 afec
aff1 aff2 aff7 affa affe afff b004 b007
b00c b00d b012 b015 b019 b01d b020 b023
b024 b026 b027 b02c b02d b032 b034 b038
b03b b03d b041 b043 b04f b051 b053 b054
b059 b05d b05f b06b b06d b071 b073 b077
b07b b07e b07f b081 b085 b088 b08c b08f
b090 b095 b099 b09d b0a0 b0a4 b0a8 b0ab
b0ac b0ae b0b2 b0b6 b0b9 b0bd b0be b0c0
b0c4 b0c8 b0cc b0d0 b0d4 b0d8 b0dc b0e0
b0e4 b0e8 b0ec b0f0 b0f4 b0f8 b104 b108
b10d b111 b114 b115 b11a b11e b122 b125
b128 b12c b12e b132 b136 b139 b13c b140
b142 b146 b14a b14d b14f b153 b157 b15b
b15e b162 b166 b168 b169 b16e 1 b172
b176 b17a b17d b181 b185 b189 b18d b190
b194 b198 b19b b19e b1a3 b1a6 b1a9 b1ac
b1ad b1b2 b1b3 1 b1b5 b1ba b1be b1c2
b1c5 b1ca b1cf b1d2 b1d6 b1d7 b1dc b1df
b1e4 b1e5 b1ea b1ed b1f2 b1f3 b1f8 b1fb
b1ff b200 b205 b208 b20d b20e b213 b216
b21a b21e b221 b224 b225 b227 b228 b22d
b22e b233 b235 b239 b23c b23e b242 b244
b250 b252 b254 b255 b25a b25e b260 b26c
b26e b270 b274 b278 b27c b280 b284 b288
b28c b290 b294 b298 b29c b2a0 b2a4 b2a8
b2ac b2b0 b2b4 b2c0 b2c4 b2c9 b2cd b2d0
b2d1 b2d6 b2da b2de b2e1 b2e4 b2e8 b2ea
b2ee b2f2 b2f5 b2f8 b2fc b2fe b302 b306
b309 b30b b30f b313 b317 b31a b31e b322
b324 b325 b32a 1 b32e b332 b336 b339
b33d b341 b345 b349 b34c b350 b354 b357
b35a b35f b362 b365 b368 b369 b36e b36f
1 b371 b376 b37a b37e b381 b386 b38b
b38e b392 b393 b398 b39b b3a0 b3a1 b3a6
b3a9 b3ae b3af b3b4 b3b7 b3bb b3bc b3c1
b3c4 b3c9 b3ca b3cf b3d2 b3d6 b3da b3dd
b3e0 b3e1 b3e3 b3e4 b3e9 b3ea b3ef b3f1
b3f5 b3f8 b3fa b3fe b400 b40c b40e b410
b411 b416 b41a b41c b428 b42a b42c b430
b434 b437 b439 b43d b441 b444 b446 b44a
b44d b451 b455 b459 b45d b461 b465 b468
b46b b46c b46e b471 b476 b477 b47c b480
b483 b487 b489 b48d b490 b492 b496 b49a
b49d b4a1 b4a5 b4a8 b4a9 b4ab b4ae b4b1
b4b2 b4b7 b4ba b4be b4c1 b4c2 b4c7 b4ca
1 b4cd b4d2 b4d6 b4da b4de b4e2 b4e6
b4ea b4ee b4fa b4fe b502 b505 b509 b50d
b50f b513 b517 b51b b51e b522 b526 b528
b529 b52e 1 b532 b536 b53a b53d b541
b545 b549 b54d b550 b554 b558 b55b b55e
b563 b566 b569 b56c b56d b572 b573 1
b575 b57a b57e b582 b585 b58a b58f b592
b596 b597 b59c b59f b5a4 b5a5 b5aa b5ad
b5b2 b5b3 b5b8 b5bb b5bf b5c0 b5c5 b5c8
b5cd b5ce b5d3 b5d6 b5da b5de b5e1 b5e4
b5e5 b5e7 b5e8 b5ed b5ee b5f3 b5f5 b5f9
b5fc b5fe b602 b604 b610 b612 b614 b615
b61a b61e b620 b62c b62e b632 b636 b639
b63d b640 b644 b647 b648 b64d b650 b654
b658 b65b b65c b65e b661 b664 b665 b66a
1 b66d b672 b676 b67a b67e b682 b686
b692 b696 b69b b69f b6a2 b6a3 b6a8 b6ac
b6b0 b6b3 b6b6 b6ba b6bc b6c0 b6c4 b6c7
b6ca b6ce b6d0 b6d4 b6d8 b6db b6dd b6e1
b6e5 b6e9 b6ec b6f0 b6f4 b6f6 b6f7 b6fc
1 b700 b704 b708 b70b b70f b713 b717
b71b b71e b722 b726 b729 b72c b731 b734
b737 b73a b73b b740 b741 1 b743 b748
b74c b750 b753 b758 b75d b760 b764 b765
b76a b76d b772 b773 b778 b77b b780 b781
b786 b789 b78d b78e b793 b796 b79b b79c
b7a1 b7a4 b7a8 b7ac b7af b7b2 b7b3 b7b5
b7b6 b7bb b7bc b7c1 b7c3 b7c7 b7ca b7cc
b7d0 b7d2 b7de b7e0 b7e2 b7e3 b7e8 b7ec
b7ee b7fa b7fc b800 b802 b806 b80a b80d
b811 b814 b818 b81b b81c b821 b824 b828
b82c b82f b830 b832 b835 b838 b839 b83e
1 b841 b846 b84a b84e b852 b855 b859
b85d b861 b865 b869 b86f b871 b875 b879
b87c b87e b882 b885 b889 b88c b890 b894
b898 b89c b8a0 b8a4 b8a8 b8ac b8b0 b8b4
b8b8 b8bc b8c0 b8c4 b8c8 b8cc b8d0 b8d4
b8d8 b8dc b8e0 b8e4 b8e8 b8ec b8f8 b8fc
b900 b903 b907 b90b b90d b911 b915 b919
b91c b920 b924 b926 b927 b92c 1 b930
b934 b938 b93b b93f b943 b947 b94b b94e
b952 b956 b959 b95c b961 b964 b967 b96a
b96b b970 b971 1 b973 b978 b97c b980
b983 b988 b98d b990 b994 b995 b99a b99d
b9a2 b9a3 b9a8 b9ab b9b0 b9b1 b9b6 b9b9
b9bd b9be b9c3 b9c6 b9cb b9cc b9d1 b9d4
b9d8 b9dc b9df b9e2 b9e3 b9e5 b9e6 b9eb
b9ec b9f1 b9f3 b9f7 b9fa b9fc ba00 ba02
ba0e ba10 ba12 ba13 ba18 ba1c ba1e ba2a
ba2c ba30 ba34 ba37 ba38 ba3a ba3d ba40
ba41 ba46 ba49 ba4a ba4f ba53 ba57 ba5b
ba5f ba63 ba67 ba6b ba6f ba73 ba77 ba7b
ba7f ba83 ba87 ba8b ba8f ba93 ba97 ba9b
ba9f baa3 baa7 baab baaf babb babf bac4
bac8 bacb bacc bad1 bad5 bad9 badc badf
bae3 bae5 bae9 baed baf0 baf3 baf7 baf9
bafd bb01 bb04 bb06 bb0a bb0e bb12 bb15
bb19 bb1d bb1f bb20 bb25 1 bb29 bb2d
bb31 bb34 bb38 bb3c bb40 bb44 bb47 bb4b
bb4f bb52 bb55 bb5a bb5d bb60 bb63 bb64
bb69 bb6a 1 bb6c bb71 bb75 bb79 bb7c
bb81 bb86 bb89 bb8d bb8e bb93 bb96 bb9b
bb9c bba1 bba4 bba9 bbaa bbaf bbb2 bbb6
bbb7 bbbc bbbf bbc4 bbc5 bbca bbcd bbd1
bbd5 bbd8 bbdb bbdc bbde bbdf bbe4 bbe5
bbea bbec bbf0 bbf3 bbf5 bbf9 bbfb bc07
bc09 bc0b bc0c bc11 bc15 bc17 bc23 bc25
bc27 bc2b bc2e bc32 bc36 bc39 bc3a bc3c
bc40 bc43 bc47 bc4a bc4b bc50 bc54 bc58
bc5c bc60 bc63 bc64 bc69 bc6c bc70 bc74
bc78 bc7c bc80 bc84 bc88 bc8c bc90 bc94
bc98 bc9c bca0 bca4 bca8 bcac bcb0 bcb4
bcb8 bcbc bcc0 bcc4 bcc8 bccc bcd0 bcd4
bcd8 bcdc bce0 bce4 bce8 bcec bcf8 bcfc
bd01 bd05 bd08 bd09 bd0e bd12 bd16 bd19
bd1c bd20 bd22 bd26 bd2a bd2d bd30 bd34
bd36 bd3a bd3e bd41 bd43 bd47 bd4b bd4f
bd52 bd56 bd5a bd5c bd5d bd62 1 bd66
bd6a bd6e bd71 bd75 bd79 bd7d bd81 bd84
bd88 bd8c bd8f bd92 bd97 bd9a bd9d bda0
bda1 bda6 bda7 1 bda9 bdae bdb2 bdb6
bdb9 bdbe bdc3 bdc6 bdca bdcb bdd0 bdd3
bdd8 bdd9 bdde bde1 bde6 bde7 bdec bdef
bdf3 bdf4 bdf9 bdfc be01 be02 be07 be0a
be0e be12 be15 be18 be19 be1b be1c be21
be22 be27 be29 be2d be30 be32 be36 be38
be44 be46 be48 be49 be4e be52 be54 be60
be62 be64 be68 be6b be6f be73 be78 be7d
be81 be85 be89 be8c be8f be93 be97 be9b
be9e be9f bea1 bea4 bea7 bea8 bead beb1
beb5 beb8 beb9 bebb bebe bec1 bec2 1
bec7 becc bed0 bed4 bed8 bedc bee0 bee4
bee8 beec bef0 bef4 bef8 befc bf00 bf04
bf08 bf0c bf18 bf1c bf21 bf25 bf28 bf29
bf2e bf32 bf36 bf39 bf3c bf40 bf42 bf46
bf4a bf4d bf50 bf54 bf56 bf5a bf5e bf61
bf63 bf67 bf6b bf6f bf72 bf76 bf7a bf7c
bf7d bf82 1 bf86 bf8a bf8e bf91 bf95
bf99 bf9d bfa1 bfa4 bfa8 bfac bfaf bfb2
bfb7 bfba bfbd bfc0 bfc1 bfc6 bfc7 1
bfc9 bfce bfd2 bfd6 bfd9 bfde bfe3 bfe6
bfea bfeb bff0 bff3 bff8 bff9 bffe c001
c006 c007 c00c c00f c013 c014 c019 c01c
c021 c022 c027 c02a c02e c032 c035 c038
c039 c03b c03c c041 c042 c047 c049 c04d
c050 c052 c056 c058 c064 c066 c068 c069
c06e c072 c074 c080 c082 c084 c088 c08c
c090 c094 c098 c09c c0a0 c0a4 c0a8 c0ac
c0b0 c0b4 c0b8 c0bc c0c0 c0c4 c0c8 c0cc
c0d0 c0d4 c0d8 c0dc c0e0 c0e4 c0e8 c0ec
c0f0 c0f4 c100 c104 c109 c10d c110 c111
c116 c11a c11e c121 c124 c128 c12a c12e
c132 c135 c138 c13c c13e c142 c146 c149
c14b c14f c153 c157 c15a c15e c162 c164
c165 c16a 1 c16e c172 c176 c179 c17d
c181 c185 c189 c18c c190 c194 c197 c19a
c19f c1a2 c1a5 c1a8 c1a9 c1ae c1af 1
c1b1 c1b6 c1ba c1be c1c1 c1c6 c1cb c1ce
c1d2 c1d3 c1d8 c1db c1e0 c1e1 c1e6 c1e9
c1ee c1ef c1f4 c1f7 c1fb c1fc c201 c204
c209 c20a c20f c212 c216 c21a c21d c220
c221 c223 c224 c229 c22a c22f c231 c235
c238 c23a c23e c240 c24c c24e c250 c251
c256 c25a c25c c268 c26a c26c c270 c274
c277 c27b c27f c282 c286 c289 c28d c290
c291 c296 c299 c29d c2a0 c2a4 c2a8 c2ac
c2b0 c2b4 c2b8 c2bc c2c0 c2cc c2d0 c2d4
c2d7 c2db c2df c2e1 c2e5 c2e9 c2ed c2f0
c2f4 c2f8 c2fa c2fb c300 1 c304 c308
c30c c30f c313 c317 c31b c31f c322 c326
c32a c32d c330 c335 c338 c33b c33e c33f
c344 c345 1 c347 c34c c350 c354 c357
c35c c361 c364 c368 c369 c36e c371 c376
c377 c37c c37f c384 c385 c38a c38d c391
c392 c397 c39a c39f c3a0 c3a5 c3a8 c3ac
c3b0 c3b3 c3b6 c3b7 c3b9 c3ba c3bf c3c0
c3c5 c3c7 c3cb c3ce c3d0 c3d4 c3d6 c3e2
c3e4 c3e6 c3e7 c3ec c3f0 c3f2 c3fe c400
c404 c408 c40b c40c c40e c411 c414 c415
c41a c41e c424 c426 c42a c42d c431 c435
c439 c43d c441 c44d c451 c456 c45a c45d
c45e c463 c467 c46b c46e c471 c475 c477
c47b c47f c482 c485 c489 c48b c48f c493
c496 c498 c49c c4a0 c4a4 c4a7 c4ab c4af
c4b1 c4b2 c4b7 1 c4bb c4bf c4c3 c4c6
c4ca c4ce c4d2 c4d6 c4d9 c4dd c4e1 c4e4
c4e7 c4ec c4ef c4f2 c4f5 c4f6 c4fb c4fc
1 c4fe c503 c507 c50b c50e c513 c518
c51b c51f c520 c525 c528 c52d c52e c533
c536 c53b c53c c541 c544 c548 c549 c54e
c551 c556 c557 c55c c55f c563 c567 c56a
c56d c56e c570 c571 c576 c577 c57c c57e
c582 c585 c587 c58b c58d c599 c59b c59d
c59e c5a3 c5a7 c5a9 c5b5 c5b7 c5bb c5bf
c5c3 c5c7 c5cb c5cc c5ce c5d1 c5d2 c5d4
c5d7 c5db c5df c5e3 c5e4 c5e6 c5e9 c5ea
c5ec c5ed c5f2 c5f5 c5f8 c5fb c5fc c601
c602 c604 c608 c60c c610 c614 c618 c61c
c620 c624 c628 c62c c638 c63c c640 c643
c647 c64b c64d c651 c655 c659 c65c c660
c664 c666 c667 c66c 1 c670 c674 c678
c67b c67f c683 c687 c68b c68e c692 c696
c699 c69c c6a1 c6a4 c6a7 c6aa c6ab c6b0
c6b1 1 c6b3 c6b8 c6bc c6c0 c6c3 c6c8
c6cd c6d0 c6d4 c6d5 c6da c6dd c6e2 c6e3
c6e8 c6eb c6f0 c6f1 c6f6 c6f9 c6fd c6fe
c703 c706 c70b c70c c711 c714 c718 c71c
c71f c722 c723 c725 c726 c72b c72c c731
c733 c737 c73a c73c c740 c742 c74e c750
c752 c753 c758 c75c c75e c76a c76c c770
c774 c777 c778 c77a c77e c781 c785 c788
c789 c78b c78c c791 c795 c799 c79c c7a0
c7a4 c7a7 c7a8 c7aa c7ae c7af c7b4 c7b6
c7ba c7bd c7c1 c7c5 c7c9 c7cd c7d1 c7d5
c7d9 c7dd c7e1 c7e5 c7e9 c7ed c7f1 c7f5
c7f9 c7fd c801 c805 c809 c80d c811 c815
c821 c825 c82a c82e c831 c832 c837 c83b
c83f c842 c845 c849 c84b c84f c853 c856
c859 c85d c85f c863 c867 c86a c86c c870
c874 c878 c87b c87f c883 c885 c886 c88b
1 c88f c893 c897 c89a c89e c8a2 c8a6
c8aa c8ad c8b1 c8b5 c8b8 c8bb c8c0 c8c3
c8c6 c8c9 c8ca c8cf c8d0 1 c8d2 c8d7
c8db c8df c8e2 c8e7 c8ec c8ef c8f3 c8f4
c8f9 c8fc c901 c902 c907 c90a c90f c910
c915 c918 c91c c91d c922 c925 c92a c92b
c930 c933 c937 c93b c93e c941 c942 c944
c945 c94a c94b c950 c952 c956 c959 c95b
c95f c961 c96d c96f c971 c972 c977 c97b
c97d c989 c98b c98f c993 c997 c99b c99f
c9a3 c9a7 c9ab c9af c9b3 c9b7 c9bb c9bf
c9c3 c9c7 c9cb c9cf c9d3 c9d7 c9db c9df
c9e3 c9e7 c9eb c9ef c9f3 c9f7 c9fb c9ff
ca03 ca07 ca0b ca0f ca13 ca17 ca1b ca1f
ca23 ca27 ca33 ca37 ca3c ca40 ca43 ca44
ca49 ca4d ca51 ca54 ca57 ca5b ca5d ca61
ca65 ca68 ca6b ca6f ca71 ca75 ca79 ca7c
ca7e ca82 ca86 ca8a ca8d ca91 ca95 ca97
ca98 ca9d 1 caa1 caa5 caa9 caac cab0
cab4 cab8 cabc cabf cac3 cac7 caca cacd
cad2 cad5 cad8 cadb cadc cae1 cae2 1
cae4 cae9 caed caf1 caf4 caf9 cafe cb01
cb05 cb06 cb0b cb0e cb13 cb14 cb19 cb1c
cb21 cb22 cb27 cb2a cb2e cb2f cb34 cb37
cb3c cb3d cb42 cb45 cb49 cb4d cb50 cb53
cb54 cb56 cb57 cb5c cb5d cb62 cb64 cb68
cb6b cb6d cb71 cb73 cb7f cb81 cb83 cb84
cb89 cb8d cb8f cb9b cb9d cba1 cba5 cba9
cbad cbb1 cbb2 cbb4 cbb7 cbb8 cbba cbbd
cbc1 cbc5 cbc9 cbca cbcc cbcf cbd0 cbd2
cbd3 cbd8 cbdb cbde cbe1 cbe2 cbe7 cbe8
cbea cbee cbf2 cbf6 cbfa cbfd cc01 cc05
cc08 cc09 cc0b cc0f cc13 cc16 cc17 cc19
cc1d cc21 cc25 cc29 cc2d cc31 cc35 cc39
cc3c cc3d cc3f cc43 cc47 cc4a cc4b cc4d
cc50 cc51 cc53 cc57 cc59 cc5d cc63 cc65
cc69 cc6d cc70 cc72 cc76 cc7a cc7e cc82
cc86 cc8a cc8e cc93 cc97 cc9b cc9f cca2
cca3 cca5 cca8 ccab ccac ccb1 ccb5 ccb9
ccbc ccbd ccbf ccc3 ccc6 ccca cccd ccce
ccd0 ccd1 ccd6 ccda ccde cce1 cce2 cce4
cce8 cceb ccef ccf2 ccf3 ccf5 ccf6 1
ccfb cd00 cd04 cd08 cd0b cd0f cd13 cd16
cd17 cd19 cd1c cd1f cd20 cd25 1 cd28
cd2d cd31 cd35 cd39 cd3c cd40 cd44 cd48
cd4c cd50 cd56 cd5a cd5c cd60 cd64 cd67
cd6b cd6f cd72 cd73 cd75 cd78 cd7b cd7c
cd81 cd85 cd89 cd8d cd91 cd95 cd99 cd9d
cda1 cda5 cdb1 cdb5 cdb9 cdbc cdc0 cdc4
cdc6 cdca cdce cdd2 cdd5 cdd9 cddd cddf
cde0 cde5 1 cde9 cded cdf1 cdf4 cdf8
cdfc ce00 ce04 ce07 ce0b ce0f ce12 ce15
ce1a ce1d ce20 ce23 ce24 ce29 ce2a 1
ce2c ce31 ce35 ce39 ce3c ce41 ce46 ce49
ce4d ce4e ce53 ce56 ce5b ce5c ce61 ce64
ce69 ce6a ce6f ce72 ce76 ce77 ce7c ce7f
ce84 ce85 ce8a ce8d ce91 ce95 ce98 ce9b
ce9c ce9e ce9f cea4 cea5 ceaa ceac ceb0
ceb3 ceb5 ceb9 cebb cec7 cec9 cecb cecc
ced1 ced5 ced7 cee3 cee5 cee9 ceed cef0
cef4 cef7 cefb cefe ceff cf04 cf07 cf0b
cf0f cf13 cf16 cf17 cf19 cf1c cf20 cf24
cf27 cf28 cf2a cf2b cf30 cf34 cf38 cf3c
cf40 cf44 cf48 cf4c cf50 cf5c cf60 cf65
cf69 cf6c cf6d cf72 cf76 cf7a cf7d cf80
cf84 cf86 cf8a cf8e cf91 cf94 cf98 cf9a
cf9e cfa2 cfa5 cfa7 cfab cfaf cfb3 cfb6
cfba cfbe cfc0 cfc1 cfc6 1 cfca cfce
cfd2 cfd5 cfd9 cfdd cfe1 cfe5 cfe8 cfec
cff0 cff3 cff6 cffb cffe d001 d004 d005
d00a d00b 1 d00d d012 d016 d01a d01d
d022 d027 d02a d02e d02f d034 d037 d03c
d03d d042 d045 d04a d04b d050 d053 d057
d058 d05d d060 d065 d066 d06b d06e d072
d076 d079 d07c d07d d07f d080 d085 d086
d08b d08d d091 d094 d096 d09a d09c d0a8
d0aa d0ac d0ad d0b2 d0b6 d0b8 d0c4 d0c6
d0c8 d0cc d0cf d0d1 d0d5 d0d9 d0dc d0de
d0e2 d0e5 d0e8 d0e9 d0ee d0f1 d0f2 d0f7
d0fb d0fe d0ff d104 1 d107 d10c d110
d114 d118 d11b d11f d121 d125 d128 d12c
d130 d133 d134 d136 d13a d13d d141 d144
d145 d147 d148 d14d d151 d155 d158 d159
d15b d15f d162 d166 d169 d16a d16c d16d
1 d172 d177 d17b d17e d182 d186 d18a
d18d d18e d190 d193 d196 d197 d19c d1a0
d1a3 d1a7 d1a9 d1ad d1b0 d1b2 d1b6 d1b9
d1bd d1c1 d1c5 d1c9 d1cd d1d1 d1d5 d1d9
d1dd d1e1 d1e5 d1e9 d1ed d1f1 d1f5 d1f9
d1fd d201 d205 d209 d20d d211 d215 d218
d219 d21b d21e d221 d222 d227 d22a d22e
d232 d235 d236 d238 d23b d23e d23f d244
1 d247 d24c d250 d253 d257 d25b d25d
d261 d265 d268 d269 d26b d26e d271 d272
d277 d27b d27f d283 d286 d287 d289 d28d
d28f d293 d297 d29a d29c d2a0 d2a4 d2a7
d2ab d2af d2b3 d2b7 d2bb d2bf d2c2 d2c3
d2c5 d2c9 d2cd d2d0 d2d1 d2d3 d2d7 d2db
d2de d2df d2e1 d2e5 d2e9 d2ec d2ed d2ef
d2f3 d2f7 d2fa d2fb d2fd d301 d305 d308
d309 d30b d30f d313 d316 d317 d319 d31d
d321 d324 d325 d327 d32b d32f d333 d334
d336 d33a d33e d342 d345 d346 d348 d34c
d34f d353 d356 d357 d35c d360 d364 d369
d36b d36f d373 d376 d37a d37e d380 d384
d388 d38c d38f d393 d397 d399 d39a d39f
1 d3a3 d3a7 d3ab d3ae d3b2 d3b6 d3ba
d3be d3c1 d3c5 d3c9 d3cc d3cf d3d4 d3d7
d3da d3dd d3de d3e3 d3e4 1 d3e6 d3eb
d3ef d3f3 d3f6 d3fb d400 d403 d407 d408
d40d d410 d415 d416 d41b d41e d423 d424
d429 d42c d430 d431 d436 d439 d43e d43f
d444 d447 d44b d44f d452 d455 d456 d458
d459 d45e d45f d464 d466 d46a d46d d46f
d473 d475 d481 d483 d485 d486 d48b d48f
d491 d49d d49f d4a3 d4a7 d4aa d4ae d4b2
d4b5 d4b8 d4bd d4c0 d4c3 d4c6 d4c7 d4cc
d4cd 1 d4cf d4d4 d4d8 d4dc d4df d4e4
d4e9 d4ec d4f0 d4f1 d4f6 d4f9 d4fe d4ff
d504 d507 d50c d50d d512 d515 d519 d51d
d521 d525 d528 d529 d52b d530 d531 d533
d534 d539 d53a d53f d541 d545 d548 d54c
d550 d553 d557 d55b d55e d561 d566 d569
d56c d56f d570 d575 d576 1 d578 d57d
d581 d585 d588 d58d d592 d595 d599 d59a
d59f d5a0 d5a5 d5a7 d5ab d5ae d5b2 d5b6
d5b9 d5bd d5c1 d5c4 d5c8 d5c9 d5ce d5d2
d5d4 d5d8 d5dc d5df d5e0 d5e2 d5e5 d5e8
d5e9 d5ee d5f2 d5f6 d5fa d5fd d5fe d600
d604 d608 d60c d610 d614 d61a d61c d620
d624 d627 d62b d62e d632 d636 d63a d63d
d63e d640 d643 d646 d647 d64c d650 d653
d657 d65b d65f d662 d663 d665 d668 d66b
d66c d671 d675 d679 d67d d680 d684 d686
d68a d68e d692 d695 d699 d69d d6a0 d6a1
d6a3 d6a7 d6ab d6ae d6af d6b1 d6b5 d6b7
d6bb d6bf d6c2 d6c6 d6c8 d6cc d6d0 d6d3
d6d4 d6d6 d6da d6dd d6e1 d6e4 d6e5 d6ea
d6ee d6f1 d6f5 d6f9 d6fd d700 d701 d703
d706 d709 d70a d70f d713 d717 d71b d71e
d722 d724 d728 d72c d730 d733 d737 d73b
d73e d73f d741 d745 d749 d74c d74d d74f
d753 d755 d759 d75d d760 d762 d766 d76a
d76d d771 d775 d779 d77c d77d d77f d782
d785 d786 d78b d78f d793 d797 d79a d79e
d7a0 d7a4 d7a8 d7ac d7af d7b3 d7b7 d7ba
d7bb d7bd d7c1 d7c5 d7c8 d7c9 d7cb d7cf
d7d1 d7d5 d7d9 d7dc d7de d7e2 d7e6 d7e9
d7ed d7f0 d7f4 d7f8 d7fc d800 d804 d808
d80c d810 d814 d818 d81c d820 d824 d828
d82c d830 d834 d838 d83c d840 d844 d848
d84c d850 d854 d858 d85c d860 d864 d868
d86c d86f d872 d875 d878 d87b d87e d87f
d881 d885 d889 d88c d88f d890 d895 d899
d89d d8a1 d8a4 d8a8 d8ac d8b0 d8b4 d8b8
d8be d8c2 d8c4 d8c8 d8cb d8ce d8cf d8d4
d8d8 d8dc d8e0 d8e3 d8e7 d8eb d8ef d8f3
d8f7 d8fd d8ff d903 d907 d90a d90b d910
d913 d917 d91b d91e d91f d921 d924 d927
d928 d92d d931 d935 d939 d93d d941 d945
d949 d94d d951 d955 d959 d95d d961 d965
d969 d975 d979 d97d d980 d984 d988 d98a
d98e d992 d996 d999 d99d d9a1 d9a3 d9a4
d9a9 1 d9ad d9b1 d9b5 d9b8 d9bc d9c0
d9c4 d9c8 d9cb d9cf d9d3 d9d6 d9d9 d9de
d9e1 d9e4 d9e7 d9e8 d9ed d9ee 1 d9f0
d9f5 d9f9 d9fd da00 da05 da0a da0d da11
da12 da17 da1a da1f da20 da25 da28 da2d
da2e da33 da36 da3a da3b da40 da43 da48
da49 da4e da51 da55 da59 da5c da5f da60
da62 da63 da68 da69 da6e da70 da74 da77
da79 da7d da7f da8b da8d da8f da90 da95
da99 da9b daa7 daa9 daab daaf dab3 dab7
dabb dabf dac3 dac7 dacb dacf dad3 dad7
dadb dadf dae3 dae7 daf3 daf7 dafb dafe
db02 db06 db08 db0c db10 db14 db17 db1b
db1f db21 db22 db27 1 db2b db2f db33
db36 db3a db3e db42 db46 db49 db4d db51
db54 db57 db5c db5f db62 db65 db66 db6b
db6c 1 db6e db73 db77 db7b db7e db83
db88 db8b db8f db90 db95 db98 db9d db9e
dba3 dba6 dbab dbac dbb1 dbb4 dbb8 dbb9
dbbe dbc1 dbc6 dbc7 dbcc dbcf dbd3 dbd7
dbda dbdd dbde dbe0 dbe1 dbe6 dbe7 dbec
dbee dbf2 dbf5 dbf7 dbfb dbfd dc09 dc0b
dc0d dc0e dc13 dc17 dc19 dc25 dc27 dc29
dc2d dc31 dc34 dc36 dc3a dc3e dc41 dc42
dc44 dc47 dc4a dc4b dc50 dc54 dc58 dc5c
dc60 dc64 dc70 dc74 dc79 dc7d dc80 dc81
dc86 dc8a dc8e dc91 dc94 dc98 dc9a dc9e
dca2 dca5 dca8 dcac dcae dcb2 dcb6 dcb9
dcbb dcbf dcc3 dcc7 dcca dcce dcd2 dcd4
dcd5 dcda 1 dcde dce2 dce6 dce9 dced
dcf1 dcf5 dcf9 dcfc dd00 dd04 dd07 dd0a
dd0f dd12 dd15 dd18 dd19 dd1e dd1f 1
dd21 dd26 dd2a dd2e dd31 dd36 dd3b dd3e
dd42 dd43 dd48 dd4b dd50 dd51 dd56 dd59
dd5e dd5f dd64 dd67 dd6b dd6c dd71 dd74
dd79 dd7a dd7f dd82 dd86 dd8a dd8d dd90
dd91 dd93 dd94 dd99 dd9a dd9f dda1 dda5
dda8 ddaa ddae ddb0 ddbc ddbe ddc0 ddc1
ddc6 ddca ddcc ddd8 ddda ddde dde1 dde5
dde9 dded ddf1 ddf5 ddf9 ddfd de01 de04
de05 de07 de0a de0d de0e de10 de14 de18
de1c de20 de24 de28 de2c de30 de3c de40
de44 de47 de4b de4f de51 de55 de59 de5d
de60 de64 de68 de6a de6b de70 1 de74
de78 de7c de7f de83 de87 de8b de8f de92
de96 de9a de9d dea0 dea5 dea8 deab deae
deaf deb4 deb5 1 deb7 debc dec0 dec4
dec7 decc ded1 ded4 ded8 ded9 dede dee1
dee6 dee7 deec deef def4 def5 defa defd
df01 df02 df07 df0a df0f df10 df15 df18
df1c df20 df23 df26 df27 df29 df2a df2f
df30 df35 df37 df3b df3e df40 df44 df46
df52 df54 df56 df57 df5c df60 df62 df6e
df70 df72 df76 df7a df7e df82 df86 df92
df96 df9b df9f dfa2 dfa3 dfa8 dfac dfb0
dfb3 dfb6 dfba dfbc dfc0 dfc4 dfc7 dfca
dfce dfd0 dfd4 dfd8 dfdb dfdd dfe1 dfe5
dfe9 dfec dff0 dff4 dff6 dff7 dffc 1
e000 e004 e008 e00b e00f e013 e017 e01b
e01e e022 e026 e029 e02c e031 e034 e037
e03a e03b e040 e041 1 e043 e048 e04c
e050 e053 e058 e05d e060 e064 e065 e06a
e06d e072 e073 e078 e07b e080 e081 e086
e089 e08d e08e e093 e096 e09b e09c e0a1
e0a4 e0a8 e0ac e0af e0b2 e0b3 e0b5 e0b6
e0bb e0bc e0c1 e0c3 e0c7 e0ca e0cc e0d0
e0d2 e0de e0e0 e0e2 e0e3 e0e8 e0ec e0ee
e0fa e0fc e100 e103 e107 e10b e10f e113
e117 e11b e11f e123 e126 e127 e129 e12c
e12f e130 e132 e136 e13a e13e e142 e146
e14a e14e e152 e15e e162 e166 e169 e16d
e171 e173 e177 e17b e17f e182 e186 e18a
e18c e18d e192 1 e196 e19a e19e e1a1
e1a5 e1a9 e1ad e1b1 e1b4 e1b8 e1bc e1bf
e1c2 e1c7 e1ca e1cd e1d0 e1d1 e1d6 e1d7
1 e1d9 e1de e1e2 e1e6 e1e9 e1ee e1f3
e1f6 e1fa e1fb e200 e203 e208 e209 e20e
e211 e216 e217 e21c e21f e223 e224 e229
e22c e231 e232 e237 e23a e23e e242 e245
e248 e249 e24b e24c e251 e252 e257 e259
e25d e260 e262 e266 e268 e274 e276 e278
e279 e27e e282 e284 e290 e292 e294 e298
e29c e29f e2a3 e2a7 e2aa e2ab e2ad e2b0
e2b3 e2b4 e2b9 e2bd e2c1 e2c5 e2c8 e2c9
e2cb e2ce e2d2 e2d6 e2d9 e2da e2dc e2dd
e2e2 e2e6 e2e8 e2ec e2ef e2f1 e2f5 e2f9
e2fc e300 e304 e307 e30b e30e e312 e315
e316 e31b e31e e322 e326 e32a e32d e331
e335 e339 e33d e341 e347 e349 e34d e350
e352 e356 e35a e35d e361 e365 e368 e369
e36b e36e e371 e372 e377 e37b e37f e383
e387 e38b e38f e393 e397 e39b e39f e3a3
e3a7 e3ab e3af e3b3 e3b7 e3bb e3bf e3c3
e3cf e3d3 e3d8 e3dc e3df e3e0 e3e5 e3e9
e3ed e3f0 e3f3 e3f7 e3f9 e3fd e401 e404
e407 e40b e40d e411 e415 e418 e41a e41e
e422 e426 e429 e42d e431 e433 e434 e439
1 e43d e441 e445 e448 e44c e450 e454
e458 e45b e45f e463 e466 e469 e46e e471
e474 e477 e478 e47d e47e 1 e480 e485
e489 e48d e490 e495 e49a e49d e4a1 e4a2
e4a7 e4aa e4af e4b0 e4b5 e4b8 e4bd e4be
e4c3 e4c6 e4ca e4cb e4d0 e4d3 e4d8 e4d9
e4de e4e1 e4e5 e4e9 e4ec e4ef e4f0 e4f2
e4f3 e4f8 e4f9 e4fe e500 e504 e507 e509
e50d e50f e51b e51d e51f e520 e525 e529
e52b e537 e539 e53b e53f e543 e547 e54b
e54f e553 e557 e55b e55f e563 e567 e56b
e56f e573 e577 e57b e57f e583 e587 e58b
e58f e593 e597 e59b e59f e5a3 e5a7 e5ab
e5af e5b3 e5b7 e5c3 e5c7 e5cc e5d0 e5d3
e5d4 e5d9 e5dd e5e1 e5e4 e5e7 e5eb e5ed
e5f1 e5f5 e5f8 e5fb e5ff e601 e605 e609
e60c e60e e612 e616 e61a e61d e621 e625
e627 e628 e62d 1 e631 e635 e639 e63c
e640 e644 e648 e64c e64f e653 e657 e65a
e65d e662 e665 e668 e66b e66c e671 e672
1 e674 e679 e67d e681 e684 e689 e68e
e691 e695 e696 e69b e69e e6a3 e6a4 e6a9
e6ac e6b1 e6b2 e6b7 e6ba e6be e6bf e6c4
e6c7 e6cc e6cd e6d2 e6d5 e6d9 e6dd e6e0
e6e3 e6e4 e6e6 e6e7 e6ec e6ed e6f2 e6f4
e6f8 e6fb e6fd e701 e703 e70f e711 e713
e714 e719 e71d e71f e72b e72d e72f e733
e737 e73a e73e e742 e745 e746 e748 e74c
e74f e753 e756 e757 e759 e75a e75f e763
e767 e76b e76f e773 e777 e77b e77f e783
e787 e78b e78e e78f e791 e795 e799 e79c
e79d e79f e7a2 e7a6 e7aa e7ad e7ae e7b0
e7b1 e7b3 e7b7 e7bb e7bf e7c3 e7c6 e7ca
e7ce e7d2 e7d6 e7da e7de e7e1 e7e2 e7e4
e7e8 e7ec e7f0 e7f3 e7f7 e7fb e7fd e801
e805 e809 e80d e811 e81d e821 e826 e82a
e82d e82e e833 e837 e83b e83e e841 e845
e847 e84b e84f e852 e855 e859 e85b e85f
e863 e866 e868 e86c e870 e874 e877 e87b
e87f e881 e882 e887 1 e88b e88f e893
e896 e89a e89e e8a2 e8a6 e8a9 e8ad e8b1
e8b4 e8b7 e8bc e8bf e8c2 e8c5 e8c6 e8cb
e8cc 1 e8ce e8d3 e8d7 e8db e8de e8e3
e8e8 e8eb e8ef e8f0 e8f5 e8f8 e8fd e8fe
e903 e906 e90b e90c e911 e914 e918 e919
e91e e921 e926 e927 e92c e92f e933 e937
e93a e93d e93e e940 e941 e946 e947 e94c
e94e e952 e955 e957 e95b e95d e969 e96b
e96d e96e e973 e977 e979 e985 e987 e98b
e98f e992 e993 e995 e998 e99b e99c e9a1
e9a5 e9a9 e9ad e9b9 e9bd e9c2 e9c6 e9c9
e9ca e9cf e9d3 e9d7 e9da e9dd e9e1 e9e3
e9e7 e9eb e9ee e9f1 e9f5 e9f7 e9fb e9ff
ea02 ea04 ea08 ea0c ea10 ea13 ea17 ea1b
ea1d ea1e ea23 1 ea27 ea2b ea2f ea32
ea36 ea3a ea3e ea42 ea45 ea49 ea4d ea50
ea53 ea58 ea5b ea5e ea61 ea62 ea67 ea68
1 ea6a ea6f ea73 ea77 ea7a ea7f ea84
ea87 ea8b ea8c ea91 ea94 ea99 ea9a ea9f
eaa2 eaa7 eaa8 eaad eab0 eab4 eab5 eaba
eabd eac2 eac3 eac8 eacb eacf ead3 ead6
ead9 eada eadc eadd eae2 eae3 eae8 eaea
eaee eaf1 eaf3 eaf7 eaf9 eb05 eb07 eb09
eb0a eb0f eb13 eb15 eb21 eb23 eb27 eb2b
eb2f eb32 eb36 eb3a eb3e eb42 eb45 eb46
eb48 eb4c eb50 eb54 eb57 eb5b eb5f eb63
eb67 eb6b eb77 eb7b eb80 eb84 eb87 eb88
eb8d eb91 eb95 eb98 eb9b eb9f eba1 eba5
eba9 ebac ebaf ebb3 ebb5 ebb9 ebbd ebc0
ebc2 ebc6 ebca ebce ebd1 ebd5 ebd9 ebdb
ebdc ebe1 1 ebe5 ebe9 ebed ebf0 ebf4
ebf8 ebfc ec00 ec03 ec07 ec0b ec0e ec11
ec16 ec19 ec1c ec1f ec20 ec25 ec26 1
ec28 ec2d ec31 ec35 ec38 ec3d ec42 ec45
ec49 ec4a ec4f ec52 ec57 ec58 ec5d ec60
ec65 ec66 ec6b ec6e ec72 ec73 ec78 ec7b
ec80 ec81 ec86 ec89 ec8d ec91 ec94 ec97
ec98 ec9a ec9b eca0 eca1 eca6 eca8 ecac
ecaf ecb1 ecb5 ecb7 ecc3 ecc5 ecc7 ecc8
eccd ecd1 ecd3 ecdf ece1 ece3 ece7 eceb
ecef ecf3 ecf7 ecfb ecff ed03 ed07 ed0b
ed0f ed13 ed17 ed1b ed1f ed23 ed27 ed2b
ed2f ed33 ed37 ed43 ed47 ed4c ed50 ed53
ed54 ed59 ed5d ed61 ed64 ed67 ed6b ed6d
ed71 ed75 ed78 ed7b ed7f ed81 ed85 ed89
ed8c ed8e ed92 ed96 ed9a ed9d eda1 eda5
eda7 eda8 edad 1 edb1 edb5 edb9 edbc
edc0 edc4 edc8 edcc edcf edd3 edd7 edda
eddd ede2 ede5 ede8 edeb edec edf1 edf2
1 edf4 edf9 edfd ee01 ee04 ee09 ee0e
ee11 ee15 ee16 ee1b ee1e ee23 ee24 ee29
ee2c ee31 ee32 ee37 ee3a ee3e ee3f ee44
ee47 ee4c ee4d ee52 ee55 ee59 ee5d ee60
ee63 ee64 ee66 ee67 ee6c ee6d ee72 ee74
ee78 ee7b ee7d ee81 ee83 ee8f ee91 ee93
ee94 ee99 ee9d ee9f eeab eead eeaf eeb3
eeb7 eeba eebc eec0 eec4 eec7 eecb eece
eed2 eed6 eeda eede eee2 eee6 eeea eeee
eef1 eef2 eef4 eef7 eefa eefb eefd ef01
ef03 ef07 ef0b ef0e ef12 ef16 ef19 ef1a
ef1c ef1f ef22 ef23 ef28 ef2b ef2c ef31
ef35 ef39 ef3d ef41 ef45 ef49 ef4d ef51
ef55 ef59 ef5d ef61 ef65 ef69 ef6d ef71
ef75 ef79 ef7d ef81 ef85 ef89 ef8d ef91
ef9d efa1 efa6 efaa efad efae efb3 efb7
efbb efbe efc1 efc5 efc7 efcb efcf efd2
efd5 efd9 efdb efdf efe3 efe6 efe8 efec
eff0 eff4 eff7 effb efff f001 f002 f007
1 f00b f00f f013 f016 f01a f01e f022
f026 f029 f02d f031 f034 f037 f03c f03f
f042 f045 f046 f04b f04c 1 f04e f053
f057 f05b f05e f063 f068 f06b f06f f070
f075 f078 f07d f07e f083 f086 f08b f08c
f091 f094 f098 f099 f09e f0a1 f0a6 f0a7
f0ac f0af f0b3 f0b7 f0ba f0bd f0be f0c0
f0c1 f0c6 f0c7 f0cc f0ce f0d2 f0d5 f0d7
f0db f0dd f0e9 f0eb f0ed f0ee f0f3 f0f7
f0f9 f105 f107 f10b f10f f113 f117 f11b
f11f f123 f127 f12b f12f f133 f13f f143
f148 f14c f14f f150 f155 f159 f15d f160
f163 f167 f169 f16d f171 f174 f177 f17b
f17d f181 f185 f188 f18a f18e f192 f196
f199 f19d f1a1 f1a3 f1a4 f1a9 1 f1ad
f1b1 f1b5 f1b8 f1bc f1c0 f1c4 f1c8 f1cb
f1cf f1d3 f1d6 f1d9 f1de f1e1 f1e4 f1e7
f1e8 f1ed f1ee 1 f1f0 f1f5 f1f9 f1fd
f200 f205 f20a f20d f211 f212 f217 f21a
f21f f220 f225 f228 f22d f22e f233 f236
f23a f23b f240 f243 f248 f249 f24e f251
f255 f259 f25c f25f f260 f262 f263 f268
f269 f26e f270 f274 f277 f279 f27d f27f
f28b f28d f28f f290 f295 f299 f29b f2a7
f2a9 f2ad f2b1 f2b5 f2b9 f2bd f2c1 f2c5
f2c9 f2cd f2d1 f2d5 f2e1 f2e5 f2ea f2ee
f2f1 f2f2 f2f7 f2fb f2ff f302 f305 f309
f30b f30f f313 f316 f319 f31d f31f f323
f327 f32a f32c f330 f334 f338 f33b f33f
f343 f345 f346 f34b 1 f34f f353 f357
f35a f35e f362 f366 f36a f36d f371 f375
f378 f37b f380 f383 f386 f389 f38a f38f
f390 1 f392 f397 f39b f39f f3a2 f3a7
f3ac f3af f3b3 f3b4 f3b9 f3bc f3c1 f3c2
f3c7 f3ca f3cf f3d0 f3d5 f3d8 f3dc f3dd
f3e2 f3e5 f3ea f3eb f3f0 f3f3 f3f7 f3fb
f3fe f401 f402 f404 f405 f40a f40b f410
f412 f416 f419 f41b f41f f421 f42d f42f
f431 f432 f437 f43b f43d f449 f44b f44d
f451 f454 f456 f45a f45d f45f f463 f467
f46b f46e f46f f471 f475 f479 f47d f480
f481 f483 f486 f489 f48a f48f f493 f497
f49b f49e f49f f4a1 f4a5 f4a9 f4ad f4b1
f4bd f4c1 f4c6 f4ca f4cd f4ce f4d3 f4d7
f4db f4de f4e1 f4e5 f4e7 f4eb f4ef f4f2
f4f5 f4f9 f4fb f4ff f503 f506 f508 f50c
f510 f514 f517 f51b f51f f521 f522 f527
1 f52b f52f f533 f536 f53a f53e f542
f546 f549 f54d f551 f554 f557 f55c f55f
f562 f565 f566 f56b f56c 1 f56e f573
f577 f57b f57e f583 f588 f58b f58f f590
f595 f598 f59d f59e f5a3 f5a6 f5ab f5ac
f5b1 f5b4 f5b8 f5b9 f5be f5c1 f5c6 f5c7
f5cc f5cf f5d3 f5d7 f5da f5dd f5de f5e0
f5e1 f5e6 f5e7 f5ec f5ee f5f2 f5f5 f5f7
f5fb f5fd f609 f60b f60d f60e f613 f617
f619 f625 f627 f62b f62f f633 f63f f643
f648 f64c f64f f650 f655 f659 f65d f660
f663 f667 f669 f66d f671 f674 f677 f67b
f67d f681 f685 f688 f68a f68e f692 f696
f699 f69d f6a1 f6a3 f6a4 f6a9 1 f6ad
f6b1 f6b5 f6b8 f6bc f6c0 f6c4 f6c8 f6cb
f6cf f6d3 f6d6 f6d9 f6de f6e1 f6e4 f6e7
f6e8 f6ed f6ee 1 f6f0 f6f5 f6f9 f6fd
f700 f705 f70a f70d f711 f712 f717 f71a
f71f f720 f725 f728 f72d f72e f733 f736
f73a f73b f740 f743 f748 f749 f74e f751
f755 f759 f75c f75f f760 f762 f763 f768
f769 f76e f770 f774 f777 f779 f77d f77f
f78b f78d f78f f790 f795 f799 f79b f7a7
f7a9 f7ad f7b1 f7b5 f7c1 f7c5 f7ca f7ce
f7d1 f7d2 f7d7 f7db f7df f7e2 f7e5 f7e9
f7eb f7ef f7f3 f7f6 f7f9 f7fd f7ff f803
f807 f80a f80c f810 f814 f818 f81b f81f
f823 f825 f826 f82b 1 f82f f833 f837
f83a f83e f842 f846 f84a f84d f851 f855
f858 f85b f860 f863 f866 f869 f86a f86f
f870 1 f872 f877 f87b f87f f882 f887
f88c f88f f893 f894 f899 f89c f8a1 f8a2
f8a7 f8aa f8af f8b0 f8b5 f8b8 f8bc f8bd
f8c2 f8c5 f8ca f8cb f8d0 f8d3 f8d7 f8db
f8de f8e1 f8e2 f8e4 f8e5 f8ea f8eb f8f0
f8f2 f8f6 f8f9 f8fb f8ff f901 f90d f90f
f911 f912 f917 f91b f91d f929 f92b f92f
f933 f937 f93b f93f f94b f94f f954 f958
f95b f95c f961 f965 f969 f96c f96f f973
f975 f979 f97d f980 f983 f987 f989 f98d
f991 f994 f996 f99a f99e f9a2 f9a5 f9a9
f9ad f9af f9b0 f9b5 1 f9b9 f9bd f9c1
f9c4 f9c8 f9cc f9d0 f9d4 f9d7 f9db f9df
f9e2 f9e5 f9ea f9ed f9f0 f9f3 f9f4 f9f9
f9fa 1 f9fc fa01 fa05 fa09 fa0c fa11
fa16 fa19 fa1d fa1e fa23 fa26 fa2b fa2c
fa31 fa34 fa39 fa3a fa3f fa42 fa46 fa47
fa4c fa4f fa54 fa55 fa5a fa5d fa61 fa65
fa68 fa6b fa6c fa6e fa6f fa74 fa75 fa7a
fa7c fa80 fa83 fa85 fa89 fa8b fa97 fa99
fa9b fa9c faa1 faa5 faa7 fab3 fab5 fab9
fabd fac1 facd fad1 fad6 fada fadd fade
fae3 fae7 faeb faee faf1 faf5 faf7 fafb
faff fb02 fb05 fb09 fb0b fb0f fb13 fb16
fb18 fb1c fb20 fb24 fb27 fb2b fb2f fb31
fb32 fb37 1 fb3b fb3f fb43 fb46 fb4a
fb4e fb52 fb56 fb59 fb5d fb61 fb64 fb67
fb6c fb6f fb72 fb75 fb76 fb7b fb7c 1
fb7e fb83 fb87 fb8b fb8e fb93 fb98 fb9b
fb9f fba0 fba5 fba8 fbad fbae fbb3 fbb6
fbbb fbbc fbc1 fbc4 fbc8 fbc9 fbce fbd1
fbd6 fbd7 fbdc fbdf fbe3 fbe7 fbea fbed
fbee fbf0 fbf1 fbf6 fbf7 fbfc fbfe fc02
fc05 fc07 fc0b fc0d fc19 fc1b fc1d fc1e
fc23 fc27 fc29 fc35 fc37 fc3b fc3f fc43
fc4f fc53 fc58 fc5c fc5f fc60 fc65 fc69
fc6d fc70 fc73 fc77 fc79 fc7d fc81 fc84
fc87 fc8b fc8d fc91 fc95 fc98 fc9a fc9e
fca2 fca6 fca9 fcad fcb1 fcb3 fcb4 fcb9
1 fcbd fcc1 fcc5 fcc8 fccc fcd0 fcd4
fcd8 fcdb fcdf fce3 fce6 fce9 fcee fcf1
fcf4 fcf7 fcf8 fcfd fcfe 1 fd00 fd05
fd09 fd0d fd10 fd15 fd1a fd1d fd21 fd22
fd27 fd2a fd2f fd30 fd35 fd38 fd3d fd3e
fd43 fd46 fd4a fd4b fd50 fd53 fd58 fd59
fd5e fd61 fd65 fd69 fd6c fd6f fd70 fd72
fd73 fd78 fd79 fd7e fd80 fd84 fd87 fd89
fd8d fd8f fd9b fd9d fd9f fda0 fda5 fda9
fdab fdb7 fdb9 fdbb fdbf fdc3 fdc6 fdc7
fdc9 fdcc fdcf fdd0 fdd5 fdd9 fddd fde1
fde3 fde7 fdea fdee fdf2 fdf6 fdfa fdfe
fe02 fe06 fe0a fe0e fe1a fe1e fe23 fe27
fe2a fe2b fe30 fe34 fe38 fe3b fe3e fe42
fe44 fe48 fe4c fe4f fe52 fe56 fe58 fe5c
fe60 fe63 fe65 fe69 fe6d fe71 fe74 fe78
fe7c fe7e fe7f fe84 1 fe88 fe8c fe90
fe93 fe97 fe9b fe9f fea3 fea6 feaa feae
feb1 feb4 feb9 febc febf fec2 fec3 fec8
fec9 1 fecb fed0 fed4 fed8 fedb fee0
fee5 fee8 feec feed fef2 fef5 fefa fefb
ff00 ff03 ff08 ff09 ff0e ff11 ff15 ff16
ff1b ff1e ff23 ff24 ff29 ff2c ff30 ff34
ff37 ff3a ff3b ff3d ff3e ff43 ff44 ff49
ff4b ff4f ff52 ff54 ff58 ff5a ff66 ff68
ff6a ff6b ff70 ff74 ff76 ff82 ff84 ff88
ff8c ff90 ff94 ff98 ff9c ffa0 ffa4 ffa8
ffac ffb0 ffb4 ffc0 ffc4 ffc8 ffcb ffcf
ffd3 ffd5 ffd9 ffdd ffe1 ffe4 ffe8 ffec
ffee ffef fff4 1 fff8 fffc 10000 10003
10007 1000b 1000f 10013 10016 1001a 1001e 10021
10024 10029 1002c 1002f 10032 10033 10038 10039
1 1003b 10040 10044 10048 1004b 10050 10055
10058 1005c 1005d 10062 10065 1006a 1006b 10070
10073 10078 10079 1007e 10081 10085 10086 1008b
1008e 10093 10094 10099 1009c 100a0 100a4 100a7
100aa 100ab 100ad 100ae 100b3 100b4 100b9 100bb
100bf 100c2 100c4 100c8 100ca 100d6 100d8 100da
100db 100e0 100e4 100e6 100f2 100f4 100f8 100fc
100ff 10103 10106 1010a 1010d 1010e 10113 10116
1011a 1011d 10121 10125 10129 1012d 10131 10135
10139 1013d 10141 10145 10149 1014d 10151 1015d
10161 10165 10168 1016c 10170 10172 10176 1017a
1017e 10181 10185 10189 1018b 1018c 10191 1
10195 10199 1019d 101a0 101a4 101a8 101ac 101b0
101b3 101b7 101bb 101be 101c1 101c6 101c9 101cc
101cf 101d0 101d5 101d6 1 101d8 101dd 101e1
101e5 101e8 101ed 101f2 101f5 101f9 101fa 101ff
10202 10207 10208 1020d 10210 10215 10216 1021b
1021e 10222 10223 10228 1022b 10230 10231 10236
10239 1023d 10241 10244 10247 10248 1024a 1024b
10250 10251 10256 10258 1025c 1025f 10261 10265
10267 10273 10275 10277 10278 1027d 10281 10283
1028f 10291 10295 10299 1029c 102a0 102a3 102a7
102aa 102ab 102b0 102b3 102b7 102bb 102bf 102c2
102c3 102c5 102c9 102cd 102d0 102d1 102d3 102d6
102da 102dd 102e1 102e4 102e5 102ea 102ee 102f1
102f5 102f9 102fd 10301 10305 10309 1030d 10311
10315 10321 10325 1032a 1032e 10331 10332 10337
1033b 1033f 10342 10345 10349 1034b 1034f 10353
10356 10359 1035d 1035f 10363 10367 1036a 1036c
10370 10374 10378 1037b 1037f 10383 10385 10386
1038b 1 1038f 10393 10397 1039a 1039e 103a2
103a6 103aa 103ad 103b1 103b5 103b8 103bb 103c0
103c3 103c6 103c9 103ca 103cf 103d0 1 103d2
103d7 103db 103df 103e2 103e7 103ec 103ef 103f3
103f4 103f9 103fc 10401 10402 10407 1040a 1040f
10410 10415 10418 1041c 1041d 10422 10425 1042a
1042b 10430 10433 10437 1043b 1043e 10441 10442
10444 10445 1044a 1044b 10450 10452 10456 10459
1045b 1045f 10461 1046d 1046f 10471 10472 10477
1047b 1047d 10489 1048b 1048f 10491 10495 10499
1049c 1049d 1049f 104a3 104a6 104aa 104ad 104ae
104b3 104b7 104bb 104be 104c2 104c6 104c9 104ca
104cc 104d0 104d4 104d7 104db 104dc 104de 104e2
104e6 104ea 104ee 104f2 104f6 104fa 104fe 10502
10506 1050a 1050e 10512 10516 10522 10526 1052b
1052f 10532 10533 10538 1053c 10540 10543 10546
1054a 1054c 10550 10554 10557 1055a 1055e 10560
10564 10568 1056b 1056d 10571 10575 10579 1057c
10580 10584 10586 10587 1058c 1 10590 10594
10598 1059b 1059f 105a3 105a7 105ab 105ae 105b2
105b6 105b9 105bc 105c1 105c4 105c7 105ca 105cb
105d0 105d1 1 105d3 105d8 105dc 105e0 105e3
105e8 105ed 105f0 105f4 105f5 105fa 105fd 10602
10603 10608 1060b 10610 10611 10616 10619 1061d
1061e 10623 10626 1062b 1062c 10631 10634 10638
1063c 1063f 10642 10643 10645 10646 1064b 1064c
10651 10653 10657 1065a 1065c 10660 10662 1066e
10670 10672 10673 10678 1067c 1067e 1068a 1068c
1068e 10692 10696 1069a 1069e 106a2 106a6 106aa
106ae 106b2 106b6 106ba 106be 106c2 106c6 106ca
106ce 106d2 106de 106e2 106e7 106eb 106ee 106ef
106f4 106f8 106fc 106ff 10702 10706 10708 1070c
10710 10713 10716 1071a 1071c 10720 10724 10727
10729 1072d 10731 10735 10738 1073c 10740 10742
10743 10748 1 1074c 10750 10754 10757 1075b
1075f 10763 10767 1076a 1076e 10772 10775 10778
1077d 10780 10783 10786 10787 1078c 1078d 1
1078f 10794 10798 1079c 1079f 107a4 107a9 107ac
107b0 107b1 107b6 107b9 107be 107bf 107c4 107c7
107cc 107cd 107d2 107d5 107d9 107da 107df 107e2
107e7 107e8 107ed 107f0 107f4 107f8 107fb 107fe
107ff 10801 10802 10807 10808 1080d 1080f 10813
10816 10818 1081c 1081e 1082a 1082c 1082e 1082f
10834 10838 1083a 10846 10848 1084a 1084e 10852
10855 10859 1085d 10860 10864 10867 1086b 1086e
1086f 10874 10877 1087b 1087f 10882 10883 10885
10888 1088b 1088c 10891 1 10894 10899 1089d
108a1 108a5 108b1 108b5 108ba 108be 108c1 108c2
108c7 108cb 108cf 108d2 108d5 108d9 108db 108df
108e3 108e6 108e9 108ed 108ef 108f3 108f7 108fa
108fc 10900 10904 10908 1090b 1090f 10913 10915
10916 1091b 1 1091f 10923 10927 1092a 1092e
10932 10936 1093a 1093d 10941 10945 10948 1094b
10950 10953 10956 10959 1095a 1095f 10960 1
10962 10967 1096b 1096f 10972 10977 1097c 1097f
10983 10984 10989 1098c 10991 10992 10997 1099a
1099f 109a0 109a5 109a8 109ac 109ad 109b2 109b5
109ba 109bb 109c0 109c3 109c7 109cb 109ce 109d1
109d2 109d4 109d5 109da 109db 109e0 109e2 109e6
109e9 109eb 109ef 109f1 109fd 109ff 10a01 10a02
10a07 10a0b 10a0d 10a19 10a1b 10a1d 10a21 10a24
10a26 10a2a 10a2e 10a32 10a36 10a3a 10a3e 10a42
10a46 10a4a 10a4e 10a52 10a56 10a5a 10a5e 10a62
10a66 10a6a 10a6e 10a72 10a76 10a7a 10a7e 10a82
10a86 10a8a 10a8e 10a92 10a96 10a9a 10a9e 10aa2
10aa6 10aaa 10aae 10aba 10abe 10ac2 10ac5 10ac9
10acd 10acf 10ad3 10ad7 10adb 10ade 10ae2 10ae6
10ae8 10ae9 10aee 1 10af2 10af6 10afa 10afd
10b01 10b05 10b09 10b0d 10b10 10b14 10b18 10b1b
10b1e 10b23 10b26 10b29 10b2c 10b2d 10b32 10b33
1 10b35 10b3a 10b3e 10b42 10b45 10b4a 10b4f
10b52 10b56 10b57 10b5c 10b5f 10b64 10b65 10b6a
10b6d 10b72 10b73 10b78 10b7b 10b7f 10b80 10b85
10b88 10b8d 10b8e 10b93 10b96 10b9a 10b9e 10ba1
10ba4 10ba5 10ba7 10ba8 10bad 10bae 10bb3 10bb5
10bb9 10bbc 10bbe 10bc2 10bc4 10bd0 10bd2 10bd4
10bd5 10bda 10bde 10be0 10bec 10bee 10bf2 10bf6
10bf9 10bfd 10c00 10c04 10c07 10c08 10c0d 10c10
10c14 10c17 10c18 10c1d 10c20 1 10c23 10c28
10c2c 10c30 10c33 10c37 10c3b 10c3e 10c3f 10c41
10c45 10c49 10c4c 10c50 10c51 10c53 10c57 10c5b
10c5f 10c63 10c6f 10c73 10c78 10c7c 10c7f 10c80
10c85 10c89 10c8d 10c90 10c93 10c97 10c99 10c9d
10ca1 10ca4 10ca7 10cab 10cad 10cb1 10cb5 10cb8
10cba 10cbe 10cc2 10cc6 10cc9 10ccd 10cd1 10cd3
10cd4 10cd9 1 10cdd 10ce1 10ce5 10ce8 10cec
10cf0 10cf4 10cf8 10cfb 10cff 10d03 10d06 10d09
10d0e 10d11 10d14 10d17 10d18 10d1d 10d1e 1
10d20 10d25 10d29 10d2d 10d30 10d35 10d3a 10d3d
10d41 10d42 10d47 10d4a 10d4f 10d50 10d55 10d58
10d5d 10d5e 10d63 10d66 10d6a 10d6b 10d70 10d73
10d78 10d79 10d7e 10d81 10d85 10d89 10d8c 10d8f
10d90 10d92 10d93 10d98 10d99 10d9e 10da0 10da4
10da7 10da9 10dad 10daf 10dbb 10dbd 10dbf 10dc0
10dc5 10dc9 10dcb 10dd7 10dd9 10ddd 10de1 10de5
10de9 10ded 10df1 10df5 10df9 10dfd 10e01 10e05
10e11 10e15 10e1a 10e1e 10e21 10e22 10e27 10e2b
10e2f 10e32 10e35 10e39 10e3b 10e3f 10e43 10e46
10e49 10e4d 10e4f 10e53 10e57 10e5a 10e5c 10e60
10e64 10e68 10e6b 10e6f 10e73 10e75 10e76 10e7b
1 10e7f 10e83 10e87 10e8a 10e8e 10e92 10e96
10e9a 10e9d 10ea1 10ea5 10ea8 10eab 10eb0 10eb3
10eb6 10eb9 10eba 10ebf 10ec0 1 10ec2 10ec7
10ecb 10ecf 10ed2 10ed7 10edc 10edf 10ee3 10ee4
10ee9 10eec 10ef1 10ef2 10ef7 10efa 10eff 10f00
10f05 10f08 10f0c 10f0d 10f12 10f15 10f1a 10f1b
10f20 10f23 10f27 10f2b 10f2e 10f31 10f32 10f34
10f35 10f3a 10f3b 10f40 10f42 10f46 10f49 10f4b
10f4f 10f51 10f5d 10f5f 10f61 10f62 10f67 10f6b
10f6d 10f79 10f7b 10f7f 10f83 10f87 10f8b 10f8f
10f93 10f97 10f9b 10fa7 10fab 10fb0 10fb4 10fb7
10fb8 10fbd 10fc1 10fc5 10fc8 10fcb 10fcf 10fd1
10fd5 10fd9 10fdc 10fdf 10fe3 10fe5 10fe9 10fed
10ff0 10ff2 10ff6 10ffa 10ffe 11001 11005 11009
1100b 1100c 11011 1 11015 11019 1101d 11020
11024 11028 1102c 11030 11033 11037 1103b 1103e
11041 11046 11049 1104c 1104f 11050 11055 11056
1 11058 1105d 11061 11065 11068 1106d 11072
11075 11079 1107a 1107f 11082 11087 11088 1108d
11090 11095 11096 1109b 1109e 110a2 110a3 110a8
110ab 110b0 110b1 110b6 110b9 110bd 110c1 110c4
110c7 110c8 110ca 110cb 110d0 110d1 110d6 110d8
110dc 110df 110e1 110e5 110e7 110f3 110f5 110f7
110f8 110fd 11101 11103 1110f 11111 11113 11117
1111b 1111f 11123 11127 1112b 1112f 11133 11137
1113b 1113f 1114b 1114f 11154 11158 1115b 1115c
11161 11165 11169 1116c 1116f 11173 11175 11179
1117d 11180 11183 11187 11189 1118d 11191 11194
11196 1119a 1119e 111a2 111a5 111a9 111ad 111af
111b0 111b5 1 111b9 111bd 111c1 111c4 111c8
111cc 111d0 111d4 111d7 111db 111df 111e2 111e5
111ea 111ed 111f0 111f3 111f4 111f9 111fa 1
111fc 11201 11205 11209 1120c 11211 11216 11219
1121d 1121e 11223 11226 1122b 1122c 11231 11234
11239 1123a 1123f 11242 11246 11247 1124c 1124f
11254 11255 1125a 1125d 11261 11265 11268 1126b
1126c 1126e 1126f 11274 11275 1127a 1127c 11280
11283 11285 11289 1128b 11297 11299 1129b 1129c
112a1 112a5 112a7 112b3 112b5 112b9 112bd 112c1
112c5 112c9 112cd 112d9 112dd 112e2 112e6 112e9
112ea 112ef 112f3 112f7 112fa 112fd 11301 11303
11307 1130b 1130e 11311 11315 11317 1131b 1131f
11322 11324 11328 1132c 11330 11333 11337 1133b
1133d 1133e 11343 1 11347 1134b 1134f 11352
11356 1135a 1135e 11362 11365 11369 1136d 11370
11373 11378 1137b 1137e 11381 11382 11387 11388
1 1138a 1138f 11393 11397 1139a 1139f 113a4
113a7 113ab 113ac 113b1 113b4 113b9 113ba 113bf
113c2 113c7 113c8 113cd 113d0 113d4 113d5 113da
113dd 113e2 113e3 113e8 113eb 113ef 113f3 113f6
113f9 113fa 113fc 113fd 11402 11403 11408 1140a
1140e 11411 11413 11417 11419 11425 11427 11429
1142a 1142f 11433 11435 11441 11443 11445 11449
1144d 11450 11452 11456 1145a 1145d 11461 11465
11468 11469 1146b 1146f 11472 11476 11479 1147a
1147f 11483 11487 1148a 1148b 1148d 11491 11494
11498 1149b 1149c 1 114a1 114a6 114aa 114ae
114b2 114b6 114ba 114c6 114ca 114cf 114d3 114d6
114d7 114dc 114e0 114e4 114e7 114ea 114ee 114f0
114f4 114f8 114fb 114fe 11502 11504 11508 1150c
1150f 11511 11515 11519 1151d 11520 11524 11528
1152a 1152b 11530 1 11534 11538 1153c 1153f
11543 11547 1154b 1154f 11552 11556 1155a 1155d
11560 11565 11568 1156b 1156e 1156f 11574 11575
1 11577 1157c 11580 11584 11587 1158c 11591
11594 11598 11599 1159e 115a1 115a6 115a7 115ac
115af 115b4 115b5 115ba 115bd 115c1 115c2 115c7
115ca 115cf 115d0 115d5 115d8 115dc 115e0 115e3
115e6 115e7 115e9 115ea 115ef 115f0 115f5 115f7
115fb 115fe 11600 11604 11606 11612 11614 11616
11617 1161c 11620 11622 1162e 11630 11632 11636
11639 1163b 1163f 11642 11646 1164a 1164e 11652
1165e 11662 11667 1166b 1166e 1166f 11674 11678
1167c 1167f 11682 11686 11688 1168c 11690 11693
11696 1169a 1169c 116a0 116a4 116a7 116a9 116ad
116b1 116b5 116b8 116bc 116c0 116c2 116c3 116c8
1 116cc 116d0 116d4 116d7 116db 116df 116e3
116e7 116ea 116ee 116f2 116f5 116f8 116fd 11700
11703 11706 11707 1170c 1170d 1 1170f 11714
11718 1171c 1171f 11724 11729 1172c 11730 11731
11736 11739 1173e 1173f 11744 11747 1174c 1174d
11752 11755 11759 1175a 1175f 11762 11767 11768
1176d 11770 11774 11778 1177b 1177e 1177f 11781
11782 11787 11788 1178d 1178f 11793 11796 11798
1179c 1179e 117aa 117ac 117ae 117af 117b4 117b8
117ba 117c6 117c8 117cc 117d0 117d4 117e0 117e4
117e9 117ed 117f0 117f1 117f6 117fa 117fe 11801
11804 11808 1180a 1180e 11812 11815 11818 1181c
1181e 11822 11826 11829 1182b 1182f 11833 11837
1183a 1183e 11842 11844 11845 1184a 1 1184e
11852 11856 11859 1185d 11861 11865 11869 1186c
11870 11874 11877 1187a 1187f 11882 11885 11888
11889 1188e 1188f 1 11891 11896 1189a 1189e
118a1 118a6 118ab 118ae 118b2 118b3 118b8 118bb
118c0 118c1 118c6 118c9 118ce 118cf 118d4 118d7
118db 118dc 118e1 118e4 118e9 118ea 118ef 118f2
118f6 118fa 118fd 11900 11901 11903 11904 11909
1190a 1190f 11911 11915 11918 1191a 1191e 11920
1192c 1192e 11930 11931 11936 1193a 1193c 11948
1194a 1194e 11952 11955 11958 11959 1195b 1195e
11963 11964 11969 1196d 11970 11974 11976 1197a
1197d 11981 11985 11988 11989 1198b 1198f 11992
11996 11999 1199a 1199f 119a3 119a7 119aa 119ab
119ad 119b1 119b4 119b8 119bb 119bc 1 119c1
119c6 119ca 119ce 119d2 119d6 119da 119e6 119ea
119ef 119f3 119f6 119f7 119fc 11a00 11a04 11a07
11a0a 11a0e 11a10 11a14 11a18 11a1b 11a1e 11a22
11a24 11a28 11a2c 11a2f 11a31 11a35 11a39 11a3d
11a40 11a44 11a48 11a4a 11a4b 11a50 1 11a54
11a58 11a5c 11a5f 11a63 11a67 11a6b 11a6f 11a72
11a76 11a7a 11a7d 11a80 11a85 11a88 11a8b 11a8e
11a8f 11a94 11a95 1 11a97 11a9c 11aa0 11aa4
11aa7 11aac 11ab1 11ab4 11ab8 11ab9 11abe 11ac1
11ac6 11ac7 11acc 11acf 11ad4 11ad5 11ada 11add
11ae1 11ae2 11ae7 11aea 11aef 11af0 11af5 11af8
11afc 11b00 11b03 11b06 11b07 11b09 11b0a 11b0f
11b10 11b15 11b17 11b1b 11b1e 11b20 11b24 11b26
11b32 11b34 11b36 11b37 11b3c 11b40 11b42 11b4e
11b50 11b54 11b58 11b5c 11b5e 11b62 11b65 11b67
11b6b 11b6f 11b72 11b76 11b7a 11b7d 11b7e 11b80
11b83 11b86 11b87 11b8c 11b90 11b94 11b97 11b98
11b9a 11b9d 11ba0 11ba1 11ba6 11ba9 11bad 11bb0
11bb1 11bb6 11bb9 1 11bbc 11bc1 11bc5 11bc9
11bcd 11bd1 11bd5 11bd9 11bdd 11be9 11bed 11bf1
11bf4 11bf8 11bfc 11bfe 11c02 11c06 11c0a 11c0d
11c11 11c15 11c17 11c18 11c1d 1 11c21 11c25
11c29 11c2c 11c30 11c34 11c38 11c3c 11c3f 11c43
11c47 11c4a 11c4d 11c52 11c55 11c58 11c5b 11c5c
11c61 11c62 1 11c64 11c69 11c6d 11c71 11c74
11c79 11c7e 11c81 11c85 11c86 11c8b 11c8e 11c93
11c94 11c99 11c9c 11ca1 11ca2 11ca7 11caa 11cae
11caf 11cb4 11cb7 11cbc 11cbd 11cc2 11cc5 11cc9
11ccd 11cd0 11cd3 11cd4 11cd6 11cd7 11cdc 11cdd
11ce2 11ce4 11ce8 11ceb 11ced 11cf1 11cf3 11cff
11d01 11d03 11d04 11d09 11d0d 11d0f 11d1b 11d1d
11d21 11d25 11d28 11d2c 11d2f 11d33 11d36 11d37
11d3c 11d3f 11d43 11d47 11d4a 11d4b 11d4d 11d50
11d53 11d54 11d59 1 11d5c 11d61 11d65 11d69
11d6d 11d71 11d75 11d81 11d85 11d8a 11d8e 11d91
11d92 11d97 11d9b 11d9f 11da2 11da5 11da9 11dab
11daf 11db3 11db6 11db9 11dbd 11dbf 11dc3 11dc7
11dca 11dcc 11dd0 11dd4 11dd8 11ddb 11ddf 11de3
11de5 11de6 11deb 1 11def 11df3 11df7 11dfa
11dfe 11e02 11e06 11e0a 11e0d 11e11 11e15 11e18
11e1b 11e20 11e23 11e26 11e29 11e2a 11e2f 11e30
1 11e32 11e37 11e3b 11e3f 11e42 11e47 11e4c
11e4f 11e53 11e54 11e59 11e5c 11e61 11e62 11e67
11e6a 11e6f 11e70 11e75 11e78 11e7c 11e7d 11e82
11e85 11e8a 11e8b 11e90 11e93 11e97 11e9b 11e9e
11ea1 11ea2 11ea4 11ea5 11eaa 11eab 11eb0 11eb2
11eb6 11eb9 11ebb 11ebf 11ec1 11ecd 11ecf 11ed1
11ed2 11ed7 11edb 11edd 11ee9 11eeb 11eef 11ef1
11ef5 11ef9 11efc 11f00 11f03 11f07 11f0a 11f0b
11f10 11f13 11f17 11f1b 11f1e 11f1f 11f21 11f24
11f27 11f28 11f2d 1 11f30 11f35 11f39 11f3d
11f41 11f44 11f48 11f4c 11f50 11f54 11f58 11f5e
11f60 11f64 11f68 11f6b 11f6d 11f71 11f74 11f78
11f7c 11f7f 11f80 11f82 11f86 11f89 11f8d 11f90
11f91 11f96 11f9a 11f9e 11fa1 11fa2 11fa4 11fa8
11fab 11faf 11fb2 11fb3 1 11fb8 11fbd 11fc1
11fc5 11fca 11fcf 11fd3 11fd7 11fdb 11fde 11fe1
11fe5 11fe9 11fed 11ff0 11ff1 11ff3 11ff6 11ff9
11ffa 11fff 12003 12007 1200a 1200b 1200d 12010
12013 12014 1 12019 1201e 12022 12026 1202a
1202e 12032 12036 1203a 1203e 12042 12046 1204a
1204e 12052 12056 1205a 1205e 1206a 1206e 12073
12077 1207a 1207b 12080 12084 12088 1208b 1208e
12092 12094 12098 1209c 1209f 120a2 120a6 120a8
120ac 120b0 120b3 120b5 120b9 120bd 120c1 120c4
120c8 120cc 120ce 120cf 120d4 1 120d8 120dc
120e0 120e3 120e7 120eb 120ef 120f3 120f6 120fa
120fe 12101 12104 12109 1210c 1210f 12112 12113
12118 12119 1 1211b 12120 12124 12128 1212b
12130 12135 12138 1213c 1213d 12142 12145 1214a
1214b 12150 12153 12158 12159 1215e 12161 12165
12166 1216b 1216e 12173 12174 12179 1217c 12180
12184 12187 1218a 1218b 1218d 1218e 12193 12194
12199 1219b 1219f 121a2 121a4 121a8 121aa 121b6
121b8 121ba 121bb 121c0 121c4 121c6 121d2 121d4
121d6 121da 121de 121e2 121e6 121ea 121ee 121f2
121f6 121fa 121fe 12202 12206 1220a 1220e 12212
12216 1221a 1221e 12222 12226 1222a 1222e 12232
12236 1223a 1223e 12242 12246 12252 12256 1225b
1225f 12262 12263 12268 1226c 12270 12273 12276
1227a 1227c 12280 12284 12287 1228a 1228e 12290
12294 12298 1229b 1229d 122a1 122a5 122a9 122ac
122b0 122b4 122b6 122b7 122bc 1 122c0 122c4
122c8 122cb 122cf 122d3 122d7 122db 122de 122e2
122e6 122e9 122ec 122f1 122f4 122f7 122fa 122fb
12300 12301 1 12303 12308 1230c 12310 12313
12318 1231d 12320 12324 12325 1232a 1232d 12332
12333 12338 1233b 12340 12341 12346 12349 1234d
1234e 12353 12356 1235b 1235c 12361 12364 12368
1236c 1236f 12372 12373 12375 12376 1237b 1237c
12381 12383 12387 1238a 1238c 12390 12392 1239e
123a0 123a2 123a3 123a8 123ac 123ae 123ba 123bc
123be 123c2 123c6 123c9 123cd 123d1 123d4 123d8
123db 123df 123e2 123e3 123e8 123eb 123ef 123f2
123f6 123fa 123fe 12402 12406 1240a 1240e 12412
12416 1241a 1241e 1242a 1242e 12432 12435 12439
1243d 1243f 12443 12447 1244b 1244e 12452 12456
12458 12459 1245e 1 12462 12466 1246a 1246d
12471 12475 12479 1247d 12480 12484 12488 1248b
1248e 12493 12496 12499 1249c 1249d 124a2 124a3
1 124a5 124aa 124ae 124b2 124b5 124ba 124bf
124c2 124c6 124c7 124cc 124cf 124d4 124d5 124da
124dd 124e2 124e3 124e8 124eb 124ef 124f0 124f5
124f8 124fd 124fe 12503 12506 1250a 1250e 12511
12514 12515 12517 12518 1251d 1251e 12523 12525
12529 1252c 1252e 12532 12534 12540 12542 12544
12545 1254a 1254e 12550 1255c 1255e 12562 12566
12569 1256a 1256c 1256f 12572 12573 12578 1257c
12582 12584 12588 1258c 12590 12594 12598 125a4
125a8 125ad 125b1 125b4 125b5 125ba 125be 125c2
125c5 125c8 125cc 125ce 125d2 125d6 125d9 125dc
125e0 125e2 125e6 125ea 125ed 125ef 125f3 125f7
125fb 125fe 12602 12606 12608 12609 1260e 1
12612 12616 1261a 1261d 12621 12625 12629 1262d
12630 12634 12638 1263b 1263e 12643 12646 12649
1264c 1264d 12652 12653 1 12655 1265a 1265e
12662 12665 1266a 1266f 12672 12676 12677 1267c
1267f 12684 12685 1268a 1268d 12692 12693 12698
1269b 1269f 126a0 126a5 126a8 126ad 126ae 126b3
126b6 126ba 126be 126c1 126c4 126c5 126c7 126c8
126cd 126ce 126d3 126d5 126d9 126dc 126de 126e2
126e4 126f0 126f2 126f4 126f5 126fa 126fe 12700
1270c 1270e 12712 12716 12719 1271a 1271c 1271f
12722 12723 12728 1272c 1272f 12730 12735 1
12738 1273d 12741 12744 12745 1274a 1 1274d
12752 12756 1275a 1275e 12760 12764 12767 1276b
1276f 12773 12777 1277b 1277c 1277e 12781 12782
12784 12787 1278b 1278f 12793 12794 12796 12799
1279a 1279c 1279d 127a2 127a5 127a8 127ab 127ac
127b1 127b2 127b4 127b8 127bc 127c0 127c4 127c8
127cc 127d0 127d4 127d8 127dc 127e8 127ec 127f0
127f3 127f7 127fb 127fd 12801 12805 12809 1280c
12810 12814 12816 12817 1281c 1 12820 12824
12828 1282b 1282f 12833 12837 1283b 1283e 12842
12846 12849 1284c 12851 12854 12857 1285a 1285b
12860 12861 1 12863 12868 1286c 12870 12873
12878 1287d 12880 12884 12885 1288a 1288d 12892
12893 12898 1289b 128a0 128a1 128a6 128a9 128ad
128ae 128b3 128b6 128bb 128bc 128c1 128c4 128c8
128cc 128cf 128d2 128d3 128d5 128d6 128db 128dc
128e1 128e3 128e7 128ea 128ec 128f0 128f2 128fe
12900 12902 12903 12908 1290c 1290e 1291a 1291c
12920 12923 12927 1292b 1292f 12933 12937 1293b
1293f 12943 12947 1294b 1294f 12953 12957 1295b
1295f 12963 12967 1296b 1296f 12973 12977 1297b
1297f 12983 12987 1298b 1298f 1299b 1299f 129a3
129a6 129aa 129ae 129b0 129b4 129b8 129bc 129bf
129c3 129c7 129c9 129ca 129cf 1 129d3 129d7
129db 129de 129e2 129e6 129ea 129ee 129f1 129f5
129f9 129fc 129ff 12a04 12a07 12a0a 12a0d 12a0e
12a13 12a14 1 12a16 12a1b 12a1f 12a23 12a26
12a2b 12a30 12a33 12a37 12a38 12a3d 12a40 12a45
12a46 12a4b 12a4e 12a53 12a54 12a59 12a5c 12a60
12a61 12a66 12a69 12a6e 12a6f 12a74 12a77 12a7b
12a7f 12a82 12a85 12a86 12a88 12a89 12a8e 12a8f
12a94 12a96 12a9a 12a9d 12a9f 12aa3 12aa5 12ab1
12ab3 12ab5 12ab6 12abb 12abf 12ac1 12acd 12acf
12ad3 12ad7 12ada 12adb 12add 12ae0 12ae3 12ae4
12ae9 12aed 12af1 12af5 12af8 12af9 12afb 12afe
12b02 12b06 12b09 12b0a 12b0c 12b0d 12b12 12b16
12b1a 12b1e 12b22 12b26 12b2a 12b2d 12b31 12b35
12b38 12b39 12b3b 12b3f 12b40 12b45 12b49 12b4d
12b50 12b51 12b53 12b57 12b5a 12b5e 12b61 12b62
12b64 12b65 12b6a 12b6e 12b72 12b75 12b79 12b7d
12b80 12b81 12b83 12b87 12b88 12b8d 12b8f 12b93
12b96 12b9a 12b9e 12ba2 12ba6 12baa 12bae 12bb2
12bb6 12bba 12bbe 12bc2 12bc6 12bca 12bce 12bd2
12bd6 12bda 12bde 12be2 12be6 12bea 12bee 12bf2
12bf6 12bfa 12bfe 12c02 12c06 12c0a 12c0e 12c12
12c16 12c1a 12c1e 12c22 12c2e 12c32 12c37 12c3b
12c3e 12c3f 12c44 12c48 12c4c 12c4f 12c52 12c56
12c58 12c5c 12c60 12c63 12c66 12c6a 12c6c 12c70
12c74 12c77 12c79 12c7d 12c81 12c85 12c88 12c8c
12c90 12c92 12c93 12c98 1 12c9c 12ca0 12ca4
12ca7 12cab 12caf 12cb3 12cb7 12cba 12cbe 12cc2
12cc5 12cc8 12ccd 12cd0 12cd3 12cd6 12cd7 12cdc
12cdd 1 12cdf 12ce4 12ce8 12cec 12cef 12cf4
12cf9 12cfc 12d00 12d01 12d06 12d09 12d0e 12d0f
12d14 12d17 12d1c 12d1d 12d22 12d25 12d29 12d2a
12d2f 12d32 12d37 12d38 12d3d 12d40 12d44 12d48
12d4b 12d4e 12d4f 12d51 12d52 12d57 12d58 12d5d
12d5f 12d63 12d66 12d68 12d6c 12d6e 12d7a 12d7c
12d7e 12d7f 12d84 12d88 12d8a 12d96 12d98 12d9a
12d9e 12da1 12da5 12da9 12dac 12dad 12daf 12db3
12db6 12dba 12dbd 12dbe 12dc0 12dc1 12dc6 12dca
12dce 12dd1 12dd5 12dd9 12ddc 12ddd 12ddf 12de3
12de4 12de9 12deb 12def 12df2 12df6 12dfa 12dfe
12e02 12e06 12e0a 12e0e 12e12 12e16 12e1a 12e1e
12e22 12e26 12e2a 12e2e 12e32 12e36 12e3a 12e3e
12e42 12e46 12e4a 12e4e 12e52 12e56 12e5a 12e5e
12e62 12e66 12e6a 12e6e 12e72 12e76 12e7a 12e7e
12e82 12e86 12e8a 12e8e 12e92 12e96 12e9a 12e9e
12ea2 12ea6 12eb2 12eb6 12ebb 12ebf 12ec2 12ec3
12ec8 12ecc 12ed0 12ed3 12ed6 12eda 12edc 12ee0
12ee4 12ee7 12eea 12eee 12ef0 12ef4 12ef8 12efb
12efd 12f01 12f05 12f09 12f0c 12f10 12f14 12f16
12f17 12f1c 1 12f20 12f24 12f28 12f2b 12f2f
12f33 12f37 12f3b 12f3e 12f42 12f46 12f49 12f4c
12f51 12f54 12f57 12f5a 12f5b 12f60 12f61 1
12f63 12f68 12f6c 12f70 12f73 12f78 12f7d 12f80
12f84 12f85 12f8a 12f8d 12f92 12f93 12f98 12f9b
12fa0 12fa1 12fa6 12fa9 12fad 12fae 12fb3 12fb6
12fbb 12fbc 12fc1 12fc4 12fc8 12fcc 12fcf 12fd2
12fd3 12fd5 12fd6 12fdb 12fdc 12fe1 12fe3 12fe7
12fea 12fec 12ff0 12ff2 12ffe 13000 13002 13003
13008 1300c 1300e 1301a 1301c 13020 13024 13027
13028 1302a 1302d 13030 13031 13036 1303a 1303e
13042 13045 13046 13048 1304b 1304f 13053 13056
13057 13059 1305a 1305f 13063 13067 1306b 1306e
1306f 13071 13075 13078 1307c 1307f 13080 13082
13083 13088 1308c 13090 13094 13097 13098 1309a
1309d 130a1 130a5 130a8 130a9 130ab 130ac 130b1
130b4 130b8 130bc 130bf 130c0 130c2 130c5 130c9
130cd 130d0 130d1 130d3 130d6 130d9 130da 130df
130e2 130e3 130e8 130eb 130ec 130f1 130f5 130f9
130fd 13100 13101 13103 13106 13109 1310a 1310f
13113 13117 1311b 1311f 13123 13127 1312b 1312f
13133 13137 13143 13147 1314c 13150 13153 13154
13159 1315d 13161 13164 13167 1316b 1316d 13171
13175 13178 1317b 1317f 13181 13185 13189 1318c
1318e 13192 13196 1319a 1319d 131a1 131a5 131a7
131a8 131ad 1 131b1 131b5 131b9 131bc 131c0
131c4 131c8 131cc 131cf 131d3 131d7 131da 131dd
131e2 131e5 131e8 131eb 131ec 131f1 131f2 1
131f4 131f9 131fd 13201 13204 13209 1320e 13211
13215 13216 1321b 1321e 13223 13224 13229 1322c
13231 13232 13237 1323a 1323e 1323f 13244 13247
1324c 1324d 13252 13255 13259 1325d 13260 13263
13264 13266 13267 1326c 1326d 13272 13274 13278
1327b 1327d 13281 13283 1328f 13291 13293 13294
13299 1329d 1329f 132ab 132ad 132af 132b3 132b6
132b8 132bc 132bf 132c3 132c7 132cb 132cf 132d3
132d7 132e3 132e7 132eb 132ee 132f2 132f6 132f8
132fc 13300 13304 13307 1330b 1330f 13311 13312
13317 1 1331b 1331f 13323 13326 1332a 1332e
13332 13336 13339 1333d 13341 13344 13347 1334c
1334f 13352 13355 13356 1335b 1335c 1 1335e
13363 13367 1336b 1336e 13373 13378 1337b 1337f
13380 13385 13388 1338d 1338e 13393 13396 1339b
1339c 133a1 133a4 133a8 133a9 133ae 133b1 133b6
133b7 133bc 133bf 133c3 133c7 133ca 133cd 133ce
133d0 133d1 133d6 133d7 133dc 133de 133e2 133e5
133e7 133eb 133ed 133f9 133fb 133fd 133fe 13403
13407 13409 13415 13417 13419 1341d 13421 13425
13428 13429 1342b 1342e 13432 13436 13439 1343a
1343c 1343d 13442 13446 1344a 1344e 13451 13452
13454 13458 1345b 1345f 13462 13463 13465 13466
1346b 1346f 13473 13477 1347a 1347b 1347d 13480
13484 13488 1348b 1348c 1348e 13491 13495 13499
1349c 1349d 1349f 134a2 134a5 134a6 134ab 134ae
134af 134b4 134b7 134b8 134bd 134c1 134c5 134c9
134cc 134cd 134cf 134d3 134d6 134da 134dd 134de
134e0 134e1 134e6 134ea 134ee 134f2 134f6 134fa
134fe 13502 13506 1350a 13516 1351a 1351f 13523
13526 13527 1352c 13530 13534 13537 1353a 1353e
13540 13544 13548 1354b 1354e 13552 13554 13558
1355c 1355f 13561 13565 13569 1356d 13570 13574
13578 1357a 1357b 13580 1 13584 13588 1358c
1358f 13593 13597 1359b 1359f 135a2 135a6 135aa
135ad 135b0 135b5 135b8 135bb 135be 135bf 135c4
135c5 1 135c7 135cc 135d0 135d4 135d7 135dc
135e1 135e4 135e8 135e9 135ee 135f1 135f6 135f7
135fc 135ff 13604 13605 1360a 1360d 13611 13612
13617 1361a 1361f 13620 13625 13628 1362c 13630
13633 13636 13637 13639 1363a 1363f 13640 13645
13647 1364b 1364e 13650 13654 13656 13662 13664
13666 13667 1366c 13670 13672 1367e 13680 13682
13686 13689 1368b 1368f 13692 13694 13698 1369c
1369f 136a1 136a5 136a9 136ac 136b0 136b4 136b8
136bc 136c0 136c4 136c8 136cc 136d0 136d4 136d8
136dc 136e0 136e4 136e8 136ec 136f0 136f4 136f8
136fc 13700 13704 13708 1370c 13710 13714 13718
1371c 13720 13724 13728 1372c 13730 13734 13738
1373c 13740 1374c 13750 13755 13759 1375c 1375d
13762 13766 1376a 1376d 13770 13774 13776 1377a
1377e 13781 13784 13788 1378a 1378e 13792 13795
13797 1379b 1379f 137a3 137a6 137aa 137ae 137b0
137b1 137b6 1 137ba 137be 137c2 137c5 137c9
137cd 137d1 137d5 137d8 137dc 137e0 137e3 137e6
137eb 137ee 137f1 137f4 137f5 137fa 137fb 1
137fd 13802 13806 1380a 1380d 13812 13817 1381a
1381e 1381f 13824 13827 1382c 1382d 13832 13835
1383a 1383b 13840 13843 13847 13848 1384d 13850
13855 13856 1385b 1385e 13862 13866 13869 1386c
1386d 1386f 13870 13875 13876 1387b 1387d 13881
13884 13886 1388a 1388c 13898 1389a 1389c 1389d
138a2 138a6 138a8 138b4 138b6 138ba 138be 138c2
138c6 138ca 138cb 138cd 138d0 138d1 138d3 138d6
138da 138de 138e2 138e3 138e5 138e8 138e9 138eb
138ec 138f1 138f4 138f7 138fa 138fb 13900 13901
13903 13907 1390b 1390f 13913 13916 1391a 1391e
13921 13922 13924 13928 1392c 1392f 13930 13932
13936 1393a 1393e 13942 13946 1394a 1394e 13952
13955 13956 13958 1395c 13960 13963 13964 13966
13969 1396a 1396c 13970 13972 13976 1397c 1397e
13982 13986 13989 1398b 1398f 13994 13998 1399c
139a0 139a3 139a4 139a6 139a9 139ac 139ad 139b2
139b6 139ba 139bd 139be 139c0 139c3 139c6 139c7
1 139cc 139d1 139d5 139d9 139dc 139dd 139df
139e2 139e5 139e6 1 139eb 139f0 139f4 139f8
139fb 139fc 139fe 13a01 13a04 13a05 1 13a0a
13a0f 13a13 13a16 13a1a 13a1e 13a22 13a26 13a29
13a2a 13a2c 13a30 13a32 13a36 13a39 13a3d 13a41
13a44 13a45 13a47 13a4a 13a4d 13a4e 13a53 13a56
13a5a 13a5e 13a61 13a62 13a64 13a68 13a6b 13a6f
13a72 13a73 13a75 13a76 13a7b 1 13a7e 13a83
13a87 13a8b 13a8f 13a92 13a93 13a95 13a99 13a9b
13a9f 13aa3 13aa7 13aab 13aae 13aaf 13ab1 13ab4
13ab8 13abc 13abf 13ac0 13ac2 13ac3 13ac8 13ac9
13acb 13acf 13ad1 13ad5 13ad9 13adc 13ae0 13ae4
13ae7 13ae8 13aea 13aed 13af0 13af1 13af6 13afa
13afe 13b02 13b05 13b06 13b08 13b0b 13b0e 13b0f
13b14 13b18 13b1a 13b1e 13b22 13b26 13b2a 13b2e
13b31 13b32 13b34 13b35 13b37 13b3a 13b3d 13b3e
13b43 13b44 13b46 13b4a 13b4c 13b50 13b54 13b57
13b5b 13b5f 13b62 13b63 13b65 13b68 13b6b 13b6c
13b71 13b75 13b79 13b7d 13b81 13b85 13b89 13b8d
13b91 13b95 13b99 13b9d 13ba1 13ba5 13ba9 13bad
13bb1 13bb5 13bb9 13bc5 13bc9 13bce 13bd2 13bd5
13bd6 13bdb 13bdf 13be3 13be6 13be9 13bed 13bef
13bf3 13bf7 13bfa 13bfd 13c01 13c03 13c07 13c0b
13c0e 13c10 13c14 13c18 13c1c 13c1f 13c23 13c27
13c29 13c2a 13c2f 1 13c33 13c37 13c3b 13c3e
13c42 13c46 13c4a 13c4e 13c51 13c55 13c59 13c5c
13c5f 13c64 13c67 13c6a 13c6d 13c6e 13c73 13c74
1 13c76 13c7b 13c7f 13c83 13c86 13c8b 13c90
13c93 13c97 13c98 13c9d 13ca0 13ca5 13ca6 13cab
13cae 13cb3 13cb4 13cb9 13cbc 13cc0 13cc1 13cc6
13cc9 13cce 13ccf 13cd4 13cd7 13cdb 13cdf 13ce2
13ce5 13ce6 13ce8 13ce9 13cee 13cef 13cf4 13cf6
13cfa 13cfd 13cff 13d03 13d05 13d11 13d13 13d15
13d16 13d1b 13d1f 13d21 13d2d 13d2f 13d31 13d35
13d39 13d3d 13d41 13d45 13d49 13d4d 13d51 13d55
13d59 13d5d 13d61 13d65 13d69 13d6d 13d71 13d75
13d79 13d7d 13d81 13d85 13d89 13d8d 13d91 13d95
13d99 13d9d 13da1 13da5 13da9 13dad 13db1 13db5
13db9 13dbd 13dc1 13dc5 13dc9 13dcd 13dd9 13ddd
13de2 13de6 13de9 13dea 13def 13df3 13df7 13dfa
13dfd 13e01 13e03 13e07 13e0b 13e0e 13e11 13e15
13e17 13e1b 13e1f 13e22 13e24 13e28 13e2c 13e30
13e33 13e37 13e3b 13e3d 13e3e 13e43 1 13e47
13e4b 13e4f 13e52 13e56 13e5a 13e5e 13e62 13e65
13e69 13e6d 13e70 13e73 13e78 13e7b 13e7e 13e81
13e82 13e87 13e88 1 13e8a 13e8f 13e93 13e97
13e9a 13e9f 13ea4 13ea7 13eab 13eac 13eb1 13eb4
13eb9 13eba 13ebf 13ec2 13ec7 13ec8 13ecd 13ed0
13ed4 13ed5 13eda 13edd 13ee2 13ee3 13ee8 13eeb
13eef 13ef3 13ef6 13ef9 13efa 13efc 13efd 13f02
13f03 13f08 13f0a 13f0e 13f11 13f13 13f17 13f19
13f25 13f27 13f29 13f2a 13f2f 13f33 13f35 13f41
13f43 13f45 13f49 13f4d 13f50 13f54 13f57 13f5b
13f5f 13f63 13f66 13f67 13f69 13f6d 13f70 13f74
13f77 13f78 13f7d 13f81 13f84 13f88 13f8a 13f8e
13f91 13f95 13f97 13f9b 13f9f 13fa2 13fa6 13faa
13fad 13fae 13fb0 13fb3 13fb6 13fb7 13fbc 13fc0
13fc4 13fc8 13fcb 13fcf 13fd1 13fd5 13fd9 13fdd
13fe0 13fe4 13fe8 13feb 13fec 13fee 13ff2 13ff6
13ff9 13ffa 13ffc 14000 14002 14006 1400a 1400d
14011 14014 14018 1401c 14020 14024 14028 1402c
14030 14034 14038 1403c 14040 14044 14048 1404c
14050 14054 14058 1405c 14060 14064 14068 1406c
14070 14074 14078 1407c 14080 14084 14088 1408c
14090 14093 14096 14099 1409c 1409f 140a2 140a3
140a5 140a9 140ad 140b0 140b3 140b4 140b9 140bd
140c1 140c5 140c8 140cc 140d0 140d4 140d8 140dc
140e2 140e6 140e8 140ec 140ef 140f2 140f3 140f8
140fc 14100 14104 14107 1410b 1410f 14113 14117
1411b 14121 14123 14127 1412b 1412e 14130 14134
14138 1413b 1413f 14143 14147 1414b 1414f 14153
14157 14163 14167 1416c 14170 14173 14174 14179
1417d 14181 14184 14187 1418b 1418d 14191 14195
14198 1419b 1419f 141a1 141a5 141a9 141ac 141ae
141b2 141b6 141ba 141bd 141c1 141c5 141c7 141c8
141cd 1 141d1 141d5 141d9 141dc 141e0 141e4
141e8 141ec 141ef 141f3 141f7 141fa 141fd 14202
14205 14208 1420b 1420c 14211 14212 1 14214
14219 1421d 14221 14224 14229 1422e 14231 14235
14236 1423b 1423e 14243 14244 14249 1424c 14251
14252 14257 1425a 1425e 1425f 14264 14267 1426c
1426d 14272 14275 14279 1427d 14280 14283 14284
14286 14287 1428c 1428d 14292 14294 14298 1429b
1429d 142a1 142a3 142af 142b1 142b3 142b4 142b9
142bd 142bf 142cb 142cd 142d1 142d5 142d8 142d9
142db 142de 142e1 142e2 142e7 142ea 142eb 142f0
142f4 142f8 142fc 14300 14304 14308 1430c 14310
14314 14318 1431c 14320 14324 14328 1432c 14330
14334 14338 1433c 14340 14344 14348 1434c 14350
1435c 14360 14365 14369 1436c 1436d 14372 14376
1437a 1437d 14380 14384 14386 1438a 1438e 14391
14394 14398 1439a 1439e 143a2 143a5 143a7 143ab
143af 143b3 143b6 143ba 143be 143c0 143c1 143c6
1 143ca 143ce 143d2 143d5 143d9 143dd 143e1
143e5 143e8 143ec 143f0 143f3 143f6 143fb 143fe
14401 14404 14405 1440a 1440b 1 1440d 14412
14416 1441a 1441d 14422 14427 1442a 1442e 1442f
14434 14437 1443c 1443d 14442 14445 1444a 1444b
14450 14453 14457 14458 1445d 14460 14465 14466
1446b 1446e 14472 14476 14479 1447c 1447d 1447f
14480 14485 14486 1448b 1448d 14491 14494 14496
1449a 1449c 144a8 144aa 144ac 144ad 144b2 144b6
144b8 144c4 144c6 144ca 144ce 144d2 144d6 144da
144de 144e2 144e6 144ea 144ee 144f2 144fe 14502
14507 1450b 1450e 1450f 14514 14518 1451c 1451f
14522 14526 14528 1452c 14530 14533 14536 1453a
1453c 14540 14544 14547 14549 1454d 14551 14555
14558 1455c 14560 14562 14563 14568 1 1456c
14570 14574 14577 1457b 1457f 14583 14587 1458a
1458e 14592 14595 14598 1459d 145a0 145a3 145a6
145a7 145ac 145ad 1 145af 145b4 145b8 145bc
145bf 145c4 145c9 145cc 145d0 145d1 145d6 145d9
145de 145df 145e4 145e7 145ec 145ed 145f2 145f5
145f9 145fa 145ff 14602 14607 14608 1460d 14610
14614 14618 1461b 1461e 1461f 14621 14622 14627
14628 1462d 1462f 14633 14636 14638 1463c 1463e
1464a 1464c 1464e 1464f 14654 14658 1465a 14666
14668 1466c 14670 14674 14678 1467c 14680 14684
14688 1468c 14690 14694 146a0 146a4 146a9 146ad
146b0 146b1 146b6 146ba 146be 146c1 146c4 146c8
146ca 146ce 146d2 146d5 146d8 146dc 146de 146e2
146e6 146e9 146eb 146ef 146f3 146f7 146fa 146fe
14702 14704 14705 1470a 1 1470e 14712 14716
14719 1471d 14721 14725 14729 1472c 14730 14734
14737 1473a 1473f 14742 14745 14748 14749 1474e
1474f 1 14751 14756 1475a 1475e 14761 14766
1476b 1476e 14772 14773 14778 1477b 14780 14781
14786 14789 1478e 1478f 14794 14797 1479b 1479c
147a1 147a4 147a9 147aa 147af 147b2 147b6 147ba
147bd 147c0 147c1 147c3 147c4 147c9 147ca 147cf
147d1 147d5 147d8 147da 147de 147e0 147ec 147ee
147f0 147f1 147f6 147fa 147fc 14808 1480a 1480c
14810 14813 14817 1481c 14820 14824 14828 1482c
14830 14834 14835 14837 1483b 1483f 14844 14848
1484c 14850 14854 14858 1485c 1485d 1485f 14863
14867 1486b 1486f 14873 14877 1487b 1487f 1488b
1488f 14894 14898 1489b 1489c 148a1 148a5 148a9
148ac 148af 148b3 148b5 148b9 148bd 148c0 148c3
148c7 148c9 148cd 148d1 148d4 148d6 148da 148de
148e2 148e5 148e9 148ed 148ef 148f0 148f5 1
148f9 148fd 14901 14904 14908 1490c 14910 14914
14917 1491b 1491f 14922 14925 1492a 1492d 14930
14933 14934 14939 1493a 1 1493c 14941 14945
14949 1494c 14951 14956 14959 1495d 1495e 14963
14966 1496b 1496c 14971 14974 14979 1497a 1497f
14982 14986 14987 1498c 1498f 14994 14995 1499a
1499d 149a1 149a5 149a8 149ab 149ac 149ae 149af
149b4 149b5 149ba 149bc 149c0 149c3 149c5 149c9
149cb 149d7 149d9 149db 149dc 149e1 149e5 149e7
149f3 149f5 149f9 149fd 14a00 14a01 14a03 14a06
14a09 14a0a 14a0f 14a12 14a16 14a1a 14a1d 14a1e
14a20 14a23 14a26 14a27 14a2c 1 14a2f 14a34
14a38 14a3c 14a40 14a44 14a48 14a4c 14a50 14a54
14a58 14a5c 14a60 14a64 14a68 14a6c 14a70 14a74
14a78 14a84 14a88 14a8d 14a91 14a94 14a95 14a9a
14a9e 14aa2 14aa5 14aa8 14aac 14aae 14ab2 14ab6
14ab9 14abc 14ac0 14ac2 14ac6 14aca 14acd 14acf
14ad3 14ad7 14adb 14ade 14ae2 14ae6 14ae8 14ae9
14aee 1 14af2 14af6 14afa 14afd 14b01 14b05
14b09 14b0d 14b10 14b14 14b18 14b1b 14b1e 14b23
14b26 14b29 14b2c 14b2d 14b32 14b33 1 14b35
14b3a 14b3e 14b42 14b45 14b4a 14b4f 14b52 14b56
14b57 14b5c 14b5f 14b64 14b65 14b6a 14b6d 14b72
14b73 14b78 14b7b 14b7f 14b80 14b85 14b88 14b8d
14b8e 14b93 14b96 14b9a 14b9e 14ba1 14ba4 14ba5
14ba7 14ba8 14bad 14bae 14bb3 14bb5 14bb9 14bbc
14bbe 14bc2 14bc4 14bd0 14bd2 14bd4 14bd5 14bda
14bde 14be0 14bec 14bee 14bf2 14bf4 14bf8 14bfc
14bff 14c00 14c02 14c05 14c08 14c09 14c0e 14c12
14c16 14c1a 14c1e 14c22 14c26 14c2a 14c2e 14c32
14c36 14c3a 14c3e 14c42 14c4e 14c52 14c57 14c5b
14c5e 14c5f 14c64 14c68 14c6c 14c6f 14c72 14c76
14c78 14c7c 14c80 14c83 14c86 14c8a 14c8c 14c90
14c94 14c97 14c99 14c9d 14ca1 14ca5 14ca8 14cac
14cb0 14cb2 14cb3 14cb8 1 14cbc 14cc0 14cc4
14cc7 14ccb 14ccf 14cd3 14cd7 14cda 14cde 14ce2
14ce5 14ce8 14ced 14cf0 14cf3 14cf6 14cf7 14cfc
14cfd 1 14cff 14d04 14d08 14d0c 14d0f 14d14
14d19 14d1c 14d20 14d21 14d26 14d29 14d2e 14d2f
14d34 14d37 14d3c 14d3d 14d42 14d45 14d49 14d4a
14d4f 14d52 14d57 14d58 14d5d 14d60 14d64 14d68
14d6b 14d6e 14d6f 14d71 14d72 14d77 14d78 14d7d
14d7f 14d83 14d86 14d88 14d8c 14d8e 14d9a 14d9c
14d9e 14d9f 14da4 14da8 14daa 14db6 14db8 14dbc
14dc0 14dc4 14dc7 14dc8 14dca 14dce 14dd2 14dd4
14dd8 14ddc 14de0 14de3 14de4 14de6 14de9 14dec
14ded 14df2 14df6 14dfa 14dfe 14e02 14e06 14e0a
14e0e 14e12 14e16 14e1a 14e1e 14e22 14e26 14e32
14e36 14e3b 14e3f 14e42 14e43 14e48 14e4c 14e50
14e53 14e56 14e5a 14e5c 14e60 14e64 14e67 14e6a
14e6e 14e70 14e74 14e78 14e7b 14e7d 14e81 14e85
14e89 14e8c 14e90 14e94 14e96 14e97 14e9c 1
14ea0 14ea4 14ea8 14eab 14eaf 14eb3 14eb7 14ebb
14ebe 14ec2 14ec6 14ec9 14ecc 14ed1 14ed4 14ed7
14eda 14edb 14ee0 14ee1 1 14ee3 14ee8 14eec
14ef0 14ef3 14ef8 14efd 14f00 14f04 14f05 14f0a
14f0d 14f12 14f13 14f18 14f1b 14f20 14f21 14f26
14f29 14f2d 14f2e 14f33 14f36 14f3b 14f3c 14f41
14f44 14f48 14f4c 14f4f 14f52 14f53 14f55 14f56
14f5b 14f5c 14f61 14f63 14f67 14f6a 14f6c 14f70
14f72 14f7e 14f80 14f82 14f83 14f88 14f8c 14f8e
14f9a 14f9c 14fa0 14fa4 14fa8 14fab 14fac 14fae
14fb2 14fb4 14fb8 14fbc 14fc0 14fc4 14fc8 14fcc
14fd0 14fd4 14fd8 14fdc 14fe8 14fec 14ff1 14ff5
14ff8 14ff9 14ffe 15002 15006 15009 1500c 15010
15012 15016 1501a 1501d 15020 15024 15026 1502a
1502e 15031 15033 15037 1503b 1503f 15042 15046
1504a 1504c 1504d 15052 1 15056 1505a 1505e
15061 15065 15069 1506d 15071 15074 15078 1507c
1507f 15082 15087 1508a 1508d 15090 15091 15096
15097 1 15099 1509e 150a2 150a6 150a9 150ae
150b3 150b6 150ba 150bb 150c0 150c3 150c8 150c9
150ce 150d1 150d6 150d7 150dc 150df 150e3 150e4
150e9 150ec 150f1 150f2 150f7 150fa 150fe 15102
15105 15108 15109 1510b 1510c 15111 15112 15117
15119 1511d 15120 15122 15126 15128 15134 15136
15138 15139 1513e 15142 15144 15150 15152 15156
1515a 1515e 15161 15162 15164 15168 1516c 15170
15174 15177 15178 1517a 1517e 15180 15184 15188
1518b 1518d 15191 15194 15198 1519c 151a0 151a3
151a4 151a6 151a9 151ac 151ad 151b2 151b6 151ba
151be 151c2 151c5 151c6 151c8 151cb 151cf 151d3
151d6 151d7 151d9 151da 151df 151e3 151e5 151e9
151ed 151f0 151f4 151f8 151fb 151ff 15203 15207
1520b 1520c 1520e 15212 15214 15218 1521c 1521f
15227 15229 1522a 1522d 1522f 15233 1523a 1523e
15242 15247 15249 1524d 15251 15254 15258 1525c
1525e 15262 15266 1526a 1526d 15271 15275 15277
15278 1527d 1 15281 15285 15289 1528c 15290
15294 15298 1529c 1529f 152a3 152a7 152aa 152ad
152b2 152b5 152b8 152bb 152bc 152c1 152c2 1
152c4 152c9 152cd 152d1 152d4 152d9 152de 152e1
152e5 152e6 152eb 152ee 152f3 152f4 152f9 152fc
15301 15302 15307 1530a 1530e 1530f 15314 15317
1531c 1531d 15322 15325 15329 1532d 15330 15333
15334 15336 15337 1533c 1533d 15342 15344 15348
1534b 1534d 15351 15353 1535f 15361 15363 15364
15369 1536d 1536f 1537b 1537d 15381 15385 15388
15389 1538b 1538e 15391 15392 15397 1539b 1539f
153a2 153a6 153aa 153ad 153b0 153b5 153b8 153bb
153be 153bf 153c4 153c5 1 153c7 153cc 153d0
153d4 153d7 153dc 153e1 153e4 153e8 153e9 153ee
153f1 153f6 153f7 153fc 153ff 15404 15405 1540a
1540d 15411 15415 15419 1541a 1541c 15421 15422
15424 15425 1542a 1542d 15432 15433 15438 1543b
15440 15441 15446 15449 1544d 1544e 15453 15456
1545b 1545c 15461 15462 15467 15469 1546d 15470
15474 15478 1547b 1547f 15483 15486 15489 1548e
15491 15494 15497 15498 1549d 1549e 1 154a0
154a5 154a9 154ad 154b0 154b5 154ba 154bd 154c1
154c2 154c7 154c8 154cd 154cf 154d3 154d6 154da
154de 154e1 154e5 154e9 154ec 154ed 154ef 154f3
154f7 154f8 154fd 154ff 15503 15506 1550a 1550d
15511 15515 15519 1551c 1551d 1551f 15522 15525
15526 1552b 1552f 15533 15537 1553b 1553f 15542
15543 15545 15549 1554c 15550 15553 15554 15556
15557 1555c 15560 15564 15568 1556b 1556c 1556e
15571 15575 15579 1557c 1557d 1557f 15580 15585
15589 1558d 15591 15594 15595 15597 1559a 1559d
1559e 155a3 155a6 155aa 155ae 155b1 155b2 155b4
155b7 155ba 155bb 155c0 1 155c3 155c8 155cc
155cf 155d0 155d5 155d8 1 155db 155e0 155e4
155e8 155ec 155f0 155f4 155f8 155fc 15600 15604
15608 1560c 15610 15614 15618 1561c 15620 15624
15628 1562c 15630 15634 15638 1563c 15640 15644
15648 1564b 1564c 1564e 15651 15654 15655 1565a
1565d 15661 15665 15668 15669 1566b 1566e 15671
15672 15677 1 1567a 1567f 15683 15686 1568a
1568e 15690 15694 15698 1569b 1569c 1569e 156a1
156a4 156a5 156aa 156ae 156b2 156b6 156b9 156ba
156bc 156c0 156c2 156c6 156ca 156cd 156d1 156d5
156d9 156dd 156e1 156e5 156e8 156e9 156eb 156ef
156f3 156f6 156f7 156f9 156fd 15701 15704 15705
15707 1570b 1570f 15712 15713 15715 15719 1571d
15720 15721 15723 15727 1572b 1572e 1572f 15731
15735 15739 1573c 1573d 1573f 15743 15747 1574a
1574b 1574d 15751 15755 15759 1575a 1575c 15760
15764 15768 1576b 1576c 1576e 15772 15775 15779
1577c 1577d 15782 15786 1578a 1578d 15791 15795
15798 1579b 157a0 157a3 157a6 157a9 157aa 157af
157b0 1 157b2 157b7 157bb 157bf 157c2 157c7
157cc 157cf 157d3 157d4 157d9 157dc 157e1 157e2
157e7 157ea 157ef 157f0 157f5 157f8 157fc 15800
15804 15808 1580b 1580c 1580e 15813 15814 15816
15817 1581c 1581d 15822 15824 15828 1582b 1582f
15833 15836 1583a 1583e 15841 15844 15849 1584c
1584f 15852 15853 15858 15859 1 1585b 15860
15864 15868 1586b 15870 15875 15878 1587c 1587d
15882 15883 15888 1588a 1588e 15891 15895 15899
1589c 158a0 158a4 158a7 158ab 158ac 158b1 158b5
158b7 158bb 158bf 158c2 158c3 158c5 158c8 158cb
158cc 158d1 158d5 158d9 158dc 158e0 158e4 158e7
158ea 158ef 158f2 158f5 158f8 158f9 158fe 158ff
1 15901 15906 1590a 1590e 15911 15916 1591b
1591e 15922 15923 15928 1592b 15930 15931 15936
15939 1593e 1593f 15944 15947 1594b 1594f 15953
15954 15956 1595b 1595c 1595e 1595f 15964 15967
1596c 1596d 15972 15975 1597a 1597b 15980 15983
15987 15988 1598d 15990 15995 15996 1599b 1599c
159a1 159a3 159a7 159aa 159ae 159b2 159b5 159b9
159bd 159c0 159c3 159c8 159cb 159ce 159d1 159d2
159d7 159d8 1 159da 159df 159e3 159e7 159ea
159ef 159f4 159f7 159fb 159fc 15a01 15a02 15a07
15a09 15a0d 15a10 15a14 15a18 15a1b 15a1f 15a23
15a26 15a27 15a29 15a2d 15a31 15a32 15a37 15a39
15a3d 15a41 15a44 15a48 15a4c 15a51 15a56 15a5a
15a5e 15a62 15a65 15a68 15a6c 15a70 15a74 15a78
15a7c 15a80 15a84 15a88 15a8c 15a90 15a94 15aa0
15aa4 15aa9 15aad 15ab0 15ab1 15ab6 15aba 15abe
15ac1 15ac4 15ac8 15aca 15ace 15ad2 15ad5 15ad8
15adc 15ade 15ae2 15ae6 15ae9 15aeb 15aef 15af3
15af7 15afa 15afe 15b02 15b04 15b05 15b0a 1
15b0e 15b12 15b16 15b19 15b1d 15b21 15b25 15b29
15b2c 15b30 15b34 15b37 15b3a 15b3f 15b42 15b45
15b48 15b49 15b4e 15b4f 1 15b51 15b56 15b5a
15b5e 15b61 15b66 15b6b 15b6e 15b72 15b73 15b78
15b7b 15b80 15b81 15b86 15b89 15b8e 15b8f 15b94
15b97 15b9b 15b9c 15ba1 15ba4 15ba9 15baa 15baf
15bb2 15bb6 15bba 15bbd 15bc0 15bc1 15bc3 15bc4
15bc9 15bca 15bcf 15bd1 15bd5 15bd8 15bda 15bde
15be0 15bec 15bee 15bf0 15bf1 15bf6 15bfa 15bfc
15c08 15c0a 15c0e 15c13 15c17 15c1b 15c1e 15c22
15c26 15c29 15c2d 15c31 15c34 15c38 15c3c 15c3f
15c43 15c47 15c4b 15c4e 15c4f 15c51 15c54 15c57
15c58 15c5d 15c61 15c65 15c69 15c6c 15c70 15c74
15c77 15c78 15c7a 15c7e 15c82 15c85 15c86 15c88
15c8c 15c90 15c93 15c97 15c99 15c9d 15ca0 15ca4
15ca6 15caa 15cae 15cb1 15cb5 15cb8 15cbc 15cc0
15cc4 15cc8 15ccc 15cd0 15cd4 15cd8 15cdc 15ce0
15ce4 15ce8 15cec 15cf0 15cf4 15cf8 15cfc 15d00
15d04 15d08 15d0c 15d10 15d14 15d18 15d1c 15d20
15d24 15d28 15d2c 15d30 15d34 15d37 15d3a 15d3d
15d40 15d43 15d46 15d47 15d49 15d4d 15d51 15d54
15d57 15d58 15d5d 15d61 15d65 15d68 15d6c 15d70
15d73 15d76 15d7b 15d7e 15d81 15d84 15d85 15d8a
15d8b 1 15d8d 15d92 15d96 15d9a 15d9d 15da2
15da7 15daa 15dae 15daf 15db4 15db7 15dbc 15dbd
15dc2 15dc5 15dca 15dcb 15dd0 15dd3 15dd7 15ddb
15ddf 15de3 15de6 15de7 15de9 15dee 15def 15df1
15df2 15df7 15dfa 15dff 15e00 15e05 15e08 15e0d
15e0e 15e13 15e16 15e1a 15e1b 15e20 15e23 15e28
15e29 15e2e 15e2f 15e34 15e36 15e3a 15e3d 15e41
15e45 15e48 15e4c 15e50 15e53 15e56 15e5b 15e5e
15e61 15e64 15e65 15e6a 15e6b 1 15e6d 15e72
15e76 15e7a 15e7d 15e82 15e87 15e8a 15e8e 15e8f
15e94 15e95 15e9a 15e9c 15ea0 15ea3 15ea7 15eab
15eae 15eb2 15eb6 15eb9 15ebd 15ec1 15ec2 15ec7
15ecb 15ecd 15ed1 15ed4 15ed7 15ed8 15edd 15ee1
15ee5 15ee8 15eec 15ef0 15ef3 15ef6 15efb 15efe
15f01 15f04 15f05 15f0a 15f0b 1 15f0d 15f12
15f16 15f1a 15f1d 15f22 15f27 15f2a 15f2e 15f2f
15f34 15f37 15f3c 15f3d 15f42 15f45 15f4a 15f4b
15f50 15f53 15f57 15f5b 15f5f 15f63 15f66 15f67
15f69 15f6e 15f6f 15f71 15f72 15f77 15f7a 15f7f
15f80 15f85 15f88 15f8d 15f8e 15f93 15f96 15f9a
15f9b 15fa0 15fa3 15fa8 15fa9 15fae 15faf 15fb4
15fb6 15fba 15fbd 15fc1 15fc5 15fc8 15fcc 15fd0
15fd3 15fd6 15fdb 15fde 15fe1 15fe4 15fe5 15fea
15feb 1 15fed 15ff2 15ff6 15ffa 15ffd 16002
16007 1600a 1600e 1600f 16014 16015 1601a 1601c
16020 16023 16027 1602b 1602e 16032 16036 16039
1603d 16041 16042 16047 16049 1604d 16051 16055
16059 1605d 16061 16065 16069 1606d 16071 16075
16079 1607d 16081 16085 16089 1608d 16091 16095
16099 1609d 160a1 160a5 160a9 160ad 160b1 160b5
160b9 160bd 160c1 160c5 160c9 160cd 160d1 160d5
160d9 160dd 160e1 160e5 160e9 160ed 160f9 160fd
16102 16106 16109 1610a 1610f 16113 16117 1611a
1611d 16121 16123 16127 1612b 1612e 16131 16135
16137 1613b 1613f 16142 16144 16148 1614c 16150
16153 16157 1615b 1615d 1615e 16163 1 16167
1616b 1616f 16172 16176 1617a 1617e 16182 16185
16189 1618d 16190 16193 16198 1619b 1619e 161a1
161a2 161a7 161a8 1 161aa 161af 161b3 161b7
161ba 161bf 161c4 161c7 161cb 161cc 161d1 161d4
161d9 161da 161df 161e2 161e7 161e8 161ed 161f0
161f4 161f5 161fa 161fd 16202 16203 16208 1620b
1620f 16213 16216 16219 1621a 1621c 1621d 16222
16223 16228 1622a 1622e 16231 16233 16237 16239
16245 16247 16249 1624a 1624f 16253 16255 16261
16263 16265 16269 1626d 16270 16272 16276 16279
1627d 1627f 16283 16287 1628a 1628b 1628d 16290
16293 16294 16299 1629d 162a0 162a1 162a6 1
162a9 162ae 162b2 162b6 162ba 162be 162c2 162c6
162ca 162d6 162da 162df 162e3 162e6 162e7 162ec
162f0 162f4 162f7 162fa 162fe 16300 16304 16308
1630b 1630e 16312 16314 16318 1631c 1631f 16321
16325 16329 1632d 16330 16334 16338 1633a 1633b
16340 1 16344 16348 1634c 1634f 16353 16357
1635b 1635f 16362 16366 1636a 1636d 16370 16375
16378 1637b 1637e 1637f 16384 16385 1 16387
1638c 16390 16394 16397 1639c 163a1 163a4 163a8
163a9 163ae 163b1 163b6 163b7 163bc 163bf 163c4
163c5 163ca 163cd 163d1 163d2 163d7 163da 163df
163e0 163e5 163e8 163ec 163f0 163f3 163f6 163f7
163f9 163fa 163ff 16400 16405 16407 1640b 1640e
16410 16414 16416 16422 16424 16426 16427 1642c
16430 16432 1643e 16440 16442 16446 1644a 1644d
16451 16455 16459 1645d 16461 16465 16469 1646d
16479 1647d 16481 16484 16488 1648c 1648e 16492
16496 1649a 1649d 164a1 164a5 164a7 164a8 164ad
1 164b1 164b5 164b9 164bc 164c0 164c4 164c8
164cc 164cf 164d3 164d7 164da 164dd 164e2 164e5
164e8 164eb 164ec 164f1 164f2 1 164f4 164f9
164fd 16501 16504 16509 1650e 16511 16515 16516
1651b 1651e 16523 16524 16529 1652c 16531 16532
16537 1653a 1653e 1653f 16544 16547 1654c 1654d
16552 16555 16559 1655d 16560 16563 16564 16566
16567 1656c 1656d 16572 16574 16578 1657b 1657d
16581 16583 1658f 16591 16593 16594 16599 1659d
1659f 165ab 165ad 165b1 165b5 165b8 165b9 165bb
165be 165c1 165c2 165c7 165cb 165cf 165d3 165d7
165db 165df 165e3 165e7 165eb 165f7 165fb 16600
16604 16607 16608 1660d 16611 16615 16618 1661b
1661f 16621 16625 16629 1662c 1662f 16633 16635
16639 1663d 16640 16642 16646 1664a 1664e 16651
16655 16659 1665b 1665c 16661 1 16665 16669
1666d 16670 16674 16678 1667c 16680 16683 16687
1668b 1668e 16691 16696 16699 1669c 1669f 166a0
166a5 166a6 1 166a8 166ad 166b1 166b5 166b8
166bd 166c2 166c5 166c9 166ca 166cf 166d2 166d7
166d8 166dd 166e0 166e5 166e6 166eb 166ee 166f2
166f3 166f8 166fb 16700 16701 16706 16709 1670d
16711 16714 16717 16718 1671a 1671b 16720 16721
16726 16728 1672c 1672f 16731 16735 16737 16743
16745 16747 16748 1674d 16751 16753 1675f 16761
16763 16767 1676a 1676c 16770 16773 16777 1677a
1677e 16782 16785 16786 1678b 1678e 16792 16796
1679a 1679e 167a2 167a6 167aa 167ae 167b2 167b6
167ba 167be 167c2 167c6 167ca 167d6 167da 167df
167e3 167e6 167e7 167ec 167f0 167f4 167f7 167fa
167fe 16800 16804 16808 1680b 1680e 16812 16814
16818 1681c 1681f 16821 16825 16829 1682d 16830
16834 16838 1683a 1683b 16840 1 16844 16848
1684c 1684f 16853 16857 1685b 1685f 16862 16866
1686a 1686d 16870 16875 16878 1687b 1687e 1687f
16884 16885 1 16887 1688c 16890 16894 16897
1689c 168a1 168a4 168a8 168a9 168ae 168b1 168b6
168b7 168bc 168bf 168c4 168c5 168ca 168cd 168d1
168d2 168d7 168da 168df 168e0 168e5 168e8 168ec
168f0 168f3 168f6 168f7 168f9 168fa 168ff 16900
16905 16907 1690b 1690e 16910 16914 16916 16922
16924 16926 16927 1692c 16930 16932 1693e 16940
16944 16948 1694b 1694c 1694e 16951 16954 16955
1695a 1695e 16962 16966 1696a 1696e 16972 16976
16982 16986 1698a 1698d 16991 16995 16997 1699b
1699f 169a3 169a6 169aa 169ae 169b0 169b1 169b6
1 169ba 169be 169c2 169c5 169c9 169cd 169d1
169d5 169d8 169dc 169e0 169e3 169e6 169eb 169ee
169f1 169f4 169f5 169fa 169fb 1 169fd 16a02
16a06 16a0a 16a0d 16a12 16a17 16a1a 16a1e 16a1f
16a24 16a27 16a2c 16a2d 16a32 16a35 16a3a 16a3b
16a40 16a43 16a47 16a48 16a4d 16a50 16a55 16a56
16a5b 16a5e 16a62 16a66 16a69 16a6c 16a6d 16a6f
16a70 16a75 16a76 16a7b 16a7d 16a81 16a84 16a86
16a8a 16a8c 16a98 16a9a 16a9c 16a9d 16aa2 16aa6
16aa8 16ab4 16ab6 16aba 16abe 16ac1 16ac2 16ac4
16ac7 16aca 16acb 16ad0 16ad4 16ad8 16adc 16ae0
16ae4 16ae8 16aec 16af0 16afc 16b00 16b05 16b09
16b0c 16b0d 16b12 16b16 16b1a 16b1d 16b20 16b24
16b26 16b2a 16b2e 16b31 16b34 16b38 16b3a 16b3e
16b42 16b45 16b47 16b4b 16b4f 16b53 16b56 16b5a
16b5e 16b60 16b61 16b66 1 16b6a 16b6e 16b72
16b75 16b79 16b7d 16b81 16b85 16b88 16b8c 16b90
16b93 16b96 16b9b 16b9e 16ba1 16ba4 16ba5 16baa
16bab 1 16bad 16bb2 16bb6 16bba 16bbd 16bc2
16bc7 16bca 16bce 16bcf 16bd4 16bd7 16bdc 16bdd
16be2 16be5 16bea 16beb 16bf0 16bf3 16bf7 16bf8
16bfd 16c00 16c05 16c06 16c0b 16c0e 16c12 16c16
16c19 16c1c 16c1d 16c1f 16c20 16c25 16c26 16c2b
16c2d 16c31 16c34 16c36 16c3a 16c3c 16c48 16c4a
16c4c 16c4d 16c52 16c56 16c58 16c64 16c66 16c6a
16c6e 16c72 16c76 16c7a 16c86 16c8a 16c8f 16c93
16c96 16c97 16c9c 16ca0 16ca4 16ca7 16caa 16cae
16cb0 16cb4 16cb8 16cbb 16cbe 16cc2 16cc4 16cc8
16ccc 16ccf 16cd1 16cd5 16cd9 16cdd 16ce0 16ce4
16ce8 16cea 16ceb 16cf0 1 16cf4 16cf8 16cfc
16cff 16d03 16d07 16d0b 16d0f 16d12 16d16 16d1a
16d1d 16d20 16d25 16d28 16d2b 16d2e 16d2f 16d34
16d35 1 16d37 16d3c 16d40 16d44 16d47 16d4c
16d51 16d54 16d58 16d59 16d5e 16d61 16d66 16d67
16d6c 16d6f 16d74 16d75 16d7a 16d7d 16d81 16d82
16d87 16d8a 16d8f 16d90 16d95 16d98 16d9c 16da0
16da3 16da6 16da7 16da9 16daa 16daf 16db0 16db5
16db7 16dbb 16dbe 16dc0 16dc4 16dc6 16dd2 16dd4
16dd6 16dd7 16ddc 16de0 16de2 16dee 16df0 16df2
16df6 16df9 16dfb 16dff 16e02 16e06 16e09 16e0d
16e11 16e15 16e19 16e1d 16e21 16e24 16e27 16e2a
16e2b 16e2d 16e31 16e35 16e39 16e3d 16e41 16e45
16e49 16e4d 16e51 16e55 16e59 16e5d 16e61 16e65
16e69 16e6d 16e71 16e75 16e79 16e7d 16e81 16e85
16e89 16e8d 16e91 16e95 16ea1 16ea5 16ea9 16eac
16eb0 16eb4 16eb6 16eba 16ebe 16ec2 16ec5 16ec9
16ecd 16ecf 16ed0 16ed5 1 16ed9 16edd 16ee1
16ee4 16ee8 16eec 16ef0 16ef4 16ef7 16efb 16eff
16f02 16f05 16f0a 16f0d 16f10 16f13 16f14 16f19
16f1a 1 16f1c 16f21 16f25 16f29 16f2c 16f31
16f36 16f39 16f3d 16f3e 16f43 16f46 16f4b 16f4c
16f51 16f54 16f59 16f5a 16f5f 16f62 16f66 16f67
16f6c 16f6f 16f74 16f75 16f7a 16f7d 16f81 16f85
16f88 16f8b 16f8c 16f8e 16f8f 16f94 16f95 16f9a
16f9c 16fa0 16fa3 16fa5 16fa9 16fab 16fb7 16fb9
16fbb 16fbc 16fc1 16fc5 16fc7 16fd3 16fd5 16fd9
16fdd 16fe0 16fe4 16fe7 16feb 16fee 16fef 16ff4
16ff7 16ffb 16ffe 16fff 17004 17007 1700b 1700e
17012 17014 17018 1701b 1701f 17023 17026 17027
17029 1702c 1702f 17030 17035 17039 1703d 17041
17045 17049 1704d 17051 17055 17059 1705d 17061
17065 17069 1706d 17071 1707d 17081 17086 1708a
1708d 1708e 17093 17097 1709b 1709e 170a1 170a5
170a7 170ab 170af 170b2 170b5 170b9 170bb 170bf
170c3 170c6 170c8 170cc 170d0 170d4 170d7 170db
170df 170e1 170e2 170e7 1 170eb 170ef 170f3
170f6 170fa 170fe 17102 17106 17109 1710d 17111
17114 17117 1711c 1711f 17122 17125 17126 1712b
1712c 1 1712e 17133 17137 1713b 1713e 17143
17148 1714b 1714f 17150 17155 17158 1715d 1715e
17163 17166 1716b 1716c 17171 17174 17178 17179
1717e 17181 17186 17187 1718c 1718f 17193 17197
1719a 1719d 1719e 171a0 171a1 171a6 171a7 171ac
171ae 171b2 171b5 171b7 171bb 171bd 171c9 171cb
171cd 171ce 171d3 171d7 171d9 171e5 171e7 171e9
171ed 171f1 171f5 171f9 171fd 17201 17205 17209
1720d 17211 17215 17219 1721d 17221 17225 17229
1722d 17239 1723d 17242 17246 17249 1724a 1724f
17253 17257 1725a 1725d 17261 17263 17267 1726b
1726e 17271 17275 17277 1727b 1727f 17282 17284
17288 1728c 17290 17293 17297 1729b 1729d 1729e
172a3 1 172a7 172ab 172af 172b2 172b6 172ba
172be 172c2 172c5 172c9 172cd 172d0 172d3 172d8
172db 172de 172e1 172e2 172e7 172e8 1 172ea
172ef 172f3 172f7 172fa 172ff 17304 17307 1730b
1730c 17311 17314 17319 1731a 1731f 17322 17327
17328 1732d 17330 17334 17335 1733a 1733d 17342
17343 17348 1734b 1734f 17353 17356 17359 1735a
1735c 1735d 17362 17363 17368 1736a 1736e 17371
17373 17377 17379 17385 17387 17389 1738a 1738f
17393 17395 173a1 173a3 173a5 173a9 173ad 173b0
173b4 173b8 173bb 173be 173bf 173c1 173c4 173c9
173ca 173cf 173d2 173d6 173da 173dd 173e1 173e5
173e9 173ed 173f0 173f1 173f3 173f7 173f9 173fd
17400 17402 17406 17409 1740d 17410 17411 17416
17419 1741c 17420 17424 17427 1742b 1742f 17430
17432 17435 17438 17439 1743e 1 17441 17446
1744a 1744d 17451 17453 17457 1745a 1745c 17460
17463 17467 1746a 1746b 17470 17473 17477 1747b
1747e 1747f 17481 17484 17487 17488 1 1748d
17492 17496 17499 1749d 174a1 174a5 174a9 174ad
174b1 174b4 174b7 174ba 174bb 174bd 174c1 174c5
174c9 174cd 174d1 174d5 174d9 174dd 174e1 174e5
174e9 174ed 174f1 174f5 174f9 174fd 17501 17505
17509 1750d 17511 17515 17519 1751d 17521 17525
17531 17535 17539 1753c 17540 17544 17546 1754a
1754e 17552 17555 17559 1755d 1755f 17560 17565
1 17569 1756d 17571 17574 17578 1757c 17580
17584 17587 1758b 1758f 17592 17595 1759a 1759d
175a0 175a3 175a4 175a9 175aa 1 175ac 175b1
175b5 175b9 175bc 175c1 175c6 175c9 175cd 175ce
175d3 175d6 175db 175dc 175e1 175e4 175e9 175ea
175ef 175f2 175f6 175f7 175fc 175ff 17604 17605
1760a 1760d 17611 17615 17618 1761b 1761c 1761e
1761f 17624 17625 1762a 1762c 17630 17633 17635
17639 1763b 17647 17649 1764b 1764c 17651 17655
17657 17663 17665 17669 1766d 17670 17671 17673
17676 17679 1767a 1767f 17683 17687 1768b 1768f
17693 17697 1769b 1769f 176a3 176a7 176ab 176af
176b3 176b7 176bb 176c7 176cb 176d0 176d4 176d7
176d8 176dd 176e1 176e5 176e8 176eb 176ef 176f1
176f5 176f9 176fc 176ff 17703 17705 17709 1770d
17710 17712 17716 1771a 1771e 17721 17725 17729
1772b 1772c 17731 1 17735 17739 1773d 17740
17744 17748 1774c 17750 17753 17757 1775b 1775e
17761 17766 17769 1776c 1776f 17770 17775 17776
1 17778 1777d 17781 17785 17788 1778d 17792
17795 17799 1779a 1779f 177a2 177a7 177a8 177ad
177b0 177b5 177b6 177bb 177be 177c2 177c3 177c8
177cb 177d0 177d1 177d6 177d9 177dd 177e1 177e4
177e7 177e8 177ea 177eb 177f0 177f1 177f6 177f8
177fc 177ff 17801 17805 17807 17813 17815 17817
17818 1781d 17821 17823 1782f 17831 17833 17837
1783b 1783f 17843 17847 1784b 1784f 17853 17857
1785b 1785f 17863 17867 1786b 1786f 17873 17877
17883 17887 1788c 17890 17893 17894 17899 1789d
178a1 178a4 178a7 178ab 178ad 178b1 178b5 178b8
178bb 178bf 178c1 178c5 178c9 178cc 178ce 178d2
178d6 178da 178dd 178e1 178e5 178e7 178e8 178ed
1 178f1 178f5 178f9 178fc 17900 17904 17908
1790c 1790f 17913 17917 1791a 1791d 17922 17925
17928 1792b 1792c 17931 17932 1 17934 17939
1793d 17941 17944 17949 1794e 17951 17955 17956
1795b 1795e 17963 17964 17969 1796c 17971 17972
17977 1797a 1797e 1797f 17984 17987 1798c 1798d
17992 17995 17999 1799d 179a0 179a3 179a4 179a6
179a7 179ac 179ad 179b2 179b4 179b8 179bb 179bd
179c1 179c3 179cf 179d1 179d3 179d4 179d9 179dd
179df 179eb 179ed 179ef 179f3 179f7 179fa 179fe
17a02 17a05 17a08 17a09 17a0b 17a0e 17a13 17a14
17a19 17a1c 17a20 17a24 17a27 17a28 17a2a 17a2d
17a30 17a31 17a36 1 17a39 17a3e 17a42 17a46
17a49 17a4d 17a51 17a55 17a59 17a5c 17a5d 17a5f
17a63 17a65 17a69 17a6c 17a6e 17a72 17a75 17a79
17a7d 17a81 17a82 17a84 17a88 17a8c 17a8f 17a92
17a93 17a98 17a9c 17aa0 17aa4 17aa8 17aac 17ab0
17ab4 17ab8 17abc 17ac0 17ac4 17ac8 17acc 17ad0
17ad4 17ae0 17ae4 17ae9 17aed 17af0 17af1 17af6
17afa 17afe 17b01 17b04 17b08 17b0a 17b0e 17b12
17b15 17b18 17b1c 17b1e 17b22 17b26 17b29 17b2b
17b2f 17b33 17b37 17b3a 17b3e 17b42 17b44 17b45
17b4a 1 17b4e 17b52 17b56 17b59 17b5d 17b61
17b65 17b69 17b6c 17b70 17b74 17b77 17b7a 17b7f
17b82 17b85 17b88 17b89 17b8e 17b8f 1 17b91
17b96 17b9a 17b9e 17ba1 17ba6 17bab 17bae 17bb2
17bb3 17bb8 17bbb 17bc0 17bc1 17bc6 17bc9 17bce
17bcf 17bd4 17bd7 17bdb 17bdc 17be1 17be4 17be9
17bea 17bef 17bf2 17bf6 17bfa 17bfd 17c00 17c01
17c03 17c04 17c09 17c0a 17c0f 17c11 17c15 17c18
17c1a 17c1e 17c20 17c2c 17c2e 17c30 17c31 17c36
17c3a 17c3c 17c48 17c4a 17c4c 17c50 17c53 17c57
17c5b 17c5e 17c61 17c64 17c65 17c6a 17c6e 17c72
17c75 17c78 17c7c 17c7e 17c82 17c85 17c89 17c8d
17c90 17c94 17c98 17c9b 17c9e 17ca3 17ca6 17ca9
17cac 17cad 17cb2 17cb3 1 17cb5 17cba 17cbe
17cc2 17cc5 17cca 17ccf 17cd2 17cd6 17cd7 17cdc
17cdf 17ce4 17ce5 17cea 17ced 17cf2 17cf3 17cf8
17cfb 17cff 17d03 17d07 17d0b 17d0e 17d0f 17d11
17d16 17d17 17d19 17d1a 17d1f 17d22 17d27 17d28
17d2d 17d30 17d35 17d36 17d3b 17d3e 17d42 17d43
17d48 17d4b 17d50 17d51 17d56 17d57 17d5c 17d5e
17d62 17d65 17d69 17d6d 17d70 17d74 17d78 17d7b
17d7f 17d83 17d84 17d89 17d8b 17d8f 17d93 17d96
17d9a 17d9e 17da1 17da5 17da9 17dac 17daf 17db4
17db7 17dba 17dbd 17dbe 17dc3 17dc4 1 17dc6
17dcb 17dcf 17dd3 17dd6 17ddb 17de0 17de3 17de7
17de8 17ded 17dee 17df3 17df7 17dfb 17dfe 17e03
17e08 17e0b 17e0f 17e13 17e16 17e17 17e1c 17e1f
17e24 17e25 17e2a 17e2d 17e31 17e35 17e38 17e39
17e3e 17e3f 17e44 17e46 17e4a 17e4d 17e51 17e55
17e59 17e5d 17e61 17e65 17e69 17e6d 17e71 17e7d
17e82 17e86 17e8a 17e8e 17e92 17e94 17e95 17e9a
1 17e9e 17ea2 17ea6 17ea9 17ead 17eb1 17eb5
17eb9 17ebc 17ec0 17ec4 17ec7 17eca 17ecf 17ed2
17ed5 17ed8 17ed9 17ede 17edf 1 17ee1 17ee6
17eea 17eee 17ef1 17ef6 17efb 17efe 17f02 17f03
17f08 17f09 17f0e 17f12 17f16 17f19 17f1e 17f23
17f26 17f2a 17f2b 17f30 17f33 17f38 17f39 17f3e
17f41 17f45 17f49 17f4c 17f4f 17f50 17f52 17f53
17f58 17f59 17f5e 17f60 17f64 17f67 17f6b 17f6f
17f73 17f77 17f7b 17f7f 17f83 17f8f 17f94 17f98
17f9c 17fa0 17fa4 17fa6 17faa 17fac 17fb8 17fba
17fbc 17fbd 17fc2 17fc6 17fc8 17fd4 17fd8 17fda
17fdb 17fe4 
6dca
2
0 1 a 6 d :3 6 14 :3 6
10 :3 6 14 :3 6 15 :3 6 10 :3 6
e :3 6 11 :3 6 c :3 6 b :3 6
11 :3 6 11 :3 6 1d :3 6 10 :3 6
12 :2 6 1 3 a 13 a :2 1
4 c 10 f c 20 :2 29 c
:2 4 d 11 10 d 21 :2 2a d
:2 4 12 1b 1a :2 12 :2 4 9 12
11 :2 9 :2 4 12 1b 1a :2 12 :2 4
f 18 17 :2 f :2 4 10 19 18
:2 10 :2 4 14 1d 1c :2 14 :2 4 18
21 20 :2 18 :2 4 18 21 20 :2 18
:2 4 18 21 20 :2 18 :2 4 18 21
20 :2 18 :2 4 18 21 20 :2 18 :2 4
e 17 16 :2 e :2 4 d 16 15
:2 d :2 4 11 1a 19 :2 11 :2 4 11
1a 19 :2 11 :2 4 :3 11 :2 4 :3 12 :2 4
:3 14 :2 4 :3 15 :2 4 f 18 17 :2 f
:2 4 f 18 17 :2 f :2 4 :3 10 :2 4
:3 e :2 4 :3 f :2 4 f 18 17 :2 f
:2 4 b 14 13 :2 b :2 4 :3 f :2 4
:3 10 :2 4 :3 12 :2 4 :3 13 :2 4 e 17
16 :2 e :2 4 10 19 18 :2 10 :2 4
9 12 11 :2 9 :2 4 13 1c 1b
:2 13 :2 4 11 1a 19 :2 11 :2 4 :2 14
23 14 :2 4 :2 12 21 12 :2 4 :2 c
1b c :2 4 :2 d 1c d :2 4 :2 a
19 a :2 4 :2 b 1a b :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 b
1a b :2 4 :2 11 20 11 :2 4 :2 c
1b c :2 4 :2 b 1a b :2 4 :2 e
1d e :2 4 :2 f 1e f :2 4 :2 10
1f 10 :2 4 :2 d 1c d :2 4 :2 f
1e f :2 4 :2 10 1f 10 :2 4 :2 e
1d e :2 4 :2 e 1d e :2 4 :2 f
1e f :2 4 :2 d 1c d :2 4 :2 f
1e f :2 4 :2 f 1e f :2 4 :2 b
1a b :2 4 :2 c 1b c :2 4 :2 c
1b c :2 4 :2 10 1f 10 :2 4 :2 16
25 16 :2 4 :2 f 19 f :2 4 :2 f
19 f :2 4 :2 10 1a 10 :2 4 :2 10
1a 10 :2 4 :2 13 1d 13 :2 4 :2 12
21 12 :2 4 :2 19 28 19 :2 4 :2 19
28 19 :2 4 :2 19 28 19 :2 4 :2 f
1e f :2 4 :2 11 20 11 :2 4 :2 11
20 11 :2 4 :2 e 1d e :2 4 :2 10
1f 10 :2 4 10 19 18 :2 10 :2 4
11 1a 19 :2 11 :2 4 :2 14 1e 14
:2 4 :2 f 1e f :2 4 14 1d 1c
:2 14 :2 4 :2 17 26 17 :2 4 17 20
1f :2 17 :2 4 13 1c 1b :2 13 :2 4
:2 13 22 13 :2 4 :2 14 23 14 :2 4
:2 13 1d 13 :2 4 :2 14 1e 14 :2 4
:2 13 1d 13 :2 4 :2 14 1e 14 :2 4
:2 f 1e f :2 4 :2 f 1e f :2 4
:2 f 1e f :2 4 :2 16 25 16 :2 4
:2 11 20 11 :2 4 :2 11 20 11 :2 4
:2 15 24 15 :2 4 :2 10 1f 10 :2 4
:2 14 23 14 :2 4 14 1d 1c :2 14
:2 4 14 1d 1c :2 14 :2 4 18 21
20 :2 18 :2 4 :2 f 1e f :2 4 f
18 17 :2 f :2 4 :2 11 20 11 :2 4
:2 17 26 17 :2 4 :2 f 1e f :2 4
:2 f 1e f :2 4 :3 d :2 4 :3 d :2 4
:2 10 28 10 :2 4 :2 d 25 d :2 4
:2 12 2a 12 :2 4 :2 d 25 d :2 4
:2 b 23 b :2 4 :3 10 :2 4 :2 16 2e
16 4 7 e 0 :2 7 11 24
11 22 2f a :6 7 e 0 :2 7
11 1f 11 22 2f 40 4e 5b
:2 a :6 7 e 0 :2 7 11 13 26
28 3b 3d 46 48 56 58 66
68 a c 1b 1d 2c 2e 3e
40 55 57 71 73 89 8b a
c 23 25 2f 31 42 44 52
54 62 64 72 74 a c 16
18 20 22 2a 2c 37 39 f
17 1a 2f 32 43 10 12 1f
30 32 40 51 53 e 10 24
26 3c 3e 4b 4d e 10 21
2a 32 3b 49 52 60 69 77
80 8d 96 a7 b0 c3 cc e1
ea 105 10e 126 12f 140 149 15b
164 17c 185 198 1a1 1c2 1c4 1ce
13 15 a :5 7 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 56 5c
5f :2 56 6d 85 8 :2 6d d 10
:2 6d 17 1a :2 6d b e :2 6d 13
16 :2 6d 1b 1e :2 6d 2c 2f :2 6d
b e :2 6d 13 16 :2 6d 1b 1e
:2 6d 28 2b :2 6d b e :2 6d 13
16 :2 6d 1b 1e :2 6d 2c 2f :2 6d
b e :2 6d 13 16 :2 6d 1b 1e
:2 6d 2d 30 :2 6d b e :2 6d 13
16 1f 27 :2 1f 33 :2 16 :2 6d b
e :2 6d 13 16 1f 27 :2 1f 31
:2 16 :2 6d b e :2 6d 13 16 1f
27 :2 1f 34 :2 16 :2 6d b e :2 6d
13 16 1f 27 :2 1f 2f :2 16 :2 6d
b e :2 6d 13 16 1f 27 :2 1f
2e :2 16 :2 6d b e :2 6d 13 16
1f 27 :2 1f 34 :2 16 :2 6d b e
:2 6d 13 16 1f 27 :2 1f 34 :2 16
:2 6d b e :2 6d 13 16 1f 27
:2 1f 40 :2 16 :2 6d b e :2 6d 13
16 1f 27 :2 1f 33 :2 16 :2 6d b
e :2 6d 13 16 :2 6d 1b 1e :2 6d
2a 2d :2 6d 32 35 :2 6d :2 7 4c
:2 4 7 :2 11 23 :2 2d 39 3c 4e
51 52 :2 4e :2 23 :3 7 :2 d 12 1e
5f 62 :2 1e :2 7 55 :3 4 11 :2 4
14 :2 4 10 :2 4 12 :2 4 12 :2 4
12 19 22 2e :2 19 32 :2 3b :2 12
4 8 11 1d :2 8 22 20 :2 2b
:2 20 7 40 e 1a :2 40 1f 1d
:2 28 :2 1d 3f :3 7 15 7 3e :3 4
14 :2 4 12 :2 4 14 :2 4 15 :2 4
9 :3 4 a 16 :2 4 7 e :2 7
:2 10 1c 7 14 7 :2 10 1c 7
:5 4 f :2 18 4 7 d :3 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 55 58 59
:2 55 :2 29 :3 d :2 13 18 24 65 68
:2 24 75 78 :2 24 7c 7f :2 24 8b
8e :2 24 96 99 :2 24 a5 a8 af
b8 bb :2 a8 :2 24 :2 d 5c :2 a :2 7
:4 13 :2 7 4 :3 1 7 10 19 :2 7
1c 1e :2 1c a :2 14 26 :2 30 3c
40 52 55 56 :2 52 :2 26 :3 a :2 10
15 21 62 65 :2 21 72 75 :2 21
79 7c :2 21 86 89 92 9a :2 a3
:2 92 b6 :2 89 :2 21 be c1 :2 21 c9
cc :2 21 d1 d4 :2 21 dd e0 :2 21
:2 a 59 :2 7 a :2 14 26 :2 30 3c
3f 51 54 55 :2 51 :2 26 :3 a :2 10
15 21 62 65 :2 21 :2 a 58 :3 7
:2 12 26 :2 2f 41 4b :2 7 22 :2 4
e 17 1d 29 38 47 c 17
1f 2d 3e 4f c 1a 27 :2 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 55 58
59 :2 55 :2 29 :3 d :2 13 18 24 65
68 :2 24 75 78 :2 24 7c 7f :2 24
8b 8e :2 24 96 99 :2 24 a5 a8
af b8 bb :2 a8 :2 24 :2 d 5c :2 a
:2 7 :4 13 :2 7 4 :3 1 8 :2 11 1c
1a :2 25 :2 1a 7 a :2 14 26 :2 30
3c 40 52 55 56 :2 52 :2 26 :3 a
:2 10 15 21 62 65 :2 21 72 75
:2 21 79 7c :2 21 86 89 92 9a
:2 a3 :2 92 b6 :2 89 :2 21 be c1 :2 21
c9 cc :2 21 d1 d4 :2 21 de e1
:2 21 :2 a 59 :2 7 a :2 14 26 :2 30
3c 3f 51 54 55 :2 51 :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 58
:3 7 :2 12 26 :2 2f 41 4c :2 7 35
:3 4 12 4 e 1e c d 1a
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 55
58 59 :2 55 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 8b 8e :2 24 96 99 :2 24 a5
a8 af b8 bb :2 a8 :2 24 :2 d 5c
:2 a :2 7 :4 13 :2 7 4 :3 1 7 10
1c :2 7 1f 21 :2 1f a :2 14 26
:2 30 3c 40 52 55 56 :2 52 :2 26
:3 a :2 10 15 21 62 65 :2 21 72
75 :2 21 79 7c :2 21 86 89 92
9a :2 a3 :2 92 b9 :2 89 :2 21 c1 c4
:2 21 cc cf :2 21 d4 d7 :2 21 e4
e7 :2 21 :2 a 59 :2 7 a :2 14 26
:2 30 3c 3f 51 54 55 :2 51 :2 26
:3 a :2 10 15 21 62 65 :2 21 :2 a
58 :3 7 :2 12 26 :2 2f 44 52 :2 7
23 :2 4 e 11 24 27 4a 53
56 6c 75 78 90 93 9d a0
ad b8 c2 c5 c 14 22 2d
39 45 54 c 14 17 1c 2b
31 34 42 45 56 59 66 :2 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 55 58
59 :2 55 :2 29 :3 d :2 13 18 24 65
68 :2 24 75 78 :2 24 7c 7f :2 24
8b 8e :2 24 96 99 :2 24 a5 a8
af b8 bb :2 a8 :2 24 :2 d 5c :2 a
:2 7 :4 13 :2 7 4 :3 1 8 :2 11 1c
1a :2 25 :2 1a 7 a :2 14 26 :2 30
3c 40 52 55 56 :2 52 :2 26 :3 a
:2 10 15 21 62 65 :2 21 72 75
:2 21 79 7c :2 21 86 89 92 9a
:2 a3 :2 92 b6 :2 89 :2 21 be c1 :2 21
c9 cc :2 21 d1 d4 :2 21 de e1
:2 21 :2 a 59 :2 7 a :2 14 26 :2 30
3c 3f 51 54 55 :2 51 :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 58
:3 7 :2 12 26 :2 2f 41 4c :2 7 35
:2 4 e 18 2b 37 49 59 67
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 55
58 59 :2 55 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 8b 8e :2 24 96 99 :2 24 a5
a8 af b8 bb :2 a8 :2 24 :2 d 5c
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1c 1a :2 25 :2 1a 7 a :2 14 26
:2 30 3c 40 52 55 56 :2 52 :2 26
:3 a :2 10 15 21 62 65 :2 21 72
75 :2 21 79 7c :2 21 86 89 92
9a :2 a3 :2 92 b6 :2 89 :2 21 be c1
:2 21 c9 cc :2 21 d1 d4 :2 21 dd
e0 :2 21 :2 a 59 :2 7 a :2 14 26
:2 30 3c 3f 51 54 55 :2 51 :2 26
:3 a :2 10 15 21 62 65 :2 21 :2 a
58 :3 7 :2 12 26 :2 2f 41 4b :2 7
35 :2 4 e 1b 2a 39 46 :2 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 55 58
59 :2 55 :2 29 :3 d :2 13 18 24 65
68 :2 24 75 78 :2 24 7c 7f :2 24
8b 8e :2 24 96 99 :2 24 a5 a8
af b8 bb :2 a8 :2 24 :2 d 5c :2 a
:2 7 :4 13 :2 7 4 :3 1 7 :2 12 19
24 :2 7 34 36 :2 34 7 14 7
38 :2 4 8 :2 11 1c 1a :2 25 :2 1a
7 a :2 14 26 :2 30 3c 40 52
55 56 :2 52 :2 26 :3 a :2 10 15 21
62 65 :2 21 72 75 :2 21 79 7c
:2 21 86 89 92 9a :2 a3 :2 92 b6
:2 89 :2 21 be c1 :2 21 c9 cc :2 21
d1 d4 :2 21 e1 e4 :2 21 :2 a 59
:2 7 a :2 14 26 :2 30 3c 3f 51
54 55 :2 51 :2 26 :3 a :2 10 15 21
62 65 :2 21 :2 a 58 :3 7 :2 12 26
:2 2f 41 4f :2 7 35 :3 4 1c :2 4
1c 23 2c 42 :2 23 46 :2 1c :2 4
12 19 22 38 :2 19 3c :2 12 :2 4
1c 23 2c 42 :2 23 46 :2 1c 4
e 14 2c c d 1a 2b 39
45 53 b 23 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 55 58 59 :2 55 :2 29
:3 d :2 13 18 24 65 68 :2 24 75
78 :2 24 7c 7f :2 24 8b 8e :2 24
96 99 :2 24 a5 a8 af b8 bb
:2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 e 14 2c c d 1a
2b 35 46 54 65 :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 4 10 :2 4 11 1b
24 2f :2 1b :2 11 10 4 7 10
13 :2 10 a 13 1f :2 a 22 24
:2 22 14 24 35 58 13 20 31
3b 4c 5a :2 d :2 16 22 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5e 5f :2 5b :2 2f :3 13
:2 19 1e 2a 6b 6e :2 2a 7b 7e
:2 2a 82 85 :2 2a 91 94 :2 2a 9c
9f :2 2a ab ae b5 be c1 :2 ae
:2 2a :2 13 62 :2 10 :2 d :4 19 :2 d a
:3 26 11 1a 27 :2 11 2a 2d :2 2a
:4 d 1b d 17 27 37 5a 16
23 34 3f 4e 5c :2 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 61 62 :2 5e
:2 32 :3 16 :2 1c 21 2d 6e 71 :2 2d
7e 81 :2 2d 85 88 :2 2d 94 97
:2 2d 9f a2 :2 2d ae b1 b8 c1
c4 :2 b1 :2 2d :2 16 65 :2 13 :2 10 :4 1c
:2 10 d :3 2f 10 19 25 :2 10 28
2b :2 28 13 :2 1d 2f :2 39 45 49
5b 5e 5f :2 5b :2 2f :3 13 :2 19 1e
2a 6b 6e :2 2a 7b 7e :2 2a 82
85 :2 2a 8f 92 9b a3 :2 ac :2 9b
cd :2 92 :2 2a d5 d8 :2 2a e0 e3
:2 2a e8 eb :2 2a f4 f7 :2 2a :2 13
62 :2 10 13 :2 1d 2f :2 39 45 48
5a 5d 5e :2 5a :2 2f :3 13 :2 19 1e
2a 6b 6e :2 2a :2 13 61 :3 10 :2 1b
2f :2 38 58 18 :2 10 2d :2 d 2f
:2 a 26 :2 7 4 15 a 18 21
2c :2 18 :2 a 30 33 :2 30 3a 43
4f :2 3a 52 54 :2 52 59 a 16
:2 59 19 1b :2 19 :2 3a 39 :2 a 7
15 7 11 21 31 54 10 1d
2e 3c 49 e :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5b 5c :2 58 :2 2c
:3 10 :2 16 1b 27 68 6b :2 27 78
7b :2 27 7f 82 :2 27 8e 91 :2 27
99 9c :2 27 a8 ab b2 bb be
:2 ab :2 27 :2 10 5f :2 d :2 a :4 16 :2 a
7 :3 1e a 13 1f :2 a 22 24
:2 22 d :2 17 29 :2 33 3f 43 55
58 59 :2 55 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 89 8c 95 9d :2 a6 :2 95 c7
:2 8c :2 24 cf d2 :2 24 da dd :2 24
e2 e5 :2 24 ee f1 :2 24 :2 d 5c
:2 a d :2 17 29 :2 33 3f 42 54
57 58 :2 54 :2 29 :3 d :2 13 18 24
65 68 :2 24 :2 d 5b :3 a :2 15 29
:2 32 52 12 :2 a 26 :2 7 1e 15
:3 4 12 :2 4 13 :2 4 17 :2 4 1b
:2 4 1b :2 4 14 :2 4 9 :3 4 a
14 :2 4 7 c :2 7 :2 10 1c 7
12 7 :2 10 1c 7 :4 4 8 :2 11
1c 1a :2 25 :2 1a 7 e :2 19 20
2e :2 e 39 3c :2 39 :3 a 46 4f
5b :2 46 5e 61 :2 5e :3 42 :2 a d
13 :3 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5e 5f :2 5b :2 2f :3 13 :2 19 1e
2a 6b 6e :2 2a 7b 7e :2 2a 82
85 :2 2a 91 94 :2 2a 9c 9f :2 2a
ab ae b5 be c1 :2 ae :2 2a :2 13
62 :2 10 :2 d :4 19 :2 d a :3 63 d
:2 17 29 :2 33 3f 43 55 58 59
:2 55 :2 29 :3 d :2 13 18 24 65 68
:2 24 75 78 :2 24 7c 7f :2 24 89
8c 95 9d :2 a6 :2 95 c7 :2 8c :2 24
cf d2 :2 24 da dd :2 24 e2 e5
:2 24 ee f1 :2 24 :2 d 5c :2 a d
:2 17 29 :2 33 3f 42 54 57 58
:2 54 :2 29 :3 d :2 13 18 24 65 68
:2 24 :2 d 5b :3 a :2 15 29 :2 32 52
12 :2 a 63 :3 7 15 7 4 35
a 13 1f :2 a 22 24 :2 22 7
15 7 26 35 7 15 7 :4 4
7 d :3 7 :2 10 1c 7 4 c
a :2 13 1f a 1a :2 7 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 55 58 59 :2 55 :2 29 :3 d :2 13
18 24 65 68 :2 24 75 78 :2 24
7c 7f :2 24 8b 8e :2 24 96 99
:2 24 a5 a8 af b8 bb :2 a8 :2 24
:2 d 5c :2 a :2 7 :4 13 :2 7 4 :3 1
e 20 34 43 50 :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 e 21 32 43 c
d 1a b 1b b 19 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 55 58 59
:2 55 :2 29 :3 d :2 13 18 24 66 69
:2 24 76 79 :2 24 7d 80 :2 24 8c
8f :2 24 97 9a :2 24 a6 a9 b0
b9 bc :2 a9 :2 24 :2 d 5c :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a 7 3d 46 52 :2 3d 55
58 :2 55 :3 39 :3 7 1a :2 7 :3 1a 7
11 1e 2f 38 f 10 1d :2 e
1c :2 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
58 5b 5c :2 58 :2 2c :3 10 :2 16 1b
27 69 6c :2 27 79 7c :2 27 80
83 :2 27 8f 92 :2 27 9a 9d :2 27
a9 ac b3 bc bf :2 ac :2 27 :2 10
5f :2 d :2 a :4 16 :2 a 7 :3 5a b
:2 14 1f 1d :2 28 :2 1d :2 a 20 :2 29
a 38 a 1d 2b 2e 37 3f
:2 2e 43 :2 4c 24 :2 1d :2 a 20 :2 29
a :5 7 1a :2 7 19 :2 7 1a 31
3f 49 51 2d 41 52 :2 1a :2 7
17 20 29 31 :2 20 :2 17 7 16
2b 3e 4a 56 a 19 26 32
3f 4c a 14 12 23 31 3f
a 16 20 2e 42 56 a 17
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 58 5b 5c :2 58 :2 2c :3 10
:2 16 1b 27 69 6c :2 27 79 7c
:2 27 80 83 :2 27 8f 92 :2 27 9a
9d :2 27 a9 ac b3 bc bf :2 ac
:2 27 :2 10 5f :2 d :2 a :4 16 :2 a 7
:3 5a e :2 19 20 2e :2 e 39 3c
:2 39 :4 a 15 a 3e 14 1a 32
3f 13 20 31 3c 11 1f 30
48 :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5e 5f :2 5b :2 2f :3 13 :2 19 1e
2a 6c 6f :2 2a 7c 7f :2 2a 83
86 :2 2a 92 95 :2 2a 9d a0 :2 2a
ac af b6 bf c2 :2 af :2 2a :2 13
62 :2 10 :2 d :4 19 :2 d a :7 7 e
17 20 :2 e 23 26 :2 23 :3 a 14
20 2f 38 46 56 13 20 31
3e d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5b 5e 5f :2 5b :2 2f
:3 13 :2 19 1e 2a 6c 6f :2 2a 7c
7f :2 2a 83 86 :2 2a 92 95 :2 2a
9d a0 :2 2a ac af b6 bf c2
:2 af :2 2a :2 13 62 :2 10 :2 d :4 19 :2 d
a :4 28 14 20 12 19 27 44
12 19 28 2f 49 12 22 13
20 31 3e d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5e 5f
:2 5b :2 2f :3 13 :2 19 1e 2a 6c 6f
:2 2a 7c 7f :2 2a 83 86 :2 2a 92
95 :2 2a 9d a0 :2 2a ac af b6
bf c2 :2 af :2 2a :2 13 62 :2 10 :2 d
:4 19 :2 d a :7 7 4 5a b :2 14
1f 1d :2 28 :2 1d a 11 1d 36
41 48 55 6c 74 82 a2 ab
b9 c9 10 1d 2e 3b a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
58 5b 5c :2 58 :2 2c :3 10 :2 16 1b
27 69 6c :2 27 79 7c :2 27 80
83 :2 27 8f 92 :2 27 9a 9d :2 27
a9 ac b3 bc bf :2 ac :2 27 :2 10
5f :2 d :2 a :4 16 :2 a 7 :3 38 7
15 7 11 28 f 10 24 38
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 58
5b 5c :2 58 :2 2c :3 10 :2 16 1b 27
69 6c :2 27 79 7c :2 27 80 83
:2 27 8f 92 :2 27 9a 9d :2 27 a9
ac b3 bc bf :2 ac :2 27 :2 10 5f
:2 d :2 a :4 16 :2 a 7 :3 38 b :2 14
1f 1d :2 28 :2 1d a 14 2b 12
13 27 3b :2 d :2 16 22 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5b 5e 5f :2 5b :2 2f :3 13
:2 19 1e 2a 6c 6f :2 2a 7c 7f
:2 2a 83 86 :2 2a 92 95 :2 2a 9d
a0 :2 2a ac af b6 bf c2 :2 af
:2 2a :2 13 62 :2 10 :2 d :4 19 :2 d a
:3 38 e :2 17 22 20 :2 2b :2 20 :2 d
1b d 3b :2 a 38 :2 7 e 17
23 :2 e 26 29 :2 26 :3 a d 16
1f :2 d 24 22 :2 2d :2 22 d 20
2e 31 3a 42 :2 31 46 :2 4f 24
:2 20 d 17 30 3d 10 1e 27
34 42 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 61
62 :2 5e :2 32 :3 16 :2 1c 21 2d 6f
72 :2 2d 7f 82 :2 2d 86 89 :2 2d
95 98 :2 2d a0 a3 :2 2d af b2
b9 c2 c5 :2 b2 :2 2d :2 16 65 :2 13
:2 10 :4 1c :2 10 d :3 3c d 20 36
:2 20 d a 3c 11 18 21 2a
:2 18 2e :2 37 :2 11 10 48 45 :2 51
:2 45 17 30 3d 10 1c 25 2c
39 42 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 61
62 :2 5e :2 32 :3 16 :2 1c 21 2d 6f
72 :2 2d 7f 82 :2 2d 86 89 :2 2d
95 98 :2 2d a0 a3 :2 2d af b2
b9 c2 c5 :2 b2 :2 2d :2 16 65 :2 13
:2 10 :4 1c :2 10 d :3 5d d 20 36
:2 20 d a 5d 3c 11 18 21
2a :2 18 2e :2 37 :2 11 10 4a 47
:2 53 :2 47 17 30 3d 10 1c 25
2c 39 42 16 2a 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5e
61 62 :2 5e :2 32 :3 16 :2 1c 21 2d
6f 72 :2 2d 7f 82 :2 2d 86 89
:2 2d 95 98 :2 2d a0 a3 :2 2d af
b2 b9 c2 c5 :2 b2 :2 2d :2 16 65
:2 13 :2 10 :4 1c :2 10 d :3 61 d 20
36 :2 20 d 61 3c :2 a 2b :2 7
38 5a :2 4 18 28 2b c 1d
28 32 35 :2 c 16 19 1e 2d
33 36 44 47 56 59 d 19
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 55
58 59 :2 55 :2 29 :3 d :2 13 18 24
66 69 :2 24 76 79 :2 24 7d 80
:2 24 8c 8f :2 24 97 9a :2 24 a6
a9 b0 b9 bc :2 a9 :2 24 :2 d 5c
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1d 1a :2 26 :2 1a :2 7 19 7 36
:3 4 13 :2 4 14 :2 4 15 :2 4 :3 17
4 8 11 27 :2 8 2a 2c :2 2a
7 33 3c 52 :2 33 55 57 :2 55
32 :3 7 1a 2b 39 43 4f 5c
27 34 40 4d 59 :2 1a 7 a
13 29 :2 a 2c 2e :2 2c a 18
21 2d :2 18 30 32 3b 4b :2 32
:2 18 :2 a 19 22 2f :2 19 32 34
3d 4d :2 34 :2 19 a 30 :2 7 a
13 29 :2 a 2c 2e :2 2c a 18
21 2d :2 18 30 32 3b 4b :2 32
:2 18 :2 a 19 22 2f :2 19 32 34
3d 4d :2 34 :2 19 a 30 :2 7 5a
:3 4 10 :2 4 f 4 e 12 26
c d 1a :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 55 58 59 :2 55 :2 29 :3 d
:2 13 18 24 66 69 :2 24 76 79
:2 24 7d 80 :2 24 8c 8f :2 24 97
9a :2 24 a6 a9 b0 b9 bc :2 a9
:2 24 :2 d 5c :2 a :2 7 :4 13 :2 7 4
:3 1 4 1b 4 e 21 c 21
c d 1a 2b 35 b 19 2a
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 55
58 59 :2 55 :2 29 :3 d :2 13 18 24
66 69 :2 24 76 79 :2 24 7d 80
:2 24 8c 8f :2 24 97 9a :2 24 a6
a9 b0 b9 bc :2 a9 :2 24 :2 d 5c
:2 a :2 7 :4 13 :2 7 4 :3 1 e 28
4a 56 c 22 2f :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 58 59 :2 55
:2 29 :3 d :2 13 18 24 66 69 :2 24
76 79 :2 24 7d 80 :2 24 8c 8f
:2 24 97 9a :2 24 a6 a9 b0 b9
bc :2 a9 :2 24 :2 d 5c :2 a :2 7 :4 13
:2 7 4 :3 1 b :2 16 1d 2b :2 b
36 39 :2 36 :3 7 3f 48 54 :2 3f
57 5a :2 57 :2 7 :4 b :2 a 19 :2 a
18 a 14 26 34 3c 43 5b
63 6a 83 8d d 1b 29 37
45 4e 59 63 6b 73 12 18
2a 36 43 4f d 1d 2e 3e
4f 5a 6b 73 7c 84 12 13
27 :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5f 60 :2 5b :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a 7d 80 :2 2a 84
87 :2 2a 93 96 :2 2a 9e a1 :2 2a
ad b0 b7 c0 c3 :2 b0 :2 2a :2 13
63 :2 10 :2 d :4 19 :2 d a :3 2c e
:2 17 22 20 :2 2b :2 20 d 14 1d
2f :2 14 32 35 :2 32 :3 10 3f 48
54 :2 3f 57 5a :2 57 :3 3b :2 10 13
:2 1d 2f :2 39 45 49 5b 5f 60
:2 5b :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a 7d 80 :2 2a 84 87 :2 2a 91
94 9d a5 :2 ae :2 9d c6 :2 94 :2 2a
ce d1 :2 2a d9 dc :2 2a e1 e4
:2 2a f8 fb :2 2a :2 13 63 :2 10 13
:2 1d 2f :2 39 45 48 5a 5e 5f
:2 5a :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a :2 13 62 :3 10 :2 1b 2f :2 38 4f
18 :2 10 5c :2 d 10 17 27 2a
:2 10 2d 2f :2 2d 10 25 :2 2e :2 10
1f 30 3e 4c 61 62 :2 61 :2 1f
:2 10 :2 19 25 10 33 :2 d 3b :2 a
d 16 22 :2 d 25 28 :2 25 1c
16 23 14 28 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 62
63 :2 5e :2 32 :3 16 :2 1c 21 2d 70
73 :2 2d 80 83 :2 2d 87 8a :2 2d
96 99 :2 2d a1 a4 :2 2d b0 b3
ba c3 c6 :2 b3 :2 2d :2 16 66 :2 13
:2 10 :4 1c :2 10 d :3 2a 1c 16 2a
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 96 99 :2 2d a1
a4 :2 2d b0 b3 ba c3 c6 :2 b3
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:3 2a 1c 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 62
63 :2 5e :2 32 :3 16 :2 1c 21 2d 70
73 :2 2d 80 83 :2 2d 87 8a :2 2d
96 99 :2 2d a1 a4 :2 2d b0 b3
ba c3 c6 :2 b3 :2 2d :2 16 66 :2 13
:2 10 :4 1c :2 10 d :4 2a d 22 d
10 19 25 :2 10 28 2a :2 28 13
1c 27 :2 13 2d 2a 36 42 :2 2d
:2 2a 48 51 59 :2 48 5f 5c 27
30 :2 5f :2 5c :3 13 28 13 33 :3 10
1c :2 10 20 :2 10 21 :2 10 1a :2 10
20 :2 10 1b :2 10 1a :2 10 1d :2 10
1d 10 2c :3 d 26 2d 39 3c
:2 26 3f 41 :2 3f 4a :2 21 51 :2 1c
d 11 :2 1a 25 23 :2 2e :2 23 10
:4 14 13 1d 30 3a 42 4d 59
61 68 1b 28 30 38 43 51
1b 1c 30 :2 16 :2 1f 2b 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:3 35 17 :2 20 2b 29 :2 34 :2 29 :2 16
22 16 19 22 2d :2 19 33 30
3c 48 :2 33 :2 30 4e 57 5f :2 4e
65 62 6e 77 :2 65 :2 62 :2 19 2b
:2 36 3e 4c 58 :2 2b 5c 5e :2 5c
2a :2 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9a 9d a6 ae :2 b7 :2 a6
cf :2 9d :2 33 d7 da :2 33 e2 e5
:2 33 ea ed :2 33 f6 f9 :2 33 :2 1c
6c :2 19 1c :2 26 38 :2 42 4e 51
63 67 68 :2 63 :2 38 :3 1c :2 22 27
33 76 79 :2 33 :2 1c 6b :3 19 :2 24
38 :2 41 58 62 :2 19 16 61 1c
:2 27 2f 3d 49 :2 1c 4d 4f :2 4d
23 32 42 22 2f 20 34 20
2e :2 1c :2 25 31 1c 19 21 1f
:2 28 34 1f 2f :2 1c :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
6a 6e 6f :2 6a :2 3e :3 22 :2 28 2d
39 7c 7f :2 39 8c 8f :2 39 93
96 :2 39 a2 a5 :2 39 ad b0 :2 39
bc bf c6 cf d2 :2 bf :2 39 :2 22
72 :2 1f :2 1c :4 28 :2 1c 19 :3 51 1d
:2 26 31 2f :2 3a :2 2f :2 1c 28 31
3b :2 28 3e 40 49 55 :2 40 :2 28
1c 2b 25 32 23 37 23 31
1f 26 22 2e :3 2c 22 :2 2b 37
22 33 22 :2 2b 37 22 :4 1f 1c
24 22 :2 2b 37 22 32 :2 1f :2 24
22 :2 2b 37 22 25 :2 2f 41 :2 4b
57 5b 6d 71 72 :2 6d :2 41 :3 25
:2 2b 30 3c 7f 82 :2 3c 8f 92
:2 3c 96 99 :2 3c a5 a8 :2 3c b0
b3 :2 3c bf c2 c9 d2 d5 :2 c2
:2 3c :2 25 75 :2 22 :2 1f :4 2b :2 1f 1c
:4 4a :2 19 51 61 :2 16 44 :2 13 35
:3 10 1f :2 10 19 10 13 1c 1f
:2 1c 13 1f 13 21 13 1f 13
:4 10 13 1c 28 :2 13 2b 2d :2 2b
13 1d 13 2f :3 10 1e 2f 3d
4c 55 5e :2 4c 62 20 28 :2 62
2c 35 41 :2 2c 45 4e 59 :2 45
22 2b 36 :2 22 3a 43 51 :2 3a
55 20 2b :2 55 2f 38 44 :2 2f
48 50 5a :2 1e 10 13 1c 28
:2 13 2d 2b :2 36 :2 2b 16 :2 20 32
:2 3c 48 4b 5d 61 62 :2 5d :2 32
:3 16 :2 1c 21 2d 70 73 :2 2d 80
83 :2 2d 87 8a :2 2d 94 97 a0
a8 :2 b1 :2 a0 c2 :2 97 :2 2d :2 16 65
:2 13 16 :2 20 32 :2 3c 48 4b 5d
61 62 :2 5d :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d :2 16 65 :3 13 :2 1e 34
:2 3d 4d :2 13 10 45 16 1f 2b
:2 16 2e 31 :2 2e 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 94 97 a0 a8
:2 a0 b5 :2 97 :2 2d bd c0 :2 2d c8
cb :2 2d d0 d3 :2 2d e0 e3 :2 2d
:2 16 66 :2 13 16 :2 20 32 :2 3c 48
4b 5d 61 62 :2 5d :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d :2 16 65 :3 13
:2 1e 32 3b 47 :2 32 4b 59 :2 13
33 45 :2 10 13 1c 27 :2 13 2c
2a :2 35 :2 2a 13 20 13 49 :3 10
26 10 21 18 1a 1d 34 49
4d 5e 19 1c 29 3a 3d 51
54 17 1a 27 38 3b :2 13 :2 1c
28 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 65 66
:2 61 :2 35 :3 19 :2 1f 24 30 73 76
:2 30 83 86 :2 30 8a 8d :2 30 99
9c :2 30 a4 a7 :2 30 b3 b6 bd
c6 c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13
:4 1f :2 13 10 :3 3e 13 1c 1f :2 1c
16 1f 33 :2 16 36 38 :2 36 16
2c 16 3a :2 13 16 1f 27 :2 16
2a 2c :2 2a 16 23 :2 2c 16 2e
16 23 :2 2c 33 3c 47 :2 33 4b
:2 54 :2 23 16 :4 13 21 16 1f 27
:2 16 2a 2c :2 2a 16 23 :2 2c 16
2e 16 23 :2 2c 33 3c 47 :2 33
4b :2 54 :2 23 16 :4 13 :4 10 17 20
34 :2 17 37 3a :2 37 :3 13 1d 16
28 37 4a 5a 6f 81 92 16
2d 41 5b 16 27 35 46 54
65 73 84 16 1c 30 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :3 3c 1d
16 32 16 33 16 33 16 31
16 34 1c 29 3a 48 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :3 3c 13
24 13 3c :3 10 23 :2 10 1c 28
3d 4b 59 63 1b 23 2f 3b
47 53 1b 2a 36 40 48 51
59 1b 27 33 40 4b 56 1b
25 30 3c 48 4b 4e 58 :2 4e
1b 25 :2 1b 2b 2e :2 1c 10 13
1c 1e :2 1c 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 94 97 a0 a8 :2 b1
:2 a0 c8 :2 97 :2 2d d0 d3 :2 2d db
de :2 2d e3 e6 :2 2d ef f2 :2 2d
:2 16 66 :2 13 16 :2 20 32 :2 3c 48
4b 5d 61 62 :2 5d :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d :2 16 65 :3 13
:2 1e 32 :2 3b 51 5b :2 13 10 22
16 1f 22 :2 1f 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 94 97 a0 a8
:2 b1 :2 a0 c9 :2 97 :2 2d d1 d4 :2 2d
dc df :2 2d e4 e7 :2 2d f7 fa
:2 2d :2 16 66 :2 13 16 :2 20 32 :2 3c
48 4b 5d 61 62 :2 5d :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d :2 16 65
:3 13 :2 1e 32 :2 3b 52 1b :2 13 24
22 :4 17 16 20 33 42 52 1e
33 41 50 1e 1f 2c 3d 47
58 66 73 :2 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 67 6b 6c :2 67 :2 3b :3 1f
:2 25 2a 36 79 7c :2 36 89 8c
:2 36 90 93 :2 36 9f a2 :2 36 aa
ad :2 36 b9 bc c3 cc cf :2 bc
:2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19 16
:4 34 19 22 25 :2 22 2e 37 41
:2 2e 44 47 :2 44 :3 2a :2 19 20 29
33 :2 20 36 39 :2 36 :3 1c 1f 28
34 :2 1f 37 3a :2 37 1f 2f 1f
29 2d 38 3c 27 36 27 28
35 26 3a 26 35 :2 22 :2 2b 37
22 1f 27 25 :2 2e 3a 25 35
:2 22 :2 27 25 :2 2e 3a 25 28 :2 32
44 :2 4e 5a 5e 70 74 75 :2 70
:2 44 :3 28 :2 2e 33 3f 82 85 :2 3f
92 95 :2 3f 99 9c :2 3f a8 ab
:2 3f b3 b6 :2 3f c2 c5 cc d5
d8 :2 c5 :2 3f :2 28 78 :2 25 :2 22 :4 2e
:2 22 1f :4 3c 29 2d 38 3c 47
4b 27 35 44 27 28 35 26
3a 26 34 :2 22 :2 2b 37 22 1f
27 25 :2 2e 3a 25 35 :2 22 :2 27
25 :2 2e 3a 25 28 :2 32 44 :2 4e
5a 5e 70 74 75 :2 70 :2 44 :3 28
:2 2e 33 3f 82 85 :2 3f 92 95
:2 3f 99 9c :2 3f a8 ab :2 3f b3
b6 :2 3f c2 c5 cc d5 d8 :2 c5
:2 3f :2 28 78 :2 25 :2 22 :4 2e :2 22 1f
:7 1c 3b 1f 28 34 :2 1f 37 3a
:2 37 1f 2f 1f 29 2d 3c 27
28 35 26 3a 26 35 :2 22 :2 2b
37 22 1f 27 25 :2 2e 3a 25
35 :2 22 :2 27 25 :2 2e 3a 25 28
:2 32 44 :2 4e 5a 5e 70 74 75
:2 70 :2 44 :3 28 :2 2e 33 3f 82 85
:2 3f 92 95 :2 3f 99 9c :2 3f a8
ab :2 3f b3 b6 :2 3f c2 c5 cc
d5 d8 :2 c5 :2 3f :2 28 78 :2 25 :2 22
:4 2e :2 22 1f :4 3c 29 2d 38 3c
4b 59 27 28 35 26 3a 26
34 :2 22 :2 2b 37 22 1f 27 25
:2 2e 3a 25 35 :2 22 :2 27 25 :2 2e
3a 25 28 :2 32 44 :2 4e 5a 5e
70 74 75 :2 70 :2 44 :3 28 :2 2e 33
3f 82 85 :2 3f 92 95 :2 3f 99
9c :2 3f a8 ab :2 3f b3 b6 :2 3f
c2 c5 cc d5 d8 :2 c5 :2 3f :2 28
78 :2 25 :2 22 :4 2e :2 22 1f :7 1c :4 19
49 19 27 :2 19 2c 3c 4a 5f
6b 24 2f :2 6b 33 36 :2 2c 19
23 2c 3a 48 51 60 21 2f
21 22 36 :2 1c :2 25 31 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6a 6e 6f :2 6a :2 3e :3 22
:2 28 2d 39 7c 7f :2 39 8c 8f
:2 39 93 96 :2 39 a2 a5 :2 39 ad
b0 :2 39 bc bf c6 cf d2 :2 bf
:2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c 19
:7 16 19 22 2e :2 19 31 34 :2 31
19 25 2e 38 :2 25 3b 3d 46
52 :2 3d :2 25 19 36 :2 16 :4 13 17
:2 20 2c 29 :2 35 :2 29 16 19 :2 23
35 :2 3f 4b 4f 61 65 66 :2 61
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
83 86 :2 30 8a 8d :2 30 97 9a
a3 ab :2 b4 :2 a3 cc :2 9a :2 30 d4
d7 :2 30 df e2 :2 30 e7 ea :2 30
fa fd :2 30 :2 19 69 :2 16 19 :2 23
35 :2 3f 4b 4e 60 64 65 :2 60
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
:2 19 68 :3 16 :2 21 35 :2 3e 55 1e
:2 16 45 :2 13 :4 10 1a 17 30 4e
5f 13 2c 4a 5b 13 2c 4a
5b 13 2c 4a 5b 13 2c 4d
6b 7b 13 2f 50 6e 7e 13
22 2b 32 3f 48 13 25 2e
35 46 4f 19 2d 13 1a 16
22 :3 20 16 :2 1f 2b 16 27 16
:2 1f 2b 16 :4 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 61
65 66 :2 61 :2 35 :3 19 :2 1f 24 30
73 76 :2 30 83 86 :2 30 8a 8d
:2 30 99 9c :2 30 a4 a7 :2 30 b3
b6 bd c6 c9 :2 b6 :2 30 :2 19 69
:2 16 :2 13 :4 1f :2 13 10 :3 3e 13 1c
2e :2 13 33 31 3c 46 :2 33 :2 31
13 21 39 4e 5a 29 3e 4c
29 37 40 4b :2 37 4f 58 62
:2 4f 29 2c 35 41 :2 2c :2 21 13
49 22 1c 29 1a 2e 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :3 10 1d
16 21 16 22 :f 16 1c 30 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :7 10
3e :2 d :4 a 2c :2 7 5c :2 4 :4 9
8 7 2c 35 41 :2 2c 44 46
:2 44 2b :2 7 4e a 16 :2 4e 19
1b :2 19 4d :3 7 13 :2 7 18 :2 7
19 :2 7 1e :2 7 :3 1e 7 a 13
19 :2 a 1c 1e :2 1c a 1d 26
2e :2 1d a 22 :2 7 b 14 2a
:2 b 2d 2f :2 2d a 36 3f 55
:2 36 58 5a :2 58 35 :2 a e 17
2d :2 e 30 32 :2 30 d 3a 43
59 :2 3a 5c 5e :2 5c 39 :2 d 1c
2d 3f 51 59 64 67 6a 73
10 1f 2f 39 47 56 62 70
10 1a 2b 38 45 52 60 6f
7e 17 2c 3d 4b 59 62 68
71 77 86 10 1f 34 43 53
5c 68 10 1c 2e 39 45 50
5c 6d 7e 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 62 63
:2 5e :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 96
99 :2 2d a1 a4 :2 2d b0 b3 ba
c3 c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10
:4 1c :2 10 d :3 61 a 61 10 19
2f :2 10 32 34 :2 32 1c 2d 3f
51 59 64 67 6a 73 10 1f
2f 39 47 56 62 70 10 1a
2b 38 45 52 60 6f 7e 17
2c 3d 4b 59 62 68 71 77
86 10 1f 34 43 53 5c 68
10 1c 2e 39 45 50 5d 6e
7f 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 62 63 :2 5e :2 32
:3 16 :2 1c 21 2d 70 73 :2 2d 80
83 :2 2d 87 8a :2 2d 96 99 :2 2d
a1 a4 :2 2d b0 b3 ba c3 c6
:2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10
d :4 36 61 1c 2d 3f 51 59
64 67 6a 73 10 1f 2f 39
47 56 62 70 10 1a 2b 38
45 52 60 6f 7e 17 2c 3d
4b 59 62 68 71 77 86 10
1f 34 43 53 5c 68 10 1c
2e 39 45 50 5d 6e 7f 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 96 99 :2 2d a1 a4
:2 2d b0 b3 ba c3 c6 :2 b3 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :7 a
5d 19 2a 3c 4e 56 61 64
67 70 d 1b 2a 33 40 4e
5a 68 d 17 28 35 42 4f
5d 6c 7b 14 29 3a 48 56
5f 65 6e 74 83 d 1c 31
40 50 59 65 d 19 2b 36
42 4d 5a 6b 7c d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5b
5f 60 :2 5b :2 2f :3 13 :2 19 1e 2a
6d 70 :2 2a 7d 80 :2 2a 84 87
:2 2a 93 96 :2 2a 9e a1 :2 2a ad
b0 b7 c0 c3 :2 b0 :2 2a :2 13 63
:2 10 :2 d :4 19 :2 d a :7 7 1e :3 4
e 15 1c 1f :2 15 24 27 :2 e
:2 4 1b :2 4 10 :2 4 16 :2 4 16
:2 4 f :2 4 14 :2 4 14 :2 4 12
:2 4 9 :4 4 d 16 23 38 43
4b 5d 7 15 21 2e 3b 7
1c 27 39 48 58 67 7 f
18 20 2b :3 7 a e :2 a :2 13
1f a 14 a :2 13 1f a :4 7
b :2 14 20 1d :2 29 :2 1d :3 a 39
:3 7 16 7 12 1a 21 3c 4b
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 58
5c 5d :2 58 :2 2c :3 10 :2 16 1b 27
6a 6d :2 27 7a 7d :2 27 81 84
:2 27 90 93 :2 27 9b 9e :2 27 aa
ad b4 bd c0 :2 ad :2 27 :2 10 60
:2 d :2 a :4 16 :2 a 7 :3 4 12 1a
21 3d 4d :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 58 5c 5d :2 58 :2 2c :3 10
:2 16 1b 27 6a 6d :2 27 7a 7d
:2 27 81 84 :2 27 90 93 :2 27 9b
9e :2 27 aa ad b4 bd c0 :2 ad
:2 27 :2 10 60 :2 d :2 a :4 16 :2 a 7
:3 4 a 13 16 :2 13 d 16 28
:2 d 2b 2d :2 2b d 22 :2 2b :2 d
1c 2d 3b 46 5b 5c :2 5b :2 1c
:2 d :2 16 22 d 17 2a 34 3e
46 51 5f 6b 73 7a 15 2a
36 3e 46 51 5c 6a 15 16
23 34 3e 4c 5a 14 :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 62 63
:2 5e :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 96
99 :2 2d a1 a4 :2 2d b0 b3 ba
c3 c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10
:4 1c :2 10 d :3 2f 11 :2 1a 25 23
:2 2e :2 23 :2 10 1f :2 10 27 10 1a
2d 3a 4b 51 60 18 19 26
34 42 4f :2 13 :2 1c 28 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 65 66 :2 61 :2 35 :3 19
:2 1f 24 30 73 76 :2 30 83 86
:2 30 8a 8d :2 30 99 9c :2 30 a4
a7 :2 30 b3 b6 bd c6 c9 :2 b6
:2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13 10
:3 3e 14 :2 1d 28 26 :2 31 :2 26 13
1d 20 33 36 43 4a 4d 5c
62 65 1b 21 30 1b 23 27
3c 1c 1f 2c 3a 3d 4a 4d
5c 5f 1a 1d 2b 2e 1d 34
45 4e 51 65 68 :2 16 :2 1f 2b
16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :3 41 17 :2 20 2b 29 :2 34
:2 29 16 :4 49 48 :3 16 29 37 3a
43 4b :2 3a 4f :2 58 24 :2 29 16
20 39 47 51 19 26 34 46
52 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 67 6b 6c
:2 67 :2 3b :3 1f :2 25 2a 36 79 7c
:2 36 89 8c :2 36 90 93 :2 36 9f
a2 :2 36 aa ad :2 36 b9 bc c3
cc cf :2 bc :2 36 :2 1f 6f :2 1c :2 19
:4 25 :2 19 16 :3 5b 16 29 :2 16 29
45 53 62 :2 29 :2 16 29 :2 16 29
45 53 5d :2 29 16 20 2c 3b
44 52 58 1f 2c 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 67
6b 6c :2 67 :2 3b :3 1f :2 25 2a 36
79 7c :2 36 89 8c :2 36 90 93
:2 36 9f a2 :2 36 aa ad :2 36 b9
bc c3 cc cf :2 bc :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :3 5b 19 22
2f :2 19 34 32 :2 3d :2 32 28 22
36 1c 23 1f 2b :3 29 1f :2 28
34 1f 30 1f :2 28 34 1f :4 1c
19 21 1f :2 28 34 1f 2f :2 1c
:2 21 1f :2 28 34 1f 22 :2 2c 3e
:2 48 54 58 6a 6e 6f :2 6a :2 3e
:3 22 :2 28 2d 39 7c 7f :2 39 8c
8f :2 39 93 96 :2 39 a2 a5 :2 39
ad b0 :2 39 bc bf c6 cf d2
:2 bf :2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c
19 :3 51 19 28 :2 19 2c :2 19 2c
48 56 64 :2 2c 19 51 :2 16 13
5b 19 22 2f :2 19 34 32 :2 3d
:2 32 16 29 37 3a 43 4b :2 3a
4f :2 58 24 :2 29 16 20 39 47
51 19 26 34 42 4b 5a 66
1f 33 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 67 6b 6c :2 67
:2 3b :3 1f :2 25 2a 36 79 7c :2 36
89 8c :2 36 90 93 :2 36 9f a2
:2 36 aa ad :2 36 b9 bc c3 cc
cf :2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25
:2 19 16 :3 51 16 29 :2 16 29 45
53 61 :2 29 :2 16 29 :2 16 29 45
53 5d :2 29 16 20 2c 3b 44
52 62 1f 2c 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 67 6b
6c :2 67 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :4 51 5b 20 2c
1e 25 34 3b 55 1e 2e 1f
2c 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :3 13 16 29 37 3a 43 4b
:2 3a 4f :2 58 24 :2 29 :2 16 2c :2 35
:2 16 29 :2 16 28 :2 16 29 40 4e
58 60 2d 41 52 :2 29 :2 16 26
2f 38 40 :2 2f :2 26 :2 16 :3 25 16
25 3a 4d 59 65 19 28 35
41 4e 5b 19 23 21 2e 3c
47 19 2a 34 42 56 6a 19
26 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :7 13 10 41 17 :2 20 2b 29
:2 34 :2 29 16 13 22 13 17 1e
27 36 :2 1e 3a :2 43 :2 17 16 55
53 :2 5e :2 53 20 19 27 19 28
19 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 67 6b 6c
:2 67 :2 3b :3 1f :2 25 2a 36 79 7c
:2 36 89 8c :2 36 90 93 :2 36 9f
a2 :2 36 aa ad :2 36 b9 bc c3
cc cf :2 bc :2 36 :2 1f 6f :2 1c :2 19
:4 25 :2 19 16 :3 6c 13 6c 19 22
31 :2 19 36 34 :2 3f :2 34 16 29
37 3a 43 4b :2 3a 4f :2 58 24
:2 29 16 20 19 28 31 19 28
19 27 19 28 19 1f 33 19
20 1c 28 :3 26 1c :2 25 31 1c
2d 1c :2 25 31 1c :4 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 67 6b 6c :2 67 :2 3b :3 1f :2 25
2a 36 79 7c :2 36 89 8c :2 36
90 93 :2 36 9f a2 :2 36 aa ad
:2 36 b9 bc c3 cc cf :2 bc :2 36
:2 1f 6f :2 1c :2 19 :4 25 :2 19 16 :4 4e
6c 20 19 28 31 38 46 4f
19 28 19 27 19 28 19 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :7 13 44 41 :2 10 3e 10 1f
:2 10 27 10 13 1a 26 29 :2 13
2c 2e :2 2c 13 22 13 32 :2 10
:4 d 11 1a 28 :2 11 2b 2d :2 2b
10 :4 36 35 34 :2 10 24 46 56
18 2a 38 43 :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 61 65 66 :2 61 :2 35
:3 19 :2 1f 24 30 73 76 :2 30 83
86 :2 30 8a 8d :2 30 99 9c :2 30
a4 a7 :2 30 b3 b6 bd c6 c9
:2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f :2 13
10 :3 51 14 :2 1d 28 26 :2 31 :2 26
13 46 4f 5d :2 46 60 62 :2 60
45 :2 13 1d 29 39 4c 57 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :3 65
10 65 17 :2 20 2b 29 :2 34 :2 29
16 49 52 60 :2 49 63 65 :2 63
48 :2 16 13 23 :2 2c :2 13 21 :3 13
68 65 :2 10 51 :3 d 23 d 1e
15 17 1a 31 46 4a 5b 16
19 26 37 3a 44 52 55 69
6c 14 17 24 35 38 :2 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5e 62 63
:2 5e :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 96
99 :2 2d a1 a4 :2 2d b0 b3 ba
c3 c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10
:4 1c :2 10 d :3 2f 14 1d 31 :2 14
34 37 :2 34 :3 10 1a 13 25 34
47 57 6c 7e 8f 13 2a 3e
58 13 24 32 43 51 62 70
81 13 19 2d 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 65
66 :2 61 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 83 86 :2 30 8a 8d :2 30
99 9c :2 30 a4 a7 :2 30 b3 b6
bd c6 c9 :2 b6 :2 30 :2 19 69 :2 16
:2 13 :4 1f :2 13 10 :4 39 :2 d 10 19
26 :2 10 2b 29 :2 34 :2 29 10 27
10 :4 14 13 1d 2e 17 1a 25
28 3d 3f 4a 52 59 5c 67
69 1b 2c 1c 1e 2b 3c 3e
52 6a 6c 77 7a 1c 1f 2c
3d 40 54 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 64 68 69
:2 64 :2 38 :3 1c :2 22 27 33 76 79
:2 33 86 89 :2 33 8d 90 :2 33 9c
9f :2 33 a7 aa :2 33 b6 b9 c0
c9 cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16
:4 22 :2 16 13 :4 35 :3 10 18 22 :3 10
:2 19 25 10 13 1c 27 :2 13 2a
2c :2 2a 32 3b 43 :2 32 46 48
:2 46 :2 13 22 1d 1f 1b 30 1c
1e 2b 38 3a 4b 53 5a 71
79 80 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :4 4a 22 1d 1f 1b 30
33 44 1c 1e 2b 38 3a 4b
53 5a 71 79 80 1a 1e 2b
3c 40 54 1a 1c 27 2b 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :7 10
14 :2 1d 28 26 :2 31 :2 26 :2 13 21
13 1d 23 2e 32 41 4d 1b
:2 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 64
68 69 :2 64 :2 38 :3 1c :2 22 27 33
76 79 :2 33 86 89 :2 33 8d 90
:2 33 9c 9f :2 33 a7 aa :2 33 b6
b9 c0 c9 cc :2 b9 :2 33 :2 1c 6c
:2 19 :2 16 :4 22 :2 16 13 :3 41 16 1f
2b :2 16 2e 30 :2 2e 1b 16 32
:2 13 22 1c 29 3a 4e 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 68 69 :2 64 :2 38 :3 1c :2 22 27
33 76 79 :2 33 86 89 :2 33 8d
90 :2 33 9c 9f :2 33 a7 aa :2 33
b6 b9 c0 c9 cc :2 b9 :2 33 :2 1c
6c :2 19 :2 16 :4 22 :2 16 13 :3 41 13
20 27 30 3a :2 30 4d :2 27 50
52 5b 65 :2 5b 72 :2 52 :2 27 26
1e 20 :2 26 :2 20 13 1d 2c 3b
48 1b 1c 29 3a 45 :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 64 68 69
:2 64 :2 38 :3 1c :2 22 27 33 76 79
:2 33 86 89 :2 33 8d 90 :2 33 9c
9f :2 33 a7 aa :2 33 b6 b9 c0
c9 cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16
:4 22 :2 16 13 :3 41 16 1f 2c :2 16
31 2f 3a 45 :2 31 :2 2f 16 :2 1f
38 41 4c :2 38 50 :2 16 48 :2 13
22 :10 16 20 34 4d 16 1b 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :3 41
1d 16 2a 37 45 4f 16 38
56 16 2f 4d 5e 16 2f 4d
5e 16 2f 4d 5e 16 2f 4d
5e 16 25 2e 35 42 4b 16
28 31 38 49 52 1c 30 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :3 41
13 26 2d 36 40 :2 36 4c :2 2d
4f 51 5a 64 :2 5a 70 :2 51 :2 2d
2c 24 26 :2 2c :2 26 :2 13 21 :2 2a
31 3a 4b :2 31 4f :2 58 :2 21 :2 13
26 36 44 59 65 24 2f :2 65
33 3c 4e :2 33 52 :2 26 13 41
18 13 :4 10 48 10 1c :2 10 20
:2 10 21 10 13 1c 29 :2 13 2c
2f :2 2c 16 1f 2a :2 16 30 2d
39 45 :2 30 :2 2d 4b 54 5c :2 4b
62 5f 6b 74 :2 62 :2 5f :2 16 2b
:2 36 3e 4c 58 :2 2b 5c 5e :2 5c
2a :3 16 26 :2 2f :2 16 24 :3 16 13
61 19 :2 24 2c 3a 46 :2 19 4a
4c :2 4a 20 2f 3f 1f 2c 1d
31 1d 2b :2 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 67 6b 6c :2 67 :2 3b :3 1f
:2 25 2a 36 79 7c :2 36 89 8c
:2 36 90 93 :2 36 9f a2 :2 36 aa
ad :2 36 b9 bc c3 cc cf :2 bc
:2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19 16
:3 4e 1a :2 23 2e 2c :2 37 :2 2c :2 19
25 2e 38 :2 25 3b 3d 46 52
:2 3d :2 25 19 28 22 2f 20 34
20 2e 1c 23 1f 2b :3 29 1f
:2 28 34 1f 30 1f :2 28 34 1f
:4 1c 19 21 1f :2 28 34 1f 2f
:2 1c :2 21 1f :2 28 34 1f 22 :2 2c
3e :2 48 54 58 6a 6e 6f :2 6a
:2 3e :3 22 :2 28 2d 39 7c 7f :2 39
8c 8f :2 39 93 96 :2 39 a2 a5
:2 39 ad b0 :2 39 bc bf c6 cf
d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c :4 28
:2 1c 19 :4 47 :2 16 4e 61 :2 13 31
1a 23 26 :2 23 :3 16 :4 2d 2c :3 16
24 :2 2d 16 4e :2 13 16 1f 2a
:2 16 30 2d 39 45 :2 30 :2 2d 4b
54 5c :2 4b 62 5f 27 30 :2 62
:2 5f :3 16 2b 16 19 22 2e :2 19
31 33 :2 31 19 2c 19 35 :2 16
33 :3 13 24 :2 13 1d :2 13 23 :2 13
1e :2 13 1d :2 13 20 :2 13 20 13
17 20 2b :2 17 2e 30 :2 2e 16
38 41 49 :2 38 4c 4f :2 4c 37
:3 16 20 16 13 54 19 22 2a
:2 19 2d 2f :2 2d 16 29 32 3a
:2 29 16 33 54 :2 13 :5 10 1e 2f
3d 4c 55 5e :2 4c 62 20 28
:2 62 2c 35 41 :2 2c 45 4e 59
:2 45 22 2b 36 :2 22 3a 43 51
:2 3a 55 20 2b :2 55 2f 38 44
:2 2f 48 50 5a :2 1e 10 13 1c
28 :2 13 2d 2b :2 36 :2 2b 16 1c
:3 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 64
68 69 :2 64 :2 38 :3 1c :2 22 27 33
76 79 :2 33 86 89 :2 33 8d 90
:2 33 9c 9f :2 33 a7 aa :2 33 b6
b9 c0 c9 cc :2 b9 :2 33 :2 1c 6c
:2 19 :2 16 :4 22 :2 16 13 :3 45 16 :2 20
32 :2 3c 48 4b 5d 61 62 :2 5d
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 94 97
a0 a8 :2 b1 :2 a0 c2 :2 97 :2 2d :2 16
65 :2 13 16 :2 20 32 :2 3c 48 4b
5d 61 62 :2 5d :2 32 :3 16 :2 1c 21
2d 70 73 :2 2d :2 16 65 :3 13 :2 1e
34 :2 3d 4d :2 13 10 45 16 1f
2b :2 16 2e 31 :2 2e 13 23 2c
38 :2 23 :2 13 21 :3 13 33 45 :3 10
19 10 13 1c 29 :2 13 2c 2f
:2 2c 13 1f 13 16 1f 27 :2 16
2a 2c :2 2a 16 23 :2 2c 16 2e
16 23 :2 2c 33 3c 47 :2 33 4b
:2 54 :2 23 16 :4 13 10 31 16 1f
2b :2 16 30 2e :2 39 :2 2e 13 1f
13 16 1f 27 :2 16 2a 2c :2 2a
16 23 :2 2c 16 2e 16 23 :2 2c
33 3c 47 :2 33 4b :2 54 :2 23 16
:4 13 4e 31 13 1f 13 16 1f
27 :2 16 2a 2c :2 2a 16 23 :2 2c
16 2e 16 23 :2 2c 33 3c 47
:2 33 4b :2 54 :2 23 16 :4 13 :5 10 20
:2 10 1c 28 3d 4b 56 60 1b
23 2f 3b 47 53 1b 2a 36
40 48 51 59 1b 27 33 40
4b 56 1b 25 30 3c 48 4b
4e 54 5a 5d :2 1c 10 13 1c
1e :2 1c 13 23 :2 2c :2 13 21 :3 13
10 22 16 1f 22 :2 1f 13 23
:2 2c :2 13 21 :3 13 24 22 :4 17 16
19 22 2f :2 19 32 34 :2 32 23
36 43 51 21 36 44 53 21
22 2f 40 4a 58 66 :2 1c :2 25
31 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 6a 6e 6f
:2 6a :2 3e :3 22 :2 28 2d 39 7c 7f
:2 39 8c 8f :2 39 93 96 :2 39 a2
a5 :2 39 ad b0 :2 39 bc bf c6
cf d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c
:4 28 :2 1c 19 :4 36 23 36 45 55
21 36 44 53 21 22 2f 40
4a 58 66 :2 1c :2 25 31 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6a 6e 6f :2 6a :2 3e :3 22
:2 28 2d 39 7c 7f :2 39 8c 8f
:2 39 93 96 :2 39 a2 a5 :2 39 ad
b0 :2 39 bc bf c6 cf d2 :2 bf
:2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c 19
:7 16 34 19 22 2f :2 19 32 34
:2 32 23 38 3e 22 36 1c 23
1f 2b :3 29 1f :2 28 34 1f 30
1f :2 28 34 1f :4 1c 19 21 1f
:2 28 34 1f 2f :2 1c :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
6a 6e 6f :2 6a :2 3e :3 22 :2 28 2d
39 7c 7f :2 39 8c 8f :2 39 93
96 :2 39 a2 a5 :2 39 ad b0 :2 39
bc bf c6 cf d2 :2 bf :2 39 :2 22
72 :2 1f :2 1c :4 28 :2 1c 19 :3 36 19
27 :2 19 2c 3c 4a 5f 6b 24
2f :2 6b 33 36 :2 2c 19 23 30
21 2f 21 22 36 :2 1c :2 25 31
1c 19 21 1f :2 28 34 1f 2f
:2 1c :2 21 1f :2 28 34 1f 22 :2 2c
3e :2 48 54 58 6a 6e 6f :2 6a
:2 3e :3 22 :2 28 2d 39 7c 7f :2 39
8c 8f :2 39 93 96 :2 39 a2 a5
:2 39 ad b0 :2 39 bc bf c6 cf
d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c :4 28
:2 1c 19 :4 36 23 38 3e 22 36
1c 23 1f 2b :3 29 1f :2 28 34
1f 30 1f :2 28 34 1f :4 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6a 6e 6f :2 6a :2 3e :3 22
:2 28 2d 39 7c 7f :2 39 8c 8f
:2 39 93 96 :2 39 a2 a5 :2 39 ad
b0 :2 39 bc bf c6 cf d2 :2 bf
:2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c 19
:3 16 19 27 :2 19 2c 3c 4a 5f
6b 24 2f :2 6b 33 36 :2 2c 19
23 32 21 2f 21 22 36 :2 1c
:2 25 31 1c 19 21 1f :2 28 34
1f 2f :2 1c :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 6a 6e
6f :2 6a :2 3e :3 22 :2 28 2d 39 7c
7f :2 39 8c 8f :2 39 93 96 :2 39
a2 a5 :2 39 ad b0 :2 39 bc bf
c6 cf d2 :2 bf :2 39 :2 22 72 :2 1f
:2 1c :4 28 :2 1c 19 :7 16 19 22 2e
:2 19 31 34 :2 31 19 25 2e 38
:2 25 3b 3d 46 52 :2 3d :2 25 19
36 :2 16 :4 13 17 :2 20 2c 29 :2 35
:2 29 :2 16 26 :2 2f :2 16 24 :3 16 45
:2 13 :4 10 13 1c 29 :2 13 2c 2f
:2 2c 1d 16 29 3f 4f 16 28
31 38 49 52 16 25 2e 35
42 4b 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :4 31 1d 16 2f
4d 5e 16 2f 4d 5e 16 2f
4d 5e 16 2f 4d 5e 16 25
2e 35 42 4b 16 28 31 38
49 52 1c 30 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :7 10 13 1c 2e
:2 13 33 31 3c 46 :2 33 :2 31 13
21 39 4e 5a 29 3e 4c 29
37 40 4b :2 37 4f 58 62 :2 4f
29 2c 35 41 :2 2c :2 21 :2 13 28
:2 31 :2 13 22 33 41 4f 64 :2 22
:2 13 :2 1c 28 13 49 22 1c 29
1a 2e 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :3 10 16 1f 2c :2 16 2f
32 :2 2f 25 1f 33 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 67
6b 6c :2 67 :2 3b :3 1f :2 25 2a 36
79 7c :2 36 89 8c :2 36 90 93
:2 36 9f a2 :2 36 aa ad :2 36 b9
bc c3 cc cf :2 bc :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :3 34 16 2b
:2 34 :2 16 25 3c 49 :2 25 :2 16 :2 1f
2b 16 25 40 54 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 67
6b 6c :2 67 :2 3b :3 1f :2 25 2a 36
79 7c :2 36 89 8c :2 36 90 93
:2 36 9f a2 :2 36 aa ad :2 36 b9
bc c3 cc cf :2 bc :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :4 34 20 19
24 19 25 :e 19 1f 33 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
67 6b 6c :2 67 :2 3b :3 1f :2 25 2a
36 79 7c :2 36 89 8c :2 36 90
93 :2 36 9f a2 :2 36 aa ad :2 36
b9 bc c3 cc cf :2 bc :2 36 :2 1f
6f :2 1c :2 19 :4 25 :2 19 16 :7 13 :5 10
1e :2 10 23 33 41 56 62 24
2f :2 62 33 36 :2 23 10 :4 d 14
1d 2a :2 14 2d 30 :2 2d :3 10 1f
1a 2f 31 3d 3f 55 57 66
68 7d 7f 18 29 2b 30 39
3e 40 4d 4f 5d 5f 6c 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 61 65 66 :2 61 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 99 9c :2 30 a4 a7
:2 30 b3 b6 bd c6 c9 :2 b6 :2 30
:2 19 69 :2 16 :2 13 :4 1f :2 13 10 :3 32
1f 1a 2f 38 4e 5d 72 86
18 34 48 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 65 66
:2 61 :2 35 :3 19 :2 1f 24 30 73 76
:2 30 83 86 :2 30 8a 8d :2 30 99
9c :2 30 a4 a7 :2 30 b3 b6 bd
c6 c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13
:4 1f :2 13 10 :3 32 1f 1a 2f 39
4f 5e 73 87 18 35 49 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 61 65 66 :2 61 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 99 9c :2 30 a4 a7
:2 30 b3 b6 bd c6 c9 :2 b6 :2 30
:2 19 69 :2 16 :2 13 :4 1f :2 13 10 :4 32
:2 d 2f :2 a 18 a 16 1f 31
:2 16 a d 16 20 :2 d 23 25
:2 23 d 20 37 44 :2 20 d 1c
37 4b 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 62 63 :2 5e
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 96 99
:2 2d a1 a4 :2 2d b0 b3 ba c3
c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c
:2 10 d :3 27 1c 33 47 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 62 63 :2 5e :2 32 :3 16 :2 1c 21
2d 70 73 :2 2d 80 83 :2 2d 87
8a :2 2d 96 99 :2 2d a1 a4 :2 2d
b0 b3 ba c3 c6 :2 b3 :2 2d :2 16
66 :2 13 :2 10 :4 1c :2 10 d :3 27 1c
2e 42 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 62 63 :2 5e
:2 32 :3 16 :2 1c 21 2d 70 73 :2 2d
80 83 :2 2d 87 8a :2 2d 96 99
:2 2d a1 a4 :2 2d b0 b3 ba c3
c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10 :4 1c
:2 10 d :3 27 1c 33 40 51 65
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 96 99 :2 2d a1
a4 :2 2d b0 b3 ba c3 c6 :2 b3
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:3 27 1c 38 4c 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 62
63 :2 5e :2 32 :3 16 :2 1c 21 2d 70
73 :2 2d 80 83 :2 2d 87 8a :2 2d
96 99 :2 2d a1 a4 :2 2d b0 b3
ba c3 c6 :2 b3 :2 2d :2 16 66 :2 13
:2 10 :4 1c :2 10 d :3 27 1c 39 4d
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 96 99 :2 2d a1
a4 :2 2d b0 b3 ba c3 c6 :2 b3
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:4 27 10 19 25 :2 10 28 2a :2 28
10 27 10 2c :2 d 17 14 22
16 2a 14 21 14 22 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 62 63 :2 5e :2 32 :3 16 :2 1c 21
2d 70 73 :2 2d 80 83 :2 2d 87
8a :2 2d 96 99 :2 2d a1 a4 :2 2d
b0 b3 ba c3 c6 :2 b3 :2 2d :2 16
66 :2 13 :2 10 :4 1c :2 10 d :3 a 17
2a 38 4d 15 16 23 34 3e
4c 5a 14 :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5e 62 63 :2 5e :2 32 :3 16
:2 1c 21 2d 70 73 :2 2d 80 83
:2 2d 87 8a :2 2d 96 99 :2 2d a1
a4 :2 2d b0 b3 ba c3 c6 :2 b3
:2 2d :2 16 66 :2 13 :2 10 :4 1c :2 10 d
:3 a 11 :2 1a 25 23 :2 2e :2 23 :2 10
1f 10 1a 2d 3a 4b 51 60
18 19 26 34 42 4f :2 13 :2 1c
28 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 65 66
:2 61 :2 35 :3 19 :2 1f 24 30 73 76
:2 30 83 86 :2 30 8a 8d :2 30 99
9c :2 30 a4 a7 :2 30 b3 b6 bd
c6 c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13
:4 1f :2 13 10 :3 3e 14 :2 1d 28 26
:2 31 :2 26 13 17 1e 27 36 :2 1e
3a :2 43 :2 17 16 55 53 :2 5e :2 53
16 22 16 20 19 27 19 28
19 1f 33 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 67 6b 6c
:2 67 :2 3b :3 1f :2 25 2a 36 79 7c
:2 36 89 8c :2 36 90 93 :2 36 9f
a2 :2 36 aa ad :2 36 b9 bc c3
cc cf :2 bc :2 36 :2 1f 6f :2 1c :2 19
:4 25 :2 19 16 :3 6c 13 6c 19 22
31 :2 19 36 34 :2 3f :2 34 16 29
37 3a 43 4b :2 3a 4f :2 58 24
:2 29 16 20 19 28 31 19 28
19 27 19 28 19 1f 33 19
20 1c 28 :3 26 1c :2 25 31 1c
2d 1c :2 25 31 1c :4 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 67 6b 6c :2 67 :2 3b :3 1f :2 25
2a 36 79 7c :2 36 89 8c :2 36
90 93 :2 36 9f a2 :2 36 aa ad
:2 36 b9 bc c3 cc cf :2 bc :2 36
:2 1f 6f :2 1c :2 19 :4 25 :2 19 16 :4 4e
6c 20 19 28 31 38 46 4f
19 28 19 27 19 28 19 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :7 13 17 :2 20 2b 29 :2 34 :2 29
16 49 52 5c :2 49 5f 61 :2 5f
48 :2 16 25 40 54 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 67
6b 6c :2 67 :2 3b :3 1f :2 25 2a 36
79 7c :2 36 89 8c :2 36 90 93
:2 36 9f a2 :2 36 aa ad :2 36 b9
bc c3 cc cf :2 bc :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :4 64 :2 13 41
1d 20 33 3a 3d 4c 52 55
1b 20 1b 23 27 3c 1c 1f
2c 3a 3d 4a 4d 5c 5f 1a
1d 2b 2e 1d 34 45 4e 51
65 68 :2 16 :2 1f 2b 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :3 10
17 :2 20 2b 29 :2 34 :2 29 16 :4 4a
49 48 :3 16 29 37 3a 43 4b
:2 3a 4f :2 58 24 :2 29 16 25 40
54 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :3 5d 20 39 47 51 19 26
34 46 52 1f 33 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 67
6b 6c :2 67 :2 3b :3 1f :2 25 2a 36
79 7c :2 36 89 8c :2 36 90 93
:2 36 9f a2 :2 36 aa ad :2 36 b9
bc c3 cc cf :2 bc :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :3 5d 20 2c
3b 44 52 58 1f 2c 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
67 6b 6c :2 67 :2 3b :3 1f :2 25 2a
36 79 7c :2 36 89 8c :2 36 90
93 :2 36 9f a2 :2 36 aa ad :2 36
b9 bc c3 cc cf :2 bc :2 36 :2 1f
6f :2 1c :2 19 :4 25 :2 19 16 :4 5d 20
2c 1e 25 34 3b 55 1e 2e
1f 2c 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 67 6b 6c :2 67
:2 3b :3 1f :2 25 2a 36 79 7c :2 36
89 8c :2 36 90 93 :2 36 9f a2
:2 36 aa ad :2 36 b9 bc c3 cc
cf :2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25
:2 19 16 :3 13 20 39 47 51 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :7 13 :4 10 13 1c 29 :2 13 2f
2c :2 38 :2 2c 4e 16 23 :2 4e 29
26 :2 32 :2 26 :2 13 22 39 46 57
6b 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 68 69 :2 64 :2 38
:3 1c :2 22 27 33 76 79 :2 33 86
89 :2 33 8d 90 :2 33 9c 9f :2 33
a7 aa :2 33 b6 b9 c0 c9 cc
:2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16
13 :4 46 :2 10 3e 10 1f 10 1f
3a 4e 13 1a 16 22 :3 20 16
:2 1f 2b 16 27 16 :2 1f 2b 16
:4 13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 65 66 :2 61
:2 35 :3 19 :2 1f 24 30 73 76 :2 30
83 86 :2 30 8a 8d :2 30 99 9c
:2 30 a4 a7 :2 30 b3 b6 bd c6
c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13 :4 1f
:2 13 10 :3 d 1f 36 4a 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
61 65 66 :2 61 :2 35 :3 19 :2 1f 24
30 73 76 :2 30 83 86 :2 30 8a
8d :2 30 99 9c :2 30 a4 a7 :2 30
b3 b6 bd c6 c9 :2 b6 :2 30 :2 19
69 :2 16 :2 13 :4 1f :2 13 10 :3 d 13
1a 26 29 :2 13 2c 2e :2 2c 13
22 13 32 :2 10 13 1c 29 :2 13
2f 2c :2 38 :2 2c 4e 16 23 :2 4e
29 26 :2 32 :2 26 :2 13 22 39 46
57 6b 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 68 69 :2 64
:2 38 :3 1c :2 22 27 33 76 79 :2 33
86 89 :2 33 8d 90 :2 33 9c 9f
:2 33 a7 aa :2 33 b6 b9 c0 c9
cc :2 b9 :2 33 :2 1c 6c :2 19 :2 16 :4 22
:2 16 13 :3 46 13 2a 13 46 :2 10
:4 d 10 19 23 :2 10 26 28 :2 26
14 1d 2b :2 14 2e 30 :2 2e 13
:4 39 38 37 :2 13 27 49 59 1b
2d 3b 46 :2 16 :2 1f 2b 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:3 54 17 :2 20 2b 29 :2 34 :2 29 16
49 52 60 :2 49 63 65 :2 63 48
:2 16 20 2c 3c 4f 5a 19 20
1c 28 :3 26 1c :2 25 31 1c 2d
1c :2 25 31 1c :4 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
67 6b 6c :2 67 :2 3b :3 1f :2 25 2a
36 79 7c :2 36 89 8c :2 36 90
93 :2 36 9f a2 :2 36 aa ad :2 36
b9 bc c3 cc cf :2 bc :2 36 :2 1f
6f :2 1c :2 19 :4 25 :2 19 16 :3 68 13
68 1a :2 23 2e 2c :2 37 :2 2c 19
4c 55 63 :2 4c 66 68 :2 66 4b
:2 19 16 26 :2 2f :2 16 24 :3 16 6b
68 :2 13 54 :2 10 13 1c 29 :2 13
2e 2c :2 37 :2 2c 4c 16 23 :2 4c
28 26 :2 31 :2 26 :3 13 1b 25 :3 13
:2 1c 28 13 16 1f 2a :2 16 2d
2f :2 2d 35 3e 46 :2 35 49 4b
:2 49 :2 16 25 20 22 1e 33 1f
21 2e 3b 3d 4e 56 5d 74
7c 83 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 67 6b 6c :2 67
:2 3b :3 1f :2 25 2a 36 79 7c :2 36
89 8c :2 36 90 93 :2 36 9f a2
:2 36 aa ad :2 36 b9 bc c3 cc
cf :2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25
:2 19 16 :4 4d 25 20 22 1e 33
36 47 1f 21 2e 3b 3d 4e
56 5d 74 7c 83 1d 21 2e
3f 43 57 1d 1f 2a 2e 19
20 1c 28 :3 26 1c :2 25 31 1c
2d 1c :2 25 31 1c :4 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 67 6b 6c :2 67 :2 3b :3 1f :2 25
2a 36 79 7c :2 36 89 8c :2 36
90 93 :2 36 9f a2 :2 36 aa ad
:2 36 b9 bc c3 cc cf :2 bc :2 36
:2 1f 6f :2 1c :2 19 :4 25 :2 19 16 :7 13
17 :2 20 2b 29 :2 34 :2 29 :2 16 21
16 20 26 31 35 40 44 53
5c 6a 1e :2 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 67 6b 6c :2 67 :2 3b :3 1f
:2 25 2a 36 79 7c :2 36 89 8c
:2 36 90 93 :2 36 9f a2 :2 36 aa
ad :2 36 b9 bc c3 cc cf :2 bc
:2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19 16
:3 44 19 22 2b :2 19 2e 30 :2 2e
1e 19 32 28 22 2f 40 54
1c 23 1f 2b :3 29 1f :2 28 34
1f 30 1f :2 28 34 1f :4 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6a 6e 6f :2 6a :2 3e :3 22
:2 28 2d 39 7c 7f :2 39 8c 8f
:2 39 93 96 :2 39 a2 a5 :2 39 ad
b0 :2 39 bc bf c6 cf d2 :2 bf
:2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c 19
:3 16 1c 25 32 :2 1c 35 38 :2 35
:4 3f 3e :2 1c :4 24 23 :3 1c 33 1c
45 :3 19 26 2d 36 40 :2 36 4b
:2 2d 4e 50 59 63 :2 59 6d :2 50
:2 2d 2c 71 73 :2 2c :2 26 19 23
32 41 4e 21 22 2f 40 4b
:2 1c :2 25 31 1c 19 21 1f :2 28
34 1f 2f :2 1c :2 21 1f :2 28 34
1f 22 :2 2c 3e :2 48 54 58 6a
6e 6f :2 6a :2 3e :3 22 :2 28 2d 39
7c 7f :2 39 8c 8f :2 39 93 96
:2 39 a2 a5 :2 39 ad b0 :2 39 bc
bf c6 cf d2 :2 bf :2 39 :2 22 72
:2 1f :2 1c :4 28 :2 1c 19 :3 16 19 27
19 23 32 21 32 23 34 38
45 56 5a 6e 20 24 32 3f
43 56 5a 23 25 33 46 4e
50 5b 5f :2 1c :2 25 31 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6a 6e 6f :2 6a :2 3e :3 22
:2 28 2d 39 7c 7f :2 39 8c 8f
:2 39 93 96 :2 39 a2 a5 :2 39 ad
b0 :2 39 bc bf c6 cf d2 :2 bf
:2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c 19
:3 16 1c 25 31 :2 1c 34 37 :2 34
1c 2a 33 3f :2 2a 42 44 4d
58 :2 44 :2 2a :2 1c 28 :2 1c :2 25 3e
47 53 :2 3e 57 :2 1c 1f 28 35
:2 1f 3a 38 43 4f :2 3a :2 38 1f
:2 28 41 4a 56 :2 41 5a :2 1f 52
:2 1c 26 37 1f 23 2f 33 3f
1f 23 2f 37 3e 42 4c 25
29 36 47 4b 5f 23 27 35
42 46 59 5d 26 28 36 49
51 53 5e 62 1f 26 22 2e
:3 2c 22 :2 2b 37 22 33 22 :2 2b
37 22 :4 1f 1c 24 22 :2 2b 37
22 32 :2 1f :2 24 22 :2 2b 37 22
25 :2 2f 41 :2 4b 57 5b 6d 71
72 :2 6d :2 41 :3 25 :2 2b 30 3c 7f
82 :2 3c 8f 92 :2 3c 96 99 :2 3c
a5 a8 :2 3c b0 b3 :2 3c bf c2
c9 d2 d5 :2 c2 :2 3c :2 25 75 :2 22
:2 1f :4 2b :2 1f 1c :4 39 :2 19 1c 25
32 :2 1c 37 35 40 4b :2 37 :2 35
1c :2 25 3e 47 52 :2 3e 56 :2 1c
4e :2 19 28 :e 1c 1e :2 1c 26 3a
53 1c 21 34 3c 3e 56 5a
68 79 22 26 33 44 48 5c
20 24 32 3f 43 56 58 63
67 1c 23 1f 2b :3 29 1f :2 28
34 1f 30 1f :2 28 34 1f :4 1c
19 21 1f :2 28 34 1f 2f :2 1c
:2 21 1f :2 28 34 1f 22 :2 2c 3e
:2 48 54 58 6a 6e 6f :2 6a :2 3e
:3 22 :2 28 2d 39 7c 7f :2 39 8c
8f :2 39 93 96 :2 39 a2 a5 :2 39
ad b0 :2 39 bc bf c6 cf d2
:2 bf :2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c
19 :3 16 1c 25 31 :2 1c 34 37
:2 34 1c 2a 33 3e :2 2a 41 43
4c 55 :2 43 :2 2a 1c 1f 28 32
:2 1f 38 35 41 4d :2 38 :2 35 1f
2c 35 40 :2 2c 43 45 4e 5b
:2 45 :2 2c 5e 61 6a 75 :2 61 25
28 31 3b :2 28 3e 40 :2 28 27
:2 61 60 :2 2c 1f 22 2b 36 :2 22
39 3c :2 39 2c 25 31 3d 2b
38 29 3d 29 34 25 2c 28
34 :3 32 28 :2 31 3d 28 39 28
:2 31 3d 28 :4 25 22 2a 28 :2 31
3d 28 38 :2 25 :2 2a 28 :2 31 3d
28 2b :2 35 47 :2 51 5d 61 73
77 78 :2 73 :2 47 :3 2b :2 31 36 42
85 88 :2 42 95 98 :2 42 9c 9f
:2 42 ab ae :2 42 b6 b9 :2 42 c5
c8 cf d8 db :2 c8 :2 42 :2 2b 7b
:2 28 :2 25 :4 31 :2 25 22 :4 3e :2 1f 50
:2 1c 26 2a 3a 24 25 39 :2 1f
:2 28 34 1f 1c 24 22 :2 2b 37
22 32 :2 1f :2 24 22 :2 2b 37 22
25 :2 2f 41 :2 4b 57 5b 6d 71
72 :2 6d :2 41 :3 25 :2 2b 30 3c 7f
82 :2 3c 8f 92 :2 3c 96 99 :2 3c
a5 a8 :2 3c b0 b3 :2 3c bf c2
c9 d2 d5 :2 c2 :2 3c :2 25 75 :2 22
:2 1f :4 2b :2 1f 1c :4 39 1c 2a 33
3e :2 2a 41 43 4c 55 :2 43 :2 2a
1c 1f 28 32 :2 1f 38 35 41
4d :2 38 :2 35 1f 2d 36 43 :2 2d
46 49 52 5d :2 49 60 63 6c
76 :2 63 79 7b :2 63 62 :2 49 48
:2 2d 1f 22 2b 37 :2 22 3d 3a
46 51 :2 3d :2 3a 2c 25 31 2b
38 29 3d 29 34 25 2c 28
34 :3 32 28 :2 31 3d 28 39 28
:2 31 3d 28 :4 25 22 2a 28 :2 31
3d 28 38 :2 25 :2 2a 28 :2 31 3d
28 2b :2 35 47 :2 51 5d 61 73
77 78 :2 73 :2 47 :3 2b :2 31 36 42
85 88 :2 42 95 98 :2 42 9c 9f
:2 42 ab ae :2 42 b6 b9 :2 42 c5
c8 cf d8 db :2 c8 :2 42 :2 2b 7b
:2 28 :2 25 :4 31 :2 25 22 :4 54 :2 1f 50
:2 1c :4 19 :4 16 20 35 43 4d 19
3b 59 19 32 50 61 19 32
50 61 19 32 50 61 19 32
50 61 19 28 31 38 45 4e
19 2b 34 3b 4c 55 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 67 6b 6c :2 67 :2 3b :3 1f
:2 25 2a 36 79 7c :2 36 89 8c
:2 36 90 93 :2 36 9f a2 :2 36 aa
ad :2 36 b9 bc c3 cc cf :2 bc
:2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19 16
:3 44 16 29 30 39 43 :2 39 4f
:2 30 52 54 5d 67 :2 5d 73 :2 54
:2 30 2f 24 26 :2 2f :2 29 :2 16 24
:2 2d 34 3d 4e :2 34 52 :2 5b :2 24
:2 16 29 39 47 5c 68 24 2f
:2 68 33 3c 46 :2 33 4a :2 29 16
44 1b 16 :4 13 45 13 24 13
16 1f 2a :2 16 2d 2f :2 2d 35
3e 46 :2 35 49 4b :2 49 :2 16 51
5a 6b :2 51 6e 71 :2 6e :2 16 1d
26 37 :2 1d 3a 3d :2 3a :3 16 20
:2 16 20 29 3a :2 20 16 3f :2 13
17 20 2c :2 17 2f 31 :2 2f 16
38 41 4d :2 38 52 50 5b 66
:2 52 :2 50 37 :3 16 24 2d 38 :2 24
16 6a 16 24 2a 33 3f :2 2a
42 44 4d 58 :2 44 :2 2a :2 24 16
:4 13 16 1f 2b :2 16 2e 30 :2 2e
16 24 2d 39 :2 24 3c 3e :2 24
16 33 16 24 2a 34 3d 49
:2 34 :2 2a 4d 4f :2 2a :2 24 16 :4 13
16 1f 2c :2 16 2f 32 :2 2f 20
1d 2f 38 3f 50 59 19 28
31 38 45 4e 19 1f 25 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6b 6c :2 67 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :4 34 20 1d 2b :2 19 3b 59
19 32 50 61 19 32 50 61
19 32 50 61 19 32 50 61
19 1f 19 28 31 38 45 4e
19 2b 34 3b 4c 55 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 67 6b 6c :2 67 :2 3b :3 1f
:2 25 2a 36 79 7c :2 36 89 8c
:2 36 90 93 :2 36 9f a2 :2 36 aa
ad :2 36 b9 bc c3 cc cf :2 bc
:2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19 16
:8 13 1c 13 16 1f 2b :2 16 30
2e :2 39 :2 2e 16 22 16 4e 16
22 16 :4 13 16 1f 27 :2 16 2a
2c :2 2a 16 23 :2 2c 16 2e 16
23 :2 2c 33 3c 47 :2 33 4b :2 54
:2 23 16 :5 13 23 :2 13 1f 2b 40
4e 59 63 1b 23 2f 3b 47
53 1b 2a 36 40 48 51 59
1b 27 33 40 4b 56 1b 25
30 3c 48 4b 4e 54 5a 5d
:2 1f 13 16 1f 21 :2 1f 16 26
:2 2f :2 16 24 :3 16 13 25 19 22
25 :2 22 16 26 :2 2f :2 16 24 :3 16
27 25 :2 13 :4 10 1a 26 35 3d
4a 6a 75 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 65 66
:2 61 :2 35 :3 19 :2 1f 24 30 73 76
:2 30 83 86 :2 30 8a 8d :2 30 99
9c :2 30 a4 a7 :2 30 b3 b6 bd
c6 c9 :2 b6 :2 30 :2 19 69 :2 16 :2 13
:4 1f :2 13 10 :3 2a 17 20 2d :2 17
30 33 :2 30 :3 13 22 1d 32 34
40 42 58 5a 69 6b 80 82
1b 2c 2e 33 3c 41 43 50
52 60 62 6f 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :3 35 22 1d 32
3b 51 60 75 89 1b 37 4b
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:3 35 22 1d 32 3c 52 61 76
8a 1b 38 4c 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 64 68
69 :2 64 :2 38 :3 1c :2 22 27 33 76
79 :2 33 86 89 :2 33 8d 90 :2 33
9c 9f :2 33 a7 aa :2 33 b6 b9
c0 c9 cc :2 b9 :2 33 :2 1c 6c :2 19
:2 16 :4 22 :2 16 13 :4 35 :3 10 23 :2 10
23 3f 4d 5b :2 23 :2 10 23 :2 10
23 3f 4d 57 :2 23 10 1a 2a
38 19 26 37 4b 13 1a 16
22 :3 20 16 :2 1f 2b 16 27 16
:2 1f 2b 16 :4 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 61
65 66 :2 61 :2 35 :3 19 :2 1f 24 30
73 76 :2 30 83 86 :2 30 8a 8d
:2 30 99 9c :2 30 a4 a7 :2 30 b3
b6 bd c6 c9 :2 b6 :2 30 :2 19 69
:2 16 :2 13 :4 1f :2 13 10 :3 2a 14 1d
33 :2 14 36 38 :2 36 13 40 49
5f :2 40 62 64 :2 62 3f :2 13 1d
1a 28 16 2c 16 2c 16 2c
16 2c 16 21 16 25 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 64 68 69 :2 64 :2 38 :3 1c
:2 22 27 33 76 79 :2 33 86 89
:2 33 8d 90 :2 33 9c 9f :2 33 a7
aa :2 33 b6 b9 c0 c9 cc :2 b9
:2 33 :2 1c 6c :2 19 :2 16 :4 22 :2 16 13
:3 67 10 67 16 1f 35 :2 16 38
3a :2 38 1d 1a 28 16 2c 16
2c 16 21 16 25 1c 30 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :3 3c
13 21 2a 3a :2 21 13 10 3c
67 16 1f 35 :2 16 38 3a :2 38
1d 1a 28 16 2c 16 2c 16
21 16 25 1c 30 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 64
68 69 :2 64 :2 38 :3 1c :2 22 27 33
76 79 :2 33 86 89 :2 33 8d 90
:2 33 9c 9f :2 33 a7 aa :2 33 b6
b9 c0 c9 cc :2 b9 :2 33 :2 1c 6c
:2 19 :2 16 :4 22 :2 16 13 :3 3c 13 21
2a 3a :2 21 13 3c 67 1d 1a
28 16 21 16 25 1c 30 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 64 68 69 :2 64 :2 38 :3 1c :2 22
27 33 76 79 :2 33 86 89 :2 33
8d 90 :2 33 9c 9f :2 33 a7 aa
:2 33 b6 b9 c0 c9 cc :2 b9 :2 33
:2 1c 6c :2 19 :2 16 :4 22 :2 16 13 :3 10
13 21 2a 3a :2 21 :2 13 21 2a
3a :2 21 13 :4 10 2a :3 d 19 22
2c :2 19 2f 31 :2 19 :2 d 18 21
2a :2 18 2d 2f 38 42 :2 2f :2 18
d :5 a :2 13 1f 35 43 51 :2 1f
a :4 7 9 7 :3 4 8 1 7
d :3 7 :2 10 1c 7 4 c a
:2 13 1f a 1a :2 7 :2 c a :2 13
1f a d :2 17 29 :2 33 3f 43
55 59 5a :2 55 :2 29 :3 d :2 13 18
24 67 6a :2 24 77 7a :2 24 7e
81 :2 24 8d 90 :2 24 98 9b :2 24
a7 aa b1 ba bd :2 aa :2 24 :2 d
5d :2 a :2 7 :4 13 :2 7 4 :3 1 7
10 1e :2 7 21 24 :2 21 a :2 14
26 :2 30 3c 40 52 56 57 :2 52
:2 26 :3 a :2 10 15 21 64 67 :2 21
74 77 :2 21 7b 7e :2 21 88 8b
94 9c :2 94 ab :2 8b :2 21 b3 b6
:2 21 be c1 :2 21 c6 c9 :2 21 d4
d7 :2 21 :2 a 5a :2 7 a :2 14 26
:2 30 3c 3f 51 55 56 :2 51 :2 26
:3 a :2 10 15 21 64 67 :2 21 :2 a
59 :3 7 :2 12 26 2f 3d :2 26 41
4d :2 7 26 :3 4 f 4 7 10
1a :2 7 1d 1f :2 1d 7 13 7
a 13 1d :2 a 23 20 2c 35
:2 23 :2 20 a 16 1f 29 :2 16 2c
2e 37 40 :2 2e :2 16 a e 17
21 :2 e 24 26 :2 24 d 2e 37
43 :2 2e 46 48 :2 46 2d :2 d :4 16
15 14 :3 d 1d :2 d 1e :2 d 17
:2 d 1d :2 d 18 :2 d 17 :2 d 1a
:2 d 1a d 11 1a 25 :2 11 28
2a :2 28 10 32 3b 43 :2 32 46
49 :2 46 31 :3 10 1a 10 d 4e
13 1c 24 :2 13 27 29 :2 27 10
23 2c 34 :2 23 10 2d 4e :3 d
1b 2c 38 45 4e 57 :2 45 5b
64 6c :2 5b 22 2b 37 :2 22 3b
44 4f :2 3b 53 20 2b :2 53 2f
38 46 :2 2f 4a 53 5e :2 4a 22
2b 37 :2 22 3b 43 4d :2 1b d
10 19 25 :2 10 2a 28 :2 33 :2 28
13 :2 1d 2f :2 39 45 48 5a 5e
5f :2 5a :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
91 94 9d a5 :2 ae :2 9d bf :2 94
:2 2a :2 13 62 :2 10 13 :2 1d 2f :2 39
45 48 5a 5e 5f :2 5a :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a :2 13 62
:3 10 :2 1b 31 :2 3a 4a :2 10 d 42
13 1c 28 :2 13 2b 2e :2 2b 13
:2 1d 2f :2 39 45 49 5b 5f 60
:2 5b :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a 7d 80 :2 2a 84 87 :2 2a 91
94 9d a5 :2 9d b2 :2 94 :2 2a ba
bd :2 2a c5 c8 :2 2a cd d0 :2 2a
dd e0 :2 2a :2 13 63 :2 10 13 :2 1d
2f :2 39 45 48 5a 5e 5f :2 5a
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
:2 13 62 :3 10 :2 1b 2f 38 44 :2 2f
48 56 :2 10 30 42 :3 d 15 1f
:3 d :2 16 22 d 1c 32 3c 40
15 16 23 34 40 19 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 62 63 :2 5e :2 32 :3 16 :2 1c 21
2d 70 73 :2 2d 80 83 :2 2d 87
8a :2 2d 96 99 :2 2d a1 a4 :2 2d
b0 b3 ba c3 c6 :2 b3 :2 2d :2 16
66 :2 13 :2 10 :4 1c :2 10 d :3 38 d
1e :2 d 1c :2 d 19 :2 d 16 :2 d
17 d 10 19 21 :2 10 24 26
:2 24 10 1a :2 23 2a 33 3b :2 2a
3f :2 48 :2 1a :2 10 1d 10 28 10
1d 10 :5 d 20 :2 d 19 25 36
44 52 5c 1b 23 2f 3b 47
53 1b 2a 36 40 48 51 59
1b 27 33 40 4b 56 1b 25
30 3c 48 4b 4e 54 5a 5d
:2 19 d 10 19 1b :2 19 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 91 94
9d a5 :2 ae :2 9d c5 :2 94 :2 2a cd
d0 :2 2a d8 db :2 2a e0 e3 :2 2a
ec ef :2 2a :2 13 63 :2 10 13 :2 1d
2f :2 39 45 48 5a 5e 5f :2 5a
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
:2 13 62 :3 10 :2 1b 2f :2 38 4e 58
:2 10 d 1f 13 1c 1f :2 1c 13
:2 1d 2f :2 39 45 49 5b 5f 60
:2 5b :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a 7d 80 :2 2a 84 87 :2 2a 91
94 9d a5 :2 ae :2 9d c6 :2 94 :2 2a
ce d1 :2 2a d9 dc :2 2a e1 e4
:2 2a f4 f7 :2 2a :2 13 63 :2 10 13
:2 1d 2f :2 39 45 48 5a 5e 5f
:2 5a :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a :2 13 62 :3 10 :2 1b 2f :2 38 4f
18 :2 10 21 1f 1a 17 2b 13
22 2c 13 2c 4a 58 6c 13
2c 4a 58 6c 13 2c 4a 58
6c 13 2c 4a 58 6c 13 25
2e 35 46 4f 13 22 2b 32
3f 48 19 2d 13 1a 16 22
:3 20 16 :2 1f 2b 16 27 16 :2 1f
2b 16 :4 13 10 18 16 :2 1f 2b
16 26 :2 13 :2 18 16 :2 1f 2b 16
19 :2 23 35 :2 3f 4b 4f 61 65
66 :2 61 :2 35 :3 19 :2 1f 24 30 73
76 :2 30 83 86 :2 30 8a 8d :2 30
99 9c :2 30 a4 a7 :2 30 b3 b6
bd c6 c9 :2 b6 :2 30 :2 19 69 :2 16
:2 13 :4 1f :2 13 10 :7 d 38 :2 a 7
38 d 16 22 :2 d 25 27 :2 25
:4 2e 2d :2 d 14 11 1d 13 20
31 45 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 93 96
:2 2a 9e a1 :2 2a ad b0 b7 c0
c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19
:2 d a :4 4f 38 :2 7 11 1f 2c
10 1d 2e 3c 4d :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 58 5c 5d :2 58
:2 2c :3 10 :2 16 1b 27 6a 6d :2 27
7a 7d :2 27 81 84 :2 27 90 93
:2 27 9b 9e :2 27 aa ad b4 bd
c0 :2 ad :2 27 :2 10 60 :2 d :2 a :4 16
:2 a 7 :3 21 a 13 1c :2 a 1f
21 :2 1f 14 20 2f 37 44 13
20 31 3e d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5f 60
:2 5b :2 2f :3 13 :2 19 1e 2a 6d 70
:2 2a 7d 80 :2 2a 84 87 :2 2a 93
96 :2 2a 9e a1 :2 2a ad b0 b7
c0 c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d
:4 19 :2 d a :4 23 :2 7 21 :3 4 12
4 :4 8 7 11 e 1c 25 2c
39 42 a 1c 25 2c 3d 46
10 1d a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 58 5c 5d :2 58
:2 2c :3 10 :2 16 1b 27 6a 6d :2 27
7a 7d :2 27 81 84 :2 27 90 93
:2 27 9b 9e :2 27 aa ad b4 bd
c0 :2 ad :2 27 :2 10 60 :2 d :2 a :4 16
:2 a 7 :3 29 a 13 1f :2 a 22
24 :2 22 14 22 2f 13 20 31
49 :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5f 60 :2 5b :2 2f :3 13 :2 19 1e
2a 6d 70 :2 2a 7d 80 :2 2a 84
87 :2 2a 93 96 :2 2a 9e a1 :2 2a
ad b0 b7 c0 c3 :2 b0 :2 2a :2 13
63 :2 10 :2 d :4 19 :2 d a :3 26 d
16 1f :2 d 22 24 :2 22 1c 37
44 10 1d 2e 3c 4d 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 62 63 :2 5e :2 32 :3 16 :2 1c 21
2d 70 73 :2 2d 80 83 :2 2d 87
8a :2 2d 96 99 :2 2d a1 a4 :2 2d
b0 b3 ba c3 c6 :2 b3 :2 2d :2 16
66 :2 13 :2 10 :4 1c :2 10 d :3 26 1c
36 43 54 62 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 62
63 :2 5e :2 32 :3 16 :2 1c 21 2d 70
73 :2 2d 80 83 :2 2d 87 8a :2 2d
96 99 :2 2d a1 a4 :2 2d b0 b3
ba c3 c6 :2 b3 :2 2d :2 16 66 :2 13
:2 10 :4 1c :2 10 d :4 26 :2 a 26 :3 7
15 :2 7 1a 2a 38 4d 59 5c
5f :2 1a 7 11 20 30 36 3e
45 5c 64 6b 83 8d 9e ac
f 1b 28 32 3d 49 55 68
78 f 26 3a :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5c 5d :2 58 :2 2c
:3 10 :2 16 1b 27 6a 6d :2 27 7a
7d :2 27 81 84 :2 27 90 93 :2 27
9b 9e :2 27 aa ad b4 bd c0
:2 ad :2 27 :2 10 60 :2 d :2 a :4 16 :2 a
7 :3 29 b :2 14 1f 1d :2 28 :2 1d
a :4 e :2 d 19 d 22 :2 a d
16 22 :2 d 25 27 :2 25 17 10
2a 10 2b 10 2b 10 2a 3c
10 16 23 34 42 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5e
62 63 :2 5e :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d 80 83 :2 2d 87 8a
:2 2d 96 99 :2 2d a1 a4 :2 2d b0
b3 ba c3 c6 :2 b3 :2 2d :2 16 66
:2 13 :2 10 :4 1c :2 10 d :4 29 17 10
2a 10 2b 10 2b 10 2a 3c
10 2d 3f 16 23 34 42 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 62 63 :2 5e :2 32 :3 16 :2 1c
21 2d 70 73 :2 2d 80 83 :2 2d
87 8a :2 2d 96 99 :2 2d a1 a4
:2 2d b0 b3 ba c3 c6 :2 b3 :2 2d
:2 16 66 :2 13 :2 10 :4 1c :2 10 d :7 a
e 15 25 28 :2 e 2b 2d :2 2b
:2 d :2 16 22 33 41 4f 64 :2 22
d 32 :2 a 38 :2 7 :4 c b a
33 :2 3e 45 f :2 33 24 26 :2 24
32 :3 a 18 a 29 :2 7 29 :2 4
:4 8 7 2d 36 42 :2 2d 45 48
:2 45 :3 7 15 :2 7 1a 2a 38 4d
59 5c 5f :2 1a 7 11 20 30
36 3e 45 5c 64 6b 83 8d
9e ac f 1b 28 32 3d 49
55 68 74 f 10 24 :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5c 5d
:2 58 :2 2c :3 10 :2 16 1b 27 6a 6d
:2 27 7a 7d :2 27 81 84 :2 27 90
93 :2 27 9b 9e :2 27 aa ad b4
bd c0 :2 ad :2 27 :2 10 60 :2 d :2 a
:4 16 :2 a 7 :3 4a a 13 1f :2 a
22 24 :2 22 14 d 28 d 28
d 28 d 29 3b d 13 20
31 3f d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5f 60 :2 5b
:2 2f :3 13 :2 19 1e 2a 6d 70 :2 2a
7d 80 :2 2a 84 87 :2 2a 93 96
:2 2a 9e a1 :2 2a ad b0 b7 c0
c3 :2 b0 :2 2a :2 13 63 :2 10 :2 d :4 19
:2 d a :4 26 14 d 28 d 28
d 28 d 29 3b d 2a 3c
13 20 31 3f d 14 10 1c
:3 1a 10 :2 19 25 10 21 10 :2 19
25 10 :4 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5f
60 :2 5b :2 2f :3 13 :2 19 1e 2a 6d
70 :2 2a 7d 80 :2 2a 84 87 :2 2a
93 96 :2 2a 9e a1 :2 2a ad b0
b7 c0 c3 :2 b0 :2 2a :2 13 63 :2 10
:2 d :4 19 :2 d a :7 7 b 12 22
25 :2 b 28 2a :2 28 a 34 3d
49 :2 34 4c 4e :2 4c 33 :3 a :2 13
1f 30 3e 4c 61 :2 1f a 51
:2 7 4a :3 4 17 21 :2 17 4 7
15 18 :2 15 11 a 26 a 27
a 27 a 25 a 28 10 1d
2e 3c a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 58 5c 5d :2 58
:2 2c :3 10 :2 16 1b 27 6a 6d :2 27
7a 7d :2 27 81 84 :2 27 90 93
:2 27 9b 9e :2 27 aa ad b4 bd
c0 :2 ad :2 27 :2 10 60 :2 d :2 a :4 16
:2 a 7 :4 1a :2 4 7 :2 10 19 1b
:2 19 7 :2 10 1c 7 1f :2 4 7
:2 11 23 :2 2d 39 3c 4e 52 53
:2 4e :2 23 :3 7 :2 d 12 1e 61 64
:2 1e 71 74 :2 1e 78 7b :2 1e 85
88 91 99 :2 a2 :2 91 ad :2 88 :2 1e
b5 b8 :2 1e c0 c3 :2 1e c8 cb
:2 1e df e2 :2 1e :2 7 56 :3 4 :2 f
21 :2 2a 34 49 :2 4 1 9 12
9 a :2 14 26 :2 30 3c 40 52
56 57 :2 52 :2 26 :3 a :2 10 15 21
64 67 :2 21 :3 a :2 10 15 39 5c
5f :2 68 :2 39 76 79 :2 39 81 84
:2 8d :2 39 :2 a 5a :3 7 c 15 1e
2c a 13 1e f e 7 e
7 e 7 29 :2 4 :2 9 7 :2 10
1c :2 7 :2 11 23 :2 2d 39 3d 4f
53 54 :2 4f :2 23 :3 7 :2 d 12 1e
61 64 :2 1e :3 7 :2 d 12 36 42
45 :2 36 4d 50 :2 36 5c 5f 66
6f 72 :2 5f :2 36 :2 7 57 :2 4 7
c 1b a 13 1e f e 7
e 7 e 7 :2 4 :4 10 :2 4 :8 1

6dca
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b :4 c
:4 d :4 e :4 f :4 10
:4 11 2 :4 12 :2 1
:a 14 :a 15 :7 16 :7 17
:7 18 :7 19 :7 1a :7 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :7 21 :7 22 :7 23
:7 24 :5 25 :5 26 :5 27
:5 28 :7 29 :7 2a :5 2b
:5 2c :5 2d :7 2e :7 2f
:5 30 :5 31 :5 32 :5 33
:7 34 :7 35 :7 36 :7 37
:7 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :6 5a :6 5b
:6 5c :6 5d :6 5e :6 5f
:6 60 :6 61 :6 62 :6 63
:7 64 :7 65 :6 66 :6 67
:7 68 :6 69 :7 6a :7 6b
:6 6c :6 6d :6 6e :6 6f
:6 70 :6 71 :6 72 :6 73
:6 74 :6 75 :6 76 :6 77
:6 78 :6 79 :6 7a :7 7b
:7 7c :7 7d :6 7e :7 7f
:6 80 :6 81 :6 82 :6 83
:5 84 :5 85 :6 86 :6 87
:6 88 :6 89 :6 8a :5 8b
:6 8c :2 8e 0 :2 8e
:2 8f :3 90 8f :5 8e
:2 92 0 :2 92 :2 93
:6 94 95 93 :5 92
:2 97 0 :2 97 :c 98
:e 99 :e 9a :a 9b :6 9c
:8 9d :8 9e :23 9f :2 a0
98 :5 97 :7 a2 :b a4
:11 a5 a6 :2 a5 :2 a6
:2 a5 :2 a6 :2 a5 :2 a7
:2 a5 :2 a7 :2 a5 :2 a7
:2 a5 :2 a7 :2 a5 :2 a8
:2 a5 :2 a8 :2 a5 :2 a8
:2 a5 :2 a8 :2 a5 :2 a9
:2 a5 :2 a9 :2 a5 :2 a9
:2 a5 :2 a9 :2 a5 :2 aa
:2 a5 :2 aa :2 a5 :2 aa
:2 a5 :2 aa :2 a5 :2 ab
:2 a5 :9 ab :2 a5 :2 ac
:2 a5 :9 ac :2 a5 :2 ad
:2 a5 :9 ad :2 a5 :2 ae
:2 a5 :9 ae :2 a5 :2 af
:2 a5 :9 af :2 a5 :2 b0
:2 a5 :9 b0 :2 a5 :2 b1
:2 a5 :9 b1 :2 a5 :2 b2
:2 a5 :9 b2 :2 a5 :2 b3
:2 a5 :9 b3 :2 a5 :2 b4
:2 a5 :2 b4 :2 a5 :2 b4
:2 a5 :2 b4 :2 a5 :2 b4
:4 a5 :3 a4 :11 b7 :b b8
:3 b7 :3 bf :3 c0 :3 c1
:3 c2 :3 c3 :d c4 :d c5
:2 c6 :2 c5 :6 c6 :3 c5
:3 c7 c6 :2 c5 :3 ca
:3 cc :3 cd :3 cf :5 d1
:4 d3 :3 d4 :5 d5 d4
:5 d7 d6 :3 d4 :5 da
:4 dd :5 de dc e0
:5 e1 :3 e0 :2 e2 :5 e4
:11 e5 :24 e6 :3 e5 :2 e3
:6 e2 df :3 a3 :9 eb
:11 ec :30 ed :3 ec :11 ef
:b f0 :3 ef :a f2 :3 eb
:6 f6 :6 f7 :3 f8 f6
:5 f9 f5 fb :5 fc
:3 fb :2 fd :5 ff :11 100
:24 101 :3 100 :2 fe :6 fd
fa :3 a3 :a 107 :11 108
:30 109 :3 108 :11 10b :b 10c
:3 10b :a 10e :3 107 :3 111
:2 113 114 :2 115 113
:5 116 112 118 :5 119
:3 118 :2 11a :5 11c :11 11d
:24 11e :3 11d :2 11b :6 11a
117 :3 a3 :9 123 :11 124
:30 125 :3 124 :11 127 :b 128
:3 127 :a 12a :3 123 :12 12e
:7 12f :c 130 12e :5 131
12d 133 :5 134 :3 133
:2 135 :5 137 :11 138 :24 139
:3 138 :2 136 :6 135 132
:3 a3 :a 13e :11 13f :30 140
:3 13f :11 142 :b 143 :3 142
:a 145 :3 13e :8 149 :5 14a
148 14c :5 14d :3 14c
:2 14e :5 150 :11 151 :24 152
:3 151 :2 14f :6 14e 14b
:3 a3 :a 157 :11 158 :30 159
:3 158 :11 15b :b 15c :3 15b
:a 15e :3 157 :6 162 :5 163
161 165 :5 166 :3 165
:2 167 :5 169 :11 16a :24 16b
:3 16a :2 168 :6 167 164
:3 a3 :b 170 :3 171 :3 170
:a 174 :11 175 :30 176 :3 175
:11 178 :b 179 :3 178 :a 17b
:3 174 :3 17e :b 18b :b 18c
:b 18d :3 190 191 :6 192
:2 193 190 :5 194 18f
196 :5 197 :3 196 :2 198
:5 19a :11 19b :24 19c :3 19b
:2 199 :6 198 195 :3 a3
:3 1a2 1a3 :7 1a4 1a2
:5 1a5 1a1 1a7 :5 1a8
:3 1a7 :2 1a9 :5 1ab :11 1ac
:24 1ad :3 1ac :2 1aa :6 1a9
1a6 :3 a3 :3 1b2 :b 1b3
:5 1b4 :9 1b6 :4 1b8 :6 1b9
1b8 :5 1ba 1b7 1bc
:5 1bd :3 1bc :2 1be :5 1c0
:11 1c1 :24 1c2 :3 1c1 :2 1bf
:6 1be 1bb :3 1b6 :c 1c7
:3 1c9 :4 1cb :6 1cc 1cb
:5 1cd 1ca 1cf :5 1d0
:3 1cf :2 1d1 :5 1d3 :11 1d4
:24 1d5 :3 1d4 :2 1d2 :6 1d1
1ce :3 1c7 :9 1da :11 1db
:30 1dc :3 1db :11 1de :b 1df
:3 1de :7 1e1 1e2 :2 1e1
:3 1da :3 1c7 :3 1b6 1e6
1b4 :16 1e6 :2 1e7 :2 1e6
:4 1e7 :5 1e6 :3 1e9 :4 1eb
:5 1ec 1ed 1eb :5 1ee
1ea 1f0 :5 1f1 :3 1f0
:2 1f2 :5 1f4 :11 1f5 :24 1f6
:3 1f5 :2 1f3 :6 1f2 1ef
:3 1e7 :9 1fb :11 1fc :30 1fd
:3 1fc :11 1ff :b 200 :3 1ff
:7 202 203 :2 202 :3 1fb
1e7 :3 1b4 :3 207 :3 208
:3 209 :3 20a :3 20b :3 20c
:5 214 :4 216 :3 217 :5 218
217 :5 21a 219 :3 217
:a 21d :1c 21e :4 220 :5 221
21f 223 :5 224 :3 223
:2 225 :5 227 :11 228 :24 229
:3 228 :2 226 :6 225 222
:3 21e :11 22e :30 22f :3 22e
:11 231 :b 232 :3 231 :7 234
235 :2 234 :3 21e :3 237
238 21d :9 238 :3 239
238 21d :3 23b 23a
:3 21d :4 23f :5 240 23e
242 :5 243 :3 242 :2 244
:5 246 :11 247 :24 248 :3 247
:2 245 :6 244 241 :3 a3
:6 24e :5 24f 24d 251
:5 252 :3 251 :2 253 :5 255
:11 256 :24 257 :3 256 :2 254
:6 253 250 :3 a3 :4 25d
25e :2 25f :2 260 :2 261
25d :5 262 25c 264
:5 265 :3 264 :2 266 :5 268
:11 269 :24 26a :3 269 :2 267
:6 266 263 :3 a3 :18 26f
:3 270 :5 271 :4 274 275
:2 276 277 :2 278 274
:5 279 273 27b :5 27c
:3 27b :2 27d :5 27f :11 280
:24 281 :3 280 :2 27e :6 27d
27a :3 26f :a 286 :5 287
286 :b 289 28a :3 289
:5 28b 288 :3 286 :3 28d
:3 28e :6 290 :3 291 :3 290
:a 293 :5 295 :6 296 :2 297
:4 298 :6 299 :2 29a 295
:6 29b :5 29c 29b :5 29e
29d :3 29b 294 2a1
:5 2a2 :3 2a1 :2 2a3 :5 2a5
:11 2a6 :24 2a7 :3 2a6 :2 2a4
:6 2a3 2a0 :3 26f :e 2ac
:3 2ad 2ac :4 2b0 :4 2b1
:4 2b2 2b0 :5 2b3 2af
2b5 :5 2b6 :3 2b5 :2 2b7
:5 2b9 :11 2ba :24 2bb :3 2ba
:2 2b8 :6 2b7 2b4 :4 2ae
:3 2ac :c 2c1 :6 2c4 :4 2c5
2c4 :6 2c6 :5 2c7 2c6
:5 2c9 2c8 :3 2c6 2c3
2cc :5 2cd :3 2cc :2 2ce
:5 2d0 :11 2d1 :24 2d2 :3 2d1
:2 2cf :6 2ce 2cb :4 2c1
:2 2da :4 2dc :5 2df :2 2e0
:4 2e3 2da :6 2e4 :5 2e5
2e4 :5 2e7 2e6 :3 2e4
2d9 2ea :5 2eb :3 2ea
:2 2ec :5 2ee :11 2ef :24 2f0
:3 2ef :2 2ed :6 2ec 2e9
:4 2d7 :3 2c1 2f5 26f
:a 2f5 :d 2f8 :4 2f9 2f8
:6 2fa :5 2fb 2fa :5 2fd
2fc :3 2fa 2f7 300
:5 301 :3 300 :2 302 :5 304
:11 305 :24 306 :3 305 :2 303
:6 302 2ff :3 2f5 :3 30b
:2 30d 30e :3 30f 30d
:5 310 30c 312 :5 313
:3 312 :2 314 :5 316 :11 317
:24 318 :3 317 :2 315 :6 314
311 :3 2f5 :a 31d :2 31f
320 :3 321 31f :5 322
31e 324 :5 325 :3 324
:2 326 :5 328 :11 329 :24 32a
:3 329 :2 327 :6 326 323
:3 31d :a 32e :3 32f :3 32e
:3 31d :c 333 :b 334 :b 335
336 :3 335 :3 338 :5 339
:2 33a 338 :6 33b :5 33c
33b :5 33e 33d :3 33b
337 341 :5 342 :3 341
:2 343 :5 345 :11 346 :24 347
:3 346 :2 344 :6 343 340
:3 334 :6 34c 34d 334
:12 34d :3 34f :6 350 :2 351
34f :6 352 :5 353 352
:5 355 354 :3 352 34e
358 :5 359 :3 358 :2 35a
:5 35c :11 35d :24 35e :3 35d
:2 35b :6 35a 357 :3 34d
:6 363 364 34d 334
:12 364 :3 366 :6 367 :2 368
366 :6 369 :5 36a 369
:5 36c 36b :3 369 365
36f :5 370 :3 36f :2 371
:5 373 :11 374 :24 375 :3 374
:2 372 :6 371 36e :3 364
:6 37a 364 :3 334 :3 333
2f5 :3 26f :3 380 :5 381
382 :b 383 :2 384 380
:5 385 37f 387 :5 388
:3 387 :2 389 :5 38b :11 38c
:24 38d :3 38c :2 38a :6 389
386 :3 a3 :a 392 :3 393
:3 392 :3 396 :3 397 :3 398
:5 39a :16 39c :7 39d :5 39e
:3 39d :9 3a0 :f 3a1 :f 3a2
:3 3a0 :9 3a5 :f 3a6 :f 3a7
:3 3a5 :3 39c :3 3ab :3 3ac
:3 3ae 3af :2 3b0 3ae
:5 3b1 3ad 3b3 :5 3b4
:3 3b3 :2 3b5 :5 3b7 :11 3b8
:24 3b9 :3 3b8 :2 3b6 :6 3b5
3b2 :3 a3 :3 3bf :2 3c1
:2 3c2 3c3 :4 3c4 :3 3c5
3c1 :5 3c6 3c0 3c8
:5 3c9 :3 3c8 :2 3ca :5 3cc
:11 3cd :24 3ce :3 3cd :2 3cb
:6 3ca 3c7 :3 a3 :4 3d4
:3 3d5 3d4 :5 3d6 3d3
3d8 :5 3d9 :3 3d8 :2 3da
:5 3dc :11 3dd :24 3de :3 3dd
:2 3db :6 3da 3d7 :3 a3
:19 3e3 :5 3e5 :3 3e6 :3 3e7
:a 3e9 :a 3ea :6 3eb :a 3ec
3ed :2 3ee 3e9 :5 3ef
3e8 3f1 :5 3f2 :3 3f1
:2 3f3 :5 3f5 :11 3f6 :24 3f7
:3 3f6 :2 3f4 :6 3f3 3f0
:3 3e5 :a 3fb :1a 3fd :11 3fe
:30 3ff :3 3fe :11 401 :b 402
:3 401 :7 404 405 :2 404
:3 3fd :a 408 :5 409 :c 40a
:5 40b :3 408 :3 3fb :9 40f
411 :2 412 :2 413 411
:6 414 :5 415 414 :5 417
416 :3 414 410 41a
:5 41b :3 41a :2 41c :5 41e
:11 41f :24 420 :3 41f :2 41d
:6 41c 419 :3 40f 426
:2 427 426 :6 428 :5 429
428 :5 42b 42a :3 428
425 42e :5 42f :3 42e
:2 430 :5 432 :11 433 :24 434
:3 433 :2 431 :6 430 42d
:3 40f 43a :2 43b 43a
:6 43c :5 43d 43c :5 43f
43e :3 43c 439 442
:5 443 :3 442 :2 444 :5 446
:11 447 :24 448 :3 447 :2 445
:6 444 441 :4 40f :3 44d
:9 44e :14 44f :2 450 :6 44f
:3 451 450 :2 44f :3 454
:3 455 :3 456 :3 457 :3 459
:3 45b :3 45c :3 45d :3 45e
:3 44e :12 461 :a 462 :5 464
:8 466 :6 467 468 :2 469
466 :5 46a 465 46c
:5 46d :3 46c :2 46e :5 470
:11 471 :24 472 :3 471 :2 46f
:6 46e 46b :3 464 :a 477
:3 479 :1c 47a :d 47b :2 47a
:11 47d :30 47e :3 47d :11 480
:b 481 :3 480 :a 483 484
47b :c 484 :3 486 :2 487
:2 488 :2 489 486 :5 48a
485 48c :5 48d :3 48c
:2 48e :5 490 :11 491 :24 492
:3 491 :2 48f :6 48e 48b
:3 484 :a 497 :f 498 49a
:2 49b :2 49c :2 49d 49a
:6 49e :5 49f 49e :5 4a1
4a0 :3 49e 499 4a4
:5 4a5 :3 4a4 :2 4a6 :5 4a8
:11 4a9 :24 4aa :3 4a9 :2 4a7
:6 4a6 4a3 :6 497 484
47b :2 47a :3 477 :3 464
:3 4b3 :3 4b4 :5 4b5 :3 4b6
4b5 :3 4b8 4b7 :3 4b5
:9 4bb :3 4bc :3 4bb :a 4bf
:2 4c0 :2 4bf :a 4c0 :b 4c1
:2 4c2 :2 4c1 :8 4c2 :3 4bf
:b 4c4 :11 4c5 :20 4c6 :3 4c5
:11 4c8 :b 4c9 :3 4c8 :9 4cb
4cc 4c4 :9 4cc :11 4cd
:2e 4ce :3 4cd :11 4d0 :b 4d1
:3 4d0 :c 4d3 4cc :3 4c4
:b 4d6 :3 4d7 :3 4d6 :3 4db
4dd 4de :6 4e0 :7 4e1
:5 4e2 4dd :5 4e3 4dc
4e5 :5 4e6 :3 4e5 :2 4e7
:5 4e9 :11 4ea :24 4eb :3 4ea
:2 4e8 :6 4e7 4e4 :3 462
:5 4ef :9 4f0 :3 4f1 :3 4f0
:9 4f4 :5 4f5 4f4 :f 4f7
4f6 :3 4f4 4ef :9 4fa
:5 4fb 4fa :f 4fd 4fc
:3 4fa 4f9 :3 4ef :c 501
503 :8 504 :4 505 :8 506
507 :2 508 503 :6 509
:5 50a 509 :5 50c 50b
:3 509 502 50f :5 510
:3 50f :2 511 :5 513 :11 514
:24 515 :3 514 :2 512 :6 511
50e :3 501 51a :2 51b
:2 51c :2 51d :2 51e :2 51f
:4 520 51a :6 521 :5 522
521 :5 524 523 :3 521
519 527 :5 528 :3 527
:2 529 :5 52b :11 52c :24 52d
:3 52c :2 52a :6 529 526
:3 501 :3 531 :3 501 :3 534
:7 535 :6 536 :7 537 :6 538
:a 539 :6 53a :3 535 :5 53c
:11 53d :30 53e :3 53d :11 540
:b 541 :3 540 :a 543 544
53c :5 544 :11 545 :30 546
:3 545 :11 548 :b 549 :3 548
:7 54b 54c :2 54b 544
53c :5 54e :4 550 :4 551
552 :7 553 550 :5 554
54f 556 :5 557 :3 556
:2 558 :5 55a :11 55b :24 55c
:3 55b :2 559 :6 558 555
:4 54e :13 561 :c 562 :9 563
:3 564 :4 566 :2 567 568
:2 569 :2 56a :2 56b 566
:5 56c 565 56e :5 56f
:3 56e :2 570 :5 572 :11 573
:24 574 :3 573 :2 571 :6 570
56d :4 563 :6 57a :3 57b
57c :2 57d :2 57e :2 57f
57a :5 580 579 582
:5 583 :3 582 :2 584 :5 586
:11 587 :24 588 :3 587 :2 585
:6 584 581 :4 578 :3 563
562 :9 58e :3 58f :3 591
592 :2 593 :2 594 :2 595
591 :5 596 590 598
:5 599 :3 598 :2 59a :5 59c
:11 59d :24 59e :3 59d :2 59b
:6 59a 597 :4 58e :6 5a4
5a5 :2 5a6 :2 5a7 :2 5a8
5a4 :5 5a9 5a3 5ab
:5 5ac :3 5ab :2 5ad :5 5af
:11 5b0 :24 5b1 :3 5b0 :2 5ae
:6 5ad 5aa :4 5a2 :3 58e
58d :3 562 561 :3 5b8
:6 5b9 :2 5ba :2 5b9 :2 5ba
:3 5b9 :6 5bc :2 5bd 5be
:2 5bf 5bc :5 5c0 5bb
5c2 :5 5c3 :3 5c2 :2 5c4
:5 5c6 :11 5c7 :24 5c8 :3 5c7
:2 5c5 :6 5c4 5c1 :4 5b7
:3 561 :9 5ce :f 5cf :3 5ce
560 :3 54e :a 5d2 :11 5d3
:30 5d4 :3 5d3 :11 5d6 :b 5d7
:3 5d6 :7 5d9 5da :2 5d9
:3 5d2 54d :3 53c 5df
:4 5e0 :4 5e1 :4 5e2 :4 5e3
:5 5e4 :5 5e5 :6 5e6 :6 5e7
:2 5e8 5df :6 5e9 :5 5ea
5e9 :5 5ec 5eb :3 5e9
5de 5ef :5 5f0 :3 5ef
:2 5f1 :5 5f3 :11 5f4 :24 5f5
:3 5f4 :2 5f2 :6 5f1 5ee
:3 462 :d 5fb :5 5fc :3 5fd
:b 5fe :6 5ff :3 5fc 5fb
602 :2 603 :2 604 602
:6 605 :5 606 605 :5 608
607 :3 605 601 60b
:5 60c :3 60b :2 60d :5 60f
:11 610 :24 611 :3 610 :2 60e
:6 60d 60a :3 600 617
:2 618 :2 619 61a 61b
61c 61d 61e 61f
620 621 622 623
624 625 626 627
628 :2 629 617 :6 62a
:5 62b 62a :5 62d 62c
:3 62a 616 630 :5 631
:3 630 :2 632 :5 634 :11 635
:24 636 :3 635 :2 633 :6 632
62f :4 600 :3 5fb :3 462
44c :3 40f :3 3e5 :3 3e3
:13 640 :2 641 :2 640 :4 641
:3 640 :3 642 :3 643 :3 644
:3 645 :5 646 :9 648 :7 649
:3 648 :16 64c :16 64d :9 64f
:8 650 :9 651 :a 652 :7 653
:9 654 64f :6 655 :5 656
655 :5 658 657 :3 655
64e 65b :5 65c :3 65b
:2 65d :5 65f :11 660 :24 661
:3 660 :2 65e :6 65d 65a
:3 64d 665 64d :9 665
:9 667 :8 668 :9 669 :a 66a
:7 66b :9 66c 667 :6 66d
:5 66e 66d :5 670 66f
:3 66d 666 673 :5 674
:3 673 :2 675 :5 677 :11 678
:24 679 :3 678 :2 676 :6 675
672 :4 665 64d :9 67f
:8 680 :9 681 :a 682 :7 683
:9 684 67f :6 685 :5 686
685 :5 688 687 :3 685
67e 68b :5 68c :3 68b
:2 68d :5 68f :11 690 :24 691
:3 690 :2 68e :6 68d 68a
:4 67d :3 64d 64c :9 698
:8 699 :9 69a :a 69b :7 69c
:9 69d 698 :6 69e :5 69f
69e :5 6a1 6a0 :3 69e
697 6a4 :5 6a5 :3 6a4
:2 6a6 :5 6a8 :11 6a9 :24 6aa
:3 6a9 :2 6a7 :6 6a6 6a3
:4 696 :3 64c 641 :2 640
:c 6b1 :3 6b2 :3 6b3 :3 6b5
:3 6b6 :3 6b7 :3 6b9 :3 6bc
:3 6bd :5 6bf 6c1 :7 6c2
:5 6c3 :7 6c4 :5 6c5 :3 6c2
:3 6c6 :5 6c7 6c6 :5 6c9
6c8 :3 6c6 :a 6cc :2 6cd
:3 6cc :3 6cf :6 6d1 :5 6d2
6d0 6d4 :5 6d5 :3 6d4
:2 6d6 :5 6d8 :11 6d9 :24 6da
:3 6d9 :2 6d7 :6 6d6 6d3
:3 6c1 :6 6df :5 6e0 6de
6e2 :5 6e3 :3 6e2 :2 6e4
:5 6e6 :11 6e7 :24 6e8 :3 6e7
:2 6e5 :6 6e4 6e1 :3 6c1
:5 6ed :9 6ee :5 6ef :c 6f0
:5 6f1 :a 6f3 :8 6f4 6f5
:6 6f6 6f7 6f3 :5 6f8
6f2 6fa :5 6fb :3 6fa
:2 6fc :5 6fe :11 6ff :24 700
:3 6ff :2 6fd :6 6fc 6f9
:3 6ee :a 705 :3 706 :3 707
:6 70c 70d :5 70e 70c
:5 70f 70b 711 :5 712
:3 711 :2 713 :5 715 :11 716
:24 717 :3 716 :2 714 :6 713
710 :3 705 :a 71c :a 71e
:3 71f :4 720 :9 721 :4 722
:7 723 71e :5 724 71d
726 :5 727 :3 726 :2 728
:5 72a :11 72b :24 72c :3 72b
:2 729 :6 728 725 :3 71c
:11 731 :b 732 733 :3 732
:4 736 :5 737 :2 738 736
:6 739 :5 73a 739 :5 73c
73b :3 739 735 73f
:5 740 :3 73f :2 741 :5 743
:11 744 :24 745 :3 744 :2 742
:6 741 73e :3 731 :3 74a
:8 74b :3 74d :8 74e :6 751
:2 752 751 :6 753 :5 754
753 :5 756 755 :3 753
750 759 :5 75a :3 759
:2 75b :5 75d :11 75e :24 75f
:3 75e :2 75c :6 75b 758
:3 731 :b 764 766 :2 767
766 :6 768 :5 769 768
:5 76b 76a :3 768 765
76e :5 76f :3 76e :2 770
:5 772 :11 773 :24 774 :3 773
:2 771 :6 770 76d :3 764
:3 778 :3 779 :8 77a :3 764
77d 731 :b 77d :b 77e
77f :3 77e :4 782 :7 783
:2 784 782 :6 785 :5 786
785 :5 788 787 :3 785
781 78b :5 78c :3 78b
:2 78d :5 78f :11 790 :24 791
:3 790 :2 78e :6 78d 78a
:3 77d :3 795 :8 796 :3 798
:8 799 :6 79c :2 79d 79c
:6 79e :5 79f 79e :5 7a1
7a0 :3 79e 79b 7a4
:5 7a5 :3 7a4 :2 7a6 :5 7a8
:11 7a9 :24 7aa :3 7a9 :2 7a7
:6 7a6 7a3 :4 77d 731
:2 7b0 :5 7b2 :2 7b3 :2 7b5
7b0 :6 7b6 :5 7b7 7b6
:5 7b9 7b8 :3 7b6 7af
7bc :5 7bd :3 7bc :2 7be
:5 7c0 :11 7c1 :24 7c2 :3 7c1
:2 7bf :6 7be 7bb :3 7ae
:b 7c8 7c9 :3 7c8 :5 7ca
:3 7cc :3 7cd :6 7cf :3 7d0
:3 7cf :a 7d2 :5 7d3 :5 7d5
:6 7d6 :2 7d7 :4 7d8 :6 7d9
:2 7da 7d5 :6 7db :5 7dc
7db :5 7de 7dd :3 7db
7d4 7e1 :5 7e2 :3 7e1
:2 7e3 :5 7e5 :11 7e6 :24 7e7
:3 7e6 :2 7e4 :6 7e3 7e0
:4 7ae :3 731 7ec 71c
:a 7ec :3 7ed :12 7ee 7f0
:2 7f1 :2 7f2 7f3 :2 7f4
7f0 :6 7f5 :5 7f6 7f5
:5 7f8 7f7 :3 7f5 7ef
7fb :5 7fc :3 7fb :2 7fd
:5 7ff :11 800 :24 801 :3 800
:2 7fe :6 7fd 7fa :3 7ee
805 7ee :b 805 :b 806
807 :3 806 80a :3 80b
:2 80c :2 80d :2 80e 80f
:2 810 80a :6 811 :5 812
811 :5 814 813 :3 811
809 817 :5 818 :3 817
:2 819 :5 81b :11 81c :24 81d
:3 81c :2 81a :6 819 816
:4 805 7ee 823 :6 824
:2 825 :2 826 :2 827 828
:2 829 823 :6 82a :5 82b
82a :5 82d 82c :3 82a
822 830 :5 831 :3 830
:2 832 :5 834 :11 835 :24 836
:3 835 :2 833 :6 832 82f
:4 821 :3 7ee 7ec :3 71c
705 :3 83e :3 83f :a 841
:3 843 :3 841 83c :3 705
:12 847 :3 849 :4 84a 849
:5 84b 848 84d :5 84e
:3 84d :2 84f :5 851 :11 852
:24 853 :3 852 :2 850 :6 84f
84c :3 847 :16 858 :6 85a
:6 85b :5 85c 85b :5 85e
85d :3 85b 859 861
:5 862 :3 861 :2 863 :5 865
:11 866 :24 867 :3 866 :2 864
:6 863 860 :3 858 86b
858 :16 86b :5 86c :3 86d
:2 86e 86b :3 858 :3 847
:3 873 875 876 :6 878
:a 879 :5 87a 875 :5 87b
874 87d :5 87e :3 87d
:2 87f :5 881 :11 882 :24 883
:3 882 :2 880 :6 87f 87c
:3 6ee :c 888 88a :8 88b
:4 88c :8 88d 88e :2 88f
88a :6 890 :5 891 890
:5 893 892 :3 890 889
896 :5 897 :3 896 :2 898
:5 89a :11 89b :24 89c :3 89b
:2 899 :6 898 895 :6 888
:b 8a2 :3 8a3 :5 8a4 :2 8a6
:c 8a7 :2 8a8 :a 8a9 :6 8aa
8a6 :6 8ab :5 8ac 8ab
:5 8ae 8ad :3 8ab 8a5
8b1 :5 8b2 :3 8b1 :2 8b3
:5 8b5 :11 8b6 :24 8b7 :3 8b6
:2 8b4 :6 8b3 8b0 :6 8a4
:5 8be :5 8bf :14 8c1 8c3
:2 8c4 :2 8c5 :b 8c6 8c3
:6 8c7 :5 8c8 8c7 :5 8ca
8c9 :3 8c7 8c2 8cd
:5 8ce :3 8cd :2 8cf :5 8d1
:11 8d2 :24 8d3 :3 8d2 :2 8d0
:6 8cf 8cc :4 8c1 8d9
:2 8da :4 8db :b 8dc :6 8dd
:4 8de 8d9 :6 8df :5 8e0
8df :5 8e2 8e1 :3 8df
8d8 8e5 :5 8e6 :3 8e5
:2 8e7 :5 8e9 :11 8ea :24 8eb
:3 8ea :2 8e8 :6 8e7 8e4
:4 8d7 :3 8c1 :a 8f1 :3 8f2
:6 8f4 8f5 8f4 :5 8f6
8f3 8f8 :5 8f9 :3 8f8
:2 8fa :5 8fc :11 8fd :24 8fe
:3 8fd :2 8fb :6 8fa 8f7
:3 8f1 :9 903 :2 904 :3 903
908 :4 909 908 :6 90a
:5 90b 90a :5 90d 90c
:3 90a 907 910 :5 911
:3 910 :2 912 :5 914 :11 915
:24 916 :3 915 :2 913 :6 912
90f :3 8f1 :16 91b :2 91c
:5 91b :4 91f 920 :4 921
91f :5 922 91e 924
:5 925 :3 924 :2 926 :5 928
:11 929 :24 92a :3 929 :2 927
:6 926 923 :3 8f1 :d 92f
:b 930 :3 92f 934 935
936 937 938 939
93a 93b 93c 93d
93e 940 941 942
943 945 946 :3 947
949 94a 934 :6 94b
:5 94c 94b :5 94e 94d
:3 94b 933 951 :5 952
:3 951 :2 953 :5 955 :11 956
:24 957 :3 956 :2 954 :6 953
950 :3 8f1 95c :5 95d
:3 95e :4 95f :4 960 :4 961
:4 962 :6 963 :6 964 :2 965
95c :6 966 :5 967 966
:5 969 968 :3 966 95b
96c :5 96d :3 96c :2 96e
:5 970 :11 971 :24 972 :3 971
:2 96f :6 96e 96b :3 8f1
:16 977 :2 978 :5 977 :f 97a
:6 97b :2 97c :2 97b :6 97c
:3 97b 8f1 :2 97e 97d
:3 8f1 8a2 :3 981 :3 982
:3 983 :9 984 :1c 985 :d 986
:2 985 :5 988 :3 989 :2 98a
98b 986 :c 98b :3 98d
:2 98e :2 98f :2 990 98d
:5 991 98c 993 :5 994
:3 993 :2 995 :5 997 :11 998
:24 999 :3 998 :2 996 :6 995
992 :3 98b :a 99e :f 99f
9a1 :2 9a2 :2 9a3 :2 9a4
9a1 :6 9a5 :5 9a6 9a5
:5 9a8 9a7 :3 9a5 9a0
9ab :5 9ac :3 9ab :2 9ad
:5 9af :11 9b0 :24 9b1 :3 9b0
:2 9ae :6 9ad 9aa :6 99e
98b 986 :2 985 984
:f 9b8 :5 9b9 :3 9b8 :14 9bb
:2 9bc :6 9bb :3 9bd :9 9bf
:3 9c0 :3 9bf 9bc :2 9bb
:3 9c4 :3 9c5 :3 9c7 :3 9c9
:3 9ca :3 9cb :3 9cc :16 9ce
:3 9cf 9d0 9ce :9 9d0
:7 9d1 9d0 :3 9ce 9b7
:3 984 :a 9d5 :2 9d6 :2 9d5
:a 9d6 :b 9d7 :2 9d8 :2 9d7
:8 9d8 :3 9d5 :b 9da :4 9dc
:5 9dd 9db 9df :5 9e0
:3 9df :2 9e1 :5 9e3 :11 9e4
:24 9e5 :3 9e4 :2 9e2 :6 9e1
9de :3 9da :11 9ea :20 9eb
:3 9ea :11 9ed :b 9ee :3 9ed
:9 9f0 9f1 9da :9 9f1
:7 9f2 :3 9f3 :2 9f4 9f1
:3 9da :3 9f7 :9 9f9 :3 9fa
:9 9fb :5 9fc 9fb :f 9fe
9fd :3 9fb a00 9f9
:b a00 :3 a01 :9 a02 :5 a03
a02 :f a05 a04 :3 a02
a00 9f9 :3 a08 :9 a09
:5 a0a a09 :f a0c a0b
:3 a09 a07 :3 9f9 :3 a10
:7 a13 :6 a14 :7 a15 :6 a16
:a a17 :3 a13 :5 a19 :5 a1a
:3 a1b :2 a1c a1d a19
:5 a1d :5 a1e :3 a1f :2 a20
a1d a19 :5 a22 :9 a23
:4 a25 :4 a26 a27 :6 a28
a25 :5 a29 a24 a2b
:5 a2c :3 a2b :2 a2d :5 a2f
:11 a30 :24 a31 :3 a30 :2 a2e
:6 a2d a2a :4 a23 :4 a37
:4 a38 a39 :6 a3a a37
:5 a3b a36 a3d :5 a3e
:3 a3d :2 a3f :5 a41 :11 a42
:24 a43 :3 a42 :2 a40 :6 a3f
a3c :4 a35 :3 a23 a22
:9 a49 :3 a4b :2 a4c a4b
:6 a4d :5 a4e a4d :5 a50
a4f :3 a4d a4a a53
:5 a54 :3 a53 :2 a55 :5 a57
:11 a58 :24 a59 :3 a58 :2 a56
:6 a55 a52 :3 a49 :3 a5e
:6 a5f :2 a60 :2 a5f :2 a60
:3 a5f :2 a62 :2 a63 a64
:2 a65 a62 :5 a66 a61
a68 :5 a69 :3 a68 :2 a6a
:5 a6c :11 a6d :24 a6e :3 a6d
:2 a6b :6 a6a a67 :4 a49
:3 a74 :2 a75 a74 :6 a76
:5 a77 a76 :5 a79 a78
:3 a76 a73 a7c :5 a7d
:3 a7c :2 a7e :5 a80 :11 a81
:24 a82 :3 a81 :2 a7f :6 a7e
a7b :3 a72 :3 a87 :6 a88
:2 a89 :2 a88 :2 a89 :3 a88
:2 a8b :2 a8c a8d :2 a8e
a8b :5 a8f a8a a91
:5 a92 :3 a91 :2 a93 :5 a95
:11 a96 :24 a97 :3 a96 :2 a94
:6 a93 a90 :4 a72 :3 a49
:9 a9d :f a9e :3 a9d a48
:3 a22 :a aa1 :5 aa2 :3 aa3
:2 aa4 :3 aa1 a21 :3 a19
:9 aa8 aaa :4 aab :6 aac
:6 aad :2 aae aaa :6 aaf
:5 ab0 aaf :5 ab2 ab1
:3 aaf aa9 ab5 :5 ab6
:3 ab5 :2 ab7 :5 ab9 :11 aba
:24 abb :3 aba :2 ab8 :6 ab7
ab4 :4 aa8 ac1 :4 ac2
:4 ac3 :4 ac4 :4 ac5 :6 ac6
:6 ac7 :2 ac8 ac1 :6 ac9
:5 aca ac9 :5 acc acb
:3 ac9 ac0 acf :5 ad0
:3 acf :2 ad1 :5 ad3 :11 ad4
:24 ad5 :3 ad4 :2 ad2 :6 ad1
ace :4 abf :3 aa8 :d adc
:5 add :3 ade :b adf :6 ae0
:3 add :5 ae2 :9 ae3 :5 ae4
adc ae7 :2 ae8 :2 ae9
ae7 :6 aea :5 aeb aea
:5 aed aec :3 aea ae6
af0 :5 af1 :3 af0 :2 af2
:5 af4 :11 af5 :24 af6 :3 af5
:2 af3 :6 af2 aef :3 ae5
:9 afb afd :2 afe afd
:6 aff :5 b00 aff :5 b02
b01 :3 aff afc b05
:5 b06 :3 b05 :2 b07 :5 b09
:11 b0a :24 b0b :3 b0a :2 b08
:6 b07 b04 :3 afb :5 b10
:7 b11 :5 b12 :4 b14 :6 b15
:5 b16 b15 :5 b18 b17
:3 b15 b13 b1b :5 b1c
:3 b1b :2 b1d :5 b1f :11 b20
:24 b21 :3 b20 :2 b1e :6 b1d
b1a :4 afb b27 :2 b28
:2 b29 b2a b2b b2c
b2d b2e b2f b30
b31 b32 b33 b34
b35 b36 b37 :2 b38
b27 :6 b39 :5 b3a b39
:5 b3c b3b :3 b39 b26
b3f :5 b40 :3 b3f :2 b41
:5 b43 :11 b44 :24 b45 :3 b44
:2 b42 :6 b41 b3e :4 b25
:3 afb ae5 :3 adc :3 b4c
:6 b4d :2 b4e :2 b4d :2 b4e
:3 b4d 980 :3 8a2 :c b51
b53 :b b54 :c b55 b53
:6 b56 :5 b57 b56 :5 b59
b58 :3 b56 b52 b5c
:5 b5d :3 b5c :2 b5e :5 b60
:11 b61 :24 b62 :3 b61 :2 b5f
:6 b5e b5b :3 b51 b68
:7 b69 :3 b6a b68 :6 b6b
:5 b6c b6b :5 b6e b6d
:3 b6b b67 b71 :5 b72
:3 b71 :2 b73 :5 b75 :11 b76
:24 b77 :3 b76 :2 b74 :6 b73
b70 :3 b51 b7d :7 b7e
:3 b7f b7d :6 b80 :5 b81
b80 :5 b83 b82 :3 b80
b7c b86 :5 b87 :3 b86
:2 b88 :5 b8a :11 b8b :24 b8c
:3 b8b :2 b89 :6 b88 b85
:6 b51 :3 6ee 6ed :7 b94
:9 b95 :7 b96 :4 b99 :6 b9a
:5 b9b b9a :5 b9d b9c
:3 b9a b98 ba0 :5 ba1
:3 ba0 :2 ba2 :5 ba4 :11 ba5
:24 ba6 :3 ba5 :2 ba3 :6 ba2
b9f :3 b95 :4 bac :6 bad
:5 bae bad :5 bb0 baf
:3 bad bab bb3 :5 bb4
:3 bb3 :2 bb5 :5 bb7 :11 bb8
:24 bb9 :3 bb8 :2 bb6 :6 bb5
bb2 :3 b95 :4 bbf :6 bc0
:5 bc1 bc0 :5 bc3 bc2
:3 bc0 bbe bc6 :5 bc7
:3 bc6 :2 bc8 :5 bca :11 bcb
:24 bcc :3 bcb :2 bc9 :6 bc8
bc5 :3 b95 :6 bd2 :6 bd3
:5 bd4 bd3 :5 bd6 bd5
:3 bd3 bd1 bd9 :5 bda
:3 bd9 :2 bdb :5 bdd :11 bde
:24 bdf :3 bde :2 bdc :6 bdb
bd8 :3 b95 :4 be5 :6 be6
:5 be7 be6 :5 be9 be8
:3 be6 be4 bec :5 bed
:3 bec :2 bee :5 bf0 :11 bf1
:24 bf2 :3 bf1 :2 bef :6 bee
beb :3 b95 :4 bf8 :6 bf9
:5 bfa bf9 :5 bfc bfb
:3 bf9 bf7 bff :5 c00
:3 bff :2 c01 :5 c03 :11 c04
:24 c05 :3 c04 :2 c02 :6 c01
bfe :4 b95 :9 c0a :3 c0b
:3 c0a c0e :2 c0f :2 c10
:2 c11 :2 c12 c0e :6 c13
:5 c14 c13 :5 c16 c15
:3 c13 c0d c19 :5 c1a
:3 c19 :2 c1b :5 c1d :11 c1e
:24 c1f :3 c1e :2 c1c :6 c1b
c18 :3 c09 :4 c25 c26
:6 c27 c28 c25 :5 c29
c24 c2b :5 c2c :3 c2b
:2 c2d :5 c2f :11 c30 :24 c31
:3 c30 :2 c2e :6 c2d c2a
:3 c09 :a c36 :3 c37 :6 c3b
c3c :5 c3d c3b :5 c3e
c3a c40 :5 c41 :3 c40
:2 c42 :5 c44 :11 c45 :24 c46
:3 c45 :2 c43 :6 c42 c3f
:3 c36 :a c4b :12 c4c :3 c4d
c4f :2 c50 :2 c51 c52
:2 c53 c4f :6 c54 :5 c55
c54 :5 c57 c56 :3 c54
c4e c5a :5 c5b :3 c5a
:2 c5c :5 c5e :11 c5f :24 c60
:3 c5f :2 c5d :6 c5c c59
:3 c4c c64 c4c :b c64
:b c65 c66 :3 c65 c69
:3 c6a :2 c6b :2 c6c :2 c6d
c6e :2 c6f c69 :6 c70
:5 c71 c70 :5 c73 c72
:3 c70 c68 c76 :5 c77
:3 c76 :2 c78 :5 c7a :11 c7b
:24 c7c :3 c7b :2 c79 :6 c78
c75 :4 c64 c4c c82
:6 c83 :2 c84 :2 c85 :2 c86
c87 :2 c88 c82 :6 c89
:5 c8a c89 :5 c8c c8b
:3 c89 c81 c8f :5 c90
:3 c8f :2 c91 :5 c93 :11 c94
:24 c95 :3 c94 :2 c92 :6 c91
c8e :4 c80 :3 c4c :16 c9b
:4 c9d :6 c9e :5 c9f c9e
:5 ca1 ca0 :3 c9e c9c
ca4 :5 ca5 :3 ca4 :2 ca6
:5 ca8 :11 ca9 :24 caa :3 ca9
:2 ca7 :6 ca6 ca3 :6 c9b
c4b :8 cb1 :2 cb2 :4 cb3
:9 cb4 :4 cb5 :7 cb6 cb1
:5 cb7 cb0 cb9 :5 cba
:3 cb9 :2 cbb :5 cbd :11 cbe
:24 cbf :3 cbe :2 cbc :6 cbb
cb8 :3 caf :12 cc4 :b cc5
cc6 :3 cc5 :4 cc9 :6 cca
:5 ccb cca :5 ccd ccc
:3 cca cc8 cd0 :5 cd1
:3 cd0 :2 cd2 :5 cd4 :11 cd5
:24 cd6 :3 cd5 :2 cd3 :6 cd2
ccf :3 cc4 :4 cdc :5 cdd
:2 cde cdc :6 cdf :5 ce0
cdf :5 ce2 ce1 :3 cdf
cdb ce5 :5 ce6 :3 ce5
:2 ce7 :5 ce9 :11 cea :24 ceb
:3 cea :2 ce8 :6 ce7 ce4
:3 cc4 :6 cf1 :2 cf2 cf1
:6 cf3 :5 cf4 cf3 :5 cf6
cf5 :3 cf3 cf0 cf9
:5 cfa :3 cf9 :2 cfb :5 cfd
:11 cfe :24 cff :3 cfe :2 cfc
:6 cfb cf8 :4 cc4 :2 d05
:5 d07 :2 d08 :2 d0a d05
:6 d0b :5 d0c d0b :5 d0e
d0d :3 d0b d04 d11
:5 d12 :3 d11 :2 d13 :5 d15
:11 d16 :24 d17 :3 d16 :2 d14
:6 d13 d10 :3 d03 :4 d1d
:2 d1e d1d :6 d1f :5 d20
d1f :5 d22 d21 :3 d1f
d1c d25 :5 d26 :3 d25
:2 d27 :5 d29 :11 d2a :24 d2b
:3 d2a :2 d28 :6 d27 d24
:4 d03 :3 cc4 caf :3 c4b
:c d32 :2 d33 :2 d32 :6 d33
:2 d32 :6 d35 :6 d36 :5 d37
d36 :5 d39 d38 :3 d36
d34 d3c :5 d3d :3 d3c
:2 d3e :5 d40 :11 d41 :24 d42
:3 d41 :2 d3f :6 d3e d3b
:4 d33 :2 d32 c36 :3 d49
:4 d4d :6 d4e :5 d4f d4e
:5 d51 d50 :3 d4e d4c
d54 :5 d55 :3 d54 :2 d56
:5 d58 :11 d59 :24 d5a :3 d59
:2 d57 :6 d56 d53 :3 d47
:4 d60 :6 d61 :5 d62 d61
:5 d64 d63 :3 d61 d5f
d67 :5 d68 :3 d67 :2 d69
:5 d6b :11 d6c :24 d6d :3 d6c
:2 d6a :6 d69 d66 :3 d47
:a d72 :3 d74 :3 d72 :c d77
:2 d78 :2 d77 :6 d78 :2 d77
:6 d7a :6 d7b :5 d7c d7b
:5 d7e d7d :3 d7b d79
d81 :5 d82 :3 d81 :2 d83
:5 d85 :11 d86 :24 d87 :3 d86
:2 d84 :6 d83 d80 :3 d78
:3 d8b d78 :2 d77 d47
:3 c36 :9 d8f :12 d90 :3 d92
:4 d93 d92 :5 d94 d91
d96 :5 d97 :3 d96 :2 d98
:5 d9a :11 d9b :24 d9c :3 d9b
:2 d99 :6 d98 d95 :3 d90
:16 da1 :6 da3 :6 da4 :5 da5
da4 :5 da7 da6 :3 da4
da2 daa :5 dab :3 daa
:2 dac :5 dae :11 daf :24 db0
:3 daf :2 dad :6 dac da9
:3 da1 db4 da1 :16 db4
:5 db5 :3 db6 :2 db7 db4
:3 da1 :3 d90 :c dbb :2 dbc
:2 dbb :6 dbc :2 dbb :5 dbe
:5 dbf :14 dc1 dc3 :2 dc4
:2 dc5 :b dc6 dc3 :6 dc7
:5 dc8 dc7 :5 dca dc9
:3 dc7 dc2 dcd :5 dce
:3 dcd :2 dcf :5 dd1 :11 dd2
:24 dd3 :3 dd2 :2 dd0 :6 dcf
dcc :4 dc1 dd9 :2 dda
:4 ddb :b ddc :6 ddd :4 dde
dd9 :6 ddf :5 de0 ddf
:5 de2 de1 :3 ddf dd8
de5 :5 de6 :3 de5 :2 de7
:5 de9 :11 dea :24 deb :3 dea
:2 de8 :6 de7 de4 :4 dd7
:3 dc1 :a df1 :3 df2 :9 df4
df5 df4 :5 df6 df3
df8 :5 df9 :3 df8 :2 dfa
:5 dfc :11 dfd :24 dfe :3 dfd
:2 dfb :6 dfa df7 :3 df1
:9 e03 :2 e04 e03 e07
:4 e08 e07 :6 e09 :5 e0a
e09 :5 e0c e0b :3 e09
e06 e0f :5 e10 :3 e0f
:2 e11 :5 e13 :11 e14 :24 e15
:3 e14 :2 e12 :6 e11 e0e
:3 e05 :10 e1a :5 e1b :2 e1a
:3 e1c e1b :2 e1a :1d e1f
:4 e22 e23 :4 e24 e22
:5 e25 e21 e27 :5 e28
:3 e27 :2 e29 :5 e2b :11 e2c
:24 e2d :3 e2c :2 e2a :6 e29
e26 :3 e05 :3 e32 :2 e34
:2 e35 :7 e36 :7 e37 :8 e38
e34 :5 e3a e33 e3c
:5 e3d :3 e3c :2 e3e :5 e40
:11 e41 :24 e42 :3 e41 :2 e3f
:6 e3e e3b :3 e05 :9 e47
:f e48 :3 e49 :b e4a :d e4c
:b e4d :3 e4c :2 e51 :5 e52
:7 e53 :6 e54 :7 e55 :8 e56
e51 :6 e57 :5 e58 e57
:5 e5a e59 :3 e57 e50
e5d :5 e5e :3 e5d :2 e5f
:5 e61 :11 e62 :24 e63 :3 e62
:2 e60 :6 e5f e5c :6 e47
:d e68 :b e69 :3 e68 e6d
e6e e6f e70 e71
e72 e73 e74 e75
e76 e77 e79 e7a
e7b :2 e7c e7e e7f
:3 e80 e82 :8 e83 :6 e84
:9 e85 e6d :6 e86 :5 e87
e86 :5 e89 e88 :3 e86
e6c e8c :5 e8d :3 e8c
:2 e8e :5 e90 :11 e91 :24 e92
:3 e91 :2 e8f :6 e8e e8b
:3 e05 :9 e97 :f e98 :d e99
:14 e9a :b e9b :6 e9a :9 e9c
e9e :3 e9f :2 ea0 :2 ea1
:2 ea2 e9e :6 ea3 :5 ea4
ea3 :5 ea6 ea5 :3 ea3
e9d ea9 :5 eaa :3 ea9
:2 eab :5 ead :11 eae :24 eaf
:3 eae :2 eac :6 eab ea8
:6 e9c :3 e99 :3 eb7 eb8
:2 eb9 eb7 :5 eba eb6
ebc :5 ebd :3 ebc :2 ebe
:5 ec0 :11 ec1 :24 ec2 :3 ec1
:2 ebf :6 ebe ebb :4 e97
:f ec7 :d ec8 :1d ec9 :d eca
ecc :2 ecd :2 ece :2 ecf
:2 ed0 ecc :6 ed1 :5 ed2
ed1 :5 ed4 ed3 :3 ed1
ecb ed7 :5 ed8 :3 ed7
:2 ed9 :5 edb :11 edc :24 edd
:3 edc :2 eda :6 ed9 ed6
:6 eca :3 ec8 ec6 :3 e97
e05 :3 e03 :4 ee7 :3 ee8
:4 ee9 :4 eea :4 eeb :4 eec
:6 eed :6 eee :2 eef ee7
:6 ef0 :5 ef1 ef0 :5 ef3
ef2 :3 ef0 ee6 ef6
:5 ef7 :3 ef6 :2 ef8 :5 efa
:11 efb :24 efc :3 efb :2 ef9
:6 ef8 ef5 :3 df1 :16 f01
:2 f02 :5 f01 :f f03 :6 f04
:2 f05 :2 f04 :6 f05 :3 f04
df1 :2 f07 f06 :3 df1
dbc :3 f0a :1f f0c :9 f0d
:2 f0c :3 f0e :7 f0f f0d
:2 f0c :1a f12 :7 f13 f12
:12 f15 f14 :3 f12 :9 f18
:b f19 f18 :11 f1b f1a
:3 f18 :9 f1e f20 :6 f21
:6 f22 :3 f23 :2 f24 f20
:6 f25 :5 f26 f25 :5 f28
f27 :3 f25 f1f f2b
:5 f2c :3 f2b :2 f2d :5 f2f
:11 f30 :24 f31 :3 f30 :2 f2e
:6 f2d f2a :4 f1e f37
:2 f38 f39 :3 f3a :4 f3b
:4 f3c :4 f3d :4 f3e :2 f3f
:6 f40 :6 f41 :2 f42 f37
:6 f43 :5 f44 f43 :5 f46
f45 :3 f43 f36 f49
:5 f4a :3 f49 :2 f4b :5 f4d
:11 f4e :24 f4f :3 f4e :2 f4c
:6 f4b f48 :4 f35 :3 f1e
:3 f55 :b f57 :3 f58 f57
:3 f5a f59 :3 f57 :9 f5d
:5 f5e f5d :f f60 f5f
:3 f5d :3 f63 :7 f7b :6 f7c
:7 f7d :6 f7e :a f7f :3 f7b
:5 f83 :5 f84 :3 f85 :2 f86
f87 f83 :5 f87 :5 f88
:3 f89 :2 f8a f87 :3 f83
f09 :3 dbb :8 f94 :6 f95
:5 f96 f95 :5 f98 f97
:3 f95 f93 f9b :5 f9c
:3 f9b :2 f9d :5 f9f :11 fa0
:24 fa1 :3 fa0 :2 f9e :6 f9d
f9a :3 d8f :c fa8 faa
:b fab :c fac faa :6 fad
:5 fae fad :5 fb0 faf
:3 fad fa9 fb3 :5 fb4
:3 fb3 :2 fb5 :5 fb7 :11 fb8
:24 fb9 :3 fb8 :2 fb6 :6 fb5
fb2 :3 fa8 fc0 :7 fc1
:3 fc2 fc0 :6 fc3 :5 fc4
fc3 :5 fc6 fc5 :3 fc3
fbf fc9 :5 fca :3 fc9
:2 fcb :5 fcd :11 fce :24 fcf
:3 fce :2 fcc :6 fcb fc8
:3 fa8 fd5 :7 fd6 :3 fd7
fd5 :6 fd8 :5 fd9 fd8
:5 fdb fda :3 fd8 fd4
fde :5 fdf :3 fde :2 fe0
:5 fe2 :11 fe3 :24 fe4 :3 fe3
:2 fe1 :6 fe0 fdd :6 fa8
:3 fec :8 fed :3 fef :8 ff0
:3 ff3 :4 ff4 ff3 :6 ff5
:5 ff6 ff5 :5 ff8 ff7
:3 ff5 ff2 ffb :5 ffc
:3 ffb :2 ffd :5 fff :11 1000
:24 1001 :3 1000 :2 ffe :6 ffd
ffa :3 d8f :16 1007 1009
:2 100a :2 100b :2 100c :2 100d
:2 100e :2 100f :2 1010 :2 1011
1009 :6 1012 :5 1013 1012
:5 1015 1014 :3 1012 1008
1018 :5 1019 :3 1018 :2 101a
:5 101c :11 101d :24 101e :3 101d
:2 101b :6 101a 1017 :3 1007
1022 1007 :9 1022 1024
:2 1025 :2 1026 :2 1027 :2 1028
:2 1029 :2 102a 1024 :6 102b
:5 102c 102b :5 102e 102d
:3 102b 1023 1031 :5 1032
:3 1031 :2 1033 :5 1035 :11 1036
:24 1037 :3 1036 :2 1034 :6 1033
1030 :3 1022 :7 103c 103d
1022 1007 :9 103d 103f
:2 1040 :2 1041 :2 1042 :2 1043
:2 1044 :2 1045 103f :6 1046
:5 1047 1046 :5 1049 1048
:3 1046 103e 104c :5 104d
:3 104c :2 104e :5 1050 :11 1051
:24 1052 :3 1051 :2 104f :6 104e
104b :3 103d :7 1057 103d
1007 105a :2 105b :2 105c
:2 105d :2 105e 105a :6 105f
:5 1060 105f :5 1062 1061
:3 105f 1059 1065 :5 1066
:3 1065 :2 1067 :5 1069 :11 106a
:24 106b :3 106a :2 1068 :6 1067
1064 :3 1058 :7 1070 :7 1071
1058 :3 1007 :3 d8f :b 1074
:f 1075 c09 :3 b95 :a 1078
b92 :3 6ed 107a 107b
:3 6c1 107c a3 :4 1080
:5 1081 107f 1083 :5 1084
:3 1083 :2 1085 :5 1087 :11 1088
:24 1089 :3 1088 :2 1086 :6 1085
1082 :3 a3 :9 108e :11 108f
:2e 1090 :3 108f :11 1092 :b 1093
:3 1092 :c 1095 :3 108e :3 1097
:9 1098 :3 1099 :d 109c :f 109d
:16 109f :6 10a0 :2 109f :3 10a1
:3 10a2 :3 10a3 :3 10a5 :3 10a7
:3 10a8 :3 10a9 :3 10aa :16 10ac
:3 10ad 10ae 10ac :9 10ae
:7 10af 10ae :3 10ac :e 10b2
:b 10b3 :2 10b4 :2 10b3 :a 10b4
:8 10b5 :3 10b2 :b 10b7 :11 10b8
:20 10b9 :3 10b8 :11 10bb :b 10bc
:3 10bb :9 10be 10bf 10b7
:9 10bf :11 10c0 :2e 10c1 :3 10c0
:11 10c3 :b 10c4 :3 10c3 :c 10c6
10bf :3 10b7 :5 10ca :5 10cb
:4 10ce 10cf :4 10d0 10d1
10ce :6 10d2 :5 10d3 10d2
:5 10d5 10d4 :3 10d2 10cd
10d8 :5 10d9 :3 10d8 :2 10da
:5 10dc :11 10dd :24 10de :3 10dd
:2 10db :6 10da 10d7 :3 10a0
:3 10e3 :3 10e4 :3 10e5 :3 10e6
:3 10e7 :9 10e9 :f 10ea :3 10eb
10e9 :3 10ed 10ec :3 10e9
:3 10f1 :7 10f2 :6 10f3 :7 10f4
:6 10f5 :a 10f6 :3 10f2 :5 10fa
:11 10fb :30 10fc :3 10fb :11 10fe
:b 10ff :3 10fe :a 1101 1102
10fa :5 1102 :11 1103 :30 1104
:3 1103 :11 1106 :b 1107 :3 1106
:7 1109 110a :2 1109 1102
10fa 110d :2 110e :3 110f
:5 1110 :5 1111 :5 1112 :5 1113
:6 1114 :6 1115 :2 1116 110d
:6 1117 :5 1118 1117 :5 111a
1119 :3 1117 110c 111d
:5 111e :3 111d :2 111f :5 1121
:11 1122 :24 1123 :3 1122 :2 1120
:6 111f 111c :4 110b :3 10fa
10a0 :2 109f 1129 109c
:10 1129 112b :2 112c :4 112d
112b :6 112e :5 112f 112e
:5 1131 1130 :3 112e 112a
1134 :5 1135 :3 1134 :2 1136
:5 1138 :11 1139 :24 113a :3 1139
:2 1137 :6 1136 1133 :4 1129
:3 109c :3 1141 :5 1142 1141
:5 1143 1140 1145 :5 1146
:3 1145 :2 1147 :5 1149 :11 114a
:24 114b :3 114a :2 1148 :6 1147
1144 :3 1098 :9 1151 :5 1153
:4 1154 1153 :6 1155 :5 1156
1155 :5 1158 1157 :3 1155
1152 115b :5 115c :3 115b
:2 115d :5 115f :11 1160 :24 1161
:3 1160 :2 115e :6 115d 115a
:6 1151 :3 1098 :3 1168 :5 116b
116d :6 116e :6 116f :2 1170
116d :6 1171 :5 1172 1171
:5 1174 1173 :3 1171 116c
1177 :5 1178 :3 1177 :2 1179
:5 117b :11 117c :24 117d :3 117c
:2 117a :6 1179 1176 :3 116b
:9 1183 :3 1185 :4 1186 1185
:5 1187 1184 1189 :5 118a
:3 1189 :2 118b :5 118d :11 118e
:24 118f :3 118e :2 118c :6 118b
1188 :3 1183 :9 1195 :3 1197
:5 1198 1197 :6 1199 :5 119a
1199 :5 119c 119b :3 1199
1196 119f :5 11a0 :3 119f
:2 11a1 :5 11a3 :11 11a4 :24 11a5
:3 11a4 :2 11a2 :6 11a1 119e
:3 1195 :6 11ab :6 11ac :5 11ad
11ac :5 11af 11ae :3 11ac
11aa 11b2 :5 11b3 :3 11b2
:2 11b4 :5 11b6 :11 11b7 :24 11b8
:3 11b7 :2 11b5 :6 11b4 11b1
:6 1195 :3 1183 :3 11c0 :b 11c1
:d 11c4 :9 11c5 :3 11c6 11c4
:5 11c7 11c3 11c9 :5 11ca
:3 11c9 :2 11cb :5 11cd :11 11ce
:24 11cf :3 11ce :2 11cc :6 11cb
11c8 :3 116b :a 11d3 :5 11d4
:3 11d5 :3 11d4 :9 11d7 11d9
:2 11da :2 11db :2 11dc :3 11dd
11de :4 11df 11d9 :6 11e0
:5 11e1 11e0 :5 11e3 11e2
:3 11e0 11d8 11e6 :5 11e7
:3 11e6 :2 11e8 :5 11ea :11 11eb
:24 11ec :3 11eb :2 11e9 :6 11e8
11e5 :4 11d7 11f2 :2 11f3
:2 11f4 :2 11f5 :3 11f6 :3 11f7
:4 11f8 11f2 :6 11f9 :5 11fa
11f9 :5 11fc 11fb :3 11f9
11f1 11ff :5 1200 :3 11ff
:2 1201 :5 1203 :11 1204 :24 1205
:3 1204 :2 1202 :6 1201 11fe
:4 11f0 :3 11d7 :b 120b :b 120c
:3 120b :3 11d3 :a 1210 1211
:2 1210 :4 1211 :3 1210 :3 1212
1211 :2 1210 :3 116b :10 1216
:3 1218 :b 1219 :d 121c :9 121d
121e :2 121f 121c :5 1220
121b 1222 :5 1223 :3 1222
:2 1224 :5 1226 :11 1227 :24 1228
:3 1227 :2 1225 :6 1224 1221
:3 1216 :9 122d 122f :2 1230
:2 1231 :2 1232 :3 1233 1234
:4 1235 122f :6 1236 :5 1237
1236 :5 1239 1238 :3 1236
122e 123c :5 123d :3 123c
:2 123e :5 1240 :11 1241 :24 1242
:3 1241 :2 123f :6 123e 123b
:4 122d 1248 :2 1249 :2 124a
:2 124b :3 124c :3 124d :4 124e
1248 :6 124f :5 1250 124f
:5 1252 1251 :3 124f 1247
1255 :5 1256 :3 1255 :2 1257
:5 1259 :11 125a :24 125b :3 125a
:2 1258 :6 1257 1254 :4 1246
:3 122d :17 1261 :b 1262 :3 1261
:3 1216 :6 1266 :5 1269 126b
:2 126c :2 126d :2 126e :2 126f
:2 1270 :4 1271 126b :6 1272
:5 1273 1272 :5 1275 1274
:3 1272 126a 1278 :5 1279
:3 1278 :2 127a :5 127c :11 127d
:24 127e :3 127d :2 127b :6 127a
1277 :6 1269 :7 1283 :5 1284
:3 1283 :11 1288 :30 1289 :3 1288
:a 128b a3 :3 128e :11 128f
:b 1290 :17 1291 :3 128f :2 1293
:3 1294 :3 1295 1296 1294
1293 1294 :3 1297 :3 128e
:2 1298 :5 129a :11 129b :b 129c
:18 129d :3 129b :2 129f 12a0
:3 12a1 12a2 12a0 129f
12a0 :3 12a3 :2 1299 :6 1298
128d :7 1 
17fe6
4
:3 0 1 :3 0 2
:a 0 6dc5 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 4 :3 0 7
:7 0 11 10 :3 0
4 :3 0 8 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 9 :7 0 19
18 :3 0 a :3 0
b :7 0 1d 1c
:3 0 15 c8 0
13 a :3 0 c
:7 0 21 20 :3 0
a :3 0 d :7 0
25 24 :3 0 19
ee 0 17 a
:3 0 e :7 0 29
28 :3 0 a :3 0
f :7 0 2d 2c
:3 0 1d 114 0
1b a :3 0 10
:7 0 31 30 :3 0
a :3 0 11 :7 0
35 34 :3 0 21
:2 0 1f a :3 0
12 :7 0 39 38
:3 0 4 :3 0 13
:7 0 3d 3c :3 0
14 :3 0 15 :3 0
16 :2 0 4 41
42 0 3f 43
0 6dc5 2 44
:2 0 19 :2 0 33
18 :3 0 19 :2 0
31 47 49 2
:5 0 1a :3 0 1b
:3 0 4b 4c 0
4f 4a 4d 6dc3
0 17 :6 0 1e
:2 0 37 18 :3 0
35 51 53 2
:5 0 1a :3 0 1b
:3 0 55 56 0
59 54 57 6dc3
0 1c :6 0 1e
:2 0 3b 4 :3 0
39 5b 5d :6 0
60 5e 0 6dc3
0 1d :6 0 1e
:2 0 3f 4 :3 0
3d 62 64 :6 0
67 65 0 6dc3
0 1f :6 0 1e
:2 0 43 4 :3 0
41 69 6b :6 0
6e 6c 0 6dc3
0 20 :6 0 1e
:2 0 47 4 :3 0
45 70 72 :6 0
75 73 0 6dc3
0 21 :6 0 1e
:2 0 4b 4 :3 0
49 77 79 :6 0
7c 7a 0 6dc3
0 22 :6 0 1e
:2 0 4f 4 :3 0
4d 7e 80 :6 0
83 81 0 6dc3
0 23 :6 0 1e
:2 0 53 4 :3 0
51 85 87 :6 0
8a 88 0 6dc3
0 24 :6 0 1e
:2 0 57 4 :3 0
55 8c 8e :6 0
91 8f 0 6dc3
0 25 :6 0 1e
:2 0 5b 4 :3 0
59 93 95 :6 0
98 96 0 6dc3
0 26 :6 0 1e
:2 0 5f 4 :3 0
5d 9a 9c :6 0
9f 9d 0 6dc3
0 27 :6 0 1e
:2 0 63 4 :3 0
61 a1 a3 :6 0
a6 a4 0 6dc3
0 28 :6 0 1e
:2 0 67 4 :3 0
65 a8 aa :6 0
ad ab 0 6dc3
0 29 :6 0 1e
:2 0 6b 4 :3 0
69 af b1 :6 0
b4 b2 0 6dc3
0 2a :6 0 1e
:2 0 6f 4 :3 0
6d b6 b8 :6 0
bb b9 0 6dc3
0 2b :6 0 75
357 0 73 4
:3 0 71 bd bf
:6 0 c2 c0 0
6dc3 0 2c :6 0
79 38b 0 77
2e :3 0 c4 :7 0
c7 c5 0 6dc3
0 2d :6 0 2e
:3 0 c9 :7 0 cc
ca 0 6dc3 0
2f :6 0 33 :2 0
7b 2e :3 0 ce
:7 0 d1 cf 0
6dc3 0 30 :6 0
2e :3 0 d3 :7 0
d6 d4 0 6dc3
0 31 :6 0 33
:2 0 7f 4 :3 0
7d d8 da :6 0
dd db 0 6dc3
0 32 :6 0 85
3f9 0 83 4
:3 0 81 df e1
:6 0 e4 e2 0
6dc3 0 34 :6 0
89 42d 0 87
36 :3 0 e6 :7 0
e9 e7 0 6dc3
0 35 :6 0 36
:3 0 eb :7 0 ee
ec 0 6dc3 0
37 :6 0 3b :2 0
8d 36 :3 0 f0
:7 0 f3 f1 0
6dc3 0 38 :6 0
4 :3 0 33 :2 0
8b f5 f7 :6 0
fa f8 0 6dc3
0 39 :6 0 93
482 0 91 4
:3 0 8f fc fe
:6 0 101 ff 0
6dc3 0 3a :6 0
97 4b6 0 95
2e :3 0 103 :7 0
106 104 0 6dc3
0 3c :6 0 2e
:3 0 108 :7 0 10b
109 0 6dc3 0
3d :6 0 1e :2 0
99 2e :3 0 10d
:7 0 110 10e 0
6dc3 0 3e :6 0
2e :3 0 112 :7 0
115 113 0 6dc3
0 3f :6 0 42
:2 0 9d 4 :3 0
9b 117 119 :6 0
11c 11a 0 6dc3
0 40 :6 0 42
:2 0 a1 4 :3 0
9f 11e 120 :6 0
123 121 0 6dc3
0 41 :6 0 42
:2 0 a5 4 :3 0
a3 125 127 :6 0
12a 128 0 6dc3
0 43 :6 0 46
:2 0 a9 4 :3 0
a7 12c 12e :6 0
131 12f 0 6dc3
0 44 :6 0 48
:2 0 ad 4 :3 0
ab 133 135 :6 0
138 136 0 6dc3
0 45 :6 0 48
:2 0 af a :3 0
13a :7 0 13e 13b
13c 6dc3 0 47
:6 0 48 :2 0 b1
a :3 0 140 :7 0
144 141 142 6dc3
0 49 :6 0 48
:2 0 b3 a :3 0
146 :7 0 14a 147
148 6dc3 0 4a
:6 0 48 :2 0 b5
a :3 0 14c :7 0
150 14d 14e 6dc3
0 4b :6 0 48
:2 0 b7 a :3 0
152 :7 0 156 153
154 6dc3 0 4c
:6 0 48 :2 0 b9
a :3 0 158 :7 0
15c 159 15a 6dc3
0 4d :6 0 48
:2 0 bb a :3 0
15e :7 0 162 15f
160 6dc3 0 4e
:6 0 48 :2 0 bd
a :3 0 164 :7 0
168 165 166 6dc3
0 4f :6 0 48
:2 0 bf a :3 0
16a :7 0 16e 16b
16c 6dc3 0 50
:6 0 48 :2 0 c1
a :3 0 170 :7 0
174 171 172 6dc3
0 51 :6 0 48
:2 0 c3 a :3 0
176 :7 0 17a 177
178 6dc3 0 52
:6 0 48 :2 0 c5
a :3 0 17c :7 0
180 17d 17e 6dc3
0 53 :6 0 48
:2 0 c7 a :3 0
182 :7 0 186 183
184 6dc3 0 54
:6 0 48 :2 0 c9
a :3 0 188 :7 0
18c 189 18a 6dc3
0 55 :6 0 48
:2 0 cb a :3 0
18e :7 0 192 18f
190 6dc3 0 56
:6 0 48 :2 0 cd
a :3 0 194 :7 0
198 195 196 6dc3
0 57 :6 0 48
:2 0 cf a :3 0
19a :7 0 19e 19b
19c 6dc3 0 58
:6 0 48 :2 0 d1
a :3 0 1a0 :7 0
1a4 1a1 1a2 6dc3
0 59 :6 0 48
:2 0 d3 a :3 0
1a6 :7 0 1aa 1a7
1a8 6dc3 0 5a
:6 0 48 :2 0 d5
a :3 0 1ac :7 0
1b0 1ad 1ae 6dc3
0 5b :6 0 48
:2 0 d7 a :3 0
1b2 :7 0 1b6 1b3
1b4 6dc3 0 5c
:6 0 48 :2 0 d9
a :3 0 1b8 :7 0
1bc 1b9 1ba 6dc3
0 5d :6 0 48
:2 0 db a :3 0
1be :7 0 1c2 1bf
1c0 6dc3 0 5e
:6 0 48 :2 0 dd
a :3 0 1c4 :7 0
1c8 1c5 1c6 6dc3
0 5f :6 0 48
:2 0 df a :3 0
1ca :7 0 1ce 1cb
1cc 6dc3 0 60
:6 0 48 :2 0 e1
a :3 0 1d0 :7 0
1d4 1d1 1d2 6dc3
0 61 :6 0 48
:2 0 e3 a :3 0
1d6 :7 0 1da 1d7
1d8 6dc3 0 62
:6 0 48 :2 0 e5
a :3 0 1dc :7 0
1e0 1dd 1de 6dc3
0 63 :6 0 48
:2 0 e7 a :3 0
1e2 :7 0 1e6 1e3
1e4 6dc3 0 64
:6 0 48 :2 0 e9
66 :3 0 1e8 :7 0
1ec 1e9 1ea 6dc3
0 65 :6 0 48
:2 0 eb 66 :3 0
1ee :7 0 1f2 1ef
1f0 6dc3 0 67
:6 0 48 :2 0 ed
66 :3 0 1f4 :7 0
1f8 1f5 1f6 6dc3
0 68 :6 0 48
:2 0 ef 66 :3 0
1fa :7 0 1fe 1fb
1fc 6dc3 0 69
:6 0 48 :2 0 f1
66 :3 0 200 :7 0
204 201 202 6dc3
0 6a :6 0 48
:2 0 f3 a :3 0
206 :7 0 20a 207
208 6dc3 0 6b
:6 0 48 :2 0 f5
a :3 0 20c :7 0
210 20d 20e 6dc3
0 6c :6 0 48
:2 0 f7 a :3 0
212 :7 0 216 213
214 6dc3 0 6d
:6 0 48 :2 0 f9
a :3 0 218 :7 0
21c 219 21a 6dc3
0 6e :6 0 48
:2 0 fb a :3 0
21e :7 0 222 21f
220 6dc3 0 6f
:6 0 48 :2 0 fd
a :3 0 224 :7 0
228 225 226 6dc3
0 70 :6 0 48
:2 0 ff a :3 0
22a :7 0 22e 22b
22c 6dc3 0 71
:6 0 48 :2 0 101
a :3 0 230 :7 0
234 231 232 6dc3
0 72 :6 0 75
:2 0 103 a :3 0
236 :7 0 23a 237
238 6dc3 0 73
:6 0 75 :2 0 107
4 :3 0 105 23c
23e :6 0 241 23f
0 6dc3 0 74
:6 0 48 :2 0 10b
4 :3 0 109 243
245 :6 0 248 246
0 6dc3 0 76
:6 0 48 :2 0 10d
66 :3 0 24a :7 0
24e 24b 24c 6dc3
0 77 :6 0 33
:2 0 10f a :3 0
250 :7 0 254 251
252 6dc3 0 78
:6 0 48 :2 0 113
4 :3 0 111 256
258 :6 0 25b 259
0 6dc3 0 79
:6 0 1e :2 0 115
a :3 0 25d :7 0
261 25e 25f 6dc3
0 7a :6 0 33
:2 0 119 4 :3 0
117 263 265 :6 0
268 266 0 6dc3
0 7b :6 0 48
:2 0 11d 4 :3 0
11b 26a 26c :6 0
26f 26d 0 6dc3
0 7c :6 0 48
:2 0 11f a :3 0
271 :7 0 275 272
273 6dc3 0 7d
:6 0 48 :2 0 121
a :3 0 277 :7 0
27b 278 279 6dc3
0 7e :6 0 48
:2 0 123 66 :3 0
27d :7 0 281 27e
27f 6dc3 0 7f
:6 0 48 :2 0 125
66 :3 0 283 :7 0
287 284 285 6dc3
0 80 :6 0 48
:2 0 127 66 :3 0
289 :7 0 28d 28a
28b 6dc3 0 81
:6 0 48 :2 0 129
66 :3 0 28f :7 0
293 290 291 6dc3
0 82 :6 0 48
:2 0 12b a :3 0
295 :7 0 299 296
297 6dc3 0 83
:6 0 48 :2 0 12d
a :3 0 29b :7 0
29f 29c 29d 6dc3
0 84 :6 0 48
:2 0 12f a :3 0
2a1 :7 0 2a5 2a2
2a3 6dc3 0 85
:6 0 48 :2 0 131
a :3 0 2a7 :7 0
2ab 2a8 2a9 6dc3
0 86 :6 0 48
:2 0 133 a :3 0
2ad :7 0 2b1 2ae
2af 6dc3 0 87
:6 0 48 :2 0 135
a :3 0 2b3 :7 0
2b7 2b4 2b5 6dc3
0 88 :6 0 48
:2 0 137 a :3 0
2b9 :7 0 2bd 2ba
2bb 6dc3 0 89
:6 0 48 :2 0 139
a :3 0 2bf :7 0
2c3 2c0 2c1 6dc3
0 8a :6 0 1e
:2 0 13b a :3 0
2c5 :7 0 2c9 2c6
2c7 6dc3 0 8b
:6 0 1e :2 0 13f
4 :3 0 13d 2cb
2cd :6 0 2d0 2ce
0 6dc3 0 8c
:6 0 1e :2 0 143
4 :3 0 141 2d2
2d4 :6 0 2d7 2d5
0 6dc3 0 8d
:6 0 48 :2 0 147
4 :3 0 145 2d9
2db :6 0 2de 2dc
0 6dc3 0 8e
:6 0 1e :2 0 149
a :3 0 2e0 :7 0
2e4 2e1 2e2 6dc3
0 8f :6 0 48
:2 0 14d 4 :3 0
14b 2e6 2e8 :6 0
2eb 2e9 0 6dc3
0 90 :6 0 48
:2 0 14f a :3 0
2ed :7 0 2f1 2ee
2ef 6dc3 0 91
:6 0 48 :2 0 151
a :3 0 2f3 :7 0
2f7 2f4 2f5 6dc3
0 92 :6 0 48
:2 0 153 a :3 0
2f9 :7 0 2fd 2fa
2fb 6dc3 0 93
:6 0 157 db8 0
155 a :3 0 2ff
:7 0 303 300 301
6dc3 0 94 :6 0
48 :2 0 159 a
:3 0 305 :7 0 308
306 0 6dc3 0
95 :6 0 a :3 0
30a :7 0 30d 30b
0 6dc3 0 96
:6 0 48 :2 0 15b
a :3 0 30f 0
2 :5 0 313 310
311 6dc3 0 97
:6 0 48 :2 0 15d
a :3 0 315 0
2 :5 0 319 316
317 6dc3 0 98
:6 0 48 :2 0 15f
a :3 0 31b 0
2 :5 0 31f 31c
31d 6dc3 0 99
:6 0 48 :2 0 161
a :3 0 321 0
2 :5 0 325 322
323 6dc3 0 9a
:6 0 165 e78 0
163 a :3 0 327
0 2 :5 0 32b
328 329 6dc3 0
9b :9 0 167 9d
:3 0 32d :7 0 330
32e 0 6dc3 0
9c :6 0 a :3 0
332 0 2 :5 0
48 :2 0 336 333
334 6dc3 0 9e
:6 0 9f :3 0 a0
:a 0 2 342 :4 0
338 33b 0 339
:3 0 a1 :3 0 a2
:3 0 a3 :3 0 a4
:3 0 2a :4 0 a5
1 :8 0 343 338
33b 344 0 6dc3
169 344 346 343
345 :6 0 342 :7 0
344 9f :3 0 a6
:a 0 3 356 :5 0
348 34b 0 349
:3 0 a7 :3 0 a8
:3 0 a3 :3 0 a9
:3 0 2b :3 0 aa
:3 0 2a :3 0 ab
:3 0 ac :4 0 ad
1 :8 0 357 348
34b 358 0 6dc3
16b 358 35a 357
359 :6 0 356 :7 0
358 9f :3 0 ae
:a 0 4 3ce :5 0
35c 35f 0 35d
:3 0 af :3 0 b0
:3 0 b1 :3 0 b2
:3 0 b1 :3 0 b3
:3 0 af :3 0 b4
:3 0 b1 :3 0 b5
:3 0 b1 :3 0 b6
:3 0 b1 :3 0 b7
:3 0 b1 :3 0 b7
:3 0 b1 :3 0 b8
:3 0 b9 :3 0 ba
:3 0 b1 :3 0 bb
:3 0 b9 :3 0 bb
:3 0 b1 :3 0 bb
:3 0 b1 :3 0 ac
:3 0 b1 :3 0 bc
:3 0 b1 :3 0 bd
:3 0 b1 :3 0 be
:3 0 b1 :3 0 bf
:3 0 b1 :3 0 c0
:3 0 b1 :3 0 c1
:3 0 b1 :3 0 c2
:3 0 b1 :3 0 c3
:3 0 b1 :3 0 c4
:3 0 b1 :3 0 c5
:3 0 b1 :3 0 c6
:3 0 c7 :3 0 b9
:3 0 c8 :3 0 af
:3 0 a8 :3 0 b1
:3 0 af :3 0 a9
:3 0 2b :3 0 af
:3 0 aa :3 0 2c
:3 0 af :3 0 ab
:3 0 b1 :3 0 b0
:3 0 af :3 0 b0
:3 0 af :3 0 a4
:3 0 b9 :3 0 a4
:3 0 af :3 0 b4
:3 0 1a :3 0 c9
:3 0 1a :3 0 ca
:3 0 1a :3 0 cb
:3 0 1a :3 0 cc
:3 0 1a :3 0 cd
:3 0 1a :3 0 ce
:3 0 1a :3 0 cf
:3 0 1a :3 0 d0
:3 0 1a :3 0 d1
:3 0 1a :3 0 d2
:3 0 1a :3 0 d3
:3 0 1a :3 0 d4
:3 0 1a :3 0 d5
:3 0 1a :3 0 d6
:3 0 1a :3 0 d7
:3 0 b9 :3 0 d8
:3 0 3a :3 0 b1
:3 0 b7 :4 0 d9
1 :8 0 3cf 35c
35f 3d0 0 6dc3
16d 3d0 3d2 3cf
3d1 :6 0 3ce :7 0
3d0 3da 3db 0
16f 15 :3 0 16
:2 0 4 3d4 3d5
0 3d6 :7 0 3d9
3d7 0 6dc3 0
da :6 0 db :3 0
dc :3 0 db :3 0
dd :3 0 3dd 3de
0 2 :4 0 171
3df 3e1 3dc 3e3
3e2 :2 0 de :3 0
df :3 0 3e5 3e6
0 e0 :4 0 db
:3 0 e1 :3 0 3e9
3ea 0 2 :4 0
173 3eb 3ed e2
:4 0 e3 :2 0 e4
:3 0 175 3f0 3f2
:3 0 e5 :4 0 e3
:2 0 e6 :4 0 178
3f5 3f7 :3 0 e3
:2 0 3 :3 0 17b
3f9 3fb :3 0 e3
:2 0 e6 :4 0 17e
3fd 3ff :3 0 e3
:2 0 e7 :4 0 181
401 403 :3 0 e3
:2 0 e6 :4 0 184
405 407 :3 0 e3
:2 0 5 :3 0 187
409 40b :3 0 e3
:2 0 e6 :4 0 18a
40d 40f :3 0 e3
:2 0 e7 :4 0 18d
411 413 :3 0 e3
:2 0 e6 :4 0 190
415 417 :3 0 e3
:2 0 6 :3 0 193
419 41b :3 0 e3
:2 0 e6 :4 0 196
41d 41f :3 0 e3
:2 0 e7 :4 0 199
421 423 :3 0 e3
:2 0 e6 :4 0 19c
425 427 :3 0 e3
:2 0 7 :3 0 19f
429 42b :3 0 e3
:2 0 e6 :4 0 1a2
42d 42f :3 0 e3
:2 0 e7 :4 0 1a5
431 433 :3 0 e3
:2 0 e6 :4 0 1a8
435 437 :3 0 e3
:2 0 8 :3 0 1ab
439 43b :3 0 e3
:2 0 e6 :4 0 1ae
43d 43f :3 0 e3
:2 0 e7 :4 0 1b1
441 443 :3 0 e3
:2 0 e8 :3 0 e9
:3 0 9 :3 0 1b4
447 449 ea :4 0
1b6 446 44c 1b9
445 44e :3 0 e3
:2 0 e7 :4 0 1bc
450 452 :3 0 e3
:2 0 e8 :3 0 e9
:3 0 b :3 0 1bf
456 458 ea :4 0
1c1 455 45b 1c4
454 45d :3 0 e3
:2 0 e7 :4 0 1c7
45f 461 :3 0 e3
:2 0 e8 :3 0 e9
:3 0 c :3 0 1ca
465 467 ea :4 0
1cc 464 46a 1cf
463 46c :3 0 e3
:2 0 e7 :4 0 1d2
46e 470 :3 0 e3
:2 0 e8 :3 0 e9
:3 0 d :3 0 1d5
474 476 ea :4 0
1d7 473 479 1da
472 47b :3 0 e3
:2 0 e7 :4 0 1dd
47d 47f :3 0 e3
:2 0 e8 :3 0 e9
:3 0 e :3 0 1e0
483 485 ea :4 0
1e2 482 488 1e5
481 48a :3 0 e3
:2 0 e7 :4 0 1e8
48c 48e :3 0 e3
:2 0 e8 :3 0 e9
:3 0 f :3 0 1eb
492 494 ea :4 0
1ed 491 497 1f0
490 499 :3 0 e3
:2 0 e7 :4 0 1f3
49b 49d :3 0 e3
:2 0 e8 :3 0 e9
:3 0 10 :3 0 1f6
4a1 4a3 ea :4 0
1f8 4a0 4a6 1fb
49f 4a8 :3 0 e3
:2 0 e7 :4 0 1fe
4aa 4ac :3 0 e3
:2 0 e8 :3 0 e9
:3 0 11 :3 0 201
4b0 4b2 ea :4 0
203 4af 4b5 206
4ae 4b7 :3 0 e3
:2 0 e7 :4 0 209
4b9 4bb :3 0 e3
:2 0 e8 :3 0 e9
:3 0 12 :3 0 20c
4bf 4c1 ea :4 0
20e 4be 4c4 211
4bd 4c6 :3 0 e3
:2 0 e7 :4 0 214
4c8 4ca :3 0 e3
:2 0 e6 :4 0 217
4cc 4ce :3 0 e3
:2 0 13 :3 0 21a
4d0 4d2 :3 0 e3
:2 0 e6 :4 0 21d
4d4 4d6 :3 0 e3
:2 0 eb :4 0 220
4d8 4da :3 0 223
3e7 4dc :2 0 4de
228 4df 3e4 4de
0 4e0 22a 0
6d23 db :3 0 dc
:3 0 4e1 4e2 0
db :3 0 ec :3 0
4e4 4e5 0 33
:2 0 2 :4 0 ed
:2 0 ee :2 0 33
:2 0 22c 4ea 4ec
:3 0 22f 4e6 4ee
4e3 4f0 4ef :2 0
de :3 0 ef :3 0
4f2 4f3 0 e0
:4 0 f0 :4 0 e3
:2 0 e4 :3 0 233
4f7 4f9 :3 0 236
4f4 4fb :2 0 4fd
239 4fe 4f1 4fd
0 4ff 23b 0
6d23 29 :3 0 3
:3 0 500 501 0
6d23 2c :3 0 5
:3 0 503 504 0
6d23 2a :3 0 6
:3 0 506 507 0
6d23 21 :3 0 13
:3 0 509 50a 0
6d23 5e :3 0 11
:3 0 50c 50d 0
6d23 5e :3 0 f1
:3 0 e8 :3 0 5e
:3 0 48 :2 0 23d
511 514 1a :3 0
f2 :3 0 516 517
0 240 510 519
50f 51a 0 6d23
e8 :3 0 5e :3 0
48 :2 0 243 51c
51f 1a :3 0 f3
:2 0 f4 :3 0 521
523 0 248 522
525 :3 0 526 :2 0
e8 :3 0 5e :3 0
48 :2 0 24b 528
52b 1a :3 0 f3
:2 0 f5 :3 0 52d
52f 0 250 52e
531 :3 0 532 :2 0
527 534 533 :2 0
5e :3 0 f6 :2 0
536 537 0 539
253 53a 535 539
0 53b 255 0
6d23 45 :3 0 f7
:4 0 53c 53d 0
6d23 34 :3 0 f7
:4 0 53f 540 0
6d23 51 :3 0 48
:2 0 542 543 0
6d23 2f :3 0 f7
:4 0 545 546 0
6d23 f8 :3 0 a0
:4 0 54b :2 0 6d23
549 54c :3 0 a0
:3 0 62 :4 0 550
:2 0 6d23 54d 54e
:3 0 a0 :3 0 f9
:3 0 551 552 :3 0
15 :3 0 fa :3 0
554 555 0 48
:2 0 556 557 0
559 257 560 15
:3 0 fa :3 0 55a
55b 0 fb :2 0
55c 55d 0 55f
259 561 553 559
0 562 0 55f
0 562 25b 0
6d23 62 :3 0 15
:3 0 fa :3 0 564
565 0 563 566
0 6d23 fc :3 0
a0 :4 0 56b :2 0
571 569 0 15
:3 0 fa :3 0 56c
56d 0 fd :3 0
56e 56f 0 571
25e 5c4 fe :3 0
15 :3 0 fa :3 0
573 574 0 fd
:3 0 575 576 0
578 261 57a 263
579 578 :2 0 5c2
ff :3 0 15 :3 0
fa :3 0 57d 57e
0 fd :3 0 57f
580 0 5ba db
:3 0 dc :3 0 582
583 0 db :3 0
ec :3 0 585 586
0 100 :2 0 2
:4 0 101 :2 0 ee
:2 0 33 :2 0 265
58b 58d :3 0 268
587 58f 584 591
590 :2 0 de :3 0
ef :3 0 593 594
0 e0 :4 0 102
:4 0 e3 :2 0 e4
:3 0 26c 598 59a
:3 0 e3 :2 0 103
:4 0 26f 59c 59e
:3 0 e3 :2 0 104
:4 0 272 5a0 5a2
:3 0 e3 :2 0 fd
:3 0 275 5a4 5a6
:3 0 e3 :2 0 105
:4 0 278 5a8 5aa
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 27b
5ad 5b1 27f 5ac
5b3 :3 0 282 595
5b5 :2 0 5b7 285
5b8 592 5b7 0
5b9 287 0 5ba
289 5bd :3 0 5bd
0 5bd 5bc 5ba
5bb :6 0 5bf 5
:3 0 28c 5c1 28e
5c0 5bf :2 0 5c2
290 :2 0 5c4 0
5c4 5c3 571 5c2
:6 0 6d23 1 :3 0
e8 :3 0 62 :3 0
48 :2 0 293 5c6
5c9 f3 :2 0 fb
:2 0 298 5cb 5cd
:3 0 db :3 0 dc
:3 0 5cf 5d0 0
db :3 0 ec :3 0
5d2 5d3 0 1e
:2 0 2 :4 0 109
:2 0 ee :2 0 33
:2 0 29b 5d8 5da
:3 0 29e 5d4 5dc
5d1 5de 5dd :2 0
de :3 0 ef :3 0
5e0 5e1 0 e0
:4 0 10a :4 0 e3
:2 0 e4 :3 0 2a2
5e5 5e7 :3 0 e3
:2 0 103 :4 0 2a5
5e9 5eb :3 0 e3
:2 0 10b :4 0 2a8
5ed 5ef :3 0 e3
:2 0 e8 :3 0 e9
:3 0 1a :3 0 10c
:3 0 5f4 5f5 0
2ab 5f3 5f7 ea
:4 0 2ad 5f2 5fa
2b0 5f1 5fc :3 0
e3 :2 0 10d :4 0
2b3 5fe 600 :3 0
e3 :2 0 e6 :4 0
2b6 602 604 :3 0
e3 :2 0 2a :3 0
2b9 606 608 :3 0
e3 :2 0 e6 :4 0
2bc 60a 60c :3 0
2bf 5e2 60e :2 0
610 2c2 611 5df
610 0 612 2c4
0 63c db :3 0
dc :3 0 613 614
0 db :3 0 ec
:3 0 616 617 0
33 :2 0 2 :4 0
10e :2 0 ee :2 0
33 :2 0 2c6 61c
61e :3 0 2c9 618
620 615 622 621
:2 0 de :3 0 ef
:3 0 624 625 0
e0 :4 0 10f :4 0
e3 :2 0 e4 :3 0
2cd 629 62b :3 0
2d0 626 62d :2 0
62f 2d3 630 623
62f 0 631 2d5
0 63c 110 :3 0
111 :3 0 632 633
0 1a :3 0 10c
:3 0 635 636 0
2a :3 0 112 :3 0
2d7 634 63a :2 0
63c 2db 63d 5ce
63c 0 63e 2df
0 6d23 113 :3 0
d8 :3 0 a9 :3 0
114 :3 0 115 :3 0
116 :3 0 4e :3 0
3a :3 0 2b :3 0
8c :3 0 8d :3 0
55 :3 0 c7 :3 0
a4 :3 0 29 :4 0
117 1 :8 0 654
15 :3 0 fa :3 0
64f 650 0 fd
:3 0 651 652 0
654 2e1 6a7 fe
:3 0 15 :3 0 fa
:3 0 656 657 0
fd :3 0 658 659
0 65b 2e4 65d
2e6 65c 65b :2 0
6a5 ff :3 0 15
:3 0 fa :3 0 660
661 0 fd :3 0
662 663 0 69d
db :3 0 dc :3 0
665 666 0 db
:3 0 ec :3 0 668
669 0 100 :2 0
2 :4 0 118 :2 0
ee :2 0 33 :2 0
2e8 66e 670 :3 0
2eb 66a 672 667
674 673 :2 0 de
:3 0 ef :3 0 676
677 0 e0 :4 0
119 :4 0 e3 :2 0
e4 :3 0 2ef 67b
67d :3 0 e3 :2 0
103 :4 0 2f2 67f
681 :3 0 e3 :2 0
104 :4 0 2f5 683
685 :3 0 e3 :2 0
fd :3 0 2f8 687
689 :3 0 e3 :2 0
105 :4 0 2fb 68b
68d :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
2fe 690 694 302
68f 696 :3 0 305
678 698 :2 0 69a
308 69b 675 69a
0 69c 30a 0
69d 30c 6a0 :3 0
6a0 0 6a0 69f
69d 69e :6 0 6a2
7 :3 0 30f 6a4
311 6a3 6a2 :2 0
6a5 313 :2 0 6a7
0 6a7 6a6 654
6a5 :6 0 6d23 1
:3 0 15 :3 0 fa
:3 0 6a9 6aa 0
15 :3 0 f3 :2 0
11a :3 0 6ac 6ae
0 318 6ad 6b0
:3 0 6b1 :2 0 db
:3 0 dc :3 0 6b3
6b4 0 db :3 0
ec :3 0 6b6 6b7
0 1e :2 0 2
:4 0 11b :2 0 ee
:2 0 33 :2 0 31b
6bc 6be :3 0 31e
6b8 6c0 6b5 6c2
6c1 :2 0 de :3 0
ef :3 0 6c4 6c5
0 e0 :4 0 11c
:4 0 e3 :2 0 e4
:3 0 322 6c9 6cb
:3 0 e3 :2 0 103
:4 0 325 6cd 6cf
:3 0 e3 :2 0 10b
:4 0 328 6d1 6d3
:3 0 e3 :2 0 e8
:3 0 e9 :3 0 1a
:3 0 10c :3 0 6d8
6d9 0 32b 6d7
6db ea :4 0 32d
6d6 6de 330 6d5
6e0 :3 0 e3 :2 0
10d :4 0 333 6e2
6e4 :3 0 e3 :2 0
e6 :4 0 336 6e6
6e8 :3 0 e3 :2 0
29 :3 0 339 6ea
6ec :3 0 e3 :2 0
e6 :4 0 33c 6ee
6f0 :3 0 33f 6c6
6f2 :2 0 6f4 342
6f5 6c3 6f4 0
6f6 344 0 720
db :3 0 dc :3 0
6f7 6f8 0 db
:3 0 ec :3 0 6fa
6fb 0 33 :2 0
2 :4 0 11d :2 0
ee :2 0 33 :2 0
346 700 702 :3 0
349 6fc 704 6f9
706 705 :2 0 de
:3 0 ef :3 0 708
709 0 e0 :4 0
11e :4 0 e3 :2 0
e4 :3 0 34d 70d
70f :3 0 350 70a
711 :2 0 713 353
714 707 713 0
715 355 0 720
110 :3 0 111 :3 0
716 717 0 1a
:3 0 10c :3 0 719
71a 0 29 :3 0
112 :3 0 357 718
71e :2 0 720 35b
721 6b2 720 0
722 35f 0 6d23
78 :3 0 48 :2 0
723 724 0 6d23
11f :3 0 78 :3 0
120 :3 0 a9 :3 0
2b :4 0 121 1
:8 0 731 15 :3 0
fa :3 0 72c 72d
0 fd :3 0 72e
72f 0 731 361
784 fe :3 0 15
:3 0 fa :3 0 733
734 0 fd :3 0
735 736 0 738
364 73a 366 739
738 :2 0 782 ff
:3 0 15 :3 0 fa
:3 0 73d 73e 0
fd :3 0 73f 740
0 77a db :3 0
dc :3 0 742 743
0 db :3 0 ec
:3 0 745 746 0
100 :2 0 2 :4 0
122 :2 0 ee :2 0
33 :2 0 368 74b
74d :3 0 36b 747
74f 744 751 750
:2 0 de :3 0 ef
:3 0 753 754 0
e0 :4 0 123 :4 0
e3 :2 0 e4 :3 0
36f 758 75a :3 0
e3 :2 0 103 :4 0
372 75c 75e :3 0
e3 :2 0 104 :4 0
375 760 762 :3 0
e3 :2 0 fd :3 0
378 764 766 :3 0
e3 :2 0 105 :4 0
37b 768 76a :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 37e 76d
771 382 76c 773
:3 0 385 755 775
:2 0 777 388 778
752 777 0 779
38a 0 77a 38c
77d :3 0 77d 0
77d 77c 77a 77b
:6 0 77f 9 :3 0
38f 781 391 780
77f :2 0 782 393
:2 0 784 0 784
783 731 782 :6 0
6d23 1 :3 0 e8
:3 0 78 :3 0 48
:2 0 396 786 789
124 :2 0 48 :2 0
39b 78b 78d :3 0
db :3 0 dc :3 0
78f 790 0 db
:3 0 ec :3 0 792
793 0 1e :2 0
2 :4 0 125 :2 0
ee :2 0 33 :2 0
39e 798 79a :3 0
3a1 794 79c 791
79e 79d :2 0 de
:3 0 ef :3 0 7a0
7a1 0 e0 :4 0
126 :4 0 e3 :2 0
e4 :3 0 3a5 7a5
7a7 :3 0 e3 :2 0
103 :4 0 3a8 7a9
7ab :3 0 e3 :2 0
10b :4 0 3ab 7ad
7af :3 0 e3 :2 0
e8 :3 0 e9 :3 0
1a :3 0 127 :3 0
7b4 7b5 0 3ae
7b3 7b7 ea :4 0
3b0 7b2 7ba 3b3
7b1 7bc :3 0 e3
:2 0 10d :4 0 3b6
7be 7c0 :3 0 e3
:2 0 e6 :4 0 3b9
7c2 7c4 :3 0 e3
:2 0 2b :3 0 3bc
7c6 7c8 :3 0 e3
:2 0 e6 :4 0 3bf
7ca 7cc :3 0 3c2
7a2 7ce :2 0 7d0
3c5 7d1 79f 7d0
0 7d2 3c7 0
7fc db :3 0 dc
:3 0 7d3 7d4 0
db :3 0 ec :3 0
7d6 7d7 0 33
:2 0 2 :4 0 128
:2 0 ee :2 0 33
:2 0 3c9 7dc 7de
:3 0 3cc 7d8 7e0
7d5 7e2 7e1 :2 0
de :3 0 ef :3 0
7e4 7e5 0 e0
:4 0 129 :4 0 e3
:2 0 e4 :3 0 3d0
7e9 7eb :3 0 3d3
7e6 7ed :2 0 7ef
3d6 7f0 7e3 7ef
0 7f1 3d8 0
7fc 110 :3 0 111
:3 0 7f2 7f3 0
1a :3 0 127 :3 0
7f5 7f6 0 2b
:3 0 112 :3 0 3da
7f4 7fa :2 0 7fc
3de 7fd 78e 7fc
0 7fe 3e2 0
6d23 12a :3 0 113
:3 0 12a :3 0 12b
:3 0 e8 :3 0 12a
:3 0 12c :3 0 e8
:3 0 12a :3 0 12d
:3 0 12a :3 0 12e
:3 0 12a :3 0 12f
:3 0 130 :3 0 131
:3 0 132 :3 0 133
:3 0 4d :3 0 71
:3 0 5b :3 0 5c
:3 0 5f :3 0 6b
:3 0 6a :3 0 c7
:3 0 12a :3 0 134
:3 0 135 :3 0 132
:3 0 12a :3 0 12f
:3 0 132 :3 0 a4
:3 0 12a :3 0 a4
:3 0 2b :4 0 136
1 :8 0 82a 15
:3 0 fa :3 0 825
826 0 fd :3 0
827 828 0 82a
3e4 87d fe :3 0
15 :3 0 fa :3 0
82c 82d 0 fd
:3 0 82e 82f 0
831 3e7 833 3e9
832 831 :2 0 87b
ff :3 0 15 :3 0
fa :3 0 836 837
0 fd :3 0 838
839 0 873 db
:3 0 dc :3 0 83b
83c 0 db :3 0
ec :3 0 83e 83f
0 100 :2 0 2
:4 0 137 :2 0 ee
:2 0 33 :2 0 3eb
844 846 :3 0 3ee
840 848 83d 84a
849 :2 0 de :3 0
ef :3 0 84c 84d
0 e0 :4 0 138
:4 0 e3 :2 0 e4
:3 0 3f2 851 853
:3 0 e3 :2 0 103
:4 0 3f5 855 857
:3 0 e3 :2 0 104
:4 0 3f8 859 85b
:3 0 e3 :2 0 fd
:3 0 3fb 85d 85f
:3 0 e3 :2 0 105
:4 0 3fe 861 863
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 401
866 86a 405 865
86c :3 0 408 84e
86e :2 0 870 40b
871 84b 870 0
872 40d 0 873
40f 876 :3 0 876
0 876 875 873
874 :6 0 878 b
:3 0 412 87a 414
879 878 :2 0 87b
416 :2 0 87d 0
87d 87c 82a 87b
:6 0 6d23 1 :3 0
15 :3 0 fa :3 0
87f 880 0 15
:3 0 f3 :2 0 11a
:3 0 882 884 0
41b 883 886 :3 0
887 :2 0 db :3 0
dc :3 0 889 88a
0 db :3 0 ec
:3 0 88c 88d 0
1e :2 0 2 :4 0
139 :2 0 ee :2 0
33 :2 0 41e 892
894 :3 0 421 88e
896 88b 898 897
:2 0 de :3 0 ef
:3 0 89a 89b 0
e0 :4 0 13a :4 0
e3 :2 0 e4 :3 0
425 89f 8a1 :3 0
e3 :2 0 103 :4 0
428 8a3 8a5 :3 0
e3 :2 0 10b :4 0
42b 8a7 8a9 :3 0
e3 :2 0 e8 :3 0
e9 :3 0 1a :3 0
10c :3 0 8ae 8af
0 42e 8ad 8b1
ea :4 0 430 8ac
8b4 433 8ab 8b6
:3 0 e3 :2 0 10d
:4 0 436 8b8 8ba
:3 0 e3 :2 0 e6
:4 0 439 8bc 8be
:3 0 e3 :2 0 29
:3 0 43c 8c0 8c2
:3 0 e3 :2 0 e6
:4 0 43f 8c4 8c6
:3 0 442 89c 8c8
:2 0 8ca 445 8cb
899 8ca 0 8cc
447 0 8f6 db
:3 0 dc :3 0 8cd
8ce 0 db :3 0
ec :3 0 8d0 8d1
0 33 :2 0 2
:4 0 13b :2 0 ee
:2 0 33 :2 0 449
8d6 8d8 :3 0 44c
8d2 8da 8cf 8dc
8db :2 0 de :3 0
ef :3 0 8de 8df
0 e0 :4 0 13c
:4 0 e3 :2 0 e4
:3 0 450 8e3 8e5
:3 0 453 8e0 8e7
:2 0 8e9 456 8ea
8dd 8e9 0 8eb
458 0 8f6 110
:3 0 111 :3 0 8ec
8ed 0 1a :3 0
10c :3 0 8ef 8f0
0 29 :3 0 112
:3 0 45a 8ee 8f4
:2 0 8f6 45e 8f7
888 8f6 0 8f8
462 0 6d23 13d
:3 0 13e :3 0 41
:3 0 45 :3 0 13f
:3 0 aa :3 0 2a
:4 0 140 1 :8 0
906 15 :3 0 fa
:3 0 901 902 0
fd :3 0 903 904
0 906 464 959
fe :3 0 15 :3 0
fa :3 0 908 909
0 fd :3 0 90a
90b 0 90d 467
90f 469 90e 90d
:2 0 957 ff :3 0
15 :3 0 fa :3 0
912 913 0 fd
:3 0 914 915 0
94f db :3 0 dc
:3 0 917 918 0
db :3 0 ec :3 0
91a 91b 0 100
:2 0 2 :4 0 141
:2 0 ee :2 0 33
:2 0 46b 920 922
:3 0 46e 91c 924
919 926 925 :2 0
de :3 0 ef :3 0
928 929 0 e0
:4 0 142 :4 0 e3
:2 0 e4 :3 0 472
92d 92f :3 0 e3
:2 0 103 :4 0 475
931 933 :3 0 e3
:2 0 104 :4 0 478
935 937 :3 0 e3
:2 0 fd :3 0 47b
939 93b :3 0 e3
:2 0 105 :4 0 47e
93d 93f :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 481 942 946
485 941 948 :3 0
488 92a 94a :2 0
94c 48b 94d 927
94c 0 94e 48d
0 94f 48f 952
:3 0 952 0 952
951 94f 950 :6 0
954 d :3 0 492
956 494 955 954
:2 0 957 496 :2 0
959 0 959 958
906 957 :6 0 6d23
1 :3 0 15 :3 0
fa :3 0 95b 95c
0 15 :3 0 f3
:2 0 11a :3 0 95e
960 0 49b 95f
962 :3 0 963 :2 0
db :3 0 dc :3 0
965 966 0 db
:3 0 ec :3 0 968
969 0 1e :2 0
2 :4 0 143 :2 0
ee :2 0 33 :2 0
49e 96e 970 :3 0
4a1 96a 972 967
974 973 :2 0 de
:3 0 ef :3 0 976
977 0 e0 :4 0
144 :4 0 e3 :2 0
e4 :3 0 4a5 97b
97d :3 0 e3 :2 0
103 :4 0 4a8 97f
981 :3 0 e3 :2 0
10b :4 0 4ab 983
985 :3 0 e3 :2 0
e8 :3 0 e9 :3 0
1a :3 0 10c :3 0
98a 98b 0 4ae
989 98d ea :4 0
4b0 988 990 4b3
987 992 :3 0 e3
:2 0 10d :4 0 4b6
994 996 :3 0 e3
:2 0 e6 :4 0 4b9
998 99a :3 0 e3
:2 0 2a :3 0 4bc
99c 99e :3 0 e3
:2 0 e6 :4 0 4bf
9a0 9a2 :3 0 4c2
978 9a4 :2 0 9a6
4c5 9a7 975 9a6
0 9a8 4c7 0
9d2 db :3 0 dc
:3 0 9a9 9aa 0
db :3 0 ec :3 0
9ac 9ad 0 33
:2 0 2 :4 0 145
:2 0 ee :2 0 33
:2 0 4c9 9b2 9b4
:3 0 4cc 9ae 9b6
9ab 9b8 9b7 :2 0
de :3 0 ef :3 0
9ba 9bb 0 e0
:4 0 146 :4 0 e3
:2 0 e4 :3 0 4d0
9bf 9c1 :3 0 4d3
9bc 9c3 :2 0 9c5
4d6 9c6 9b9 9c5
0 9c7 4d8 0
9d2 110 :3 0 111
:3 0 9c8 9c9 0
1a :3 0 10c :3 0
9cb 9cc 0 2a
:3 0 112 :3 0 4da
9ca 9d0 :2 0 9d2
4de 9d3 964 9d2
0 9d4 4e2 0
6d23 147 :3 0 40
:3 0 148 :3 0 149
:3 0 2c :4 0 14a
1 :8 0 9e0 15
:3 0 fa :3 0 9db
9dc 0 fd :3 0
9dd 9de 0 9e0
4e4 a33 fe :3 0
15 :3 0 fa :3 0
9e2 9e3 0 fd
:3 0 9e4 9e5 0
9e7 4e7 9e9 4e9
9e8 9e7 :2 0 a31
ff :3 0 15 :3 0
fa :3 0 9ec 9ed
0 fd :3 0 9ee
9ef 0 a29 db
:3 0 dc :3 0 9f1
9f2 0 db :3 0
ec :3 0 9f4 9f5
0 100 :2 0 2
:4 0 14b :2 0 ee
:2 0 33 :2 0 4eb
9fa 9fc :3 0 4ee
9f6 9fe 9f3 a00
9ff :2 0 de :3 0
ef :3 0 a02 a03
0 e0 :4 0 14c
:4 0 e3 :2 0 e4
:3 0 4f2 a07 a09
:3 0 e3 :2 0 103
:4 0 4f5 a0b a0d
:3 0 e3 :2 0 104
:4 0 4f8 a0f a11
:3 0 e3 :2 0 fd
:3 0 4fb a13 a15
:3 0 e3 :2 0 105
:4 0 4fe a17 a19
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 501
a1c a20 505 a1b
a22 :3 0 508 a04
a24 :2 0 a26 50b
a27 a01 a26 0
a28 50d 0 a29
50f a2c :3 0 a2c
0 a2c a2b a29
a2a :6 0 a2e f
:3 0 512 a30 514
a2f a2e :2 0 a31
516 :2 0 a33 0
a33 a32 9e0 a31
:6 0 6d23 1 :3 0
130 :3 0 14d :3 0
a35 a36 0 40
:3 0 14e :4 0 519
a37 a3a f3 :2 0
48 :2 0 51e a3c
a3e :3 0 40 :3 0
f7 :4 0 a40 a41
0 a43 521 a44
a3f a43 0 a45
523 0 6d23 15
:3 0 fa :3 0 a46
a47 0 15 :3 0
f3 :2 0 11a :3 0
a49 a4b 0 527
a4a a4d :3 0 a4e
:2 0 db :3 0 dc
:3 0 a50 a51 0
db :3 0 ec :3 0
a53 a54 0 1e
:2 0 2 :4 0 14f
:2 0 ee :2 0 33
:2 0 52a a59 a5b
:3 0 52d a55 a5d
a52 a5f a5e :2 0
de :3 0 ef :3 0
a61 a62 0 e0
:4 0 150 :4 0 e3
:2 0 e4 :3 0 531
a66 a68 :3 0 e3
:2 0 103 :4 0 534
a6a a6c :3 0 e3
:2 0 10b :4 0 537
a6e a70 :3 0 e3
:2 0 e8 :3 0 e9
:3 0 1a :3 0 10c
:3 0 a75 a76 0
53a a74 a78 ea
:4 0 53c a73 a7b
53f a72 a7d :3 0
e3 :2 0 10d :4 0
542 a7f a81 :3 0
e3 :2 0 e6 :4 0
545 a83 a85 :3 0
e3 :2 0 2c :3 0
548 a87 a89 :3 0
e3 :2 0 e6 :4 0
54b a8b a8d :3 0
54e a63 a8f :2 0
a91 551 a92 a60
a91 0 a93 553
0 abd db :3 0
dc :3 0 a94 a95
0 db :3 0 ec
:3 0 a97 a98 0
33 :2 0 2 :4 0
151 :2 0 ee :2 0
33 :2 0 555 a9d
a9f :3 0 558 a99
aa1 a96 aa3 aa2
:2 0 de :3 0 ef
:3 0 aa5 aa6 0
e0 :4 0 152 :4 0
e3 :2 0 e4 :3 0
55c aaa aac :3 0
55f aa7 aae :2 0
ab0 562 ab1 aa4
ab0 0 ab2 564
0 abd 110 :3 0
111 :3 0 ab3 ab4
0 1a :3 0 10c
:3 0 ab6 ab7 0
2c :3 0 112 :3 0
566 ab5 abb :2 0
abd 56a abe a4f
abd 0 abf 56e
0 6d23 6c :3 0
12 :3 0 ac0 ac1
0 6d23 6e :3 0
f1 :3 0 e8 :3 0
6c :3 0 48 :2 0
570 ac5 ac8 f6
:2 0 573 ac4 acb
ac3 acc 0 6d23
6f :3 0 f1 :3 0
e8 :3 0 6c :3 0
48 :2 0 576 ad0
ad3 153 :2 0 579
acf ad6 ace ad7
0 6d23 6d :3 0
f1 :3 0 e8 :3 0
6c :3 0 48 :2 0
57c adb ade 33
:2 0 57f ada ae1
ad9 ae2 0 6d23
154 :3 0 b2 :3 0
84 :3 0 a8 :3 0
a9 :3 0 2b :3 0
a9 :3 0 b3 :3 0
aa :3 0 2c :3 0
ab :3 0 b5 :4 0
155 1 :8 0 af6
15 :3 0 fa :3 0
af1 af2 0 fd
:3 0 af3 af4 0
af6 582 b49 fe
:3 0 15 :3 0 fa
:3 0 af8 af9 0
fd :3 0 afa afb
0 afd 585 aff
587 afe afd :2 0
b47 ff :3 0 15
:3 0 fa :3 0 b02
b03 0 fd :3 0
b04 b05 0 b3f
db :3 0 dc :3 0
b07 b08 0 db
:3 0 ec :3 0 b0a
b0b 0 100 :2 0
2 :4 0 156 :2 0
ee :2 0 33 :2 0
589 b10 b12 :3 0
58c b0c b14 b09
b16 b15 :2 0 de
:3 0 ef :3 0 b18
b19 0 e0 :4 0
157 :4 0 e3 :2 0
e4 :3 0 590 b1d
b1f :3 0 e3 :2 0
103 :4 0 593 b21
b23 :3 0 e3 :2 0
104 :4 0 596 b25
b27 :3 0 e3 :2 0
fd :3 0 599 b29
b2b :3 0 e3 :2 0
105 :4 0 59c b2d
b2f :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
59f b32 b36 5a3
b31 b38 :3 0 5a6
b1a b3a :2 0 b3c
5a9 b3d b17 b3c
0 b3e 5ab 0
b3f 5ad b42 :3 0
b42 0 b42 b41
b3f b40 :6 0 b44
11 :3 0 5b0 b46
5b2 b45 b44 :2 0
b47 5b4 :2 0 b49
0 b49 b48 af6
b47 :6 0 6d23 1
:3 0 154 :3 0 b2
:3 0 83 :3 0 a8
:3 0 a9 :3 0 2b
:3 0 b3 :3 0 2b
:3 0 aa :3 0 2c
:3 0 ab :4 0 158
1 :8 0 b5c 15
:3 0 fa :3 0 b57
b58 0 fd :3 0
b59 b5a 0 b5c
5b7 baf fe :3 0
15 :3 0 fa :3 0
b5e b5f 0 fd
:3 0 b60 b61 0
b63 5ba b65 5bc
b64 b63 :2 0 bad
ff :3 0 15 :3 0
fa :3 0 b68 b69
0 fd :3 0 b6a
b6b 0 ba5 db
:3 0 dc :3 0 b6d
b6e 0 db :3 0
ec :3 0 b70 b71
0 100 :2 0 2
:4 0 159 :2 0 ee
:2 0 33 :2 0 5be
b76 b78 :3 0 5c1
b72 b7a b6f b7c
b7b :2 0 de :3 0
ef :3 0 b7e b7f
0 e0 :4 0 15a
:4 0 e3 :2 0 e4
:3 0 5c5 b83 b85
:3 0 e3 :2 0 103
:4 0 5c8 b87 b89
:3 0 e3 :2 0 104
:4 0 5cb b8b b8d
:3 0 e3 :2 0 fd
:3 0 5ce b8f b91
:3 0 e3 :2 0 105
:4 0 5d1 b93 b95
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 5d4
b98 b9c 5d8 b97
b9e :3 0 5db b80
ba0 :2 0 ba2 5de
ba3 b7d ba2 0
ba4 5e0 0 ba5
5e2 ba8 :3 0 ba8
0 ba8 ba7 ba5
ba6 :6 0 baa 13
:3 0 5e5 bac 5e7
bab baa :2 0 bad
5e9 :2 0 baf 0
baf bae b5c bad
:6 0 6d23 1 :3 0
96 :3 0 48 :2 0
bb1 bb2 0 6d23
95 :3 0 15b :3 0
e8 :3 0 4e :3 0
48 :2 0 5ec bb6
bb9 5ef bb5 bbb
bbc :2 0 bb4 bbd
0 6d23 95 :3 0
15c :2 0 48 :2 0
5f3 bc0 bc2 :3 0
e8 :3 0 6f :3 0
48 :2 0 5f6 bc4
bc7 f3 :2 0 48
:2 0 5fb bc9 bcb
:3 0 154 :3 0 73
:3 0 15d :3 0 a8
:3 0 a9 :3 0 2b
:3 0 b3 :3 0 2b
:3 0 aa :3 0 2a
:4 0 15e 1 :8 0
bdd 15 :3 0 fa
:3 0 bd8 bd9 0
fd :3 0 bda bdb
0 bdd 5fe c30
fe :3 0 15 :3 0
fa :3 0 bdf be0
0 fd :3 0 be1
be2 0 be4 601
be6 603 be5 be4
:2 0 c2e ff :3 0
15 :3 0 fa :3 0
be9 bea 0 fd
:3 0 beb bec 0
c26 db :3 0 dc
:3 0 bee bef 0
db :3 0 ec :3 0
bf1 bf2 0 100
:2 0 2 :4 0 15f
:2 0 ee :2 0 33
:2 0 605 bf7 bf9
:3 0 608 bf3 bfb
bf0 bfd bfc :2 0
de :3 0 ef :3 0
bff c00 0 e0
:4 0 160 :4 0 e3
:2 0 e4 :3 0 60c
c04 c06 :3 0 e3
:2 0 103 :4 0 60f
c08 c0a :3 0 e3
:2 0 104 :4 0 612
c0c c0e :3 0 e3
:2 0 fd :3 0 615
c10 c12 :3 0 e3
:2 0 105 :4 0 618
c14 c16 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 61b c19 c1d
61f c18 c1f :3 0
622 c01 c21 :2 0
c23 625 c24 bfe
c23 0 c25 627
0 c26 629 c29
:3 0 c29 0 c29
c28 c26 c27 :6 0
c2b 15 :3 0 62c
c2d 62e c2c c2b
:2 0 c2e 630 :2 0
c30 0 c30 c2f
bdd c2e :6 0 d22
1 :3 0 e8 :3 0
73 :3 0 48 :2 0
633 c32 c35 15c
:2 0 48 :2 0 638
c37 c39 :3 0 161
:2 0 63b c3b c3c
:3 0 78 :3 0 48
:2 0 c3e c3f 0
d1f 154 :3 0 78
:3 0 15d :3 0 a8
:3 0 a9 :3 0 2b
:3 0 b3 :3 0 a9
:3 0 aa :3 0 2a
:4 0 162 1 :8 0
c51 15 :3 0 fa
:3 0 c4c c4d 0
fd :3 0 c4e c4f
0 c51 63d ca4
fe :3 0 15 :3 0
fa :3 0 c53 c54
0 fd :3 0 c55
c56 0 c58 640
c5a 642 c59 c58
:2 0 ca2 ff :3 0
15 :3 0 fa :3 0
c5d c5e 0 fd
:3 0 c5f c60 0
c9a db :3 0 dc
:3 0 c62 c63 0
db :3 0 ec :3 0
c65 c66 0 100
:2 0 2 :4 0 163
:2 0 ee :2 0 33
:2 0 644 c6b c6d
:3 0 647 c67 c6f
c64 c71 c70 :2 0
de :3 0 ef :3 0
c73 c74 0 e0
:4 0 164 :4 0 e3
:2 0 e4 :3 0 64b
c78 c7a :3 0 e3
:2 0 103 :4 0 64e
c7c c7e :3 0 e3
:2 0 104 :4 0 651
c80 c82 :3 0 e3
:2 0 fd :3 0 654
c84 c86 :3 0 e3
:2 0 105 :4 0 657
c88 c8a :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 65a c8d c91
65e c8c c93 :3 0
661 c75 c95 :2 0
c97 664 c98 c72
c97 0 c99 666
0 c9a 668 c9d
:3 0 c9d 0 c9d
c9c c9a c9b :6 0
c9f 17 :3 0 66b
ca1 66d ca0 c9f
:2 0 ca2 66f :2 0
ca4 0 ca4 ca3
c51 ca2 :6 0 d1f
1 :3 0 e8 :3 0
78 :3 0 48 :2 0
672 ca6 ca9 15c
:2 0 48 :2 0 677
cab cad :3 0 db
:3 0 dc :3 0 caf
cb0 0 db :3 0
ec :3 0 cb2 cb3
0 1e :2 0 2
:4 0 165 :2 0 ee
:2 0 33 :2 0 67a
cb8 cba :3 0 67d
cb4 cbc cb1 cbe
cbd :2 0 de :3 0
ef :3 0 cc0 cc1
0 e0 :4 0 166
:4 0 e3 :2 0 e4
:3 0 681 cc5 cc7
:3 0 e3 :2 0 103
:4 0 684 cc9 ccb
:3 0 e3 :2 0 10b
:4 0 687 ccd ccf
:3 0 e3 :2 0 e8
:3 0 e9 :3 0 1a
:3 0 167 :3 0 cd4
cd5 0 68a cd3
cd7 ea :4 0 68c
cd2 cda 68f cd1
cdc :3 0 e3 :2 0
10d :4 0 692 cde
ce0 :3 0 e3 :2 0
e6 :4 0 695 ce2
ce4 :3 0 e3 :2 0
2a :3 0 698 ce6
ce8 :3 0 e3 :2 0
e6 :4 0 69b cea
cec :3 0 69e cc2
cee :2 0 cf0 6a1
cf1 cbf cf0 0
cf2 6a3 0 d1c
db :3 0 dc :3 0
cf3 cf4 0 db
:3 0 ec :3 0 cf6
cf7 0 33 :2 0
2 :4 0 168 :2 0
ee :2 0 33 :2 0
6a5 cfc cfe :3 0
6a8 cf8 d00 cf5
d02 d01 :2 0 de
:3 0 ef :3 0 d04
d05 0 e0 :4 0
169 :4 0 e3 :2 0
e4 :3 0 6ac d09
d0b :3 0 6af d06
d0d :2 0 d0f 6b2
d10 d03 d0f 0
d11 6b4 0 d1c
110 :3 0 111 :3 0
d12 d13 0 1a
:3 0 167 :3 0 d15
d16 0 2a :3 0
112 :3 0 6b6 d14
d1a :2 0 d1c 6ba
d1d cae d1c 0
d1e 6be 0 d1f
6c0 d20 c3d d1f
0 d21 6c4 0
d22 6c6 d23 bcc
d22 0 d24 6c9
0 d26 16a :3 0
6cb e2d 16b :3 0
e8 :3 0 4e :3 0
48 :2 0 6cd d28
d2b 6d0 d27 d2d
15c :2 0 48 :2 0
6d4 d2f d31 :3 0
e8 :3 0 6f :3 0
48 :2 0 6d7 d33
d36 f3 :2 0 48
:2 0 6dc d38 d3a
:3 0 e8 :3 0 84
:3 0 48 :2 0 6df
d3c d3f f3 :2 0
48 :2 0 6e4 d41
d43 :3 0 d3b d45
d44 :2 0 d46 :2 0
d32 d48 d47 :2 0
78 :3 0 48 :2 0
d4a d4b 0 e2b
154 :3 0 78 :3 0
15d :3 0 a8 :3 0
a9 :3 0 2b :3 0
aa :3 0 2a :3 0
ab :3 0 ac :4 0
16c 1 :8 0 d5d
15 :3 0 fa :3 0
d58 d59 0 fd
:3 0 d5a d5b 0
d5d 6e7 db0 fe
:3 0 15 :3 0 fa
:3 0 d5f d60 0
fd :3 0 d61 d62
0 d64 6ea d66
6ec d65 d64 :2 0
dae ff :3 0 15
:3 0 fa :3 0 d69
d6a 0 fd :3 0
d6b d6c 0 da6
db :3 0 dc :3 0
d6e d6f 0 db
:3 0 ec :3 0 d71
d72 0 100 :2 0
2 :4 0 16d :2 0
ee :2 0 33 :2 0
6ee d77 d79 :3 0
6f1 d73 d7b d70
d7d d7c :2 0 de
:3 0 ef :3 0 d7f
d80 0 e0 :4 0
16e :4 0 e3 :2 0
e4 :3 0 6f5 d84
d86 :3 0 e3 :2 0
103 :4 0 6f8 d88
d8a :3 0 e3 :2 0
104 :4 0 6fb d8c
d8e :3 0 e3 :2 0
fd :3 0 6fe d90
d92 :3 0 e3 :2 0
105 :4 0 701 d94
d96 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
704 d99 d9d 708
d98 d9f :3 0 70b
d81 da1 :2 0 da3
70e da4 d7e da3
0 da5 710 0
da6 712 da9 :3 0
da9 0 da9 da8
da6 da7 :6 0 dab
19 :3 0 715 dad
717 dac dab :2 0
dae 719 :2 0 db0
0 db0 daf d5d
dae :6 0 e2b 1
:3 0 e8 :3 0 78
:3 0 48 :2 0 71c
db2 db5 124 :2 0
48 :2 0 721 db7
db9 :3 0 db :3 0
dc :3 0 dbb dbc
0 db :3 0 ec
:3 0 dbe dbf 0
1e :2 0 2 :4 0
16f :2 0 ee :2 0
33 :2 0 724 dc4
dc6 :3 0 727 dc0
dc8 dbd dca dc9
:2 0 de :3 0 ef
:3 0 dcc dcd 0
e0 :4 0 170 :4 0
e3 :2 0 e4 :3 0
72b dd1 dd3 :3 0
e3 :2 0 103 :4 0
72e dd5 dd7 :3 0
e3 :2 0 10b :4 0
731 dd9 ddb :3 0
e3 :2 0 e8 :3 0
e9 :3 0 1a :3 0
167 :3 0 de0 de1
0 734 ddf de3
ea :4 0 736 dde
de6 739 ddd de8
:3 0 e3 :2 0 10d
:4 0 73c dea dec
:3 0 e3 :2 0 e6
:4 0 73f dee df0
:3 0 e3 :2 0 2a
:3 0 742 df2 df4
:3 0 e3 :2 0 e6
:4 0 745 df6 df8
:3 0 748 dce dfa
:2 0 dfc 74b dfd
dcb dfc 0 dfe
74d 0 e28 db
:3 0 dc :3 0 dff
e00 0 db :3 0
ec :3 0 e02 e03
0 33 :2 0 2
:4 0 171 :2 0 ee
:2 0 33 :2 0 74f
e08 e0a :3 0 752
e04 e0c e01 e0e
e0d :2 0 de :3 0
ef :3 0 e10 e11
0 e0 :4 0 172
:4 0 e3 :2 0 e4
:3 0 756 e15 e17
:3 0 759 e12 e19
:2 0 e1b 75c e1c
e0f e1b 0 e1d
75e 0 e28 110
:3 0 111 :3 0 e1e
e1f 0 1a :3 0
167 :3 0 e21 e22
0 2a :3 0 112
:3 0 760 e20 e26
:2 0 e28 764 e29
dba e28 0 e2a
768 0 e2b 76a
e2c d49 e2b 0
e2e bc3 d26 0
e2e 76e 0 6d23
39 :3 0 48 :4 0
e2f e30 0 6d23
22 :3 0 f7 :4 0
e32 e33 0 6d23
23 :3 0 f7 :4 0
e35 e36 0 6d23
26 :4 0 e38 e39
0 6d23 8e :4 0
e3b e3c 0 6d23
2d :4 0 e3e e3f
0 6d23 f8 :3 0
a6 :4 0 e44 :2 0
6d23 e42 e45 :3 0
a6 :3 0 62 :4 0
e49 :2 0 6d23 e46
e47 :3 0 a6 :3 0
f9 :3 0 e4a e4b
:3 0 15 :3 0 fa
:3 0 e4d e4e 0
48 :2 0 e4f e50
0 e52 771 e59
15 :3 0 fa :3 0
e53 e54 0 fb
:2 0 e55 e56 0
e58 773 e5a e4c
e52 0 e5b 0
e58 0 e5b 775
0 6d23 15 :3 0
fa :3 0 e5c e5d
0 15 :3 0 f3
:2 0 173 :3 0 e5f
e61 0 77a e60
e63 :3 0 e64 :2 0
130 :3 0 14d :3 0
e66 e67 0 2b
:3 0 29 :3 0 77d
e68 e6b 15c :2 0
48 :2 0 782 e6d
e6f :3 0 161 :2 0
785 e71 e72 :3 0
e8 :3 0 6f :3 0
48 :2 0 787 e74
e77 15c :2 0 48
:2 0 78c e79 e7b
:3 0 161 :2 0 78f
e7d e7e :3 0 e73
e80 e7f :2 0 fc
:3 0 a6 :4 0 e85
:2 0 e8b e83 0
15 :3 0 fa :3 0
e86 e87 0 fd
:3 0 e88 e89 0
e8b 791 ede fe
:3 0 15 :3 0 fa
:3 0 e8d e8e 0
fd :3 0 e8f e90
0 e92 794 e94
796 e93 e92 :2 0
edc ff :3 0 15
:3 0 fa :3 0 e97
e98 0 fd :3 0
e99 e9a 0 ed4
db :3 0 dc :3 0
e9c e9d 0 db
:3 0 ec :3 0 e9f
ea0 0 100 :2 0
2 :4 0 174 :2 0
ee :2 0 33 :2 0
798 ea5 ea7 :3 0
79b ea1 ea9 e9e
eab eaa :2 0 de
:3 0 ef :3 0 ead
eae 0 e0 :4 0
175 :4 0 e3 :2 0
e4 :3 0 79f eb2
eb4 :3 0 e3 :2 0
103 :4 0 7a2 eb6
eb8 :3 0 e3 :2 0
104 :4 0 7a5 eba
ebc :3 0 e3 :2 0
fd :3 0 7a8 ebe
ec0 :3 0 e3 :2 0
105 :4 0 7ab ec2
ec4 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
7ae ec7 ecb 7b2
ec6 ecd :3 0 7b5
eaf ecf :2 0 ed1
7b8 ed2 eac ed1
0 ed3 7ba 0
ed4 7bc ed7 :3 0
ed7 0 ed7 ed6
ed4 ed5 :6 0 ed9
1b :3 0 7bf edb
7c1 eda ed9 :2 0
edc 7c3 :2 0 ede
0 ede edd e8b
edc :6 0 f4d 1
:3 0 db :3 0 dc
:3 0 ee0 ee1 0
db :3 0 ec :3 0
ee3 ee4 0 1e
:2 0 2 :4 0 176
:2 0 ee :2 0 33
:2 0 7c6 ee9 eeb
:3 0 7c9 ee5 eed
ee2 eef eee :2 0
de :3 0 ef :3 0
ef1 ef2 0 e0
:4 0 177 :4 0 e3
:2 0 e4 :3 0 7cd
ef6 ef8 :3 0 e3
:2 0 103 :4 0 7d0
efa efc :3 0 e3
:2 0 10b :4 0 7d3
efe f00 :3 0 e3
:2 0 e8 :3 0 e9
:3 0 1a :3 0 167
:3 0 f05 f06 0
7d6 f04 f08 ea
:4 0 7d8 f03 f0b
7db f02 f0d :3 0
e3 :2 0 10d :4 0
7de f0f f11 :3 0
e3 :2 0 e6 :4 0
7e1 f13 f15 :3 0
e3 :2 0 2a :3 0
7e4 f17 f19 :3 0
e3 :2 0 e6 :4 0
7e7 f1b f1d :3 0
7ea ef3 f1f :2 0
f21 7ed f22 ef0
f21 0 f23 7ef
0 f4d db :3 0
dc :3 0 f24 f25
0 db :3 0 ec
:3 0 f27 f28 0
33 :2 0 2 :4 0
178 :2 0 ee :2 0
33 :2 0 7f1 f2d
f2f :3 0 7f4 f29
f31 f26 f33 f32
:2 0 de :3 0 ef
:3 0 f35 f36 0
e0 :4 0 179 :4 0
e3 :2 0 e4 :3 0
7f8 f3a f3c :3 0
7fb f37 f3e :2 0
f40 7fe f41 f34
f40 0 f42 800
0 f4d 110 :3 0
111 :3 0 f43 f44
0 1a :3 0 167
:3 0 f46 f47 0
2a :3 0 112 :3 0
802 f45 f4b :2 0
f4d 806 f4e e81
f4d 0 f4f 80b
0 f54 58 :3 0
48 :2 0 f50 f51
0 f54 16a :3 0
80d f67 e8 :3 0
6f :3 0 48 :2 0
810 f55 f58 f3
:2 0 153 :2 0 815
f5a f5c :3 0 58
:3 0 48 :2 0 f5e
f5f 0 f61 818
f62 f5d f61 0
f69 58 :3 0 153
:2 0 f63 f64 0
f66 81a f68 e65
f54 0 f69 0
f66 0 f69 81c
0 6d23 fc :3 0
a6 :4 0 f6d :2 0
f73 f6b 0 15
:3 0 fa :3 0 f6e
f6f 0 fd :3 0
f70 f71 0 f73
820 fc6 fe :3 0
15 :3 0 fa :3 0
f75 f76 0 fd
:3 0 f77 f78 0
f7a 823 f7c 825
f7b f7a :2 0 fc4
ff :3 0 15 :3 0
fa :3 0 f7f f80
0 fd :3 0 f81
f82 0 fbc db
:3 0 dc :3 0 f84
f85 0 db :3 0
ec :3 0 f87 f88
0 100 :2 0 2
:4 0 17a :2 0 ee
:2 0 33 :2 0 827
f8d f8f :3 0 82a
f89 f91 f86 f93
f92 :2 0 de :3 0
ef :3 0 f95 f96
0 e0 :4 0 17b
:4 0 e3 :2 0 e4
:3 0 82e f9a f9c
:3 0 e3 :2 0 103
:4 0 831 f9e fa0
:3 0 e3 :2 0 104
:4 0 834 fa2 fa4
:3 0 e3 :2 0 fd
:3 0 837 fa6 fa8
:3 0 e3 :2 0 105
:4 0 83a faa fac
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 83d
faf fb3 841 fae
fb5 :3 0 844 f97
fb7 :2 0 fb9 847
fba f94 fb9 0
fbb 849 0 fbc
84b fbf :3 0 fbf
0 fbf fbe fbc
fbd :6 0 fc1 1d
:3 0 84e fc3 850
fc2 fc1 :2 0 fc4
852 :2 0 fc6 0
fc6 fc5 f73 fc4
:6 0 6d23 1 :3 0
17c :3 0 44 :3 0
148 :3 0 149 :3 0
2c :4 0 17d 1
:8 0 fd3 15 :3 0
fa :3 0 fce fcf
0 fd :3 0 fd0
fd1 0 fd3 855
1026 fe :3 0 15
:3 0 fa :3 0 fd5
fd6 0 fd :3 0
fd7 fd8 0 fda
858 fdc 85a fdb
fda :2 0 1024 ff
:3 0 15 :3 0 fa
:3 0 fdf fe0 0
fd :3 0 fe1 fe2
0 101c db :3 0
dc :3 0 fe4 fe5
0 db :3 0 ec
:3 0 fe7 fe8 0
100 :2 0 2 :4 0
17e :2 0 ee :2 0
33 :2 0 85c fed
fef :3 0 85f fe9
ff1 fe6 ff3 ff2
:2 0 de :3 0 ef
:3 0 ff5 ff6 0
e0 :4 0 17f :4 0
e3 :2 0 e4 :3 0
863 ffa ffc :3 0
e3 :2 0 103 :4 0
866 ffe 1000 :3 0
e3 :2 0 104 :4 0
869 1002 1004 :3 0
e3 :2 0 fd :3 0
86c 1006 1008 :3 0
e3 :2 0 105 :4 0
86f 100a 100c :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 872 100f
1013 876 100e 1015
:3 0 879 ff7 1017
:2 0 1019 87c 101a
ff4 1019 0 101b
87e 0 101c 880
101f :3 0 101f 0
101f 101e 101c 101d
:6 0 1021 1f :3 0
883 1023 885 1022
1021 :2 0 1024 887
:2 0 1026 0 1026
1025 fd3 1024 :6 0
6d23 1 :3 0 b0
:3 0 180 :3 0 23
:3 0 61 :3 0 c8
:3 0 a4 :3 0 2b
:3 0 ab :3 0 39
:3 0 aa :3 0 2a
:4 0 181 1 :8 0
1039 15 :3 0 fa
:3 0 1034 1035 0
fd :3 0 1036 1037
0 1039 88a 108c
fe :3 0 15 :3 0
fa :3 0 103b 103c
0 fd :3 0 103d
103e 0 1040 88d
1042 88f 1041 1040
:2 0 108a ff :3 0
15 :3 0 fa :3 0
1045 1046 0 fd
:3 0 1047 1048 0
1082 db :3 0 dc
:3 0 104a 104b 0
db :3 0 ec :3 0
104d 104e 0 100
:2 0 2 :4 0 182
:2 0 ee :2 0 33
:2 0 891 1053 1055
:3 0 894 104f 1057
104c 1059 1058 :2 0
de :3 0 ef :3 0
105b 105c 0 e0
:4 0 183 :4 0 e3
:2 0 e4 :3 0 898
1060 1062 :3 0 e3
:2 0 103 :4 0 89b
1064 1066 :3 0 e3
:2 0 104 :4 0 89e
1068 106a :3 0 e3
:2 0 fd :3 0 8a1
106c 106e :3 0 e3
:2 0 105 :4 0 8a4
1070 1072 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 8a7 1075 1079
8ab 1074 107b :3 0
8ae 105d 107d :2 0
107f 8b1 1080 105a
107f 0 1081 8b3
0 1082 8b5 1085
:3 0 1085 0 1085
1084 1082 1083 :6 0
1087 21 :3 0 8b8
1089 8ba 1088 1087
:2 0 108a 8bc :2 0
108c 0 108c 108b
1039 108a :6 0 6d23
1 :3 0 15 :3 0
fa :3 0 108e 108f
0 15 :3 0 f3
:2 0 11a :3 0 1091
1093 0 8c1 1092
1095 :3 0 1096 :2 0
e8 :3 0 6f :3 0
48 :2 0 8c4 1098
109b 15c :2 0 48
:2 0 8c9 109d 109f
:3 0 161 :2 0 8cc
10a1 10a2 :3 0 1097
10a4 10a3 :2 0 23
:3 0 f7 :4 0 10a6
10a7 0 135b 23
:3 0 184 :4 0 10aa
10ab :3 0 10a9 10ac
0 135b 180 :3 0
185 :3 0 61 :3 0
7b :3 0 c8 :3 0
a4 :3 0 2b :3 0
ab :3 0 aa :3 0
2c :4 0 186 1
:8 0 10be 15 :3 0
fa :3 0 10b9 10ba
0 fd :3 0 10bb
10bc 0 10be 8ce
1111 fe :3 0 15
:3 0 fa :3 0 10c0
10c1 0 fd :3 0
10c2 10c3 0 10c5
8d1 10c7 8d3 10c6
10c5 :2 0 110f ff
:3 0 15 :3 0 fa
:3 0 10ca 10cb 0
fd :3 0 10cc 10cd
0 1107 db :3 0
dc :3 0 10cf 10d0
0 db :3 0 ec
:3 0 10d2 10d3 0
100 :2 0 2 :4 0
187 :2 0 ee :2 0
33 :2 0 8d5 10d8
10da :3 0 8d8 10d4
10dc 10d1 10de 10dd
:2 0 de :3 0 ef
:3 0 10e0 10e1 0
e0 :4 0 188 :4 0
e3 :2 0 e4 :3 0
8dc 10e5 10e7 :3 0
e3 :2 0 103 :4 0
8df 10e9 10eb :3 0
e3 :2 0 104 :4 0
8e2 10ed 10ef :3 0
e3 :2 0 fd :3 0
8e5 10f1 10f3 :3 0
e3 :2 0 105 :4 0
8e8 10f5 10f7 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 8eb 10fa
10fe 8ef 10f9 1100
:3 0 8f2 10e2 1102
:2 0 1104 8f5 1105
10df 1104 0 1106
8f7 0 1107 8f9
110a :3 0 110a 0
110a 1109 1107 1108
:6 0 110c 23 :3 0
8fc 110e 8fe 110d
110c :2 0 110f 900
:2 0 1111 0 1111
1110 10be 110f :6 0
135b 1 :3 0 15
:3 0 fa :3 0 1113
1114 0 15 :3 0
f3 :2 0 173 :3 0
1116 1118 0 905
1117 111a :3 0 111b
:2 0 7a :3 0 1a
:3 0 189 :3 0 111e
111f 0 111d 1120
0 1122 908 1138
7e :3 0 18a :3 0
48 :2 0 e8 :3 0
4d :3 0 48 :2 0
90a 1126 1129 1a
:3 0 18b :3 0 112b
112c 0 7b :3 0
90d 1124 112f 1123
1130 0 1137 7a
:3 0 1a :3 0 189
:3 0 1133 1134 0
1132 1135 0 1137
912 1139 111c 1122
0 113a 0 1137
0 113a 915 0
135b 79 :3 0 48
:4 0 113b 113c 0
135b 7d :3 0 33
:2 0 113e 113f 0
135b 7e :3 0 18c
:3 0 2b :3 0 2a
:3 0 4d :3 0 7a
:3 0 7b :3 0 79
:3 0 7d :3 0 918
1142 114a 1141 114b
0 135b 88 :3 0
18d :3 0 e8 :3 0
4d :3 0 48 :2 0
920 114f 1152 923
114e 1154 114d 1155
0 135b c8 :3 0
b0 :3 0 a9 :3 0
a4 :3 0 b4 :3 0
ab :3 0 aa :3 0
149 :3 0 180 :3 0
185 :3 0 18e :3 0
18f :3 0 190 :3 0
23 :3 0 2b :3 0
2b :3 0 4d :3 0
39 :3 0 2a :3 0
2c :3 0 7a :3 0
7b :3 0 88 :3 0
13 :3 0 e4 :4 0
191 1 :8 0 1186
f9 :4 0 1171 :3 0
112 :3 0 f3 :2 0
927 1174 1175 :3 0
15 :3 0 fa :3 0
1177 1178 0 48
:2 0 1179 117a 0
117c 92a 1183 15
:3 0 fa :3 0 117d
117e 0 fb :2 0
117f 1180 0 1182
92c 1184 1176 117c
0 1185 0 1182
0 1185 92e 0
1186 931 11d9 fe
:3 0 15 :3 0 fa
:3 0 1188 1189 0
fd :3 0 118a 118b
0 118d 934 118f
936 118e 118d :2 0
11d7 ff :3 0 15
:3 0 fa :3 0 1192
1193 0 fd :3 0
1194 1195 0 11cf
db :3 0 dc :3 0
1197 1198 0 db
:3 0 ec :3 0 119a
119b 0 100 :2 0
2 :4 0 192 :2 0
ee :2 0 33 :2 0
938 11a0 11a2 :3 0
93b 119c 11a4 1199
11a6 11a5 :2 0 de
:3 0 ef :3 0 11a8
11a9 0 e0 :4 0
193 :4 0 e3 :2 0
e4 :3 0 93f 11ad
11af :3 0 e3 :2 0
103 :4 0 942 11b1
11b3 :3 0 e3 :2 0
104 :4 0 945 11b5
11b7 :3 0 e3 :2 0
fd :3 0 948 11b9
11bb :3 0 e3 :2 0
105 :4 0 94b 11bd
11bf :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
94e 11c2 11c6 952
11c1 11c8 :3 0 955
11aa 11ca :2 0 11cc
958 11cd 11a7 11cc
0 11ce 95a 0
11cf 95c 11d2 :3 0
11d2 0 11d2 11d1
11cf 11d0 :6 0 11d4
25 :3 0 95f 11d6
961 11d5 11d4 :2 0
11d7 963 :2 0 11d9
0 11d9 11d8 1186
11d7 :6 0 135b 1
:3 0 130 :3 0 14d
:3 0 11db 11dc 0
2b :3 0 29 :3 0
966 11dd 11e0 15c
:2 0 48 :2 0 96b
11e2 11e4 :3 0 161
:2 0 96e 11e6 11e7
:3 0 4f :3 0 48
:2 0 11e9 11ea 0
11ec 970 1255 154
:3 0 b2 :3 0 4f
:3 0 a8 :3 0 a9
:3 0 2b :3 0 b3
:3 0 29 :3 0 aa
:3 0 2c :3 0 ab
:3 0 194 :4 0 195
1 :8 0 11ff 15
:3 0 fa :3 0 11fa
11fb 0 fd :3 0
11fc 11fd 0 11ff
972 1252 fe :3 0
15 :3 0 fa :3 0
1201 1202 0 fd
:3 0 1203 1204 0
1206 975 1208 977
1207 1206 :2 0 1250
ff :3 0 15 :3 0
fa :3 0 120b 120c
0 fd :3 0 120d
120e 0 1248 db
:3 0 dc :3 0 1210
1211 0 db :3 0
ec :3 0 1213 1214
0 100 :2 0 2
:4 0 196 :2 0 ee
:2 0 33 :2 0 979
1219 121b :3 0 97c
1215 121d 1212 121f
121e :2 0 de :3 0
ef :3 0 1221 1222
0 e0 :4 0 197
:4 0 e3 :2 0 e4
:3 0 980 1226 1228
:3 0 e3 :2 0 103
:4 0 983 122a 122c
:3 0 e3 :2 0 104
:4 0 986 122e 1230
:3 0 e3 :2 0 fd
:3 0 989 1232 1234
:3 0 e3 :2 0 105
:4 0 98c 1236 1238
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 98f
123b 123f 993 123a
1241 :3 0 996 1223
1243 :2 0 1245 999
1246 1220 1245 0
1247 99b 0 1248
99d 124b :3 0 124b
0 124b 124a 1248
1249 :6 0 124d 27
:3 0 9a0 124f 9a2
124e 124d :2 0 1250
9a4 :2 0 1252 0
1252 1251 11ff 1250
:6 0 1254 1 :3 0
9a7 1256 11e8 11ec
0 1257 0 1254
0 1257 9a9 0
135b e8 :3 0 4f
:3 0 48 :2 0 9ac
1258 125b 15c :2 0
48 :2 0 9b1 125d
125f :3 0 161 :2 0
9b4 1261 1262 :3 0
c7 :3 0 198 :3 0
199 :3 0 198 :3 0
44 :3 0 41 :3 0
a4 :3 0 2b :3 0
a9 :3 0 2b :4 0
19a 1 :8 0 1284
f9 :4 0 126f :3 0
112 :3 0 f3 :2 0
9b8 1272 1273 :3 0
15 :3 0 fa :3 0
1275 1276 0 48
:2 0 1277 1278 0
127a 9bb 1281 15
:3 0 fa :3 0 127b
127c 0 fb :2 0
127d 127e 0 1280
9bd 1282 1274 127a
0 1283 0 1280
0 1283 9bf 0
1284 9c2 12d7 fe
:3 0 15 :3 0 fa
:3 0 1286 1287 0
fd :3 0 1288 1289
0 128b 9c5 128d
9c7 128c 128b :2 0
12d5 ff :3 0 15
:3 0 fa :3 0 1290
1291 0 fd :3 0
1292 1293 0 12cd
db :3 0 dc :3 0
1295 1296 0 db
:3 0 ec :3 0 1298
1299 0 100 :2 0
2 :4 0 19b :2 0
ee :2 0 33 :2 0
9c9 129e 12a0 :3 0
9cc 129a 12a2 1297
12a4 12a3 :2 0 de
:3 0 ef :3 0 12a6
12a7 0 e0 :4 0
19c :4 0 e3 :2 0
e4 :3 0 9d0 12ab
12ad :3 0 e3 :2 0
103 :4 0 9d3 12af
12b1 :3 0 e3 :2 0
104 :4 0 9d6 12b3
12b5 :3 0 e3 :2 0
fd :3 0 9d9 12b7
12b9 :3 0 e3 :2 0
105 :4 0 9dc 12bb
12bd :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
9df 12c0 12c4 9e3
12bf 12c6 :3 0 9e6
12a8 12c8 :2 0 12ca
9e9 12cb 12a5 12ca
0 12cc 9eb 0
12cd 9ed 12d0 :3 0
12d0 0 12d0 12cf
12cd 12ce :6 0 12d2
29 :3 0 9f0 12d4
9f2 12d3 12d2 :2 0
12d5 9f4 :2 0 12d7
0 12d7 12d6 1284
12d5 :6 0 12d9 1
:3 0 9f7 1357 c7
:3 0 198 :3 0 19d
:3 0 198 :3 0 41
:3 0 198 :3 0 19e
:3 0 41 :3 0 19e
:3 0 198 :3 0 198
:3 0 198 :3 0 41
:3 0 a9 :3 0 2b
:3 0 a4 :3 0 2b
:4 0 19f 1 :8 0
1301 f9 :4 0 12ec
:3 0 112 :3 0 f3
:2 0 9fb 12ef 12f0
:3 0 15 :3 0 fa
:3 0 12f2 12f3 0
48 :2 0 12f4 12f5
0 12f7 9fe 12fe
15 :3 0 fa :3 0
12f8 12f9 0 fb
:2 0 12fa 12fb 0
12fd a00 12ff 12f1
12f7 0 1300 0
12fd 0 1300 a02
0 1301 a05 1354
fe :3 0 15 :3 0
fa :3 0 1303 1304
0 fd :3 0 1305
1306 0 1308 a08
130a a0a 1309 1308
:2 0 1352 ff :3 0
15 :3 0 fa :3 0
130d 130e 0 fd
:3 0 130f 1310 0
134a db :3 0 dc
:3 0 1312 1313 0
db :3 0 ec :3 0
1315 1316 0 100
:2 0 2 :4 0 1a0
:2 0 ee :2 0 33
:2 0 a0c 131b 131d
:3 0 a0f 1317 131f
1314 1321 1320 :2 0
de :3 0 ef :3 0
1323 1324 0 e0
:4 0 1a1 :4 0 e3
:2 0 e4 :3 0 a13
1328 132a :3 0 e3
:2 0 103 :4 0 a16
132c 132e :3 0 e3
:2 0 104 :4 0 a19
1330 1332 :3 0 e3
:2 0 fd :3 0 a1c
1334 1336 :3 0 e3
:2 0 105 :4 0 a1f
1338 133a :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 a22 133d 1341
a26 133c 1343 :3 0
a29 1325 1345 :2 0
1347 a2c 1348 1322
1347 0 1349 a2e
0 134a a30 134d
:3 0 134d 0 134d
134c 134a 134b :6 0
134f 2b :3 0 a33
1351 a35 1350 134f
:2 0 1352 a37 :2 0
1354 0 1354 1353
1301 1352 :6 0 1356
1 :3 0 a3a 1358
1263 12d9 0 1359
0 1356 0 1359
a3c 0 135b 16a
:3 0 a3f 168f 15
:3 0 fa :3 0 135c
135d 0 15 :3 0
f3 :2 0 173 :3 0
135f 1361 0 a4d
1360 1363 :3 0 1364
:2 0 c7 :3 0 198
:3 0 130 :3 0 1a2
:3 0 41 :3 0 198
:3 0 199 :3 0 198
:3 0 44 :3 0 199
:3 0 198 :3 0 44
:3 0 41 :3 0 a4
:3 0 2b :3 0 a9
:3 0 2b :4 0 1a3
1 :8 0 138d f9
:4 0 1378 :3 0 112
:3 0 f3 :2 0 a52
137b 137c :3 0 15
:3 0 fa :3 0 137e
137f 0 48 :2 0
1380 1381 0 1383
a55 138a 15 :3 0
fa :3 0 1384 1385
0 fb :2 0 1386
1387 0 1389 a57
138b 137d 1383 0
138c 0 1389 0
138c a59 0 138d
a5c 13e0 fe :3 0
15 :3 0 fa :3 0
138f 1390 0 fd
:3 0 1391 1392 0
1394 a5f 1396 a61
1395 1394 :2 0 13de
ff :3 0 15 :3 0
fa :3 0 1399 139a
0 fd :3 0 139b
139c 0 13d6 db
:3 0 dc :3 0 139e
139f 0 db :3 0
ec :3 0 13a1 13a2
0 100 :2 0 2
:4 0 1a4 :2 0 ee
:2 0 33 :2 0 a63
13a7 13a9 :3 0 a66
13a3 13ab 13a0 13ad
13ac :2 0 de :3 0
ef :3 0 13af 13b0
0 e0 :4 0 1a5
:4 0 e3 :2 0 e4
:3 0 a6a 13b4 13b6
:3 0 e3 :2 0 103
:4 0 a6d 13b8 13ba
:3 0 e3 :2 0 104
:4 0 a70 13bc 13be
:3 0 e3 :2 0 fd
:3 0 a73 13c0 13c2
:3 0 e3 :2 0 105
:4 0 a76 13c4 13c6
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 a79
13c9 13cd a7d 13c8
13cf :3 0 a80 13b1
13d1 :2 0 13d3 a83
13d4 13ae 13d3 0
13d5 a85 0 13d6
a87 13d9 :3 0 13d9
0 13d9 13d8 13d6
13d7 :6 0 13db 2d
:3 0 a8a 13dd a8c
13dc 13db :2 0 13de
a8e :2 0 13e0 0
13e0 13df 138d 13de
:6 0 168d 1 :3 0
32 :3 0 48 :4 0
13e2 13e3 0 168d
b2 :3 0 26 :3 0
a8 :3 0 b0 :3 0
23 :3 0 194 :4 0
1a6 1 :8 0 13f1
15 :3 0 fa :3 0
13ec 13ed 0 fd
:3 0 13ee 13ef 0
13f1 a91 1444 fe
:3 0 15 :3 0 fa
:3 0 13f3 13f4 0
fd :3 0 13f5 13f6
0 13f8 a94 13fa
a96 13f9 13f8 :2 0
1442 ff :3 0 15
:3 0 fa :3 0 13fd
13fe 0 fd :3 0
13ff 1400 0 143a
db :3 0 dc :3 0
1402 1403 0 db
:3 0 ec :3 0 1405
1406 0 100 :2 0
2 :4 0 1a7 :2 0
ee :2 0 33 :2 0
a98 140b 140d :3 0
a9b 1407 140f 1404
1411 1410 :2 0 de
:3 0 ef :3 0 1413
1414 0 e0 :4 0
1a8 :4 0 e3 :2 0
e4 :3 0 a9f 1418
141a :3 0 e3 :2 0
103 :4 0 aa2 141c
141e :3 0 e3 :2 0
104 :4 0 aa5 1420
1422 :3 0 e3 :2 0
fd :3 0 aa8 1424
1426 :3 0 e3 :2 0
105 :4 0 aab 1428
142a :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
aae 142d 1431 ab2
142c 1433 :3 0 ab5
1415 1435 :2 0 1437
ab8 1438 1412 1437
0 1439 aba 0
143a abc 143d :3 0
143d 0 143d 143c
143a 143b :6 0 143f
2f :3 0 abf 1441
ac1 1440 143f :2 0
1442 ac3 :2 0 1444
0 1444 1443 13f1
1442 :6 0 168d 1
:3 0 15 :3 0 fa
:3 0 1446 1447 0
15 :3 0 f3 :2 0
11a :3 0 1449 144b
0 ac8 144a 144d
:3 0 144e :2 0 b2
:3 0 26 :3 0 a8
:3 0 b0 :3 0 23
:3 0 194 :4 0 1a9
1 :8 0 145c 15
:3 0 fa :3 0 1457
1458 0 fd :3 0
1459 145a 0 145c
acb 14af fe :3 0
15 :3 0 fa :3 0
145e 145f 0 fd
:3 0 1460 1461 0
1463 ace 1465 ad0
1464 1463 :2 0 14ad
ff :3 0 15 :3 0
fa :3 0 1468 1469
0 fd :3 0 146a
146b 0 14a5 db
:3 0 dc :3 0 146d
146e 0 db :3 0
ec :3 0 1470 1471
0 100 :2 0 2
:4 0 1aa :2 0 ee
:2 0 33 :2 0 ad2
1476 1478 :3 0 ad5
1472 147a 146f 147c
147b :2 0 de :3 0
ef :3 0 147e 147f
0 e0 :4 0 1ab
:4 0 e3 :2 0 e4
:3 0 ad9 1483 1485
:3 0 e3 :2 0 103
:4 0 adc 1487 1489
:3 0 e3 :2 0 104
:4 0 adf 148b 148d
:3 0 e3 :2 0 fd
:3 0 ae2 148f 1491
:3 0 e3 :2 0 105
:4 0 ae5 1493 1495
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 ae8
1498 149c aec 1497
149e :3 0 aef 1480
14a0 :2 0 14a2 af2
14a3 147d 14a2 0
14a4 af4 0 14a5
af6 14a8 :3 0 14a8
0 14a8 14a7 14a5
14a6 :6 0 14aa 31
:3 0 af9 14ac afb
14ab 14aa :2 0 14ad
afd :2 0 14af 0
14af 14ae 145c 14ad
:6 0 14c1 1 :3 0
15 :3 0 fa :3 0
14b1 14b2 0 15
:3 0 f3 :2 0 173
:3 0 14b4 14b6 0
b02 14b5 14b8 :3 0
14b9 :2 0 32 :3 0
153 :4 0 14bb 14bc
0 14be b05 14bf
14ba 14be 0 14c0
b07 0 14c1 b09
14c2 144f 14c1 0
14c3 b0c 0 168d
e8 :3 0 6f :3 0
48 :2 0 b0e 14c4
14c7 15c :2 0 48
:2 0 b13 14c9 14cb
:3 0 161 :2 0 b16
14cd 14ce :3 0 e8
:3 0 61 :3 0 48
:2 0 b18 14d0 14d3
1a :3 0 f3 :2 0
1ac :3 0 14d5 14d7
0 b1d 14d6 14d9
:3 0 7e :3 0 18a
:3 0 48 :2 0 e8
:3 0 4d :3 0 48
:2 0 b20 14de 14e1
1a :3 0 18b :3 0
14e3 14e4 0 7b
:3 0 b23 14dc 14e7
14db 14e8 0 1566
c8 :3 0 149 :3 0
2c :3 0 180 :3 0
1a :3 0 189 :3 0
185 :3 0 7b :3 0
b0 :3 0 23 :4 0
1ad 1 :8 0 150a
f9 :4 0 14f5 :3 0
112 :3 0 f3 :2 0
b2a 14f8 14f9 :3 0
15 :3 0 fa :3 0
14fb 14fc 0 48
:2 0 14fd 14fe 0
1500 b2d 1507 15
:3 0 fa :3 0 1501
1502 0 fb :2 0
1503 1504 0 1506
b2f 1508 14fa 1500
0 1509 0 1506
0 1509 b31 0
150a b34 155d fe
:3 0 15 :3 0 fa
:3 0 150c 150d 0
fd :3 0 150e 150f
0 1511 b37 1513
b39 1512 1511 :2 0
155b ff :3 0 15
:3 0 fa :3 0 1516
1517 0 fd :3 0
1518 1519 0 1553
db :3 0 dc :3 0
151b 151c 0 db
:3 0 ec :3 0 151e
151f 0 100 :2 0
2 :4 0 1ae :2 0
ee :2 0 33 :2 0
b3b 1524 1526 :3 0
b3e 1520 1528 151d
152a 1529 :2 0 de
:3 0 ef :3 0 152c
152d 0 e0 :4 0
1af :4 0 e3 :2 0
e4 :3 0 b42 1531
1533 :3 0 e3 :2 0
103 :4 0 b45 1535
1537 :3 0 e3 :2 0
104 :4 0 b48 1539
153b :3 0 e3 :2 0
fd :3 0 b4b 153d
153f :3 0 e3 :2 0
105 :4 0 b4e 1541
1543 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
b51 1546 154a b55
1545 154c :3 0 b58
152e 154e :2 0 1550
b5b 1551 152b 1550
0 1552 b5d 0
1553 b5f 1556 :3 0
1556 0 1556 1555
1553 1554 :6 0 1558
33 :3 0 b62 155a
b64 1559 1558 :2 0
155b b66 :2 0 155d
0 155d 155c 150a
155b :6 0 1566 1
:3 0 7e :3 0 1b0
:3 0 23 :3 0 b69
1560 1562 155f 1563
0 1566 16a :3 0
b6b 1688 f1 :3 0
e8 :3 0 61 :3 0
48 :2 0 b6f 1568
156b 1a :3 0 189
:3 0 156d 156e 0
b72 1567 1570 1571
:2 0 1a :3 0 15c
:2 0 189 :3 0 1573
1575 0 b77 1574
1577 :3 0 c8 :3 0
149 :3 0 2c :3 0
180 :3 0 1b1 :3 0
1b2 :3 0 180 :3 0
1a :3 0 189 :3 0
b0 :3 0 23 :4 0
1b3 1 :8 0 159a
f9 :4 0 1585 :3 0
112 :3 0 f3 :2 0
b7c 1588 1589 :3 0
15 :3 0 fa :3 0
158b 158c 0 48
:2 0 158d 158e 0
1590 b7f 1597 15
:3 0 fa :3 0 1591
1592 0 fb :2 0
1593 1594 0 1596
b81 1598 158a 1590
0 1599 0 1596
0 1599 b83 0
159a b86 15ed fe
:3 0 15 :3 0 fa
:3 0 159c 159d 0
fd :3 0 159e 159f
0 15a1 b89 15a3
b8b 15a2 15a1 :2 0
15eb ff :3 0 15
:3 0 fa :3 0 15a6
15a7 0 fd :3 0
15a8 15a9 0 15e3
db :3 0 dc :3 0
15ab 15ac 0 db
:3 0 ec :3 0 15ae
15af 0 100 :2 0
2 :4 0 1b4 :2 0
ee :2 0 33 :2 0
b8d 15b4 15b6 :3 0
b90 15b0 15b8 15ad
15ba 15b9 :2 0 de
:3 0 ef :3 0 15bc
15bd 0 e0 :4 0
1b5 :4 0 e3 :2 0
e4 :3 0 b94 15c1
15c3 :3 0 e3 :2 0
103 :4 0 b97 15c5
15c7 :3 0 e3 :2 0
104 :4 0 b9a 15c9
15cb :3 0 e3 :2 0
fd :3 0 b9d 15cd
15cf :3 0 e3 :2 0
105 :4 0 ba0 15d1
15d3 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
ba3 15d6 15da ba7
15d5 15dc :3 0 baa
15be 15de :2 0 15e0
bad 15e1 15bb 15e0
0 15e2 baf 0
15e3 bb1 15e6 :3 0
15e6 0 15e6 15e5
15e3 15e4 :6 0 15e8
35 :3 0 bb4 15ea
bb6 15e9 15e8 :2 0
15eb bb8 :2 0 15ed
0 15ed 15ec 159a
15eb :6 0 15f6 1
:3 0 7e :3 0 1b0
:3 0 23 :3 0 bbb
15f0 15f2 15ef 15f3
0 15f6 16a :3 0
bbd 15f7 1578 15f6
0 1689 f1 :3 0
e8 :3 0 61 :3 0
48 :2 0 bc0 15f9
15fc 1a :3 0 1b6
:3 0 15fe 15ff 0
bc3 15f8 1601 1602
:2 0 1a :3 0 15c
:2 0 1b6 :3 0 1604
1606 0 bc8 1605
1608 :3 0 c8 :3 0
149 :3 0 2c :3 0
180 :3 0 1b1 :3 0
1b2 :3 0 180 :3 0
1a :3 0 1b6 :3 0
b0 :3 0 23 :4 0
1b7 1 :8 0 162b
f9 :4 0 1616 :3 0
112 :3 0 f3 :2 0
bcd 1619 161a :3 0
15 :3 0 fa :3 0
161c 161d 0 48
:2 0 161e 161f 0
1621 bd0 1628 15
:3 0 fa :3 0 1622
1623 0 fb :2 0
1624 1625 0 1627
bd2 1629 161b 1621
0 162a 0 1627
0 162a bd4 0
162b bd7 167e fe
:3 0 15 :3 0 fa
:3 0 162d 162e 0
fd :3 0 162f 1630
0 1632 bda 1634
bdc 1633 1632 :2 0
167c ff :3 0 15
:3 0 fa :3 0 1637
1638 0 fd :3 0
1639 163a 0 1674
db :3 0 dc :3 0
163c 163d 0 db
:3 0 ec :3 0 163f
1640 0 100 :2 0
2 :4 0 1b8 :2 0
ee :2 0 33 :2 0
bde 1645 1647 :3 0
be1 1641 1649 163e
164b 164a :2 0 de
:3 0 ef :3 0 164d
164e 0 e0 :4 0
1b9 :4 0 e3 :2 0
e4 :3 0 be5 1652
1654 :3 0 e3 :2 0
103 :4 0 be8 1656
1658 :3 0 e3 :2 0
104 :4 0 beb 165a
165c :3 0 e3 :2 0
fd :3 0 bee 165e
1660 :3 0 e3 :2 0
105 :4 0 bf1 1662
1664 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
bf4 1667 166b bf8
1666 166d :3 0 bfb
164f 166f :2 0 1671
bfe 1672 164c 1671
0 1673 c00 0
1674 c02 1677 :3 0
1677 0 1677 1676
1674 1675 :6 0 1679
37 :3 0 c05 167b
c07 167a 1679 :2 0
167c c09 :2 0 167e
0 167e 167d 162b
167c :6 0 1686 1
:3 0 7e :3 0 1b0
:3 0 23 :3 0 c0c
1681 1683 1680 1684
0 1686 c0e 1687
1609 1686 0 1689
14da 1566 0 1689
c11 0 168a c15
168b 14cf 168a 0
168c c17 0 168d
c19 168e 1365 168d
0 1690 10a5 135b
0 1690 c1f 0
6d23 6b :3 0 1ba
:3 0 12f :3 0 6a
:3 0 130 :3 0 131
:3 0 132 :3 0 133
:3 0 6a :3 0 13f
:3 0 1ba :3 0 134
:3 0 135 :3 0 132
:3 0 1ba :3 0 12f
:3 0 132 :3 0 a4
:3 0 1ba :3 0 12f
:3 0 aa :3 0 2a
:4 0 1bb 1 :8 0
16ad 15 :3 0 fa
:3 0 16a8 16a9 0
fd :3 0 16aa 16ab
0 16ad c22 1700
fe :3 0 15 :3 0
fa :3 0 16af 16b0
0 fd :3 0 16b1
16b2 0 16b4 c25
16b6 c27 16b5 16b4
:2 0 16fe ff :3 0
15 :3 0 fa :3 0
16b9 16ba 0 fd
:3 0 16bb 16bc 0
16f6 db :3 0 dc
:3 0 16be 16bf 0
db :3 0 ec :3 0
16c1 16c2 0 100
:2 0 2 :4 0 1bc
:2 0 ee :2 0 33
:2 0 c29 16c7 16c9
:3 0 c2c 16c3 16cb
16c0 16cd 16cc :2 0
de :3 0 ef :3 0
16cf 16d0 0 e0
:4 0 1bd :4 0 e3
:2 0 e4 :3 0 c30
16d4 16d6 :3 0 e3
:2 0 103 :4 0 c33
16d8 16da :3 0 e3
:2 0 104 :4 0 c36
16dc 16de :3 0 e3
:2 0 fd :3 0 c39
16e0 16e2 :3 0 e3
:2 0 105 :4 0 c3c
16e4 16e6 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 c3f 16e9 16ed
c43 16e8 16ef :3 0
c46 16d1 16f1 :2 0
16f3 c49 16f4 16ce
16f3 0 16f5 c4b
0 16f6 c4d 16f9
:3 0 16f9 0 16f9
16f8 16f6 16f7 :6 0
16fb 39 :3 0 c50
16fd c52 16fc 16fb
:2 0 16fe c54 :2 0
1700 0 1700 16ff
16ad 16fe :6 0 6d23
1 :3 0 15 :3 0
fa :3 0 1702 1703
0 15 :3 0 15c
:2 0 173 :3 0 1705
1707 0 c59 1706
1709 :3 0 170a :2 0
6a :3 0 1be :2 0
170c 170d 0 170f
c5c 1710 170b 170f
0 1711 c5e 0
6d23 74 :3 0 f7
:4 0 1712 1713 0
6d23 76 :3 0 f7
:4 0 1715 1716 0
6d23 2f :3 0 f7
:4 0 1718 1719 0
6d23 7e :3 0 1bf
:4 0 171c 171d :3 0
171b 171e 0 6d23
e8 :3 0 6d :3 0
48 :2 0 c60 1720
1723 f3 :2 0 48
:2 0 c65 1725 1727
:3 0 1728 :2 0 e8
:3 0 6e :3 0 48
:2 0 c68 172a 172d
f3 :2 0 48 :2 0
c6d 172f 1731 :3 0
1732 :2 0 1729 1734
1733 :2 0 7e :3 0
1c0 :3 0 2b :3 0
2a :3 0 39 :3 0
74 :3 0 76 :3 0
97 :3 0 65 :3 0
68 :3 0 67 :3 0
69 :3 0 c70 1737
1742 1736 1743 0
1799 e8 :3 0 6e
:3 0 48 :2 0 c7b
1745 1748 f3 :2 0
48 :2 0 c80 174a
174c :3 0 65 :3 0
e8 :3 0 65 :3 0
48 :2 0 c83 174f
1752 1c1 :2 0 e8
:3 0 6a :3 0 48
:2 0 c86 1755 1758
c89 1754 175a :3 0
174e 175b 0 176c
68 :3 0 e8 :3 0
68 :3 0 48 :2 0
c8c 175e 1761 1c1
:2 0 e8 :3 0 6a
:3 0 48 :2 0 c8f
1764 1767 c92 1763
1769 :3 0 175d 176a
0 176c c95 176d
174d 176c 0 176e
c98 0 1799 e8
:3 0 6d :3 0 48
:2 0 c9a 176f 1772
f3 :2 0 48 :2 0
c9f 1774 1776 :3 0
67 :3 0 e8 :3 0
67 :3 0 48 :2 0
ca2 1779 177c 1c1
:2 0 e8 :3 0 6a
:3 0 48 :2 0 ca5
177f 1782 ca8 177e
1784 :3 0 1778 1785
0 1796 69 :3 0
e8 :3 0 69 :3 0
48 :2 0 cab 1788
178b 1c1 :2 0 e8
:3 0 6a :3 0 48
:2 0 cae 178e 1791
cb1 178d 1793 :3 0
1787 1794 0 1796
cb4 1797 1777 1796
0 1798 cb7 0
1799 cb9 179a 1735
1799 0 179b cbd
0 6d23 57 :3 0
48 :2 0 179c 179d
0 6d23 4f :3 0
48 :2 0 179f 17a0
0 6d23 1c2 :3 0
a1 :3 0 47 :3 0
a2 :3 0 a4 :3 0
2a :4 0 1c3 1
:8 0 17ae 15 :3 0
fa :3 0 17a9 17aa
0 fd :3 0 17ab
17ac 0 17ae cbf
1801 fe :3 0 15
:3 0 fa :3 0 17b0
17b1 0 fd :3 0
17b2 17b3 0 17b5
cc2 17b7 cc4 17b6
17b5 :2 0 17ff ff
:3 0 15 :3 0 fa
:3 0 17ba 17bb 0
fd :3 0 17bc 17bd
0 17f7 db :3 0
dc :3 0 17bf 17c0
0 db :3 0 ec
:3 0 17c2 17c3 0
100 :2 0 2 :4 0
1c4 :2 0 ee :2 0
33 :2 0 cc6 17c8
17ca :3 0 cc9 17c4
17cc 17c1 17ce 17cd
:2 0 de :3 0 ef
:3 0 17d0 17d1 0
e0 :4 0 1c5 :4 0
e3 :2 0 e4 :3 0
ccd 17d5 17d7 :3 0
e3 :2 0 103 :4 0
cd0 17d9 17db :3 0
e3 :2 0 104 :4 0
cd3 17dd 17df :3 0
e3 :2 0 fd :3 0
cd6 17e1 17e3 :3 0
e3 :2 0 105 :4 0
cd9 17e5 17e7 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 cdc 17ea
17ee ce0 17e9 17f0
:3 0 ce3 17d2 17f2
:2 0 17f4 ce6 17f5
17cf 17f4 0 17f6
ce8 0 17f7 cea
17fa :3 0 17fa 0
17fa 17f9 17f7 17f8
:6 0 17fc 3b :3 0
ced 17fe cef 17fd
17fc :2 0 17ff cf1
:2 0 1801 0 1801
1800 17ae 17ff :6 0
6d23 1 :3 0 8e
:4 0 1803 1804 0
6d23 b2 :3 0 bc
:3 0 8e :3 0 85
:3 0 a8 :3 0 a9
:3 0 2b :3 0 b3
:3 0 2b :3 0 aa
:3 0 2c :3 0 ab
:4 0 1c6 1 :8 0
1818 15 :3 0 fa
:3 0 1813 1814 0
fd :3 0 1815 1816
0 1818 cf4 186b
fe :3 0 15 :3 0
fa :3 0 181a 181b
0 fd :3 0 181c
181d 0 181f cf7
1821 cf9 1820 181f
:2 0 1869 ff :3 0
15 :3 0 fa :3 0
1824 1825 0 fd
:3 0 1826 1827 0
1861 db :3 0 dc
:3 0 1829 182a 0
db :3 0 ec :3 0
182c 182d 0 100
:2 0 2 :4 0 1c7
:2 0 ee :2 0 33
:2 0 cfb 1832 1834
:3 0 cfe 182e 1836
182b 1838 1837 :2 0
de :3 0 ef :3 0
183a 183b 0 e0
:4 0 1c8 :4 0 e3
:2 0 e4 :3 0 d02
183f 1841 :3 0 e3
:2 0 103 :4 0 d05
1843 1845 :3 0 e3
:2 0 104 :4 0 d08
1847 1849 :3 0 e3
:2 0 fd :3 0 d0b
184b 184d :3 0 e3
:2 0 105 :4 0 d0e
184f 1851 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 d11 1854 1858
d15 1853 185a :3 0
d18 183c 185c :2 0
185e d1b 185f 1839
185e 0 1860 d1d
0 1861 d1f 1864
:3 0 1864 0 1864
1863 1861 1862 :6 0
1866 3d :3 0 d22
1868 d24 1867 1866
:2 0 1869 d26 :2 0
186b 0 186b 186a
1818 1869 :6 0 6d23
1 :3 0 1c9 :3 0
1ca :3 0 85 :3 0
7c :3 0 120 :3 0
a9 :3 0 2b :4 0
1cb 1 :8 0 187a
15 :3 0 fa :3 0
1875 1876 0 fd
:3 0 1877 1878 0
187a d29 18cd fe
:3 0 15 :3 0 fa
:3 0 187c 187d 0
fd :3 0 187e 187f
0 1881 d2c 1883
d2e 1882 1881 :2 0
18cb ff :3 0 15
:3 0 fa :3 0 1886
1887 0 fd :3 0
1888 1889 0 18c3
db :3 0 dc :3 0
188b 188c 0 db
:3 0 ec :3 0 188e
188f 0 100 :2 0
2 :4 0 1cc :2 0
ee :2 0 33 :2 0
d30 1894 1896 :3 0
d33 1890 1898 188d
189a 1899 :2 0 de
:3 0 ef :3 0 189c
189d 0 e0 :4 0
1cd :4 0 e3 :2 0
e4 :3 0 d37 18a1
18a3 :3 0 e3 :2 0
103 :4 0 d3a 18a5
18a7 :3 0 e3 :2 0
104 :4 0 d3d 18a9
18ab :3 0 e3 :2 0
fd :3 0 d40 18ad
18af :3 0 e3 :2 0
105 :4 0 d43 18b1
18b3 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
d46 18b6 18ba d4a
18b5 18bc :3 0 d4d
189e 18be :2 0 18c0
d50 18c1 189b 18c0
0 18c2 d52 0
18c3 d54 18c6 :3 0
18c6 0 18c6 18c5
18c3 18c4 :6 0 18c8
3f :3 0 d57 18ca
d59 18c9 18c8 :2 0
18cb d5b :2 0 18cd
0 18cd 18cc 187a
18cb :6 0 6d23 1
:3 0 130 :3 0 14d
:3 0 18cf 18d0 0
2b :3 0 29 :3 0
d5e 18d1 18d4 15c
:2 0 48 :2 0 d63
18d6 18d8 :3 0 161
:2 0 d66 18da 18db
:3 0 e8 :3 0 58
:3 0 48 :2 0 d68
18dd 18e0 15c :2 0
48 :2 0 d6d 18e2
18e4 :3 0 18dc 18e6
18e5 :2 0 8e :3 0
1ce :2 0 d70 18e9
18ea :3 0 18eb :2 0
56 :3 0 48 :2 0
18ed 18ee 0 2779
8f :3 0 48 :2 0
18f0 18f1 0 2779
b0 :3 0 b5 :3 0
1cf :3 0 106 :3 0
b7 :3 0 1cf :3 0
106 :3 0 b8 :3 0
bc :3 0 bd :3 0
be :3 0 bf :3 0
c0 :3 0 c1 :3 0
b3 :3 0 b6 :3 0
c2 :3 0 c3 :3 0
c4 :3 0 c5 :3 0
1f :3 0 89 :3 0
3c :3 0 3d :3 0
85 :3 0 86 :3 0
7f :3 0 80 :3 0
81 :3 0 82 :3 0
29 :3 0 8b :3 0
50 :3 0 52 :3 0
53 :3 0 54 :3 0
a8 :3 0 b2 :3 0
8e :4 0 1d0 1
:8 0 1920 15 :3 0
fa :3 0 191b 191c
0 fd :3 0 191d
191e 0 1920 d72
1973 fe :3 0 15
:3 0 fa :3 0 1922
1923 0 fd :3 0
1924 1925 0 1927
d75 1929 d77 1928
1927 :2 0 1971 ff
:3 0 15 :3 0 fa
:3 0 192c 192d 0
fd :3 0 192e 192f
0 1969 db :3 0
dc :3 0 1931 1932
0 db :3 0 ec
:3 0 1934 1935 0
100 :2 0 2 :4 0
1d1 :2 0 ee :2 0
33 :2 0 d79 193a
193c :3 0 d7c 1936
193e 1933 1940 193f
:2 0 de :3 0 ef
:3 0 1942 1943 0
e0 :4 0 1d2 :4 0
e3 :2 0 e4 :3 0
d80 1947 1949 :3 0
e3 :2 0 103 :4 0
d83 194b 194d :3 0
e3 :2 0 104 :4 0
d86 194f 1951 :3 0
e3 :2 0 fd :3 0
d89 1953 1955 :3 0
e3 :2 0 105 :4 0
d8c 1957 1959 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 d8f 195c
1960 d93 195b 1962
:3 0 d96 1944 1964
:2 0 1966 d99 1967
1941 1966 0 1968
d9b 0 1969 d9d
196c :3 0 196c 0
196c 196b 1969 196a
:6 0 196e 41 :3 0
da0 1970 da2 196f
196e :2 0 1971 da4
:2 0 1973 0 1973
1972 1920 1971 :6 0
2779 1 :3 0 15
:3 0 fa :3 0 1975
1976 0 15 :3 0
f3 :2 0 173 :3 0
1978 197a 0 da9
1979 197c :3 0 197d
:2 0 e8 :3 0 89
:3 0 48 :2 0 dac
197f 1982 15c :2 0
48 :2 0 db1 1984
1986 :3 0 161 :2 0
db4 1988 1989 :3 0
e8 :3 0 84 :3 0
48 :2 0 db6 198b
198e 15c :2 0 48
:2 0 dbb 1990 1992
:3 0 161 :2 0 dbe
1994 1995 :3 0 198a
1997 1996 :2 0 db
:3 0 dc :3 0 1999
199a 0 db :3 0
ec :3 0 199c 199d
0 1e :2 0 2
:4 0 1d3 :2 0 ee
:2 0 33 :2 0 dc0
19a2 19a4 :3 0 dc3
199e 19a6 199b 19a8
19a7 :2 0 de :3 0
ef :3 0 19aa 19ab
0 e0 :4 0 1d4
:4 0 e3 :2 0 e4
:3 0 dc7 19af 19b1
:3 0 e3 :2 0 103
:4 0 dca 19b3 19b5
:3 0 e3 :2 0 10b
:4 0 dcd 19b7 19b9
:3 0 e3 :2 0 e8
:3 0 e9 :3 0 1a
:3 0 1d5 :3 0 19be
19bf 0 dd0 19bd
19c1 ea :4 0 dd2
19bc 19c4 dd5 19bb
19c6 :3 0 e3 :2 0
10d :4 0 dd8 19c8
19ca :3 0 e3 :2 0
e6 :4 0 ddb 19cc
19ce :3 0 e3 :2 0
8e :3 0 dde 19d0
19d2 :3 0 e3 :2 0
e6 :4 0 de1 19d4
19d6 :3 0 de4 19ac
19d8 :2 0 19da de7
19db 19a9 19da 0
19dc de9 0 1a06
db :3 0 dc :3 0
19dd 19de 0 db
:3 0 ec :3 0 19e0
19e1 0 33 :2 0
2 :4 0 1d6 :2 0
ee :2 0 33 :2 0
deb 19e6 19e8 :3 0
dee 19e2 19ea 19df
19ec 19eb :2 0 de
:3 0 ef :3 0 19ee
19ef 0 e0 :4 0
1d7 :4 0 e3 :2 0
e4 :3 0 df2 19f3
19f5 :3 0 df5 19f0
19f7 :2 0 19f9 df8
19fa 19ed 19f9 0
19fb dfa 0 1a06
110 :3 0 111 :3 0
19fc 19fd 0 1a
:3 0 1d5 :3 0 19ff
1a00 0 8e :3 0
112 :3 0 dfc 19fe
1a04 :2 0 1a06 e00
1a07 1998 1a06 0
1a08 e04 0 1a2c
106 :3 0 7c :3 0
33 :2 0 33 :2 0
e06 1a09 1a0d f3
:2 0 1d8 :4 0 e0c
1a0f 1a11 :3 0 9e
:3 0 15 :3 0 fa
:3 0 1a14 1a15 0
1a13 1a16 0 1a29
9c :3 0 1d9 :3 0
2b :3 0 2b :3 0
8e :3 0 1da :2 0
33 :2 0 e0f 1a1d
1a1f :3 0 e11 1a19
1a21 1a18 1a22 0
1a29 15 :3 0 fa
:3 0 1a24 1a25 0
9e :3 0 1a26 1a27
0 1a29 e16 1a2a
1a12 1a29 0 1a2b
e1a 0 1a2c e1c
1a2d 197e 1a2c 0
1a2e e1f 0 2779
e8 :3 0 84 :3 0
48 :2 0 e21 1a2f
1a32 15c :2 0 48
:2 0 e26 1a34 1a36
:3 0 1db :3 0 a9
:3 0 2b :3 0 b2
:3 0 8e :4 0 1dc
1 :8 0 1a53 f9
:4 0 1a3e :3 0 112
:3 0 f3 :2 0 e2b
1a41 1a42 :3 0 15
:3 0 fa :3 0 1a44
1a45 0 48 :2 0
1a46 1a47 0 1a49
e2e 1a50 15 :3 0
fa :3 0 1a4a 1a4b
0 fb :2 0 1a4c
1a4d 0 1a4f e30
1a51 1a43 1a49 0
1a52 0 1a4f 0
1a52 e32 0 1a53
e35 1aa6 fe :3 0
15 :3 0 fa :3 0
1a55 1a56 0 fd
:3 0 1a57 1a58 0
1a5a e38 1a5c e3a
1a5b 1a5a :2 0 1aa4
ff :3 0 15 :3 0
fa :3 0 1a5f 1a60
0 fd :3 0 1a61
1a62 0 1a9c db
:3 0 dc :3 0 1a64
1a65 0 db :3 0
ec :3 0 1a67 1a68
0 100 :2 0 2
:4 0 1dd :2 0 ee
:2 0 33 :2 0 e3c
1a6d 1a6f :3 0 e3f
1a69 1a71 1a66 1a73
1a72 :2 0 de :3 0
ef :3 0 1a75 1a76
0 e0 :4 0 1de
:4 0 e3 :2 0 e4
:3 0 e43 1a7a 1a7c
:3 0 e3 :2 0 103
:4 0 e46 1a7e 1a80
:3 0 e3 :2 0 104
:4 0 e49 1a82 1a84
:3 0 e3 :2 0 fd
:3 0 e4c 1a86 1a88
:3 0 e3 :2 0 105
:4 0 e4f 1a8a 1a8c
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 e52
1a8f 1a93 e56 1a8e
1a95 :3 0 e59 1a77
1a97 :2 0 1a99 e5c
1a9a 1a74 1a99 0
1a9b e5e 0 1a9c
e60 1a9f :3 0 1a9f
0 1a9f 1a9e 1a9c
1a9d :6 0 1aa1 43
:3 0 e63 1aa3 e65
1aa2 1aa1 :2 0 1aa4
e67 :2 0 1aa6 0
1aa6 1aa5 1a53 1aa4
:6 0 1b84 1 :3 0
a8 :3 0 b2 :3 0
8e :4 0 1df 1
:8 0 1ac1 f9 :4 0
1aac :3 0 112 :3 0
f3 :2 0 e6c 1aaf
1ab0 :3 0 15 :3 0
fa :3 0 1ab2 1ab3
0 48 :2 0 1ab4
1ab5 0 1ab7 e6f
1abe 15 :3 0 fa
:3 0 1ab8 1ab9 0
fb :2 0 1aba 1abb
0 1abd e71 1abf
1ab1 1ab7 0 1ac0
0 1abd 0 1ac0
e73 0 1ac1 e76
1b14 fe :3 0 15
:3 0 fa :3 0 1ac3
1ac4 0 fd :3 0
1ac5 1ac6 0 1ac8
e79 1aca e7b 1ac9
1ac8 :2 0 1b12 ff
:3 0 15 :3 0 fa
:3 0 1acd 1ace 0
fd :3 0 1acf 1ad0
0 1b0a db :3 0
dc :3 0 1ad2 1ad3
0 db :3 0 ec
:3 0 1ad5 1ad6 0
100 :2 0 2 :4 0
1e0 :2 0 ee :2 0
33 :2 0 e7d 1adb
1add :3 0 e80 1ad7
1adf 1ad4 1ae1 1ae0
:2 0 de :3 0 ef
:3 0 1ae3 1ae4 0
e0 :4 0 1e1 :4 0
e3 :2 0 e4 :3 0
e84 1ae8 1aea :3 0
e3 :2 0 103 :4 0
e87 1aec 1aee :3 0
e3 :2 0 104 :4 0
e8a 1af0 1af2 :3 0
e3 :2 0 fd :3 0
e8d 1af4 1af6 :3 0
e3 :2 0 105 :4 0
e90 1af8 1afa :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 e93 1afd
1b01 e97 1afc 1b03
:3 0 e9a 1ae5 1b05
:2 0 1b07 e9d 1b08
1ae2 1b07 0 1b09
e9f 0 1b0a ea1
1b0d :3 0 1b0d 0
1b0d 1b0c 1b0a 1b0b
:6 0 1b0f 45 :3 0
ea4 1b11 ea6 1b10
1b0f :2 0 1b12 ea8
:2 0 1b14 0 1b14
1b13 1ac1 1b12 :6 0
1b84 1 :3 0 c8
:3 0 b0 :3 0 1f
:4 0 1e2 1 :8 0
1b2f f9 :4 0 1b1a
:3 0 112 :3 0 f3
:2 0 ead 1b1d 1b1e
:3 0 15 :3 0 fa
:3 0 1b20 1b21 0
48 :2 0 1b22 1b23
0 1b25 eb0 1b2c
15 :3 0 fa :3 0
1b26 1b27 0 fb
:2 0 1b28 1b29 0
1b2b eb2 1b2d 1b1f
1b25 0 1b2e 0
1b2b 0 1b2e eb4
0 1b2f eb7 1b82
fe :3 0 15 :3 0
fa :3 0 1b31 1b32
0 fd :3 0 1b33
1b34 0 1b36 eba
1b38 ebc 1b37 1b36
:2 0 1b80 ff :3 0
15 :3 0 fa :3 0
1b3b 1b3c 0 fd
:3 0 1b3d 1b3e 0
1b78 db :3 0 dc
:3 0 1b40 1b41 0
db :3 0 ec :3 0
1b43 1b44 0 100
:2 0 2 :4 0 1e3
:2 0 ee :2 0 33
:2 0 ebe 1b49 1b4b
:3 0 ec1 1b45 1b4d
1b42 1b4f 1b4e :2 0
de :3 0 ef :3 0
1b51 1b52 0 e0
:4 0 1e4 :4 0 e3
:2 0 e4 :3 0 ec5
1b56 1b58 :3 0 e3
:2 0 103 :4 0 ec8
1b5a 1b5c :3 0 e3
:2 0 104 :4 0 ecb
1b5e 1b60 :3 0 e3
:2 0 fd :3 0 ece
1b62 1b64 :3 0 e3
:2 0 105 :4 0 ed1
1b66 1b68 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 ed4 1b6b 1b6f
ed8 1b6a 1b71 :3 0
edb 1b53 1b73 :2 0
1b75 ede 1b76 1b50
1b75 0 1b77 ee0
0 1b78 ee2 1b7b
:3 0 1b7b 0 1b7b
1b7a 1b78 1b79 :6 0
1b7d 47 :3 0 ee5
1b7f ee7 1b7e 1b7d
:2 0 1b80 ee9 :2 0
1b82 0 1b82 1b81
1b2f 1b80 :6 0 1b84
1 :3 0 eec 2776
64 :3 0 48 :2 0
1b85 1b86 0 2775
e8 :3 0 83 :3 0
48 :2 0 ef0 1b88
1b8b f3 :2 0 33
:2 0 ef5 1b8d 1b8f
:3 0 e8 :3 0 54
:3 0 48 :2 0 ef8
1b91 1b94 e8 :3 0
15c :2 0 f :3 0
48 :2 0 efb 1b96
1b9a f00 1b97 1b9c
:3 0 e8 :3 0 50
:3 0 48 :2 0 f03
1b9e 1ba1 e8 :3 0
15c :2 0 b :3 0
48 :2 0 f06 1ba3
1ba7 f0b 1ba4 1ba9
:3 0 1b9d 1bab 1baa
:2 0 64 :3 0 33
:2 0 1bad 1bae 0
1bb0 f0e 1bb1 1bac
1bb0 0 1bb2 f10
0 1bce 4b :3 0
9 :3 0 1bb3 1bb4
0 1bce 2d :3 0
7 :3 0 1bb6 1bb7
0 1bce 2f :3 0
8 :3 0 1bb9 1bba
0 1bce 50 :3 0
b :3 0 1bbc 1bbd
0 1bce 51 :3 0
10 :3 0 1bbf 1bc0
0 1bce 52 :3 0
d :3 0 1bc2 1bc3
0 1bce 53 :3 0
e :3 0 1bc5 1bc6
0 1bce 5a :3 0
c :3 0 1bc8 1bc9
0 1bce 54 :3 0
f :3 0 1bcb 1bcc
0 1bce f12 1bcf
1b90 1bce 0 1bd0
f1d 0 2775 56
:3 0 106 :3 0 32
:3 0 33 :2 0 33
:2 0 f1f 1bd2 1bd6
f3 :2 0 153 :4 0
f25 1bd8 1bda :3 0
153 :2 0 f28 1bdd
1bdc 48 :3 0 1bdf
0 f2a :2 0 1bd1
1be1 0 2775 15
:3 0 fa :3 0 1be3
1be4 0 15 :3 0
f3 :2 0 173 :3 0
1be6 1be8 0 f2f
1be7 1bea :3 0 1beb
:2 0 26 :3 0 1ce
:2 0 f32 1bee 1bef
:3 0 1bf0 :2 0 b0
:3 0 c2 :3 0 c4
:3 0 c5 :3 0 18e
:3 0 1cf :3 0 106
:3 0 1e5 :3 0 22
:3 0 50 :3 0 53
:3 0 54 :3 0 88
:3 0 38 :3 0 a8
:3 0 b2 :3 0 26
:4 0 1e6 1 :8 0
1c09 15 :3 0 fa
:3 0 1c04 1c05 0
fd :3 0 1c06 1c07
0 1c09 f34 1c5c
fe :3 0 15 :3 0
fa :3 0 1c0b 1c0c
0 fd :3 0 1c0d
1c0e 0 1c10 f37
1c12 f39 1c11 1c10
:2 0 1c5a ff :3 0
15 :3 0 fa :3 0
1c15 1c16 0 fd
:3 0 1c17 1c18 0
1c52 db :3 0 dc
:3 0 1c1a 1c1b 0
db :3 0 ec :3 0
1c1d 1c1e 0 100
:2 0 2 :4 0 1e7
:2 0 ee :2 0 33
:2 0 f3b 1c23 1c25
:3 0 f3e 1c1f 1c27
1c1c 1c29 1c28 :2 0
de :3 0 ef :3 0
1c2b 1c2c 0 e0
:4 0 1e8 :4 0 e3
:2 0 e4 :3 0 f42
1c30 1c32 :3 0 e3
:2 0 103 :4 0 f45
1c34 1c36 :3 0 e3
:2 0 104 :4 0 f48
1c38 1c3a :3 0 e3
:2 0 fd :3 0 f4b
1c3c 1c3e :3 0 e3
:2 0 105 :4 0 f4e
1c40 1c42 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 f51 1c45 1c49
f55 1c44 1c4b :3 0
f58 1c2d 1c4d :2 0
1c4f f5b 1c50 1c2a
1c4f 0 1c51 f5d
0 1c52 f5f 1c55
:3 0 1c55 0 1c55
1c54 1c52 1c53 :6 0
1c57 49 :3 0 f62
1c59 f64 1c58 1c57
:2 0 1c5a f66 :2 0
1c5c 0 1c5c 1c5b
1c09 1c5a :6 0 1e0a
1 :3 0 15 :3 0
fa :3 0 1c5e 1c5f
0 15 :3 0 f3
:2 0 173 :3 0 1c61
1c63 0 f6b 1c62
1c65 :3 0 1c66 :2 0
98 :3 0 33 :2 0
1c68 1c69 0 1e07
e8 :3 0 54 :3 0
48 :2 0 f6e 1c6b
1c6e e8 :3 0 15c
:2 0 f :3 0 48
:2 0 f71 1c70 1c74
f76 1c71 1c76 :3 0
e8 :3 0 50 :3 0
48 :2 0 f79 1c78
1c7b e8 :3 0 15c
:2 0 b :3 0 48
:2 0 f7c 1c7d 1c81
f81 1c7e 1c83 :3 0
1c77 1c85 1c84 :2 0
130 :3 0 1e9 :3 0
1c87 1c88 0 2d
:3 0 38 :3 0 1ea
:2 0 f84 1c89 1c8d
1eb :2 0 48 :2 0
f8a 1c8f 1c91 :3 0
1c92 :2 0 1c86 1c94
1c93 :2 0 db :3 0
dc :3 0 1c96 1c97
0 db :3 0 ec
:3 0 1c99 1c9a 0
1e :2 0 2 :4 0
1ec :2 0 ee :2 0
33 :2 0 f8d 1c9f
1ca1 :3 0 f90 1c9b
1ca3 1c98 1ca5 1ca4
:2 0 de :3 0 ef
:3 0 1ca7 1ca8 0
e0 :4 0 1ed :4 0
e3 :2 0 e4 :3 0
f94 1cac 1cae :3 0
e3 :2 0 103 :4 0
f97 1cb0 1cb2 :3 0
e3 :2 0 10b :4 0
f9a 1cb4 1cb6 :3 0
e3 :2 0 e8 :3 0
e9 :3 0 1a :3 0
1d5 :3 0 1cbb 1cbc
0 f9d 1cba 1cbe
ea :4 0 f9f 1cb9
1cc1 fa2 1cb8 1cc3
:3 0 e3 :2 0 10d
:4 0 fa5 1cc5 1cc7
:3 0 e3 :2 0 e6
:4 0 fa8 1cc9 1ccb
:3 0 e3 :2 0 2a
:3 0 fab 1ccd 1ccf
:3 0 e3 :2 0 e6
:4 0 fae 1cd1 1cd3
:3 0 fb1 1ca9 1cd5
:2 0 1cd7 fb4 1cd8
1ca6 1cd7 0 1cd9
fb6 0 1d04 db
:3 0 dc :3 0 1cda
1cdb 0 db :3 0
ec :3 0 1cdd 1cde
0 33 :2 0 2
:4 0 1ee :2 0 ee
:2 0 33 :2 0 fb8
1ce3 1ce5 :3 0 fbb
1cdf 1ce7 1cdc 1ce9
1ce8 :2 0 de :3 0
ef :3 0 1ceb 1cec
0 e0 :4 0 1ef
:4 0 e3 :2 0 e4
:3 0 fbf 1cf0 1cf2
:3 0 fc2 1ced 1cf4
:2 0 1cf6 fc5 1cf7
1cea 1cf6 0 1cf8
fc7 0 1d04 110
:3 0 111 :3 0 1cf9
1cfa 0 1a :3 0
1d5 :3 0 1cfc 1cfd
0 2a :3 0 112
:3 0 fc9 1cfb 1d01
:2 0 1d04 16a :3 0
fcd 1e05 130 :3 0
1e9 :3 0 1d05 1d06
0 2d :3 0 38
:3 0 1ea :2 0 fd1
1d07 1d0b f3 :2 0
48 :2 0 fd7 1d0d
1d0f :3 0 1f0 :3 0
8f :3 0 1db :3 0
a9 :3 0 2b :3 0
b2 :3 0 26 :3 0
1f1 :3 0 38 :4 0
1f2 1 :8 0 1d20
15 :3 0 fa :3 0
1d1b 1d1c 0 fd
:3 0 1d1d 1d1e 0
1d20 fda 1d73 fe
:3 0 15 :3 0 fa
:3 0 1d22 1d23 0
fd :3 0 1d24 1d25
0 1d27 fdd 1d29
fdf 1d28 1d27 :2 0
1d71 ff :3 0 15
:3 0 fa :3 0 1d2c
1d2d 0 fd :3 0
1d2e 1d2f 0 1d69
db :3 0 dc :3 0
1d31 1d32 0 db
:3 0 ec :3 0 1d34
1d35 0 100 :2 0
2 :4 0 1f3 :2 0
ee :2 0 33 :2 0
fe1 1d3a 1d3c :3 0
fe4 1d36 1d3e 1d33
1d40 1d3f :2 0 de
:3 0 ef :3 0 1d42
1d43 0 e0 :4 0
1f4 :4 0 e3 :2 0
e4 :3 0 fe8 1d47
1d49 :3 0 e3 :2 0
103 :4 0 feb 1d4b
1d4d :3 0 e3 :2 0
104 :4 0 fee 1d4f
1d51 :3 0 e3 :2 0
fd :3 0 ff1 1d53
1d55 :3 0 e3 :2 0
105 :4 0 ff4 1d57
1d59 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
ff7 1d5c 1d60 ffb
1d5b 1d62 :3 0 ffe
1d44 1d64 :2 0 1d66
1001 1d67 1d41 1d66
0 1d68 1003 0
1d69 1005 1d6c :3 0
1d6c 0 1d6c 1d6b
1d69 1d6a :6 0 1d6e
4b :3 0 1008 1d70
100a 1d6f 1d6e :2 0
1d71 100c :2 0 1d73
0 1d73 1d72 1d20
1d71 :6 0 1e03 1
:3 0 15 :3 0 fa
:3 0 1d75 1d76 0
15 :3 0 f3 :2 0
173 :3 0 1d78 1d7a
0 1011 1d79 1d7c
:3 0 1d7d :2 0 4b
:3 0 e8 :3 0 4b
:3 0 48 :2 0 1014
1d80 1d83 ee :2 0
e8 :3 0 8f :3 0
48 :2 0 1017 1d86
1d89 101a 1d85 1d8b
:3 0 1d7f 1d8c 0
1e00 1db :3 0 a9
:3 0 2b :3 0 b2
:3 0 26 :3 0 1f1
:3 0 38 :4 0 1f5
1 :8 0 1dab f9
:4 0 1d96 :3 0 112
:3 0 f3 :2 0 101f
1d99 1d9a :3 0 15
:3 0 fa :3 0 1d9c
1d9d 0 48 :2 0
1d9e 1d9f 0 1da1
1022 1da8 15 :3 0
fa :3 0 1da2 1da3
0 fb :2 0 1da4
1da5 0 1da7 1024
1da9 1d9b 1da1 0
1daa 0 1da7 0
1daa 1026 0 1dab
1029 1dfe fe :3 0
15 :3 0 fa :3 0
1dad 1dae 0 fd
:3 0 1daf 1db0 0
1db2 102c 1db4 102e
1db3 1db2 :2 0 1dfc
ff :3 0 15 :3 0
fa :3 0 1db7 1db8
0 fd :3 0 1db9
1dba 0 1df4 db
:3 0 dc :3 0 1dbc
1dbd 0 db :3 0
ec :3 0 1dbf 1dc0
0 100 :2 0 2
:4 0 1f6 :2 0 ee
:2 0 33 :2 0 1030
1dc5 1dc7 :3 0 1033
1dc1 1dc9 1dbe 1dcb
1dca :2 0 de :3 0
ef :3 0 1dcd 1dce
0 e0 :4 0 1f7
:4 0 e3 :2 0 e4
:3 0 1037 1dd2 1dd4
:3 0 e3 :2 0 103
:4 0 103a 1dd6 1dd8
:3 0 e3 :2 0 104
:4 0 103d 1dda 1ddc
:3 0 e3 :2 0 fd
:3 0 1040 1dde 1de0
:3 0 e3 :2 0 105
:4 0 1043 1de2 1de4
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 1046
1de7 1deb 104a 1de6
1ded :3 0 104d 1dcf
1def :2 0 1df1 1050
1df2 1dcc 1df1 0
1df3 1052 0 1df4
1054 1df7 :3 0 1df7
0 1df7 1df6 1df4
1df5 :6 0 1df9 4d
:3 0 1057 1dfb 1059
1dfa 1df9 :2 0 1dfc
105b :2 0 1dfe 0
1dfe 1dfd 1dab 1dfc
:6 0 1e00 1 :3 0
105e 1e01 1d7e 1e00
0 1e02 1061 0
1e03 1063 1e04 1d10
1e03 0 1e06 1c95
1d04 0 1e06 1066
0 1e07 1069 1e08
1c67 1e07 0 1e09
106c 0 1e0a 106e
1e0b 1bf1 1e0a 0
1e0c 1071 0 2772
56 :3 0 48 :2 0
1e0d 1e0e 0 2772
4c :3 0 48 :2 0
1e10 1e11 0 2772
98 :3 0 15c :2 0
48 :2 0 1075 1e14
1e16 :3 0 5d :3 0
33 :2 0 1e18 1e19
0 1e1b 1078 1e20
5d :3 0 153 :2 0
1e1c 1e1d 0 1e1f
107a 1e21 1e17 1e1b
0 1e22 0 1e1f
0 1e22 107c 0
2772 e8 :3 0 f
:3 0 48 :2 0 107f
1e23 1e26 f3 :2 0
48 :2 0 1084 1e28
1e2a :3 0 50 :3 0
48 :2 0 1e2c 1e2d
0 1e2f 1087 1e30
1e2b 1e2f 0 1e31
1089 0 2772 78
:3 0 1f8 :3 0 2d
:3 0 2f :3 0 e8
:3 0 52 :3 0 48
:2 0 108b 1e36 1e39
e8 :3 0 53 :3 0
48 :2 0 108e 1e3b
1e3e e8 :3 0 5e
:3 0 48 :2 0 1091
1e40 1e43 e8 :3 0
5a :3 0 48 :2 0
1094 1e45 1e48 e8
:3 0 54 :3 0 48
:2 0 1097 1e4a 1e4d
e8 :3 0 51 :3 0
48 :2 0 109a 1e4f
1e52 e8 :3 0 5b
:3 0 48 :2 0 109d
1e54 1e57 e8 :3 0
5c :3 0 48 :2 0
10a0 1e59 1e5c 50
:3 0 4b :3 0 55
:3 0 10a3 1e33 1e61
1e32 1e62 0 2772
e8 :3 0 78 :3 0
48 :2 0 10b1 1e64
1e67 1a :3 0 f3
:2 0 1f9 :3 0 1e69
1e6b 0 10b6 1e6a
1e6d :3 0 db :3 0
dc :3 0 1e6f 1e70
0 db :3 0 ec
:3 0 1e72 1e73 0
1fa :2 0 2 :4 0
1fb :2 0 ee :2 0
33 :2 0 10b9 1e78
1e7a :3 0 10bc 1e74
1e7c 1e71 1e7e 1e7d
:2 0 de :3 0 ef
:3 0 1e80 1e81 0
e0 :4 0 1fc :4 0
e3 :2 0 e4 :3 0
10c0 1e85 1e87 :3 0
e3 :2 0 103 :4 0
10c3 1e89 1e8b :3 0
e3 :2 0 10b :4 0
10c6 1e8d 1e8f :3 0
e3 :2 0 e8 :3 0
e9 :3 0 1a :3 0
1f9 :3 0 1e94 1e95
0 10c9 1e93 1e97
ea :4 0 10cb 1e92
1e9a 10ce 1e91 1e9c
:3 0 10d1 1e82 1e9e
:2 0 1ea0 10d4 1ea1
1e7f 1ea0 0 1ea2
10d6 0 1ecc db
:3 0 dc :3 0 1ea3
1ea4 0 db :3 0
ec :3 0 1ea6 1ea7
0 33 :2 0 2
:4 0 1fd :2 0 ee
:2 0 33 :2 0 10d8
1eac 1eae :3 0 10db
1ea8 1eb0 1ea5 1eb2
1eb1 :2 0 de :3 0
ef :3 0 1eb4 1eb5
0 e0 :4 0 1fe
:4 0 e3 :2 0 e4
:3 0 10df 1eb9 1ebb
:3 0 10e2 1eb6 1ebd
:2 0 1ebf 10e5 1ec0
1eb3 1ebf 0 1ec1
10e7 0 1ecc 110
:3 0 1ff :3 0 1ec2
1ec3 0 1a :3 0
1f9 :3 0 1ec5 1ec6
0 112 :3 0 10e9
1ec4 1ec9 :2 0 1ecc
16a :3 0 10ec 1f45
e8 :3 0 78 :3 0
48 :2 0 10f0 1ecd
1ed0 15c :2 0 48
:2 0 10f5 1ed2 1ed4
:3 0 db :3 0 dc
:3 0 1ed6 1ed7 0
db :3 0 ec :3 0
1ed9 1eda 0 1e
:2 0 2 :4 0 200
:2 0 ee :2 0 33
:2 0 10f8 1edf 1ee1
:3 0 10fb 1edb 1ee3
1ed8 1ee5 1ee4 :2 0
de :3 0 ef :3 0
1ee7 1ee8 0 e0
:4 0 201 :4 0 e3
:2 0 e4 :3 0 10ff
1eec 1eee :3 0 e3
:2 0 103 :4 0 1102
1ef0 1ef2 :3 0 e3
:2 0 10b :4 0 1105
1ef4 1ef6 :3 0 e3
:2 0 e8 :3 0 e9
:3 0 78 :3 0 1108
1efa 1efc ea :4 0
110a 1ef9 1eff 110d
1ef8 1f01 :3 0 e3
:2 0 10d :4 0 1110
1f03 1f05 :3 0 e3
:2 0 e6 :4 0 1113
1f07 1f09 :3 0 e3
:2 0 2b :3 0 1116
1f0b 1f0d :3 0 e3
:2 0 e6 :4 0 1119
1f0f 1f11 :3 0 111c
1ee9 1f13 :2 0 1f15
111f 1f16 1ee6 1f15
0 1f17 1121 0
1f43 db :3 0 dc
:3 0 1f18 1f19 0
db :3 0 ec :3 0
1f1b 1f1c 0 33
:2 0 2 :4 0 202
:2 0 ee :2 0 33
:2 0 1123 1f21 1f23
:3 0 1126 1f1d 1f25
1f1a 1f27 1f26 :2 0
de :3 0 ef :3 0
1f29 1f2a 0 e0
:4 0 203 :4 0 e3
:2 0 e4 :3 0 112a
1f2e 1f30 :3 0 112d
1f2b 1f32 :2 0 1f34
1130 1f35 1f28 1f34
0 1f36 1132 0
1f43 110 :3 0 111
:3 0 1f37 1f38 0
e8 :3 0 78 :3 0
48 :2 0 1134 1f3a
1f3d 2b :3 0 112
:3 0 1137 1f39 1f41
:2 0 1f43 113b 1f44
1ed5 1f43 0 1f46
1e6e 1ecc 0 1f46
113f 0 2772 e8
:3 0 5a :3 0 48
:2 0 1142 1f47 1f4a
1a :3 0 f3 :2 0
204 :3 0 1f4c 1f4e
0 1147 1f4d 1f50
:3 0 5a :3 0 48
:2 0 1f52 1f53 0
1f55 114a 1f56 1f51
1f55 0 1f57 114c
0 2772 92 :3 0
48 :2 0 1f58 1f59
0 2772 92 :3 0
15d :3 0 205 :3 0
b0 :3 0 c8 :3 0
205 :3 0 a8 :3 0
206 :3 0 206 :3 0
a9 :3 0 2b :3 0
205 :3 0 b0 :3 0
206 :3 0 b0 :3 0
205 :3 0 149 :3 0
2c :3 0 205 :3 0
ab :4 0 207 1
:8 0 1f75 15 :3 0
fa :3 0 1f70 1f71
0 fd :3 0 1f72
1f73 0 1f75 114e
1fc8 fe :3 0 15
:3 0 fa :3 0 1f77
1f78 0 fd :3 0
1f79 1f7a 0 1f7c
1151 1f7e 1153 1f7d
1f7c :2 0 1fc6 ff
:3 0 15 :3 0 fa
:3 0 1f81 1f82 0
fd :3 0 1f83 1f84
0 1fbe db :3 0
dc :3 0 1f86 1f87
0 db :3 0 ec
:3 0 1f89 1f8a 0
100 :2 0 2 :4 0
208 :2 0 ee :2 0
33 :2 0 1155 1f8f
1f91 :3 0 1158 1f8b
1f93 1f88 1f95 1f94
:2 0 de :3 0 ef
:3 0 1f97 1f98 0
e0 :4 0 209 :4 0
e3 :2 0 e4 :3 0
115c 1f9c 1f9e :3 0
e3 :2 0 103 :4 0
115f 1fa0 1fa2 :3 0
e3 :2 0 104 :4 0
1162 1fa4 1fa6 :3 0
e3 :2 0 fd :3 0
1165 1fa8 1faa :3 0
e3 :2 0 105 :4 0
1168 1fac 1fae :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 116b 1fb1
1fb5 116f 1fb0 1fb7
:3 0 1172 1f99 1fb9
:2 0 1fbb 1175 1fbc
1f96 1fbb 0 1fbd
1177 0 1fbe 1179
1fc1 :3 0 1fc1 0
1fc1 1fc0 1fbe 1fbf
:6 0 1fc3 4f :3 0
117c 1fc5 117e 1fc4
1fc3 :2 0 1fc6 1180
:2 0 1fc8 0 1fc8
1fc7 1f75 1fc6 :6 0
2772 1 :3 0 98
:3 0 15c :2 0 48
:2 0 1185 1fcb 1fcd
:3 0 e8 :3 0 92
:3 0 48 :2 0 1188
1fcf 1fd2 f3 :2 0
33 :2 0 118d 1fd4
1fd6 :3 0 92 :3 0
48 :2 0 1fd8 1fd9
0 1fdb 1190 1fdc
1fd7 1fdb 0 1fdd
1192 0 2000 e8
:3 0 50 :3 0 48
:2 0 1194 1fde 1fe1
f3 :2 0 48 :2 0
1199 1fe3 1fe5 :3 0
5a :3 0 1a :3 0
20a :3 0 1fe8 1fe9
0 1fe7 1fea 0
1fec 119c 1ffd 5a
:3 0 20b :3 0 1b2
:3 0 1fee 1fef 0
e8 :3 0 5a :3 0
48 :2 0 119e 1ff1
1ff4 1a :3 0 20a
:3 0 1ff6 1ff7 0
11a1 1ff0 1ff9 1fed
1ffa 0 1ffc 11a4
1ffe 1fe6 1fec 0
1fff 0 1ffc 0
1fff 11a6 0 2000
11a9 2024 e8 :3 0
50 :3 0 48 :2 0
11ac 2001 2004 f3
:2 0 48 :2 0 11b1
2006 2008 :3 0 5a
:3 0 1a :3 0 20c
:3 0 200b 200c 0
200a 200d 0 200f
11b4 2020 5a :3 0
20b :3 0 1b2 :3 0
2011 2012 0 e8
:3 0 5a :3 0 48
:2 0 11b6 2014 2017
1a :3 0 20c :3 0
2019 201a 0 11b9
2013 201c 2010 201d
0 201f 11bc 2021
2009 200f 0 2022
0 201f 0 2022
11be 0 2023 11c1
2025 1fce 2000 0
2026 0 2023 0
2026 11c3 0 2772
e8 :3 0 92 :3 0
48 :2 0 11c6 2027
202a 15c :2 0 48
:2 0 11cb 202c 202e
:3 0 161 :2 0 11ce
2030 2031 :3 0 a8
:3 0 20d :3 0 b7
:3 0 20e :3 0 b8
:3 0 20f :3 0 bb
:3 0 210 :3 0 b5
:3 0 211 :3 0 212
:3 0 213 :3 0 214
:3 0 215 :3 0 be
:3 0 216 :3 0 c0
:3 0 217 :3 0 bf
:3 0 218 :3 0 c1
:3 0 219 :3 0 b2
:3 0 8e :4 0 21a
1 :8 0 2061 f9
:4 0 204c :3 0 112
:3 0 f3 :2 0 11d2
204f 2050 :3 0 15
:3 0 fa :3 0 2052
2053 0 48 :2 0
2054 2055 0 2057
11d5 205e 15 :3 0
fa :3 0 2058 2059
0 fb :2 0 205a
205b 0 205d 11d7
205f 2051 2057 0
2060 0 205d 0
2060 11d9 0 2061
11dc 20b4 fe :3 0
15 :3 0 fa :3 0
2063 2064 0 fd
:3 0 2065 2066 0
2068 11df 206a 11e1
2069 2068 :2 0 20b2
ff :3 0 15 :3 0
fa :3 0 206d 206e
0 fd :3 0 206f
2070 0 20aa db
:3 0 dc :3 0 2072
2073 0 db :3 0
ec :3 0 2075 2076
0 100 :2 0 2
:4 0 21b :2 0 ee
:2 0 33 :2 0 11e3
207b 207d :3 0 11e6
2077 207f 2074 2081
2080 :2 0 de :3 0
ef :3 0 2083 2084
0 e0 :4 0 21c
:4 0 e3 :2 0 e4
:3 0 11ea 2088 208a
:3 0 e3 :2 0 103
:4 0 11ed 208c 208e
:3 0 e3 :2 0 104
:4 0 11f0 2090 2092
:3 0 e3 :2 0 fd
:3 0 11f3 2094 2096
:3 0 e3 :2 0 105
:4 0 11f6 2098 209a
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 11f9
209d 20a1 11fd 209c
20a3 :3 0 1200 2085
20a5 :2 0 20a7 1203
20a8 2082 20a7 0
20a9 1205 0 20aa
1207 20ad :3 0 20ad
0 20ad 20ac 20aa
20ab :6 0 20af 51
:3 0 120a 20b1 120c
20b0 20af :2 0 20b2
120e :2 0 20b4 0
20b4 20b3 2061 20b2
:6 0 2133 1 :3 0
21d :3 0 21e :3 0
21f :3 0 220 :3 0
221 :3 0 222 :3 0
223 :3 0 224 :3 0
225 :3 0 226 :3 0
227 :3 0 a9 :3 0
2b :3 0 aa :3 0
2c :4 0 228 1
:8 0 20db f9 :4 0
20c6 :3 0 112 :3 0
f3 :2 0 1213 20c9
20ca :3 0 15 :3 0
fa :3 0 20cc 20cd
0 48 :2 0 20ce
20cf 0 20d1 1216
20d8 15 :3 0 fa
:3 0 20d2 20d3 0
fb :2 0 20d4 20d5
0 20d7 1218 20d9
20cb 20d1 0 20da
0 20d7 0 20da
121a 0 20db 121d
212e fe :3 0 15
:3 0 fa :3 0 20dd
20de 0 fd :3 0
20df 20e0 0 20e2
1220 20e4 1222 20e3
20e2 :2 0 212c ff
:3 0 15 :3 0 fa
:3 0 20e7 20e8 0
fd :3 0 20e9 20ea
0 2124 db :3 0
dc :3 0 20ec 20ed
0 db :3 0 ec
:3 0 20ef 20f0 0
100 :2 0 2 :4 0
229 :2 0 ee :2 0
33 :2 0 1224 20f5
20f7 :3 0 1227 20f1
20f9 20ee 20fb 20fa
:2 0 de :3 0 ef
:3 0 20fd 20fe 0
e0 :4 0 22a :4 0
e3 :2 0 e4 :3 0
122b 2102 2104 :3 0
e3 :2 0 103 :4 0
122e 2106 2108 :3 0
e3 :2 0 104 :4 0
1231 210a 210c :3 0
e3 :2 0 fd :3 0
1234 210e 2110 :3 0
e3 :2 0 105 :4 0
1237 2112 2114 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 123a 2117
211b 123e 2116 211d
:3 0 1241 20ff 211f
:2 0 2121 1244 2122
20fc 2121 0 2123
1246 0 2124 1248
2127 :3 0 2127 0
2127 2126 2124 2125
:6 0 2129 53 :3 0
124b 212b 124d 212a
2129 :2 0 212c 124f
:2 0 212e 0 212e
212d 20db 212c :6 0
2133 1 :3 0 99
:3 0 33 :2 0 2130
2131 0 2133 1252
2134 2032 2133 0
2135 1256 0 2772
77 :3 0 22b :2 0
2136 2137 0 2772
96 :3 0 22c :3 0
26 :3 0 2b :3 0
2b :3 0 2a :3 0
77 :3 0 4d :3 0
34 :3 0 34 :3 0
34 :3 0 34 :3 0
2d :3 0 2f :3 0
55 :3 0 4b :3 0
50 :3 0 52 :3 0
53 :3 0 4c :3 0
5e :3 0 39 :3 0
56 :3 0 5a :3 0
54 :3 0 51 :3 0
5d :3 0 5b :3 0
5f :3 0 21 :3 0
48 :2 0 48 :2 0
22d :3 0 22e :2 0
1258 2159 215b 22d
:3 0 22e :2 0 125a
215d 215f 48 :2 0
48 :2 0 125c 213a
2163 2139 2164 0
2772 96 :3 0 f3
:2 0 22f :2 0 1281
2167 2169 :3 0 db
:3 0 dc :3 0 216b
216c 0 db :3 0
ec :3 0 216e 216f
0 1e :2 0 2
:4 0 230 :2 0 ee
:2 0 33 :2 0 1284
2174 2176 :3 0 1287
2170 2178 216d 217a
2179 :2 0 de :3 0
ef :3 0 217c 217d
0 e0 :4 0 231
:4 0 e3 :2 0 e4
:3 0 128b 2181 2183
:3 0 e3 :2 0 103
:4 0 128e 2185 2187
:3 0 e3 :2 0 10b
:4 0 1291 2189 218b
:3 0 e3 :2 0 e8
:3 0 e9 :3 0 1a
:3 0 232 :3 0 2190
2191 0 1294 218f
2193 ea :4 0 1296
218e 2196 1299 218d
2198 :3 0 e3 :2 0
10d :4 0 129c 219a
219c :3 0 e3 :2 0
e6 :4 0 129f 219e
21a0 :3 0 e3 :2 0
2a :3 0 12a2 21a2
21a4 :3 0 e3 :2 0
e6 :4 0 12a5 21a6
21a8 :3 0 12a8 217e
21aa :2 0 21ac 12ab
21ad 217b 21ac 0
21ae 12ad 0 21d9
db :3 0 dc :3 0
21af 21b0 0 db
:3 0 ec :3 0 21b2
21b3 0 33 :2 0
2 :4 0 233 :2 0
ee :2 0 33 :2 0
12af 21b8 21ba :3 0
12b2 21b4 21bc 21b1
21be 21bd :2 0 de
:3 0 ef :3 0 21c0
21c1 0 e0 :4 0
234 :4 0 e3 :2 0
e4 :3 0 12b6 21c5
21c7 :3 0 12b9 21c2
21c9 :2 0 21cb 12bc
21cc 21bf 21cb 0
21cd 12be 0 21d9
110 :3 0 111 :3 0
21ce 21cf 0 1a
:3 0 232 :3 0 21d1
21d2 0 2a :3 0
112 :3 0 12c0 21d0
21d6 :2 0 21d9 16a
:3 0 12c4 25bc 96
:3 0 15c :2 0 48
:2 0 12ca 21db 21dd
:3 0 db :3 0 dc
:3 0 21df 21e0 0
db :3 0 ec :3 0
21e2 21e3 0 1e
:2 0 2 :4 0 235
:2 0 ee :2 0 33
:2 0 12cd 21e8 21ea
:3 0 12d0 21e4 21ec
21e1 21ee 21ed :2 0
de :3 0 ef :3 0
21f0 21f1 0 e0
:4 0 236 :4 0 e3
:2 0 e4 :3 0 12d4
21f5 21f7 :3 0 e3
:2 0 103 :4 0 12d7
21f9 21fb :3 0 e3
:2 0 10b :4 0 12da
21fd 21ff :3 0 e3
:2 0 e8 :3 0 e9
:3 0 1a :3 0 1d5
:3 0 2204 2205 0
12dd 2203 2207 ea
:4 0 12df 2202 220a
12e2 2201 220c :3 0
e3 :2 0 10d :4 0
12e5 220e 2210 :3 0
e3 :2 0 e6 :4 0
12e8 2212 2214 :3 0
e3 :2 0 23 :3 0
12eb 2216 2218 :3 0
e3 :2 0 e6 :4 0
12ee 221a 221c :3 0
12f1 21f2 221e :2 0
2220 12f4 2221 21ef
2220 0 2222 12f6
0 224c db :3 0
dc :3 0 2223 2224
0 db :3 0 ec
:3 0 2226 2227 0
33 :2 0 2 :4 0
237 :2 0 ee :2 0
33 :2 0 12f8 222c
222e :3 0 12fb 2228
2230 2225 2232 2231
:2 0 de :3 0 ef
:3 0 2234 2235 0
e0 :4 0 238 :4 0
e3 :2 0 e4 :3 0
12ff 2239 223b :3 0
1302 2236 223d :2 0
223f 1305 2240 2233
223f 0 2241 1307
0 224c 110 :3 0
111 :3 0 2242 2243
0 1a :3 0 1d5
:3 0 2245 2246 0
23 :3 0 112 :3 0
1309 2244 224a :2 0
224c 130d 224d 21de
224c 0 25be 26
:3 0 239 :2 0 1311
224f 2250 :3 0 2251
:2 0 b2 :3 0 b7
:3 0 b8 :3 0 b5
:3 0 26 :3 0 2d
:3 0 2f :3 0 4b
:3 0 a8 :3 0 a9
:3 0 2b :3 0 b3
:3 0 2b :3 0 aa
:3 0 2a :3 0 194
:4 0 23a 1 :8 0
2269 15 :3 0 fa
:3 0 2264 2265 0
fd :3 0 2266 2267
0 2269 1313 22bc
fe :3 0 15 :3 0
fa :3 0 226b 226c
0 fd :3 0 226d
226e 0 2270 1316
2272 1318 2271 2270
:2 0 22ba ff :3 0
15 :3 0 fa :3 0
2275 2276 0 fd
:3 0 2277 2278 0
22b2 db :3 0 dc
:3 0 227a 227b 0
db :3 0 ec :3 0
227d 227e 0 100
:2 0 2 :4 0 23b
:2 0 ee :2 0 33
:2 0 131a 2283 2285
:3 0 131d 227f 2287
227c 2289 2288 :2 0
de :3 0 ef :3 0
228b 228c 0 e0
:4 0 23c :4 0 e3
:2 0 e4 :3 0 1321
2290 2292 :3 0 e3
:2 0 103 :4 0 1324
2294 2296 :3 0 e3
:2 0 104 :4 0 1327
2298 229a :3 0 e3
:2 0 fd :3 0 132a
229c 229e :3 0 e3
:2 0 105 :4 0 132d
22a0 22a2 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 1330 22a5 22a9
1334 22a4 22ab :3 0
1337 228d 22ad :2 0
22af 133a 22b0 228a
22af 0 22b1 133c
0 22b2 133e 22b5
:3 0 22b5 0 22b5
22b4 22b2 22b3 :6 0
22b7 55 :3 0 1341
22b9 1343 22b8 22b7
:2 0 22ba 1345 :2 0
22bc 0 22bc 22bb
2269 22ba :6 0 22be
1 :3 0 1348 253e
98 :3 0 15c :2 0
48 :2 0 134c 22c0
22c2 :3 0 e8 :3 0
4b :3 0 48 :2 0
134f 22c4 22c7 15c
:2 0 48 :2 0 1354
22c9 22cb :3 0 161
:2 0 1357 22cd 22ce
:3 0 22c3 22d0 22cf
:2 0 e8 :3 0 4b
:3 0 48 :2 0 1359
22d2 22d5 15c :2 0
48 :2 0 135e 22d7
22d9 :3 0 161 :2 0
1361 22db 22dc :3 0
e8 :3 0 8f :3 0
48 :2 0 1363 22de
22e1 15c :2 0 48
:2 0 1368 22e3 22e5
:3 0 2d :3 0 38
:3 0 22e7 22e8 0
2352 1c2 :3 0 1f1
:3 0 23d :3 0 1f0
:3 0 2f :3 0 4b
:3 0 1db :3 0 a9
:3 0 2b :3 0 b2
:3 0 26 :3 0 1f1
:3 0 38 :4 0 23e
1 :8 0 22fd 15
:3 0 fa :3 0 22f8
22f9 0 fd :3 0
22fa 22fb 0 22fd
136b 2350 fe :3 0
15 :3 0 fa :3 0
22ff 2300 0 fd
:3 0 2301 2302 0
2304 136e 2306 1370
2305 2304 :2 0 234e
ff :3 0 15 :3 0
fa :3 0 2309 230a
0 fd :3 0 230b
230c 0 2346 db
:3 0 dc :3 0 230e
230f 0 db :3 0
ec :3 0 2311 2312
0 100 :2 0 2
:4 0 23f :2 0 ee
:2 0 33 :2 0 1372
2317 2319 :3 0 1375
2313 231b 2310 231d
231c :2 0 de :3 0
ef :3 0 231f 2320
0 e0 :4 0 240
:4 0 e3 :2 0 e4
:3 0 1379 2324 2326
:3 0 e3 :2 0 103
:4 0 137c 2328 232a
:3 0 e3 :2 0 104
:4 0 137f 232c 232e
:3 0 e3 :2 0 fd
:3 0 1382 2330 2332
:3 0 e3 :2 0 105
:4 0 1385 2334 2336
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 1388
2339 233d 138c 2338
233f :3 0 138f 2321
2341 :2 0 2343 1392
2344 231e 2343 0
2345 1394 0 2346
1396 2349 :3 0 2349
0 2349 2348 2346
2347 :6 0 234b 57
:3 0 1399 234d 139b
234c 234b :2 0 234e
139d :2 0 2350 0
2350 234f 22fd 234e
:6 0 2352 1 :3 0
13a0 23bf 241 :3 0
1f1 :3 0 1c2 :3 0
1f1 :3 0 23d :3 0
1f0 :3 0 2d :3 0
2f :3 0 4b :3 0
1db :3 0 a9 :3 0
2b :3 0 b2 :3 0
26 :3 0 1f1 :3 0
38 :4 0 242 1
:8 0 2369 15 :3 0
fa :3 0 2364 2365
0 fd :3 0 2366
2367 0 2369 13a3
23bc fe :3 0 15
:3 0 fa :3 0 236b
236c 0 fd :3 0
236d 236e 0 2370
13a6 2372 13a8 2371
2370 :2 0 23ba ff
:3 0 15 :3 0 fa
:3 0 2375 2376 0
fd :3 0 2377 2378
0 23b2 db :3 0
dc :3 0 237a 237b
0 db :3 0 ec
:3 0 237d 237e 0
100 :2 0 2 :4 0
243 :2 0 ee :2 0
33 :2 0 13aa 2383
2385 :3 0 13ad 237f
2387 237c 2389 2388
:2 0 de :3 0 ef
:3 0 238b 238c 0
e0 :4 0 244 :4 0
e3 :2 0 e4 :3 0
13b1 2390 2392 :3 0
e3 :2 0 103 :4 0
13b4 2394 2396 :3 0
e3 :2 0 104 :4 0
13b7 2398 239a :3 0
e3 :2 0 fd :3 0
13ba 239c 239e :3 0
e3 :2 0 105 :4 0
13bd 23a0 23a2 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 13c0 23a5
23a9 13c4 23a4 23ab
:3 0 13c7 238d 23ad
:2 0 23af 13ca 23b0
238a 23af 0 23b1
13cc 0 23b2 13ce
23b5 :3 0 23b5 0
23b5 23b4 23b2 23b3
:6 0 23b7 59 :3 0
13d1 23b9 13d3 23b8
23b7 :2 0 23ba 13d5
:2 0 23bc 0 23bc
23bb 2369 23ba :6 0
23be 1 :3 0 13d8
23c0 22e6 2352 0
23c1 0 23be 0
23c1 13da 0 23c2
13dd 24a2 e8 :3 0
8f :3 0 48 :2 0
13df 23c3 23c6 15c
:2 0 48 :2 0 13e4
23c8 23ca :3 0 2d
:3 0 38 :3 0 23cc
23cd 0 2434 1c2
:3 0 1f1 :3 0 2f
:3 0 1db :3 0 a9
:3 0 2b :3 0 b2
:3 0 26 :3 0 1f1
:3 0 38 :4 0 245
1 :8 0 23df 15
:3 0 fa :3 0 23da
23db 0 fd :3 0
23dc 23dd 0 23df
13e7 2432 fe :3 0
15 :3 0 fa :3 0
23e1 23e2 0 fd
:3 0 23e3 23e4 0
23e6 13ea 23e8 13ec
23e7 23e6 :2 0 2430
ff :3 0 15 :3 0
fa :3 0 23eb 23ec
0 fd :3 0 23ed
23ee 0 2428 db
:3 0 dc :3 0 23f0
23f1 0 db :3 0
ec :3 0 23f3 23f4
0 100 :2 0 2
:4 0 246 :2 0 ee
:2 0 33 :2 0 13ee
23f9 23fb :3 0 13f1
23f5 23fd 23f2 23ff
23fe :2 0 de :3 0
ef :3 0 2401 2402
0 e0 :4 0 247
:4 0 e3 :2 0 e4
:3 0 13f5 2406 2408
:3 0 e3 :2 0 103
:4 0 13f8 240a 240c
:3 0 e3 :2 0 104
:4 0 13fb 240e 2410
:3 0 e3 :2 0 fd
:3 0 13fe 2412 2414
:3 0 e3 :2 0 105
:4 0 1401 2416 2418
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 1404
241b 241f 1408 241a
2421 :3 0 140b 2403
2423 :2 0 2425 140e
2426 2400 2425 0
2427 1410 0 2428
1412 242b :3 0 242b
0 242b 242a 2428
2429 :6 0 242d 5b
:3 0 1415 242f 1417
242e 242d :2 0 2430
1419 :2 0 2432 0
2432 2431 23df 2430
:6 0 2434 1 :3 0
141c 249e 241 :3 0
1f1 :3 0 1c2 :3 0
1f1 :3 0 2d :3 0
2f :3 0 1db :3 0
a9 :3 0 2b :3 0
b2 :3 0 26 :3 0
1f1 :3 0 38 :4 0
248 1 :8 0 2448
15 :3 0 fa :3 0
2443 2444 0 fd
:3 0 2445 2446 0
2448 141f 249b fe
:3 0 15 :3 0 fa
:3 0 244a 244b 0
fd :3 0 244c 244d
0 244f 1422 2451
1424 2450 244f :2 0
2499 ff :3 0 15
:3 0 fa :3 0 2454
2455 0 fd :3 0
2456 2457 0 2491
db :3 0 dc :3 0
2459 245a 0 db
:3 0 ec :3 0 245c
245d 0 100 :2 0
2 :4 0 249 :2 0
ee :2 0 33 :2 0
1426 2462 2464 :3 0
1429 245e 2466 245b
2468 2467 :2 0 de
:3 0 ef :3 0 246a
246b 0 e0 :4 0
24a :4 0 e3 :2 0
e4 :3 0 142d 246f
2471 :3 0 e3 :2 0
103 :4 0 1430 2473
2475 :3 0 e3 :2 0
104 :4 0 1433 2477
2479 :3 0 e3 :2 0
fd :3 0 1436 247b
247d :3 0 e3 :2 0
105 :4 0 1439 247f
2481 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
143c 2484 2488 1440
2483 248a :3 0 1443
246c 248c :2 0 248e
1446 248f 2469 248e
0 2490 1448 0
2491 144a 2494 :3 0
2494 0 2494 2493
2491 2492 :6 0 2496
5d :3 0 144d 2498
144f 2497 2496 :2 0
2499 1451 :2 0 249b
0 249b 249a 2448
2499 :6 0 249d 1
:3 0 1454 249f 23cb
2434 0 24a0 0
249d 0 24a0 1456
0 24a1 1459 24a3
22dd 23c2 0 24a4
0 24a1 0 24a4
145b 0 24a5 145e
251f 78 :3 0 24b
:2 0 24a6 24a7 0
251e 7e :3 0 24c
:3 0 2b :3 0 26
:3 0 78 :3 0 e8
:3 0 5b :3 0 48
:2 0 1460 24ae 24b1
48 :2 0 48 :2 0
1463 24aa 24b5 24a9
24b6 0 251e e8
:3 0 b7 :3 0 24d
:3 0 e8 :3 0 b8
:3 0 24e :3 0 2d
:3 0 2f :3 0 a8
:3 0 b2 :3 0 26
:4 0 24f 1 :8 0
24c9 15 :3 0 fa
:3 0 24c4 24c5 0
fd :3 0 24c6 24c7
0 24c9 146a 251c
fe :3 0 15 :3 0
fa :3 0 24cb 24cc
0 fd :3 0 24cd
24ce 0 24d0 146d
24d2 146f 24d1 24d0
:2 0 251a ff :3 0
15 :3 0 fa :3 0
24d5 24d6 0 fd
:3 0 24d7 24d8 0
2512 db :3 0 dc
:3 0 24da 24db 0
db :3 0 ec :3 0
24dd 24de 0 100
:2 0 2 :4 0 250
:2 0 ee :2 0 33
:2 0 1471 24e3 24e5
:3 0 1474 24df 24e7
24dc 24e9 24e8 :2 0
de :3 0 ef :3 0
24eb 24ec 0 e0
:4 0 251 :4 0 e3
:2 0 e4 :3 0 1478
24f0 24f2 :3 0 e3
:2 0 103 :4 0 147b
24f4 24f6 :3 0 e3
:2 0 104 :4 0 147e
24f8 24fa :3 0 e3
:2 0 fd :3 0 1481
24fc 24fe :3 0 e3
:2 0 105 :4 0 1484
2500 2502 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 1487 2505 2509
148b 2504 250b :3 0
148e 24ed 250d :2 0
250f 1491 2510 24ea
250f 0 2511 1493
0 2512 1495 2515
:3 0 2515 0 2515
2514 2512 2513 :6 0
2517 5f :3 0 1498
2519 149a 2518 2517
:2 0 251a 149c :2 0
251c 0 251c 251b
24c9 251a :6 0 251e
1 :3 0 149f 2520
22d1 24a5 0 2521
0 251e 0 2521
14a3 0 253d e8
:3 0 8f :3 0 48
:2 0 14a6 2522 2525
15c :2 0 48 :2 0
14ab 2527 2529 :3 0
4b :3 0 e8 :3 0
4b :3 0 48 :2 0
14ae 252c 252f 1da
:2 0 e8 :3 0 8f
:3 0 48 :2 0 14b1
2532 2535 14b4 2531
2537 :3 0 252b 2538
0 253a 14b7 253b
252a 253a 0 253c
14b9 0 253d 14bb
253f 2252 22be 0
2540 0 253d 0
2540 14be 0 25bb
15 :3 0 fa :3 0
2541 2542 0 15
:3 0 15c :2 0 173
:3 0 2544 2546 0
14c3 2545 2548 :3 0
2549 :2 0 db :3 0
dc :3 0 254b 254c
0 db :3 0 ec
:3 0 254e 254f 0
1e :2 0 2 :4 0
252 :2 0 ee :2 0
33 :2 0 14c6 2554
2556 :3 0 14c9 2550
2558 254d 255a 2559
:2 0 de :3 0 ef
:3 0 255c 255d 0
e0 :4 0 253 :4 0
e3 :2 0 e4 :3 0
14cd 2561 2563 :3 0
e3 :2 0 103 :4 0
14d0 2565 2567 :3 0
e3 :2 0 10b :4 0
14d3 2569 256b :3 0
e3 :2 0 e8 :3 0
e9 :3 0 1a :3 0
1d5 :3 0 2570 2571
0 14d6 256f 2573
ea :4 0 14d8 256e
2576 14db 256d 2578
:3 0 e3 :2 0 10d
:4 0 14de 257a 257c
:3 0 e3 :2 0 e6
:4 0 14e1 257e 2580
:3 0 e3 :2 0 23
:3 0 14e4 2582 2584
:3 0 e3 :2 0 e6
:4 0 14e7 2586 2588
:3 0 14ea 255e 258a
:2 0 258c 14ed 258d
255b 258c 0 258e
14ef 0 25b8 db
:3 0 dc :3 0 258f
2590 0 db :3 0
ec :3 0 2592 2593
0 33 :2 0 2
:4 0 254 :2 0 ee
:2 0 33 :2 0 14f1
2598 259a :3 0 14f4
2594 259c 2591 259e
259d :2 0 de :3 0
ef :3 0 25a0 25a1
0 e0 :4 0 255
:4 0 e3 :2 0 e4
:3 0 14f8 25a5 25a7
:3 0 14fb 25a2 25a9
:2 0 25ab 14fe 25ac
259f 25ab 0 25ad
1500 0 25b8 110
:3 0 111 :3 0 25ae
25af 0 1a :3 0
1d5 :3 0 25b1 25b2
0 23 :3 0 112
:3 0 1502 25b0 25b6
:2 0 25b8 1506 25b9
254a 25b8 0 25ba
150a 0 25bb 150c
25bd 216a 21d9 0
25be 0 25bb 0
25be 150f 0 2772
a8 :3 0 be :3 0
6e :3 0 65 :3 0
7f :3 0 bf :3 0
6e :3 0 68 :3 0
80 :3 0 c0 :3 0
6d :3 0 67 :3 0
81 :3 0 c1 :3 0
6d :3 0 69 :3 0
82 :3 0 256 :3 0
b5 :3 0 6e :3 0
65 :3 0 7f :3 0
257 :3 0 b5 :3 0
6e :3 0 67 :3 0
81 :3 0 258 :3 0
1b1 :3 0 1b2 :3 0
258 :3 0 1a :3 0
259 :3 0 25a :3 0
1b1 :3 0 1b2 :3 0
25a :3 0 1a :3 0
25b :3 0 b2 :3 0
26 :4 0 25c 1
:8 0 25fe f9 :4 0
25e9 :3 0 112 :3 0
f3 :2 0 1515 25ec
25ed :3 0 15 :3 0
fa :3 0 25ef 25f0
0 48 :2 0 25f1
25f2 0 25f4 1518
25fb 15 :3 0 fa
:3 0 25f5 25f6 0
fb :2 0 25f7 25f8
0 25fa 151a 25fc
25ee 25f4 0 25fd
0 25fa 0 25fd
151c 0 25fe 151f
2651 fe :3 0 15
:3 0 fa :3 0 2600
2601 0 fd :3 0
2602 2603 0 2605
1522 2607 1524 2606
2605 :2 0 264f ff
:3 0 15 :3 0 fa
:3 0 260a 260b 0
fd :3 0 260c 260d
0 2647 db :3 0
dc :3 0 260f 2610
0 db :3 0 ec
:3 0 2612 2613 0
100 :2 0 2 :4 0
25d :2 0 ee :2 0
33 :2 0 1526 2618
261a :3 0 1529 2614
261c 2611 261e 261d
:2 0 de :3 0 ef
:3 0 2620 2621 0
e0 :4 0 25e :4 0
e3 :2 0 e4 :3 0
152d 2625 2627 :3 0
e3 :2 0 103 :4 0
1530 2629 262b :3 0
e3 :2 0 104 :4 0
1533 262d 262f :3 0
e3 :2 0 fd :3 0
1536 2631 2633 :3 0
e3 :2 0 105 :4 0
1539 2635 2637 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 153c 263a
263e 1540 2639 2640
:3 0 1543 2622 2642
:2 0 2644 1546 2645
261f 2644 0 2646
1548 0 2647 154a
264a :3 0 264a 0
264a 2649 2647 2648
:6 0 264c 61 :3 0
154d 264e 154f 264d
264c :2 0 264f 1551
:2 0 2651 0 2651
2650 25fe 264f :6 0
2772 1 :3 0 e8
:3 0 89 :3 0 48
:2 0 1554 2653 2656
e8 :3 0 124 :2 0
4b :3 0 48 :2 0
1557 2658 265c 155c
2659 265e :3 0 78
:3 0 25f :3 0 8e
:3 0 3c :3 0 3d
:3 0 26 :3 0 2d
:3 0 2f :3 0 2b
:3 0 e8 :3 0 5b
:3 0 48 :2 0 155f
2669 266c e8 :3 0
4b :3 0 48 :2 0
1562 266e 2671 33
:2 0 e8 :3 0 8f
:3 0 48 :2 0 1565
2674 2677 1568 2661
2679 2660 267a 0
267c 1574 276f 1db
:3 0 a9 :3 0 2b
:3 0 b2 :3 0 8e
:4 0 260 1 :8 0
2698 f9 :4 0 2683
:3 0 112 :3 0 f3
:2 0 1578 2686 2687
:3 0 15 :3 0 fa
:3 0 2689 268a 0
48 :2 0 268b 268c
0 268e 157b 2695
15 :3 0 fa :3 0
268f 2690 0 fb
:2 0 2691 2692 0
2694 157d 2696 2688
268e 0 2697 0
2694 0 2697 157f
0 2698 1582 26eb
fe :3 0 15 :3 0
fa :3 0 269a 269b
0 fd :3 0 269c
269d 0 269f 1585
26a1 1587 26a0 269f
:2 0 26e9 ff :3 0
15 :3 0 fa :3 0
26a4 26a5 0 fd
:3 0 26a6 26a7 0
26e1 db :3 0 dc
:3 0 26a9 26aa 0
db :3 0 ec :3 0
26ac 26ad 0 100
:2 0 2 :4 0 261
:2 0 ee :2 0 33
:2 0 1589 26b2 26b4
:3 0 158c 26ae 26b6
26ab 26b8 26b7 :2 0
de :3 0 ef :3 0
26ba 26bb 0 e0
:4 0 262 :4 0 e3
:2 0 e4 :3 0 1590
26bf 26c1 :3 0 e3
:2 0 103 :4 0 1593
26c3 26c5 :3 0 e3
:2 0 104 :4 0 1596
26c7 26c9 :3 0 e3
:2 0 fd :3 0 1599
26cb 26cd :3 0 e3
:2 0 105 :4 0 159c
26cf 26d1 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 159f 26d4 26d8
15a3 26d3 26da :3 0
15a6 26bc 26dc :2 0
26de 15a9 26df 26b9
26de 0 26e0 15ab
0 26e1 15ad 26e4
:3 0 26e4 0 26e4
26e3 26e1 26e2 :6 0
26e6 63 :3 0 15b0
26e8 15b2 26e7 26e6
:2 0 26e9 15b4 :2 0
26eb 0 26eb 26ea
2698 26e9 :6 0 276e
1 :3 0 a8 :3 0
263 :3 0 2d :3 0
264 :3 0 2d :3 0
265 :3 0 266 :3 0
267 :3 0 268 :3 0
269 :3 0 b7 :3 0
b8 :3 0 bb :3 0
b5 :3 0 26a :3 0
26b :3 0 26c :3 0
1e5 :3 0 116 :3 0
26d :3 0 b2 :3 0
8e :4 0 26e 1
:8 0 2719 f9 :4 0
2704 :3 0 112 :3 0
f3 :2 0 15b9 2707
2708 :3 0 15 :3 0
fa :3 0 270a 270b
0 48 :2 0 270c
270d 0 270f 15bc
2716 15 :3 0 fa
:3 0 2710 2711 0
fb :2 0 2712 2713
0 2715 15be 2717
2709 270f 0 2718
0 2715 0 2718
15c0 0 2719 15c3
276c fe :3 0 15
:3 0 fa :3 0 271b
271c 0 fd :3 0
271d 271e 0 2720
15c6 2722 15c8 2721
2720 :2 0 276a ff
:3 0 15 :3 0 fa
:3 0 2725 2726 0
fd :3 0 2727 2728
0 2762 db :3 0
dc :3 0 272a 272b
0 db :3 0 ec
:3 0 272d 272e 0
100 :2 0 2 :4 0
26f :2 0 ee :2 0
33 :2 0 15ca 2733
2735 :3 0 15cd 272f
2737 272c 2739 2738
:2 0 de :3 0 ef
:3 0 273b 273c 0
e0 :4 0 270 :4 0
e3 :2 0 e4 :3 0
15d1 2740 2742 :3 0
e3 :2 0 103 :4 0
15d4 2744 2746 :3 0
e3 :2 0 104 :4 0
15d7 2748 274a :3 0
e3 :2 0 fd :3 0
15da 274c 274e :3 0
e3 :2 0 105 :4 0
15dd 2750 2752 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 15e0 2755
2759 15e4 2754 275b
:3 0 15e7 273d 275d
:2 0 275f 15ea 2760
273a 275f 0 2761
15ec 0 2762 15ee
2765 :3 0 2765 0
2765 2764 2762 2763
:6 0 2767 65 :3 0
15f1 2769 15f3 2768
2767 :2 0 276a 15f5
:2 0 276c 0 276c
276b 2719 276a :6 0
276e 1 :3 0 15f8
2770 265f 267c 0
2771 0 276e 0
2771 15fb 0 2772
15fe 2773 1bec 2772
0 2774 1610 0
2775 1612 2777 1a37
1b84 0 2778 0
2775 0 2778 1617
0 2779 161a 277a
18ec 2779 0 277b
1620 0 277c 1622
277d 18e7 277c 0
277e 1624 0 6d23
26 :3 0 239 :2 0
1626 2780 2781 :3 0
2782 :2 0 2783 :2 0
e8 :3 0 58 :3 0
48 :2 0 1628 2785
2788 124 :2 0 48
:2 0 162d 278a 278c
:3 0 278d :2 0 2784
278f 278e :2 0 e8
:3 0 6f :3 0 48
:2 0 1630 2791 2794
f3 :2 0 48 :2 0
1635 2796 2798 :3 0
2799 :2 0 2790 279b
279a :2 0 9a :3 0
33 :2 0 279d 279e
0 2a7f 3e :3 0
7 :3 0 27a0 27a1
0 2a7f 3f :3 0
3e :3 0 27a3 27a4
0 2a7f 26 :3 0
f7 :4 0 27a6 27a7
0 2a7f 26 :3 0
184 :4 0 27aa 27ab
:3 0 27a9 27ac 0
2a7f e8 :3 0 e
:3 0 48 :2 0 1638
27ae 27b1 f3 :2 0
fb :2 0 163d 27b3
27b5 :3 0 8b :3 0
e8 :3 0 50 :3 0
48 :2 0 1640 27b8
27bb 27b7 27bc 0
27be 1643 27bf 27b6
27be 0 27c0 1645
0 2a7f e8 :3 0
6e :3 0 48 :2 0
1647 27c1 27c4 f3
:2 0 48 :2 0 164c
27c6 27c8 :3 0 27c9
:2 0 e8 :3 0 6d
:3 0 48 :2 0 164f
27cb 27ce f3 :2 0
48 :2 0 1654 27d0
27d2 :3 0 27d3 :2 0
27ca 27d5 27d4 :2 0
e8 :3 0 6e :3 0
48 :2 0 1657 27d7
27da f3 :2 0 48
:2 0 165c 27dc 27de
:3 0 27df :2 0 e8
:3 0 6d :3 0 48
:2 0 165f 27e1 27e4
f3 :2 0 48 :2 0
1664 27e6 27e8 :3 0
27e9 :2 0 27e0 27eb
27ea :2 0 a8 :3 0
b2 :3 0 b0 :3 0
b3 :3 0 a9 :3 0
271 :3 0 272 :3 0
263 :3 0 264 :3 0
b7 :3 0 b8 :3 0
194 :3 0 273 :3 0
274 :3 0 aa :3 0
ab :3 0 ac :3 0
bc :3 0 bd :3 0
be :3 0 bf :3 0
c0 :3 0 c1 :3 0
114 :3 0 115 :3 0
18e :3 0 26 :3 0
23 :3 0 2b :3 0
2b :3 0 1a :3 0
275 :3 0 1a :3 0
276 :3 0 3e :3 0
3f :3 0 3e :3 0
3f :3 0 3e :3 0
3f :3 0 2a :3 0
39 :3 0 26 :3 0
85 :3 0 86 :3 0
65 :3 0 68 :3 0
67 :3 0 69 :3 0
8c :3 0 8d :3 0
88 :4 0 277 1
:8 0 2837 f9 :4 0
2822 :3 0 112 :3 0
f3 :2 0 1669 2825
2826 :3 0 15 :3 0
fa :3 0 2828 2829
0 48 :2 0 282a
282b 0 282d 166c
2834 15 :3 0 fa
:3 0 282e 282f 0
fb :2 0 2830 2831
0 2833 166e 2835
2827 282d 0 2836
0 2833 0 2836
1670 0 2837 1673
288a fe :3 0 15
:3 0 fa :3 0 2839
283a 0 fd :3 0
283b 283c 0 283e
1676 2840 1678 283f
283e :2 0 2888 ff
:3 0 15 :3 0 fa
:3 0 2843 2844 0
fd :3 0 2845 2846
0 2880 db :3 0
dc :3 0 2848 2849
0 db :3 0 ec
:3 0 284b 284c 0
100 :2 0 2 :4 0
278 :2 0 ee :2 0
33 :2 0 167a 2851
2853 :3 0 167d 284d
2855 284a 2857 2856
:2 0 de :3 0 ef
:3 0 2859 285a 0
e0 :4 0 279 :4 0
e3 :2 0 e4 :3 0
1681 285e 2860 :3 0
e3 :2 0 103 :4 0
1684 2862 2864 :3 0
e3 :2 0 104 :4 0
1687 2866 2868 :3 0
e3 :2 0 fd :3 0
168a 286a 286c :3 0
e3 :2 0 105 :4 0
168d 286e 2870 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 1690 2873
2877 1694 2872 2879
:3 0 1697 285b 287b
:2 0 287d 169a 287e
2858 287d 0 287f
169c 0 2880 169e
2883 :3 0 2883 0
2883 2882 2880 2881
:6 0 2885 67 :3 0
16a1 2887 16a3 2886
2885 :2 0 2888 16a5
:2 0 288a 0 288a
2889 2837 2888 :6 0
288d 1 :3 0 16a
:3 0 16a8 29d8 e8
:3 0 6d :3 0 48
:2 0 16aa 288e 2891
f3 :2 0 48 :2 0
16af 2893 2895 :3 0
a8 :3 0 b2 :3 0
b0 :3 0 b3 :3 0
a9 :3 0 271 :3 0
272 :3 0 263 :3 0
264 :3 0 b7 :3 0
b8 :3 0 194 :3 0
273 :3 0 274 :3 0
aa :3 0 ab :3 0
ac :3 0 bc :3 0
bd :3 0 be :3 0
bf :3 0 c0 :3 0
c1 :3 0 114 :3 0
115 :3 0 18e :3 0
26 :3 0 23 :3 0
2b :3 0 2b :3 0
1a :3 0 275 :3 0
1a :3 0 276 :3 0
3e :3 0 3f :3 0
3e :3 0 3f :3 0
3e :3 0 3f :3 0
2a :3 0 39 :3 0
26 :3 0 85 :3 0
86 :3 0 65 :3 0
68 :3 0 67 :3 0
69 :3 0 8c :3 0
8d :3 0 88 :4 0
27a 1 :8 0 28e1
f9 :4 0 28cc :3 0
112 :3 0 f3 :2 0
16b4 28cf 28d0 :3 0
15 :3 0 fa :3 0
28d2 28d3 0 48
:2 0 28d4 28d5 0
28d7 16b7 28de 15
:3 0 fa :3 0 28d8
28d9 0 fb :2 0
28da 28db 0 28dd
16b9 28df 28d1 28d7
0 28e0 0 28dd
0 28e0 16bb 0
28e1 16be 2934 fe
:3 0 15 :3 0 fa
:3 0 28e3 28e4 0
fd :3 0 28e5 28e6
0 28e8 16c1 28ea
16c3 28e9 28e8 :2 0
2932 ff :3 0 15
:3 0 fa :3 0 28ed
28ee 0 fd :3 0
28ef 28f0 0 292a
db :3 0 dc :3 0
28f2 28f3 0 db
:3 0 ec :3 0 28f5
28f6 0 100 :2 0
2 :4 0 27b :2 0
ee :2 0 33 :2 0
16c5 28fb 28fd :3 0
16c8 28f7 28ff 28f4
2901 2900 :2 0 de
:3 0 ef :3 0 2903
2904 0 e0 :4 0
27c :4 0 e3 :2 0
e4 :3 0 16cc 2908
290a :3 0 e3 :2 0
103 :4 0 16cf 290c
290e :3 0 e3 :2 0
104 :4 0 16d2 2910
2912 :3 0 e3 :2 0
fd :3 0 16d5 2914
2916 :3 0 e3 :2 0
105 :4 0 16d8 2918
291a :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
16db 291d 2921 16df
291c 2923 :3 0 16e2
2905 2925 :2 0 2927
16e5 2928 2902 2927
0 2929 16e7 0
292a 16e9 292d :3 0
292d 0 292d 292c
292a 292b :6 0 292f
69 :3 0 16ec 2931
16ee 2930 292f :2 0
2932 16f0 :2 0 2934
0 2934 2933 28e1
2932 :6 0 2936 1
:3 0 16f3 2937 2896
2936 0 29da a8
:3 0 b2 :3 0 b0
:3 0 b3 :3 0 a9
:3 0 271 :3 0 272
:3 0 263 :3 0 264
:3 0 b7 :3 0 b8
:3 0 194 :3 0 273
:3 0 274 :3 0 aa
:3 0 ab :3 0 ac
:3 0 bc :3 0 bd
:3 0 be :3 0 bf
:3 0 c0 :3 0 c1
:3 0 114 :3 0 115
:3 0 18e :3 0 26
:3 0 23 :3 0 2b
:3 0 2b :3 0 1a
:3 0 275 :3 0 1a
:3 0 276 :3 0 3e
:3 0 3f :3 0 3e
:3 0 3f :3 0 3e
:3 0 3f :3 0 2a
:3 0 39 :3 0 26
:3 0 85 :3 0 86
:3 0 65 :3 0 68
:3 0 67 :3 0 69
:3 0 8c :3 0 8d
:3 0 88 :4 0 27a
1 :8 0 2982 f9
:4 0 296d :3 0 112
:3 0 f3 :2 0 16f7
2970 2971 :3 0 15
:3 0 fa :3 0 2973
2974 0 48 :2 0
2975 2976 0 2978
16fa 297f 15 :3 0
fa :3 0 2979 297a
0 fb :2 0 297b
297c 0 297e 16fc
2980 2972 2978 0
2981 0 297e 0
2981 16fe 0 2982
1701 29d5 fe :3 0
15 :3 0 fa :3 0
2984 2985 0 fd
:3 0 2986 2987 0
2989 1704 298b 1706
298a 2989 :2 0 29d3
ff :3 0 15 :3 0
fa :3 0 298e 298f
0 fd :3 0 2990
2991 0 29cb db
:3 0 dc :3 0 2993
2994 0 db :3 0
ec :3 0 2996 2997
0 100 :2 0 2
:4 0 27d :2 0 ee
:2 0 33 :2 0 1708
299c 299e :3 0 170b
2998 29a0 2995 29a2
29a1 :2 0 de :3 0
ef :3 0 29a4 29a5
0 e0 :4 0 27e
:4 0 e3 :2 0 e4
:3 0 170f 29a9 29ab
:3 0 e3 :2 0 103
:4 0 1712 29ad 29af
:3 0 e3 :2 0 104
:4 0 1715 29b1 29b3
:3 0 e3 :2 0 fd
:3 0 1718 29b5 29b7
:3 0 e3 :2 0 105
:4 0 171b 29b9 29bb
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 171e
29be 29c2 1722 29bd
29c4 :3 0 1725 29a6
29c6 :2 0 29c8 1728
29c9 29a3 29c8 0
29ca 172a 0 29cb
172c 29ce :3 0 29ce
0 29ce 29cd 29cb
29cc :6 0 29d0 6b
:3 0 172f 29d2 1731
29d1 29d0 :2 0 29d3
1733 :2 0 29d5 0
29d5 29d4 2982 29d3
:6 0 29d7 1 :3 0
1736 29d9 27ec 288d
0 29da 0 29d7
0 29da 1738 0
29db 173c 2a7c a8
:3 0 b2 :3 0 b0
:3 0 b3 :3 0 a9
:3 0 271 :3 0 272
:3 0 263 :3 0 264
:3 0 b7 :3 0 b8
:3 0 194 :3 0 273
:3 0 274 :3 0 aa
:3 0 ab :3 0 ac
:3 0 bc :3 0 bd
:3 0 be :3 0 bf
:3 0 c0 :3 0 c1
:3 0 114 :3 0 115
:3 0 18e :3 0 26
:3 0 23 :3 0 2b
:3 0 2b :3 0 1a
:3 0 275 :3 0 1a
:3 0 276 :3 0 3e
:3 0 3f :3 0 3e
:3 0 3f :3 0 3e
:3 0 3f :3 0 2a
:3 0 39 :3 0 26
:3 0 85 :3 0 86
:3 0 65 :3 0 68
:3 0 67 :3 0 69
:3 0 8c :3 0 8d
:3 0 88 :4 0 27f
1 :8 0 2a26 f9
:4 0 2a11 :3 0 112
:3 0 f3 :2 0 1740
2a14 2a15 :3 0 15
:3 0 fa :3 0 2a17
2a18 0 48 :2 0
2a19 2a1a 0 2a1c
1743 2a23 15 :3 0
fa :3 0 2a1d 2a1e
0 fb :2 0 2a1f
2a20 0 2a22 1745
2a24 2a16 2a1c 0
2a25 0 2a22 0
2a25 1747 0 2a26
174a 2a79 fe :3 0
15 :3 0 fa :3 0
2a28 2a29 0 fd
:3 0 2a2a 2a2b 0
2a2d 174d 2a2f 174f
2a2e 2a2d :2 0 2a77
ff :3 0 15 :3 0
fa :3 0 2a32 2a33
0 fd :3 0 2a34
2a35 0 2a6f db
:3 0 dc :3 0 2a37
2a38 0 db :3 0
ec :3 0 2a3a 2a3b
0 100 :2 0 2
:4 0 280 :2 0 ee
:2 0 33 :2 0 1751
2a40 2a42 :3 0 1754
2a3c 2a44 2a39 2a46
2a45 :2 0 de :3 0
ef :3 0 2a48 2a49
0 e0 :4 0 281
:4 0 e3 :2 0 e4
:3 0 1758 2a4d 2a4f
:3 0 e3 :2 0 103
:4 0 175b 2a51 2a53
:3 0 e3 :2 0 104
:4 0 175e 2a55 2a57
:3 0 e3 :2 0 fd
:3 0 1761 2a59 2a5b
:3 0 e3 :2 0 105
:4 0 1764 2a5d 2a5f
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 1767
2a62 2a66 176b 2a61
2a68 :3 0 176e 2a4a
2a6a :2 0 2a6c 1771
2a6d 2a47 2a6c 0
2a6e 1773 0 2a6f
1775 2a72 :3 0 2a72
0 2a72 2a71 2a6f
2a70 :6 0 2a74 6d
:3 0 1778 2a76 177a
2a75 2a74 :2 0 2a77
177c :2 0 2a79 0
2a79 2a78 2a26 2a77
:6 0 2a7b 1 :3 0
177f 2a7d 27d6 29db
0 2a7e 0 2a7b
0 2a7e 1781 0
2a7f 1784 2a80 279c
2a7f 0 2a81 178c
0 6d23 3a :3 0
106 :3 0 3a :3 0
e3 :2 0 282 :4 0
178e 2a85 2a87 :3 0
33 :2 0 3b :2 0
1791 2a83 2a8b 2a82
2a8c 0 6d23 24
:3 0 f7 :4 0 2a8e
2a8f 0 6d23 4b
:3 0 9 :3 0 2a91
2a92 0 6d23 7f
:3 0 22b :2 0 2a94
2a95 0 6d23 81
:3 0 22b :2 0 2a97
2a98 0 6d23 4f
:3 0 48 :2 0 2a9a
2a9b 0 6d23 2d
:3 0 3c :3 0 2a9d
2a9e 0 6d23 91
:3 0 48 :2 0 2aa0
2aa1 0 6d23 90
:4 0 2aa3 2aa4 0
6d23 f8 :3 0 ae
:4 0 2aa9 :2 0 6d23
2aa7 2aaa :3 0 283
:3 0 ae :3 0 22
:3 0 24 :3 0 29
:3 0 4d :3 0 89
:3 0 8b :3 0 2d
:3 0 3c :3 0 3d
:3 0 8a :3 0 55
:3 0 28 :3 0 85
:3 0 86 :3 0 7f
:3 0 80 :3 0 81
:3 0 82 :3 0 50
:3 0 52 :3 0 53
:3 0 54 :3 0 5a
:4 0 2ac5 :2 0 6083
2aac 2ac6 :3 0 1795
:3 0 ae :3 0 f9
:3 0 2ac7 2ac8 :3 0
15 :3 0 fa :3 0
2aca 2acb 0 48
:2 0 2acc 2acd 0
2acf 17ad 2ad6 15
:3 0 fa :3 0 2ad0
2ad1 0 fb :2 0
2ad2 2ad3 0 2ad5
17af 2ad7 2ac9 2acf
0 2ad8 0 2ad5
0 2ad8 17b1 0
6083 15 :3 0 fa
:3 0 2ad9 2ada 0
15 :3 0 15c :2 0
173 :3 0 2adc 2ade
0 17b6 2add 2ae0
:3 0 2ae1 :2 0 284
:8 0 2ae5 17b9 2ae6
2ae2 2ae5 0 2ae7
17bb 0 6083 56
:3 0 48 :2 0 2ae8
2ae9 0 6083 1cf
:3 0 106 :3 0 3c
:3 0 37 :3 0 15d
:4 0 285 1 :8 0
2af6 15 :3 0 fa
:3 0 2af1 2af2 0
fd :3 0 2af3 2af4
0 2af6 17bd 2b49
fe :3 0 15 :3 0
fa :3 0 2af8 2af9
0 fd :3 0 2afa
2afb 0 2afd 17c0
2aff 17c2 2afe 2afd
:2 0 2b47 ff :3 0
15 :3 0 fa :3 0
2b02 2b03 0 fd
:3 0 2b04 2b05 0
2b3f db :3 0 dc
:3 0 2b07 2b08 0
db :3 0 ec :3 0
2b0a 2b0b 0 100
:2 0 2 :4 0 286
:2 0 ee :2 0 33
:2 0 17c4 2b10 2b12
:3 0 17c7 2b0c 2b14
2b09 2b16 2b15 :2 0
de :3 0 ef :3 0
2b18 2b19 0 e0
:4 0 287 :4 0 e3
:2 0 e4 :3 0 17cb
2b1d 2b1f :3 0 e3
:2 0 103 :4 0 17ce
2b21 2b23 :3 0 e3
:2 0 104 :4 0 17d1
2b25 2b27 :3 0 e3
:2 0 fd :3 0 17d4
2b29 2b2b :3 0 e3
:2 0 105 :4 0 17d7
2b2d 2b2f :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 17da 2b32 2b36
17de 2b31 2b38 :3 0
17e1 2b1a 2b3a :2 0
2b3c 17e4 2b3d 2b17
2b3c 0 2b3e 17e6
0 2b3f 17e8 2b42
:3 0 2b42 0 2b42
2b41 2b3f 2b40 :6 0
2b44 70 :3 0 17eb
2b46 17ed 2b45 2b44
:2 0 2b47 17ef :2 0
2b49 0 2b49 2b48
2af6 2b47 :6 0 6083
6f :3 0 1cf :3 0
106 :3 0 3d :3 0
38 :3 0 15d :4 0
288 1 :8 0 2b56
15 :3 0 fa :3 0
2b51 2b52 0 fd
:3 0 2b53 2b54 0
2b56 17f2 2ba9 fe
:3 0 15 :3 0 fa
:3 0 2b58 2b59 0
fd :3 0 2b5a 2b5b
0 2b5d 17f5 2b5f
17f7 2b5e 2b5d :2 0
2ba7 ff :3 0 15
:3 0 fa :3 0 2b62
2b63 0 fd :3 0
2b64 2b65 0 2b9f
db :3 0 dc :3 0
2b67 2b68 0 db
:3 0 ec :3 0 2b6a
2b6b 0 100 :2 0
2 :4 0 289 :2 0
ee :2 0 33 :2 0
17f9 2b70 2b72 :3 0
17fc 2b6c 2b74 2b69
2b76 2b75 :2 0 de
:3 0 ef :3 0 2b78
2b79 0 e0 :4 0
28a :4 0 e3 :2 0
e4 :3 0 1800 2b7d
2b7f :3 0 e3 :2 0
103 :4 0 1803 2b81
2b83 :3 0 e3 :2 0
104 :4 0 1806 2b85
2b87 :3 0 e3 :2 0
fd :3 0 1809 2b89
2b8b :3 0 e3 :2 0
105 :4 0 180c 2b8d
2b8f :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
180f 2b92 2b96 1813
2b91 2b98 :3 0 1816
2b7a 2b9a :2 0 2b9c
1819 2b9d 2b77 2b9c
0 2b9e 181b 0
2b9f 181d 2ba2 :3 0
2ba2 0 2ba2 2ba1
2b9f 2ba0 :6 0 2ba4
72 :3 0 1820 2ba6
1822 2ba5 2ba4 :2 0
2ba7 1824 :2 0 2ba9
0 2ba9 2ba8 2b56
2ba7 :6 0 6083 6f
:3 0 95 :3 0 15c
:2 0 48 :2 0 1829
2bac 2bae :3 0 e8
:3 0 89 :3 0 48
:2 0 182c 2bb0 2bb3
124 :2 0 48 :2 0
1831 2bb5 2bb7 :3 0
9e :3 0 15 :3 0
fa :3 0 2bba 2bbb
0 2bb9 2bbc 0
4571 9c :3 0 1d9
:3 0 2b :3 0 29
:3 0 24 :3 0 1da
:2 0 33 :2 0 1834
2bc3 2bc5 :3 0 1836
2bbf 2bc7 2bbe 2bc8
0 4571 15 :3 0
fa :3 0 2bca 2bcb
0 9e :3 0 2bcc
2bcd 0 4571 b2
:3 0 194 :3 0 c2
:3 0 c4 :3 0 c5
:3 0 c6 :3 0 18e
:3 0 1cf :3 0 106
:3 0 1e5 :3 0 27
:3 0 32 :3 0 50
:3 0 53 :3 0 54
:3 0 5a :3 0 88
:3 0 38 :3 0 a8
:3 0 a9 :3 0 2b
:3 0 b3 :3 0 29
:3 0 aa :3 0 2a
:3 0 ab :4 0 28b
1 :8 0 2bef 15
:3 0 fa :3 0 2bea
2beb 0 fd :3 0
2bec 2bed 0 2bef
183b 2c42 fe :3 0
15 :3 0 fa :3 0
2bf1 2bf2 0 fd
:3 0 2bf3 2bf4 0
2bf6 183e 2bf8 1840
2bf7 2bf6 :2 0 2c40
ff :3 0 15 :3 0
fa :3 0 2bfb 2bfc
0 fd :3 0 2bfd
2bfe 0 2c38 db
:3 0 dc :3 0 2c00
2c01 0 db :3 0
ec :3 0 2c03 2c04
0 100 :2 0 2
:4 0 28c :2 0 ee
:2 0 33 :2 0 1842
2c09 2c0b :3 0 1845
2c05 2c0d 2c02 2c0f
2c0e :2 0 de :3 0
ef :3 0 2c11 2c12
0 e0 :4 0 28d
:4 0 e3 :2 0 e4
:3 0 1849 2c16 2c18
:3 0 e3 :2 0 103
:4 0 184c 2c1a 2c1c
:3 0 e3 :2 0 104
:4 0 184f 2c1e 2c20
:3 0 e3 :2 0 fd
:3 0 1852 2c22 2c24
:3 0 e3 :2 0 105
:4 0 1855 2c26 2c28
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 1858
2c2b 2c2f 185c 2c2a
2c31 :3 0 185f 2c13
2c33 :2 0 2c35 1862
2c36 2c10 2c35 0
2c37 1864 0 2c38
1866 2c3b :3 0 2c3b
0 2c3b 2c3a 2c38
2c39 :6 0 2c3d 74
:3 0 1869 2c3f 186b
2c3e 2c3d :2 0 2c40
186d :2 0 2c42 0
2c42 2c41 2bef 2c40
:6 0 4571 6f :3 0
15 :3 0 fa :3 0
2c44 2c45 0 15
:3 0 f3 :2 0 11a
:3 0 2c47 2c49 0
1872 2c48 2c4b :3 0
2c4c :2 0 73 :3 0
48 :2 0 2c4e 2c4f
0 32ed 25 :3 0
f7 :4 0 2c51 2c52
0 32ed b0 :3 0
180 :3 0 185 :3 0
1f :3 0 49 :3 0
20 :3 0 c8 :3 0
a4 :3 0 29 :3 0
aa :3 0 2a :3 0
ab :4 0 28e 1
:8 0 2c66 15 :3 0
fa :3 0 2c61 2c62
0 fd :3 0 2c63
2c64 0 2c66 1875
2cb9 fe :3 0 15
:3 0 fa :3 0 2c68
2c69 0 fd :3 0
2c6a 2c6b 0 2c6d
1878 2c6f 187a 2c6e
2c6d :2 0 2cb7 ff
:3 0 15 :3 0 fa
:3 0 2c72 2c73 0
fd :3 0 2c74 2c75
0 2caf db :3 0
dc :3 0 2c77 2c78
0 db :3 0 ec
:3 0 2c7a 2c7b 0
100 :2 0 2 :4 0
28f :2 0 ee :2 0
33 :2 0 187c 2c80
2c82 :3 0 187f 2c7c
2c84 2c79 2c86 2c85
:2 0 de :3 0 ef
:3 0 2c88 2c89 0
e0 :4 0 290 :4 0
e3 :2 0 e4 :3 0
1883 2c8d 2c8f :3 0
e3 :2 0 103 :4 0
1886 2c91 2c93 :3 0
e3 :2 0 104 :4 0
1889 2c95 2c97 :3 0
e3 :2 0 fd :3 0
188c 2c99 2c9b :3 0
e3 :2 0 105 :4 0
188f 2c9d 2c9f :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 1892 2ca2
2ca6 1896 2ca1 2ca8
:3 0 1899 2c8a 2caa
:2 0 2cac 189c 2cad
2c87 2cac 0 2cae
189e 0 2caf 18a0
2cb2 :3 0 2cb2 0
2cb2 2cb1 2caf 2cb0
:6 0 2cb4 76 :3 0
18a3 2cb6 18a5 2cb5
2cb4 :2 0 2cb7 18a7
:2 0 2cb9 0 2cb9
2cb8 2c66 2cb7 :6 0
32ed 6f :3 0 15
:3 0 fa :3 0 2cbb
2cbc 0 15 :3 0
f3 :2 0 11a :3 0
2cbe 2cc0 0 18ac
2cbf 2cc2 :3 0 2cc3
:2 0 205 :3 0 b0
:3 0 205 :3 0 aa
:3 0 106 :3 0 12a
:3 0 198 :3 0 19d
:3 0 12a :3 0 198
:3 0 1f :3 0 1d
:3 0 43 :3 0 c7
:3 0 12a :3 0 c8
:3 0 205 :3 0 12a
:3 0 a4 :3 0 29
:3 0 12a :3 0 a4
:3 0 205 :3 0 a4
:3 0 205 :3 0 180
:3 0 205 :3 0 aa
:3 0 12a :3 0 291
:3 0 b2 :3 0 a8
:3 0 206 :3 0 206
:3 0 b0 :3 0 205
:3 0 b0 :4 0 292
1 :8 0 2cf0 15
:3 0 fa :3 0 2ceb
2cec 0 fd :3 0
2ced 2cee 0 2cf0
18af 2d43 fe :3 0
15 :3 0 fa :3 0
2cf2 2cf3 0 fd
:3 0 2cf4 2cf5 0
2cf7 18b2 2cf9 18b4
2cf8 2cf7 :2 0 2d41
ff :3 0 15 :3 0
fa :3 0 2cfc 2cfd
0 fd :3 0 2cfe
2cff 0 2d39 db
:3 0 dc :3 0 2d01
2d02 0 db :3 0
ec :3 0 2d04 2d05
0 100 :2 0 2
:4 0 293 :2 0 ee
:2 0 33 :2 0 18b6
2d0a 2d0c :3 0 18b9
2d06 2d0e 2d03 2d10
2d0f :2 0 de :3 0
ef :3 0 2d12 2d13
0 e0 :4 0 294
:4 0 e3 :2 0 e4
:3 0 18bd 2d17 2d19
:3 0 e3 :2 0 103
:4 0 18c0 2d1b 2d1d
:3 0 e3 :2 0 104
:4 0 18c3 2d1f 2d21
:3 0 e3 :2 0 fd
:3 0 18c6 2d23 2d25
:3 0 e3 :2 0 105
:4 0 18c9 2d27 2d29
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 18cc
2d2c 2d30 18d0 2d2b
2d32 :3 0 18d3 2d14
2d34 :2 0 2d36 18d6
2d37 2d11 2d36 0
2d38 18d8 0 2d39
18da 2d3c :3 0 2d3c
0 2d3c 2d3b 2d39
2d3a :6 0 2d3e 78
:3 0 18dd 2d40 18df
2d3f 2d3e :2 0 2d41
18e1 :2 0 2d43 0
2d43 2d42 2cf0 2d41
:6 0 3141 6f :3 0
15 :3 0 fa :3 0
2d45 2d46 0 15
:3 0 f3 :2 0 173
:3 0 2d48 2d4a 0
18e6 2d49 2d4c :3 0
2d4d :2 0 1f :3 0
1ce :2 0 18e9 2d50
2d51 :3 0 2d52 :2 0
2d4e 2d54 2d53 :2 0
7e :3 0 18a :3 0
48 :2 0 e8 :3 0
4d :3 0 48 :2 0
18eb 2d59 2d5c 1a
:3 0 295 :3 0 2d5e
2d5f 0 7b :3 0
18ee 2d57 2d62 2d56
2d63 0 2eef c8
:3 0 aa :3 0 2a
:3 0 ab :3 0 149
:3 0 2c :3 0 180
:3 0 185 :3 0 7b
:3 0 b0 :3 0 1f
:4 0 296 1 :8 0
2d86 f9 :4 0 2d71
:3 0 112 :3 0 f3
:2 0 18f5 2d74 2d75
:3 0 15 :3 0 fa
:3 0 2d77 2d78 0
48 :2 0 2d79 2d7a
0 2d7c 18f8 2d83
15 :3 0 fa :3 0
2d7d 2d7e 0 fb
:2 0 2d7f 2d80 0
2d82 18fa 2d84 2d76
2d7c 0 2d85 0
2d82 0 2d85 18fc
0 2d86 18ff 2dd9
fe :3 0 15 :3 0
fa :3 0 2d88 2d89
0 fd :3 0 2d8a
2d8b 0 2d8d 1902
2d8f 1904 2d8e 2d8d
:2 0 2dd7 ff :3 0
15 :3 0 fa :3 0
2d92 2d93 0 fd
:3 0 2d94 2d95 0
2dcf db :3 0 dc
:3 0 2d97 2d98 0
db :3 0 ec :3 0
2d9a 2d9b 0 100
:2 0 2 :4 0 297
:2 0 ee :2 0 33
:2 0 1906 2da0 2da2
:3 0 1909 2d9c 2da4
2d99 2da6 2da5 :2 0
de :3 0 ef :3 0
2da8 2da9 0 e0
:4 0 298 :4 0 e3
:2 0 e4 :3 0 190d
2dad 2daf :3 0 e3
:2 0 103 :4 0 1910
2db1 2db3 :3 0 e3
:2 0 104 :4 0 1913
2db5 2db7 :3 0 e3
:2 0 fd :3 0 1916
2db9 2dbb :3 0 e3
:2 0 105 :4 0 1919
2dbd 2dbf :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 191c 2dc2 2dc6
1920 2dc1 2dc8 :3 0
1923 2daa 2dca :2 0
2dcc 1926 2dcd 2da7
2dcc 0 2dce 1928
0 2dcf 192a 2dd2
:3 0 2dd2 0 2dd2
2dd1 2dcf 2dd0 :6 0
2dd4 7a :3 0 192d
2dd6 192f 2dd5 2dd4
:2 0 2dd7 1931 :2 0
2dd9 0 2dd9 2dd8
2d86 2dd7 :6 0 2eef
6f :3 0 79 :3 0
48 :4 0 2ddb 2ddc
0 2eef 7e :3 0
299 :3 0 2b :3 0
1d :3 0 79 :3 0
1934 2ddf 2de3 2dde
2de4 0 2eef 79
:3 0 48 :4 0 2de6
2de7 0 2eef 7e
:3 0 299 :3 0 2b
:3 0 2a :3 0 79
:3 0 1938 2dea 2dee
2de9 2def 0 2eef
c7 :3 0 198 :3 0
199 :3 0 198 :3 0
43 :3 0 41 :3 0
a4 :3 0 29 :4 0
29a 1 :8 0 2e0f
f9 :4 0 2dfa :3 0
112 :3 0 f3 :2 0
193e 2dfd 2dfe :3 0
15 :3 0 fa :3 0
2e00 2e01 0 48
:2 0 2e02 2e03 0
2e05 1941 2e0c 15
:3 0 fa :3 0 2e06
2e07 0 fb :2 0
2e08 2e09 0 2e0b
1943 2e0d 2dff 2e05
0 2e0e 0 2e0b
0 2e0e 1945 0
2e0f 1948 2e62 fe
:3 0 15 :3 0 fa
:3 0 2e11 2e12 0
fd :3 0 2e13 2e14
0 2e16 194b 2e18
194d 2e17 2e16 :2 0
2e60 ff :3 0 15
:3 0 fa :3 0 2e1b
2e1c 0 fd :3 0
2e1d 2e1e 0 2e58
db :3 0 dc :3 0
2e20 2e21 0 db
:3 0 ec :3 0 2e23
2e24 0 100 :2 0
2 :4 0 29b :2 0
ee :2 0 33 :2 0
194f 2e29 2e2b :3 0
1952 2e25 2e2d 2e22
2e2f 2e2e :2 0 de
:3 0 ef :3 0 2e31
2e32 0 e0 :4 0
29c :4 0 e3 :2 0
e4 :3 0 1956 2e36
2e38 :3 0 e3 :2 0
103 :4 0 1959 2e3a
2e3c :3 0 e3 :2 0
104 :4 0 195c 2e3e
2e40 :3 0 e3 :2 0
fd :3 0 195f 2e42
2e44 :3 0 e3 :2 0
105 :4 0 1962 2e46
2e48 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
1965 2e4b 2e4f 1969
2e4a 2e51 :3 0 196c
2e33 2e53 :2 0 2e55
196f 2e56 2e30 2e55
0 2e57 1971 0
2e58 1973 2e5b :3 0
2e5b 0 2e5b 2e5a
2e58 2e59 :6 0 2e5d
7c :3 0 1976 2e5f
1978 2e5e 2e5d :2 0
2e60 197a :2 0 2e62
0 2e62 2e61 2e0f
2e60 :6 0 2eef 6f
:3 0 e8 :3 0 8a
:3 0 48 :2 0 197d
2e64 2e67 1a :3 0
f3 :2 0 29d :3 0
2e69 2e6b 0 1982
2e6a 2e6d :3 0 c8
:3 0 b0 :3 0 22
:4 0 29e 1 :8 0
2e88 f9 :4 0 2e73
:3 0 112 :3 0 f3
:2 0 1987 2e76 2e77
:3 0 15 :3 0 fa
:3 0 2e79 2e7a 0
48 :2 0 2e7b 2e7c
0 2e7e 198a 2e85
15 :3 0 fa :3 0
2e7f 2e80 0 fb
:2 0 2e81 2e82 0
2e84 198c 2e86 2e78
2e7e 0 2e87 0
2e84 0 2e87 198e
0 2e88 1991 2edb
fe :3 0 15 :3 0
fa :3 0 2e8a 2e8b
0 fd :3 0 2e8c
2e8d 0 2e8f 1994
2e91 1996 2e90 2e8f
:2 0 2ed9 ff :3 0
15 :3 0 fa :3 0
2e94 2e95 0 fd
:3 0 2e96 2e97 0
2ed1 db :3 0 dc
:3 0 2e99 2e9a 0
db :3 0 ec :3 0
2e9c 2e9d 0 100
:2 0 2 :4 0 29f
:2 0 ee :2 0 33
:2 0 1998 2ea2 2ea4
:3 0 199b 2e9e 2ea6
2e9b 2ea8 2ea7 :2 0
de :3 0 ef :3 0
2eaa 2eab 0 e0
:4 0 2a0 :4 0 e3
:2 0 e4 :3 0 199f
2eaf 2eb1 :3 0 e3
:2 0 103 :4 0 19a2
2eb3 2eb5 :3 0 e3
:2 0 104 :4 0 19a5
2eb7 2eb9 :3 0 e3
:2 0 fd :3 0 19a8
2ebb 2ebd :3 0 e3
:2 0 105 :4 0 19ab
2ebf 2ec1 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 19ae 2ec4 2ec8
19b2 2ec3 2eca :3 0
19b5 2eac 2ecc :2 0
2ece 19b8 2ecf 2ea9
2ece 0 2ed0 19ba
0 2ed1 19bc 2ed4
:3 0 2ed4 0 2ed4
2ed3 2ed1 2ed2 :6 0
2ed6 7e :3 0 19bf
2ed8 19c1 2ed7 2ed6
:2 0 2ed9 19c3 :2 0
2edb 0 2edb 2eda
2e88 2ed9 :6 0 2eeb
6f :3 0 22 :3 0
1f :3 0 2edd 2ede
0 2eeb 79 :3 0
33 :4 0 2ee0 2ee1
0 2eeb 7e :3 0
299 :3 0 2b :3 0
2c :3 0 79 :3 0
19c6 2ee4 2ee8 2ee3
2ee9 0 2eeb 19ca
2eec 2e6e 2eeb 0
2eed 19cf 0 2eef
16a :3 0 19d1 313d
e8 :3 0 8a :3 0
48 :2 0 19da 2ef0
2ef3 1a :3 0 f3
:2 0 29d :3 0 2ef5
2ef7 0 19df 2ef6
2ef9 :3 0 7e :3 0
18a :3 0 48 :2 0
e8 :3 0 4d :3 0
48 :2 0 19e2 2efe
2f01 1a :3 0 18b
:3 0 2f03 2f04 0
7b :3 0 19e5 2efc
2f07 2efb 2f08 0
300b c8 :3 0 aa
:3 0 2a :3 0 ab
:3 0 149 :3 0 2c
:3 0 180 :3 0 1a
:3 0 1b6 :3 0 185
:3 0 7b :3 0 b0
:3 0 22 :4 0 2a1
1 :8 0 2f2d f9
:4 0 2f18 :3 0 112
:3 0 f3 :2 0 19ec
2f1b 2f1c :3 0 15
:3 0 fa :3 0 2f1e
2f1f 0 48 :2 0
2f20 2f21 0 2f23
19ef 2f2a 15 :3 0
fa :3 0 2f24 2f25
0 fb :2 0 2f26
2f27 0 2f29 19f1
2f2b 2f1d 2f23 0
2f2c 0 2f29 0
2f2c 19f3 0 2f2d
19f6 2f80 fe :3 0
15 :3 0 fa :3 0
2f2f 2f30 0 fd
:3 0 2f31 2f32 0
2f34 19f9 2f36 19fb
2f35 2f34 :2 0 2f7e
ff :3 0 15 :3 0
fa :3 0 2f39 2f3a
0 fd :3 0 2f3b
2f3c 0 2f76 db
:3 0 dc :3 0 2f3e
2f3f 0 db :3 0
ec :3 0 2f41 2f42
0 100 :2 0 2
:4 0 2a2 :2 0 ee
:2 0 33 :2 0 19fd
2f47 2f49 :3 0 1a00
2f43 2f4b 2f40 2f4d
2f4c :2 0 de :3 0
ef :3 0 2f4f 2f50
0 e0 :4 0 2a3
:4 0 e3 :2 0 e4
:3 0 1a04 2f54 2f56
:3 0 e3 :2 0 103
:4 0 1a07 2f58 2f5a
:3 0 e3 :2 0 104
:4 0 1a0a 2f5c 2f5e
:3 0 e3 :2 0 fd
:3 0 1a0d 2f60 2f62
:3 0 e3 :2 0 105
:4 0 1a10 2f64 2f66
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 1a13
2f69 2f6d 1a17 2f68
2f6f :3 0 1a1a 2f51
2f71 :2 0 2f73 1a1d
2f74 2f4e 2f73 0
2f75 1a1f 0 2f76
1a21 2f79 :3 0 2f79
0 2f79 2f78 2f76
2f77 :6 0 2f7b 80
:3 0 1a24 2f7d 1a26
2f7c 2f7b :2 0 2f7e
1a28 :2 0 2f80 0
2f80 2f7f 2f2d 2f7e
:6 0 300b 6f :3 0
79 :3 0 33 :4 0
2f82 2f83 0 300b
7e :3 0 299 :3 0
2b :3 0 2c :3 0
79 :3 0 1a2b 2f86
2f8a 2f85 2f8b 0
300b 79 :3 0 48
:4 0 2f8d 2f8e 0
300b 7e :3 0 299
:3 0 2b :3 0 2a
:3 0 79 :3 0 1a2f
2f91 2f95 2f90 2f96
0 300b c7 :3 0
198 :3 0 199 :3 0
198 :3 0 44 :3 0
41 :3 0 a4 :3 0
29 :4 0 2a4 1
:8 0 2fb6 f9 :4 0
2fa1 :3 0 112 :3 0
f3 :2 0 1a35 2fa4
2fa5 :3 0 15 :3 0
fa :3 0 2fa7 2fa8
0 48 :2 0 2fa9
2faa 0 2fac 1a38
2fb3 15 :3 0 fa
:3 0 2fad 2fae 0
fb :2 0 2faf 2fb0
0 2fb2 1a3a 2fb4
2fa6 2fac 0 2fb5
0 2fb2 0 2fb5
1a3c 0 2fb6 1a3f
3009 fe :3 0 15
:3 0 fa :3 0 2fb8
2fb9 0 fd :3 0
2fba 2fbb 0 2fbd
1a42 2fbf 1a44 2fbe
2fbd :2 0 3007 ff
:3 0 15 :3 0 fa
:3 0 2fc2 2fc3 0
fd :3 0 2fc4 2fc5
0 2fff db :3 0
dc :3 0 2fc7 2fc8
0 db :3 0 ec
:3 0 2fca 2fcb 0
100 :2 0 2 :4 0
2a5 :2 0 ee :2 0
33 :2 0 1a46 2fd0
2fd2 :3 0 1a49 2fcc
2fd4 2fc9 2fd6 2fd5
:2 0 de :3 0 ef
:3 0 2fd8 2fd9 0
e0 :4 0 2a6 :4 0
e3 :2 0 e4 :3 0
1a4d 2fdd 2fdf :3 0
e3 :2 0 103 :4 0
1a50 2fe1 2fe3 :3 0
e3 :2 0 104 :4 0
1a53 2fe5 2fe7 :3 0
e3 :2 0 fd :3 0
1a56 2fe9 2feb :3 0
e3 :2 0 105 :4 0
1a59 2fed 2fef :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 1a5c 2ff2
2ff6 1a60 2ff1 2ff8
:3 0 1a63 2fda 2ffa
:2 0 2ffc 1a66 2ffd
2fd7 2ffc 0 2ffe
1a68 0 2fff 1a6a
3002 :3 0 3002 0
3002 3001 2fff 3000
:6 0 3004 82 :3 0
1a6d 3006 1a6f 3005
3004 :2 0 3007 1a71
:2 0 3009 0 3009
3008 2fb6 3007 :6 0
300b 6f :3 0 1a74
300c 2efa 300b 0
313f c7 :3 0 198
:3 0 19e :3 0 41
:3 0 19e :3 0 198
:3 0 198 :3 0 198
:3 0 41 :3 0 a4
:3 0 29 :4 0 2a7
1 :8 0 302e f9
:4 0 3019 :3 0 112
:3 0 f3 :2 0 1a7e
301c 301d :3 0 15
:3 0 fa :3 0 301f
3020 0 48 :2 0
3021 3022 0 3024
1a81 302b 15 :3 0
fa :3 0 3025 3026
0 fb :2 0 3027
3028 0 302a 1a83
302c 301e 3024 0
302d 0 302a 0
302d 1a85 0 302e
1a88 3081 fe :3 0
15 :3 0 fa :3 0
3030 3031 0 fd
:3 0 3032 3033 0
3035 1a8b 3037 1a8d
3036 3035 :2 0 307f
ff :3 0 15 :3 0
fa :3 0 303a 303b
0 fd :3 0 303c
303d 0 3077 db
:3 0 dc :3 0 303f
3040 0 db :3 0
ec :3 0 3042 3043
0 100 :2 0 2
:4 0 2a8 :2 0 ee
:2 0 33 :2 0 1a8f
3048 304a :3 0 1a92
3044 304c 3041 304e
304d :2 0 de :3 0
ef :3 0 3050 3051
0 e0 :4 0 2a9
:4 0 e3 :2 0 e4
:3 0 1a96 3055 3057
:3 0 e3 :2 0 103
:4 0 1a99 3059 305b
:3 0 e3 :2 0 104
:4 0 1a9c 305d 305f
:3 0 e3 :2 0 fd
:3 0 1a9f 3061 3063
:3 0 e3 :2 0 105
:4 0 1aa2 3065 3067
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 1aa5
306a 306e 1aa9 3069
3070 :3 0 1aac 3052
3072 :2 0 3074 1aaf
3075 304f 3074 0
3076 1ab1 0 3077
1ab3 307a :3 0 307a
0 307a 3079 3077
3078 :6 0 307c 84
:3 0 1ab6 307e 1ab8
307d 307c :2 0 307f
1aba :2 0 3081 0
3081 3080 302e 307f
:6 0 313c 6f :3 0
7e :3 0 18a :3 0
48 :2 0 e8 :3 0
4d :3 0 48 :2 0
1abd 3086 3089 1a
:3 0 18b :3 0 308b
308c 0 7b :3 0
1ac0 3084 308f 3083
3090 0 313c 7a
:3 0 1a :3 0 1b6
:3 0 3093 3094 0
3092 3095 0 313c
79 :3 0 48 :4 0
3097 3098 0 313c
7d :3 0 48 :2 0
309a 309b 0 313c
7e :3 0 18c :3 0
2b :3 0 2a :3 0
4d :3 0 7a :3 0
7b :3 0 79 :3 0
7d :3 0 1ac5 309e
30a6 309d 30a7 0
313c 88 :3 0 18d
:3 0 e8 :3 0 4d
:3 0 48 :2 0 1acd
30ab 30ae 1ad0 30aa
30b0 30a9 30b1 0
313c 22 :3 0 184
:4 0 30b4 30b5 :3 0
30b3 30b6 0 313c
c8 :3 0 b0 :3 0
a9 :3 0 a4 :3 0
b4 :3 0 ab :3 0
aa :3 0 149 :3 0
180 :3 0 185 :3 0
18e :3 0 18f :3 0
190 :3 0 22 :3 0
2b :3 0 29 :3 0
4d :3 0 79 :3 0
2a :3 0 2c :3 0
7a :3 0 7b :3 0
88 :3 0 13 :3 0
e4 :4 0 2aa 1
:8 0 30e7 f9 :4 0
30d2 :3 0 112 :3 0
f3 :2 0 1ad4 30d5
30d6 :3 0 15 :3 0
fa :3 0 30d8 30d9
0 48 :2 0 30da
30db 0 30dd 1ad7
30e4 15 :3 0 fa
:3 0 30de 30df 0
fb :2 0 30e0 30e1
0 30e3 1ad9 30e5
30d7 30dd 0 30e6
0 30e3 0 30e6
1adb 0 30e7 1ade
313a fe :3 0 15
:3 0 fa :3 0 30e9
30ea 0 fd :3 0
30eb 30ec 0 30ee
1ae1 30f0 1ae3 30ef
30ee :2 0 3138 ff
:3 0 15 :3 0 fa
:3 0 30f3 30f4 0
fd :3 0 30f5 30f6
0 3130 db :3 0
dc :3 0 30f8 30f9
0 db :3 0 ec
:3 0 30fb 30fc 0
100 :2 0 2 :4 0
2ab :2 0 ee :2 0
33 :2 0 1ae5 3101
3103 :3 0 1ae8 30fd
3105 30fa 3107 3106
:2 0 de :3 0 ef
:3 0 3109 310a 0
e0 :4 0 2ac :4 0
e3 :2 0 e4 :3 0
1aec 310e 3110 :3 0
e3 :2 0 103 :4 0
1aef 3112 3114 :3 0
e3 :2 0 104 :4 0
1af2 3116 3118 :3 0
e3 :2 0 fd :3 0
1af5 311a 311c :3 0
e3 :2 0 105 :4 0
1af8 311e 3120 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 1afb 3123
3127 1aff 3122 3129
:3 0 1b02 310b 312b
:2 0 312d 1b05 312e
3108 312d 0 312f
1b07 0 3130 1b09
3133 :3 0 3133 0
3133 3132 3130 3131
:6 0 3135 86 :3 0
1b0c 3137 1b0e 3136
3135 :2 0 3138 1b10
:2 0 313a 0 313a
3139 30e7 3138 :6 0
313c 6f :3 0 1b13
313e 2d55 2eef 0
313f 0 313c 0
313f 1b1d 0 3141
16a :3 0 1b21 32eb
15 :3 0 fa :3 0
3142 3143 0 15
:3 0 f3 :2 0 173
:3 0 3145 3147 0
1b26 3146 3149 :3 0
314a :2 0 22 :3 0
1f :3 0 314c 314d
0 32e9 f1 :3 0
e8 :3 0 49 :3 0
48 :2 0 1b29 3150
3153 1a :3 0 1b6
:3 0 3155 3156 0
1b2c 314f 3158 3159
:2 0 1a :3 0 f3
:2 0 1b6 :3 0 315b
315d 0 1b31 315c
315f :3 0 c8 :3 0
149 :3 0 2c :3 0
aa :3 0 2a :3 0
ab :3 0 b0 :3 0
22 :4 0 2ad 1
:8 0 317f f9 :4 0
316a :3 0 112 :3 0
f3 :2 0 1b36 316d
316e :3 0 15 :3 0
fa :3 0 3170 3171
0 48 :2 0 3172
3173 0 3175 1b39
317c 15 :3 0 fa
:3 0 3176 3177 0
fb :2 0 3178 3179
0 317b 1b3b 317d
316f 3175 0 317e
0 317b 0 317e
1b3d 0 317f 1b40
31d2 fe :3 0 15
:3 0 fa :3 0 3181
3182 0 fd :3 0
3183 3184 0 3186
1b43 3188 1b45 3187
3186 :2 0 31d0 ff
:3 0 15 :3 0 fa
:3 0 318b 318c 0
fd :3 0 318d 318e
0 31c8 db :3 0
dc :3 0 3190 3191
0 db :3 0 ec
:3 0 3193 3194 0
100 :2 0 2 :4 0
2ae :2 0 ee :2 0
33 :2 0 1b47 3199
319b :3 0 1b4a 3195
319d 3192 319f 319e
:2 0 de :3 0 ef
:3 0 31a1 31a2 0
e0 :4 0 2af :4 0
e3 :2 0 e4 :3 0
1b4e 31a6 31a8 :3 0
e3 :2 0 103 :4 0
1b51 31aa 31ac :3 0
e3 :2 0 104 :4 0
1b54 31ae 31b0 :3 0
e3 :2 0 fd :3 0
1b57 31b2 31b4 :3 0
e3 :2 0 105 :4 0
1b5a 31b6 31b8 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 1b5d 31bb
31bf 1b61 31ba 31c1
:3 0 1b64 31a3 31c3
:2 0 31c5 1b67 31c6
31a0 31c5 0 31c7
1b69 0 31c8 1b6b
31cb :3 0 31cb 0
31cb 31ca 31c8 31c9
:6 0 31cd 88 :3 0
1b6e 31cf 1b70 31ce
31cd :2 0 31d0 1b72
:2 0 31d2 0 31d2
31d1 317f 31d0 :6 0
31d5 6f :3 0 16a
:3 0 1b75 32e6 e8
:3 0 49 :3 0 48
:2 0 1b77 31d6 31d9
1a :3 0 f3 :2 0
1ac :3 0 31db 31dd
0 1b7c 31dc 31df
:3 0 7e :3 0 18a
:3 0 48 :2 0 e8
:3 0 4d :3 0 48
:2 0 1b7f 31e4 31e7
1a :3 0 18b :3 0
31e9 31ea 0 7b
:3 0 1b82 31e2 31ed
31e1 31ee 0 3268
c8 :3 0 180 :3 0
1a :3 0 1b6 :3 0
185 :3 0 7b :3 0
149 :3 0 2c :3 0
aa :3 0 2a :3 0
ab :3 0 b0 :3 0
22 :4 0 2b0 1
:8 0 3213 f9 :4 0
31fe :3 0 112 :3 0
f3 :2 0 1b89 3201
3202 :3 0 15 :3 0
fa :3 0 3204 3205
0 48 :2 0 3206
3207 0 3209 1b8c
3210 15 :3 0 fa
:3 0 320a 320b 0
fb :2 0 320c 320d
0 320f 1b8e 3211
3203 3209 0 3212
0 320f 0 3212
1b90 0 3213 1b93
3266 fe :3 0 15
:3 0 fa :3 0 3215
3216 0 fd :3 0
3217 3218 0 321a
1b96 321c 1b98 321b
321a :2 0 3264 ff
:3 0 15 :3 0 fa
:3 0 321f 3220 0
fd :3 0 3221 3222
0 325c db :3 0
dc :3 0 3224 3225
0 db :3 0 ec
:3 0 3227 3228 0
100 :2 0 2 :4 0
2b1 :2 0 ee :2 0
33 :2 0 1b9a 322d
322f :3 0 1b9d 3229
3231 3226 3233 3232
:2 0 de :3 0 ef
:3 0 3235 3236 0
e0 :4 0 2b2 :4 0
e3 :2 0 e4 :3 0
1ba1 323a 323c :3 0
e3 :2 0 103 :4 0
1ba4 323e 3240 :3 0
e3 :2 0 104 :4 0
1ba7 3242 3244 :3 0
e3 :2 0 fd :3 0
1baa 3246 3248 :3 0
e3 :2 0 105 :4 0
1bad 324a 324c :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 1bb0 324f
3253 1bb4 324e 3255
:3 0 1bb7 3237 3257
:2 0 3259 1bba 325a
3234 3259 0 325b
1bbc 0 325c 1bbe
325f :3 0 325f 0
325f 325e 325c 325d
:6 0 3261 8a :3 0
1bc1 3263 1bc3 3262
3261 :2 0 3264 1bc5
:2 0 3266 0 3266
3265 3213 3264 :6 0
3268 6f :3 0 1bc8
3269 31e0 3268 0
32e8 c8 :3 0 180
:3 0 1b1 :3 0 1b2
:3 0 49 :3 0 1a
:3 0 1b6 :3 0 185
:3 0 20 :3 0 149
:3 0 2c :3 0 aa
:3 0 2a :3 0 ab
:3 0 b0 :3 0 22
:4 0 2b3 1 :8 0
3290 f9 :4 0 327b
:3 0 112 :3 0 f3
:2 0 1bcd 327e 327f
:3 0 15 :3 0 fa
:3 0 3281 3282 0
48 :2 0 3283 3284
0 3286 1bd0 328d
15 :3 0 fa :3 0
3287 3288 0 fb
:2 0 3289 328a 0
328c 1bd2 328e 3280
3286 0 328f 0
328c 0 328f 1bd4
0 3290 1bd7 32e3
fe :3 0 15 :3 0
fa :3 0 3292 3293
0 fd :3 0 3294
3295 0 3297 1bda
3299 1bdc 3298 3297
:2 0 32e1 ff :3 0
15 :3 0 fa :3 0
329c 329d 0 fd
:3 0 329e 329f 0
32d9 db :3 0 dc
:3 0 32a1 32a2 0
db :3 0 ec :3 0
32a4 32a5 0 100
:2 0 2 :4 0 2b4
:2 0 ee :2 0 33
:2 0 1bde 32aa 32ac
:3 0 1be1 32a6 32ae
32a3 32b0 32af :2 0
de :3 0 ef :3 0
32b2 32b3 0 e0
:4 0 2b5 :4 0 e3
:2 0 e4 :3 0 1be5
32b7 32b9 :3 0 e3
:2 0 103 :4 0 1be8
32bb 32bd :3 0 e3
:2 0 104 :4 0 1beb
32bf 32c1 :3 0 e3
:2 0 fd :3 0 1bee
32c3 32c5 :3 0 e3
:2 0 105 :4 0 1bf1
32c7 32c9 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 1bf4 32cc 32d0
1bf8 32cb 32d2 :3 0
1bfb 32b4 32d4 :2 0
32d6 1bfe 32d7 32b1
32d6 0 32d8 1c00
0 32d9 1c02 32dc
:3 0 32dc 0 32dc
32db 32d9 32da :6 0
32de 8c :3 0 1c05
32e0 1c07 32df 32de
:2 0 32e1 1c09 :2 0
32e3 0 32e3 32e2
3290 32e1 :6 0 32e5
6f :3 0 1c0c 32e7
3160 31d5 0 32e8
0 32e5 0 32e8
1c0e 0 32e9 1c12
32ea 314b 32e9 0
32ec 2cc4 3141 0
32ec 1c15 0 32ed
1c18 3305 73 :3 0
33 :2 0 32ee 32ef
0 3304 25 :3 0
27 :3 0 32f1 32f2
0 3304 106 :3 0
32 :3 0 33 :2 0
33 :2 0 1c1d 32f4
32f8 f3 :2 0 153
:4 0 1c23 32fa 32fc
:3 0 56 :3 0 153
:2 0 32fe 32ff 0
3301 1c26 3302 32fd
3301 0 3303 1c28
0 3304 1c2a 3306
2c4d 32ed 0 3307
0 3304 0 3307
1c2e 0 4571 e8
:3 0 71 :3 0 48
:2 0 1c31 3308 330b
f3 :2 0 33 :2 0
1c36 330d 330f :3 0
3310 :2 0 45 :3 0
1ce :2 0 1c39 3313
3314 :3 0 3315 :2 0
3316 :2 0 3311 3318
3317 :2 0 13e :3 0
13e :3 0 45 :3 0
70 :3 0 c7 :3 0
a4 :3 0 29 :4 0
2b6 1 :8 0 3327
15 :3 0 fa :3 0
3322 3323 0 fd
:3 0 3324 3325 0
3327 1c3b 337a fe
:3 0 15 :3 0 fa
:3 0 3329 332a 0
fd :3 0 332b 332c
0 332e 1c3e 3330
1c40 332f 332e :2 0
3378 ff :3 0 15
:3 0 fa :3 0 3333
3334 0 fd :3 0
3335 3336 0 3370
db :3 0 dc :3 0
3338 3339 0 db
:3 0 ec :3 0 333b
333c 0 100 :2 0
2 :4 0 2b7 :2 0
ee :2 0 33 :2 0
1c42 3341 3343 :3 0
1c45 333d 3345 333a
3347 3346 :2 0 de
:3 0 ef :3 0 3349
334a 0 e0 :4 0
2b8 :4 0 e3 :2 0
e4 :3 0 1c49 334e
3350 :3 0 e3 :2 0
103 :4 0 1c4c 3352
3354 :3 0 e3 :2 0
104 :4 0 1c4f 3356
3358 :3 0 e3 :2 0
fd :3 0 1c52 335a
335c :3 0 e3 :2 0
105 :4 0 1c55 335e
3360 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
1c58 3363 3367 1c5c
3362 3369 :3 0 1c5f
334b 336b :2 0 336d
1c62 336e 3348 336d
0 336f 1c64 0
3370 1c66 3373 :3 0
3373 0 3373 3372
3370 3371 :6 0 3375
8e :3 0 1c69 3377
1c6b 3376 3375 :2 0
3378 1c6d :2 0 337a
0 337a 3379 3327
3378 :6 0 3428 6f
:3 0 15 :3 0 fa
:3 0 337c 337d 0
15 :3 0 f3 :2 0
173 :3 0 337f 3381
0 1c72 3380 3383
:3 0 3384 :2 0 e8
:3 0 70 :3 0 48
:2 0 1c75 3386 3389
f3 :2 0 48 :2 0
1c7a 338b 338d :3 0
338e :2 0 3385 3390
338f :2 0 c7 :3 0
13e :3 0 45 :3 0
a4 :3 0 29 :4 0
2b9 1 :8 0 33ad
f9 :4 0 3398 :3 0
112 :3 0 f3 :2 0
1c7f 339b 339c :3 0
15 :3 0 fa :3 0
339e 339f 0 48
:2 0 33a0 33a1 0
33a3 1c82 33aa 15
:3 0 fa :3 0 33a4
33a5 0 fb :2 0
33a6 33a7 0 33a9
1c84 33ab 339d 33a3
0 33ac 0 33a9
0 33ac 1c86 0
33ad 1c89 3400 fe
:3 0 15 :3 0 fa
:3 0 33af 33b0 0
fd :3 0 33b1 33b2
0 33b4 1c8c 33b6
1c8e 33b5 33b4 :2 0
33fe ff :3 0 15
:3 0 fa :3 0 33b9
33ba 0 fd :3 0
33bb 33bc 0 33f6
db :3 0 dc :3 0
33be 33bf 0 db
:3 0 ec :3 0 33c1
33c2 0 100 :2 0
2 :4 0 2ba :2 0
ee :2 0 33 :2 0
1c90 33c7 33c9 :3 0
1c93 33c3 33cb 33c0
33cd 33cc :2 0 de
:3 0 ef :3 0 33cf
33d0 0 e0 :4 0
2bb :4 0 e3 :2 0
e4 :3 0 1c97 33d4
33d6 :3 0 e3 :2 0
103 :4 0 1c9a 33d8
33da :3 0 e3 :2 0
104 :4 0 1c9d 33dc
33de :3 0 e3 :2 0
fd :3 0 1ca0 33e0
33e2 :3 0 e3 :2 0
105 :4 0 1ca3 33e4
33e6 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
1ca6 33e9 33ed 1caa
33e8 33ef :3 0 1cad
33d1 33f1 :2 0 33f3
1cb0 33f4 33ce 33f3
0 33f5 1cb2 0
33f6 1cb4 33f9 :3 0
33f9 0 33f9 33f8
33f6 33f7 :6 0 33fb
90 :3 0 1cb7 33fd
1cb9 33fc 33fb :2 0
33fe 1cbb :2 0 3400
0 3400 33ff 33ad
33fe :6 0 3403 6f
:3 0 16a :3 0 1cbe
3426 15 :3 0 fa
:3 0 3404 3405 0
15 :3 0 f3 :2 0
173 :3 0 3407 3409
0 1cc2 3408 340b
:3 0 340c :2 0 e8
:3 0 70 :3 0 48
:2 0 1cc5 340e 3411
f3 :2 0 153 :2 0
1cca 3413 3415 :3 0
3416 :2 0 340d 3418
3417 :2 0 91 :3 0
1a :3 0 2bc :3 0
341b 341c 0 341a
341d 0 3424 90
:3 0 29 :3 0 341f
3420 0 3424 284
:8 0 3424 1ccd 3425
3419 3424 0 3427
3391 3403 0 3427
1cd1 0 3428 1cd4
3429 3319 3428 0
342a 1cd7 0 4571
92 :3 0 48 :2 0
342b 342c 0 4571
92 :3 0 15d :3 0
205 :3 0 b0 :3 0
c8 :3 0 205 :3 0
a8 :3 0 206 :3 0
206 :3 0 a9 :3 0
2b :3 0 206 :3 0
b3 :3 0 29 :3 0
205 :3 0 b0 :3 0
206 :3 0 b0 :3 0
205 :3 0 149 :3 0
2c :3 0 205 :3 0
ab :4 0 2bd 1
:8 0 344b 15 :3 0
fa :3 0 3446 3447
0 fd :3 0 3448
3449 0 344b 1cd9
349e fe :3 0 15
:3 0 fa :3 0 344d
344e 0 fd :3 0
344f 3450 0 3452
1cdc 3454 1cde 3453
3452 :2 0 349c ff
:3 0 15 :3 0 fa
:3 0 3457 3458 0
fd :3 0 3459 345a
0 3494 db :3 0
dc :3 0 345c 345d
0 db :3 0 ec
:3 0 345f 3460 0
100 :2 0 2 :4 0
2be :2 0 ee :2 0
33 :2 0 1ce0 3465
3467 :3 0 1ce3 3461
3469 345e 346b 346a
:2 0 de :3 0 ef
:3 0 346d 346e 0
e0 :4 0 2bf :4 0
e3 :2 0 e4 :3 0
1ce7 3472 3474 :3 0
e3 :2 0 103 :4 0
1cea 3476 3478 :3 0
e3 :2 0 104 :4 0
1ced 347a 347c :3 0
e3 :2 0 fd :3 0
1cf0 347e 3480 :3 0
e3 :2 0 105 :4 0
1cf3 3482 3484 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 1cf6 3487
348b 1cfa 3486 348d
:3 0 1cfd 346f 348f
:2 0 3491 1d00 3492
346c 3491 0 3493
1d02 0 3494 1d04
3497 :3 0 3497 0
3497 3496 3494 3495
:6 0 3499 92 :3 0
1d07 349b 1d09 349a
3499 :2 0 349c 1d0b
:2 0 349e 0 349e
349d 344b 349c :6 0
4571 6f :3 0 e8
:3 0 92 :3 0 48
:2 0 1d0e 34a0 34a3
15c :2 0 48 :2 0
1d13 34a5 34a7 :3 0
161 :2 0 1d16 34a9
34aa :3 0 a8 :3 0
20d :3 0 b7 :3 0
20e :3 0 b8 :3 0
20f :3 0 bb :3 0
210 :3 0 b5 :3 0
211 :3 0 212 :3 0
213 :3 0 214 :3 0
215 :3 0 be :3 0
216 :3 0 c0 :3 0
217 :3 0 bf :3 0
218 :3 0 c1 :3 0
219 :3 0 b2 :3 0
24 :4 0 2c0 1
:8 0 34da f9 :4 0
34c5 :3 0 112 :3 0
f3 :2 0 1d1a 34c8
34c9 :3 0 15 :3 0
fa :3 0 34cb 34cc
0 48 :2 0 34cd
34ce 0 34d0 1d1d
34d7 15 :3 0 fa
:3 0 34d1 34d2 0
fb :2 0 34d3 34d4
0 34d6 1d1f 34d8
34ca 34d0 0 34d9
0 34d6 0 34d9
1d21 0 34da 1d24
352d fe :3 0 15
:3 0 fa :3 0 34dc
34dd 0 fd :3 0
34de 34df 0 34e1
1d27 34e3 1d29 34e2
34e1 :2 0 352b ff
:3 0 15 :3 0 fa
:3 0 34e6 34e7 0
fd :3 0 34e8 34e9
0 3523 db :3 0
dc :3 0 34eb 34ec
0 db :3 0 ec
:3 0 34ee 34ef 0
100 :2 0 2 :4 0
2c1 :2 0 ee :2 0
33 :2 0 1d2b 34f4
34f6 :3 0 1d2e 34f0
34f8 34ed 34fa 34f9
:2 0 de :3 0 ef
:3 0 34fc 34fd 0
e0 :4 0 2c2 :4 0
e3 :2 0 e4 :3 0
1d32 3501 3503 :3 0
e3 :2 0 103 :4 0
1d35 3505 3507 :3 0
e3 :2 0 104 :4 0
1d38 3509 350b :3 0
e3 :2 0 fd :3 0
1d3b 350d 350f :3 0
e3 :2 0 105 :4 0
1d3e 3511 3513 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 1d41 3516
351a 1d45 3515 351c
:3 0 1d48 34fe 351e
:2 0 3520 1d4b 3521
34fb 3520 0 3522
1d4d 0 3523 1d4f
3526 :3 0 3526 0
3526 3525 3523 3524
:6 0 3528 94 :3 0
1d52 352a 1d54 3529
3528 :2 0 352b 1d56
:2 0 352d 0 352d
352c 34da 352b :6 0
352f 6f :3 0 1d59
3530 34ab 352f 0
3531 1d5b 0 4571
e8 :3 0 8a :3 0
48 :2 0 1d5d 3532
3535 1a :3 0 f3
:2 0 29d :3 0 3537
3539 0 1d62 3538
353b :3 0 25 :3 0
24 :3 0 353d 353e
0 39da 26 :3 0
1ce :2 0 1d65 3541
3542 :3 0 3543 :2 0
1db :3 0 2c3 :3 0
2c3 :3 0 1f0 :3 0
2c3 :3 0 2c4 :3 0
2c5 :3 0 1f0 :3 0
2c6 :3 0 1b2 :3 0
2c3 :3 0 2c4 :3 0
2c5 :3 0 2c4 :3 0
1db :3 0 2c5 :3 0
2c5 :3 0 a9 :3 0
2b :3 0 2c5 :3 0
b2 :3 0 24 :3 0
2c5 :3 0 1f1 :3 0
2c3 :3 0 1f1 :3 0
2c3 :3 0 a9 :3 0
2b :3 0 2c3 :3 0
b2 :3 0 26 :4 0
2c7 1 :8 0 357b
f9 :4 0 3566 :3 0
112 :3 0 f3 :2 0
1d69 3569 356a :3 0
15 :3 0 fa :3 0
356c 356d 0 48
:2 0 356e 356f 0
3571 1d6c 3578 15
:3 0 fa :3 0 3572
3573 0 fb :2 0
3574 3575 0 3577
1d6e 3579 356b 3571
0 357a 0 3577
0 357a 1d70 0
357b 1d73 35ce fe
:3 0 15 :3 0 fa
:3 0 357d 357e 0
fd :3 0 357f 3580
0 3582 1d76 3584
1d78 3583 3582 :2 0
35cc ff :3 0 15
:3 0 fa :3 0 3587
3588 0 fd :3 0
3589 358a 0 35c4
db :3 0 dc :3 0
358c 358d 0 db
:3 0 ec :3 0 358f
3590 0 100 :2 0
2 :4 0 2c8 :2 0
ee :2 0 33 :2 0
1d7a 3595 3597 :3 0
1d7d 3591 3599 358e
359b 359a :2 0 de
:3 0 ef :3 0 359d
359e 0 e0 :4 0
2c9 :4 0 e3 :2 0
e4 :3 0 1d81 35a2
35a4 :3 0 e3 :2 0
103 :4 0 1d84 35a6
35a8 :3 0 e3 :2 0
104 :4 0 1d87 35aa
35ac :3 0 e3 :2 0
fd :3 0 1d8a 35ae
35b0 :3 0 e3 :2 0
105 :4 0 1d8d 35b2
35b4 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
1d90 35b7 35bb 1d94
35b6 35bd :3 0 1d97
359f 35bf :2 0 35c1
1d9a 35c2 359c 35c1
0 35c3 1d9c 0
35c4 1d9e 35c7 :3 0
35c7 0 35c7 35c6
35c4 35c5 :6 0 35c9
96 :3 0 1da1 35cb
1da3 35ca 35c9 :2 0
35cc 1da5 :2 0 35ce
0 35ce 35cd 357b
35cc :6 0 35d0 6f
:3 0 1da8 35d1 3544
35d0 0 35d2 1daa
0 39da 2ca :3 0
2cb :3 0 2cc :4 0
35d5 :4 0 35d6 :2 0
39da 15 :3 0 fa
:3 0 35d8 35d9 0
48 :2 0 35da 35db
0 39da e8 :3 0
54 :3 0 48 :2 0
1dac 35dd 35e0 f3
:2 0 48 :2 0 1db1
35e2 35e4 :3 0 e8
:3 0 50 :3 0 48
:2 0 1db4 35e6 35e9
f3 :2 0 48 :2 0
1db9 35eb 35ed :3 0
35e5 35ef 35ee :2 0
2cd :3 0 af :3 0
1f1 :3 0 a2 :3 0
af :3 0 af :3 0
a4 :3 0 2a :3 0
af :3 0 1f1 :3 0
1cf :3 0 106 :3 0
37 :3 0 1cf :3 0
106 :3 0 38 :4 0
2ce 1 :8 0 3617
f9 :4 0 3602 :3 0
112 :3 0 f3 :2 0
1dbe 3605 3606 :3 0
15 :3 0 fa :3 0
3608 3609 0 48
:2 0 360a 360b 0
360d 1dc1 3614 15
:3 0 fa :3 0 360e
360f 0 fb :2 0
3610 3611 0 3613
1dc3 3615 3607 360d
0 3616 0 3613
0 3616 1dc5 0
3617 1dc8 366a fe
:3 0 15 :3 0 fa
:3 0 3619 361a 0
fd :3 0 361b 361c
0 361e 1dcb 3620
1dcd 361f 361e :2 0
3668 ff :3 0 15
:3 0 fa :3 0 3623
3624 0 fd :3 0
3625 3626 0 3660
db :3 0 dc :3 0
3628 3629 0 db
:3 0 ec :3 0 362b
362c 0 100 :2 0
2 :4 0 2cf :2 0
ee :2 0 33 :2 0
1dcf 3631 3633 :3 0
1dd2 362d 3635 362a
3637 3636 :2 0 de
:3 0 ef :3 0 3639
363a 0 e0 :4 0
2d0 :4 0 e3 :2 0
e4 :3 0 1dd6 363e
3640 :3 0 e3 :2 0
103 :4 0 1dd9 3642
3644 :3 0 e3 :2 0
104 :4 0 1ddc 3646
3648 :3 0 e3 :2 0
fd :3 0 1ddf 364a
364c :3 0 e3 :2 0
105 :4 0 1de2 364e
3650 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
1de5 3653 3657 1de9
3652 3659 :3 0 1dec
363b 365b :2 0 365d
1def 365e 3638 365d
0 365f 1df1 0
3660 1df3 3663 :3 0
3663 0 3663 3662
3660 3661 :6 0 3665
98 :3 0 1df6 3667
1df8 3666 3665 :2 0
3668 1dfa :2 0 366a
0 366a 3669 3617
3668 :6 0 366c 6f
:3 0 1dfd 36f5 2cd
:3 0 af :3 0 1f1
:3 0 a2 :3 0 af
:3 0 1db :3 0 2d1
:3 0 af :3 0 a4
:3 0 2a :3 0 af
:3 0 1f1 :3 0 1cf
:3 0 106 :3 0 37
:3 0 1cf :3 0 106
:3 0 38 :3 0 2d1
:3 0 a9 :3 0 2b
:3 0 2d1 :3 0 b2
:3 0 24 :3 0 af
:3 0 1f1 :3 0 2d1
:3 0 1f1 :4 0 2d2
1 :8 0 369f f9
:4 0 368a :3 0 112
:3 0 f3 :2 0 1e01
368d 368e :3 0 15
:3 0 fa :3 0 3690
3691 0 48 :2 0
3692 3693 0 3695
1e04 369c 15 :3 0
fa :3 0 3696 3697
0 fb :2 0 3698
3699 0 369b 1e06
369d 368f 3695 0
369e 0 369b 0
369e 1e08 0 369f
1e0b 36f2 fe :3 0
15 :3 0 fa :3 0
36a1 36a2 0 fd
:3 0 36a3 36a4 0
36a6 1e0e 36a8 1e10
36a7 36a6 :2 0 36f0
ff :3 0 15 :3 0
fa :3 0 36ab 36ac
0 fd :3 0 36ad
36ae 0 36e8 db
:3 0 dc :3 0 36b0
36b1 0 db :3 0
ec :3 0 36b3 36b4
0 100 :2 0 2
:4 0 2d3 :2 0 ee
:2 0 33 :2 0 1e12
36b9 36bb :3 0 1e15
36b5 36bd 36b2 36bf
36be :2 0 de :3 0
ef :3 0 36c1 36c2
0 e0 :4 0 2d4
:4 0 e3 :2 0 e4
:3 0 1e19 36c6 36c8
:3 0 e3 :2 0 103
:4 0 1e1c 36ca 36cc
:3 0 e3 :2 0 104
:4 0 1e1f 36ce 36d0
:3 0 e3 :2 0 fd
:3 0 1e22 36d2 36d4
:3 0 e3 :2 0 105
:4 0 1e25 36d6 36d8
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 1e28
36db 36df 1e2c 36da
36e1 :3 0 1e2f 36c3
36e3 :2 0 36e5 1e32
36e6 36c0 36e5 0
36e7 1e34 0 36e8
1e36 36eb :3 0 36eb
0 36eb 36ea 36e8
36e9 :6 0 36ed 9a
:3 0 1e39 36ef 1e3b
36ee 36ed :2 0 36f0
1e3d :2 0 36f2 0
36f2 36f1 369f 36f0
:6 0 36f4 6f :3 0
1e40 36f6 35f0 366c
0 36f7 0 36f4
0 36f7 1e42 0
39da 15 :3 0 fa
:3 0 36f8 36f9 0
15 :3 0 f3 :2 0
173 :3 0 36fb 36fd
0 1e47 36fc 36ff
:3 0 3700 :2 0 78
:3 0 48 :2 0 3702
3703 0 39d3 154
:3 0 1f1 :3 0 241
:3 0 1f1 :3 0 78
:3 0 35 :3 0 2cd
:4 0 2d5 1 :8 0
3712 15 :3 0 fa
:3 0 370d 370e 0
fd :3 0 370f 3710
0 3712 1e4a 3765
fe :3 0 15 :3 0
fa :3 0 3714 3715
0 fd :3 0 3716
3717 0 3719 1e4d
371b 1e4f 371a 3719
:2 0 3763 ff :3 0
15 :3 0 fa :3 0
371e 371f 0 fd
:3 0 3720 3721 0
375b db :3 0 dc
:3 0 3723 3724 0
db :3 0 ec :3 0
3726 3727 0 100
:2 0 2 :4 0 2d6
:2 0 ee :2 0 33
:2 0 1e51 372c 372e
:3 0 1e54 3728 3730
3725 3732 3731 :2 0
de :3 0 ef :3 0
3734 3735 0 e0
:4 0 2d7 :4 0 e3
:2 0 e4 :3 0 1e58
3739 373b :3 0 e3
:2 0 103 :4 0 1e5b
373d 373f :3 0 e3
:2 0 104 :4 0 1e5e
3741 3743 :3 0 e3
:2 0 fd :3 0 1e61
3745 3747 :3 0 e3
:2 0 105 :4 0 1e64
3749 374b :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 1e67 374e 3752
1e6b 374d 3754 :3 0
1e6e 3736 3756 :2 0
3758 1e71 3759 3733
3758 0 375a 1e73
0 375b 1e75 375e
:3 0 375e 0 375e
375d 375b 375c :6 0
3760 9c :3 0 1e78
3762 1e7a 3761 3760
:2 0 3763 1e7c :2 0
3765 0 3765 3764
3712 3763 :6 0 39d3
6f :3 0 e8 :3 0
78 :3 0 48 :2 0
1e7f 3767 376a f3
:2 0 48 :2 0 1e84
376c 376e :3 0 2d8
:3 0 3770 :4 0 3772
1e87 3773 376f 3772
0 3774 1e89 0
39d3 1db :3 0 a9
:3 0 2b :3 0 b2
:3 0 24 :4 0 2d9
1 :8 0 3790 f9
:4 0 377b :3 0 112
:3 0 f3 :2 0 1e8d
377e 377f :3 0 15
:3 0 fa :3 0 3781
3782 0 48 :2 0
3783 3784 0 3786
1e90 378d 15 :3 0
fa :3 0 3787 3788
0 fb :2 0 3789
378a 0 378c 1e92
378e 3780 3786 0
378f 0 378c 0
378f 1e94 0 3790
1e97 37e3 fe :3 0
15 :3 0 fa :3 0
3792 3793 0 fd
:3 0 3794 3795 0
3797 1e9a 3799 1e9c
3798 3797 :2 0 37e1
ff :3 0 15 :3 0
fa :3 0 379c 379d
0 fd :3 0 379e
379f 0 37d9 db
:3 0 dc :3 0 37a1
37a2 0 db :3 0
ec :3 0 37a4 37a5
0 100 :2 0 2
:4 0 2da :2 0 ee
:2 0 33 :2 0 1e9e
37aa 37ac :3 0 1ea1
37a6 37ae 37a3 37b0
37af :2 0 de :3 0
ef :3 0 37b2 37b3
0 e0 :4 0 2db
:4 0 e3 :2 0 e4
:3 0 1ea5 37b7 37b9
:3 0 e3 :2 0 103
:4 0 1ea8 37bb 37bd
:3 0 e3 :2 0 104
:4 0 1eab 37bf 37c1
:3 0 e3 :2 0 fd
:3 0 1eae 37c3 37c5
:3 0 e3 :2 0 105
:4 0 1eb1 37c7 37c9
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 1eb4
37cc 37d0 1eb8 37cb
37d2 :3 0 1ebb 37b4
37d4 :2 0 37d6 1ebe
37d7 37b1 37d6 0
37d8 1ec0 0 37d9
1ec2 37dc :3 0 37dc
0 37dc 37db 37d9
37da :6 0 37de 9e
:3 0 1ec5 37e0 1ec7
37df 37de :2 0 37e1
1ec9 :2 0 37e3 0
37e3 37e2 3790 37e1
:6 0 39d3 6f :3 0
72 :3 0 2dc :3 0
e8 :3 0 22d :3 0
89 :3 0 1ecc 37e8
37ea 48 :2 0 1ece
37e7 37ed 2dd :2 0
e8 :3 0 22d :3 0
78 :3 0 1ed1 37f1
37f3 48 :2 0 1ed3
37f0 37f6 1ed6 37ef
37f8 :3 0 37f9 :2 0
ee :2 0 2de :2 0
1ed9 37fb 37fd :3 0
1edc 37e6 37ff 37e5
3800 0 39d3 a1
:3 0 2c4 :3 0 63
:3 0 17 :3 0 a2
:3 0 a4 :3 0 2b
:3 0 1f1 :3 0 35
:4 0 2df 1 :8 0
3811 15 :3 0 fa
:3 0 380c 380d 0
fd :3 0 380e 380f
0 3811 1ede 3864
fe :3 0 15 :3 0
fa :3 0 3813 3814
0 fd :3 0 3815
3816 0 3818 1ee1
381a 1ee3 3819 3818
:2 0 3862 ff :3 0
15 :3 0 fa :3 0
381d 381e 0 fd
:3 0 381f 3820 0
385a db :3 0 dc
:3 0 3822 3823 0
db :3 0 ec :3 0
3825 3826 0 100
:2 0 2 :4 0 2e0
:2 0 ee :2 0 33
:2 0 1ee5 382b 382d
:3 0 1ee8 3827 382f
3824 3831 3830 :2 0
de :3 0 ef :3 0
3833 3834 0 e0
:4 0 2e1 :4 0 e3
:2 0 e4 :3 0 1eec
3838 383a :3 0 e3
:2 0 103 :4 0 1eef
383c 383e :3 0 e3
:2 0 104 :4 0 1ef2
3840 3842 :3 0 e3
:2 0 fd :3 0 1ef5
3844 3846 :3 0 e3
:2 0 105 :4 0 1ef8
3848 384a :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 1efb 384d 3851
1eff 384c 3853 :3 0
1f02 3835 3855 :2 0
3857 1f05 3858 3832
3857 0 3859 1f07
0 385a 1f09 385d
:3 0 385d 0 385d
385c 385a 385b :6 0
385f a0 :3 0 1f0c
3861 1f0e 3860 385f
:2 0 3862 1f10 :2 0
3864 0 3864 3863
3811 3862 :6 0 39d3
6f :3 0 e8 :3 0
63 :3 0 48 :2 0
1f13 3866 3869 e8
:3 0 124 :2 0 72
:3 0 48 :2 0 1f16
386b 386f 1f1b 386c
3871 :3 0 1b1 :3 0
2e2 :3 0 3873 3874
0 e8 :3 0 72
:3 0 48 :2 0 1f1e
3876 3879 17 :3 0
1f21 3875 387c :2 0
387e 1f24 387f 3872
387e 0 3880 1f26
0 39d3 1db :3 0
a9 :3 0 aa :3 0
b2 :3 0 1f1 :3 0
194 :3 0 1f0 :3 0
2c4 :3 0 2e3 :3 0
2e4 :3 0 b3 :3 0
2b :3 0 2a :3 0
24 :3 0 1f1 :3 0
72 :3 0 17 :3 0
58 :3 0 24 :3 0
26 :3 0 29 :3 0
2cd :4 0 2e5 1
:8 0 38ad f9 :4 0
3898 :3 0 112 :3 0
f3 :2 0 1f2a 389b
389c :3 0 15 :3 0
fa :3 0 389e 389f
0 48 :2 0 38a0
38a1 0 38a3 1f2d
38aa 15 :3 0 fa
:3 0 38a4 38a5 0
fb :2 0 38a6 38a7
0 38a9 1f2f 38ab
389d 38a3 0 38ac
0 38a9 0 38ac
1f31 0 38ad 1f34
3900 fe :3 0 15
:3 0 fa :3 0 38af
38b0 0 fd :3 0
38b1 38b2 0 38b4
1f37 38b6 1f39 38b5
38b4 :2 0 38fe ff
:3 0 15 :3 0 fa
:3 0 38b9 38ba 0
fd :3 0 38bb 38bc
0 38f6 db :3 0
dc :3 0 38be 38bf
0 db :3 0 ec
:3 0 38c1 38c2 0
100 :2 0 2 :4 0
2e6 :2 0 ee :2 0
33 :2 0 1f3b 38c7
38c9 :3 0 1f3e 38c3
38cb 38c0 38cd 38cc
:2 0 de :3 0 ef
:3 0 38cf 38d0 0
e0 :4 0 2e7 :4 0
e3 :2 0 e4 :3 0
1f42 38d4 38d6 :3 0
e3 :2 0 103 :4 0
1f45 38d8 38da :3 0
e3 :2 0 104 :4 0
1f48 38dc 38de :3 0
e3 :2 0 fd :3 0
1f4b 38e0 38e2 :3 0
e3 :2 0 105 :4 0
1f4e 38e4 38e6 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 1f51 38e9
38ed 1f55 38e8 38ef
:3 0 1f58 38d1 38f1
:2 0 38f3 1f5b 38f4
38ce 38f3 0 38f5
1f5d 0 38f6 1f5f
38f9 :3 0 38f9 0
38f9 38f8 38f6 38f7
:6 0 38fb a2 :3 0
1f62 38fd 1f64 38fc
38fb :2 0 38fe 1f66
:2 0 3900 0 3900
38ff 38ad 38fe :6 0
39d3 6f :3 0 a8
:3 0 b0 :3 0 22
:3 0 aa :3 0 2a
:3 0 ab :3 0 ac
:3 0 58 :3 0 26
:3 0 be :3 0 6e
:3 0 65 :3 0 7f
:3 0 bf :3 0 6e
:3 0 68 :3 0 80
:3 0 c0 :3 0 6d
:3 0 67 :3 0 81
:3 0 c1 :3 0 6d
:3 0 69 :3 0 82
:3 0 258 :3 0 1b1
:3 0 1b2 :3 0 258
:3 0 1a :3 0 259
:3 0 25a :3 0 1b1
:3 0 1b2 :3 0 25a
:3 0 1a :3 0 25b
:3 0 b2 :3 0 24
:4 0 2e8 1 :8 0
393f f9 :4 0 392a
:3 0 112 :3 0 f3
:2 0 1f6b 392d 392e
:3 0 15 :3 0 fa
:3 0 3930 3931 0
48 :2 0 3932 3933
0 3935 1f6e 393c
15 :3 0 fa :3 0
3936 3937 0 fb
:2 0 3938 3939 0
393b 1f70 393d 392f
3935 0 393e 0
393b 0 393e 1f72
0 393f 1f75 3992
fe :3 0 15 :3 0
fa :3 0 3941 3942
0 fd :3 0 3943
3944 0 3946 1f78
3948 1f7a 3947 3946
:2 0 3990 ff :3 0
15 :3 0 fa :3 0
394b 394c 0 fd
:3 0 394d 394e 0
3988 db :3 0 dc
:3 0 3950 3951 0
db :3 0 ec :3 0
3953 3954 0 100
:2 0 2 :4 0 2e9
:2 0 ee :2 0 33
:2 0 1f7c 3959 395b
:3 0 1f7f 3955 395d
3952 395f 395e :2 0
de :3 0 ef :3 0
3961 3962 0 e0
:4 0 2ea :4 0 e3
:2 0 e4 :3 0 1f83
3966 3968 :3 0 e3
:2 0 103 :4 0 1f86
396a 396c :3 0 e3
:2 0 104 :4 0 1f89
396e 3970 :3 0 e3
:2 0 fd :3 0 1f8c
3972 3974 :3 0 e3
:2 0 105 :4 0 1f8f
3976 3978 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 1f92 397b 397f
1f96 397a 3981 :3 0
1f99 3963 3983 :2 0
3985 1f9c 3986 3960
3985 0 3987 1f9e
0 3988 1fa0 398b
:3 0 398b 0 398b
398a 3988 3989 :6 0
398d a4 :3 0 1fa3
398f 1fa5 398e 398d
:2 0 3990 1fa7 :2 0
3992 0 3992 3991
393f 3990 :6 0 39d3
6f :3 0 8b :3 0
2dc :3 0 e8 :3 0
22d :3 0 72 :3 0
1faa 3997 3999 48
:2 0 1fac 3996 399c
2dd :2 0 e8 :3 0
22d :3 0 5b :3 0
1faf 39a0 39a2 48
:2 0 1fb1 399f 39a5
1fb4 399e 39a7 :3 0
39a8 :2 0 1c1 :2 0
2eb :2 0 1fb7 39aa
39ac :3 0 1fba 3995
39ae 3994 39af 0
39d3 78 :3 0 20b
:3 0 1b2 :3 0 39b2
39b3 0 e8 :3 0
8b :3 0 48 :2 0
1fbc 39b5 39b8 1a
:3 0 2ec :3 0 39ba
39bb 0 1fbf 39b4
39bd 39b1 39be 0
39d3 7e :3 0 24c
:3 0 2b :3 0 24
:3 0 78 :3 0 e8
:3 0 5b :3 0 48
:2 0 1fc2 39c5 39c8
e8 :3 0 89 :3 0
48 :2 0 1fc5 39ca
39cd 48 :2 0 1fc8
39c1 39d0 39c0 39d1
0 39d3 1fcf 39d7
2d8 :3 0 39d4 :4 0
39d6 1fdc 39d8 3701
39d3 0 39d9 0
39d6 0 39d9 1fde
0 39da 1fe1 43f0
4b :3 0 9 :3 0
39db 39dc 0 43ef
2d :3 0 7 :3 0
39de 39df 0 43ef
2f :3 0 f7 :4 0
39e1 39e2 0 43ef
e8 :3 0 73 :3 0
48 :2 0 1fe8 39e4
39e7 15c :2 0 48
:2 0 1fed 39e9 39eb
:3 0 e8 :3 0 54
:3 0 48 :2 0 1ff0
39ed 39f0 e8 :3 0
15c :2 0 f :3 0
48 :2 0 1ff3 39f2
39f6 1ff8 39f3 39f8
:3 0 e8 :3 0 50
:3 0 48 :2 0 1ffb
39fa 39fd e8 :3 0
15c :2 0 b :3 0
48 :2 0 1ffe 39ff
3a03 2003 3a00 3a05
:3 0 39f9 3a07 3a06
:2 0 130 :3 0 1e9
:3 0 3a09 3a0a 0
2d :3 0 38 :3 0
1ea :2 0 2006 3a0b
3a0f 1eb :2 0 48
:2 0 200c 3a11 3a13
:3 0 3a14 :2 0 3a08
3a16 3a15 :2 0 91
:3 0 1a :3 0 1d5
:3 0 3a19 3a1a 0
3a18 3a1b 0 3a23
90 :3 0 2a :3 0
3a1d 3a1e 0 3a23
284 :8 0 3a23 16a
:3 0 200f 3b24 130
:3 0 1e9 :3 0 3a24
3a25 0 2d :3 0
38 :3 0 1ea :2 0
2013 3a26 3a2a f3
:2 0 48 :2 0 2019
3a2c 3a2e :3 0 1f0
:3 0 8f :3 0 1db
:3 0 a9 :3 0 2b
:3 0 b2 :3 0 27
:3 0 1f1 :3 0 38
:4 0 2ed 1 :8 0
3a3f 15 :3 0 fa
:3 0 3a3a 3a3b 0
fd :3 0 3a3c 3a3d
0 3a3f 201c 3a92
fe :3 0 15 :3 0
fa :3 0 3a41 3a42
0 fd :3 0 3a43
3a44 0 3a46 201f
3a48 2021 3a47 3a46
:2 0 3a90 ff :3 0
15 :3 0 fa :3 0
3a4b 3a4c 0 fd
:3 0 3a4d 3a4e 0
3a88 db :3 0 dc
:3 0 3a50 3a51 0
db :3 0 ec :3 0
3a53 3a54 0 100
:2 0 2 :4 0 2ee
:2 0 ee :2 0 33
:2 0 2023 3a59 3a5b
:3 0 2026 3a55 3a5d
3a52 3a5f 3a5e :2 0
de :3 0 ef :3 0
3a61 3a62 0 e0
:4 0 2ef :4 0 e3
:2 0 e4 :3 0 202a
3a66 3a68 :3 0 e3
:2 0 103 :4 0 202d
3a6a 3a6c :3 0 e3
:2 0 104 :4 0 2030
3a6e 3a70 :3 0 e3
:2 0 fd :3 0 2033
3a72 3a74 :3 0 e3
:2 0 105 :4 0 2036
3a76 3a78 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 2039 3a7b 3a7f
203d 3a7a 3a81 :3 0
2040 3a63 3a83 :2 0
3a85 2043 3a86 3a60
3a85 0 3a87 2045
0 3a88 2047 3a8b
:3 0 3a8b 0 3a8b
3a8a 3a88 3a89 :6 0
3a8d a6 :3 0 204a
3a8f 204c 3a8e 3a8d
:2 0 3a90 204e :2 0
3a92 0 3a92 3a91
3a3f 3a90 :6 0 3b22
6f :3 0 15 :3 0
fa :3 0 3a94 3a95
0 15 :3 0 f3
:2 0 173 :3 0 3a97
3a99 0 2053 3a98
3a9b :3 0 3a9c :2 0
4b :3 0 e8 :3 0
4b :3 0 48 :2 0
2056 3a9f 3aa2 ee
:2 0 e8 :3 0 8f
:3 0 48 :2 0 2059
3aa5 3aa8 205c 3aa4
3aaa :3 0 3a9e 3aab
0 3b1f 1db :3 0
a9 :3 0 2b :3 0
b2 :3 0 27 :3 0
1f1 :3 0 38 :4 0
2f0 1 :8 0 3aca
f9 :4 0 3ab5 :3 0
112 :3 0 f3 :2 0
2061 3ab8 3ab9 :3 0
15 :3 0 fa :3 0
3abb 3abc 0 48
:2 0 3abd 3abe 0
3ac0 2064 3ac7 15
:3 0 fa :3 0 3ac1
3ac2 0 fb :2 0
3ac3 3ac4 0 3ac6
2066 3ac8 3aba 3ac0
0 3ac9 0 3ac6
0 3ac9 2068 0
3aca 206b 3b1d fe
:3 0 15 :3 0 fa
:3 0 3acc 3acd 0
fd :3 0 3ace 3acf
0 3ad1 206e 3ad3
2070 3ad2 3ad1 :2 0
3b1b ff :3 0 15
:3 0 fa :3 0 3ad6
3ad7 0 fd :3 0
3ad8 3ad9 0 3b13
db :3 0 dc :3 0
3adb 3adc 0 db
:3 0 ec :3 0 3ade
3adf 0 100 :2 0
2 :4 0 2f1 :2 0
ee :2 0 33 :2 0
2072 3ae4 3ae6 :3 0
2075 3ae0 3ae8 3add
3aea 3ae9 :2 0 de
:3 0 ef :3 0 3aec
3aed 0 e0 :4 0
2f2 :4 0 e3 :2 0
e4 :3 0 2079 3af1
3af3 :3 0 e3 :2 0
103 :4 0 207c 3af5
3af7 :3 0 e3 :2 0
104 :4 0 207f 3af9
3afb :3 0 e3 :2 0
fd :3 0 2082 3afd
3aff :3 0 e3 :2 0
105 :4 0 2085 3b01
3b03 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
2088 3b06 3b0a 208c
3b05 3b0c :3 0 208f
3aee 3b0e :2 0 3b10
2092 3b11 3aeb 3b10
0 3b12 2094 0
3b13 2096 3b16 :3 0
3b16 0 3b16 3b15
3b13 3b14 :6 0 3b18
a8 :3 0 2099 3b1a
209b 3b19 3b18 :2 0
3b1b 209d :2 0 3b1d
0 3b1d 3b1c 3aca
3b1b :6 0 3b1f 6f
:3 0 20a0 3b20 3a9d
3b1f 0 3b21 20a3
0 3b22 20a5 3b23
3a2f 3b22 0 3b25
3a17 3a23 0 3b25
20a8 0 3b26 20ab
3bb4 9a :3 0 15c
:2 0 48 :2 0 20af
3b28 3b2a :3 0 161
:2 0 20b2 3b2c 3b2d
:3 0 26 :3 0 1ce
:2 0 20b4 3b30 3b31
:3 0 3b32 :2 0 3b2e
3b34 3b33 :2 0 5e
:3 0 1a :3 0 f5
:3 0 3b37 3b38 0
3b36 3b39 0 3b3b
20b6 3b3c 3b35 3b3b
0 3b3d 20b8 0
3bb3 e8 :3 0 54
:3 0 48 :2 0 20ba
3b3e 3b41 e8 :3 0
15c :2 0 f :3 0
48 :2 0 20bd 3b43
3b47 20c2 3b44 3b49
:3 0 e8 :3 0 50
:3 0 48 :2 0 20c5
3b4b 3b4e e8 :3 0
15c :2 0 b :3 0
48 :2 0 20c8 3b50
3b54 20cd 3b51 3b56
:3 0 3b4a 3b58 3b57
:2 0 64 :3 0 33
:2 0 3b5a 3b5b 0
3b6c e8 :3 0 f
:3 0 48 :2 0 20d0
3b5d 3b60 f3 :2 0
48 :2 0 20d5 3b62
3b64 :3 0 8b :3 0
48 :2 0 3b66 3b67
0 3b69 20d8 3b6a
3b65 3b69 0 3b6b
20da 0 3b6c 20dc
3b6d 3b59 3b6c 0
3b6e 20df 0 3bb3
2f :3 0 8 :3 0
3b6f 3b70 0 3bb3
50 :3 0 b :3 0
3b72 3b73 0 3bb3
51 :3 0 10 :3 0
3b75 3b76 0 3bb3
52 :3 0 d :3 0
3b78 3b79 0 3bb3
53 :3 0 e :3 0
3b7b 3b7c 0 3bb3
5a :3 0 c :3 0
3b7e 3b7f 0 3bb3
54 :3 0 f :3 0
3b81 3b82 0 3bb3
e8 :3 0 54 :3 0
48 :2 0 20e1 3b84
3b87 f3 :2 0 48
:2 0 20e6 3b89 3b8b
:3 0 3b8c :2 0 e8
:3 0 53 :3 0 48
:2 0 20e9 3b8e 3b91
15c :2 0 fb :2 0
20ee 3b93 3b95 :3 0
3b96 :2 0 3b8d 3b98
3b97 :2 0 50 :3 0
48 :2 0 3b9a 3b9b
0 3b9e 16a :3 0
20f1 3bb1 e8 :3 0
53 :3 0 48 :2 0
20f3 3b9f 3ba2 f3
:2 0 fb :2 0 20f8
3ba4 3ba6 :3 0 8b
:3 0 e8 :3 0 50
:3 0 48 :2 0 20fb
3ba9 3bac 3ba8 3bad
0 3baf 20fe 3bb0
3ba7 3baf 0 3bb2
3b99 3b9e 0 3bb2
2100 0 3bb3 2103
3bb5 39ec 3b26 0
3bb6 0 3bb3 0
3bb6 210e 0 43ef
78 :3 0 1f8 :3 0
2d :3 0 2f :3 0
e8 :3 0 52 :3 0
48 :2 0 2111 3bbb
3bbe e8 :3 0 53
:3 0 48 :2 0 2114
3bc0 3bc3 e8 :3 0
5e :3 0 48 :2 0
2117 3bc5 3bc8 e8
:3 0 5a :3 0 48
:2 0 211a 3bca 3bcd
e8 :3 0 54 :3 0
48 :2 0 211d 3bcf
3bd2 e8 :3 0 51
:3 0 48 :2 0 2120
3bd4 3bd7 e8 :3 0
5b :3 0 48 :2 0
2123 3bd9 3bdc e8
:3 0 5c :3 0 48
:2 0 2126 3bde 3be1
50 :3 0 4b :3 0
55 :3 0 2129 3bb8
3be6 3bb7 3be7 0
43ef e8 :3 0 78
:3 0 48 :2 0 2137
3be9 3bec 1a :3 0
f3 :2 0 1f9 :3 0
3bee 3bf0 0 213c
3bef 3bf2 :3 0 fc
:3 0 ae :4 0 3bf7
:2 0 3bfd 3bf5 0
15 :3 0 fa :3 0
3bf8 3bf9 0 fd
:3 0 3bfa 3bfb 0
3bfd 213f 3c50 fe
:3 0 15 :3 0 fa
:3 0 3bff 3c00 0
fd :3 0 3c01 3c02
0 3c04 2142 3c06
2144 3c05 3c04 :2 0
3c4e ff :3 0 15
:3 0 fa :3 0 3c09
3c0a 0 fd :3 0
3c0b 3c0c 0 3c46
db :3 0 dc :3 0
3c0e 3c0f 0 db
:3 0 ec :3 0 3c11
3c12 0 100 :2 0
2 :4 0 2f3 :2 0
ee :2 0 33 :2 0
2146 3c17 3c19 :3 0
2149 3c13 3c1b 3c10
3c1d 3c1c :2 0 de
:3 0 ef :3 0 3c1f
3c20 0 e0 :4 0
2f4 :4 0 e3 :2 0
e4 :3 0 214d 3c24
3c26 :3 0 e3 :2 0
103 :4 0 2150 3c28
3c2a :3 0 e3 :2 0
104 :4 0 2153 3c2c
3c2e :3 0 e3 :2 0
fd :3 0 2156 3c30
3c32 :3 0 e3 :2 0
105 :4 0 2159 3c34
3c36 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
215c 3c39 3c3d 2160
3c38 3c3f :3 0 2163
3c21 3c41 :2 0 3c43
2166 3c44 3c1e 3c43
0 3c45 2168 0
3c46 216a 3c49 :3 0
3c49 0 3c49 3c48
3c46 3c47 :6 0 3c4b
aa :3 0 216d 3c4d
216f 3c4c 3c4b :2 0
3c4e 2171 :2 0 3c50
0 3c50 3c4f 3bfd
3c4e :6 0 3caf 6f
:3 0 db :3 0 dc
:3 0 3c52 3c53 0
db :3 0 ec :3 0
3c55 3c56 0 1fa
:2 0 2 :4 0 2f5
:2 0 ee :2 0 33
:2 0 2174 3c5b 3c5d
:3 0 2177 3c57 3c5f
3c54 3c61 3c60 :2 0
de :3 0 ef :3 0
3c63 3c64 0 e0
:4 0 2f6 :4 0 e3
:2 0 e4 :3 0 217b
3c68 3c6a :3 0 e3
:2 0 103 :4 0 217e
3c6c 3c6e :3 0 e3
:2 0 10b :4 0 2181
3c70 3c72 :3 0 e3
:2 0 e8 :3 0 e9
:3 0 1a :3 0 1f9
:3 0 3c77 3c78 0
2184 3c76 3c7a ea
:4 0 2186 3c75 3c7d
2189 3c74 3c7f :3 0
218c 3c65 3c81 :2 0
3c83 218f 3c84 3c62
3c83 0 3c85 2191
0 3caf db :3 0
dc :3 0 3c86 3c87
0 db :3 0 ec
:3 0 3c89 3c8a 0
33 :2 0 2 :4 0
2f7 :2 0 ee :2 0
33 :2 0 2193 3c8f
3c91 :3 0 2196 3c8b
3c93 3c88 3c95 3c94
:2 0 de :3 0 ef
:3 0 3c97 3c98 0
e0 :4 0 2f8 :4 0
e3 :2 0 e4 :3 0
219a 3c9c 3c9e :3 0
219d 3c99 3ca0 :2 0
3ca2 21a0 3ca3 3c96
3ca2 0 3ca4 21a2
0 3caf 110 :3 0
1ff :3 0 3ca5 3ca6
0 1a :3 0 1f9
:3 0 3ca8 3ca9 0
112 :3 0 21a4 3ca7
3cac :2 0 3caf 16a
:3 0 21a7 3cc7 e8
:3 0 78 :3 0 48
:2 0 21ac 3cb0 3cb3
15c :2 0 48 :2 0
21b1 3cb5 3cb7 :3 0
91 :3 0 e8 :3 0
78 :3 0 48 :2 0
21b4 3cba 3cbd 3cb9
3cbe 0 3cc5 90
:3 0 2b :3 0 3cc0
3cc1 0 3cc5 284
:8 0 3cc5 21b7 3cc6
3cb8 3cc5 0 3cc8
3bf3 3caf 0 3cc8
21bb 0 43ef 4c
:3 0 48 :2 0 3cc9
3cca 0 43ef e8
:3 0 73 :3 0 48
:2 0 21be 3ccc 3ccf
15c :2 0 48 :2 0
21c3 3cd1 3cd3 :3 0
5d :3 0 33 :2 0
3cd5 3cd6 0 3cfb
e8 :3 0 50 :3 0
48 :2 0 21c6 3cd8
3cdb f3 :2 0 48
:2 0 21cb 3cdd 3cdf
:3 0 5a :3 0 1a
:3 0 20a :3 0 3ce2
3ce3 0 3ce1 3ce4
0 3ce6 21ce 3cf7
5a :3 0 20b :3 0
1b2 :3 0 3ce8 3ce9
0 e8 :3 0 5a
:3 0 48 :2 0 21d0
3ceb 3cee 1a :3 0
20a :3 0 3cf0 3cf1
0 21d3 3cea 3cf3
3ce7 3cf4 0 3cf6
21d6 3cf8 3ce0 3ce6
0 3cf9 0 3cf6
0 3cf9 21d8 0
3cfb 16a :3 0 21db
3d54 e8 :3 0 5e
:3 0 48 :2 0 21de
3cfc 3cff 1a :3 0
f3 :2 0 f5 :3 0
3d01 3d03 0 21e3
3d02 3d05 :3 0 5d
:3 0 24b :2 0 3d07
3d08 0 3d2c e8
:3 0 50 :3 0 48
:2 0 21e6 3d0a 3d0d
f3 :2 0 48 :2 0
21eb 3d0f 3d11 :3 0
5a :3 0 1a :3 0
2f9 :3 0 3d14 3d15
0 3d13 3d16 0
3d18 21ee 3d29 5a
:3 0 20b :3 0 1b2
:3 0 3d1a 3d1b 0
e8 :3 0 5a :3 0
48 :2 0 21f0 3d1d
3d20 1a :3 0 2f9
:3 0 3d22 3d23 0
21f3 3d1c 3d25 3d19
3d26 0 3d28 21f6
3d2a 3d12 3d18 0
3d2b 0 3d28 0
3d2b 21f8 0 3d2c
21fb 3d2d 3d06 3d2c
0 3d56 5d :3 0
153 :2 0 3d2e 3d2f
0 3d53 e8 :3 0
50 :3 0 48 :2 0
21fe 3d31 3d34 f3
:2 0 48 :2 0 2203
3d36 3d38 :3 0 5a
:3 0 1a :3 0 20c
:3 0 3d3b 3d3c 0
3d3a 3d3d 0 3d3f
2206 3d50 5a :3 0
20b :3 0 1b2 :3 0
3d41 3d42 0 e8
:3 0 5a :3 0 48
:2 0 2208 3d44 3d47
1a :3 0 20c :3 0
3d49 3d4a 0 220b
3d43 3d4c 3d40 3d4d
0 3d4f 220e 3d51
3d39 3d3f 0 3d52
0 3d4f 0 3d52
2210 0 3d53 2213
3d55 3cd4 3cfb 0
3d56 0 3d53 0
3d56 2216 0 43ef
51 :3 0 48 :2 0
3d57 3d58 0 43ef
96 :3 0 22c :3 0
25 :3 0 2b :3 0
29 :3 0 2a :3 0
77 :3 0 4d :3 0
34 :3 0 34 :3 0
34 :3 0 34 :3 0
2d :3 0 2f :3 0
55 :3 0 4b :3 0
50 :3 0 52 :3 0
53 :3 0 4c :3 0
5e :3 0 39 :3 0
56 :3 0 5a :3 0
54 :3 0 51 :3 0
5d :3 0 5b :3 0
5f :3 0 21 :3 0
48 :2 0 48 :2 0
22b :2 0 22b :2 0
48 :2 0 48 :2 0
221a 3d5b 3d7e 3d5a
3d7f 0 43ef 96
:3 0 f3 :2 0 22f
:2 0 223f 3d82 3d84
:3 0 91 :3 0 1a
:3 0 232 :3 0 3d87
3d88 0 3d86 3d89
0 3d91 90 :3 0
2a :3 0 3d8b 3d8c
0 3d91 284 :8 0
3d91 16a :3 0 2242
4098 96 :3 0 15c
:2 0 48 :2 0 2248
3d93 3d95 :3 0 91
:3 0 1a :3 0 1d5
:3 0 3d98 3d99 0
3d97 3d9a 0 3da1
90 :3 0 23 :3 0
3d9c 3d9d 0 3da1
284 :8 0 3da1 224b
3da2 3d96 3da1 0
409a 25 :3 0 239
:2 0 224f 3da4 3da5
:3 0 3da6 :2 0 e8
:3 0 56 :3 0 48
:2 0 2251 3da8 3dab
f3 :2 0 153 :2 0
2256 3dad 3daf :3 0
b2 :3 0 24d :3 0
24e :3 0 2fa :3 0
25 :3 0 2d :3 0
2f :3 0 4b :3 0
a8 :3 0 a9 :3 0
2b :3 0 b3 :3 0
29 :3 0 aa :3 0
2a :4 0 2fb 1
:8 0 3dc6 15 :3 0
fa :3 0 3dc1 3dc2
0 fd :3 0 3dc3
3dc4 0 3dc6 2259
3e19 fe :3 0 15
:3 0 fa :3 0 3dc8
3dc9 0 fd :3 0
3dca 3dcb 0 3dcd
225c 3dcf 225e 3dce
3dcd :2 0 3e17 ff
:3 0 15 :3 0 fa
:3 0 3dd2 3dd3 0
fd :3 0 3dd4 3dd5
0 3e0f db :3 0
dc :3 0 3dd7 3dd8
0 db :3 0 ec
:3 0 3dda 3ddb 0
100 :2 0 2 :4 0
2fc :2 0 ee :2 0
33 :2 0 2260 3de0
3de2 :3 0 2263 3ddc
3de4 3dd9 3de6 3de5
:2 0 de :3 0 ef
:3 0 3de8 3de9 0
e0 :4 0 2fd :4 0
e3 :2 0 e4 :3 0
2267 3ded 3def :3 0
e3 :2 0 103 :4 0
226a 3df1 3df3 :3 0
e3 :2 0 104 :4 0
226d 3df5 3df7 :3 0
e3 :2 0 fd :3 0
2270 3df9 3dfb :3 0
e3 :2 0 105 :4 0
2273 3dfd 3dff :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 2276 3e02
3e06 227a 3e01 3e08
:3 0 227d 3dea 3e0a
:2 0 3e0c 2280 3e0d
3de7 3e0c 0 3e0e
2282 0 3e0f 2284
3e12 :3 0 3e12 0
3e12 3e11 3e0f 3e10
:6 0 3e14 ac :3 0
2287 3e16 2289 3e15
3e14 :2 0 3e17 228b
:2 0 3e19 0 3e19
3e18 3dc6 3e17 :6 0
3e1b 6f :3 0 228e
3e87 b2 :3 0 b7
:3 0 b8 :3 0 b5
:3 0 25 :3 0 2d
:3 0 2f :3 0 4b
:3 0 a8 :3 0 a9
:3 0 2b :3 0 b3
:3 0 29 :3 0 aa
:3 0 2a :4 0 2fe
1 :8 0 3e31 15
:3 0 fa :3 0 3e2c
3e2d 0 fd :3 0
3e2e 3e2f 0 3e31
2290 3e84 fe :3 0
15 :3 0 fa :3 0
3e33 3e34 0 fd
:3 0 3e35 3e36 0
3e38 2293 3e3a 2295
3e39 3e38 :2 0 3e82
ff :3 0 15 :3 0
fa :3 0 3e3d 3e3e
0 fd :3 0 3e3f
3e40 0 3e7a db
:3 0 dc :3 0 3e42
3e43 0 db :3 0
ec :3 0 3e45 3e46
0 100 :2 0 2
:4 0 2ff :2 0 ee
:2 0 33 :2 0 2297
3e4b 3e4d :3 0 229a
3e47 3e4f 3e44 3e51
3e50 :2 0 de :3 0
ef :3 0 3e53 3e54
0 e0 :4 0 300
:4 0 e3 :2 0 e4
:3 0 229e 3e58 3e5a
:3 0 e3 :2 0 103
:4 0 22a1 3e5c 3e5e
:3 0 e3 :2 0 104
:4 0 22a4 3e60 3e62
:3 0 e3 :2 0 fd
:3 0 22a7 3e64 3e66
:3 0 e3 :2 0 105
:4 0 22aa 3e68 3e6a
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 22ad
3e6d 3e71 22b1 3e6c
3e73 :3 0 22b4 3e55
3e75 :2 0 3e77 22b7
3e78 3e52 3e77 0
3e79 22b9 0 3e7a
22bb 3e7d :3 0 3e7d
0 3e7d 3e7c 3e7a
3e7b :6 0 3e7f ae
:3 0 22be 3e81 22c0
3e80 3e7f :2 0 3e82
22c2 :2 0 3e84 0
3e84 3e83 3e31 3e82
:6 0 3e86 6f :3 0
22c5 3e88 3db0 3e1b
0 3e89 0 3e86
0 3e89 22c7 0
3e8a 22ca 407d e8
:3 0 56 :3 0 48
:2 0 22cc 3e8b 3e8e
f3 :2 0 153 :2 0
22d1 3e90 3e92 :3 0
a8 :3 0 26a :3 0
2fa :3 0 b2 :3 0
25 :4 0 301 1
:8 0 3eaf f9 :4 0
3e9a :3 0 112 :3 0
f3 :2 0 22d6 3e9d
3e9e :3 0 15 :3 0
fa :3 0 3ea0 3ea1
0 48 :2 0 3ea2
3ea3 0 3ea5 22d9
3eac 15 :3 0 fa
:3 0 3ea6 3ea7 0
fb :2 0 3ea8 3ea9
0 3eab 22db 3ead
3e9f 3ea5 0 3eae
0 3eab 0 3eae
22dd 0 3eaf 22e0
3f02 fe :3 0 15
:3 0 fa :3 0 3eb1
3eb2 0 fd :3 0
3eb3 3eb4 0 3eb6
22e3 3eb8 22e5 3eb7
3eb6 :2 0 3f00 ff
:3 0 15 :3 0 fa
:3 0 3ebb 3ebc 0
fd :3 0 3ebd 3ebe
0 3ef8 db :3 0
dc :3 0 3ec0 3ec1
0 db :3 0 ec
:3 0 3ec3 3ec4 0
100 :2 0 2 :4 0
302 :2 0 ee :2 0
33 :2 0 22e7 3ec9
3ecb :3 0 22ea 3ec5
3ecd 3ec2 3ecf 3ece
:2 0 de :3 0 ef
:3 0 3ed1 3ed2 0
e0 :4 0 303 :4 0
e3 :2 0 e4 :3 0
22ee 3ed6 3ed8 :3 0
e3 :2 0 103 :4 0
22f1 3eda 3edc :3 0
e3 :2 0 104 :4 0
22f4 3ede 3ee0 :3 0
e3 :2 0 fd :3 0
22f7 3ee2 3ee4 :3 0
e3 :2 0 105 :4 0
22fa 3ee6 3ee8 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 22fd 3eeb
3eef 2301 3eea 3ef1
:3 0 2304 3ed3 3ef3
:2 0 3ef5 2307 3ef6
3ed0 3ef5 0 3ef7
2309 0 3ef8 230b
3efb :3 0 3efb 0
3efb 3efa 3ef8 3ef9
:6 0 3efd b0 :3 0
230e 3eff 2310 3efe
3efd :2 0 3f00 2312
:2 0 3f02 0 3f02
3f01 3eaf 3f00 :6 0
3f78 6f :3 0 78
:3 0 24b :2 0 3f04
3f05 0 3f78 7e
:3 0 24c :3 0 2b
:3 0 25 :3 0 78
:3 0 e8 :3 0 5b
:3 0 48 :2 0 2315
3f0c 3f0f 48 :2 0
48 :2 0 2318 3f08
3f13 3f07 3f14 0
3f78 24d :3 0 24e
:3 0 2d :3 0 2f
:3 0 a8 :3 0 b2
:3 0 25 :4 0 304
1 :8 0 3f23 15
:3 0 fa :3 0 3f1e
3f1f 0 fd :3 0
3f20 3f21 0 3f23
231f 3f76 fe :3 0
15 :3 0 fa :3 0
3f25 3f26 0 fd
:3 0 3f27 3f28 0
3f2a 2322 3f2c 2324
3f2b 3f2a :2 0 3f74
ff :3 0 15 :3 0
fa :3 0 3f2f 3f30
0 fd :3 0 3f31
3f32 0 3f6c db
:3 0 dc :3 0 3f34
3f35 0 db :3 0
ec :3 0 3f37 3f38
0 100 :2 0 2
:4 0 305 :2 0 ee
:2 0 33 :2 0 2326
3f3d 3f3f :3 0 2329
3f39 3f41 3f36 3f43
3f42 :2 0 de :3 0
ef :3 0 3f45 3f46
0 e0 :4 0 306
:4 0 e3 :2 0 e4
:3 0 232d 3f4a 3f4c
:3 0 e3 :2 0 103
:4 0 2330 3f4e 3f50
:3 0 e3 :2 0 104
:4 0 2333 3f52 3f54
:3 0 e3 :2 0 fd
:3 0 2336 3f56 3f58
:3 0 e3 :2 0 105
:4 0 2339 3f5a 3f5c
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 233c
3f5f 3f63 2340 3f5e
3f65 :3 0 2343 3f47
3f67 :2 0 3f69 2346
3f6a 3f44 3f69 0
3f6b 2348 0 3f6c
234a 3f6f :3 0 3f6f
0 3f6f 3f6e 3f6c
3f6d :6 0 3f71 b2
:3 0 234d 3f73 234f
3f72 3f71 :2 0 3f74
2351 :2 0 3f76 0
3f76 3f75 3f23 3f74
:6 0 3f78 6f :3 0
2354 405e a8 :3 0
26a :3 0 b5 :3 0
b2 :3 0 25 :4 0
307 1 :8 0 3f94
f9 :4 0 3f7f :3 0
112 :3 0 f3 :2 0
235b 3f82 3f83 :3 0
15 :3 0 fa :3 0
3f85 3f86 0 48
:2 0 3f87 3f88 0
3f8a 235e 3f91 15
:3 0 fa :3 0 3f8b
3f8c 0 fb :2 0
3f8d 3f8e 0 3f90
2360 3f92 3f84 3f8a
0 3f93 0 3f90
0 3f93 2362 0
3f94 2365 3fe7 fe
:3 0 15 :3 0 fa
:3 0 3f96 3f97 0
fd :3 0 3f98 3f99
0 3f9b 2368 3f9d
236a 3f9c 3f9b :2 0
3fe5 ff :3 0 15
:3 0 fa :3 0 3fa0
3fa1 0 fd :3 0
3fa2 3fa3 0 3fdd
db :3 0 dc :3 0
3fa5 3fa6 0 db
:3 0 ec :3 0 3fa8
3fa9 0 100 :2 0
2 :4 0 308 :2 0
ee :2 0 33 :2 0
236c 3fae 3fb0 :3 0
236f 3faa 3fb2 3fa7
3fb4 3fb3 :2 0 de
:3 0 ef :3 0 3fb6
3fb7 0 e0 :4 0
309 :4 0 e3 :2 0
e4 :3 0 2373 3fbb
3fbd :3 0 e3 :2 0
103 :4 0 2376 3fbf
3fc1 :3 0 e3 :2 0
104 :4 0 2379 3fc3
3fc5 :3 0 e3 :2 0
fd :3 0 237c 3fc7
3fc9 :3 0 e3 :2 0
105 :4 0 237f 3fcb
3fcd :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
2382 3fd0 3fd4 2386
3fcf 3fd6 :3 0 2389
3fb8 3fd8 :2 0 3fda
238c 3fdb 3fb5 3fda
0 3fdc 238e 0
3fdd 2390 3fe0 :3 0
3fe0 0 3fe0 3fdf
3fdd 3fde :6 0 3fe2
b4 :3 0 2393 3fe4
2395 3fe3 3fe2 :2 0
3fe5 2397 :2 0 3fe7
0 3fe7 3fe6 3f94
3fe5 :6 0 405d 6f
:3 0 78 :3 0 24b
:2 0 3fe9 3fea 0
405d 7e :3 0 24c
:3 0 2b :3 0 25
:3 0 78 :3 0 e8
:3 0 5b :3 0 48
:2 0 239a 3ff1 3ff4
48 :2 0 48 :2 0
239d 3fed 3ff8 3fec
3ff9 0 405d b7
:3 0 b8 :3 0 2d
:3 0 2f :3 0 a8
:3 0 b2 :3 0 25
:4 0 30a 1 :8 0
4008 15 :3 0 fa
:3 0 4003 4004 0
fd :3 0 4005 4006
0 4008 23a4 405b
fe :3 0 15 :3 0
fa :3 0 400a 400b
0 fd :3 0 400c
400d 0 400f 23a7
4011 23a9 4010 400f
:2 0 4059 ff :3 0
15 :3 0 fa :3 0
4014 4015 0 fd
:3 0 4016 4017 0
4051 db :3 0 dc
:3 0 4019 401a 0
db :3 0 ec :3 0
401c 401d 0 100
:2 0 2 :4 0 30b
:2 0 ee :2 0 33
:2 0 23ab 4022 4024
:3 0 23ae 401e 4026
401b 4028 4027 :2 0
de :3 0 ef :3 0
402a 402b 0 e0
:4 0 30c :4 0 e3
:2 0 e4 :3 0 23b2
402f 4031 :3 0 e3
:2 0 103 :4 0 23b5
4033 4035 :3 0 e3
:2 0 104 :4 0 23b8
4037 4039 :3 0 e3
:2 0 fd :3 0 23bb
403b 403d :3 0 e3
:2 0 105 :4 0 23be
403f 4041 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 23c1 4044 4048
23c5 4043 404a :3 0
23c8 402c 404c :2 0
404e 23cb 404f 4029
404e 0 4050 23cd
0 4051 23cf 4054
:3 0 4054 0 4054
4053 4051 4052 :6 0
4056 b6 :3 0 23d2
4058 23d4 4057 4056
:2 0 4059 23d6 :2 0
405b 0 405b 405a
4008 4059 :6 0 405d
6f :3 0 23d9 405f
3e93 3f78 0 4060
0 405d 0 4060
23de 0 407c e8
:3 0 8f :3 0 48
:2 0 23e1 4061 4064
15c :2 0 48 :2 0
23e6 4066 4068 :3 0
4b :3 0 e8 :3 0
4b :3 0 48 :2 0
23e9 406b 406e 1da
:2 0 e8 :3 0 8f
:3 0 48 :2 0 23ec
4071 4074 23ef 4070
4076 :3 0 406a 4077
0 4079 23f2 407a
4069 4079 0 407b
23f4 0 407c 23f6
407e 3da7 3e8a 0
407f 0 407c 0
407f 23f9 0 4097
15 :3 0 fa :3 0
4080 4081 0 15
:3 0 15c :2 0 173
:3 0 4083 4085 0
23fe 4084 4087 :3 0
4088 :2 0 91 :3 0
1a :3 0 1d5 :3 0
408b 408c 0 408a
408d 0 4094 90
:3 0 24 :3 0 408f
4090 0 4094 284
:8 0 4094 2401 4095
4089 4094 0 4096
2405 0 4097 2407
4099 3d85 3d91 0
409a 0 4097 0
409a 240a 0 43ef
e8 :3 0 73 :3 0
48 :2 0 240e 409b
409e 15c :2 0 48
:2 0 2413 40a0 40a2
:3 0 a8 :3 0 26a
:3 0 b5 :3 0 2fa
:3 0 b5 :3 0 25a
:3 0 1b1 :3 0 1b2
:3 0 25a :3 0 1a
:3 0 25b :3 0 258
:3 0 1b1 :3 0 1b2
:3 0 258 :3 0 1a
:3 0 259 :3 0 b2
:3 0 24 :4 0 30d
1 :8 0 40cd f9
:4 0 40b8 :3 0 112
:3 0 f3 :2 0 2418
40bb 40bc :3 0 15
:3 0 fa :3 0 40be
40bf 0 48 :2 0
40c0 40c1 0 40c3
241b 40ca 15 :3 0
fa :3 0 40c4 40c5
0 fb :2 0 40c6
40c7 0 40c9 241d
40cb 40bd 40c3 0
40cc 0 40c9 0
40cc 241f 0 40cd
2422 4120 fe :3 0
15 :3 0 fa :3 0
40cf 40d0 0 fd
:3 0 40d1 40d2 0
40d4 2425 40d6 2427
40d5 40d4 :2 0 411e
ff :3 0 15 :3 0
fa :3 0 40d9 40da
0 fd :3 0 40db
40dc 0 4116 db
:3 0 dc :3 0 40de
40df 0 db :3 0
ec :3 0 40e1 40e2
0 100 :2 0 2
:4 0 30e :2 0 ee
:2 0 33 :2 0 2429
40e7 40e9 :3 0 242c
40e3 40eb 40e0 40ed
40ec :2 0 de :3 0
ef :3 0 40ef 40f0
0 e0 :4 0 30f
:4 0 e3 :2 0 e4
:3 0 2430 40f4 40f6
:3 0 e3 :2 0 103
:4 0 2433 40f8 40fa
:3 0 e3 :2 0 104
:4 0 2436 40fc 40fe
:3 0 e3 :2 0 fd
:3 0 2439 4100 4102
:3 0 e3 :2 0 105
:4 0 243c 4104 4106
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 243f
4109 410d 2443 4108
410f :3 0 2446 40f1
4111 :2 0 4113 2449
4114 40ee 4113 0
4115 244b 0 4116
244d 4119 :3 0 4119
0 4119 4118 4116
4117 :6 0 411b b8
:3 0 2450 411d 2452
411c 411b :2 0 411e
2454 :2 0 4120 0
4120 411f 40cd 411e
:6 0 4122 6f :3 0
2457 41ae a8 :3 0
be :3 0 6e :3 0
65 :3 0 7f :3 0
bf :3 0 6e :3 0
68 :3 0 80 :3 0
c0 :3 0 6d :3 0
67 :3 0 81 :3 0
c1 :3 0 6d :3 0
69 :3 0 82 :3 0
258 :3 0 1b1 :3 0
1b2 :3 0 258 :3 0
1a :3 0 259 :3 0
25a :3 0 1b1 :3 0
1b2 :3 0 25a :3 0
1a :3 0 25b :3 0
b2 :3 0 25 :4 0
310 1 :8 0 4158
f9 :4 0 4143 :3 0
112 :3 0 f3 :2 0
245b 4146 4147 :3 0
15 :3 0 fa :3 0
4149 414a 0 48
:2 0 414b 414c 0
414e 245e 4155 15
:3 0 fa :3 0 414f
4150 0 fb :2 0
4151 4152 0 4154
2460 4156 4148 414e
0 4157 0 4154
0 4157 2462 0
4158 2465 41ab fe
:3 0 15 :3 0 fa
:3 0 415a 415b 0
fd :3 0 415c 415d
0 415f 2468 4161
246a 4160 415f :2 0
41a9 ff :3 0 15
:3 0 fa :3 0 4164
4165 0 fd :3 0
4166 4167 0 41a1
db :3 0 dc :3 0
4169 416a 0 db
:3 0 ec :3 0 416c
416d 0 100 :2 0
2 :4 0 311 :2 0
ee :2 0 33 :2 0
246c 4172 4174 :3 0
246f 416e 4176 416b
4178 4177 :2 0 de
:3 0 ef :3 0 417a
417b 0 e0 :4 0
312 :4 0 e3 :2 0
e4 :3 0 2473 417f
4181 :3 0 e3 :2 0
103 :4 0 2476 4183
4185 :3 0 e3 :2 0
104 :4 0 2479 4187
4189 :3 0 e3 :2 0
fd :3 0 247c 418b
418d :3 0 e3 :2 0
105 :4 0 247f 418f
4191 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
2482 4194 4198 2486
4193 419a :3 0 2489
417c 419c :2 0 419e
248c 419f 4179 419e
0 41a0 248e 0
41a1 2490 41a4 :3 0
41a4 0 41a4 41a3
41a1 41a2 :6 0 41a6
ba :3 0 2493 41a8
2495 41a7 41a6 :2 0
41a9 2497 :2 0 41ab
0 41ab 41aa 4158
41a9 :6 0 41ad 6f
:3 0 249a 41af 40a3
4122 0 41b0 0
41ad 0 41b0 249c
0 43ef e8 :3 0
89 :3 0 48 :2 0
249f 41b1 41b4 e8
:3 0 124 :2 0 4b
:3 0 48 :2 0 24a2
41b6 41ba 24a7 41b7
41bc :3 0 78 :3 0
25f :3 0 24 :3 0
3c :3 0 3d :3 0
25 :3 0 2d :3 0
2f :3 0 2b :3 0
e8 :3 0 5b :3 0
48 :2 0 24aa 41c7
41ca e8 :3 0 4b
:3 0 48 :2 0 24ad
41cc 41cf 33 :2 0
e8 :3 0 8f :3 0
48 :2 0 24b0 41d2
41d5 24b3 41bf 41d7
41be 41d8 0 41ed
9e :3 0 15 :3 0
fa :3 0 41db 41dc
0 41da 41dd 0
41ed 9c :3 0 1d9
:3 0 2b :3 0 2b
:3 0 24 :3 0 48
:2 0 24bf 41e0 41e5
41df 41e6 0 41ed
15 :3 0 fa :3 0
41e8 41e9 0 9e
:3 0 41ea 41eb 0
41ed 24c4 43da 1db
:3 0 a9 :3 0 2b
:3 0 b2 :3 0 24
:4 0 313 1 :8 0
4209 f9 :4 0 41f4
:3 0 112 :3 0 f3
:2 0 24cb 41f7 41f8
:3 0 15 :3 0 fa
:3 0 41fa 41fb 0
48 :2 0 41fc 41fd
0 41ff 24ce 4206
15 :3 0 fa :3 0
4200 4201 0 fb
:2 0 4202 4203 0
4205 24d0 4207 41f9
41ff 0 4208 0
4205 0 4208 24d2
0 4209 24d5 425c
fe :3 0 15 :3 0
fa :3 0 420b 420c
0 fd :3 0 420d
420e 0 4210 24d8
4212 24da 4211 4210
:2 0 425a ff :3 0
15 :3 0 fa :3 0
4215 4216 0 fd
:3 0 4217 4218 0
4252 db :3 0 dc
:3 0 421a 421b 0
db :3 0 ec :3 0
421d 421e 0 100
:2 0 2 :4 0 314
:2 0 ee :2 0 33
:2 0 24dc 4223 4225
:3 0 24df 421f 4227
421c 4229 4228 :2 0
de :3 0 ef :3 0
422b 422c 0 e0
:4 0 315 :4 0 e3
:2 0 e4 :3 0 24e3
4230 4232 :3 0 e3
:2 0 103 :4 0 24e6
4234 4236 :3 0 e3
:2 0 104 :4 0 24e9
4238 423a :3 0 e3
:2 0 fd :3 0 24ec
423c 423e :3 0 e3
:2 0 105 :4 0 24ef
4240 4242 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 24f2 4245 4249
24f6 4244 424b :3 0
24f9 422d 424d :2 0
424f 24fc 4250 422a
424f 0 4251 24fe
0 4252 2500 4255
:3 0 4255 0 4255
4254 4252 4253 :6 0
4257 bc :3 0 2503
4259 2505 4258 4257
:2 0 425a 2507 :2 0
425c 0 425c 425b
4209 425a :6 0 43d9
6f :3 0 e8 :3 0
56 :3 0 48 :2 0
250a 425e 4261 15c
:2 0 48 :2 0 250f
4263 4265 :3 0 a8
:3 0 b2 :3 0 24
:4 0 316 1 :8 0
4280 f9 :4 0 426b
:3 0 112 :3 0 f3
:2 0 2514 426e 426f
:3 0 15 :3 0 fa
:3 0 4271 4272 0
48 :2 0 4273 4274
0 4276 2517 427d
15 :3 0 fa :3 0
4277 4278 0 fb
:2 0 4279 427a 0
427c 2519 427e 4270
4276 0 427f 0
427c 0 427f 251b
0 4280 251e 42d3
fe :3 0 15 :3 0
fa :3 0 4282 4283
0 fd :3 0 4284
4285 0 4287 2521
4289 2523 4288 4287
:2 0 42d1 ff :3 0
15 :3 0 fa :3 0
428c 428d 0 fd
:3 0 428e 428f 0
42c9 db :3 0 dc
:3 0 4291 4292 0
db :3 0 ec :3 0
4294 4295 0 100
:2 0 2 :4 0 317
:2 0 ee :2 0 33
:2 0 2525 429a 429c
:3 0 2528 4296 429e
4293 42a0 429f :2 0
de :3 0 ef :3 0
42a2 42a3 0 e0
:4 0 318 :4 0 e3
:2 0 e4 :3 0 252c
42a7 42a9 :3 0 e3
:2 0 103 :4 0 252f
42ab 42ad :3 0 e3
:2 0 104 :4 0 2532
42af 42b1 :3 0 e3
:2 0 fd :3 0 2535
42b3 42b5 :3 0 e3
:2 0 105 :4 0 2538
42b7 42b9 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 253b 42bc 42c0
253f 42bb 42c2 :3 0
2542 42a4 42c4 :2 0
42c6 2545 42c7 42a1
42c6 0 42c8 2547
0 42c9 2549 42cc
:3 0 42cc 0 42cc
42cb 42c9 42ca :6 0
42ce be :3 0 254c
42d0 254e 42cf 42ce
:2 0 42d1 2550 :2 0
42d3 0 42d3 42d2
4280 42d1 :6 0 4354
6f :3 0 9e :3 0
15 :3 0 fa :3 0
42d6 42d7 0 42d5
42d8 0 4354 9c
:3 0 319 :3 0 22
:3 0 48 :2 0 2553
42db 42de 42da 42df
0 4354 15 :3 0
fa :3 0 42e1 42e2
0 9e :3 0 42e3
42e4 0 4354 c8
:3 0 b0 :3 0 22
:4 0 31a 1 :8 0
42ff f9 :4 0 42ea
:3 0 112 :3 0 f3
:2 0 2558 42ed 42ee
:3 0 15 :3 0 fa
:3 0 42f0 42f1 0
48 :2 0 42f2 42f3
0 42f5 255b 42fc
15 :3 0 fa :3 0
42f6 42f7 0 fb
:2 0 42f8 42f9 0
42fb 255d 42fd 42ef
42f5 0 42fe 0
42fb 0 42fe 255f
0 42ff 2562 4352
fe :3 0 15 :3 0
fa :3 0 4301 4302
0 fd :3 0 4303
4304 0 4306 2565
4308 2567 4307 4306
:2 0 4350 ff :3 0
15 :3 0 fa :3 0
430b 430c 0 fd
:3 0 430d 430e 0
4348 db :3 0 dc
:3 0 4310 4311 0
db :3 0 ec :3 0
4313 4314 0 100
:2 0 2 :4 0 31b
:2 0 ee :2 0 33
:2 0 2569 4319 431b
:3 0 256c 4315 431d
4312 431f 431e :2 0
de :3 0 ef :3 0
4321 4322 0 e0
:4 0 31c :4 0 e3
:2 0 e4 :3 0 2570
4326 4328 :3 0 e3
:2 0 103 :4 0 2573
432a 432c :3 0 e3
:2 0 104 :4 0 2576
432e 4330 :3 0 e3
:2 0 fd :3 0 2579
4332 4334 :3 0 e3
:2 0 105 :4 0 257c
4336 4338 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 257f 433b 433f
2583 433a 4341 :3 0
2586 4323 4343 :2 0
4345 2589 4346 4320
4345 0 4347 258b
0 4348 258d 434b
:3 0 434b 0 434b
434a 4348 4349 :6 0
434d c0 :3 0 2590
434f 2592 434e 434d
:2 0 4350 2594 :2 0
4352 0 4352 4351
42ff 4350 :6 0 4354
6f :3 0 2597 43d6
a8 :3 0 263 :3 0
2d :3 0 264 :3 0
2d :3 0 265 :3 0
266 :3 0 267 :3 0
268 :3 0 269 :3 0
b7 :3 0 b8 :3 0
bb :3 0 b5 :3 0
26a :3 0 26c :3 0
1e5 :3 0 116 :3 0
26d :3 0 b2 :3 0
24 :4 0 31d 1
:8 0 4380 f9 :4 0
436b :3 0 112 :3 0
f3 :2 0 259f 436e
436f :3 0 15 :3 0
fa :3 0 4371 4372
0 48 :2 0 4373
4374 0 4376 25a2
437d 15 :3 0 fa
:3 0 4377 4378 0
fb :2 0 4379 437a
0 437c 25a4 437e
4370 4376 0 437f
0 437c 0 437f
25a6 0 4380 25a9
43d3 fe :3 0 15
:3 0 fa :3 0 4382
4383 0 fd :3 0
4384 4385 0 4387
25ac 4389 25ae 4388
4387 :2 0 43d1 ff
:3 0 15 :3 0 fa
:3 0 438c 438d 0
fd :3 0 438e 438f
0 43c9 db :3 0
dc :3 0 4391 4392
0 db :3 0 ec
:3 0 4394 4395 0
100 :2 0 2 :4 0
31e :2 0 ee :2 0
33 :2 0 25b0 439a
439c :3 0 25b3 4396
439e 4393 43a0 439f
:2 0 de :3 0 ef
:3 0 43a2 43a3 0
e0 :4 0 31f :4 0
e3 :2 0 e4 :3 0
25b7 43a7 43a9 :3 0
e3 :2 0 103 :4 0
25ba 43ab 43ad :3 0
e3 :2 0 104 :4 0
25bd 43af 43b1 :3 0
e3 :2 0 fd :3 0
25c0 43b3 43b5 :3 0
e3 :2 0 105 :4 0
25c3 43b7 43b9 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 25c6 43bc
43c0 25ca 43bb 43c2
:3 0 25cd 43a4 43c4
:2 0 43c6 25d0 43c7
43a1 43c6 0 43c8
25d2 0 43c9 25d4
43cc :3 0 43cc 0
43cc 43cb 43c9 43ca
:6 0 43ce c2 :3 0
25d7 43d0 25d9 43cf
43ce :2 0 43d1 25db
:2 0 43d3 0 43d3
43d2 4380 43d1 :6 0
43d5 6f :3 0 25de
43d7 4266 4354 0
43d8 0 43d5 0
43d8 25e0 0 43d9
25e3 43db 41bd 41ed
0 43dc 0 43d9
0 43dc 25e6 0
43ef 78 :3 0 48
:2 0 43dd 43de 0
43ef 7e :3 0 24c
:3 0 2b :3 0 24
:3 0 78 :3 0 e8
:3 0 5b :3 0 48
:2 0 25e9 43e5 43e8
48 :2 0 48 :2 0
25ec 43e1 43ec 43e0
43ed 0 43ef 25f3
43f1 353c 39da 0
43f2 0 43ef 0
43f2 2603 0 4571
e8 :3 0 73 :3 0
48 :2 0 2606 43f3
43f6 15c :2 0 48
:2 0 260b 43f8 43fa
:3 0 161 :2 0 260e
43fc 43fd :3 0 320
:3 0 25 :3 0 321
:3 0 a4 :3 0 321
:3 0 322 :3 0 321
:3 0 323 :3 0 321
:3 0 324 :3 0 321
:3 0 325 :3 0 326
:3 0 321 :3 0 134
:3 0 148 :3 0 327
:3 0 321 :3 0 a4
:3 0 327 :3 0 147
:3 0 327 :3 0 149
:3 0 2c :4 0 328
1 :8 0 442d f9
:4 0 4418 :3 0 112
:3 0 f3 :2 0 2612
441b 441c :3 0 15
:3 0 fa :3 0 441e
441f 0 48 :2 0
4420 4421 0 4423
2615 442a 15 :3 0
fa :3 0 4424 4425
0 fb :2 0 4426
4427 0 4429 2617
442b 441d 4423 0
442c 0 4429 0
442c 2619 0 442d
261c 4480 fe :3 0
15 :3 0 fa :3 0
442f 4430 0 fd
:3 0 4431 4432 0
4434 261f 4436 2621
4435 4434 :2 0 447e
ff :3 0 15 :3 0
fa :3 0 4439 443a
0 fd :3 0 443b
443c 0 4476 db
:3 0 dc :3 0 443e
443f 0 db :3 0
ec :3 0 4441 4442
0 100 :2 0 2
:4 0 329 :2 0 ee
:2 0 33 :2 0 2623
4447 4449 :3 0 2626
4443 444b 4440 444d
444c :2 0 de :3 0
ef :3 0 444f 4450
0 e0 :4 0 32a
:4 0 e3 :2 0 e4
:3 0 262a 4454 4456
:3 0 e3 :2 0 103
:4 0 262d 4458 445a
:3 0 e3 :2 0 104
:4 0 2630 445c 445e
:3 0 e3 :2 0 fd
:3 0 2633 4460 4462
:3 0 e3 :2 0 105
:4 0 2636 4464 4466
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 2639
4469 446d 263d 4468
446f :3 0 2640 4451
4471 :2 0 4473 2643
4474 444e 4473 0
4475 2645 0 4476
2647 4479 :3 0 4479
0 4479 4478 4476
4477 :6 0 447b c4
:3 0 264a 447d 264c
447c 447b :2 0 447e
264e :2 0 4480 0
4480 447f 442d 447e
:6 0 456e 6f :3 0
320 :3 0 25 :3 0
147 :3 0 322 :3 0
323 :3 0 324 :3 0
325 :3 0 32b :3 0
320 :3 0 b0 :3 0
2c :4 0 32c 1
:8 0 44a3 f9 :4 0
448e :3 0 112 :3 0
f3 :2 0 2653 4491
4492 :3 0 15 :3 0
fa :3 0 4494 4495
0 48 :2 0 4496
4497 0 4499 2656
44a0 15 :3 0 fa
:3 0 449a 449b 0
fb :2 0 449c 449d
0 449f 2658 44a1
4493 4499 0 44a2
0 449f 0 44a2
265a 0 44a3 265d
44f6 fe :3 0 15
:3 0 fa :3 0 44a5
44a6 0 fd :3 0
44a7 44a8 0 44aa
2660 44ac 2662 44ab
44aa :2 0 44f4 ff
:3 0 15 :3 0 fa
:3 0 44af 44b0 0
fd :3 0 44b1 44b2
0 44ec db :3 0
dc :3 0 44b4 44b5
0 db :3 0 ec
:3 0 44b7 44b8 0
100 :2 0 2 :4 0
32d :2 0 ee :2 0
33 :2 0 2664 44bd
44bf :3 0 2667 44b9
44c1 44b6 44c3 44c2
:2 0 de :3 0 ef
:3 0 44c5 44c6 0
e0 :4 0 32e :4 0
e3 :2 0 e4 :3 0
266b 44ca 44cc :3 0
e3 :2 0 103 :4 0
266e 44ce 44d0 :3 0
e3 :2 0 104 :4 0
2671 44d2 44d4 :3 0
e3 :2 0 fd :3 0
2674 44d6 44d8 :3 0
e3 :2 0 105 :4 0
2677 44da 44dc :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 267a 44df
44e3 267e 44de 44e5
:3 0 2681 44c7 44e7
:2 0 44e9 2684 44ea
44c4 44e9 0 44eb
2686 0 44ec 2688
44ef :3 0 44ef 0
44ef 44ee 44ec 44ed
:6 0 44f1 c6 :3 0
268b 44f3 268d 44f2
44f1 :2 0 44f4 268f
:2 0 44f6 0 44f6
44f5 44a3 44f4 :6 0
456e 6f :3 0 32f
:3 0 25 :3 0 330
:3 0 322 :3 0 323
:3 0 324 :3 0 325
:3 0 331 :3 0 32f
:3 0 b0 :3 0 2c
:4 0 332 1 :8 0
4519 f9 :4 0 4504
:3 0 112 :3 0 f3
:2 0 2694 4507 4508
:3 0 15 :3 0 fa
:3 0 450a 450b 0
48 :2 0 450c 450d
0 450f 2697 4516
15 :3 0 fa :3 0
4510 4511 0 fb
:2 0 4512 4513 0
4515 2699 4517 4509
450f 0 4518 0
4515 0 4518 269b
0 4519 269e 456c
fe :3 0 15 :3 0
fa :3 0 451b 451c
0 fd :3 0 451d
451e 0 4520 26a1
4522 26a3 4521 4520
:2 0 456a ff :3 0
15 :3 0 fa :3 0
4525 4526 0 fd
:3 0 4527 4528 0
4562 db :3 0 dc
:3 0 452a 452b 0
db :3 0 ec :3 0
452d 452e 0 100
:2 0 2 :4 0 333
:2 0 ee :2 0 33
:2 0 26a5 4533 4535
:3 0 26a8 452f 4537
452c 4539 4538 :2 0
de :3 0 ef :3 0
453b 453c 0 e0
:4 0 334 :4 0 e3
:2 0 e4 :3 0 26ac
4540 4542 :3 0 e3
:2 0 103 :4 0 26af
4544 4546 :3 0 e3
:2 0 104 :4 0 26b2
4548 454a :3 0 e3
:2 0 fd :3 0 26b5
454c 454e :3 0 e3
:2 0 105 :4 0 26b8
4550 4552 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 26bb 4555 4559
26bf 4554 455b :3 0
26c2 453d 455d :2 0
455f 26c5 4560 453a
455f 0 4561 26c7
0 4562 26c9 4565
:3 0 4565 0 4565
4564 4562 4563 :6 0
4567 c8 :3 0 26cc
4569 26ce 4568 4567
:2 0 456a 26d0 :2 0
456c 0 456c 456b
4519 456a :6 0 456e
6f :3 0 26d3 456f
43fe 456e 0 4570
26d7 0 4571 26d9
4572 2bb8 4571 0
4573 26e5 0 4574
26e7 607c 4b :3 0
e8 :3 0 89 :3 0
48 :2 0 26e9 4576
4579 4575 457a 0
607b e8 :3 0 4b
:3 0 48 :2 0 26ec
457c 457f f3 :2 0
48 :2 0 26f1 4581
4583 :3 0 7e :3 0
319 :3 0 22 :3 0
48 :2 0 26f4 4586
4589 4585 458a 0
4822 c8 :3 0 b0
:3 0 22 :4 0 31a
1 :8 0 45a5 f9
:4 0 4590 :3 0 112
:3 0 f3 :2 0 26f9
4593 4594 :3 0 15
:3 0 fa :3 0 4596
4597 0 48 :2 0
4598 4599 0 459b
26fc 45a2 15 :3 0
fa :3 0 459c 459d
0 fb :2 0 459e
459f 0 45a1 26fe
45a3 4595 459b 0
45a4 0 45a1 0
45a4 2700 0 45a5
2703 45f8 fe :3 0
15 :3 0 fa :3 0
45a7 45a8 0 fd
:3 0 45a9 45aa 0
45ac 2706 45ae 2708
45ad 45ac :2 0 45f6
ff :3 0 15 :3 0
fa :3 0 45b1 45b2
0 fd :3 0 45b3
45b4 0 45ee db
:3 0 dc :3 0 45b6
45b7 0 db :3 0
ec :3 0 45b9 45ba
0 100 :2 0 2
:4 0 335 :2 0 ee
:2 0 33 :2 0 270a
45bf 45c1 :3 0 270d
45bb 45c3 45b8 45c5
45c4 :2 0 de :3 0
ef :3 0 45c7 45c8
0 e0 :4 0 336
:4 0 e3 :2 0 e4
:3 0 2711 45cc 45ce
:3 0 e3 :2 0 103
:4 0 2714 45d0 45d2
:3 0 e3 :2 0 104
:4 0 2717 45d4 45d6
:3 0 e3 :2 0 fd
:3 0 271a 45d8 45da
:3 0 e3 :2 0 105
:4 0 271d 45dc 45de
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 2720
45e1 45e5 2724 45e0
45e7 :3 0 2727 45c9
45e9 :2 0 45eb 272a
45ec 45c6 45eb 0
45ed 272c 0 45ee
272e 45f1 :3 0 45f1
0 45f1 45f0 45ee
45ef :6 0 45f3 ca
:3 0 2731 45f5 2733
45f4 45f3 :2 0 45f6
2735 :2 0 45f8 0
45f8 45f7 45a5 45f6
:6 0 4822 6f :3 0
a8 :3 0 b2 :3 0
24 :4 0 337 1
:8 0 4613 f9 :4 0
45fe :3 0 112 :3 0
f3 :2 0 273a 4601
4602 :3 0 15 :3 0
fa :3 0 4604 4605
0 48 :2 0 4606
4607 0 4609 273d
4610 15 :3 0 fa
:3 0 460a 460b 0
fb :2 0 460c 460d
0 460f 273f 4611
4603 4609 0 4612
0 460f 0 4612
2741 0 4613 2744
4666 fe :3 0 15
:3 0 fa :3 0 4615
4616 0 fd :3 0
4617 4618 0 461a
2747 461c 2749 461b
461a :2 0 4664 ff
:3 0 15 :3 0 fa
:3 0 461f 4620 0
fd :3 0 4621 4622
0 465c db :3 0
dc :3 0 4624 4625
0 db :3 0 ec
:3 0 4627 4628 0
100 :2 0 2 :4 0
338 :2 0 ee :2 0
33 :2 0 274b 462d
462f :3 0 274e 4629
4631 4626 4633 4632
:2 0 de :3 0 ef
:3 0 4635 4636 0
e0 :4 0 339 :4 0
e3 :2 0 e4 :3 0
2752 463a 463c :3 0
e3 :2 0 103 :4 0
2755 463e 4640 :3 0
e3 :2 0 104 :4 0
2758 4642 4644 :3 0
e3 :2 0 fd :3 0
275b 4646 4648 :3 0
e3 :2 0 105 :4 0
275e 464a 464c :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 2761 464f
4653 2765 464e 4655
:3 0 2768 4637 4657
:2 0 4659 276b 465a
4634 4659 0 465b
276d 0 465c 276f
465f :3 0 465f 0
465f 465e 465c 465d
:6 0 4661 cc :3 0
2772 4663 2774 4662
4661 :2 0 4664 2776
:2 0 4666 0 4666
4665 4613 4664 :6 0
4822 6f :3 0 33a
:3 0 b2 :3 0 24
:4 0 33b 1 :8 0
4681 f9 :4 0 466c
:3 0 112 :3 0 f3
:2 0 277b 466f 4670
:3 0 15 :3 0 fa
:3 0 4672 4673 0
48 :2 0 4674 4675
0 4677 277e 467e
15 :3 0 fa :3 0
4678 4679 0 fb
:2 0 467a 467b 0
467d 2780 467f 4671
4677 0 4680 0
467d 0 4680 2782
0 4681 2785 46d4
fe :3 0 15 :3 0
fa :3 0 4683 4684
0 fd :3 0 4685
4686 0 4688 2788
468a 278a 4689 4688
:2 0 46d2 ff :3 0
15 :3 0 fa :3 0
468d 468e 0 fd
:3 0 468f 4690 0
46ca db :3 0 dc
:3 0 4692 4693 0
db :3 0 ec :3 0
4695 4696 0 100
:2 0 2 :4 0 33c
:2 0 ee :2 0 33
:2 0 278c 469b 469d
:3 0 278f 4697 469f
4694 46a1 46a0 :2 0
de :3 0 ef :3 0
46a3 46a4 0 e0
:4 0 33d :4 0 e3
:2 0 e4 :3 0 2793
46a8 46aa :3 0 e3
:2 0 103 :4 0 2796
46ac 46ae :3 0 e3
:2 0 104 :4 0 2799
46b0 46b2 :3 0 e3
:2 0 fd :3 0 279c
46b4 46b6 :3 0 e3
:2 0 105 :4 0 279f
46b8 46ba :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 27a2 46bd 46c1
27a6 46bc 46c3 :3 0
27a9 46a5 46c5 :2 0
46c7 27ac 46c8 46a2
46c7 0 46c9 27ae
0 46ca 27b0 46cd
:3 0 46cd 0 46cd
46cc 46ca 46cb :6 0
46cf ce :3 0 27b3
46d1 27b5 46d0 46cf
:2 0 46d2 27b7 :2 0
46d4 0 46d4 46d3
4681 46d2 :6 0 4822
6f :3 0 1db :3 0
a9 :3 0 2b :3 0
b2 :3 0 24 :4 0
33e 1 :8 0 46f1
f9 :4 0 46dc :3 0
112 :3 0 f3 :2 0
27bc 46df 46e0 :3 0
15 :3 0 fa :3 0
46e2 46e3 0 48
:2 0 46e4 46e5 0
46e7 27bf 46ee 15
:3 0 fa :3 0 46e8
46e9 0 fb :2 0
46ea 46eb 0 46ed
27c1 46ef 46e1 46e7
0 46f0 0 46ed
0 46f0 27c3 0
46f1 27c6 4744 fe
:3 0 15 :3 0 fa
:3 0 46f3 46f4 0
fd :3 0 46f5 46f6
0 46f8 27c9 46fa
27cb 46f9 46f8 :2 0
4742 ff :3 0 15
:3 0 fa :3 0 46fd
46fe 0 fd :3 0
46ff 4700 0 473a
db :3 0 dc :3 0
4702 4703 0 db
:3 0 ec :3 0 4705
4706 0 100 :2 0
2 :4 0 33f :2 0
ee :2 0 33 :2 0
27cd 470b 470d :3 0
27d0 4707 470f 4704
4711 4710 :2 0 de
:3 0 ef :3 0 4713
4714 0 e0 :4 0
340 :4 0 e3 :2 0
e4 :3 0 27d4 4718
471a :3 0 e3 :2 0
103 :4 0 27d7 471c
471e :3 0 e3 :2 0
104 :4 0 27da 4720
4722 :3 0 e3 :2 0
fd :3 0 27dd 4724
4726 :3 0 e3 :2 0
105 :4 0 27e0 4728
472a :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
27e3 472d 4731 27e7
472c 4733 :3 0 27ea
4715 4735 :2 0 4737
27ed 4738 4712 4737
0 4739 27ef 0
473a 27f1 473d :3 0
473d 0 473d 473c
473a 473b :6 0 473f
d0 :3 0 27f4 4741
27f6 4740 473f :2 0
4742 27f8 :2 0 4744
0 4744 4743 46f1
4742 :6 0 4822 6f
:3 0 320 :3 0 b0
:3 0 24 :4 0 341
1 :8 0 475f f9
:4 0 474a :3 0 112
:3 0 f3 :2 0 27fd
474d 474e :3 0 15
:3 0 fa :3 0 4750
4751 0 48 :2 0
4752 4753 0 4755
2800 475c 15 :3 0
fa :3 0 4756 4757
0 fb :2 0 4758
4759 0 475b 2802
475d 474f 4755 0
475e 0 475b 0
475e 2804 0 475f
2807 47b2 fe :3 0
15 :3 0 fa :3 0
4761 4762 0 fd
:3 0 4763 4764 0
4766 280a 4768 280c
4767 4766 :2 0 47b0
ff :3 0 15 :3 0
fa :3 0 476b 476c
0 fd :3 0 476d
476e 0 47a8 db
:3 0 dc :3 0 4770
4771 0 db :3 0
ec :3 0 4773 4774
0 100 :2 0 2
:4 0 342 :2 0 ee
:2 0 33 :2 0 280e
4779 477b :3 0 2811
4775 477d 4772 477f
477e :2 0 de :3 0
ef :3 0 4781 4782
0 e0 :4 0 343
:4 0 e3 :2 0 e4
:3 0 2815 4786 4788
:3 0 e3 :2 0 103
:4 0 2818 478a 478c
:3 0 e3 :2 0 104
:4 0 281b 478e 4790
:3 0 e3 :2 0 fd
:3 0 281e 4792 4794
:3 0 e3 :2 0 105
:4 0 2821 4796 4798
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 2824
479b 479f 2828 479a
47a1 :3 0 282b 4783
47a3 :2 0 47a5 282e
47a6 4780 47a5 0
47a7 2830 0 47a8
2832 47ab :3 0 47ab
0 47ab 47aa 47a8
47a9 :6 0 47ad d2
:3 0 2835 47af 2837
47ae 47ad :2 0 47b0
2839 :2 0 47b2 0
47b2 47b1 475f 47b0
:6 0 4822 6f :3 0
32f :3 0 b0 :3 0
24 :4 0 344 1
:8 0 47cd f9 :4 0
47b8 :3 0 112 :3 0
f3 :2 0 283e 47bb
47bc :3 0 15 :3 0
fa :3 0 47be 47bf
0 48 :2 0 47c0
47c1 0 47c3 2841
47ca 15 :3 0 fa
:3 0 47c4 47c5 0
fb :2 0 47c6 47c7
0 47c9 2843 47cb
47bd 47c3 0 47cc
0 47c9 0 47cc
2845 0 47cd 2848
4820 fe :3 0 15
:3 0 fa :3 0 47cf
47d0 0 fd :3 0
47d1 47d2 0 47d4
284b 47d6 284d 47d5
47d4 :2 0 481e ff
:3 0 15 :3 0 fa
:3 0 47d9 47da 0
fd :3 0 47db 47dc
0 4816 db :3 0
dc :3 0 47de 47df
0 db :3 0 ec
:3 0 47e1 47e2 0
100 :2 0 2 :4 0
345 :2 0 ee :2 0
33 :2 0 284f 47e7
47e9 :3 0 2852 47e3
47eb 47e0 47ed 47ec
:2 0 de :3 0 ef
:3 0 47ef 47f0 0
e0 :4 0 346 :4 0
e3 :2 0 e4 :3 0
2856 47f4 47f6 :3 0
e3 :2 0 103 :4 0
2859 47f8 47fa :3 0
e3 :2 0 104 :4 0
285c 47fc 47fe :3 0
e3 :2 0 fd :3 0
285f 4800 4802 :3 0
e3 :2 0 105 :4 0
2862 4804 4806 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 2865 4809
480d 2869 4808 480f
:3 0 286c 47f1 4811
:2 0 4813 286f 4814
47ee 4813 0 4815
2871 0 4816 2873
4819 :3 0 4819 0
4819 4818 4816 4817
:6 0 481b d4 :3 0
2876 481d 2878 481c
481b :2 0 481e 287a
:2 0 4820 0 4820
481f 47cd 481e :6 0
4822 6f :3 0 287d
606e e8 :3 0 58
:3 0 48 :2 0 2885
4823 4826 f3 :2 0
48 :2 0 288a 4828
482a :3 0 26 :3 0
24 :3 0 482c 482d
0 482f 288d 4830
482b 482f 0 4831
288f 0 606d 347
:3 0 aa :3 0 2a
:3 0 b2 :3 0 24
:3 0 a9 :3 0 2b
:3 0 aa :3 0 2c
:4 0 348 1 :8 0
4851 f9 :4 0 483c
:3 0 112 :3 0 f3
:2 0 2893 483f 4840
:3 0 15 :3 0 fa
:3 0 4842 4843 0
48 :2 0 4844 4845
0 4847 2896 484e
15 :3 0 fa :3 0
4848 4849 0 fb
:2 0 484a 484b 0
484d 2898 484f 4841
4847 0 4850 0
484d 0 4850 289a
0 4851 289d 48a4
fe :3 0 15 :3 0
fa :3 0 4853 4854
0 fd :3 0 4855
4856 0 4858 28a0
485a 28a2 4859 4858
:2 0 48a2 ff :3 0
15 :3 0 fa :3 0
485d 485e 0 fd
:3 0 485f 4860 0
489a db :3 0 dc
:3 0 4862 4863 0
db :3 0 ec :3 0
4865 4866 0 100
:2 0 2 :4 0 349
:2 0 ee :2 0 33
:2 0 28a4 486b 486d
:3 0 28a7 4867 486f
4864 4871 4870 :2 0
de :3 0 ef :3 0
4873 4874 0 e0
:4 0 34a :4 0 e3
:2 0 e4 :3 0 28ab
4878 487a :3 0 e3
:2 0 103 :4 0 28ae
487c 487e :3 0 e3
:2 0 104 :4 0 28b1
4880 4882 :3 0 e3
:2 0 fd :3 0 28b4
4884 4886 :3 0 e3
:2 0 105 :4 0 28b7
4888 488a :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 28ba 488d 4891
28be 488c 4893 :3 0
28c1 4875 4895 :2 0
4897 28c4 4898 4872
4897 0 4899 28c6
0 489a 28c8 489d
:3 0 489d 0 489d
489c 489a 489b :6 0
489f d6 :3 0 28cb
48a1 28cd 48a0 489f
:2 0 48a2 28cf :2 0
48a4 0 48a4 48a3
4851 48a2 :6 0 606d
6f :3 0 b2 :3 0
194 :3 0 27 :3 0
32 :3 0 a8 :3 0
a9 :3 0 2b :3 0
b3 :3 0 29 :3 0
aa :3 0 2a :3 0
ab :4 0 34b 1
:8 0 48b8 15 :3 0
fa :3 0 48b3 48b4
0 fd :3 0 48b5
48b6 0 48b8 28d2
490b fe :3 0 15
:3 0 fa :3 0 48ba
48bb 0 fd :3 0
48bc 48bd 0 48bf
28d5 48c1 28d7 48c0
48bf :2 0 4909 ff
:3 0 15 :3 0 fa
:3 0 48c4 48c5 0
fd :3 0 48c6 48c7
0 4901 db :3 0
dc :3 0 48c9 48ca
0 db :3 0 ec
:3 0 48cc 48cd 0
100 :2 0 2 :4 0
34c :2 0 ee :2 0
33 :2 0 28d9 48d2
48d4 :3 0 28dc 48ce
48d6 48cb 48d8 48d7
:2 0 de :3 0 ef
:3 0 48da 48db 0
e0 :4 0 34d :4 0
e3 :2 0 e4 :3 0
28e0 48df 48e1 :3 0
e3 :2 0 103 :4 0
28e3 48e3 48e5 :3 0
e3 :2 0 104 :4 0
28e6 48e7 48e9 :3 0
e3 :2 0 fd :3 0
28e9 48eb 48ed :3 0
e3 :2 0 105 :4 0
28ec 48ef 48f1 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 28ef 48f4
48f8 28f3 48f3 48fa
:3 0 28f6 48dc 48fc
:2 0 48fe 28f9 48ff
48d9 48fe 0 4900
28fb 0 4901 28fd
4904 :3 0 4904 0
4904 4903 4901 4902
:6 0 4906 d8 :3 0
2900 4908 2902 4907
4906 :2 0 4909 2904
:2 0 490b 0 490b
490a 48b8 4909 :6 0
606d 6f :3 0 15
:3 0 fa :3 0 490d
490e 0 15 :3 0
f3 :2 0 11a :3 0
4910 4912 0 2909
4911 4914 :3 0 4915
:2 0 73 :3 0 48
:2 0 4917 4918 0
4f20 b0 :3 0 180
:3 0 185 :3 0 1f
:3 0 49 :3 0 20
:3 0 c8 :3 0 a4
:3 0 29 :3 0 aa
:3 0 2a :3 0 ab
:4 0 28e 1 :8 0
492c 15 :3 0 fa
:3 0 4927 4928 0
fd :3 0 4929 492a
0 492c 290c 497f
fe :3 0 15 :3 0
fa :3 0 492e 492f
0 fd :3 0 4930
4931 0 4933 290f
4935 2911 4934 4933
:2 0 497d ff :3 0
15 :3 0 fa :3 0
4938 4939 0 fd
:3 0 493a 493b 0
4975 db :3 0 dc
:3 0 493d 493e 0
db :3 0 ec :3 0
4940 4941 0 100
:2 0 2 :4 0 34e
:2 0 ee :2 0 33
:2 0 2913 4946 4948
:3 0 2916 4942 494a
493f 494c 494b :2 0
de :3 0 ef :3 0
494e 494f 0 e0
:4 0 34f :4 0 e3
:2 0 e4 :3 0 291a
4953 4955 :3 0 e3
:2 0 103 :4 0 291d
4957 4959 :3 0 e3
:2 0 104 :4 0 2920
495b 495d :3 0 e3
:2 0 fd :3 0 2923
495f 4961 :3 0 e3
:2 0 105 :4 0 2926
4963 4965 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 2929 4968 496c
292d 4967 496e :3 0
2930 4950 4970 :2 0
4972 2933 4973 494d
4972 0 4974 2935
0 4975 2937 4978
:3 0 4978 0 4978
4977 4975 4976 :6 0
497a da :3 0 293a
497c 293c 497b 497a
:2 0 497d 293e :2 0
497f 0 497f 497e
492c 497d :6 0 4f20
6f :3 0 15 :3 0
fa :3 0 4981 4982
0 15 :3 0 f3
:2 0 173 :3 0 4984
4986 0 2943 4985
4988 :3 0 4989 :2 0
f1 :3 0 e8 :3 0
49 :3 0 48 :2 0
2946 498c 498f 1a
:3 0 1b6 :3 0 4991
4992 0 2949 498b
4994 4995 :2 0 1a
:3 0 f3 :2 0 1b6
:3 0 4997 4999 0
294e 4998 499b :3 0
4b :3 0 48 :2 0
499d 499e 0 4a14
c8 :3 0 149 :3 0
2c :3 0 aa :3 0
2a :3 0 ab :3 0
b0 :3 0 22 :4 0
2ad 1 :8 0 49be
f9 :4 0 49a9 :3 0
112 :3 0 f3 :2 0
2953 49ac 49ad :3 0
15 :3 0 fa :3 0
49af 49b0 0 48
:2 0 49b1 49b2 0
49b4 2956 49bb 15
:3 0 fa :3 0 49b5
49b6 0 fb :2 0
49b7 49b8 0 49ba
2958 49bc 49ae 49b4
0 49bd 0 49ba
0 49bd 295a 0
49be 295d 4a11 fe
:3 0 15 :3 0 fa
:3 0 49c0 49c1 0
fd :3 0 49c2 49c3
0 49c5 2960 49c7
2962 49c6 49c5 :2 0
4a0f ff :3 0 15
:3 0 fa :3 0 49ca
49cb 0 fd :3 0
49cc 49cd 0 4a07
db :3 0 dc :3 0
49cf 49d0 0 db
:3 0 ec :3 0 49d2
49d3 0 100 :2 0
2 :4 0 350 :2 0
ee :2 0 33 :2 0
2964 49d8 49da :3 0
2967 49d4 49dc 49d1
49de 49dd :2 0 de
:3 0 ef :3 0 49e0
49e1 0 e0 :4 0
351 :4 0 e3 :2 0
e4 :3 0 296b 49e5
49e7 :3 0 e3 :2 0
103 :4 0 296e 49e9
49eb :3 0 e3 :2 0
104 :4 0 2971 49ed
49ef :3 0 e3 :2 0
fd :3 0 2974 49f1
49f3 :3 0 e3 :2 0
105 :4 0 2977 49f5
49f7 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
297a 49fa 49fe 297e
49f9 4a00 :3 0 2981
49e2 4a02 :2 0 4a04
2984 4a05 49df 4a04
0 4a06 2986 0
4a07 2988 4a0a :3 0
4a0a 0 4a0a 4a09
4a07 4a08 :6 0 4a0c
dc :3 0 298b 4a0e
298d 4a0d 4a0c :2 0
4a0f 298f :2 0 4a11
0 4a11 4a10 49be
4a0f :6 0 4a14 6f
:3 0 16a :3 0 2992
4b25 e8 :3 0 49
:3 0 48 :2 0 2995
4a15 4a18 1a :3 0
f3 :2 0 1ac :3 0
4a1a 4a1c 0 299a
4a1b 4a1e :3 0 7e
:3 0 18a :3 0 48
:2 0 e8 :3 0 4d
:3 0 48 :2 0 299d
4a23 4a26 1a :3 0
18b :3 0 4a28 4a29
0 7b :3 0 29a0
4a21 4a2c 4a20 4a2d
0 4aa7 c8 :3 0
180 :3 0 1a :3 0
1b6 :3 0 185 :3 0
7b :3 0 149 :3 0
2c :3 0 aa :3 0
2a :3 0 ab :3 0
b0 :3 0 22 :4 0
2b0 1 :8 0 4a52
f9 :4 0 4a3d :3 0
112 :3 0 f3 :2 0
29a7 4a40 4a41 :3 0
15 :3 0 fa :3 0
4a43 4a44 0 48
:2 0 4a45 4a46 0
4a48 29aa 4a4f 15
:3 0 fa :3 0 4a49
4a4a 0 fb :2 0
4a4b 4a4c 0 4a4e
29ac 4a50 4a42 4a48
0 4a51 0 4a4e
0 4a51 29ae 0
4a52 29b1 4aa5 fe
:3 0 15 :3 0 fa
:3 0 4a54 4a55 0
fd :3 0 4a56 4a57
0 4a59 29b4 4a5b
29b6 4a5a 4a59 :2 0
4aa3 ff :3 0 15
:3 0 fa :3 0 4a5e
4a5f 0 fd :3 0
4a60 4a61 0 4a9b
db :3 0 dc :3 0
4a63 4a64 0 db
:3 0 ec :3 0 4a66
4a67 0 100 :2 0
2 :4 0 352 :2 0
ee :2 0 33 :2 0
29b8 4a6c 4a6e :3 0
29bb 4a68 4a70 4a65
4a72 4a71 :2 0 de
:3 0 ef :3 0 4a74
4a75 0 e0 :4 0
353 :4 0 e3 :2 0
e4 :3 0 29bf 4a79
4a7b :3 0 e3 :2 0
103 :4 0 29c2 4a7d
4a7f :3 0 e3 :2 0
104 :4 0 29c5 4a81
4a83 :3 0 e3 :2 0
fd :3 0 29c8 4a85
4a87 :3 0 e3 :2 0
105 :4 0 29cb 4a89
4a8b :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
29ce 4a8e 4a92 29d2
4a8d 4a94 :3 0 29d5
4a76 4a96 :2 0 4a98
29d8 4a99 4a73 4a98
0 4a9a 29da 0
4a9b 29dc 4a9e :3 0
4a9e 0 4a9e 4a9d
4a9b 4a9c :6 0 4aa0
de :3 0 29df 4aa2
29e1 4aa1 4aa0 :2 0
4aa3 29e3 :2 0 4aa5
0 4aa5 4aa4 4a52
4aa3 :6 0 4aa7 6f
:3 0 29e6 4aa8 4a1f
4aa7 0 4b27 c8
:3 0 180 :3 0 1b1
:3 0 1b2 :3 0 49
:3 0 1a :3 0 1b6
:3 0 185 :3 0 20
:3 0 149 :3 0 2c
:3 0 aa :3 0 2a
:3 0 ab :3 0 b0
:3 0 22 :4 0 2b3
1 :8 0 4acf f9
:4 0 4aba :3 0 112
:3 0 f3 :2 0 29eb
4abd 4abe :3 0 15
:3 0 fa :3 0 4ac0
4ac1 0 48 :2 0
4ac2 4ac3 0 4ac5
29ee 4acc 15 :3 0
fa :3 0 4ac6 4ac7
0 fb :2 0 4ac8
4ac9 0 4acb 29f0
4acd 4abf 4ac5 0
4ace 0 4acb 0
4ace 29f2 0 4acf
29f5 4b22 fe :3 0
15 :3 0 fa :3 0
4ad1 4ad2 0 fd
:3 0 4ad3 4ad4 0
4ad6 29f8 4ad8 29fa
4ad7 4ad6 :2 0 4b20
ff :3 0 15 :3 0
fa :3 0 4adb 4adc
0 fd :3 0 4add
4ade 0 4b18 db
:3 0 dc :3 0 4ae0
4ae1 0 db :3 0
ec :3 0 4ae3 4ae4
0 100 :2 0 2
:4 0 354 :2 0 ee
:2 0 33 :2 0 29fc
4ae9 4aeb :3 0 29ff
4ae5 4aed 4ae2 4aef
4aee :2 0 de :3 0
ef :3 0 4af1 4af2
0 e0 :4 0 355
:4 0 e3 :2 0 e4
:3 0 2a03 4af6 4af8
:3 0 e3 :2 0 103
:4 0 2a06 4afa 4afc
:3 0 e3 :2 0 104
:4 0 2a09 4afe 4b00
:3 0 e3 :2 0 fd
:3 0 2a0c 4b02 4b04
:3 0 e3 :2 0 105
:4 0 2a0f 4b06 4b08
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 2a12
4b0b 4b0f 2a16 4b0a
4b11 :3 0 2a19 4af3
4b13 :2 0 4b15 2a1c
4b16 4af0 4b15 0
4b17 2a1e 0 4b18
2a20 4b1b :3 0 4b1b
0 4b1b 4b1a 4b18
4b19 :6 0 4b1d e0
:3 0 2a23 4b1f 2a25
4b1e 4b1d :2 0 4b20
2a27 :2 0 4b22 0
4b22 4b21 4acf 4b20
:6 0 4b24 6f :3 0
2a2a 4b26 499c 4a14
0 4b27 0 4b24
0 4b27 2a2c 0
4baf 15 :3 0 fa
:3 0 4b28 4b29 0
15 :3 0 f3 :2 0
173 :3 0 4b2b 4b2d
0 2a32 4b2c 4b2f
:3 0 4b30 :2 0 e8
:3 0 4b :3 0 48
:2 0 2a35 4b32 4b35
124 :2 0 48 :2 0
2a3a 4b37 4b39 :3 0
4b3a :2 0 4b31 4b3c
4b3b :2 0 c8 :3 0
b0 :3 0 1f :4 0
356 1 :8 0 4b57
f9 :4 0 4b42 :3 0
112 :3 0 f3 :2 0
2a3f 4b45 4b46 :3 0
15 :3 0 fa :3 0
4b48 4b49 0 48
:2 0 4b4a 4b4b 0
4b4d 2a42 4b54 15
:3 0 fa :3 0 4b4e
4b4f 0 fb :2 0
4b50 4b51 0 4b53
2a44 4b55 4b47 4b4d
0 4b56 0 4b53
0 4b56 2a46 0
4b57 2a49 4baa fe
:3 0 15 :3 0 fa
:3 0 4b59 4b5a 0
fd :3 0 4b5b 4b5c
0 4b5e 2a4c 4b60
2a4e 4b5f 4b5e :2 0
4ba8 ff :3 0 15
:3 0 fa :3 0 4b63
4b64 0 fd :3 0
4b65 4b66 0 4ba0
db :3 0 dc :3 0
4b68 4b69 0 db
:3 0 ec :3 0 4b6b
4b6c 0 100 :2 0
2 :4 0 357 :2 0
ee :2 0 33 :2 0
2a50 4b71 4b73 :3 0
2a53 4b6d 4b75 4b6a
4b77 4b76 :2 0 de
:3 0 ef :3 0 4b79
4b7a 0 e0 :4 0
358 :4 0 e3 :2 0
e4 :3 0 2a57 4b7e
4b80 :3 0 e3 :2 0
103 :4 0 2a5a 4b82
4b84 :3 0 e3 :2 0
104 :4 0 2a5d 4b86
4b88 :3 0 e3 :2 0
fd :3 0 2a60 4b8a
4b8c :3 0 e3 :2 0
105 :4 0 2a63 4b8e
4b90 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
2a66 4b93 4b97 2a6a
4b92 4b99 :3 0 2a6d
4b7b 4b9b :2 0 4b9d
2a70 4b9e 4b78 4b9d
0 4b9f 2a72 0
4ba0 2a74 4ba3 :3 0
4ba3 0 4ba3 4ba2
4ba0 4ba1 :6 0 4ba5
e2 :3 0 2a77 4ba7
2a79 4ba6 4ba5 :2 0
4ba8 2a7b :2 0 4baa
0 4baa 4ba9 4b57
4ba8 :6 0 4bac 6f
:3 0 2a7e 4bad 4b3d
4bac 0 4bae 2a80
0 4baf 2a82 4e92
205 :3 0 b0 :3 0
106 :3 0 12a :3 0
198 :3 0 19d :3 0
12a :3 0 198 :3 0
1f :3 0 43 :3 0
c7 :3 0 12a :3 0
c8 :3 0 205 :3 0
12a :3 0 a4 :3 0
29 :3 0 12a :3 0
a4 :3 0 205 :3 0
a4 :3 0 205 :3 0
180 :3 0 205 :3 0
aa :3 0 12a :3 0
291 :3 0 b2 :3 0
a8 :3 0 206 :3 0
206 :3 0 b0 :3 0
205 :3 0 b0 :4 0
359 1 :8 0 4bd8
15 :3 0 fa :3 0
4bd3 4bd4 0 fd
:3 0 4bd5 4bd6 0
4bd8 2a85 4c2b fe
:3 0 15 :3 0 fa
:3 0 4bda 4bdb 0
fd :3 0 4bdc 4bdd
0 4bdf 2a88 4be1
2a8a 4be0 4bdf :2 0
4c29 ff :3 0 15
:3 0 fa :3 0 4be4
4be5 0 fd :3 0
4be6 4be7 0 4c21
db :3 0 dc :3 0
4be9 4bea 0 db
:3 0 ec :3 0 4bec
4bed 0 100 :2 0
2 :4 0 35a :2 0
ee :2 0 33 :2 0
2a8c 4bf2 4bf4 :3 0
2a8f 4bee 4bf6 4beb
4bf8 4bf7 :2 0 de
:3 0 ef :3 0 4bfa
4bfb 0 e0 :4 0
35b :4 0 e3 :2 0
e4 :3 0 2a93 4bff
4c01 :3 0 e3 :2 0
103 :4 0 2a96 4c03
4c05 :3 0 e3 :2 0
104 :4 0 2a99 4c07
4c09 :3 0 e3 :2 0
fd :3 0 2a9c 4c0b
4c0d :3 0 e3 :2 0
105 :4 0 2a9f 4c0f
4c11 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
2aa2 4c14 4c18 2aa6
4c13 4c1a :3 0 2aa9
4bfc 4c1c :2 0 4c1e
2aac 4c1f 4bf9 4c1e
0 4c20 2aae 0
4c21 2ab0 4c24 :3 0
4c24 0 4c24 4c23
4c21 4c22 :6 0 4c26
e4 :3 0 2ab3 4c28
2ab5 4c27 4c26 :2 0
4c29 2ab7 :2 0 4c2b
0 4c2b 4c2a 4bd8
4c29 :6 0 4e91 6f
:3 0 15 :3 0 fa
:3 0 4c2d 4c2e 0
15 :3 0 f3 :2 0
173 :3 0 4c30 4c32
0 2abc 4c31 4c34
:3 0 4c35 :2 0 1f
:3 0 1ce :2 0 2abf
4c38 4c39 :3 0 4c3a
:2 0 4c3b :2 0 4c36
4c3d 4c3c :2 0 7e
:3 0 18a :3 0 48
:2 0 e8 :3 0 4d
:3 0 48 :2 0 2ac1
4c42 4c45 1a :3 0
295 :3 0 4c47 4c48
0 7b :3 0 2ac4
4c40 4c4b 4c3f 4c4c
0 4da5 c8 :3 0
b0 :3 0 1f :4 0
356 1 :8 0 4c67
f9 :4 0 4c52 :3 0
112 :3 0 f3 :2 0
2acb 4c55 4c56 :3 0
15 :3 0 fa :3 0
4c58 4c59 0 48
:2 0 4c5a 4c5b 0
4c5d 2ace 4c64 15
:3 0 fa :3 0 4c5e
4c5f 0 fb :2 0
4c60 4c61 0 4c63
2ad0 4c65 4c57 4c5d
0 4c66 0 4c63
0 4c66 2ad2 0
4c67 2ad5 4cba fe
:3 0 15 :3 0 fa
:3 0 4c69 4c6a 0
fd :3 0 4c6b 4c6c
0 4c6e 2ad8 4c70
2ada 4c6f 4c6e :2 0
4cb8 ff :3 0 15
:3 0 fa :3 0 4c73
4c74 0 fd :3 0
4c75 4c76 0 4cb0
db :3 0 dc :3 0
4c78 4c79 0 db
:3 0 ec :3 0 4c7b
4c7c 0 100 :2 0
2 :4 0 35c :2 0
ee :2 0 33 :2 0
2adc 4c81 4c83 :3 0
2adf 4c7d 4c85 4c7a
4c87 4c86 :2 0 de
:3 0 ef :3 0 4c89
4c8a 0 e0 :4 0
35d :4 0 e3 :2 0
e4 :3 0 2ae3 4c8e
4c90 :3 0 e3 :2 0
103 :4 0 2ae6 4c92
4c94 :3 0 e3 :2 0
104 :4 0 2ae9 4c96
4c98 :3 0 e3 :2 0
fd :3 0 2aec 4c9a
4c9c :3 0 e3 :2 0
105 :4 0 2aef 4c9e
4ca0 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
2af2 4ca3 4ca7 2af6
4ca2 4ca9 :3 0 2af9
4c8b 4cab :2 0 4cad
2afc 4cae 4c88 4cad
0 4caf 2afe 0
4cb0 2b00 4cb3 :3 0
4cb3 0 4cb3 4cb2
4cb0 4cb1 :6 0 4cb5
e6 :3 0 2b03 4cb7
2b05 4cb6 4cb5 :2 0
4cb8 2b07 :2 0 4cba
0 4cba 4cb9 4c67
4cb8 :6 0 4da5 6f
:3 0 c8 :3 0 aa
:3 0 2a :3 0 ab
:3 0 149 :3 0 2c
:3 0 180 :3 0 185
:3 0 7b :3 0 b0
:3 0 22 :4 0 35e
1 :8 0 4cdd f9
:4 0 4cc8 :3 0 112
:3 0 f3 :2 0 2b0c
4ccb 4ccc :3 0 15
:3 0 fa :3 0 4cce
4ccf 0 48 :2 0
4cd0 4cd1 0 4cd3
2b0f 4cda 15 :3 0
fa :3 0 4cd4 4cd5
0 fb :2 0 4cd6
4cd7 0 4cd9 2b11
4cdb 4ccd 4cd3 0
4cdc 0 4cd9 0
4cdc 2b13 0 4cdd
2b16 4d30 fe :3 0
15 :3 0 fa :3 0
4cdf 4ce0 0 fd
:3 0 4ce1 4ce2 0
4ce4 2b19 4ce6 2b1b
4ce5 4ce4 :2 0 4d2e
ff :3 0 15 :3 0
fa :3 0 4ce9 4cea
0 fd :3 0 4ceb
4cec 0 4d26 db
:3 0 dc :3 0 4cee
4cef 0 db :3 0
ec :3 0 4cf1 4cf2
0 100 :2 0 2
:4 0 35f :2 0 ee
:2 0 33 :2 0 2b1d
4cf7 4cf9 :3 0 2b20
4cf3 4cfb 4cf0 4cfd
4cfc :2 0 de :3 0
ef :3 0 4cff 4d00
0 e0 :4 0 360
:4 0 e3 :2 0 e4
:3 0 2b24 4d04 4d06
:3 0 e3 :2 0 103
:4 0 2b27 4d08 4d0a
:3 0 e3 :2 0 104
:4 0 2b2a 4d0c 4d0e
:3 0 e3 :2 0 fd
:3 0 2b2d 4d10 4d12
:3 0 e3 :2 0 105
:4 0 2b30 4d14 4d16
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 2b33
4d19 4d1d 2b37 4d18
4d1f :3 0 2b3a 4d01
4d21 :2 0 4d23 2b3d
4d24 4cfe 4d23 0
4d25 2b3f 0 4d26
2b41 4d29 :3 0 4d29
0 4d29 4d28 4d26
4d27 :6 0 4d2b e8
:3 0 2b44 4d2d 2b46
4d2c 4d2b :2 0 4d2e
2b48 :2 0 4d30 0
4d30 4d2f 4cdd 4d2e
:6 0 4da5 6f :3 0
c7 :3 0 198 :3 0
199 :3 0 198 :3 0
43 :3 0 41 :3 0
a4 :3 0 29 :4 0
29a 1 :8 0 4d50
f9 :4 0 4d3b :3 0
112 :3 0 f3 :2 0
2b4d 4d3e 4d3f :3 0
15 :3 0 fa :3 0
4d41 4d42 0 48
:2 0 4d43 4d44 0
4d46 2b50 4d4d 15
:3 0 fa :3 0 4d47
4d48 0 fb :2 0
4d49 4d4a 0 4d4c
2b52 4d4e 4d40 4d46
0 4d4f 0 4d4c
0 4d4f 2b54 0
4d50 2b57 4da3 fe
:3 0 15 :3 0 fa
:3 0 4d52 4d53 0
fd :3 0 4d54 4d55
0 4d57 2b5a 4d59
2b5c 4d58 4d57 :2 0
4da1 ff :3 0 15
:3 0 fa :3 0 4d5c
4d5d 0 fd :3 0
4d5e 4d5f 0 4d99
db :3 0 dc :3 0
4d61 4d62 0 db
:3 0 ec :3 0 4d64
4d65 0 100 :2 0
2 :4 0 361 :2 0
ee :2 0 33 :2 0
2b5e 4d6a 4d6c :3 0
2b61 4d66 4d6e 4d63
4d70 4d6f :2 0 de
:3 0 ef :3 0 4d72
4d73 0 e0 :4 0
362 :4 0 e3 :2 0
e4 :3 0 2b65 4d77
4d79 :3 0 e3 :2 0
103 :4 0 2b68 4d7b
4d7d :3 0 e3 :2 0
104 :4 0 2b6b 4d7f
4d81 :3 0 e3 :2 0
fd :3 0 2b6e 4d83
4d85 :3 0 e3 :2 0
105 :4 0 2b71 4d87
4d89 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
2b74 4d8c 4d90 2b78
4d8b 4d92 :3 0 2b7b
4d74 4d94 :2 0 4d96
2b7e 4d97 4d71 4d96
0 4d98 2b80 0
4d99 2b82 4d9c :3 0
4d9c 0 4d9c 4d9b
4d99 4d9a :6 0 4d9e
ea :3 0 2b85 4da0
2b87 4d9f 4d9e :2 0
4da1 2b89 :2 0 4da3
0 4da3 4da2 4d50
4da1 :6 0 4da5 6f
:3 0 2b8c 4e8e c7
:3 0 198 :3 0 19e
:3 0 41 :3 0 19e
:3 0 198 :3 0 198
:3 0 198 :3 0 41
:3 0 a4 :3 0 29
:4 0 2a7 1 :8 0
4dc7 f9 :4 0 4db2
:3 0 112 :3 0 f3
:2 0 2b93 4db5 4db6
:3 0 15 :3 0 fa
:3 0 4db8 4db9 0
48 :2 0 4dba 4dbb
0 4dbd 2b96 4dc4
15 :3 0 fa :3 0
4dbe 4dbf 0 fb
:2 0 4dc0 4dc1 0
4dc3 2b98 4dc5 4db7
4dbd 0 4dc6 0
4dc3 0 4dc6 2b9a
0 4dc7 2b9d 4e1a
fe :3 0 15 :3 0
fa :3 0 4dc9 4dca
0 fd :3 0 4dcb
4dcc 0 4dce 2ba0
4dd0 2ba2 4dcf 4dce
:2 0 4e18 ff :3 0
15 :3 0 fa :3 0
4dd3 4dd4 0 fd
:3 0 4dd5 4dd6 0
4e10 db :3 0 dc
:3 0 4dd8 4dd9 0
db :3 0 ec :3 0
4ddb 4ddc 0 100
:2 0 2 :4 0 363
:2 0 ee :2 0 33
:2 0 2ba4 4de1 4de3
:3 0 2ba7 4ddd 4de5
4dda 4de7 4de6 :2 0
de :3 0 ef :3 0
4de9 4dea 0 e0
:4 0 364 :4 0 e3
:2 0 e4 :3 0 2bab
4dee 4df0 :3 0 e3
:2 0 103 :4 0 2bae
4df2 4df4 :3 0 e3
:2 0 104 :4 0 2bb1
4df6 4df8 :3 0 e3
:2 0 fd :3 0 2bb4
4dfa 4dfc :3 0 e3
:2 0 105 :4 0 2bb7
4dfe 4e00 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 2bba 4e03 4e07
2bbe 4e02 4e09 :3 0
2bc1 4deb 4e0b :2 0
4e0d 2bc4 4e0e 4de8
4e0d 0 4e0f 2bc6
0 4e10 2bc8 4e13
:3 0 4e13 0 4e13
4e12 4e10 4e11 :6 0
4e15 ec :3 0 2bcb
4e17 2bcd 4e16 4e15
:2 0 4e18 2bcf :2 0
4e1a 0 4e1a 4e19
4dc7 4e18 :6 0 4e8d
6f :3 0 c8 :3 0
aa :3 0 2a :3 0
ab :3 0 b0 :3 0
22 :4 0 365 1
:8 0 4e38 f9 :4 0
4e23 :3 0 112 :3 0
f3 :2 0 2bd4 4e26
4e27 :3 0 15 :3 0
fa :3 0 4e29 4e2a
0 48 :2 0 4e2b
4e2c 0 4e2e 2bd7
4e35 15 :3 0 fa
:3 0 4e2f 4e30 0
fb :2 0 4e31 4e32
0 4e34 2bd9 4e36
4e28 4e2e 0 4e37
0 4e34 0 4e37
2bdb 0 4e38 2bde
4e8b fe :3 0 15
:3 0 fa :3 0 4e3a
4e3b 0 fd :3 0
4e3c 4e3d 0 4e3f
2be1 4e41 2be3 4e40
4e3f :2 0 4e89 ff
:3 0 15 :3 0 fa
:3 0 4e44 4e45 0
fd :3 0 4e46 4e47
0 4e81 db :3 0
dc :3 0 4e49 4e4a
0 db :3 0 ec
:3 0 4e4c 4e4d 0
100 :2 0 2 :4 0
366 :2 0 ee :2 0
33 :2 0 2be5 4e52
4e54 :3 0 2be8 4e4e
4e56 4e4b 4e58 4e57
:2 0 de :3 0 ef
:3 0 4e5a 4e5b 0
e0 :4 0 367 :4 0
e3 :2 0 e4 :3 0
2bec 4e5f 4e61 :3 0
e3 :2 0 103 :4 0
2bef 4e63 4e65 :3 0
e3 :2 0 104 :4 0
2bf2 4e67 4e69 :3 0
e3 :2 0 fd :3 0
2bf5 4e6b 4e6d :3 0
e3 :2 0 105 :4 0
2bf8 4e6f 4e71 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 2bfb 4e74
4e78 2bff 4e73 4e7a
:3 0 2c02 4e5c 4e7c
:2 0 4e7e 2c05 4e7f
4e59 4e7e 0 4e80
2c07 0 4e81 2c09
4e84 :3 0 4e84 0
4e84 4e83 4e81 4e82
:6 0 4e86 ee :3 0
2c0c 4e88 2c0e 4e87
4e86 :2 0 4e89 2c10
:2 0 4e8b 0 4e8b
4e8a 4e38 4e89 :6 0
4e8d 6f :3 0 2c13
4e8f 4c3e 4da5 0
4e90 0 4e8d 0
4e90 2c16 0 4e91
2c19 4e93 498a 4baf
0 4e94 0 4e91
0 4e94 2c1c 0
4f20 e8 :3 0 8a
:3 0 48 :2 0 2c1f
4e95 4e98 1a :3 0
15c :2 0 368 :3 0
4e9a 4e9c 0 2c24
4e9b 4e9e :3 0 e8
:3 0 8a :3 0 48
:2 0 2c27 4ea0 4ea3
1a :3 0 15c :2 0
29d :3 0 4ea5 4ea7
0 2c2c 4ea6 4ea9
:3 0 4e9f 4eab 4eaa
:2 0 1db :3 0 a9
:3 0 2b :3 0 b2
:3 0 24 :4 0 33e
1 :8 0 4ec8 f9
:4 0 4eb3 :3 0 112
:3 0 f3 :2 0 2c31
4eb6 4eb7 :3 0 15
:3 0 fa :3 0 4eb9
4eba 0 48 :2 0
4ebb 4ebc 0 4ebe
2c34 4ec5 15 :3 0
fa :3 0 4ebf 4ec0
0 fb :2 0 4ec1
4ec2 0 4ec4 2c36
4ec6 4eb8 4ebe 0
4ec7 0 4ec4 0
4ec7 2c38 0 4ec8
2c3b 4f1b fe :3 0
15 :3 0 fa :3 0
4eca 4ecb 0 fd
:3 0 4ecc 4ecd 0
4ecf 2c3e 4ed1 2c40
4ed0 4ecf :2 0 4f19
ff :3 0 15 :3 0
fa :3 0 4ed4 4ed5
0 fd :3 0 4ed6
4ed7 0 4f11 db
:3 0 dc :3 0 4ed9
4eda 0 db :3 0
ec :3 0 4edc 4edd
0 100 :2 0 2
:4 0 369 :2 0 ee
:2 0 33 :2 0 2c42
4ee2 4ee4 :3 0 2c45
4ede 4ee6 4edb 4ee8
4ee7 :2 0 de :3 0
ef :3 0 4eea 4eeb
0 e0 :4 0 36a
:4 0 e3 :2 0 e4
:3 0 2c49 4eef 4ef1
:3 0 e3 :2 0 103
:4 0 2c4c 4ef3 4ef5
:3 0 e3 :2 0 104
:4 0 2c4f 4ef7 4ef9
:3 0 e3 :2 0 fd
:3 0 2c52 4efb 4efd
:3 0 e3 :2 0 105
:4 0 2c55 4eff 4f01
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 2c58
4f04 4f08 2c5c 4f03
4f0a :3 0 2c5f 4eec
4f0c :2 0 4f0e 2c62
4f0f 4ee9 4f0e 0
4f10 2c64 0 4f11
2c66 4f14 :3 0 4f14
0 4f14 4f13 4f11
4f12 :6 0 4f16 f0
:3 0 2c69 4f18 2c6b
4f17 4f16 :2 0 4f19
2c6d :2 0 4f1b 0
4f1b 4f1a 4ec8 4f19
:6 0 4f1d 6f :3 0
2c70 4f1e 4eac 4f1d
0 4f1f 2c72 0
4f20 2c74 509f 73
:3 0 33 :2 0 4f21
4f22 0 509e c8
:3 0 b0 :3 0 22
:4 0 31a 1 :8 0
4f3d f9 :4 0 4f28
:3 0 112 :3 0 f3
:2 0 2c7b 4f2b 4f2c
:3 0 15 :3 0 fa
:3 0 4f2e 4f2f 0
48 :2 0 4f30 4f31
0 4f33 2c7e 4f3a
15 :3 0 fa :3 0
4f34 4f35 0 fb
:2 0 4f36 4f37 0
4f39 2c80 4f3b 4f2d
4f33 0 4f3c 0
4f39 0 4f3c 2c82
0 4f3d 2c85 4f90
fe :3 0 15 :3 0
fa :3 0 4f3f 4f40
0 fd :3 0 4f41
4f42 0 4f44 2c88
4f46 2c8a 4f45 4f44
:2 0 4f8e ff :3 0
15 :3 0 fa :3 0
4f49 4f4a 0 fd
:3 0 4f4b 4f4c 0
4f86 db :3 0 dc
:3 0 4f4e 4f4f 0
db :3 0 ec :3 0
4f51 4f52 0 100
:2 0 2 :4 0 36b
:2 0 ee :2 0 33
:2 0 2c8c 4f57 4f59
:3 0 2c8f 4f53 4f5b
4f50 4f5d 4f5c :2 0
de :3 0 ef :3 0
4f5f 4f60 0 e0
:4 0 36c :4 0 e3
:2 0 e4 :3 0 2c93
4f64 4f66 :3 0 e3
:2 0 103 :4 0 2c96
4f68 4f6a :3 0 e3
:2 0 104 :4 0 2c99
4f6c 4f6e :3 0 e3
:2 0 fd :3 0 2c9c
4f70 4f72 :3 0 e3
:2 0 105 :4 0 2c9f
4f74 4f76 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 2ca2 4f79 4f7d
2ca6 4f78 4f7f :3 0
2ca9 4f61 4f81 :2 0
4f83 2cac 4f84 4f5e
4f83 0 4f85 2cae
0 4f86 2cb0 4f89
:3 0 4f89 0 4f89
4f88 4f86 4f87 :6 0
4f8b f2 :3 0 2cb3
4f8d 2cb5 4f8c 4f8b
:2 0 4f8e 2cb7 :2 0
4f90 0 4f90 4f8f
4f3d 4f8e :6 0 509e
6f :3 0 a8 :3 0
b2 :3 0 24 :4 0
337 1 :8 0 4fab
f9 :4 0 4f96 :3 0
112 :3 0 f3 :2 0
2cbc 4f99 4f9a :3 0
15 :3 0 fa :3 0
4f9c 4f9d 0 48
:2 0 4f9e 4f9f 0
4fa1 2cbf 4fa8 15
:3 0 fa :3 0 4fa2
4fa3 0 fb :2 0
4fa4 4fa5 0 4fa7
2cc1 4fa9 4f9b 4fa1
0 4faa 0 4fa7
0 4faa 2cc3 0
4fab 2cc6 4ffe fe
:3 0 15 :3 0 fa
:3 0 4fad 4fae 0
fd :3 0 4faf 4fb0
0 4fb2 2cc9 4fb4
2ccb 4fb3 4fb2 :2 0
4ffc ff :3 0 15
:3 0 fa :3 0 4fb7
4fb8 0 fd :3 0
4fb9 4fba 0 4ff4
db :3 0 dc :3 0
4fbc 4fbd 0 db
:3 0 ec :3 0 4fbf
4fc0 0 100 :2 0
2 :4 0 36d :2 0
ee :2 0 33 :2 0
2ccd 4fc5 4fc7 :3 0
2cd0 4fc1 4fc9 4fbe
4fcb 4fca :2 0 de
:3 0 ef :3 0 4fcd
4fce 0 e0 :4 0
36e :4 0 e3 :2 0
e4 :3 0 2cd4 4fd2
4fd4 :3 0 e3 :2 0
103 :4 0 2cd7 4fd6
4fd8 :3 0 e3 :2 0
104 :4 0 2cda 4fda
4fdc :3 0 e3 :2 0
fd :3 0 2cdd 4fde
4fe0 :3 0 e3 :2 0
105 :4 0 2ce0 4fe2
4fe4 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
2ce3 4fe7 4feb 2ce7
4fe6 4fed :3 0 2cea
4fcf 4fef :2 0 4ff1
2ced 4ff2 4fcc 4ff1
0 4ff3 2cef 0
4ff4 2cf1 4ff7 :3 0
4ff7 0 4ff7 4ff6
4ff4 4ff5 :6 0 4ff9
f4 :3 0 2cf4 4ffb
2cf6 4ffa 4ff9 :2 0
4ffc 2cf8 :2 0 4ffe
0 4ffe 4ffd 4fab
4ffc :6 0 509e 6f
:3 0 106 :3 0 32
:3 0 33 :2 0 33
:2 0 2cfb 5000 5004
f3 :2 0 153 :4 0
2d01 5006 5008 :3 0
56 :3 0 153 :2 0
500a 500b 0 500d
2d04 500e 5009 500d
0 500f 2d06 0
509e e8 :3 0 8a
:3 0 48 :2 0 2d08
5010 5013 1a :3 0
15c :2 0 368 :3 0
5015 5017 0 2d0d
5016 5019 :3 0 e8
:3 0 8a :3 0 48
:2 0 2d10 501b 501e
1a :3 0 15c :2 0
29d :3 0 5020 5022
0 2d15 5021 5024
:3 0 501a 5026 5025
:2 0 1db :3 0 a9
:3 0 2b :3 0 b2
:3 0 24 :4 0 33e
1 :8 0 5043 f9
:4 0 502e :3 0 112
:3 0 f3 :2 0 2d1a
5031 5032 :3 0 15
:3 0 fa :3 0 5034
5035 0 48 :2 0
5036 5037 0 5039
2d1d 5040 15 :3 0
fa :3 0 503a 503b
0 fb :2 0 503c
503d 0 503f 2d1f
5041 5033 5039 0
5042 0 503f 0
5042 2d21 0 5043
2d24 5096 fe :3 0
15 :3 0 fa :3 0
5045 5046 0 fd
:3 0 5047 5048 0
504a 2d27 504c 2d29
504b 504a :2 0 5094
ff :3 0 15 :3 0
fa :3 0 504f 5050
0 fd :3 0 5051
5052 0 508c db
:3 0 dc :3 0 5054
5055 0 db :3 0
ec :3 0 5057 5058
0 100 :2 0 2
:4 0 36f :2 0 ee
:2 0 33 :2 0 2d2b
505d 505f :3 0 2d2e
5059 5061 5056 5063
5062 :2 0 de :3 0
ef :3 0 5065 5066
0 e0 :4 0 370
:4 0 e3 :2 0 e4
:3 0 2d32 506a 506c
:3 0 e3 :2 0 103
:4 0 2d35 506e 5070
:3 0 e3 :2 0 104
:4 0 2d38 5072 5074
:3 0 e3 :2 0 fd
:3 0 2d3b 5076 5078
:3 0 e3 :2 0 105
:4 0 2d3e 507a 507c
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 2d41
507f 5083 2d45 507e
5085 :3 0 2d48 5067
5087 :2 0 5089 2d4b
508a 5064 5089 0
508b 2d4d 0 508c
2d4f 508f :3 0 508f
0 508f 508e 508c
508d :6 0 5091 f6
:3 0 2d52 5093 2d54
5092 5091 :2 0 5094
2d56 :2 0 5096 0
5096 5095 5043 5094
:6 0 509b 6f :3 0
24 :3 0 27 :3 0
5098 5099 0 509b
2d59 509c 5027 509b
0 509d 2d5c 0
509e 2d5e 50a0 4916
4f20 0 50a1 0
509e 0 50a1 2d64
0 606d e8 :3 0
4b :3 0 48 :2 0
2d67 50a2 50a5 124
:2 0 48 :2 0 2d6c
50a7 50a9 :3 0 e8
:3 0 71 :3 0 48
:2 0 2d6f 50ab 50ae
f3 :2 0 33 :2 0
2d74 50b0 50b2 :3 0
50b3 :2 0 45 :3 0
1ce :2 0 2d77 50b6
50b7 :3 0 50b8 :2 0
50b9 :2 0 50b4 50bb
50ba :2 0 13e :3 0
13e :3 0 45 :3 0
70 :3 0 c7 :3 0
a4 :3 0 29 :4 0
371 1 :8 0 50ca
15 :3 0 fa :3 0
50c5 50c6 0 fd
:3 0 50c7 50c8 0
50ca 2d79 511d fe
:3 0 15 :3 0 fa
:3 0 50cc 50cd 0
fd :3 0 50ce 50cf
0 50d1 2d7c 50d3
2d7e 50d2 50d1 :2 0
511b ff :3 0 15
:3 0 fa :3 0 50d6
50d7 0 fd :3 0
50d8 50d9 0 5113
db :3 0 dc :3 0
50db 50dc 0 db
:3 0 ec :3 0 50de
50df 0 100 :2 0
2 :4 0 372 :2 0
ee :2 0 33 :2 0
2d80 50e4 50e6 :3 0
2d83 50e0 50e8 50dd
50ea 50e9 :2 0 de
:3 0 ef :3 0 50ec
50ed 0 e0 :4 0
373 :4 0 e3 :2 0
e4 :3 0 2d87 50f1
50f3 :3 0 e3 :2 0
103 :4 0 2d8a 50f5
50f7 :3 0 e3 :2 0
104 :4 0 2d8d 50f9
50fb :3 0 e3 :2 0
fd :3 0 2d90 50fd
50ff :3 0 e3 :2 0
105 :4 0 2d93 5101
5103 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
2d96 5106 510a 2d9a
5105 510c :3 0 2d9d
50ee 510e :2 0 5110
2da0 5111 50eb 5110
0 5112 2da2 0
5113 2da4 5116 :3 0
5116 0 5116 5115
5113 5114 :6 0 5118
f8 :3 0 2da7 511a
2da9 5119 5118 :2 0
511b 2dab :2 0 511d
0 511d 511c 50ca
511b :6 0 51cb 6f
:3 0 15 :3 0 fa
:3 0 511f 5120 0
15 :3 0 f3 :2 0
173 :3 0 5122 5124
0 2db0 5123 5126
:3 0 5127 :2 0 e8
:3 0 70 :3 0 48
:2 0 2db3 5129 512c
f3 :2 0 48 :2 0
2db8 512e 5130 :3 0
5131 :2 0 5128 5133
5132 :2 0 c7 :3 0
13e :3 0 45 :3 0
a4 :3 0 29 :4 0
2b9 1 :8 0 5150
f9 :4 0 513b :3 0
112 :3 0 f3 :2 0
2dbd 513e 513f :3 0
15 :3 0 fa :3 0
5141 5142 0 48
:2 0 5143 5144 0
5146 2dc0 514d 15
:3 0 fa :3 0 5147
5148 0 fb :2 0
5149 514a 0 514c
2dc2 514e 5140 5146
0 514f 0 514c
0 514f 2dc4 0
5150 2dc7 51a3 fe
:3 0 15 :3 0 fa
:3 0 5152 5153 0
fd :3 0 5154 5155
0 5157 2dca 5159
2dcc 5158 5157 :2 0
51a1 ff :3 0 15
:3 0 fa :3 0 515c
515d 0 fd :3 0
515e 515f 0 5199
db :3 0 dc :3 0
5161 5162 0 db
:3 0 ec :3 0 5164
5165 0 100 :2 0
2 :4 0 374 :2 0
ee :2 0 33 :2 0
2dce 516a 516c :3 0
2dd1 5166 516e 5163
5170 516f :2 0 de
:3 0 ef :3 0 5172
5173 0 e0 :4 0
375 :4 0 e3 :2 0
e4 :3 0 2dd5 5177
5179 :3 0 e3 :2 0
103 :4 0 2dd8 517b
517d :3 0 e3 :2 0
104 :4 0 2ddb 517f
5181 :3 0 e3 :2 0
fd :3 0 2dde 5183
5185 :3 0 e3 :2 0
105 :4 0 2de1 5187
5189 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
2de4 518c 5190 2de8
518b 5192 :3 0 2deb
5174 5194 :2 0 5196
2dee 5197 5171 5196
0 5198 2df0 0
5199 2df2 519c :3 0
519c 0 519c 519b
5199 519a :6 0 519e
fa :3 0 2df5 51a0
2df7 519f 519e :2 0
51a1 2df9 :2 0 51a3
0 51a3 51a2 5150
51a1 :6 0 51a6 6f
:3 0 16a :3 0 2dfc
51c9 15 :3 0 fa
:3 0 51a7 51a8 0
15 :3 0 f3 :2 0
173 :3 0 51aa 51ac
0 2e00 51ab 51ae
:3 0 51af :2 0 e8
:3 0 70 :3 0 48
:2 0 2e03 51b1 51b4
f3 :2 0 153 :2 0
2e08 51b6 51b8 :3 0
51b9 :2 0 51b0 51bb
51ba :2 0 91 :3 0
1a :3 0 2bc :3 0
51be 51bf 0 51bd
51c0 0 51c7 90
:3 0 29 :3 0 51c2
51c3 0 51c7 284
:8 0 51c7 2e0b 51c8
51bc 51c7 0 51ca
5134 51a6 0 51ca
2e0f 0 51cb 2e12
51cc 50bc 51cb 0
51cd 2e15 0 6050
e8 :3 0 8a :3 0
48 :2 0 2e17 51ce
51d1 1a :3 0 f3
:2 0 368 :3 0 51d3
51d5 0 2e1c 51d4
51d7 :3 0 e8 :3 0
8a :3 0 48 :2 0
2e1f 51d9 51dc 1a
:3 0 f3 :2 0 29d
:3 0 51de 51e0 0
2e24 51df 51e2 :3 0
51d8 51e4 51e3 :2 0
2ca :3 0 2cb :3 0
2cc :4 0 51e8 :4 0
51e9 :2 0 5962 15
:3 0 fa :3 0 51eb
51ec 0 48 :2 0
51ed 51ee 0 5962
e8 :3 0 54 :3 0
48 :2 0 2e27 51f0
51f3 f3 :2 0 48
:2 0 2e2c 51f5 51f7
:3 0 e8 :3 0 50
:3 0 48 :2 0 2e2f
51f9 51fc f3 :2 0
48 :2 0 2e34 51fe
5200 :3 0 51f8 5202
5201 :2 0 2cd :3 0
af :3 0 1f1 :3 0
a2 :3 0 af :3 0
af :3 0 a4 :3 0
2a :3 0 af :3 0
1f1 :3 0 1cf :3 0
106 :3 0 37 :3 0
1cf :3 0 106 :3 0
38 :4 0 376 1
:8 0 522a f9 :4 0
5215 :3 0 112 :3 0
f3 :2 0 2e39 5218
5219 :3 0 15 :3 0
fa :3 0 521b 521c
0 48 :2 0 521d
521e 0 5220 2e3c
5227 15 :3 0 fa
:3 0 5221 5222 0
fb :2 0 5223 5224
0 5226 2e3e 5228
521a 5220 0 5229
0 5226 0 5229
2e40 0 522a 2e43
527d fe :3 0 15
:3 0 fa :3 0 522c
522d 0 fd :3 0
522e 522f 0 5231
2e46 5233 2e48 5232
5231 :2 0 527b ff
:3 0 15 :3 0 fa
:3 0 5236 5237 0
fd :3 0 5238 5239
0 5273 db :3 0
dc :3 0 523b 523c
0 db :3 0 ec
:3 0 523e 523f 0
100 :2 0 2 :4 0
377 :2 0 ee :2 0
33 :2 0 2e4a 5244
5246 :3 0 2e4d 5240
5248 523d 524a 5249
:2 0 de :3 0 ef
:3 0 524c 524d 0
e0 :4 0 378 :4 0
e3 :2 0 e4 :3 0
2e51 5251 5253 :3 0
e3 :2 0 103 :4 0
2e54 5255 5257 :3 0
e3 :2 0 104 :4 0
2e57 5259 525b :3 0
e3 :2 0 fd :3 0
2e5a 525d 525f :3 0
e3 :2 0 105 :4 0
2e5d 5261 5263 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 2e60 5266
526a 2e64 5265 526c
:3 0 2e67 524e 526e
:2 0 5270 2e6a 5271
524b 5270 0 5272
2e6c 0 5273 2e6e
5276 :3 0 5276 0
5276 5275 5273 5274
:6 0 5278 fc :3 0
2e71 527a 2e73 5279
5278 :2 0 527b 2e75
:2 0 527d 0 527d
527c 522a 527b :6 0
527f 6f :3 0 2e78
5308 2cd :3 0 af
:3 0 1f1 :3 0 a2
:3 0 af :3 0 1db
:3 0 2d1 :3 0 af
:3 0 a4 :3 0 2a
:3 0 af :3 0 1f1
:3 0 1cf :3 0 106
:3 0 37 :3 0 1cf
:3 0 106 :3 0 38
:3 0 2d1 :3 0 a9
:3 0 2b :3 0 2d1
:3 0 b2 :3 0 24
:3 0 af :3 0 1f1
:3 0 2d1 :3 0 1f1
:4 0 379 1 :8 0
52b2 f9 :4 0 529d
:3 0 112 :3 0 f3
:2 0 2e7c 52a0 52a1
:3 0 15 :3 0 fa
:3 0 52a3 52a4 0
48 :2 0 52a5 52a6
0 52a8 2e7f 52af
15 :3 0 fa :3 0
52a9 52aa 0 fb
:2 0 52ab 52ac 0
52ae 2e81 52b0 52a2
52a8 0 52b1 0
52ae 0 52b1 2e83
0 52b2 2e86 5305
fe :3 0 15 :3 0
fa :3 0 52b4 52b5
0 fd :3 0 52b6
52b7 0 52b9 2e89
52bb 2e8b 52ba 52b9
:2 0 5303 ff :3 0
15 :3 0 fa :3 0
52be 52bf 0 fd
:3 0 52c0 52c1 0
52fb db :3 0 dc
:3 0 52c3 52c4 0
db :3 0 ec :3 0
52c6 52c7 0 100
:2 0 2 :4 0 37a
:2 0 ee :2 0 33
:2 0 2e8d 52cc 52ce
:3 0 2e90 52c8 52d0
52c5 52d2 52d1 :2 0
de :3 0 ef :3 0
52d4 52d5 0 e0
:4 0 37b :4 0 e3
:2 0 e4 :3 0 2e94
52d9 52db :3 0 e3
:2 0 103 :4 0 2e97
52dd 52df :3 0 e3
:2 0 104 :4 0 2e9a
52e1 52e3 :3 0 e3
:2 0 fd :3 0 2e9d
52e5 52e7 :3 0 e3
:2 0 105 :4 0 2ea0
52e9 52eb :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 2ea3 52ee 52f2
2ea7 52ed 52f4 :3 0
2eaa 52d6 52f6 :2 0
52f8 2ead 52f9 52d3
52f8 0 52fa 2eaf
0 52fb 2eb1 52fe
:3 0 52fe 0 52fe
52fd 52fb 52fc :6 0
5300 fe :3 0 2eb4
5302 2eb6 5301 5300
:2 0 5303 2eb8 :2 0
5305 0 5305 5304
52b2 5303 :6 0 5307
6f :3 0 2ebb 5309
5203 527f 0 530a
0 5307 0 530a
2ebd 0 5962 15
:3 0 fa :3 0 530b
530c 0 15 :3 0
f3 :2 0 173 :3 0
530e 5310 0 2ec2
530f 5312 :3 0 5313
:2 0 62 :3 0 48
:2 0 5315 5316 0
595b 154 :3 0 1f1
:3 0 241 :3 0 1f1
:3 0 1c2 :3 0 1f1
:3 0 62 :3 0 35
:3 0 38 :3 0 2cd
:4 0 37c 1 :8 0
5328 15 :3 0 fa
:3 0 5323 5324 0
fd :3 0 5325 5326
0 5328 2ec5 537b
fe :3 0 15 :3 0
fa :3 0 532a 532b
0 fd :3 0 532c
532d 0 532f 2ec8
5331 2eca 5330 532f
:2 0 5379 ff :3 0
15 :3 0 fa :3 0
5334 5335 0 fd
:3 0 5336 5337 0
5371 db :3 0 dc
:3 0 5339 533a 0
db :3 0 ec :3 0
533c 533d 0 100
:2 0 2 :4 0 37d
:2 0 ee :2 0 33
:2 0 2ecc 5342 5344
:3 0 2ecf 533e 5346
533b 5348 5347 :2 0
de :3 0 ef :3 0
534a 534b 0 e0
:4 0 37e :4 0 e3
:2 0 e4 :3 0 2ed3
534f 5351 :3 0 e3
:2 0 103 :4 0 2ed6
5353 5355 :3 0 e3
:2 0 104 :4 0 2ed9
5357 5359 :3 0 e3
:2 0 fd :3 0 2edc
535b 535d :3 0 e3
:2 0 105 :4 0 2edf
535f 5361 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 2ee2 5364 5368
2ee6 5363 536a :3 0
2ee9 534c 536c :2 0
536e 2eec 536f 5349
536e 0 5370 2eee
0 5371 2ef0 5374
:3 0 5374 0 5374
5373 5371 5372 :6 0
5376 100 :3 0 2ef3
5378 2ef5 5377 5376
:2 0 5379 2ef7 :2 0
537b 0 537b 537a
5328 5379 :6 0 595b
6f :3 0 e8 :3 0
62 :3 0 48 :2 0
2efa 537d 5380 f3
:2 0 48 :2 0 2eff
5382 5384 :3 0 2d8
:3 0 5386 :4 0 5388
2f02 5889 1db :3 0
a9 :3 0 2b :3 0
b2 :3 0 24 :4 0
37f 1 :8 0 53a4
f9 :4 0 538f :3 0
112 :3 0 f3 :2 0
2f06 5392 5393 :3 0
15 :3 0 fa :3 0
5395 5396 0 48
:2 0 5397 5398 0
539a 2f09 53a1 15
:3 0 fa :3 0 539b
539c 0 fb :2 0
539d 539e 0 53a0
2f0b 53a2 5394 539a
0 53a3 0 53a0
0 53a3 2f0d 0
53a4 2f10 53f7 fe
:3 0 15 :3 0 fa
:3 0 53a6 53a7 0
fd :3 0 53a8 53a9
0 53ab 2f13 53ad
2f15 53ac 53ab :2 0
53f5 ff :3 0 15
:3 0 fa :3 0 53b0
53b1 0 fd :3 0
53b2 53b3 0 53ed
db :3 0 dc :3 0
53b5 53b6 0 db
:3 0 ec :3 0 53b8
53b9 0 100 :2 0
2 :4 0 380 :2 0
ee :2 0 33 :2 0
2f17 53be 53c0 :3 0
2f1a 53ba 53c2 53b7
53c4 53c3 :2 0 de
:3 0 ef :3 0 53c6
53c7 0 e0 :4 0
381 :4 0 e3 :2 0
e4 :3 0 2f1e 53cb
53cd :3 0 e3 :2 0
103 :4 0 2f21 53cf
53d1 :3 0 e3 :2 0
104 :4 0 2f24 53d3
53d5 :3 0 e3 :2 0
fd :3 0 2f27 53d7
53d9 :3 0 e3 :2 0
105 :4 0 2f2a 53db
53dd :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
2f2d 53e0 53e4 2f31
53df 53e6 :3 0 2f34
53c8 53e8 :2 0 53ea
2f37 53eb 53c5 53ea
0 53ec 2f39 0
53ed 2f3b 53f0 :3 0
53f0 0 53f0 53ef
53ed 53ee :6 0 53f2
102 :3 0 2f3e 53f4
2f40 53f3 53f2 :2 0
53f5 2f42 :2 0 53f7
0 53f7 53f6 53a4
53f5 :6 0 5888 6f
:3 0 e8 :3 0 73
:3 0 48 :2 0 2f45
53f9 53fc 15c :2 0
48 :2 0 2f4a 53fe
5400 :3 0 27 :3 0
1ce :2 0 2f4d 5403
5404 :3 0 5405 :2 0
5401 5407 5406 :2 0
27 :3 0 1ce :2 0
2f4f 540a 540b :3 0
540c :2 0 5408 540e
540d :2 0 24 :3 0
27 :3 0 5410 5411
0 5413 2f51 5414
540f 5413 0 5415
2f53 0 5888 72
:3 0 2dc :3 0 e8
:3 0 22d :3 0 4b
:3 0 2f55 5419 541b
48 :2 0 2f57 5418
541e 2dd :2 0 e8
:3 0 22d :3 0 62
:3 0 2f5a 5422 5424
48 :2 0 2f5c 5421
5427 2f5f 5420 5429
:3 0 542a :2 0 ee
:2 0 2de :2 0 2f62
542c 542e :3 0 2f65
5417 5430 5416 5431
0 5888 a1 :3 0
2c4 :3 0 63 :3 0
17 :3 0 a2 :3 0
a4 :3 0 2b :3 0
1f1 :3 0 35 :4 0
382 1 :8 0 5442
15 :3 0 fa :3 0
543d 543e 0 fd
:3 0 543f 5440 0
5442 2f67 5495 fe
:3 0 15 :3 0 fa
:3 0 5444 5445 0
fd :3 0 5446 5447
0 5449 2f6a 544b
2f6c 544a 5449 :2 0
5493 ff :3 0 15
:3 0 fa :3 0 544e
544f 0 fd :3 0
5450 5451 0 548b
db :3 0 dc :3 0
5453 5454 0 db
:3 0 ec :3 0 5456
5457 0 100 :2 0
2 :4 0 383 :2 0
ee :2 0 33 :2 0
2f6e 545c 545e :3 0
2f71 5458 5460 5455
5462 5461 :2 0 de
:3 0 ef :3 0 5464
5465 0 e0 :4 0
384 :4 0 e3 :2 0
e4 :3 0 2f75 5469
546b :3 0 e3 :2 0
103 :4 0 2f78 546d
546f :3 0 e3 :2 0
104 :4 0 2f7b 5471
5473 :3 0 e3 :2 0
fd :3 0 2f7e 5475
5477 :3 0 e3 :2 0
105 :4 0 2f81 5479
547b :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
2f84 547e 5482 2f88
547d 5484 :3 0 2f8b
5466 5486 :2 0 5488
2f8e 5489 5463 5488
0 548a 2f90 0
548b 2f92 548e :3 0
548e 0 548e 548d
548b 548c :6 0 5490
104 :3 0 2f95 5492
2f97 5491 5490 :2 0
5493 2f99 :2 0 5495
0 5495 5494 5442
5493 :6 0 5888 6f
:3 0 94 :3 0 48
:2 0 5497 5498 0
5888 1f0 :3 0 94
:3 0 1db :3 0 2d1
:3 0 a3 :3 0 2d1
:3 0 a9 :3 0 2b
:3 0 2d1 :3 0 b2
:3 0 24 :3 0 2d1
:3 0 aa :3 0 2a
:3 0 2d1 :3 0 194
:3 0 2d1 :3 0 1f1
:3 0 b1 :3 0 1f1
:3 0 2cd :3 0 b1
:3 0 b1 :3 0 1f1
:3 0 2d1 :3 0 1f1
:4 0 385 1 :8 0
54ba 15 :3 0 fa
:3 0 54b5 54b6 0
fd :3 0 54b7 54b8
0 54ba 2f9c 550d
fe :3 0 15 :3 0
fa :3 0 54bc 54bd
0 fd :3 0 54be
54bf 0 54c1 2f9f
54c3 2fa1 54c2 54c1
:2 0 550b ff :3 0
15 :3 0 fa :3 0
54c6 54c7 0 fd
:3 0 54c8 54c9 0
5503 db :3 0 dc
:3 0 54cb 54cc 0
db :3 0 ec :3 0
54ce 54cf 0 100
:2 0 2 :4 0 386
:2 0 ee :2 0 33
:2 0 2fa3 54d4 54d6
:3 0 2fa6 54d0 54d8
54cd 54da 54d9 :2 0
de :3 0 ef :3 0
54dc 54dd 0 e0
:4 0 387 :4 0 e3
:2 0 e4 :3 0 2faa
54e1 54e3 :3 0 e3
:2 0 103 :4 0 2fad
54e5 54e7 :3 0 e3
:2 0 104 :4 0 2fb0
54e9 54eb :3 0 e3
:2 0 fd :3 0 2fb3
54ed 54ef :3 0 e3
:2 0 105 :4 0 2fb6
54f1 54f3 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 2fb9 54f6 54fa
2fbd 54f5 54fc :3 0
2fc0 54de 54fe :2 0
5500 2fc3 5501 54db
5500 0 5502 2fc5
0 5503 2fc7 5506
:3 0 5506 0 5506
5505 5503 5504 :6 0
5508 106 :3 0 2fca
550a 2fcc 5509 5508
:2 0 550b 2fce :2 0
550d 0 550d 550c
54ba 550b :6 0 5888
6f :3 0 e8 :3 0
94 :3 0 48 :2 0
2fd1 550f 5512 15c
:2 0 48 :2 0 2fd6
5514 5516 :3 0 94
:3 0 e8 :3 0 94
:3 0 48 :2 0 2fd9
5519 551c ee :2 0
e8 :3 0 72 :3 0
48 :2 0 2fdc 551f
5522 2fdf 551e 5524
:3 0 5518 5525 0
55de 1c :3 0 17
:3 0 5527 5528 0
55de 1b1 :3 0 388
:3 0 552a 552b 0
e8 :3 0 94 :3 0
48 :2 0 2fe2 552d
5530 1c :3 0 2fe5
552c 5533 :2 0 55de
e8 :3 0 63 :3 0
48 :2 0 2fe8 5535
5538 e8 :3 0 124
:2 0 94 :3 0 48
:2 0 2feb 553a 553e
2ff0 553b 5540 :3 0
1b1 :3 0 2e2 :3 0
5542 5543 0 e8
:3 0 94 :3 0 48
:2 0 2ff3 5545 5548
1c :3 0 2ff6 5544
554b :2 0 554d 2ff9
554e 5541 554d 0
554f 2ffb 0 55de
1db :3 0 2d1 :3 0
2d1 :3 0 1f0 :3 0
2d1 :3 0 1f0 :3 0
72 :3 0 2d1 :3 0
2c4 :3 0 2c6 :3 0
1b2 :3 0 2d1 :3 0
2c4 :3 0 1c :3 0
2d1 :3 0 a9 :3 0
2b :3 0 2d1 :3 0
b2 :3 0 24 :3 0
2d1 :3 0 aa :3 0
2a :3 0 2d1 :3 0
194 :3 0 2d1 :3 0
1f1 :3 0 b1 :3 0
1f1 :3 0 2cd :3 0
b1 :3 0 b1 :3 0
1f1 :3 0 2d1 :3 0
1f1 :4 0 389 1
:8 0 5589 f9 :4 0
5574 :3 0 112 :3 0
f3 :2 0 2fff 5577
5578 :3 0 15 :3 0
fa :3 0 557a 557b
0 48 :2 0 557c
557d 0 557f 3002
5586 15 :3 0 fa
:3 0 5580 5581 0
fb :2 0 5582 5583
0 5585 3004 5587
5579 557f 0 5588
0 5585 0 5588
3006 0 5589 3009
55dc fe :3 0 15
:3 0 fa :3 0 558b
558c 0 fd :3 0
558d 558e 0 5590
300c 5592 300e 5591
5590 :2 0 55da ff
:3 0 15 :3 0 fa
:3 0 5595 5596 0
fd :3 0 5597 5598
0 55d2 db :3 0
dc :3 0 559a 559b
0 db :3 0 ec
:3 0 559d 559e 0
100 :2 0 2 :4 0
38a :2 0 ee :2 0
33 :2 0 3010 55a3
55a5 :3 0 3013 559f
55a7 559c 55a9 55a8
:2 0 de :3 0 ef
:3 0 55ab 55ac 0
e0 :4 0 38b :4 0
e3 :2 0 e4 :3 0
3017 55b0 55b2 :3 0
e3 :2 0 103 :4 0
301a 55b4 55b6 :3 0
e3 :2 0 104 :4 0
301d 55b8 55ba :3 0
e3 :2 0 fd :3 0
3020 55bc 55be :3 0
e3 :2 0 105 :4 0
3023 55c0 55c2 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 3026 55c5
55c9 302a 55c4 55cb
:3 0 302d 55ad 55cd
:2 0 55cf 3030 55d0
55aa 55cf 0 55d1
3032 0 55d2 3034
55d5 :3 0 55d5 0
55d5 55d4 55d2 55d3
:6 0 55d7 108 :3 0
3037 55d9 3039 55d8
55d7 :2 0 55da 303b
:2 0 55dc 0 55dc
55db 5589 55da :6 0
55de 6f :3 0 303e
55df 5517 55de 0
55e0 3044 0 5888
e8 :3 0 63 :3 0
48 :2 0 3046 55e1
55e4 e8 :3 0 124
:2 0 72 :3 0 48
:2 0 3049 55e6 55ea
304e 55e7 55ec :3 0
1b1 :3 0 2e2 :3 0
55ee 55ef 0 e8
:3 0 72 :3 0 48
:2 0 3051 55f1 55f4
17 :3 0 3054 55f0
55f7 :2 0 55f9 3057
55fa 55ed 55f9 0
55fb 3059 0 5888
1db :3 0 a9 :3 0
aa :3 0 b2 :3 0
1f1 :3 0 194 :3 0
1f0 :3 0 2c4 :3 0
2e3 :3 0 2e4 :3 0
b3 :3 0 2b :3 0
2a :3 0 24 :3 0
b1 :3 0 1f1 :3 0
72 :3 0 17 :3 0
58 :3 0 24 :3 0
26 :3 0 29 :3 0
2cd :3 0 b1 :3 0
b1 :3 0 1f1 :3 0
2d1 :3 0 1f1 :3 0
1db :3 0 2d1 :3 0
2d1 :3 0 a9 :3 0
2b :3 0 2d1 :3 0
b2 :3 0 24 :3 0
2d1 :3 0 aa :3 0
2a :3 0 2d1 :3 0
194 :3 0 b1 :3 0
1f1 :3 0 2d1 :3 0
1f1 :4 0 38c 1
:8 0 563f f9 :4 0
562a :3 0 112 :3 0
f3 :2 0 305d 562d
562e :3 0 15 :3 0
fa :3 0 5630 5631
0 48 :2 0 5632
5633 0 5635 3060
563c 15 :3 0 fa
:3 0 5636 5637 0
fb :2 0 5638 5639
0 563b 3062 563d
562f 5635 0 563e
0 563b 0 563e
3064 0 563f 3067
5692 fe :3 0 15
:3 0 fa :3 0 5641
5642 0 fd :3 0
5643 5644 0 5646
306a 5648 306c 5647
5646 :2 0 5690 ff
:3 0 15 :3 0 fa
:3 0 564b 564c 0
fd :3 0 564d 564e
0 5688 db :3 0
dc :3 0 5650 5651
0 db :3 0 ec
:3 0 5653 5654 0
100 :2 0 2 :4 0
38d :2 0 ee :2 0
33 :2 0 306e 5659
565b :3 0 3071 5655
565d 5652 565f 565e
:2 0 de :3 0 ef
:3 0 5661 5662 0
e0 :4 0 38e :4 0
e3 :2 0 e4 :3 0
3075 5666 5668 :3 0
e3 :2 0 103 :4 0
3078 566a 566c :3 0
e3 :2 0 104 :4 0
307b 566e 5670 :3 0
e3 :2 0 fd :3 0
307e 5672 5674 :3 0
e3 :2 0 105 :4 0
3081 5676 5678 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 3084 567b
567f 3088 567a 5681
:3 0 308b 5663 5683
:2 0 5685 308e 5686
5660 5685 0 5687
3090 0 5688 3092
568b :3 0 568b 0
568b 568a 5688 5689
:6 0 568d 10a :3 0
3095 568f 3097 568e
568d :2 0 5690 3099
:2 0 5692 0 5692
5691 563f 5690 :6 0
5888 6f :3 0 e8
:3 0 94 :3 0 48
:2 0 309c 5694 5697
15c :2 0 48 :2 0
30a1 5699 569b :3 0
93 :3 0 e8 :3 0
72 :3 0 48 :2 0
30a4 569e 56a1 1c1
:2 0 e8 :3 0 62
:3 0 48 :2 0 30a7
56a4 56a7 30aa 56a3
56a9 :3 0 569d 56aa
0 57c3 e8 :3 0
4b :3 0 48 :2 0
30ad 56ac 56af e8
:3 0 15c :2 0 93
:3 0 48 :2 0 30b0
56b1 56b5 30b5 56b2
56b7 :3 0 72 :3 0
e8 :3 0 72 :3 0
48 :2 0 30b8 56ba
56bd 1da :2 0 e8
:3 0 59 :3 0 48
:2 0 30bb 56c0 56c3
30be 56bf 56c5 :3 0
1da :2 0 e8 :3 0
72 :3 0 48 :2 0
30c1 56c8 56cb 1c1
:2 0 e8 :3 0 4b
:3 0 48 :2 0 30c4
56ce 56d1 1da :2 0
33 :2 0 30c7 56d3
56d5 :3 0 56d6 :2 0
30ca 56cd 56d8 :3 0
56d9 :2 0 30cd 56c7
56db :3 0 56b9 56dc
0 575f e8 :3 0
72 :3 0 48 :2 0
30d0 56de 56e1 15c
:2 0 48 :2 0 30d5
56e3 56e5 :3 0 1db
:3 0 1f0 :3 0 1f0
:3 0 72 :3 0 a9
:3 0 2b :3 0 b2
:3 0 24 :3 0 1f1
:3 0 38 :4 0 38f
1 :8 0 5707 f9
:4 0 56f2 :3 0 112
:3 0 f3 :2 0 30da
56f5 56f6 :3 0 15
:3 0 fa :3 0 56f8
56f9 0 48 :2 0
56fa 56fb 0 56fd
30dd 5704 15 :3 0
fa :3 0 56fe 56ff
0 fb :2 0 5700
5701 0 5703 30df
5705 56f7 56fd 0
5706 0 5703 0
5706 30e1 0 5707
30e4 575a fe :3 0
15 :3 0 fa :3 0
5709 570a 0 fd
:3 0 570b 570c 0
570e 30e7 5710 30e9
570f 570e :2 0 5758
ff :3 0 15 :3 0
fa :3 0 5713 5714
0 fd :3 0 5715
5716 0 5750 db
:3 0 dc :3 0 5718
5719 0 db :3 0
ec :3 0 571b 571c
0 100 :2 0 2
:4 0 390 :2 0 ee
:2 0 33 :2 0 30eb
5721 5723 :3 0 30ee
571d 5725 571a 5727
5726 :2 0 de :3 0
ef :3 0 5729 572a
0 e0 :4 0 391
:4 0 e3 :2 0 e4
:3 0 30f2 572e 5730
:3 0 e3 :2 0 103
:4 0 30f5 5732 5734
:3 0 e3 :2 0 104
:4 0 30f8 5736 5738
:3 0 e3 :2 0 fd
:3 0 30fb 573a 573c
:3 0 e3 :2 0 105
:4 0 30fe 573e 5740
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 3101
5743 5747 3105 5742
5749 :3 0 3108 572b
574b :2 0 574d 310b
574e 5728 574d 0
574f 310d 0 5750
310f 5753 :3 0 5753
0 5753 5752 5750
5751 :6 0 5755 10c
:3 0 3112 5757 3114
5756 5755 :2 0 5758
3116 :2 0 575a 0
575a 5759 5707 5758
:6 0 575c 6f :3 0
3119 575d 56e6 575c
0 575e 311b 0
575f 311d 5760 56b8
575f 0 5761 3120
0 57c3 1c2 :3 0
1f0 :3 0 72 :3 0
1db :3 0 b2 :3 0
24 :4 0 392 1
:8 0 576e 15 :3 0
fa :3 0 5769 576a
0 fd :3 0 576b
576c 0 576e 3122
57c1 fe :3 0 15
:3 0 fa :3 0 5770
5771 0 fd :3 0
5772 5773 0 5775
3125 5777 3127 5776
5775 :2 0 57bf ff
:3 0 15 :3 0 fa
:3 0 577a 577b 0
fd :3 0 577c 577d
0 57b7 db :3 0
dc :3 0 577f 5780
0 db :3 0 ec
:3 0 5782 5783 0
100 :2 0 2 :4 0
393 :2 0 ee :2 0
33 :2 0 3129 5788
578a :3 0 312c 5784
578c 5781 578e 578d
:2 0 de :3 0 ef
:3 0 5790 5791 0
e0 :4 0 394 :4 0
e3 :2 0 e4 :3 0
3130 5795 5797 :3 0
e3 :2 0 103 :4 0
3133 5799 579b :3 0
e3 :2 0 104 :4 0
3136 579d 579f :3 0
e3 :2 0 fd :3 0
3139 57a1 57a3 :3 0
e3 :2 0 105 :4 0
313c 57a5 57a7 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 313f 57aa
57ae 3143 57a9 57b0
:3 0 3146 5792 57b2
:2 0 57b4 3149 57b5
578f 57b4 0 57b6
314b 0 57b7 314d
57ba :3 0 57ba 0
57ba 57b9 57b7 57b8
:6 0 57bc 10e :3 0
3150 57be 3152 57bd
57bc :2 0 57bf 3154
:2 0 57c1 0 57c1
57c0 576e 57bf :6 0
57c3 6f :3 0 3157
5885 93 :3 0 e8
:3 0 72 :3 0 48
:2 0 315b 57c5 57c8
1c1 :2 0 e8 :3 0
62 :3 0 48 :2 0
315e 57cb 57ce 3161
57ca 57d0 :3 0 57c4
57d1 0 5884 e8
:3 0 4b :3 0 48
:2 0 3164 57d3 57d6
e8 :3 0 15c :2 0
93 :3 0 48 :2 0
3167 57d8 57dc 316c
57d9 57de :3 0 94
:3 0 e8 :3 0 59
:3 0 48 :2 0 316f
57e1 57e4 1da :2 0
e8 :3 0 72 :3 0
48 :2 0 3172 57e7
57ea 1c1 :2 0 e8
:3 0 4b :3 0 48
:2 0 3175 57ed 57f0
1da :2 0 33 :2 0
3178 57f2 57f4 :3 0
57f5 :2 0 317b 57ec
57f7 :3 0 57f8 :2 0
317e 57e6 57fa :3 0
57e0 57fb 0 5881
e8 :3 0 94 :3 0
48 :2 0 3181 57fd
5800 e8 :3 0 15c
:2 0 72 :3 0 48
:2 0 3184 5802 5806
3189 5803 5808 :3 0
1db :3 0 1f0 :3 0
94 :3 0 a9 :3 0
2b :3 0 b2 :3 0
24 :3 0 1f1 :3 0
38 :4 0 395 1
:8 0 5829 f9 :4 0
5814 :3 0 112 :3 0
f3 :2 0 318e 5817
5818 :3 0 15 :3 0
fa :3 0 581a 581b
0 48 :2 0 581c
581d 0 581f 3191
5826 15 :3 0 fa
:3 0 5820 5821 0
fb :2 0 5822 5823
0 5825 3193 5827
5819 581f 0 5828
0 5825 0 5828
3195 0 5829 3198
587c fe :3 0 15
:3 0 fa :3 0 582b
582c 0 fd :3 0
582d 582e 0 5830
319b 5832 319d 5831
5830 :2 0 587a ff
:3 0 15 :3 0 fa
:3 0 5835 5836 0
fd :3 0 5837 5838
0 5872 db :3 0
dc :3 0 583a 583b
0 db :3 0 ec
:3 0 583d 583e 0
100 :2 0 2 :4 0
396 :2 0 ee :2 0
33 :2 0 319f 5843
5845 :3 0 31a2 583f
5847 583c 5849 5848
:2 0 de :3 0 ef
:3 0 584b 584c 0
e0 :4 0 397 :4 0
e3 :2 0 e4 :3 0
31a6 5850 5852 :3 0
e3 :2 0 103 :4 0
31a9 5854 5856 :3 0
e3 :2 0 104 :4 0
31ac 5858 585a :3 0
e3 :2 0 fd :3 0
31af 585c 585e :3 0
e3 :2 0 105 :4 0
31b2 5860 5862 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 31b5 5865
5869 31b9 5864 586b
:3 0 31bc 584d 586d
:2 0 586f 31bf 5870
584a 586f 0 5871
31c1 0 5872 31c3
5875 :3 0 5875 0
5875 5874 5872 5873
:6 0 5877 110 :3 0
31c6 5879 31c8 5878
5877 :2 0 587a 31ca
:2 0 587c 0 587c
587b 5829 587a :6 0
587e 6f :3 0 31cd
587f 5809 587e 0
5880 31cf 0 5881
31d1 5882 57df 5881
0 5883 31d4 0
5884 31d6 5886 569c
57c3 0 5887 0
5884 0 5887 31d9
0 5888 31dc 588a
5385 5388 0 588b
0 5888 0 588b
31e7 0 595b a8
:3 0 aa :3 0 2a
:3 0 ab :3 0 ac
:3 0 58 :3 0 26
:3 0 be :3 0 6e
:3 0 65 :3 0 be
:3 0 bf :3 0 6e
:3 0 68 :3 0 bf
:3 0 c0 :3 0 6d
:3 0 67 :3 0 c0
:3 0 c1 :3 0 6d
:3 0 69 :3 0 c1
:3 0 258 :3 0 1b1
:3 0 1b2 :3 0 258
:3 0 1a :3 0 259
:3 0 25a :3 0 1b1
:3 0 1b2 :3 0 25a
:3 0 1a :3 0 25b
:3 0 b2 :3 0 24
:4 0 398 1 :8 0
58c7 f9 :4 0 58b2
:3 0 112 :3 0 f3
:2 0 31ec 58b5 58b6
:3 0 15 :3 0 fa
:3 0 58b8 58b9 0
48 :2 0 58ba 58bb
0 58bd 31ef 58c4
15 :3 0 fa :3 0
58be 58bf 0 fb
:2 0 58c0 58c1 0
58c3 31f1 58c5 58b7
58bd 0 58c6 0
58c3 0 58c6 31f3
0 58c7 31f6 591a
fe :3 0 15 :3 0
fa :3 0 58c9 58ca
0 fd :3 0 58cb
58cc 0 58ce 31f9
58d0 31fb 58cf 58ce
:2 0 5918 ff :3 0
15 :3 0 fa :3 0
58d3 58d4 0 fd
:3 0 58d5 58d6 0
5910 db :3 0 dc
:3 0 58d8 58d9 0
db :3 0 ec :3 0
58db 58dc 0 100
:2 0 2 :4 0 399
:2 0 ee :2 0 33
:2 0 31fd 58e1 58e3
:3 0 3200 58dd 58e5
58da 58e7 58e6 :2 0
de :3 0 ef :3 0
58e9 58ea 0 e0
:4 0 39a :4 0 e3
:2 0 e4 :3 0 3204
58ee 58f0 :3 0 e3
:2 0 103 :4 0 3207
58f2 58f4 :3 0 e3
:2 0 104 :4 0 320a
58f6 58f8 :3 0 e3
:2 0 fd :3 0 320d
58fa 58fc :3 0 e3
:2 0 105 :4 0 3210
58fe 5900 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 3213 5903 5907
3217 5902 5909 :3 0
321a 58eb 590b :2 0
590d 321d 590e 58e8
590d 0 590f 321f
0 5910 3221 5913
:3 0 5913 0 5913
5912 5910 5911 :6 0
5915 112 :3 0 3224
5917 3226 5916 5915
:2 0 5918 3228 :2 0
591a 0 591a 5919
58c7 5918 :6 0 595b
6f :3 0 8b :3 0
2dc :3 0 e8 :3 0
22d :3 0 72 :3 0
322b 591f 5921 48
:2 0 322d 591e 5924
2dd :2 0 e8 :3 0
22d :3 0 5b :3 0
3230 5928 592a 48
:2 0 3232 5927 592d
3235 5926 592f :3 0
5930 :2 0 1c1 :2 0
2eb :2 0 3238 5932
5934 :3 0 323b 591d
5936 591c 5937 0
595b 78 :3 0 20b
:3 0 1b2 :3 0 593a
593b 0 e8 :3 0
8b :3 0 48 :2 0
323d 593d 5940 1a
:3 0 39b :3 0 5942
5943 0 3240 593c
5945 5939 5946 0
595b 7e :3 0 24c
:3 0 2b :3 0 24
:3 0 78 :3 0 e8
:3 0 5b :3 0 48
:2 0 3243 594d 5950
e8 :3 0 4b :3 0
48 :2 0 3246 5952
5955 48 :2 0 3249
5949 5958 5948 5959
0 595b 3250 595f
2d8 :3 0 595c :4 0
595e 3258 5960 5314
595b 0 5961 0
595e 0 5961 325a
0 5962 325d 5ba6
2f :3 0 f7 :4 0
5963 5964 0 5ba5
e8 :3 0 5a :3 0
48 :2 0 3262 5966
5969 f3 :2 0 33
:2 0 3267 596b 596d
:3 0 e8 :3 0 50
:3 0 48 :2 0 326a
596f 5972 f3 :2 0
48 :2 0 326f 5974
5976 :3 0 596e 5978
5977 :2 0 e8 :3 0
8b :3 0 48 :2 0
3272 597a 597d 15c
:2 0 39c :2 0 3277
597f 5981 :3 0 5979
5983 5982 :2 0 e8
:3 0 8b :3 0 48
:2 0 327a 5985 5988
15c :2 0 48 :2 0
327f 598a 598c :3 0
5984 598e 598d :2 0
53 :3 0 fb :2 0
5990 5991 0 599a
50 :3 0 e8 :3 0
8b :3 0 48 :2 0
3282 5994 5997 5993
5998 0 599a 3285
599b 598f 599a 0
599c 3288 0 5ba5
e8 :3 0 55 :3 0
48 :2 0 328a 599d
59a0 f3 :2 0 48
:2 0 328f 59a2 59a4
:3 0 59a5 :2 0 e8
:3 0 55 :3 0 48
:2 0 3292 59a7 59aa
e8 :3 0 1eb :2 0
5b :3 0 48 :2 0
3295 59ac 59b0 329a
59ad 59b2 :3 0 59b3
:2 0 59a6 59b5 59b4
:2 0 55 :3 0 e8
:3 0 5b :3 0 48
:2 0 329d 59b8 59bb
59b7 59bc 0 59be
32a0 59d2 55 :3 0
2dc :3 0 e8 :3 0
55 :3 0 48 :2 0
32a2 59c1 59c4 2dd
:2 0 e8 :3 0 5b
:3 0 48 :2 0 32a5
59c7 59ca 32a8 59c6
59cc :3 0 32ab 59c0
59ce 59bf 59cf 0
59d1 32ad 59d3 59b6
59be 0 59d4 0
59d1 0 59d4 32af
0 5ba5 e8 :3 0
55 :3 0 48 :2 0
32b2 59d5 59d8 1eb
:2 0 39d :2 0 32b7
59da 59dc :3 0 55
:3 0 e8 :3 0 55
:3 0 48 :2 0 32ba
59df 59e2 1c1 :2 0
46 :2 0 32bd 59e4
59e6 :3 0 59de 59e7
0 59e9 32c0 59fc
55 :3 0 2dc :3 0
22d :3 0 e8 :3 0
55 :3 0 48 :2 0
32c2 59ed 59f0 32c5
59ec 59f2 1c1 :2 0
39e :2 0 32c7 59f4
59f6 :3 0 32ca 59eb
59f8 59ea 59f9 0
59fb 32cc 59fd 59dd
59e9 0 59fe 0
59fb 0 59fe 32ce
0 5ba5 e8 :3 0
73 :3 0 48 :2 0
32d1 59ff 5a02 15c
:2 0 48 :2 0 32d6
5a04 5a06 :3 0 a8
:3 0 25a :3 0 1b1
:3 0 1b2 :3 0 25a
:3 0 1a :3 0 25b
:3 0 258 :3 0 1b1
:3 0 1b2 :3 0 258
:3 0 1a :3 0 259
:3 0 26a :3 0 26a
:3 0 4b :3 0 b2
:3 0 24 :4 0 39f
1 :8 0 5a30 f9
:4 0 5a1b :3 0 112
:3 0 f3 :2 0 32db
5a1e 5a1f :3 0 15
:3 0 fa :3 0 5a21
5a22 0 48 :2 0
5a23 5a24 0 5a26
32de 5a2d 15 :3 0
fa :3 0 5a27 5a28
0 fb :2 0 5a29
5a2a 0 5a2c 32e0
5a2e 5a20 5a26 0
5a2f 0 5a2c 0
5a2f 32e2 0 5a30
32e5 5a83 fe :3 0
15 :3 0 fa :3 0
5a32 5a33 0 fd
:3 0 5a34 5a35 0
5a37 32e8 5a39 32ea
5a38 5a37 :2 0 5a81
ff :3 0 15 :3 0
fa :3 0 5a3c 5a3d
0 fd :3 0 5a3e
5a3f 0 5a79 db
:3 0 dc :3 0 5a41
5a42 0 db :3 0
ec :3 0 5a44 5a45
0 100 :2 0 2
:4 0 3a0 :2 0 ee
:2 0 33 :2 0 32ec
5a4a 5a4c :3 0 32ef
5a46 5a4e 5a43 5a50
5a4f :2 0 de :3 0
ef :3 0 5a52 5a53
0 e0 :4 0 3a1
:4 0 e3 :2 0 e4
:3 0 32f3 5a57 5a59
:3 0 e3 :2 0 103
:4 0 32f6 5a5b 5a5d
:3 0 e3 :2 0 104
:4 0 32f9 5a5f 5a61
:3 0 e3 :2 0 fd
:3 0 32fc 5a63 5a65
:3 0 e3 :2 0 105
:4 0 32ff 5a67 5a69
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 3302
5a6c 5a70 3306 5a6b
5a72 :3 0 3309 5a54
5a74 :2 0 5a76 330c
5a77 5a51 5a76 0
5a78 330e 0 5a79
3310 5a7c :3 0 5a7c
0 5a7c 5a7b 5a79
5a7a :6 0 5a7e 114
:3 0 3313 5a80 3315
5a7f 5a7e :2 0 5a81
3317 :2 0 5a83 0
5a83 5a82 5a30 5a81
:6 0 5a85 6f :3 0
331a 5b19 a8 :3 0
aa :3 0 2a :3 0
ab :3 0 ac :3 0
58 :3 0 26 :3 0
be :3 0 6e :3 0
65 :3 0 be :3 0
bf :3 0 6e :3 0
68 :3 0 bf :3 0
c0 :3 0 6d :3 0
67 :3 0 c0 :3 0
c1 :3 0 6d :3 0
69 :3 0 c1 :3 0
26a :3 0 4b :3 0
258 :3 0 1b1 :3 0
1b2 :3 0 258 :3 0
1a :3 0 259 :3 0
25a :3 0 1b1 :3 0
1b2 :3 0 25a :3 0
1a :3 0 25b :3 0
b2 :3 0 24 :4 0
3a2 1 :8 0 5ac3
f9 :4 0 5aae :3 0
112 :3 0 f3 :2 0
331e 5ab1 5ab2 :3 0
15 :3 0 fa :3 0
5ab4 5ab5 0 48
:2 0 5ab6 5ab7 0
5ab9 3321 5ac0 15
:3 0 fa :3 0 5aba
5abb 0 fb :2 0
5abc 5abd 0 5abf
3323 5ac1 5ab3 5ab9
0 5ac2 0 5abf
0 5ac2 3325 0
5ac3 3328 5b16 fe
:3 0 15 :3 0 fa
:3 0 5ac5 5ac6 0
fd :3 0 5ac7 5ac8
0 5aca 332b 5acc
332d 5acb 5aca :2 0
5b14 ff :3 0 15
:3 0 fa :3 0 5acf
5ad0 0 fd :3 0
5ad1 5ad2 0 5b0c
db :3 0 dc :3 0
5ad4 5ad5 0 db
:3 0 ec :3 0 5ad7
5ad8 0 100 :2 0
2 :4 0 3a3 :2 0
ee :2 0 33 :2 0
332f 5add 5adf :3 0
3332 5ad9 5ae1 5ad6
5ae3 5ae2 :2 0 de
:3 0 ef :3 0 5ae5
5ae6 0 e0 :4 0
3a4 :4 0 e3 :2 0
e4 :3 0 3336 5aea
5aec :3 0 e3 :2 0
103 :4 0 3339 5aee
5af0 :3 0 e3 :2 0
104 :4 0 333c 5af2
5af4 :3 0 e3 :2 0
fd :3 0 333f 5af6
5af8 :3 0 e3 :2 0
105 :4 0 3342 5afa
5afc :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
3345 5aff 5b03 3349
5afe 5b05 :3 0 334c
5ae7 5b07 :2 0 5b09
334f 5b0a 5ae4 5b09
0 5b0b 3351 0
5b0c 3353 5b0f :3 0
5b0f 0 5b0f 5b0e
5b0c 5b0d :6 0 5b11
116 :3 0 3356 5b13
3358 5b12 5b11 :2 0
5b14 335a :2 0 5b16
0 5b16 5b15 5ac3
5b14 :6 0 5b18 6f
:3 0 335d 5b1a 5a07
5a85 0 5b1b 0
5b18 0 5b1b 335f
0 5ba5 4c :3 0
48 :2 0 5b1c 5b1d
0 5ba5 e8 :3 0
5e :3 0 48 :2 0
3362 5b1f 5b22 1a
:3 0 f3 :2 0 f5
:3 0 5b24 5b26 0
3367 5b25 5b28 :3 0
5d :3 0 24b :2 0
5b2a 5b2b 0 5b2d
336a 5b32 5d :3 0
33 :2 0 5b2e 5b2f
0 5b31 336c 5b33
5b29 5b2d 0 5b34
0 5b31 0 5b34
336e 0 5ba5 e8
:3 0 50 :3 0 48
:2 0 3371 5b35 5b38
f3 :2 0 48 :2 0
3376 5b3a 5b3c :3 0
5a :3 0 1a :3 0
20a :3 0 5b3f 5b40
0 5b3e 5b41 0
5b43 3379 5b54 5a
:3 0 20b :3 0 1b2
:3 0 5b45 5b46 0
e8 :3 0 5a :3 0
48 :2 0 337b 5b48
5b4b 1a :3 0 20a
:3 0 5b4d 5b4e 0
337e 5b47 5b50 5b44
5b51 0 5b53 3381
5b55 5b3d 5b43 0
5b56 0 5b53 0
5b56 3383 0 5ba5
51 :3 0 48 :2 0
5b57 5b58 0 5ba5
96 :3 0 22c :3 0
24 :3 0 2b :3 0
29 :3 0 2a :3 0
77 :3 0 4d :3 0
34 :3 0 34 :3 0
34 :3 0 34 :3 0
2d :3 0 2f :3 0
55 :3 0 4b :3 0
50 :3 0 52 :3 0
53 :3 0 4c :3 0
5e :3 0 39 :3 0
56 :3 0 5a :3 0
54 :3 0 51 :3 0
5d :3 0 5b :3 0
5f :3 0 21 :3 0
48 :2 0 48 :2 0
22b :2 0 22b :2 0
48 :2 0 48 :2 0
3386 5b5b 5b7e 5b5a
5b7f 0 5ba5 96
:3 0 f3 :2 0 22f
:2 0 33ab 5b82 5b84
:3 0 91 :3 0 1a
:3 0 232 :3 0 5b87
5b88 0 5b86 5b89
0 5b91 90 :3 0
2a :3 0 5b8b 5b8c
0 5b91 284 :8 0
5b91 16a :3 0 33ae
5ba3 96 :3 0 15c
:2 0 48 :2 0 33b4
5b93 5b95 :3 0 91
:3 0 1a :3 0 1d5
:3 0 5b98 5b99 0
5b97 5b9a 0 5ba1
90 :3 0 23 :3 0
5b9c 5b9d 0 5ba1
284 :8 0 5ba1 33b7
5ba2 5b96 5ba1 0
5ba4 5b85 5b91 0
5ba4 33bb 0 5ba5
33be 5ba7 51e5 5962
0 5ba8 0 5ba5
0 5ba8 33ca 0
6050 c7 :3 0 198
:3 0 199 :3 0 198
:3 0 44 :3 0 a4
:3 0 29 :4 0 3a5
1 :8 0 5bc6 f9
:4 0 5bb1 :3 0 112
:3 0 f3 :2 0 33cf
5bb4 5bb5 :3 0 15
:3 0 fa :3 0 5bb7
5bb8 0 48 :2 0
5bb9 5bba 0 5bbc
33d2 5bc3 15 :3 0
fa :3 0 5bbd 5bbe
0 fb :2 0 5bbf
5bc0 0 5bc2 33d4
5bc4 5bb6 5bbc 0
5bc5 0 5bc2 0
5bc5 33d6 0 5bc6
33d9 5c19 fe :3 0
15 :3 0 fa :3 0
5bc8 5bc9 0 fd
:3 0 5bca 5bcb 0
5bcd 33dc 5bcf 33de
5bce 5bcd :2 0 5c17
ff :3 0 15 :3 0
fa :3 0 5bd2 5bd3
0 fd :3 0 5bd4
5bd5 0 5c0f db
:3 0 dc :3 0 5bd7
5bd8 0 db :3 0
ec :3 0 5bda 5bdb
0 100 :2 0 2
:4 0 75 :2 0 ee
:2 0 33 :2 0 33e0
5be0 5be2 :3 0 33e3
5bdc 5be4 5bd9 5be6
5be5 :2 0 de :3 0
ef :3 0 5be8 5be9
0 e0 :4 0 3a6
:4 0 e3 :2 0 e4
:3 0 33e7 5bed 5bef
:3 0 e3 :2 0 103
:4 0 33ea 5bf1 5bf3
:3 0 e3 :2 0 104
:4 0 33ed 5bf5 5bf7
:3 0 e3 :2 0 fd
:3 0 33f0 5bf9 5bfb
:3 0 e3 :2 0 105
:4 0 33f3 5bfd 5bff
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 33f6
5c02 5c06 33fa 5c01
5c08 :3 0 33fd 5bea
5c0a :2 0 5c0c 3400
5c0d 5be7 5c0c 0
5c0e 3402 0 5c0f
3404 5c12 :3 0 5c12
0 5c12 5c11 5c0f
5c10 :6 0 5c14 118
:3 0 3407 5c16 3409
5c15 5c14 :2 0 5c17
340b :2 0 5c19 0
5c19 5c18 5bc6 5c17
:6 0 6050 6f :3 0
e8 :3 0 73 :3 0
48 :2 0 340e 5c1b
5c1e 15c :2 0 48
:2 0 3413 5c20 5c22
:3 0 161 :2 0 3416
5c24 5c25 :3 0 320
:3 0 24 :3 0 321
:3 0 a4 :3 0 321
:3 0 322 :3 0 321
:3 0 323 :3 0 321
:3 0 324 :3 0 321
:3 0 325 :3 0 326
:3 0 321 :3 0 134
:3 0 148 :3 0 327
:3 0 321 :3 0 a4
:3 0 327 :3 0 147
:3 0 327 :3 0 149
:3 0 2c :4 0 3a7
1 :8 0 5c55 f9
:4 0 5c40 :3 0 112
:3 0 f3 :2 0 341a
5c43 5c44 :3 0 15
:3 0 fa :3 0 5c46
5c47 0 48 :2 0
5c48 5c49 0 5c4b
341d 5c52 15 :3 0
fa :3 0 5c4c 5c4d
0 fb :2 0 5c4e
5c4f 0 5c51 341f
5c53 5c45 5c4b 0
5c54 0 5c51 0
5c54 3421 0 5c55
3424 5ca8 fe :3 0
15 :3 0 fa :3 0
5c57 5c58 0 fd
:3 0 5c59 5c5a 0
5c5c 3427 5c5e 3429
5c5d 5c5c :2 0 5ca6
ff :3 0 15 :3 0
fa :3 0 5c61 5c62
0 fd :3 0 5c63
5c64 0 5c9e db
:3 0 dc :3 0 5c66
5c67 0 db :3 0
ec :3 0 5c69 5c6a
0 100 :2 0 2
:4 0 3a8 :2 0 ee
:2 0 33 :2 0 342b
5c6f 5c71 :3 0 342e
5c6b 5c73 5c68 5c75
5c74 :2 0 de :3 0
ef :3 0 5c77 5c78
0 e0 :4 0 3a9
:4 0 e3 :2 0 e4
:3 0 3432 5c7c 5c7e
:3 0 e3 :2 0 103
:4 0 3435 5c80 5c82
:3 0 e3 :2 0 104
:4 0 3438 5c84 5c86
:3 0 e3 :2 0 fd
:3 0 343b 5c88 5c8a
:3 0 e3 :2 0 105
:4 0 343e 5c8c 5c8e
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 3441
5c91 5c95 3445 5c90
5c97 :3 0 3448 5c79
5c99 :2 0 5c9b 344b
5c9c 5c76 5c9b 0
5c9d 344d 0 5c9e
344f 5ca1 :3 0 5ca1
0 5ca1 5ca0 5c9e
5c9f :6 0 5ca3 11a
:3 0 3452 5ca5 3454
5ca4 5ca3 :2 0 5ca6
3456 :2 0 5ca8 0
5ca8 5ca7 5c55 5ca6
:6 0 5d96 6f :3 0
320 :3 0 24 :3 0
147 :3 0 322 :3 0
323 :3 0 324 :3 0
325 :3 0 32b :3 0
320 :3 0 b0 :3 0
2c :4 0 3aa 1
:8 0 5ccb f9 :4 0
5cb6 :3 0 112 :3 0
f3 :2 0 345b 5cb9
5cba :3 0 15 :3 0
fa :3 0 5cbc 5cbd
0 48 :2 0 5cbe
5cbf 0 5cc1 345e
5cc8 15 :3 0 fa
:3 0 5cc2 5cc3 0
fb :2 0 5cc4 5cc5
0 5cc7 3460 5cc9
5cbb 5cc1 0 5cca
0 5cc7 0 5cca
3462 0 5ccb 3465
5d1e fe :3 0 15
:3 0 fa :3 0 5ccd
5cce 0 fd :3 0
5ccf 5cd0 0 5cd2
3468 5cd4 346a 5cd3
5cd2 :2 0 5d1c ff
:3 0 15 :3 0 fa
:3 0 5cd7 5cd8 0
fd :3 0 5cd9 5cda
0 5d14 db :3 0
dc :3 0 5cdc 5cdd
0 db :3 0 ec
:3 0 5cdf 5ce0 0
100 :2 0 2 :4 0
3ab :2 0 ee :2 0
33 :2 0 346c 5ce5
5ce7 :3 0 346f 5ce1
5ce9 5cde 5ceb 5cea
:2 0 de :3 0 ef
:3 0 5ced 5cee 0
e0 :4 0 3ac :4 0
e3 :2 0 e4 :3 0
3473 5cf2 5cf4 :3 0
e3 :2 0 103 :4 0
3476 5cf6 5cf8 :3 0
e3 :2 0 104 :4 0
3479 5cfa 5cfc :3 0
e3 :2 0 fd :3 0
347c 5cfe 5d00 :3 0
e3 :2 0 105 :4 0
347f 5d02 5d04 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 3482 5d07
5d0b 3486 5d06 5d0d
:3 0 3489 5cef 5d0f
:2 0 5d11 348c 5d12
5cec 5d11 0 5d13
348e 0 5d14 3490
5d17 :3 0 5d17 0
5d17 5d16 5d14 5d15
:6 0 5d19 11c :3 0
3493 5d1b 3495 5d1a
5d19 :2 0 5d1c 3497
:2 0 5d1e 0 5d1e
5d1d 5ccb 5d1c :6 0
5d96 6f :3 0 32f
:3 0 24 :3 0 330
:3 0 322 :3 0 323
:3 0 324 :3 0 325
:3 0 331 :3 0 32f
:3 0 b0 :3 0 2c
:4 0 3ad 1 :8 0
5d41 f9 :4 0 5d2c
:3 0 112 :3 0 f3
:2 0 349c 5d2f 5d30
:3 0 15 :3 0 fa
:3 0 5d32 5d33 0
48 :2 0 5d34 5d35
0 5d37 349f 5d3e
15 :3 0 fa :3 0
5d38 5d39 0 fb
:2 0 5d3a 5d3b 0
5d3d 34a1 5d3f 5d31
5d37 0 5d40 0
5d3d 0 5d40 34a3
0 5d41 34a6 5d94
fe :3 0 15 :3 0
fa :3 0 5d43 5d44
0 fd :3 0 5d45
5d46 0 5d48 34a9
5d4a 34ab 5d49 5d48
:2 0 5d92 ff :3 0
15 :3 0 fa :3 0
5d4d 5d4e 0 fd
:3 0 5d4f 5d50 0
5d8a db :3 0 dc
:3 0 5d52 5d53 0
db :3 0 ec :3 0
5d55 5d56 0 100
:2 0 2 :4 0 3ae
:2 0 ee :2 0 33
:2 0 34ad 5d5b 5d5d
:3 0 34b0 5d57 5d5f
5d54 5d61 5d60 :2 0
de :3 0 ef :3 0
5d63 5d64 0 e0
:4 0 3af :4 0 e3
:2 0 e4 :3 0 34b4
5d68 5d6a :3 0 e3
:2 0 103 :4 0 34b7
5d6c 5d6e :3 0 e3
:2 0 104 :4 0 34ba
5d70 5d72 :3 0 e3
:2 0 fd :3 0 34bd
5d74 5d76 :3 0 e3
:2 0 105 :4 0 34c0
5d78 5d7a :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 34c3 5d7d 5d81
34c7 5d7c 5d83 :3 0
34ca 5d65 5d85 :2 0
5d87 34cd 5d88 5d62
5d87 0 5d89 34cf
0 5d8a 34d1 5d8d
:3 0 5d8d 0 5d8d
5d8c 5d8a 5d8b :6 0
5d8f 11e :3 0 34d4
5d91 34d6 5d90 5d8f
:2 0 5d92 34d8 :2 0
5d94 0 5d94 5d93
5d41 5d92 :6 0 5d96
6f :3 0 34db 5d97
5c26 5d96 0 5d98
34df 0 6050 79
:3 0 33 :4 0 5d99
5d9a 0 6050 7e
:3 0 299 :3 0 2b
:3 0 2c :3 0 79
:3 0 34e1 5d9d 5da1
5d9c 5da2 0 6050
79 :3 0 48 :4 0
5da4 5da5 0 6050
7e :3 0 299 :3 0
2b :3 0 2a :3 0
79 :3 0 34e5 5da8
5dac 5da7 5dad 0
6050 33a :3 0 aa
:3 0 2a :3 0 a9
:3 0 2b :3 0 b2
:3 0 24 :4 0 3b0
1 :8 0 5dcc f9
:4 0 5db7 :3 0 112
:3 0 f3 :2 0 34eb
5dba 5dbb :3 0 15
:3 0 fa :3 0 5dbd
5dbe 0 48 :2 0
5dbf 5dc0 0 5dc2
34ee 5dc9 15 :3 0
fa :3 0 5dc3 5dc4
0 fb :2 0 5dc5
5dc6 0 5dc8 34f0
5dca 5dbc 5dc2 0
5dcb 0 5dc8 0
5dcb 34f2 0 5dcc
34f5 5e1f fe :3 0
15 :3 0 fa :3 0
5dce 5dcf 0 fd
:3 0 5dd0 5dd1 0
5dd3 34f8 5dd5 34fa
5dd4 5dd3 :2 0 5e1d
ff :3 0 15 :3 0
fa :3 0 5dd8 5dd9
0 fd :3 0 5dda
5ddb 0 5e15 db
:3 0 dc :3 0 5ddd
5dde 0 db :3 0
ec :3 0 5de0 5de1
0 100 :2 0 2
:4 0 3b1 :2 0 ee
:2 0 33 :2 0 34fc
5de6 5de8 :3 0 34ff
5de2 5dea 5ddf 5dec
5deb :2 0 de :3 0
ef :3 0 5dee 5def
0 e0 :4 0 3b2
:4 0 e3 :2 0 e4
:3 0 3503 5df3 5df5
:3 0 e3 :2 0 103
:4 0 3506 5df7 5df9
:3 0 e3 :2 0 104
:4 0 3509 5dfb 5dfd
:3 0 e3 :2 0 fd
:3 0 350c 5dff 5e01
:3 0 e3 :2 0 105
:4 0 350f 5e03 5e05
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 3512
5e08 5e0c 3516 5e07
5e0e :3 0 3519 5df0
5e10 :2 0 5e12 351c
5e13 5ded 5e12 0
5e14 351e 0 5e15
3520 5e18 :3 0 5e18
0 5e18 5e17 5e15
5e16 :6 0 5e1a 120
:3 0 3523 5e1c 3525
5e1b 5e1a :2 0 5e1d
3527 :2 0 5e1f 0
5e1f 5e1e 5dcc 5e1d
:6 0 6050 6f :3 0
e8 :3 0 6e :3 0
48 :2 0 352a 5e21
5e24 f3 :2 0 48
:2 0 352f 5e26 5e28
:3 0 5e29 :2 0 e8
:3 0 6d :3 0 48
:2 0 3532 5e2b 5e2e
f3 :2 0 48 :2 0
3537 5e30 5e32 :3 0
5e33 :2 0 5e2a 5e35
5e34 :2 0 347 :3 0
aa :3 0 2a :3 0
3b3 :3 0 65 :3 0
3b4 :3 0 68 :3 0
3b5 :3 0 67 :3 0
3b6 :3 0 69 :3 0
18f :3 0 21 :3 0
190 :3 0 e4 :3 0
b2 :3 0 1f :4 0
3b7 1 :8 0 5e5e
f9 :4 0 5e49 :3 0
112 :3 0 f3 :2 0
353c 5e4c 5e4d :3 0
15 :3 0 fa :3 0
5e4f 5e50 0 48
:2 0 5e51 5e52 0
5e54 353f 5e5b 15
:3 0 fa :3 0 5e55
5e56 0 fb :2 0
5e57 5e58 0 5e5a
3541 5e5c 5e4e 5e54
0 5e5d 0 5e5a
0 5e5d 3543 0
5e5e 3546 5eb1 fe
:3 0 15 :3 0 fa
:3 0 5e60 5e61 0
fd :3 0 5e62 5e63
0 5e65 3549 5e67
354b 5e66 5e65 :2 0
5eaf ff :3 0 15
:3 0 fa :3 0 5e6a
5e6b 0 fd :3 0
5e6c 5e6d 0 5ea7
db :3 0 dc :3 0
5e6f 5e70 0 db
:3 0 ec :3 0 5e72
5e73 0 100 :2 0
2 :4 0 3b8 :2 0
ee :2 0 33 :2 0
354d 5e78 5e7a :3 0
3550 5e74 5e7c 5e71
5e7e 5e7d :2 0 de
:3 0 ef :3 0 5e80
5e81 0 e0 :4 0
3b9 :4 0 e3 :2 0
e4 :3 0 3554 5e85
5e87 :3 0 e3 :2 0
103 :4 0 3557 5e89
5e8b :3 0 e3 :2 0
104 :4 0 355a 5e8d
5e8f :3 0 e3 :2 0
fd :3 0 355d 5e91
5e93 :3 0 e3 :2 0
105 :4 0 3560 5e95
5e97 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
3563 5e9a 5e9e 3567
5e99 5ea0 :3 0 356a
5e82 5ea2 :2 0 5ea4
356d 5ea5 5e7f 5ea4
0 5ea6 356f 0
5ea7 3571 5eaa :3 0
5eaa 0 5eaa 5ea9
5ea7 5ea8 :6 0 5eac
122 :3 0 3574 5eae
3576 5ead 5eac :2 0
5eaf 3578 :2 0 5eb1
0 5eb1 5eb0 5e5e
5eaf :6 0 5eb4 6f
:3 0 16a :3 0 357b
604d e8 :3 0 6e
:3 0 48 :2 0 357d
5eb5 5eb8 f3 :2 0
48 :2 0 3582 5eba
5ebc :3 0 347 :3 0
aa :3 0 2a :3 0
3b3 :3 0 65 :3 0
3b4 :3 0 68 :3 0
18f :3 0 21 :3 0
190 :3 0 e4 :3 0
b2 :3 0 1f :4 0
3ba 1 :8 0 5ee1
f9 :4 0 5ecc :3 0
112 :3 0 f3 :2 0
3587 5ecf 5ed0 :3 0
15 :3 0 fa :3 0
5ed2 5ed3 0 48
:2 0 5ed4 5ed5 0
5ed7 358a 5ede 15
:3 0 fa :3 0 5ed8
5ed9 0 fb :2 0
5eda 5edb 0 5edd
358c 5edf 5ed1 5ed7
0 5ee0 0 5edd
0 5ee0 358e 0
5ee1 3591 5f34 fe
:3 0 15 :3 0 fa
:3 0 5ee3 5ee4 0
fd :3 0 5ee5 5ee6
0 5ee8 3594 5eea
3596 5ee9 5ee8 :2 0
5f32 ff :3 0 15
:3 0 fa :3 0 5eed
5eee 0 fd :3 0
5eef 5ef0 0 5f2a
db :3 0 dc :3 0
5ef2 5ef3 0 db
:3 0 ec :3 0 5ef5
5ef6 0 100 :2 0
2 :4 0 3bb :2 0
ee :2 0 33 :2 0
3598 5efb 5efd :3 0
359b 5ef7 5eff 5ef4
5f01 5f00 :2 0 de
:3 0 ef :3 0 5f03
5f04 0 e0 :4 0
3bc :4 0 e3 :2 0
e4 :3 0 359f 5f08
5f0a :3 0 e3 :2 0
103 :4 0 35a2 5f0c
5f0e :3 0 e3 :2 0
104 :4 0 35a5 5f10
5f12 :3 0 e3 :2 0
fd :3 0 35a8 5f14
5f16 :3 0 e3 :2 0
105 :4 0 35ab 5f18
5f1a :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
35ae 5f1d 5f21 35b2
5f1c 5f23 :3 0 35b5
5f05 5f25 :2 0 5f27
35b8 5f28 5f02 5f27
0 5f29 35ba 0
5f2a 35bc 5f2d :3 0
5f2d 0 5f2d 5f2c
5f2a 5f2b :6 0 5f2f
124 :3 0 35bf 5f31
35c1 5f30 5f2f :2 0
5f32 35c3 :2 0 5f34
0 5f34 5f33 5ee1
5f32 :6 0 5f3e 6f
:3 0 67 :3 0 e8
:3 0 81 :3 0 48
:2 0 35c6 5f37 5f3a
5f36 5f3b 0 5f3e
16a :3 0 35c9 5f3f
5ebd 5f3e 0 604f
e8 :3 0 6d :3 0
48 :2 0 35cc 5f40
5f43 f3 :2 0 48
:2 0 35d1 5f45 5f47
:3 0 347 :3 0 aa
:3 0 2a :3 0 3b5
:3 0 67 :3 0 3b6
:3 0 69 :3 0 18f
:3 0 21 :3 0 190
:3 0 e4 :3 0 b2
:3 0 1f :4 0 3bd
1 :8 0 5f6c f9
:4 0 5f57 :3 0 112
:3 0 f3 :2 0 35d6
5f5a 5f5b :3 0 15
:3 0 fa :3 0 5f5d
5f5e 0 48 :2 0
5f5f 5f60 0 5f62
35d9 5f69 15 :3 0
fa :3 0 5f63 5f64
0 fb :2 0 5f65
5f66 0 5f68 35db
5f6a 5f5c 5f62 0
5f6b 0 5f68 0
5f6b 35dd 0 5f6c
35e0 5fbf fe :3 0
15 :3 0 fa :3 0
5f6e 5f6f 0 fd
:3 0 5f70 5f71 0
5f73 35e3 5f75 35e5
5f74 5f73 :2 0 5fbd
ff :3 0 15 :3 0
fa :3 0 5f78 5f79
0 fd :3 0 5f7a
5f7b 0 5fb5 db
:3 0 dc :3 0 5f7d
5f7e 0 db :3 0
ec :3 0 5f80 5f81
0 100 :2 0 2
:4 0 3be :2 0 ee
:2 0 33 :2 0 35e7
5f86 5f88 :3 0 35ea
5f82 5f8a 5f7f 5f8c
5f8b :2 0 de :3 0
ef :3 0 5f8e 5f8f
0 e0 :4 0 3bf
:4 0 e3 :2 0 e4
:3 0 35ee 5f93 5f95
:3 0 e3 :2 0 103
:4 0 35f1 5f97 5f99
:3 0 e3 :2 0 104
:4 0 35f4 5f9b 5f9d
:3 0 e3 :2 0 fd
:3 0 35f7 5f9f 5fa1
:3 0 e3 :2 0 105
:4 0 35fa 5fa3 5fa5
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 35fd
5fa8 5fac 3601 5fa7
5fae :3 0 3604 5f90
5fb0 :2 0 5fb2 3607
5fb3 5f8d 5fb2 0
5fb4 3609 0 5fb5
360b 5fb8 :3 0 5fb8
0 5fb8 5fb7 5fb5
5fb6 :6 0 5fba 126
:3 0 360e 5fbc 3610
5fbb 5fba :2 0 5fbd
3612 :2 0 5fbf 0
5fbf 5fbe 5f6c 5fbd
:6 0 5fc8 6f :3 0
65 :3 0 e8 :3 0
7f :3 0 48 :2 0
3615 5fc2 5fc5 5fc1
5fc6 0 5fc8 3618
5fc9 5f48 5fc8 0
604f 347 :3 0 aa
:3 0 2a :3 0 18f
:3 0 21 :3 0 190
:3 0 e4 :3 0 b2
:3 0 1f :4 0 3c0
1 :8 0 5fe9 f9
:4 0 5fd4 :3 0 112
:3 0 f3 :2 0 361d
5fd7 5fd8 :3 0 15
:3 0 fa :3 0 5fda
5fdb 0 48 :2 0
5fdc 5fdd 0 5fdf
3620 5fe6 15 :3 0
fa :3 0 5fe0 5fe1
0 fb :2 0 5fe2
5fe3 0 5fe5 3622
5fe7 5fd9 5fdf 0
5fe8 0 5fe5 0
5fe8 3624 0 5fe9
3627 603c fe :3 0
15 :3 0 fa :3 0
5feb 5fec 0 fd
:3 0 5fed 5fee 0
5ff0 362a 5ff2 362c
5ff1 5ff0 :2 0 603a
ff :3 0 15 :3 0
fa :3 0 5ff5 5ff6
0 fd :3 0 5ff7
5ff8 0 6032 db
:3 0 dc :3 0 5ffa
5ffb 0 db :3 0
ec :3 0 5ffd 5ffe
0 100 :2 0 2
:4 0 3c1 :2 0 ee
:2 0 33 :2 0 362e
6003 6005 :3 0 3631
5fff 6007 5ffc 6009
6008 :2 0 de :3 0
ef :3 0 600b 600c
0 e0 :4 0 3c2
:4 0 e3 :2 0 e4
:3 0 3635 6010 6012
:3 0 e3 :2 0 103
:4 0 3638 6014 6016
:3 0 e3 :2 0 104
:4 0 363b 6018 601a
:3 0 e3 :2 0 fd
:3 0 363e 601c 601e
:3 0 e3 :2 0 105
:4 0 3641 6020 6022
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 3644
6025 6029 3648 6024
602b :3 0 364b 600d
602d :2 0 602f 364e
6030 600a 602f 0
6031 3650 0 6032
3652 6035 :3 0 6035
0 6035 6034 6032
6033 :6 0 6037 128
:3 0 3655 6039 3657
6038 6037 :2 0 603a
3659 :2 0 603c 0
603c 603b 5fe9 603a
:6 0 604c 6f :3 0
65 :3 0 e8 :3 0
7f :3 0 48 :2 0
365c 603f 6042 603e
6043 0 604c 67
:3 0 e8 :3 0 81
:3 0 48 :2 0 365f
6046 6049 6045 604a
0 604c 3662 604e
5e36 5eb4 0 604f
0 604c 0 604f
3666 0 6050 366b
6051 50aa 6050 0
6052 3676 0 606d
57 :3 0 e8 :3 0
57 :3 0 48 :2 0
3678 6054 6057 ee
:2 0 33 :2 0 367b
6059 605b :3 0 6053
605c 0 606d 4f
:3 0 e8 :3 0 4f
:3 0 48 :2 0 367e
605f 6062 ee :2 0
e8 :3 0 4b :3 0
48 :2 0 3681 6065
6068 3684 6064 606a
:3 0 605e 606b 0
606d 3687 606f 4584
4822 0 6070 0
606d 0 6070 368f
0 607b 15 :3 0
fa :3 0 6071 6072
0 3c3 :3 0 2b
:3 0 2c :3 0 21
:3 0 3692 6074 6078
6073 6079 0 607b
3696 607d 2baf 4574
0 607e 0 607b
0 607e 369a 0
6083 2d8 :5 0 6081
12a 0 6082 369d
6081 6080 6083 369f
6085 283 :4 0 6083
:4 0 6d23 fc :3 0
ae :4 0 6089 :2 0
608f 6087 0 15
:3 0 fa :3 0 608a
608b 0 fd :3 0
608c 608d 0 608f
36a8 60e2 fe :3 0
15 :3 0 fa :3 0
6091 6092 0 fd
:3 0 6093 6094 0
6096 36ab 6098 36ad
6097 6096 :2 0 60e0
ff :3 0 15 :3 0
fa :3 0 609b 609c
0 fd :3 0 609d
609e 0 60d8 db
:3 0 dc :3 0 60a0
60a1 0 db :3 0
ec :3 0 60a3 60a4
0 100 :2 0 2
:4 0 3c4 :2 0 ee
:2 0 33 :2 0 36af
60a9 60ab :3 0 36b2
60a5 60ad 60a2 60af
60ae :2 0 de :3 0
ef :3 0 60b1 60b2
0 e0 :4 0 3c5
:4 0 e3 :2 0 e4
:3 0 36b6 60b6 60b8
:3 0 e3 :2 0 103
:4 0 36b9 60ba 60bc
:3 0 e3 :2 0 104
:4 0 36bc 60be 60c0
:3 0 e3 :2 0 fd
:3 0 36bf 60c2 60c4
:3 0 e3 :2 0 105
:4 0 36c2 60c6 60c8
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 36c5
60cb 60cf 36c9 60ca
60d1 :3 0 36cc 60b3
60d3 :2 0 60d5 36cf
60d6 60b0 60d5 0
60d7 36d1 0 60d8
36d3 60db :3 0 60db
0 60db 60da 60d8
60d9 :6 0 60dd 12a
:3 0 36d6 60df 36d8
60de 60dd :2 0 60e0
36da :2 0 60e2 0
60e2 60e1 608f 60e0
:6 0 6d23 1 :3 0
e8 :3 0 91 :3 0
48 :2 0 36dd 60e4
60e7 15c :2 0 48
:2 0 36e2 60e9 60eb
:3 0 db :3 0 dc
:3 0 60ed 60ee 0
db :3 0 ec :3 0
60f0 60f1 0 1e
:2 0 2 :4 0 3c6
:2 0 ee :2 0 33
:2 0 36e5 60f6 60f8
:3 0 36e8 60f2 60fa
60ef 60fc 60fb :2 0
de :3 0 ef :3 0
60fe 60ff 0 e0
:4 0 3c7 :4 0 e3
:2 0 e4 :3 0 36ec
6103 6105 :3 0 e3
:2 0 103 :4 0 36ef
6107 6109 :3 0 e3
:2 0 10b :4 0 36f2
610b 610d :3 0 e3
:2 0 e8 :3 0 e9
:3 0 91 :3 0 36f5
6111 6113 ea :4 0
36f7 6110 6116 36fa
610f 6118 :3 0 e3
:2 0 10d :4 0 36fd
611a 611c :3 0 e3
:2 0 e6 :4 0 3700
611e 6120 :3 0 e3
:2 0 90 :3 0 3703
6122 6124 :3 0 e3
:2 0 e6 :4 0 3706
6126 6128 :3 0 3709
6100 612a :2 0 612c
370c 612d 60fd 612c
0 612e 370e 0
615a db :3 0 dc
:3 0 612f 6130 0
db :3 0 ec :3 0
6132 6133 0 33
:2 0 2 :4 0 3c8
:2 0 ee :2 0 33
:2 0 3710 6138 613a
:3 0 3713 6134 613c
6131 613e 613d :2 0
de :3 0 ef :3 0
6140 6141 0 e0
:4 0 3c9 :4 0 e3
:2 0 e4 :3 0 3717
6145 6147 :3 0 371a
6142 6149 :2 0 614b
371d 614c 613f 614b
0 614d 371f 0
615a 110 :3 0 111
:3 0 614e 614f 0
e8 :3 0 91 :3 0
48 :2 0 3721 6151
6154 90 :3 0 112
:3 0 3724 6150 6158
:2 0 615a 3728 615b
60ec 615a 0 615c
372c 0 6d23 62
:3 0 48 :2 0 615d
615e 0 6d23 e8
:3 0 57 :3 0 48
:2 0 372e 6160 6163
124 :2 0 48 :2 0
3733 6165 6167 :3 0
4b :3 0 9 :3 0
6169 616a 0 66ca
e8 :3 0 4b :3 0
48 :2 0 3736 616c
616f e8 :3 0 3ca
:2 0 4f :3 0 48
:2 0 3739 6171 6175
373e 6172 6177 :3 0
4b :3 0 e8 :3 0
4b :3 0 48 :2 0
3741 617a 617d 1da
:2 0 e8 :3 0 4f
:3 0 48 :2 0 3744
6180 6183 3747 617f
6185 :3 0 6179 6186
0 6560 e8 :3 0
4b :3 0 48 :2 0
374a 6188 618b 124
:2 0 48 :2 0 374f
618d 618f :3 0 6190
:2 0 e8 :3 0 58
:3 0 48 :2 0 3752
6192 6195 124 :2 0
48 :2 0 3757 6197
6199 :3 0 619a :2 0
6191 619c 619b :2 0
26 :3 0 1ce :2 0
375a 619f 61a0 :3 0
61a1 :2 0 61a2 :2 0
619d 61a4 61a3 :2 0
2d :3 0 7 :3 0
61a6 61a7 0 655c
2f :3 0 8 :3 0
61a9 61aa 0 655c
50 :3 0 b :3 0
61ac 61ad 0 655c
51 :3 0 10 :3 0
61af 61b0 0 655c
52 :3 0 d :3 0
61b2 61b3 0 655c
53 :3 0 e :3 0
61b5 61b6 0 655c
5a :3 0 c :3 0
61b8 61b9 0 655c
54 :3 0 f :3 0
61bb 61bc 0 655c
e8 :3 0 54 :3 0
48 :2 0 375c 61be
61c1 f3 :2 0 48
:2 0 3761 61c3 61c5
:3 0 61c6 :2 0 e8
:3 0 53 :3 0 48
:2 0 3764 61c8 61cb
15c :2 0 fb :2 0
3769 61cd 61cf :3 0
61d0 :2 0 61c7 61d2
61d1 :2 0 50 :3 0
48 :2 0 61d4 61d5
0 61d8 16a :3 0
376c 61eb e8 :3 0
53 :3 0 48 :2 0
376e 61d9 61dc f3
:2 0 fb :2 0 3773
61de 61e0 :3 0 8b
:3 0 e8 :3 0 50
:3 0 48 :2 0 3776
61e3 61e6 61e2 61e7
0 61e9 3779 61ea
61e1 61e9 0 61ec
61d3 61d8 0 61ec
377b 0 655c 78
:3 0 1f8 :3 0 3c
:3 0 3d :3 0 e8
:3 0 52 :3 0 48
:2 0 377e 61f1 61f4
e8 :3 0 53 :3 0
48 :2 0 3781 61f6
61f9 e8 :3 0 5e
:3 0 48 :2 0 3784
61fb 61fe e8 :3 0
5a :3 0 48 :2 0
3787 6200 6203 e8
:3 0 54 :3 0 48
:2 0 378a 6205 6208
e8 :3 0 51 :3 0
48 :2 0 378d 620a
620d e8 :3 0 5b
:3 0 48 :2 0 3790
620f 6212 e8 :3 0
5c :3 0 48 :2 0
3793 6214 6217 50
:3 0 4b :3 0 55
:3 0 3796 61ee 621c
61ed 621d 0 655c
e8 :3 0 78 :3 0
48 :2 0 37a4 621f
6222 1a :3 0 f3
:2 0 1f9 :3 0 6224
6226 0 37a9 6225
6228 :3 0 db :3 0
dc :3 0 622a 622b
0 db :3 0 ec
:3 0 622d 622e 0
1fa :2 0 2 :4 0
3cb :2 0 ee :2 0
33 :2 0 37ac 6233
6235 :3 0 37af 622f
6237 622c 6239 6238
:2 0 de :3 0 ef
:3 0 623b 623c 0
e0 :4 0 3cc :4 0
e3 :2 0 e4 :3 0
37b3 6240 6242 :3 0
e3 :2 0 103 :4 0
37b6 6244 6246 :3 0
e3 :2 0 10b :4 0
37b9 6248 624a :3 0
e3 :2 0 e8 :3 0
e9 :3 0 1a :3 0
1f9 :3 0 624f 6250
0 37bc 624e 6252
ea :4 0 37be 624d
6255 37c1 624c 6257
:3 0 37c4 623d 6259
:2 0 625b 37c7 625c
623a 625b 0 625d
37c9 0 6287 db
:3 0 dc :3 0 625e
625f 0 db :3 0
ec :3 0 6261 6262
0 33 :2 0 2
:4 0 3cd :2 0 ee
:2 0 33 :2 0 37cb
6267 6269 :3 0 37ce
6263 626b 6260 626d
626c :2 0 de :3 0
ef :3 0 626f 6270
0 e0 :4 0 3ce
:4 0 e3 :2 0 e4
:3 0 37d2 6274 6276
:3 0 37d5 6271 6278
:2 0 627a 37d8 627b
626e 627a 0 627c
37da 0 6287 110
:3 0 1ff :3 0 627d
627e 0 1a :3 0
1f9 :3 0 6280 6281
0 112 :3 0 37dc
627f 6284 :2 0 6287
16a :3 0 37df 6300
e8 :3 0 78 :3 0
48 :2 0 37e3 6288
628b 15c :2 0 48
:2 0 37e8 628d 628f
:3 0 db :3 0 dc
:3 0 6291 6292 0
db :3 0 ec :3 0
6294 6295 0 1e
:2 0 2 :4 0 3cf
:2 0 ee :2 0 33
:2 0 37eb 629a 629c
:3 0 37ee 6296 629e
6293 62a0 629f :2 0
de :3 0 ef :3 0
62a2 62a3 0 e0
:4 0 3d0 :4 0 e3
:2 0 e4 :3 0 37f2
62a7 62a9 :3 0 e3
:2 0 103 :4 0 37f5
62ab 62ad :3 0 e3
:2 0 10b :4 0 37f8
62af 62b1 :3 0 e3
:2 0 e8 :3 0 e9
:3 0 78 :3 0 37fb
62b5 62b7 ea :4 0
37fd 62b4 62ba 3800
62b3 62bc :3 0 e3
:2 0 10d :4 0 3803
62be 62c0 :3 0 e3
:2 0 e6 :4 0 3806
62c2 62c4 :3 0 e3
:2 0 2b :3 0 3809
62c6 62c8 :3 0 e3
:2 0 e6 :4 0 380c
62ca 62cc :3 0 380f
62a4 62ce :2 0 62d0
3812 62d1 62a1 62d0
0 62d2 3814 0
62fe db :3 0 dc
:3 0 62d3 62d4 0
db :3 0 ec :3 0
62d6 62d7 0 33
:2 0 2 :4 0 3d1
:2 0 ee :2 0 33
:2 0 3816 62dc 62de
:3 0 3819 62d8 62e0
62d5 62e2 62e1 :2 0
de :3 0 ef :3 0
62e4 62e5 0 e0
:4 0 3d2 :4 0 e3
:2 0 e4 :3 0 381d
62e9 62eb :3 0 3820
62e6 62ed :2 0 62ef
3823 62f0 62e3 62ef
0 62f1 3825 0
62fe 110 :3 0 111
:3 0 62f2 62f3 0
e8 :3 0 78 :3 0
48 :2 0 3827 62f5
62f8 2b :3 0 112
:3 0 382a 62f4 62fc
:2 0 62fe 382e 62ff
6290 62fe 0 6301
6229 6287 0 6301
3832 0 655c 2ca
:3 0 2cb :3 0 3d3
:4 0 6304 :4 0 6305
:2 0 655c 15 :3 0
fa :3 0 6307 6308
0 48 :2 0 6309
630a 0 655c 3d4
:3 0 1f1 :3 0 23d
:3 0 1f0 :3 0 1db
:3 0 a9 :3 0 2b
:3 0 2e3 :3 0 26
:3 0 1f1 :4 0 3d5
1 :8 0 632c f9
:4 0 6317 :3 0 112
:3 0 f3 :2 0 3837
631a 631b :3 0 15
:3 0 fa :3 0 631d
631e 0 48 :2 0
631f 6320 0 6322
383a 6329 15 :3 0
fa :3 0 6323 6324
0 fb :2 0 6325
6326 0 6328 383c
632a 631c 6322 0
632b 0 6328 0
632b 383e 0 632c
3841 637f fe :3 0
15 :3 0 fa :3 0
632e 632f 0 fd
:3 0 6330 6331 0
6333 3844 6335 3846
6334 6333 :2 0 637d
ff :3 0 15 :3 0
fa :3 0 6338 6339
0 fd :3 0 633a
633b 0 6375 db
:3 0 dc :3 0 633d
633e 0 db :3 0
ec :3 0 6340 6341
0 100 :2 0 2
:4 0 3d6 :2 0 ee
:2 0 33 :2 0 3848
6346 6348 :3 0 384b
6342 634a 633f 634c
634b :2 0 de :3 0
ef :3 0 634e 634f
0 e0 :4 0 3d7
:4 0 e3 :2 0 e4
:3 0 384f 6353 6355
:3 0 e3 :2 0 103
:4 0 3852 6357 6359
:3 0 e3 :2 0 104
:4 0 3855 635b 635d
:3 0 e3 :2 0 fd
:3 0 3858 635f 6361
:3 0 e3 :2 0 105
:4 0 385b 6363 6365
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 385e
6368 636c 3862 6367
636e :3 0 3865 6350
6370 :2 0 6372 3868
6373 634d 6372 0
6374 386a 0 6375
386c 6378 :3 0 6378
0 6378 6377 6375
6376 :6 0 637a 12c
:3 0 386f 637c 3871
637b 637a :2 0 637d
3873 :2 0 637f 0
637f 637e 632c 637d
:6 0 655c 1 :3 0
2f :3 0 f7 :4 0
6381 6382 0 655c
56 :3 0 48 :2 0
6384 6385 0 655c
5d :3 0 48 :2 0
6387 6388 0 655c
4c :3 0 48 :2 0
638a 638b 0 655c
4d :3 0 33 :2 0
638d 638e 0 655c
e8 :3 0 50 :3 0
48 :2 0 3876 6390
6393 124 :2 0 48
:2 0 387b 6395 6397
:3 0 50 :3 0 20b
:3 0 1b2 :3 0 639a
639b 0 e8 :3 0
50 :3 0 48 :2 0
387e 639d 63a0 1a
:3 0 2ec :3 0 63a2
63a3 0 3881 639c
63a5 6399 63a6 0
63ab 5a :3 0 33
:2 0 63a8 63a9 0
63ab 3884 63b0 5a
:3 0 48 :2 0 63ac
63ad 0 63af 3887
63b1 6398 63ab 0
63b2 0 63af 0
63b2 3889 0 655c
77 :3 0 22b :2 0
63b3 63b4 0 655c
96 :3 0 22c :3 0
23 :3 0 2b :3 0
2b :3 0 2a :3 0
77 :3 0 4d :3 0
34 :3 0 34 :3 0
34 :3 0 34 :3 0
2d :3 0 2f :3 0
55 :3 0 4b :3 0
50 :3 0 52 :3 0
53 :3 0 4c :3 0
5e :3 0 39 :3 0
56 :3 0 5a :3 0
54 :3 0 51 :3 0
5d :3 0 5b :3 0
5f :3 0 21 :3 0
48 :2 0 48 :2 0
22b :2 0 22b :2 0
48 :2 0 48 :2 0
388c 63b7 63da 63b6
63db 0 655c 96
:3 0 f3 :2 0 22f
:2 0 38b1 63de 63e0
:3 0 db :3 0 dc
:3 0 63e2 63e3 0
db :3 0 ec :3 0
63e5 63e6 0 1e
:2 0 2 :4 0 3d8
:2 0 ee :2 0 33
:2 0 38b4 63eb 63ed
:3 0 38b7 63e7 63ef
63e4 63f1 63f0 :2 0
de :3 0 ef :3 0
63f3 63f4 0 e0
:4 0 3d9 :4 0 e3
:2 0 e4 :3 0 38bb
63f8 63fa :3 0 e3
:2 0 103 :4 0 38be
63fc 63fe :3 0 e3
:2 0 10b :4 0 38c1
6400 6402 :3 0 e3
:2 0 e8 :3 0 e9
:3 0 1a :3 0 232
:3 0 6407 6408 0
38c4 6406 640a ea
:4 0 38c6 6405 640d
38c9 6404 640f :3 0
e3 :2 0 10d :4 0
38cc 6411 6413 :3 0
e3 :2 0 e6 :4 0
38cf 6415 6417 :3 0
e3 :2 0 2a :3 0
38d2 6419 641b :3 0
e3 :2 0 e6 :4 0
38d5 641d 641f :3 0
38d8 63f5 6421 :2 0
6423 38db 6424 63f2
6423 0 6425 38dd
0 6450 db :3 0
dc :3 0 6426 6427
0 db :3 0 ec
:3 0 6429 642a 0
33 :2 0 2 :4 0
3da :2 0 ee :2 0
33 :2 0 38df 642f
6431 :3 0 38e2 642b
6433 6428 6435 6434
:2 0 de :3 0 ef
:3 0 6437 6438 0
e0 :4 0 3db :4 0
e3 :2 0 e4 :3 0
38e6 643c 643e :3 0
38e9 6439 6440 :2 0
6442 38ec 6443 6436
6442 0 6444 38ee
0 6450 110 :3 0
111 :3 0 6445 6446
0 1a :3 0 232
:3 0 6448 6449 0
2a :3 0 112 :3 0
38f0 6447 644d :2 0
6450 16a :3 0 38f4
6559 96 :3 0 15c
:2 0 48 :2 0 38fa
6452 6454 :3 0 db
:3 0 dc :3 0 6456
6457 0 db :3 0
ec :3 0 6459 645a
0 1e :2 0 2
:4 0 3dc :2 0 ee
:2 0 33 :2 0 38fd
645f 6461 :3 0 3900
645b 6463 6458 6465
6464 :2 0 de :3 0
ef :3 0 6467 6468
0 e0 :4 0 3dd
:4 0 e3 :2 0 e4
:3 0 3904 646c 646e
:3 0 e3 :2 0 103
:4 0 3907 6470 6472
:3 0 e3 :2 0 10b
:4 0 390a 6474 6476
:3 0 e3 :2 0 e8
:3 0 e9 :3 0 1a
:3 0 1d5 :3 0 647b
647c 0 390d 647a
647e ea :4 0 390f
6479 6481 3912 6478
6483 :3 0 e3 :2 0
10d :4 0 3915 6485
6487 :3 0 e3 :2 0
e6 :4 0 3918 6489
648b :3 0 e3 :2 0
23 :3 0 391b 648d
648f :3 0 e3 :2 0
e6 :4 0 391e 6491
6493 :3 0 3921 6469
6495 :2 0 6497 3924
6498 6466 6497 0
6499 3926 0 64c3
db :3 0 dc :3 0
649a 649b 0 db
:3 0 ec :3 0 649d
649e 0 33 :2 0
2 :4 0 3de :2 0
ee :2 0 33 :2 0
3928 64a3 64a5 :3 0
392b 649f 64a7 649c
64a9 64a8 :2 0 de
:3 0 ef :3 0 64ab
64ac 0 e0 :4 0
3df :4 0 e3 :2 0
e4 :3 0 392f 64b0
64b2 :3 0 3932 64ad
64b4 :2 0 64b6 3935
64b7 64aa 64b6 0
64b8 3937 0 64c3
110 :3 0 111 :3 0
64b9 64ba 0 1a
:3 0 1d5 :3 0 64bc
64bd 0 23 :3 0
112 :3 0 3939 64bb
64c1 :2 0 64c3 393d
64c4 6455 64c3 0
655b a8 :3 0 b0
:3 0 23 :3 0 aa
:3 0 2a :3 0 ab
:3 0 be :3 0 6d
:3 0 65 :3 0 6a
:3 0 be :3 0 bf
:3 0 6d :3 0 68
:3 0 6a :3 0 bf
:3 0 c0 :3 0 6e
:3 0 67 :3 0 6a
:3 0 c0 :3 0 c1
:3 0 6e :3 0 69
:3 0 6a :3 0 c1
:3 0 25a :3 0 1b1
:3 0 1b2 :3 0 25a
:3 0 1a :3 0 25b
:3 0 258 :3 0 1b1
:3 0 1b2 :3 0 258
:3 0 1a :3 0 259
:3 0 b2 :3 0 26
:4 0 3e0 1 :8 0
6503 f9 :4 0 64ee
:3 0 112 :3 0 f3
:2 0 3943 64f1 64f2
:3 0 15 :3 0 fa
:3 0 64f4 64f5 0
48 :2 0 64f6 64f7
0 64f9 3946 6500
15 :3 0 fa :3 0
64fa 64fb 0 fb
:2 0 64fc 64fd 0
64ff 3948 6501 64f3
64f9 0 6502 0
64ff 0 6502 394a
0 6503 394d 6556
fe :3 0 15 :3 0
fa :3 0 6505 6506
0 fd :3 0 6507
6508 0 650a 3950
650c 3952 650b 650a
:2 0 6554 ff :3 0
15 :3 0 fa :3 0
650f 6510 0 fd
:3 0 6511 6512 0
654c db :3 0 dc
:3 0 6514 6515 0
db :3 0 ec :3 0
6517 6518 0 100
:2 0 2 :4 0 3e1
:2 0 ee :2 0 33
:2 0 3954 651d 651f
:3 0 3957 6519 6521
6516 6523 6522 :2 0
de :3 0 ef :3 0
6525 6526 0 e0
:4 0 3e2 :4 0 e3
:2 0 e4 :3 0 395b
652a 652c :3 0 e3
:2 0 103 :4 0 395e
652e 6530 :3 0 e3
:2 0 104 :4 0 3961
6532 6534 :3 0 e3
:2 0 fd :3 0 3964
6536 6538 :3 0 e3
:2 0 105 :4 0 3967
653a 653c :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 396a 653f 6543
396e 653e 6545 :3 0
3971 6527 6547 :2 0
6549 3974 654a 6524
6549 0 654b 3976
0 654c 3978 654f
:3 0 654f 0 654f
654e 654c 654d :6 0
6551 12e :3 0 397b
6553 397d 6552 6551
:2 0 6554 397f :2 0
6556 0 6556 6555
6503 6554 :6 0 6558
1 :3 0 3982 655a
63e1 6450 0 655b
0 6558 0 655b
3984 0 655c 3988
655d 61a5 655c 0
655e 39a0 0 6560
16a :3 0 39a2 65e5
e8 :3 0 58 :3 0
48 :2 0 39a5 6561
6564 124 :2 0 48
:2 0 39aa 6566 6568
:3 0 26 :3 0 1ce
:2 0 39ad 656b 656c
:3 0 656d :2 0 6569
656f 656e :2 0 1db
:3 0 2e3 :3 0 26
:3 0 a9 :3 0 2b
:3 0 b2 :3 0 24
:4 0 3e3 1 :8 0
658e f9 :4 0 6579
:3 0 112 :3 0 f3
:2 0 39b1 657c 657d
:3 0 15 :3 0 fa
:3 0 657f 6580 0
48 :2 0 6581 6582
0 6584 39b4 658b
15 :3 0 fa :3 0
6585 6586 0 fb
:2 0 6587 6588 0
658a 39b6 658c 657e
6584 0 658d 0
658a 0 658d 39b8
0 658e 39bb 65e1
fe :3 0 15 :3 0
fa :3 0 6590 6591
0 fd :3 0 6592
6593 0 6595 39be
6597 39c0 6596 6595
:2 0 65df ff :3 0
15 :3 0 fa :3 0
659a 659b 0 fd
:3 0 659c 659d 0
65d7 db :3 0 dc
:3 0 659f 65a0 0
db :3 0 ec :3 0
65a2 65a3 0 100
:2 0 2 :4 0 3e4
:2 0 ee :2 0 33
:2 0 39c2 65a8 65aa
:3 0 39c5 65a4 65ac
65a1 65ae 65ad :2 0
de :3 0 ef :3 0
65b0 65b1 0 e0
:4 0 3e5 :4 0 e3
:2 0 e4 :3 0 39c9
65b5 65b7 :3 0 e3
:2 0 103 :4 0 39cc
65b9 65bb :3 0 e3
:2 0 104 :4 0 39cf
65bd 65bf :3 0 e3
:2 0 fd :3 0 39d2
65c1 65c3 :3 0 e3
:2 0 105 :4 0 39d5
65c5 65c7 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 39d8 65ca 65ce
39dc 65c9 65d0 :3 0
39df 65b2 65d2 :2 0
65d4 39e2 65d5 65af
65d4 0 65d6 39e4
0 65d7 39e6 65da
:3 0 65da 0 65da
65d9 65d7 65d8 :6 0
65dc 130 :3 0 39e9
65de 39eb 65dd 65dc
:2 0 65df 39ed :2 0
65e1 0 65e1 65e0
658e 65df :6 0 65e3
1 :3 0 39f0 65e4
6570 65e3 0 65e6
6178 6560 0 65e6
39f2 0 66ca 154
:3 0 62 :3 0 c8
:3 0 a4 :3 0 2b
:3 0 aa :3 0 2c
:3 0 ab :4 0 3e6
1 :8 0 65f5 15
:3 0 fa :3 0 65f0
65f1 0 fd :3 0
65f2 65f3 0 65f5
39f5 6648 fe :3 0
15 :3 0 fa :3 0
65f7 65f8 0 fd
:3 0 65f9 65fa 0
65fc 39f8 65fe 39fa
65fd 65fc :2 0 6646
ff :3 0 15 :3 0
fa :3 0 6601 6602
0 fd :3 0 6603
6604 0 663e db
:3 0 dc :3 0 6606
6607 0 db :3 0
ec :3 0 6609 660a
0 100 :2 0 2
:4 0 3e7 :2 0 ee
:2 0 33 :2 0 39fc
660f 6611 :3 0 39ff
660b 6613 6608 6615
6614 :2 0 de :3 0
ef :3 0 6617 6618
0 e0 :4 0 3e8
:4 0 e3 :2 0 e4
:3 0 3a03 661c 661e
:3 0 e3 :2 0 103
:4 0 3a06 6620 6622
:3 0 e3 :2 0 104
:4 0 3a09 6624 6626
:3 0 e3 :2 0 fd
:3 0 3a0c 6628 662a
:3 0 e3 :2 0 105
:4 0 3a0f 662c 662e
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 3a12
6631 6635 3a16 6630
6637 :3 0 3a19 6619
6639 :2 0 663b 3a1c
663c 6616 663b 0
663d 3a1e 0 663e
3a20 6641 :3 0 6641
0 6641 6640 663e
663f :6 0 6643 132
:3 0 3a23 6645 3a25
6644 6643 :2 0 6646
3a27 :2 0 6648 0
6648 6647 65f5 6646
:6 0 66ca 1 :3 0
e8 :3 0 62 :3 0
48 :2 0 3a2a 664a
664d f3 :2 0 48
:2 0 3a2f 664f 6651
:3 0 c7 :3 0 198
:3 0 199 :3 0 198
:3 0 44 :3 0 a9
:3 0 2b :3 0 a4
:3 0 2b :4 0 3e9
1 :8 0 6672 f9
:4 0 665d :3 0 112
:3 0 f3 :2 0 3a34
6660 6661 :3 0 15
:3 0 fa :3 0 6663
6664 0 48 :2 0
6665 6666 0 6668
3a37 666f 15 :3 0
fa :3 0 6669 666a
0 fb :2 0 666b
666c 0 666e 3a39
6670 6662 6668 0
6671 0 666e 0
6671 3a3b 0 6672
3a3e 66c5 fe :3 0
15 :3 0 fa :3 0
6674 6675 0 fd
:3 0 6676 6677 0
6679 3a41 667b 3a43
667a 6679 :2 0 66c3
ff :3 0 15 :3 0
fa :3 0 667e 667f
0 fd :3 0 6680
6681 0 66bb db
:3 0 dc :3 0 6683
6684 0 db :3 0
ec :3 0 6686 6687
0 100 :2 0 2
:4 0 3ea :2 0 ee
:2 0 33 :2 0 3a45
668c 668e :3 0 3a48
6688 6690 6685 6692
6691 :2 0 de :3 0
ef :3 0 6694 6695
0 e0 :4 0 3eb
:4 0 e3 :2 0 e4
:3 0 3a4c 6699 669b
:3 0 e3 :2 0 103
:4 0 3a4f 669d 669f
:3 0 e3 :2 0 104
:4 0 3a52 66a1 66a3
:3 0 e3 :2 0 fd
:3 0 3a55 66a5 66a7
:3 0 e3 :2 0 105
:4 0 3a58 66a9 66ab
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 3a5b
66ae 66b2 3a5f 66ad
66b4 :3 0 3a62 6696
66b6 :2 0 66b8 3a65
66b9 6693 66b8 0
66ba 3a67 0 66bb
3a69 66be :3 0 66be
0 66be 66bd 66bb
66bc :6 0 66c0 134
:3 0 3a6c 66c2 3a6e
66c1 66c0 :2 0 66c3
3a70 :2 0 66c5 0
66c5 66c4 6672 66c3
:6 0 66c7 1 :3 0
3a73 66c8 6652 66c7
0 66c9 3a75 0
66ca 3a77 66cb 6168
66ca 0 66cc 3a7c
0 6d23 6f :3 0
48 :2 0 66cd 66ce
0 6d23 8e :3 0
1ce :2 0 3a7e 66d1
66d2 :3 0 66d3 :2 0
c7 :3 0 258 :3 0
1b1 :3 0 1b2 :3 0
258 :3 0 1a :3 0
259 :3 0 25a :3 0
1b1 :3 0 1b2 :3 0
25a :3 0 1a :3 0
25b :3 0 a4 :3 0
2b :4 0 3ec 1
:8 0 66fa f9 :4 0
66e5 :3 0 112 :3 0
f3 :2 0 3a82 66e8
66e9 :3 0 15 :3 0
fa :3 0 66eb 66ec
0 48 :2 0 66ed
66ee 0 66f0 3a85
66f7 15 :3 0 fa
:3 0 66f1 66f2 0
fb :2 0 66f3 66f4
0 66f6 3a87 66f8
66ea 66f0 0 66f9
0 66f6 0 66f9
3a89 0 66fa 3a8c
674d fe :3 0 15
:3 0 fa :3 0 66fc
66fd 0 fd :3 0
66fe 66ff 0 6701
3a8f 6703 3a91 6702
6701 :2 0 674b ff
:3 0 15 :3 0 fa
:3 0 6706 6707 0
fd :3 0 6708 6709
0 6743 db :3 0
dc :3 0 670b 670c
0 db :3 0 ec
:3 0 670e 670f 0
100 :2 0 2 :4 0
3ed :2 0 ee :2 0
33 :2 0 3a93 6714
6716 :3 0 3a96 6710
6718 670d 671a 6719
:2 0 de :3 0 ef
:3 0 671c 671d 0
e0 :4 0 3ee :4 0
e3 :2 0 e4 :3 0
3a9a 6721 6723 :3 0
e3 :2 0 103 :4 0
3a9d 6725 6727 :3 0
e3 :2 0 104 :4 0
3aa0 6729 672b :3 0
e3 :2 0 fd :3 0
3aa3 672d 672f :3 0
e3 :2 0 105 :4 0
3aa6 6731 6733 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 3aa9 6736
673a 3aad 6735 673c
:3 0 3ab0 671e 673e
:2 0 6740 3ab3 6741
671b 6740 0 6742
3ab5 0 6743 3ab7
6746 :3 0 6746 0
6746 6745 6743 6744
:6 0 6748 136 :3 0
3aba 674a 3abc 6749
6748 :2 0 674b 3abe
:2 0 674d 0 674d
674c 66fa 674b :6 0
6a7d 1 :3 0 e8
:3 0 58 :3 0 48
:2 0 3ac1 674f 6752
f3 :2 0 48 :2 0
3ac6 6754 6756 :3 0
154 :3 0 62 :3 0
a8 :3 0 a9 :3 0
2b :3 0 ac :3 0
8e :4 0 3ef 1
:8 0 6765 15 :3 0
fa :3 0 6760 6761
0 fd :3 0 6762
6763 0 6765 3ac9
67b8 fe :3 0 15
:3 0 fa :3 0 6767
6768 0 fd :3 0
6769 676a 0 676c
3acc 676e 3ace 676d
676c :2 0 67b6 ff
:3 0 15 :3 0 fa
:3 0 6771 6772 0
fd :3 0 6773 6774
0 67ae db :3 0
dc :3 0 6776 6777
0 db :3 0 ec
:3 0 6779 677a 0
100 :2 0 2 :4 0
3f0 :2 0 ee :2 0
33 :2 0 3ad0 677f
6781 :3 0 3ad3 677b
6783 6778 6785 6784
:2 0 de :3 0 ef
:3 0 6787 6788 0
e0 :4 0 3f1 :4 0
e3 :2 0 e4 :3 0
3ad7 678c 678e :3 0
e3 :2 0 103 :4 0
3ada 6790 6792 :3 0
e3 :2 0 104 :4 0
3add 6794 6796 :3 0
e3 :2 0 fd :3 0
3ae0 6798 679a :3 0
e3 :2 0 105 :4 0
3ae3 679c 679e :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 3ae6 67a1
67a5 3aea 67a0 67a7
:3 0 3aed 6789 67a9
:2 0 67ab 3af0 67ac
6786 67ab 0 67ad
3af2 0 67ae 3af4
67b1 :3 0 67b1 0
67b1 67b0 67ae 67af
:6 0 67b3 138 :3 0
3af7 67b5 3af9 67b4
67b3 :2 0 67b6 3afb
:2 0 67b8 0 67b8
67b7 6765 67b6 :6 0
68a9 1 :3 0 e8
:3 0 62 :3 0 48
:2 0 3afe 67ba 67bd
f3 :2 0 48 :2 0
3b03 67bf 67c1 :3 0
c8 :3 0 a9 :3 0
2b :3 0 a4 :3 0
2b :3 0 aa :3 0
2c :3 0 ab :4 0
3f2 1 :8 0 67e1
f9 :4 0 67cc :3 0
112 :3 0 f3 :2 0
3b08 67cf 67d0 :3 0
15 :3 0 fa :3 0
67d2 67d3 0 48
:2 0 67d4 67d5 0
67d7 3b0b 67de 15
:3 0 fa :3 0 67d8
67d9 0 fb :2 0
67da 67db 0 67dd
3b0d 67df 67d1 67d7
0 67e0 0 67dd
0 67e0 3b0f 0
67e1 3b12 6834 fe
:3 0 15 :3 0 fa
:3 0 67e3 67e4 0
fd :3 0 67e5 67e6
0 67e8 3b15 67ea
3b17 67e9 67e8 :2 0
6832 ff :3 0 15
:3 0 fa :3 0 67ed
67ee 0 fd :3 0
67ef 67f0 0 682a
db :3 0 dc :3 0
67f2 67f3 0 db
:3 0 ec :3 0 67f5
67f6 0 100 :2 0
2 :4 0 3f3 :2 0
ee :2 0 33 :2 0
3b19 67fb 67fd :3 0
3b1c 67f7 67ff 67f4
6801 6800 :2 0 de
:3 0 ef :3 0 6803
6804 0 e0 :4 0
3f4 :4 0 e3 :2 0
e4 :3 0 3b20 6808
680a :3 0 e3 :2 0
103 :4 0 3b23 680c
680e :3 0 e3 :2 0
104 :4 0 3b26 6810
6812 :3 0 e3 :2 0
fd :3 0 3b29 6814
6816 :3 0 e3 :2 0
105 :4 0 3b2c 6818
681a :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
3b2f 681d 6821 3b33
681c 6823 :3 0 3b36
6805 6825 :2 0 6827
3b39 6828 6802 6827
0 6829 3b3b 0
682a 3b3d 682d :3 0
682d 0 682d 682c
682a 682b :6 0 682f
13a :3 0 3b40 6831
3b42 6830 682f :2 0
6832 3b44 :2 0 6834
0 6834 6833 67e1
6832 :6 0 68a6 1
:3 0 21d :3 0 a9
:3 0 2b :3 0 aa
:3 0 2c :4 0 3f5
1 :8 0 6851 f9
:4 0 683c :3 0 112
:3 0 f3 :2 0 3b49
683f 6840 :3 0 15
:3 0 fa :3 0 6842
6843 0 48 :2 0
6844 6845 0 6847
3b4c 684e 15 :3 0
fa :3 0 6848 6849
0 fb :2 0 684a
684b 0 684d 3b4e
684f 6841 6847 0
6850 0 684d 0
6850 3b50 0 6851
3b53 68a4 fe :3 0
15 :3 0 fa :3 0
6853 6854 0 fd
:3 0 6855 6856 0
6858 3b56 685a 3b58
6859 6858 :2 0 68a2
ff :3 0 15 :3 0
fa :3 0 685d 685e
0 fd :3 0 685f
6860 0 689a db
:3 0 dc :3 0 6862
6863 0 db :3 0
ec :3 0 6865 6866
0 100 :2 0 2
:4 0 3f6 :2 0 ee
:2 0 33 :2 0 3b5a
686b 686d :3 0 3b5d
6867 686f 6864 6871
6870 :2 0 de :3 0
ef :3 0 6873 6874
0 e0 :4 0 3f7
:4 0 e3 :2 0 e4
:3 0 3b61 6878 687a
:3 0 e3 :2 0 103
:4 0 3b64 687c 687e
:3 0 e3 :2 0 104
:4 0 3b67 6880 6882
:3 0 e3 :2 0 fd
:3 0 3b6a 6884 6886
:3 0 e3 :2 0 105
:4 0 3b6d 6888 688a
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 3b70
688d 6891 3b74 688c
6893 :3 0 3b77 6875
6895 :2 0 6897 3b7a
6898 6872 6897 0
6899 3b7c 0 689a
3b7e 689d :3 0 689d
0 689d 689c 689a
689b :6 0 689f 13c
:3 0 3b81 68a1 3b83
68a0 689f :2 0 68a2
3b85 :2 0 68a4 0
68a4 68a3 6851 68a2
:6 0 68a6 1 :3 0
3b88 68a7 67c2 68a6
0 68a8 3b8b 0
68a9 3b8d 68aa 6757
68a9 0 68ab 3b90
0 6a7d 78 :3 0
24b :2 0 68ac 68ad
0 6a7d 7e :3 0
24c :3 0 2b :3 0
8e :3 0 78 :3 0
48 :2 0 48 :2 0
48 :2 0 3b92 68b0
68b7 68af 68b8 0
6a7d b7 :3 0 b8
:3 0 26b :3 0 1cf
:3 0 106 :3 0 273
:3 0 1cf :3 0 106
:3 0 274 :3 0 bc
:3 0 bd :3 0 be
:3 0 c0 :3 0 3c
:3 0 3d :3 0 4b
:3 0 37 :3 0 38
:3 0 85 :3 0 86
:3 0 7f :3 0 81
:3 0 a8 :3 0 b2
:3 0 8e :4 0 3f8
1 :8 0 68d9 15
:3 0 fa :3 0 68d4
68d5 0 fd :3 0
68d6 68d7 0 68d9
3b99 692c fe :3 0
15 :3 0 fa :3 0
68db 68dc 0 fd
:3 0 68dd 68de 0
68e0 3b9c 68e2 3b9e
68e1 68e0 :2 0 692a
ff :3 0 15 :3 0
fa :3 0 68e5 68e6
0 fd :3 0 68e7
68e8 0 6922 db
:3 0 dc :3 0 68ea
68eb 0 db :3 0
ec :3 0 68ed 68ee
0 100 :2 0 2
:4 0 3f9 :2 0 ee
:2 0 33 :2 0 3ba0
68f3 68f5 :3 0 3ba3
68ef 68f7 68ec 68f9
68f8 :2 0 de :3 0
ef :3 0 68fb 68fc
0 e0 :4 0 3fa
:4 0 e3 :2 0 e4
:3 0 3ba7 6900 6902
:3 0 e3 :2 0 103
:4 0 3baa 6904 6906
:3 0 e3 :2 0 104
:4 0 3bad 6908 690a
:3 0 e3 :2 0 fd
:3 0 3bb0 690c 690e
:3 0 e3 :2 0 105
:4 0 3bb3 6910 6912
:3 0 e3 :2 0 106
:3 0 107 :3 0 33
:2 0 108 :2 0 3bb6
6915 6919 3bba 6914
691b :3 0 3bbd 68fd
691d :2 0 691f 3bc0
6920 68fa 691f 0
6921 3bc2 0 6922
3bc4 6925 :3 0 6925
0 6925 6924 6922
6923 :6 0 6927 13e
:3 0 3bc7 6929 3bc9
6928 6927 :2 0 692a
3bcb :2 0 692c 0
692c 692b 68d9 692a
:6 0 6a7d 1 :3 0
15 :3 0 fa :3 0
692e 692f 0 15
:3 0 f3 :2 0 173
:3 0 6931 6933 0
3bd0 6932 6935 :3 0
6936 :2 0 3c :3 0
239 :2 0 3bd3 6939
693a :3 0 693b :2 0
4b :3 0 48 :2 0
693d 693e 0 6940
3bd5 6941 693c 6940
0 6942 3bd7 0
6a60 e8 :3 0 85
:3 0 48 :2 0 3bd9
6943 6946 f3 :2 0
48 :2 0 3bde 6948
694a :3 0 21d :3 0
21f :3 0 3c :3 0
221 :3 0 3d :3 0
223 :3 0 4b :3 0
225 :3 0 4b :3 0
7f :3 0 227 :3 0
a9 :3 0 2b :3 0
aa :3 0 2c :4 0
3fb 1 :8 0 6971
f9 :4 0 695c :3 0
112 :3 0 f3 :2 0
3be3 695f 6960 :3 0
15 :3 0 fa :3 0
6962 6963 0 48
:2 0 6964 6965 0
6967 3be6 696e 15
:3 0 fa :3 0 6968
6969 0 fb :2 0
696a 696b 0 696d
3be8 696f 6961 6967
0 6970 0 696d
0 6970 3bea 0
6971 3bed 69c4 fe
:3 0 15 :3 0 fa
:3 0 6973 6974 0
fd :3 0 6975 6976
0 6978 3bf0 697a
3bf2 6979 6978 :2 0
69c2 ff :3 0 15
:3 0 fa :3 0 697d
697e 0 fd :3 0
697f 6980 0 69ba
db :3 0 dc :3 0
6982 6983 0 db
:3 0 ec :3 0 6985
6986 0 100 :2 0
2 :4 0 3fc :2 0
ee :2 0 33 :2 0
3bf4 698b 698d :3 0
3bf7 6987 698f 6984
6991 6990 :2 0 de
:3 0 ef :3 0 6993
6994 0 e0 :4 0
3fd :4 0 e3 :2 0
e4 :3 0 3bfb 6998
699a :3 0 e3 :2 0
103 :4 0 3bfe 699c
699e :3 0 e3 :2 0
104 :4 0 3c01 69a0
69a2 :3 0 e3 :2 0
fd :3 0 3c04 69a4
69a6 :3 0 e3 :2 0
105 :4 0 3c07 69a8
69aa :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
3c0a 69ad 69b1 3c0e
69ac 69b3 :3 0 3c11
6995 69b5 :2 0 69b7
3c14 69b8 6992 69b7
0 69b9 3c16 0
69ba 3c18 69bd :3 0
69bd 0 69bd 69bc
69ba 69bb :6 0 69bf
140 :3 0 3c1b 69c1
3c1d 69c0 69bf :2 0
69c2 3c1f :2 0 69c4
0 69c4 69c3 6971
69c2 :6 0 69c6 1
:3 0 3c22 6a44 21d
:3 0 21f :3 0 3c
:3 0 221 :3 0 3d
:3 0 223 :3 0 4b
:3 0 225 :3 0 4b
:3 0 7f :3 0 227
:3 0 4b :3 0 81
:3 0 a9 :3 0 2b
:3 0 aa :3 0 2c
:4 0 3fe 1 :8 0
69ee f9 :4 0 69d9
:3 0 112 :3 0 f3
:2 0 3c26 69dc 69dd
:3 0 15 :3 0 fa
:3 0 69df 69e0 0
48 :2 0 69e1 69e2
0 69e4 3c29 69eb
15 :3 0 fa :3 0
69e5 69e6 0 fb
:2 0 69e7 69e8 0
69ea 3c2b 69ec 69de
69e4 0 69ed 0
69ea 0 69ed 3c2d
0 69ee 3c30 6a41
fe :3 0 15 :3 0
fa :3 0 69f0 69f1
0 fd :3 0 69f2
69f3 0 69f5 3c33
69f7 3c35 69f6 69f5
:2 0 6a3f ff :3 0
15 :3 0 fa :3 0
69fa 69fb 0 fd
:3 0 69fc 69fd 0
6a37 db :3 0 dc
:3 0 69ff 6a00 0
db :3 0 ec :3 0
6a02 6a03 0 100
:2 0 2 :4 0 3ff
:2 0 ee :2 0 33
:2 0 3c37 6a08 6a0a
:3 0 3c3a 6a04 6a0c
6a01 6a0e 6a0d :2 0
de :3 0 ef :3 0
6a10 6a11 0 e0
:4 0 400 :4 0 e3
:2 0 e4 :3 0 3c3e
6a15 6a17 :3 0 e3
:2 0 103 :4 0 3c41
6a19 6a1b :3 0 e3
:2 0 104 :4 0 3c44
6a1d 6a1f :3 0 e3
:2 0 fd :3 0 3c47
6a21 6a23 :3 0 e3
:2 0 105 :4 0 3c4a
6a25 6a27 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 3c4d 6a2a 6a2e
3c51 6a29 6a30 :3 0
3c54 6a12 6a32 :2 0
6a34 3c57 6a35 6a0f
6a34 0 6a36 3c59
0 6a37 3c5b 6a3a
:3 0 6a3a 0 6a3a
6a39 6a37 6a38 :6 0
6a3c 142 :3 0 3c5e
6a3e 3c60 6a3d 6a3c
:2 0 6a3f 3c62 :2 0
6a41 0 6a41 6a40
69ee 6a3f :6 0 6a43
1 :3 0 3c65 6a45
694b 69c6 0 6a46
0 6a43 0 6a46
3c67 0 6a60 106
:3 0 7c :3 0 33
:2 0 33 :2 0 3c6a
6a47 6a4b f3 :2 0
1d8 :4 0 3c70 6a4d
6a4f :3 0 6a50 :2 0
15 :3 0 fa :3 0
6a52 6a53 0 1d9
:3 0 2b :3 0 2b
:3 0 8e :3 0 48
:2 0 3c73 6a55 6a5a
6a54 6a5b 0 6a5d
3c78 6a5e 6a51 6a5d
0 6a5f 3c7a 0
6a60 3c7c 6a61 6937
6a60 0 6a62 3c80
0 6a7d 26 :3 0
1ce :2 0 3c82 6a64
6a65 :3 0 6a66 :2 0
6a67 :2 0 130 :3 0
14d :3 0 6a69 6a6a
0 8e :3 0 26
:3 0 3c84 6a6b 6a6e
f3 :2 0 48 :2 0
3c89 6a70 6a72 :3 0
6a73 :2 0 6a68 6a75
6a74 :2 0 6f :3 0
33 :2 0 6a77 6a78
0 6a7a 3c8c 6a7b
6a76 6a7a 0 6a7c
3c8e 0 6a7d 3c90
6a7e 66d4 6a7d 0
6a7f 3c98 0 6d23
26 :3 0 1ce :2 0
3c9a 6a81 6a82 :3 0
6a83 :2 0 e8 :3 0
58 :3 0 48 :2 0
3c9c 6a85 6a88 15c
:2 0 48 :2 0 3ca1
6a8a 6a8c :3 0 6a84
6a8e 6a8d :2 0 78
:3 0 24b :2 0 6a90
6a91 0 6c3b 7e
:3 0 24c :3 0 2b
:3 0 26 :3 0 78
:3 0 48 :2 0 48
:2 0 48 :2 0 3ca4
6a94 6a9b 6a93 6a9c
0 6c3b b7 :3 0
b8 :3 0 26b :3 0
1cf :3 0 106 :3 0
273 :3 0 1cf :3 0
106 :3 0 274 :3 0
bc :3 0 bd :3 0
be :3 0 c0 :3 0
3c :3 0 3d :3 0
4b :3 0 37 :3 0
38 :3 0 85 :3 0
86 :3 0 65 :3 0
67 :3 0 a8 :3 0
b2 :3 0 26 :4 0
401 1 :8 0 6abd
15 :3 0 fa :3 0
6ab8 6ab9 0 fd
:3 0 6aba 6abb 0
6abd 3cab 6b10 fe
:3 0 15 :3 0 fa
:3 0 6abf 6ac0 0
fd :3 0 6ac1 6ac2
0 6ac4 3cae 6ac6
3cb0 6ac5 6ac4 :2 0
6b0e ff :3 0 15
:3 0 fa :3 0 6ac9
6aca 0 fd :3 0
6acb 6acc 0 6b06
db :3 0 dc :3 0
6ace 6acf 0 db
:3 0 ec :3 0 6ad1
6ad2 0 100 :2 0
2 :4 0 402 :2 0
ee :2 0 33 :2 0
3cb2 6ad7 6ad9 :3 0
3cb5 6ad3 6adb 6ad0
6add 6adc :2 0 de
:3 0 ef :3 0 6adf
6ae0 0 e0 :4 0
403 :4 0 e3 :2 0
e4 :3 0 3cb9 6ae4
6ae6 :3 0 e3 :2 0
103 :4 0 3cbc 6ae8
6aea :3 0 e3 :2 0
104 :4 0 3cbf 6aec
6aee :3 0 e3 :2 0
fd :3 0 3cc2 6af0
6af2 :3 0 e3 :2 0
105 :4 0 3cc5 6af4
6af6 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
3cc8 6af9 6afd 3ccc
6af8 6aff :3 0 3ccf
6ae1 6b01 :2 0 6b03
3cd2 6b04 6ade 6b03
0 6b05 3cd4 0
6b06 3cd6 6b09 :3 0
6b09 0 6b09 6b08
6b06 6b07 :6 0 6b0b
144 :3 0 3cd9 6b0d
3cdb 6b0c 6b0b :2 0
6b0e 3cdd :2 0 6b10
0 6b10 6b0f 6abd
6b0e :6 0 6c3b 1
:3 0 e8 :3 0 85
:3 0 48 :2 0 3ce0
6b12 6b15 f3 :2 0
48 :2 0 3ce5 6b17
6b19 :3 0 21d :3 0
21f :3 0 3c :3 0
221 :3 0 3d :3 0
223 :3 0 4b :3 0
225 :3 0 4b :3 0
65 :3 0 227 :3 0
a9 :3 0 2b :3 0
aa :3 0 2a :4 0
404 1 :8 0 6b40
f9 :4 0 6b2b :3 0
112 :3 0 f3 :2 0
3cea 6b2e 6b2f :3 0
15 :3 0 fa :3 0
6b31 6b32 0 48
:2 0 6b33 6b34 0
6b36 3ced 6b3d 15
:3 0 fa :3 0 6b37
6b38 0 fb :2 0
6b39 6b3a 0 6b3c
3cef 6b3e 6b30 6b36
0 6b3f 0 6b3c
0 6b3f 3cf1 0
6b40 3cf4 6b93 fe
:3 0 15 :3 0 fa
:3 0 6b42 6b43 0
fd :3 0 6b44 6b45
0 6b47 3cf7 6b49
3cf9 6b48 6b47 :2 0
6b91 ff :3 0 15
:3 0 fa :3 0 6b4c
6b4d 0 fd :3 0
6b4e 6b4f 0 6b89
db :3 0 dc :3 0
6b51 6b52 0 db
:3 0 ec :3 0 6b54
6b55 0 100 :2 0
2 :4 0 405 :2 0
ee :2 0 33 :2 0
3cfb 6b5a 6b5c :3 0
3cfe 6b56 6b5e 6b53
6b60 6b5f :2 0 de
:3 0 ef :3 0 6b62
6b63 0 e0 :4 0
406 :4 0 e3 :2 0
e4 :3 0 3d02 6b67
6b69 :3 0 e3 :2 0
103 :4 0 3d05 6b6b
6b6d :3 0 e3 :2 0
104 :4 0 3d08 6b6f
6b71 :3 0 e3 :2 0
fd :3 0 3d0b 6b73
6b75 :3 0 e3 :2 0
105 :4 0 3d0e 6b77
6b79 :3 0 e3 :2 0
106 :3 0 107 :3 0
33 :2 0 108 :2 0
3d11 6b7c 6b80 3d15
6b7b 6b82 :3 0 3d18
6b64 6b84 :2 0 6b86
3d1b 6b87 6b61 6b86
0 6b88 3d1d 0
6b89 3d1f 6b8c :3 0
6b8c 0 6b8c 6b8b
6b89 6b8a :6 0 6b8e
146 :3 0 3d22 6b90
3d24 6b8f 6b8e :2 0
6b91 3d26 :2 0 6b93
0 6b93 6b92 6b40
6b91 :6 0 6b95 1
:3 0 3d29 6c13 21d
:3 0 21f :3 0 3c
:3 0 221 :3 0 3d
:3 0 223 :3 0 4b
:3 0 225 :3 0 4b
:3 0 65 :3 0 227
:3 0 4b :3 0 67
:3 0 a9 :3 0 2b
:3 0 aa :3 0 2a
:4 0 407 1 :8 0
6bbd f9 :4 0 6ba8
:3 0 112 :3 0 f3
:2 0 3d2d 6bab 6bac
:3 0 15 :3 0 fa
:3 0 6bae 6baf 0
48 :2 0 6bb0 6bb1
0 6bb3 3d30 6bba
15 :3 0 fa :3 0
6bb4 6bb5 0 fb
:2 0 6bb6 6bb7 0
6bb9 3d32 6bbb 6bad
6bb3 0 6bbc 0
6bb9 0 6bbc 3d34
0 6bbd 3d37 6c10
fe :3 0 15 :3 0
fa :3 0 6bbf 6bc0
0 fd :3 0 6bc1
6bc2 0 6bc4 3d3a
6bc6 3d3c 6bc5 6bc4
:2 0 6c0e ff :3 0
15 :3 0 fa :3 0
6bc9 6bca 0 fd
:3 0 6bcb 6bcc 0
6c06 db :3 0 dc
:3 0 6bce 6bcf 0
db :3 0 ec :3 0
6bd1 6bd2 0 100
:2 0 2 :4 0 408
:2 0 ee :2 0 33
:2 0 3d3e 6bd7 6bd9
:3 0 3d41 6bd3 6bdb
6bd0 6bdd 6bdc :2 0
de :3 0 ef :3 0
6bdf 6be0 0 e0
:4 0 409 :4 0 e3
:2 0 e4 :3 0 3d45
6be4 6be6 :3 0 e3
:2 0 103 :4 0 3d48
6be8 6bea :3 0 e3
:2 0 104 :4 0 3d4b
6bec 6bee :3 0 e3
:2 0 fd :3 0 3d4e
6bf0 6bf2 :3 0 e3
:2 0 105 :4 0 3d51
6bf4 6bf6 :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 3d54 6bf9 6bfd
3d58 6bf8 6bff :3 0
3d5b 6be1 6c01 :2 0
6c03 3d5e 6c04 6bde
6c03 0 6c05 3d60
0 6c06 3d62 6c09
:3 0 6c09 0 6c09
6c08 6c06 6c07 :6 0
6c0b 148 :3 0 3d65
6c0d 3d67 6c0c 6c0b
:2 0 6c0e 3d69 :2 0
6c10 0 6c10 6c0f
6bbd 6c0e :6 0 6c12
1 :3 0 3d6c 6c14
6b1a 6b95 0 6c15
0 6c12 0 6c15
3d6e 0 6c3b 106
:3 0 7c :3 0 33
:2 0 33 :2 0 3d71
6c16 6c1a f3 :2 0
1d8 :4 0 3d77 6c1c
6c1e :3 0 6c1f :2 0
e8 :3 0 6f :3 0
48 :2 0 3d7a 6c21
6c24 f3 :2 0 48
:2 0 3d7f 6c26 6c28
:3 0 6c29 :2 0 6c20
6c2b 6c2a :2 0 15
:3 0 fa :3 0 6c2d
6c2e 0 1d9 :3 0
2b :3 0 2b :3 0
26 :3 0 48 :2 0
3d82 6c30 6c35 6c2f
6c36 0 6c38 3d87
6c39 6c2c 6c38 0
6c3a 3d89 0 6c3b
3d8b 6c3c 6a8f 6c3b
0 6c3d 3d91 0
6d23 7e :3 0 40a
:3 0 2b :3 0 3d93
6c3f 6c41 6c3e 6c42
0 6d23 99 :3 0
15c :2 0 48 :2 0
3d97 6c45 6c47 :3 0
21d :3 0 21e :3 0
21f :3 0 220 :3 0
221 :3 0 222 :3 0
223 :3 0 224 :3 0
225 :3 0 226 :3 0
227 :3 0 a9 :3 0
2b :3 0 aa :3 0
2c :4 0 40b 1
:8 0 6c6e f9 :4 0
6c59 :3 0 112 :3 0
f3 :2 0 3d9c 6c5c
6c5d :3 0 15 :3 0
fa :3 0 6c5f 6c60
0 48 :2 0 6c61
6c62 0 6c64 3d9f
6c6b 15 :3 0 fa
:3 0 6c65 6c66 0
fb :2 0 6c67 6c68
0 6c6a 3da1 6c6c
6c5e 6c64 0 6c6d
0 6c6a 0 6c6d
3da3 0 6c6e 3da6
6cc1 fe :3 0 15
:3 0 fa :3 0 6c70
6c71 0 fd :3 0
6c72 6c73 0 6c75
3da9 6c77 3dab 6c76
6c75 :2 0 6cbf ff
:3 0 15 :3 0 fa
:3 0 6c7a 6c7b 0
fd :3 0 6c7c 6c7d
0 6cb7 db :3 0
dc :3 0 6c7f 6c80
0 db :3 0 ec
:3 0 6c82 6c83 0
100 :2 0 2 :4 0
40c :2 0 ee :2 0
33 :2 0 3dad 6c88
6c8a :3 0 3db0 6c84
6c8c 6c81 6c8e 6c8d
:2 0 de :3 0 ef
:3 0 6c90 6c91 0
e0 :4 0 40d :4 0
e3 :2 0 e4 :3 0
3db4 6c95 6c97 :3 0
e3 :2 0 103 :4 0
3db7 6c99 6c9b :3 0
e3 :2 0 104 :4 0
3dba 6c9d 6c9f :3 0
e3 :2 0 fd :3 0
3dbd 6ca1 6ca3 :3 0
e3 :2 0 105 :4 0
3dc0 6ca5 6ca7 :3 0
e3 :2 0 106 :3 0
107 :3 0 33 :2 0
108 :2 0 3dc3 6caa
6cae 3dc7 6ca9 6cb0
:3 0 3dca 6c92 6cb2
:2 0 6cb4 3dcd 6cb5
6c8f 6cb4 0 6cb6
3dcf 0 6cb7 3dd1
6cba :3 0 6cba 0
6cba 6cb9 6cb7 6cb8
:6 0 6cbc 14a :3 0
3dd4 6cbe 3dd6 6cbd
6cbc :2 0 6cbf 3dd8
:2 0 6cc1 0 6cc1
6cc0 6c6e 6cbf :6 0
6cc3 1 :3 0 3ddb
6cc4 6c48 6cc3 0
6cc5 3ddd 0 6d23
15 :3 0 fa :3 0
6cc6 6cc7 0 f3
:2 0 fb :2 0 3de1
6cc9 6ccb :3 0 15
:3 0 fa :3 0 6ccd
6cce 0 48 :2 0
6ccf 6cd0 0 6cd2
3de4 6cd3 6ccc 6cd2
0 6cd4 3de6 0
6d23 db :3 0 dc
:3 0 6cd5 6cd6 0
db :3 0 ec :3 0
6cd8 6cd9 0 f6
:2 0 2 :4 0 40e
:2 0 ee :2 0 33
:2 0 3de8 6cde 6ce0
:3 0 3deb 6cda 6ce2
6cd7 6ce4 6ce3 :2 0
de :3 0 ef :3 0
6ce6 6ce7 0 e0
:4 0 40f :4 0 e3
:2 0 e4 :3 0 3def
6ceb 6ced :3 0 e3
:2 0 103 :4 0 3df2
6cef 6cf1 :3 0 e3
:2 0 10b :4 0 3df5
6cf3 6cf5 :3 0 e3
:2 0 e8 :3 0 e9
:3 0 15 :3 0 fa
:3 0 6cfa 6cfb 0
3df8 6cf9 6cfd ea
:4 0 3dfa 6cf8 6d00
3dfd 6cf7 6d02 :3 0
e3 :2 0 10d :4 0
3e00 6d04 6d06 :3 0
e3 :2 0 e6 :4 0
3e03 6d08 6d0a :3 0
e3 :2 0 26 :3 0
3e06 6d0c 6d0e :3 0
e3 :2 0 e6 :4 0
3e09 6d10 6d12 :3 0
3e0c 6ce8 6d14 :2 0
6d16 3e0f 6d17 6ce5
6d16 0 6d18 3e11
0 6d23 110 :3 0
410 :3 0 6d19 6d1a
0 15 :3 0 fa
:3 0 6d1c 6d1d 0
26 :3 0 112 :3 0
3e13 6d1b 6d21 :2 0
6d23 3e17 6dc4 15
:3 0 411 :2 0 4
6d24 6d25 0 db
:3 0 dc :3 0 6d27
6d28 0 db :3 0
ec :3 0 6d2a 6d2b
0 100 :2 0 2
:4 0 412 :2 0 ee
:2 0 33 :2 0 3e74
6d30 6d32 :3 0 3e77
6d2c 6d34 6d29 6d36
6d35 :2 0 de :3 0
ef :3 0 6d38 6d39
0 e0 :4 0 413
:4 0 e3 :2 0 e4
:3 0 3e7b 6d3d 6d3f
:3 0 3e7e 6d3a 6d41
:2 0 6d5a de :3 0
ef :3 0 6d43 6d44
0 e0 :4 0 414
:4 0 e3 :2 0 15
:3 0 415 :3 0 6d49
6d4a 0 3e81 6d48
6d4c :3 0 e3 :2 0
10d :4 0 3e84 6d4e
6d50 :3 0 e3 :2 0
15 :3 0 416 :3 0
6d53 6d54 0 3e87
6d52 6d56 :3 0 3e8a
6d45 6d58 :2 0 6d5a
3e8d 6d5b 6d37 6d5a
0 6d5c 3e90 0
6d6c f8 :3 0 da
:3 0 15 :3 0 415
:3 0 417 :3 0 15
:3 0 416 :3 0 418
:3 0 15d :4 0 419
1 :a 0 6d68 :2 0
6d6c 6d5e 6d66 :2 0
14 :3 0 da :3 0
6d6a :2 0 6d6c 3e92
6d6e 3e96 6d6d 6d6c
:2 0 6dc2 ff :3 0
15 :3 0 fa :3 0
6d71 6d72 0 fd
:3 0 6d73 6d74 0
6dba db :3 0 dc
:3 0 6d76 6d77 0
db :3 0 ec :3 0
6d79 6d7a 0 100
:2 0 2 :4 0 41a
:2 0 ee :2 0 33
:2 0 3e98 6d7f 6d81
:3 0 3e9b 6d7b 6d83
6d78 6d85 6d84 :2 0
de :3 0 ef :3 0
6d87 6d88 0 e0
:4 0 41b :4 0 e3
:2 0 e4 :3 0 3e9f
6d8c 6d8e :3 0 3ea2
6d89 6d90 :2 0 6daa
de :3 0 ef :3 0
6d92 6d93 0 e0
:4 0 104 :4 0 e3
:2 0 fd :3 0 3ea5
6d97 6d99 :3 0 e3
:2 0 105 :4 0 3ea8
6d9b 6d9d :3 0 e3
:2 0 106 :3 0 107
:3 0 33 :2 0 108
:2 0 3eab 6da0 6da4
3eaf 6d9f 6da6 :3 0
3eb2 6d94 6da8 :2 0
6daa 3eb5 6dab 6d86
6daa 0 6dac 3eb8
0 6dba f8 :3 0
da :3 0 417 :3 0
15 :3 0 416 :3 0
418 :3 0 15d :4 0
41c 1 :a 0 6db6
:2 0 6dba 6dae 6db4
:2 0 14 :3 0 da
:3 0 6db8 :2 0 6dba
3eba 6dbd :3 0 6dbd
0 6dbd 6dbc 6dba
6dbb :6 0 6dbf 1
:3 0 3ebf 6dc1 3ec1
6dc0 6dbf :2 0 6dc2
3ec3 :2 0 6dc4 3ec6
6dc4 6dc3 6d23 6dc2
:6 0 6dc5 :2 0 2
44 6dc4 6dc8 :3 0
6dc7 6dc5 6dc9 :8 0

3f44
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 1
27 1 2b 1
2f 1 33 1
37 1 3b f
6 a e 12
16 1a 1e 22
26 2a 2e 32
36 3a 3e 1
48 1 46 1
52 1 50 1
5c 1 5a 1
63 1 61 1
6a 1 68 1
71 1 6f 1
78 1 76 1
7f 1 7d 1
86 1 84 1
8d 1 8b 1
94 1 92 1
9b 1 99 1
a2 1 a0 1
a9 1 a7 1
b0 1 ae 1
b7 1 b5 1
be 1 bc 1
c3 1 c8 1
cd 1 d2 1
d9 1 d7 1
e0 1 de 1
e5 1 ea 1
ef 1 f6 1
f4 1 fd 1
fb 1 102 1
107 1 10c 1
111 1 118 1
116 1 11f 1
11d 1 126 1
124 1 12d 1
12b 1 134 1
132 1 139 1
13f 1 145 1
14b 1 151 1
157 1 15d 1
163 1 169 1
16f 1 175 1
17b 1 181 1
187 1 18d 1
193 1 199 1
19f 1 1a5 1
1ab 1 1b1 1
1b7 1 1bd 1
1c3 1 1c9 1
1cf 1 1d5 1
1db 1 1e1 1
1e7 1 1ed 1
1f3 1 1f9 1
1ff 1 205 1
20b 1 211 1
217 1 21d 1
223 1 229 1
22f 1 235 1
23d 1 23b 1
244 1 242 1
249 1 24f 1
257 1 255 1
25c 1 264 1
262 1 26b 1
269 1 270 1
276 1 27c 1
282 1 288 1
28e 1 294 1
29a 1 2a0 1
2a6 1 2ac 1
2b2 1 2b8 1
2be 1 2c4 1
2cc 1 2ca 1
2d3 1 2d1 1
2da 1 2d8 1
2df 1 2e7 1
2e5 1 2ec 1
2f2 1 2f8 1
2fe 1 304 1
309 1 30e 1
314 1 31a 1
320 1 326 1
32c 1 331 1
341 1 355 1
3cd 1 3d3 1
3e0 1 3ec 2
3ef 3f1 2 3f4
3f6 2 3f8 3fa
2 3fc 3fe 2
400 402 2 404
406 2 408 40a
2 40c 40e 2
410 412 2 414
416 2 418 41a
2 41c 41e 2
420 422 2 424
426 2 428 42a
2 42c 42e 2
430 432 2 434
436 2 438 43a
2 43c 43e 2
440 442 1 448
2 44a 44b 2
444 44d 2 44f
451 1 457 2
459 45a 2 453
45c 2 45e 460
1 466 2 468
469 2 462 46b
2 46d 46f 1
475 2 477 478
2 471 47a 2
47c 47e 1 484
2 486 487 2
480 489 2 48b
48d 1 493 2
495 496 2 48f
498 2 49a 49c
1 4a2 2 4a4
4a5 2 49e 4a7
2 4a9 4ab 1
4b1 2 4b3 4b4
2 4ad 4b6 2
4b8 4ba 1 4c0
2 4c2 4c3 2
4bc 4c5 2 4c7
4c9 2 4cb 4cd
2 4cf 4d1 2
4d3 4d5 2 4d7
4d9 4 3e8 3ee
3f3 4db 1 4dd
1 4df 2 4e9
4eb 3 4e7 4e8
4ed 2 4f6 4f8
2 4f5 4fa 1
4fc 1 4fe 2
512 513 2 515
518 2 51d 51e
1 524 2 520
524 2 529 52a
1 530 2 52c
530 1 538 1
53a 1 558 1
55e 2 560 561
2 56a 570 1
577 1 572 2
58a 58c 3 588
589 58e 2 597
599 2 59b 59d
2 59f 5a1 2
5a3 5a5 2 5a7
5a9 3 5ae 5af
5b0 2 5ab 5b2
2 596 5b4 1
5b6 1 5b8 2
581 5b9 1 5bd
1 57c 2 57a
5c1 2 5c7 5c8
1 5cc 2 5ca
5cc 2 5d7 5d9
3 5d5 5d6 5db
2 5e4 5e6 2
5e8 5ea 2 5ec
5ee 1 5f6 2
5f8 5f9 2 5f0
5fb 2 5fd 5ff
2 601 603 2
605 607 2 609
60b 2 5e3 60d
1 60f 1 611
2 61b 61d 3
619 61a 61f 2
628 62a 2 627
62c 1 62e 1
630 3 637 638
639 3 612 631
63b 1 63d 2
64e 653 1 65a
1 655 2 66d
66f 3 66b 66c
671 2 67a 67c
2 67e 680 2
682 684 2 686
688 2 68a 68c
3 691 692 693
2 68e 695 2
679 697 1 699
1 69b 2 664
69c 1 6a0 1
65f 2 65d 6a4
1 6af 2 6ab
6af 2 6bb 6bd
3 6b9 6ba 6bf
2 6c8 6ca 2
6cc 6ce 2 6d0
6d2 1 6da 2
6dc 6dd 2 6d4
6df 2 6e1 6e3
2 6e5 6e7 2
6e9 6eb 2 6ed
6ef 2 6c7 6f1
1 6f3 1 6f5
2 6ff 701 3
6fd 6fe 703 2
70c 70e 2 70b
710 1 712 1
714 3 71b 71c
71d 3 6f6 715
71f 1 721 2
72b 730 1 737
1 732 2 74a
74c 3 748 749
74e 2 757 759
2 75b 75d 2
75f 761 2 763
765 2 767 769
3 76e 76f 770
2 76b 772 2
756 774 1 776
1 778 2 741
779 1 77d 1
73c 2 73a 781
2 787 788 1
78c 2 78a 78c
2 797 799 3
795 796 79b 2
7a4 7a6 2 7a8
7aa 2 7ac 7ae
1 7b6 2 7b8
7b9 2 7b0 7bb
2 7bd 7bf 2
7c1 7c3 2 7c5
7c7 2 7c9 7cb
2 7a3 7cd 1
7cf 1 7d1 2
7db 7dd 3 7d9
7da 7df 2 7e8
7ea 2 7e7 7ec
1 7ee 1 7f0
3 7f7 7f8 7f9
3 7d2 7f1 7fb
1 7fd 2 824
829 1 830 1
82b 2 843 845
3 841 842 847
2 850 852 2
854 856 2 858
85a 2 85c 85e
2 860 862 3
867 868 869 2
864 86b 2 84f
86d 1 86f 1
871 2 83a 872
1 876 1 835
2 833 87a 1
885 2 881 885
2 891 893 3
88f 890 895 2
89e 8a0 2 8a2
8a4 2 8a6 8a8
1 8b0 2 8b2
8b3 2 8aa 8b5
2 8b7 8b9 2
8bb 8bd 2 8bf
8c1 2 8c3 8c5
2 89d 8c7 1
8c9 1 8cb 2
8d5 8d7 3 8d3
8d4 8d9 2 8e2
8e4 2 8e1 8e6
1 8e8 1 8ea
3 8f1 8f2 8f3
3 8cc 8eb 8f5
1 8f7 2 900
905 1 90c 1
907 2 91f 921
3 91d 91e 923
2 92c 92e 2
930 932 2 934
936 2 938 93a
2 93c 93e 3
943 944 945 2
940 947 2 92b
949 1 94b 1
94d 2 916 94e
1 952 1 911
2 90f 956 1
961 2 95d 961
2 96d 96f 3
96b 96c 971 2
97a 97c 2 97e
980 2 982 984
1 98c 2 98e
98f 2 986 991
2 993 995 2
997 999 2 99b
99d 2 99f 9a1
2 979 9a3 1
9a5 1 9a7 2
9b1 9b3 3 9af
9b0 9b5 2 9be
9c0 2 9bd 9c2
1 9c4 1 9c6
3 9cd 9ce 9cf
3 9a8 9c7 9d1
1 9d3 2 9da
9df 1 9e6 1
9e1 2 9f9 9fb
3 9f7 9f8 9fd
2 a06 a08 2
a0a a0c 2 a0e
a10 2 a12 a14
2 a16 a18 3
a1d a1e a1f 2
a1a a21 2 a05
a23 1 a25 1
a27 2 9f0 a28
1 a2c 1 9eb
2 9e9 a30 2
a38 a39 1 a3d
2 a3b a3d 1
a42 1 a44 1
a4c 2 a48 a4c
2 a58 a5a 3
a56 a57 a5c 2
a65 a67 2 a69
a6b 2 a6d a6f
1 a77 2 a79
a7a 2 a71 a7c
2 a7e a80 2
a82 a84 2 a86
a88 2 a8a a8c
2 a64 a8e 1
a90 1 a92 2
a9c a9e 3 a9a
a9b aa0 2 aa9
aab 2 aa8 aad
1 aaf 1 ab1
3 ab8 ab9 aba
3 a93 ab2 abc
1 abe 2 ac6
ac7 2 ac9 aca
2 ad1 ad2 2
ad4 ad5 2 adc
add 2 adf ae0
2 af0 af5 1
afc 1 af7 2
b0f b11 3 b0d
b0e b13 2 b1c
b1e 2 b20 b22
2 b24 b26 2
b28 b2a 2 b2c
b2e 3 b33 b34
b35 2 b30 b37
2 b1b b39 1
b3b 1 b3d 2
b06 b3e 1 b42
1 b01 2 aff
b46 2 b56 b5b
1 b62 1 b5d
2 b75 b77 3
b73 b74 b79 2
b82 b84 2 b86
b88 2 b8a b8c
2 b8e b90 2
b92 b94 3 b99
b9a b9b 2 b96
b9d 2 b81 b9f
1 ba1 1 ba3
2 b6c ba4 1
ba8 1 b67 2
b65 bac 2 bb7
bb8 1 bba 1
bc1 2 bbf bc1
2 bc5 bc6 1
bca 2 bc8 bca
2 bd7 bdc 1
be3 1 bde 2
bf6 bf8 3 bf4
bf5 bfa 2 c03
c05 2 c07 c09
2 c0b c0d 2
c0f c11 2 c13
c15 3 c1a c1b
c1c 2 c17 c1e
2 c02 c20 1
c22 1 c24 2
bed c25 1 c29
1 be8 2 be6
c2d 2 c33 c34
1 c38 2 c36
c38 1 c3a 2
c4b c50 1 c57
1 c52 2 c6a
c6c 3 c68 c69
c6e 2 c77 c79
2 c7b c7d 2
c7f c81 2 c83
c85 2 c87 c89
3 c8e c8f c90
2 c8b c92 2
c76 c94 1 c96
1 c98 2 c61
c99 1 c9d 1
c5c 2 c5a ca1
2 ca7 ca8 1
cac 2 caa cac
2 cb7 cb9 3
cb5 cb6 cbb 2
cc4 cc6 2 cc8
cca 2 ccc cce
1 cd6 2 cd8
cd9 2 cd0 cdb
2 cdd cdf 2
ce1 ce3 2 ce5
ce7 2 ce9 ceb
2 cc3 ced 1
cef 1 cf1 2
cfb cfd 3 cf9
cfa cff 2 d08
d0a 2 d07 d0c
1 d0e 1 d10
3 d17 d18 d19
3 cf2 d11 d1b
1 d1d 3 c40
ca4 d1e 1 d20
2 c30 d21 1
d23 1 d24 2
d29 d2a 1 d2c
1 d30 2 d2e
d30 2 d34 d35
1 d39 2 d37
d39 2 d3d d3e
1 d42 2 d40
d42 2 d57 d5c
1 d63 1 d5e
2 d76 d78 3
d74 d75 d7a 2
d83 d85 2 d87
d89 2 d8b d8d
2 d8f d91 2
d93 d95 3 d9a
d9b d9c 2 d97
d9e 2 d82 da0
1 da2 1 da4
2 d6d da5 1
da9 1 d68 2
d66 dad 2 db3
db4 1 db8 2
db6 db8 2 dc3
dc5 3 dc1 dc2
dc7 2 dd0 dd2
2 dd4 dd6 2
dd8 dda 1 de2
2 de4 de5 2
ddc de7 2 de9
deb 2 ded def
2 df1 df3 2
df5 df7 2 dcf
df9 1 dfb 1
dfd 2 e07 e09
3 e05 e06 e0b
2 e14 e16 2
e13 e18 1 e1a
1 e1c 3 e23
e24 e25 3 dfe
e1d e27 1 e29
3 d4c db0 e2a
2 e2d e2c 1
e51 1 e57 2
e59 e5a 1 e62
2 e5e e62 2
e69 e6a 1 e6e
2 e6c e6e 1
e70 2 e75 e76
1 e7a 2 e78
e7a 1 e7c 2
e84 e8a 1 e91
1 e8c 2 ea4
ea6 3 ea2 ea3
ea8 2 eb1 eb3
2 eb5 eb7 2
eb9 ebb 2 ebd
ebf 2 ec1 ec3
3 ec8 ec9 eca
2 ec5 ecc 2
eb0 ece 1 ed0
1 ed2 2 e9b
ed3 1 ed7 1
e96 2 e94 edb
2 ee8 eea 3
ee6 ee7 eec 2
ef5 ef7 2 ef9
efb 2 efd eff
1 f07 2 f09
f0a 2 f01 f0c
2 f0e f10 2
f12 f14 2 f16
f18 2 f1a f1c
2 ef4 f1e 1
f20 1 f22 2
f2c f2e 3 f2a
f2b f30 2 f39
f3b 2 f38 f3d
1 f3f 1 f41
3 f48 f49 f4a
4 ede f23 f42
f4c 1 f4e 2
f4f f52 2 f56
f57 1 f5b 2
f59 f5b 1 f60
1 f65 3 f67
f62 f68 2 f6c
f72 1 f79 1
f74 2 f8c f8e
3 f8a f8b f90
2 f99 f9b 2
f9d f9f 2 fa1
fa3 2 fa5 fa7
2 fa9 fab 3
fb0 fb1 fb2 2
fad fb4 2 f98
fb6 1 fb8 1
fba 2 f83 fbb
1 fbf 1 f7e
2 f7c fc3 2
fcd fd2 1 fd9
1 fd4 2 fec
fee 3 fea feb
ff0 2 ff9 ffb
2 ffd fff 2
1001 1003 2 1005
1007 2 1009 100b
3 1010 1011 1012
2 100d 1014 2
ff8 1016 1 1018
1 101a 2 fe3
101b 1 101f 1
fde 2 fdc 1023
2 1033 1038 1
103f 1 103a 2
1052 1054 3 1050
1051 1056 2 105f
1061 2 1063 1065
2 1067 1069 2
106b 106d 2 106f
1071 3 1076 1077
1078 2 1073 107a
2 105e 107c 1
107e 1 1080 2
1049 1081 1 1085
1 1044 2 1042
1089 1 1094 2
1090 1094 2 1099
109a 1 109e 2
109c 109e 1 10a0
2 10b8 10bd 1
10c4 1 10bf 2
10d7 10d9 3 10d5
10d6 10db 2 10e4
10e6 2 10e8 10ea
2 10ec 10ee 2
10f0 10f2 2 10f4
10f6 3 10fb 10fc
10fd 2 10f8 10ff
2 10e3 1101 1
1103 1 1105 2
10ce 1106 1 110a
1 10c9 2 10c7
110e 1 1119 2
1115 1119 1 1121
2 1127 1128 4
1125 112a 112d 112e
2 1131 1136 2
1138 1139 7 1143
1144 1145 1146 1147
1148 1149 2 1150
1151 1 1153 1
1173 2 1172 1173
1 117b 1 1181
2 1183 1184 2
1170 1185 1 118c
1 1187 2 119f
11a1 3 119d 119e
11a3 2 11ac 11ae
2 11b0 11b2 2
11b4 11b6 2 11b8
11ba 2 11bc 11be
3 11c3 11c4 11c5
2 11c0 11c7 2
11ab 11c9 1 11cb
1 11cd 2 1196
11ce 1 11d2 1
1191 2 118f 11d6
2 11de 11df 1
11e3 2 11e1 11e3
1 11e5 1 11eb
2 11f9 11fe 1
1205 1 1200 2
1218 121a 3 1216
1217 121c 2 1225
1227 2 1229 122b
2 122d 122f 2
1231 1233 2 1235
1237 3 123c 123d
123e 2 1239 1240
2 1224 1242 1
1244 1 1246 2
120f 1247 1 124b
1 120a 2 1208
124f 1 1252 2
1255 1256 2 1259
125a 1 125e 2
125c 125e 1 1260
1 1271 2 1270
1271 1 1279 1
127f 2 1281 1282
2 126e 1283 1
128a 1 1285 2
129d 129f 3 129b
129c 12a1 2 12aa
12ac 2 12ae 12b0
2 12b2 12b4 2
12b6 12b8 2 12ba
12bc 3 12c1 12c2
12c3 2 12be 12c5
2 12a9 12c7 1
12c9 1 12cb 2
1294 12cc 1 12d0
1 128f 2 128d
12d4 1 12d7 1
12ee 2 12ed 12ee
1 12f6 1 12fc
2 12fe 12ff 2
12eb 1300 1 1307
1 1302 2 131a
131c 3 1318 1319
131e 2 1327 1329
2 132b 132d 2
132f 1331 2 1333
1335 2 1337 1339
3 133e 133f 1340
2 133b 1342 2
1326 1344 1 1346
1 1348 2 1311
1349 1 134d 1
130c 2 130a 1351
1 1354 2 1357
1358 b 10a8 10ad
1111 113a 113d 1140
114c 1156 11d9 1257
1359 1 1362 2
135e 1362 1 137a
2 1379 137a 1
1382 1 1388 2
138a 138b 2 1377
138c 1 1393 1
138e 2 13a6 13a8
3 13a4 13a5 13aa
2 13b3 13b5 2
13b7 13b9 2 13bb
13bd 2 13bf 13c1
2 13c3 13c5 3
13ca 13cb 13cc 2
13c7 13ce 2 13b2
13d0 1 13d2 1
13d4 2 139d 13d5
1 13d9 1 1398
2 1396 13dd 2
13eb 13f0 1 13f7
1 13f2 2 140a
140c 3 1408 1409
140e 2 1417 1419
2 141b 141d 2
141f 1421 2 1423
1425 2 1427 1429
3 142e 142f 1430
2 142b 1432 2
1416 1434 1 1436
1 1438 2 1401
1439 1 143d 1
13fc 2 13fa 1441
1 144c 2 1448
144c 2 1456 145b
1 1462 1 145d
2 1475 1477 3
1473 1474 1479 2
1482 1484 2 1486
1488 2 148a 148c
2 148e 1490 2
1492 1494 3 1499
149a 149b 2 1496
149d 2 1481 149f
1 14a1 1 14a3
2 146c 14a4 1
14a8 1 1467 2
1465 14ac 1 14b7
2 14b3 14b7 1
14bd 1 14bf 2
14af 14c0 1 14c2
2 14c5 14c6 1
14ca 2 14c8 14ca
1 14cc 2 14d1
14d2 1 14d8 2
14d4 14d8 2 14df
14e0 4 14dd 14e2
14e5 14e6 1 14f7
2 14f6 14f7 1
14ff 1 1505 2
1507 1508 2 14f4
1509 1 1510 1
150b 2 1523 1525
3 1521 1522 1527
2 1530 1532 2
1534 1536 2 1538
153a 2 153c 153e
2 1540 1542 3
1547 1548 1549 2
1544 154b 2 152f
154d 1 154f 1
1551 2 151a 1552
1 1556 1 1515
2 1513 155a 1
1561 3 14e9 155d
1564 2 1569 156a
2 156c 156f 1
1576 2 1572 1576
1 1587 2 1586
1587 1 158f 1
1595 2 1597 1598
2 1584 1599 1
15a0 1 159b 2
15b3 15b5 3 15b1
15b2 15b7 2 15c0
15c2 2 15c4 15c6
2 15c8 15ca 2
15cc 15ce 2 15d0
15d2 3 15d7 15d8
15d9 2 15d4 15db
2 15bf 15dd 1
15df 1 15e1 2
15aa 15e2 1 15e6
1 15a5 2 15a3
15ea 1 15f1 2
15ed 15f4 2 15fa
15fb 2 15fd 1600
1 1607 2 1603
1607 1 1618 2
1617 1618 1 1620
1 1626 2 1628
1629 2 1615 162a
1 1631 1 162c
2 1644 1646 3
1642 1643 1648 2
1651 1653 2 1655
1657 2 1659 165b
2 165d 165f 2
1661 1663 3 1668
1669 166a 2 1665
166c 2 1650 166e
1 1670 1 1672
2 163b 1673 1
1677 1 1636 2
1634 167b 1 1682
2 167e 1685 3
1688 15f7 1687 1
1689 1 168b 5
13e0 13e4 1444 14c3
168c 2 168f 168e
2 16a7 16ac 1
16b3 1 16ae 2
16c6 16c8 3 16c4
16c5 16ca 2 16d3
16d5 2 16d7 16d9
2 16db 16dd 2
16df 16e1 2 16e3
16e5 3 16ea 16eb
16ec 2 16e7 16ee
2 16d2 16f0 1
16f2 1 16f4 2
16bd 16f5 1 16f9
1 16b8 2 16b6
16fd 1 1708 2
1704 1708 1 170e
1 1710 2 1721
1722 1 1726 2
1724 1726 2 172b
172c 1 1730 2
172e 1730 a 1738
1739 173a 173b 173c
173d 173e 173f 1740
1741 2 1746 1747
1 174b 2 1749
174b 2 1750 1751
2 1756 1757 2
1753 1759 2 175f
1760 2 1765 1766
2 1762 1768 2
175c 176b 1 176d
2 1770 1771 1
1775 2 1773 1775
2 177a 177b 2
1780 1781 2 177d
1783 2 1789 178a
2 178f 1790 2
178c 1792 2 1786
1795 1 1797 3
1744 176e 1798 1
179a 2 17a8 17ad
1 17b4 1 17af
2 17c7 17c9 3
17c5 17c6 17cb 2
17d4 17d6 2 17d8
17da 2 17dc 17de
2 17e0 17e2 2
17e4 17e6 3 17eb
17ec 17ed 2 17e8
17ef 2 17d3 17f1
1 17f3 1 17f5
2 17be 17f6 1
17fa 1 17b9 2
17b7 17fe 2 1812
1817 1 181e 1
1819 2 1831 1833
3 182f 1830 1835
2 183e 1840 2
1842 1844 2 1846
1848 2 184a 184c
2 184e 1850 3
1855 1856 1857 2
1852 1859 2 183d
185b 1 185d 1
185f 2 1828 1860
1 1864 1 1823
2 1821 1868 2
1874 1879 1 1880
1 187b 2 1893
1895 3 1891 1892
1897 2 18a0 18a2
2 18a4 18a6 2
18a8 18aa 2 18ac
18ae 2 18b0 18b2
3 18b7 18b8 18b9
2 18b4 18bb 2
189f 18bd 1 18bf
1 18c1 2 188a
18c2 1 18c6 1
1885 2 1883 18ca
2 18d2 18d3 1
18d7 2 18d5 18d7
1 18d9 2 18de
18df 1 18e3 2
18e1 18e3 1 18e8
2 191a 191f 1
1926 1 1921 2
1939 193b 3 1937
1938 193d 2 1946
1948 2 194a 194c
2 194e 1950 2
1952 1954 2 1956
1958 3 195d 195e
195f 2 195a 1961
2 1945 1963 1
1965 1 1967 2
1930 1968 1 196c
1 192b 2 1929
1970 1 197b 2
1977 197b 2 1980
1981 1 1985 2
1983 1985 1 1987
2 198c 198d 1
1991 2 198f 1991
1 1993 2 19a1
19a3 3 199f 19a0
19a5 2 19ae 19b0
2 19b2 19b4 2
19b6 19b8 1 19c0
2 19c2 19c3 2
19ba 19c5 2 19c7
19c9 2 19cb 19cd
2 19cf 19d1 2
19d3 19d5 2 19ad
19d7 1 19d9 1
19db 2 19e5 19e7
3 19e3 19e4 19e9
2 19f2 19f4 2
19f1 19f6 1 19f8
1 19fa 3 1a01
1a02 1a03 3 19dc
19fb 1a05 1 1a07
3 1a0a 1a0b 1a0c
1 1a10 2 1a0e
1a10 1 1a1e 4
1a1a 1a1b 1a1c 1a20
3 1a17 1a23 1a28
1 1a2a 2 1a08
1a2b 1 1a2d 2
1a30 1a31 1 1a35
2 1a33 1a35 1
1a40 2 1a3f 1a40
1 1a48 1 1a4e
2 1a50 1a51 2
1a3d 1a52 1 1a59
1 1a54 2 1a6c
1a6e 3 1a6a 1a6b
1a70 2 1a79 1a7b
2 1a7d 1a7f 2
1a81 1a83 2 1a85
1a87 2 1a89 1a8b
3 1a90 1a91 1a92
2 1a8d 1a94 2
1a78 1a96 1 1a98
1 1a9a 2 1a63
1a9b 1 1a9f 1
1a5e 2 1a5c 1aa3
1 1aae 2 1aad
1aae 1 1ab6 1
1abc 2 1abe 1abf
2 1aab 1ac0 1
1ac7 1 1ac2 2
1ada 1adc 3 1ad8
1ad9 1ade 2 1ae7
1ae9 2 1aeb 1aed
2 1aef 1af1 2
1af3 1af5 2 1af7
1af9 3 1afe 1aff
1b00 2 1afb 1b02
2 1ae6 1b04 1
1b06 1 1b08 2
1ad1 1b09 1 1b0d
1 1acc 2 1aca
1b11 1 1b1c 2
1b1b 1b1c 1 1b24
1 1b2a 2 1b2c
1b2d 2 1b19 1b2e
1 1b35 1 1b30
2 1b48 1b4a 3
1b46 1b47 1b4c 2
1b55 1b57 2 1b59
1b5b 2 1b5d 1b5f
2 1b61 1b63 2
1b65 1b67 3 1b6c
1b6d 1b6e 2 1b69
1b70 2 1b54 1b72
1 1b74 1 1b76
2 1b3f 1b77 1
1b7b 1 1b3a 2
1b38 1b7f 3 1aa6
1b14 1b82 2 1b89
1b8a 1 1b8e 2
1b8c 1b8e 2 1b92
1b93 2 1b98 1b99
1 1b9b 2 1b95
1b9b 2 1b9f 1ba0
2 1ba5 1ba6 1
1ba8 2 1ba2 1ba8
1 1baf 1 1bb1
a 1bb2 1bb5 1bb8
1bbb 1bbe 1bc1 1bc4
1bc7 1bca 1bcd 1
1bcf 3 1bd3 1bd4
1bd5 1 1bd9 2
1bd7 1bd9 1 1bdb
2 1bde 1be0 1
1be9 2 1be5 1be9
1 1bed 2 1c03
1c08 1 1c0f 1
1c0a 2 1c22 1c24
3 1c20 1c21 1c26
2 1c2f 1c31 2
1c33 1c35 2 1c37
1c39 2 1c3b 1c3d
2 1c3f 1c41 3
1c46 1c47 1c48 2
1c43 1c4a 2 1c2e
1c4c 1 1c4e 1
1c50 2 1c19 1c51
1 1c55 1 1c14
2 1c12 1c59 1
1c64 2 1c60 1c64
2 1c6c 1c6d 2
1c72 1c73 1 1c75
2 1c6f 1c75 2
1c79 1c7a 2 1c7f
1c80 1 1c82 2
1c7c 1c82 3 1c8a
1c8b 1c8c 1 1c90
2 1c8e 1c90 2
1c9e 1ca0 3 1c9c
1c9d 1ca2 2 1cab
1cad 2 1caf 1cb1
2 1cb3 1cb5 1
1cbd 2 1cbf 1cc0
2 1cb7 1cc2 2
1cc4 1cc6 2 1cc8
1cca 2 1ccc 1cce
2 1cd0 1cd2 2
1caa 1cd4 1 1cd6
1 1cd8 2 1ce2
1ce4 3 1ce0 1ce1
1ce6 2 1cef 1cf1
2 1cee 1cf3 1
1cf5 1 1cf7 3
1cfe 1cff 1d00 3
1cd9 1cf8 1d02 3
1d08 1d09 1d0a 1
1d0e 2 1d0c 1d0e
2 1d1a 1d1f 1
1d26 1 1d21 2
1d39 1d3b 3 1d37
1d38 1d3d 2 1d46
1d48 2 1d4a 1d4c
2 1d4e 1d50 2
1d52 1d54 2 1d56
1d58 3 1d5d 1d5e
1d5f 2 1d5a 1d61
2 1d45 1d63 1
1d65 1 1d67 2
1d30 1d68 1 1d6c
1 1d2b 2 1d29
1d70 1 1d7b 2
1d77 1d7b 2 1d81
1d82 2 1d87 1d88
2 1d84 1d8a 1
1d98 2 1d97 1d98
1 1da0 1 1da6
2 1da8 1da9 2
1d95 1daa 1 1db1
1 1dac 2 1dc4
1dc6 3 1dc2 1dc3
1dc8 2 1dd1 1dd3
2 1dd5 1dd7 2
1dd9 1ddb 2 1ddd
1ddf 2 1de1 1de3
3 1de8 1de9 1dea
2 1de5 1dec 2
1dd0 1dee 1 1df0
1 1df2 2 1dbb
1df3 1 1df7 1
1db6 2 1db4 1dfb
2 1d8d 1dfe 1
1e01 2 1d73 1e02
2 1e05 1e04 2
1c6a 1e06 1 1e08
2 1c5c 1e09 1
1e0b 1 1e15 2
1e13 1e15 1 1e1a
1 1e1e 2 1e20
1e21 2 1e24 1e25
1 1e29 2 1e27
1e29 1 1e2e 1
1e30 2 1e37 1e38
2 1e3c 1e3d 2
1e41 1e42 2 1e46
1e47 2 1e4b 1e4c
2 1e50 1e51 2
1e55 1e56 2 1e5a
1e5b d 1e34 1e35
1e3a 1e3f 1e44 1e49
1e4e 1e53 1e58 1e5d
1e5e 1e5f 1e60 2
1e65 1e66 1 1e6c
2 1e68 1e6c 2
1e77 1e79 3 1e75
1e76 1e7b 2 1e84
1e86 2 1e88 1e8a
2 1e8c 1e8e 1
1e96 2 1e98 1e99
2 1e90 1e9b 2
1e83 1e9d 1 1e9f
1 1ea1 2 1eab
1ead 3 1ea9 1eaa
1eaf 2 1eb8 1eba
2 1eb7 1ebc 1
1ebe 1 1ec0 2
1ec7 1ec8 3 1ea2
1ec1 1eca 2 1ece
1ecf 1 1ed3 2
1ed1 1ed3 2 1ede
1ee0 3 1edc 1edd
1ee2 2 1eeb 1eed
2 1eef 1ef1 2
1ef3 1ef5 1 1efb
2 1efd 1efe 2
1ef7 1f00 2 1f02
1f04 2 1f06 1f08
2 1f0a 1f0c 2
1f0e 1f10 2 1eea
1f12 1 1f14 1
1f16 2 1f20 1f22
3 1f1e 1f1f 1f24
2 1f2d 1f2f 2
1f2c 1f31 1 1f33
1 1f35 2 1f3b
1f3c 3 1f3e 1f3f
1f40 3 1f17 1f36
1f42 2 1f45 1f44
2 1f48 1f49 1
1f4f 2 1f4b 1f4f
1 1f54 1 1f56
2 1f6f 1f74 1
1f7b 1 1f76 2
1f8e 1f90 3 1f8c
1f8d 1f92 2 1f9b
1f9d 2 1f9f 1fa1
2 1fa3 1fa5 2
1fa7 1fa9 2 1fab
1fad 3 1fb2 1fb3
1fb4 2 1faf 1fb6
2 1f9a 1fb8 1
1fba 1 1fbc 2
1f85 1fbd 1 1fc1
1 1f80 2 1f7e
1fc5 1 1fcc 2
1fca 1fcc 2 1fd0
1fd1 1 1fd5 2
1fd3 1fd5 1 1fda
1 1fdc 2 1fdf
1fe0 1 1fe4 2
1fe2 1fe4 1 1feb
2 1ff2 1ff3 2
1ff5 1ff8 1 1ffb
2 1ffd 1ffe 2
1fdd 1fff 2 2002
2003 1 2007 2
2005 2007 1 200e
2 2015 2016 2
2018 201b 1 201e
2 2020 2021 1
2022 2 2024 2025
2 2028 2029 1
202d 2 202b 202d
1 202f 1 204e
2 204d 204e 1
2056 1 205c 2
205e 205f 2 204b
2060 1 2067 1
2062 2 207a 207c
3 2078 2079 207e
2 2087 2089 2
208b 208d 2 208f
2091 2 2093 2095
2 2097 2099 3
209e 209f 20a0 2
209b 20a2 2 2086
20a4 1 20a6 1
20a8 2 2071 20a9
1 20ad 1 206c
2 206a 20b1 1
20c8 2 20c7 20c8
1 20d0 1 20d6
2 20d8 20d9 2
20c5 20da 1 20e1
1 20dc 2 20f4
20f6 3 20f2 20f3
20f8 2 2101 2103
2 2105 2107 2
2109 210b 2 210d
210f 2 2111 2113
3 2118 2119 211a
2 2115 211c 2
2100 211e 1 2120
1 2122 2 20eb
2123 1 2127 1
20e6 2 20e4 212b
3 20b4 212e 2132
1 2134 1 215a
1 215e 22 213b
213c 213d 213e 213f
2140 2141 2142 2143
2144 2145 2146 2147
2148 2149 214a 214b
214c 214d 214e 214f
2150 2151 2152 2153
2154 2155 2156 2157
2158 215c 2160 2161
2162 1 2168 2
2166 2168 2 2173
2175 3 2171 2172
2177 2 2180 2182
2 2184 2186 2
2188 218a 1 2192
2 2194 2195 2
218c 2197 2 2199
219b 2 219d 219f
2 21a1 21a3 2
21a5 21a7 2 217f
21a9 1 21ab 1
21ad 2 21b7 21b9
3 21b5 21b6 21bb
2 21c4 21c6 2
21c3 21c8 1 21ca
1 21cc 3 21d3
21d4 21d5 3 21ae
21cd 21d7 1 21dc
2 21da 21dc 2
21e7 21e9 3 21e5
21e6 21eb 2 21f4
21f6 2 21f8 21fa
2 21fc 21fe 1
2206 2 2208 2209
2 2200 220b 2
220d 220f 2 2211
2213 2 2215 2217
2 2219 221b 2
21f3 221d 1 221f
1 2221 2 222b
222d 3 2229 222a
222f 2 2238 223a
2 2237 223c 1
223e 1 2240 3
2247 2248 2249 3
2222 2241 224b 1
224e 2 2263 2268
1 226f 1 226a
2 2282 2284 3
2280 2281 2286 2
228f 2291 2 2293
2295 2 2297 2299
2 229b 229d 2
229f 22a1 3 22a6
22a7 22a8 2 22a3
22aa 2 228e 22ac
1 22ae 1 22b0
2 2279 22b1 1
22b5 1 2274 2
2272 22b9 1 22bc
1 22c1 2 22bf
22c1 2 22c5 22c6
1 22ca 2 22c8
22ca 1 22cc 2
22d3 22d4 1 22d8
2 22d6 22d8 1
22da 2 22df 22e0
1 22e4 2 22e2
22e4 2 22f7 22fc
1 2303 1 22fe
2 2316 2318 3
2314 2315 231a 2
2323 2325 2 2327
2329 2 232b 232d
2 232f 2331 2
2333 2335 3 233a
233b 233c 2 2337
233e 2 2322 2340
1 2342 1 2344
2 230d 2345 1
2349 1 2308 2
2306 234d 2 22e9
2350 2 2363 2368
1 236f 1 236a
2 2382 2384 3
2380 2381 2386 2
238f 2391 2 2393
2395 2 2397 2399
2 239b 239d 2
239f 23a1 3 23a6
23a7 23a8 2 23a3
23aa 2 238e 23ac
1 23ae 1 23b0
2 2379 23b1 1
23b5 1 2374 2
2372 23b9 1 23bc
2 23bf 23c0 1
23c1 2 23c4 23c5
1 23c9 2 23c7
23c9 2 23d9 23de
1 23e5 1 23e0
2 23f8 23fa 3
23f6 23f7 23fc 2
2405 2407 2 2409
240b 2 240d 240f
2 2411 2413 2
2415 2417 3 241c
241d 241e 2 2419
2420 2 2404 2422
1 2424 1 2426
2 23ef 2427 1
242b 1 23ea 2
23e8 242f 2 23ce
2432 2 2442 2447
1 244e 1 2449
2 2461 2463 3
245f 2460 2465 2
246e 2470 2 2472
2474 2 2476 2478
2 247a 247c 2
247e 2480 3 2485
2486 2487 2 2482
2489 2 246d 248b
1 248d 1 248f
2 2458 2490 1
2494 1 2453 2
2451 2498 1 249b
2 249e 249f 1
24a0 2 24a2 24a3
1 24a4 2 24af
24b0 6 24ab 24ac
24ad 24b2 24b3 24b4
2 24c3 24c8 1
24cf 1 24ca 2
24e2 24e4 3 24e0
24e1 24e6 2 24ef
24f1 2 24f3 24f5
2 24f7 24f9 2
24fb 24fd 2 24ff
2501 3 2506 2507
2508 2 2503 250a
2 24ee 250c 1
250e 1 2510 2
24d9 2511 1 2515
1 24d4 2 24d2
2519 3 24a8 24b7
251c 2 251f 2520
2 2523 2524 1
2528 2 2526 2528
2 252d 252e 2
2533 2534 2 2530
2536 1 2539 1
253b 2 2521 253c
2 253e 253f 1
2547 2 2543 2547
2 2553 2555 3
2551 2552 2557 2
2560 2562 2 2564
2566 2 2568 256a
1 2572 2 2574
2575 2 256c 2577
2 2579 257b 2
257d 257f 2 2581
2583 2 2585 2587
2 255f 2589 1
258b 1 258d 2
2597 2599 3 2595
2596 259b 2 25a4
25a6 2 25a3 25a8
1 25aa 1 25ac
3 25b3 25b4 25b5
3 258e 25ad 25b7
1 25b9 2 2540
25ba 3 25bc 224d
25bd 1 25eb 2
25ea 25eb 1 25f3
1 25f9 2 25fb
25fc 2 25e8 25fd
1 2604 1 25ff
2 2617 2619 3
2615 2616 261b 2
2624 2626 2 2628
262a 2 262c 262e
2 2630 2632 2
2634 2636 3 263b
263c 263d 2 2638
263f 2 2623 2641
1 2643 1 2645
2 260e 2646 1
264a 1 2609 2
2607 264e 2 2654
2655 2 265a 265b
1 265d 2 2657
265d 2 266a 266b
2 266f 2670 2
2675 2676 b 2662
2663 2664 2665 2666
2667 2668 266d 2672
2673 2678 1 267b
1 2685 2 2684
2685 1 268d 1
2693 2 2695 2696
2 2682 2697 1
269e 1 2699 2
26b1 26b3 3 26af
26b0 26b5 2 26be
26c0 2 26c2 26c4
2 26c6 26c8 2
26ca 26cc 2 26ce
26d0 3 26d5 26d6
26d7 2 26d2 26d9
2 26bd 26db 1
26dd 1 26df 2
26a8 26e0 1 26e4
1 26a3 2 26a1
26e8 1 2706 2
2705 2706 1 270e
1 2714 2 2716
2717 2 2703 2718
1 271f 1 271a
2 2732 2734 3
2730 2731 2736 2
273f 2741 2 2743
2745 2 2747 2749
2 274b 274d 2
274f 2751 3 2756
2757 2758 2 2753
275a 2 273e 275c
1 275e 1 2760
2 2729 2761 1
2765 1 2724 2
2722 2769 2 26eb
276c 2 276f 2770
11 1e0c 1e0f 1e12
1e22 1e31 1e63 1f46
1f57 1f5a 1fc8 2026
2135 2138 2165 25be
2651 2771 1 2773
4 1b87 1bd0 1be2
2774 2 2776 2777
5 18ef 18f2 1973
1a2e 2778 1 277a
1 277b 1 277d
1 277f 2 2786
2787 1 278b 2
2789 278b 2 2792
2793 1 2797 2
2795 2797 2 27af
27b0 1 27b4 2
27b2 27b4 2 27b9
27ba 1 27bd 1
27bf 2 27c2 27c3
1 27c7 2 27c5
27c7 2 27cc 27cd
1 27d1 2 27cf
27d1 2 27d8 27d9
1 27dd 2 27db
27dd 2 27e2 27e3
1 27e7 2 27e5
27e7 1 2824 2
2823 2824 1 282c
1 2832 2 2834
2835 2 2821 2836
1 283d 1 2838
2 2850 2852 3
284e 284f 2854 2
285d 285f 2 2861
2863 2 2865 2867
2 2869 286b 2
286d 286f 3 2874
2875 2876 2 2871
2878 2 285c 287a
1 287c 1 287e
2 2847 287f 1
2883 1 2842 2
2840 2887 1 288a
2 288f 2890 1
2894 2 2892 2894
1 28ce 2 28cd
28ce 1 28d6 1
28dc 2 28de 28df
2 28cb 28e0 1
28e7 1 28e2 2
28fa 28fc 3 28f8
28f9 28fe 2 2907
2909 2 290b 290d
2 290f 2911 2
2913 2915 2 2917
2919 3 291e 291f
2920 2 291b 2922
2 2906 2924 1
2926 1 2928 2
28f1 2929 1 292d
1 28ec 2 28ea
2931 1 2934 1
296f 2 296e 296f
1 2977 1 297d
2 297f 2980 2
296c 2981 1 2988
1 2983 2 299b
299d 3 2999 299a
299f 2 29a8 29aa
2 29ac 29ae 2
29b0 29b2 2 29b4
29b6 2 29b8 29ba
3 29bf 29c0 29c1
2 29bc 29c3 2
29a7 29c5 1 29c7
1 29c9 2 2992
29ca 1 29ce 1
298d 2 298b 29d2
1 29d5 3 29d8
2937 29d9 1 29da
1 2a13 2 2a12
2a13 1 2a1b 1
2a21 2 2a23 2a24
2 2a10 2a25 1
2a2c 1 2a27 2
2a3f 2a41 3 2a3d
2a3e 2a43 2 2a4c
2a4e 2 2a50 2a52
2 2a54 2a56 2
2a58 2a5a 2 2a5c
2a5e 3 2a63 2a64
2a65 2 2a60 2a67
2 2a4b 2a69 1
2a6b 1 2a6d 2
2a36 2a6e 1 2a72
1 2a31 2 2a2f
2a76 1 2a79 2
2a7c 2a7d 7 279f
27a2 27a5 27a8 27ad
27c0 2a7e 1 2a80
2 2a84 2a86 3
2a88 2a89 2a8a 17
2aad 2aae 2aaf 2ab0
2ab1 2ab2 2ab3 2ab4
2ab5 2ab6 2ab7 2ab8
2ab9 2aba 2abb 2abc
2abd 2abe 2abf 2ac0
2ac1 2ac2 2ac3 1
2ace 1 2ad4 2
2ad6 2ad7 1 2adf
2 2adb 2adf 1
2ae4 1 2ae6 2
2af0 2af5 1 2afc
1 2af7 2 2b0f
2b11 3 2b0d 2b0e
2b13 2 2b1c 2b1e
2 2b20 2b22 2
2b24 2b26 2 2b28
2b2a 2 2b2c 2b2e
3 2b33 2b34 2b35
2 2b30 2b37 2
2b1b 2b39 1 2b3b
1 2b3d 2 2b06
2b3e 1 2b42 1
2b01 2 2aff 2b46
2 2b50 2b55 1
2b5c 1 2b57 2
2b6f 2b71 3 2b6d
2b6e 2b73 2 2b7c
2b7e 2 2b80 2b82
2 2b84 2b86 2
2b88 2b8a 2 2b8c
2b8e 3 2b93 2b94
2b95 2 2b90 2b97
2 2b7b 2b99 1
2b9b 1 2b9d 2
2b66 2b9e 1 2ba2
1 2b61 2 2b5f
2ba6 1 2bad 2
2bab 2bad 2 2bb1
2bb2 1 2bb6 2
2bb4 2bb6 1 2bc4
4 2bc0 2bc1 2bc2
2bc6 2 2be9 2bee
1 2bf5 1 2bf0
2 2c08 2c0a 3
2c06 2c07 2c0c 2
2c15 2c17 2 2c19
2c1b 2 2c1d 2c1f
2 2c21 2c23 2
2c25 2c27 3 2c2c
2c2d 2c2e 2 2c29
2c30 2 2c14 2c32
1 2c34 1 2c36
2 2bff 2c37 1
2c3b 1 2bfa 2
2bf8 2c3f 1 2c4a
2 2c46 2c4a 2
2c60 2c65 1 2c6c
1 2c67 2 2c7f
2c81 3 2c7d 2c7e
2c83 2 2c8c 2c8e
2 2c90 2c92 2
2c94 2c96 2 2c98
2c9a 2 2c9c 2c9e
3 2ca3 2ca4 2ca5
2 2ca0 2ca7 2
2c8b 2ca9 1 2cab
1 2cad 2 2c76
2cae 1 2cb2 1
2c71 2 2c6f 2cb6
1 2cc1 2 2cbd
2cc1 2 2cea 2cef
1 2cf6 1 2cf1
2 2d09 2d0b 3
2d07 2d08 2d0d 2
2d16 2d18 2 2d1a
2d1c 2 2d1e 2d20
2 2d22 2d24 2
2d26 2d28 3 2d2d
2d2e 2d2f 2 2d2a
2d31 2 2d15 2d33
1 2d35 1 2d37
2 2d00 2d38 1
2d3c 1 2cfb 2
2cf9 2d40 1 2d4b
2 2d47 2d4b 1
2d4f 2 2d5a 2d5b
4 2d58 2d5d 2d60
2d61 1 2d73 2
2d72 2d73 1 2d7b
1 2d81 2 2d83
2d84 2 2d70 2d85
1 2d8c 1 2d87
2 2d9f 2da1 3
2d9d 2d9e 2da3 2
2dac 2dae 2 2db0
2db2 2 2db4 2db6
2 2db8 2dba 2
2dbc 2dbe 3 2dc3
2dc4 2dc5 2 2dc0
2dc7 2 2dab 2dc9
1 2dcb 1 2dcd
2 2d96 2dce 1
2dd2 1 2d91 2
2d8f 2dd6 3 2de0
2de1 2de2 3 2deb
2dec 2ded 1 2dfc
2 2dfb 2dfc 1
2e04 1 2e0a 2
2e0c 2e0d 2 2df9
2e0e 1 2e15 1
2e10 2 2e28 2e2a
3 2e26 2e27 2e2c
2 2e35 2e37 2
2e39 2e3b 2 2e3d
2e3f 2 2e41 2e43
2 2e45 2e47 3
2e4c 2e4d 2e4e 2
2e49 2e50 2 2e34
2e52 1 2e54 1
2e56 2 2e1f 2e57
1 2e5b 1 2e1a
2 2e18 2e5f 2
2e65 2e66 1 2e6c
2 2e68 2e6c 1
2e75 2 2e74 2e75
1 2e7d 1 2e83
2 2e85 2e86 2
2e72 2e87 1 2e8e
1 2e89 2 2ea1
2ea3 3 2e9f 2ea0
2ea5 2 2eae 2eb0
2 2eb2 2eb4 2
2eb6 2eb8 2 2eba
2ebc 2 2ebe 2ec0
3 2ec5 2ec6 2ec7
2 2ec2 2ec9 2
2ead 2ecb 1 2ecd
1 2ecf 2 2e98
2ed0 1 2ed4 1
2e93 2 2e91 2ed8
3 2ee5 2ee6 2ee7
4 2edb 2edf 2ee2
2eea 1 2eec 8
2d64 2dd9 2ddd 2de5
2de8 2df0 2e62 2eed
2 2ef1 2ef2 1
2ef8 2 2ef4 2ef8
2 2eff 2f00 4
2efd 2f02 2f05 2f06
1 2f1a 2 2f19
2f1a 1 2f22 1
2f28 2 2f2a 2f2b
2 2f17 2f2c 1
2f33 1 2f2e 2
2f46 2f48 3 2f44
2f45 2f4a 2 2f53
2f55 2 2f57 2f59
2 2f5b 2f5d 2
2f5f 2f61 2 2f63
2f65 3 2f6a 2f6b
2f6c 2 2f67 2f6e
2 2f52 2f70 1
2f72 1 2f74 2
2f3d 2f75 1 2f79
1 2f38 2 2f36
2f7d 3 2f87 2f88
2f89 3 2f92 2f93
2f94 1 2fa3 2
2fa2 2fa3 1 2fab
1 2fb1 2 2fb3
2fb4 2 2fa0 2fb5
1 2fbc 1 2fb7
2 2fcf 2fd1 3
2fcd 2fce 2fd3 2
2fdc 2fde 2 2fe0
2fe2 2 2fe4 2fe6
2 2fe8 2fea 2
2fec 2fee 3 2ff3
2ff4 2ff5 2 2ff0
2ff7 2 2fdb 2ff9
1 2ffb 1 2ffd
2 2fc6 2ffe 1
3002 1 2fc1 2
2fbf 3006 7 2f09
2f80 2f84 2f8c 2f8f
2f97 3009 1 301b
2 301a 301b 1
3023 1 3029 2
302b 302c 2 3018
302d 1 3034 1
302f 2 3047 3049
3 3045 3046 304b
2 3054 3056 2
3058 305a 2 305c
305e 2 3060 3062
2 3064 3066 3
306b 306c 306d 2
3068 306f 2 3053
3071 1 3073 1
3075 2 303e 3076
1 307a 1 3039
2 3037 307e 2
3087 3088 4 3085
308a 308d 308e 7
309f 30a0 30a1 30a2
30a3 30a4 30a5 2
30ac 30ad 1 30af
1 30d4 2 30d3
30d4 1 30dc 1
30e2 2 30e4 30e5
2 30d1 30e6 1
30ed 1 30e8 2
3100 3102 3 30fe
30ff 3104 2 310d
310f 2 3111 3113
2 3115 3117 2
3119 311b 2 311d
311f 3 3124 3125
3126 2 3121 3128
2 310c 312a 1
312c 1 312e 2
30f7 312f 1 3133
1 30f2 2 30f0
3137 9 3081 3091
3096 3099 309c 30a8
30b2 30b7 313a 3
313d 300c 313e 2
2d43 313f 1 3148
2 3144 3148 2
3151 3152 2 3154
3157 1 315e 2
315a 315e 1 316c
2 316b 316c 1
3174 1 317a 2
317c 317d 2 3169
317e 1 3185 1
3180 2 3198 319a
3 3196 3197 319c
2 31a5 31a7 2
31a9 31ab 2 31ad
31af 2 31b1 31b3
2 31b5 31b7 3
31bc 31bd 31be 2
31b9 31c0 2 31a4
31c2 1 31c4 1
31c6 2 318f 31c7
1 31cb 1 318a
2 3188 31cf 1
31d2 2 31d7 31d8
1 31de 2 31da
31de 2 31e5 31e6
4 31e3 31e8 31eb
31ec 1 3200 2
31ff 3200 1 3208
1 320e 2 3210
3211 2 31fd 3212
1 3219 1 3214
2 322c 322e 3
322a 322b 3230 2
3239 323b 2 323d
323f 2 3241 3243
2 3245 3247 2
3249 324b 3 3250
3251 3252 2 324d
3254 2 3238 3256
1 3258 1 325a
2 3223 325b 1
325f 1 321e 2
321c 3263 2 31ef
3266 1 327d 2
327c 327d 1 3285
1 328b 2 328d
328e 2 327a 328f
1 3296 1 3291
2 32a9 32ab 3
32a7 32a8 32ad 2
32b6 32b8 2 32ba
32bc 2 32be 32c0
2 32c2 32c4 2
32c6 32c8 3 32cd
32ce 32cf 2 32ca
32d1 2 32b5 32d3
1 32d5 1 32d7
2 32a0 32d8 1
32dc 1 329b 2
3299 32e0 1 32e3
3 32e6 3269 32e7
2 314e 32e8 2
32eb 32ea 4 2c50
2c53 2cb9 32ec 3
32f5 32f6 32f7 1
32fb 2 32f9 32fb
1 3300 1 3302
3 32f0 32f3 3303
2 3305 3306 2
3309 330a 1 330e
2 330c 330e 1
3312 2 3321 3326
1 332d 1 3328
2 3340 3342 3
333e 333f 3344 2
334d 334f 2 3351
3353 2 3355 3357
2 3359 335b 2
335d 335f 3 3364
3365 3366 2 3361
3368 2 334c 336a
1 336c 1 336e
2 3337 336f 1
3373 1 3332 2
3330 3377 1 3382
2 337e 3382 2
3387 3388 1 338c
2 338a 338c 1
339a 2 3399 339a
1 33a2 1 33a8
2 33aa 33ab 2
3397 33ac 1 33b3
1 33ae 2 33c6
33c8 3 33c4 33c5
33ca 2 33d3 33d5
2 33d7 33d9 2
33db 33dd 2 33df
33e1 2 33e3 33e5
3 33ea 33eb 33ec
2 33e7 33ee 2
33d2 33f0 1 33f2
1 33f4 2 33bd
33f5 1 33f9 1
33b8 2 33b6 33fd
1 3400 1 340a
2 3406 340a 2
340f 3410 1 3414
2 3412 3414 3
341e 3421 3423 2
3426 3425 2 337a
3427 1 3429 2
3445 344a 1 3451
1 344c 2 3464
3466 3 3462 3463
3468 2 3471 3473
2 3475 3477 2
3479 347b 2 347d
347f 2 3481 3483
3 3488 3489 348a
2 3485 348c 2
3470 348e 1 3490
1 3492 2 345b
3493 1 3497 1
3456 2 3454 349b
2 34a1 34a2 1
34a6 2 34a4 34a6
1 34a8 1 34c7
2 34c6 34c7 1
34cf 1 34d5 2
34d7 34d8 2 34c4
34d9 1 34e0 1
34db 2 34f3 34f5
3 34f1 34f2 34f7
2 3500 3502 2
3504 3506 2 3508
350a 2 350c 350e
2 3510 3512 3
3517 3518 3519 2
3514 351b 2 34ff
351d 1 351f 1
3521 2 34ea 3522
1 3526 1 34e5
2 34e3 352a 1
352d 1 3530 2
3533 3534 1 353a
2 3536 353a 1
3540 1 3568 2
3567 3568 1 3570
1 3576 2 3578
3579 2 3565 357a
1 3581 1 357c
2 3594 3596 3
3592 3593 3598 2
35a1 35a3 2 35a5
35a7 2 35a9 35ab
2 35ad 35af 2
35b1 35b3 3 35b8
35b9 35ba 2 35b5
35bc 2 35a0 35be
1 35c0 1 35c2
2 358b 35c3 1
35c7 1 3586 2
3584 35cb 1 35ce
1 35d1 2 35de
35df 1 35e3 2
35e1 35e3 2 35e7
35e8 1 35ec 2
35ea 35ec 1 3604
2 3603 3604 1
360c 1 3612 2
3614 3615 2 3601
3616 1 361d 1
3618 2 3630 3632
3 362e 362f 3634
2 363d 363f 2
3641 3643 2 3645
3647 2 3649 364b
2 364d 364f 3
3654 3655 3656 2
3651 3658 2 363c
365a 1 365c 1
365e 2 3627 365f
1 3663 1 3622
2 3620 3667 1
366a 1 368c 2
368b 368c 1 3694
1 369a 2 369c
369d 2 3689 369e
1 36a5 1 36a0
2 36b8 36ba 3
36b6 36b7 36bc 2
36c5 36c7 2 36c9
36cb 2 36cd 36cf
2 36d1 36d3 2
36d5 36d7 3 36dc
36dd 36de 2 36d9
36e0 2 36c4 36e2
1 36e4 1 36e6
2 36af 36e7 1
36eb 1 36aa 2
36a8 36ef 1 36f2
2 36f5 36f6 1
36fe 2 36fa 36fe
2 370c 3711 1
3718 1 3713 2
372b 372d 3 3729
372a 372f 2 3738
373a 2 373c 373e
2 3740 3742 2
3744 3746 2 3748
374a 3 374f 3750
3751 2 374c 3753
2 3737 3755 1
3757 1 3759 2
3722 375a 1 375e
1 371d 2 371b
3762 2 3768 3769
1 376d 2 376b
376d 1 3771 1
3773 1 377d 2
377c 377d 1 3785
1 378b 2 378d
378e 2 377a 378f
1 3796 1 3791
2 37a9 37ab 3
37a7 37a8 37ad 2
37b6 37b8 2 37ba
37bc 2 37be 37c0
2 37c2 37c4 2
37c6 37c8 3 37cd
37ce 37cf 2 37ca
37d1 2 37b5 37d3
1 37d5 1 37d7
2 37a0 37d8 1
37dc 1 379b 2
3799 37e0 1 37e9
2 37eb 37ec 1
37f2 2 37f4 37f5
2 37ee 37f7 2
37fa 37fc 1 37fe
2 380b 3810 1
3817 1 3812 2
382a 382c 3 3828
3829 382e 2 3837
3839 2 383b 383d
2 383f 3841 2
3843 3845 2 3847
3849 3 384e 384f
3850 2 384b 3852
2 3836 3854 1
3856 1 3858 2
3821 3859 1 385d
1 381c 2 381a
3861 2 3867 3868
2 386d 386e 1
3870 2 386a 3870
2 3877 3878 2
387a 387b 1 387d
1 387f 1 389a
2 3899 389a 1
38a2 1 38a8 2
38aa 38ab 2 3897
38ac 1 38b3 1
38ae 2 38c6 38c8
3 38c4 38c5 38ca
2 38d3 38d5 2
38d7 38d9 2 38db
38dd 2 38df 38e1
2 38e3 38e5 3
38ea 38eb 38ec 2
38e7 38ee 2 38d2
38f0 1 38f2 1
38f4 2 38bd 38f5
1 38f9 1 38b8
2 38b6 38fd 1
392c 2 392b 392c
1 3934 1 393a
2 393c 393d 2
3929 393e 1 3945
1 3940 2 3958
395a 3 3956 3957
395c 2 3965 3967
2 3969 396b 2
396d 396f 2 3971
3973 2 3975 3977
3 397c 397d 397e
2 3979 3980 2
3964 3982 1 3984
1 3986 2 394f
3987 1 398b 1
394a 2 3948 398f
1 3998 2 399a
399b 1 39a1 2
39a3 39a4 2 399d
39a6 2 39a9 39ab
1 39ad 2 39b6
39b7 2 39b9 39bc
2 39c6 39c7 2
39cb 39cc 6 39c2
39c3 39c4 39c9 39ce
39cf c 3704 3765
3774 37e3 3801 3864
3880 3900 3992 39b0
39bf 39d2 1 39d5
2 39d7 39d8 6
353f 35d2 35d7 35dc
36f7 39d9 2 39e5
39e6 1 39ea 2
39e8 39ea 2 39ee
39ef 2 39f4 39f5
1 39f7 2 39f1
39f7 2 39fb 39fc
2 3a01 3a02 1
3a04 2 39fe 3a04
3 3a0c 3a0d 3a0e
1 3a12 2 3a10
3a12 3 3a1c 3a1f
3a21 3 3a27 3a28
3a29 1 3a2d 2
3a2b 3a2d 2 3a39
3a3e 1 3a45 1
3a40 2 3a58 3a5a
3 3a56 3a57 3a5c
2 3a65 3a67 2
3a69 3a6b 2 3a6d
3a6f 2 3a71 3a73
2 3a75 3a77 3
3a7c 3a7d 3a7e 2
3a79 3a80 2 3a64
3a82 1 3a84 1
3a86 2 3a4f 3a87
1 3a8b 1 3a4a
2 3a48 3a8f 1
3a9a 2 3a96 3a9a
2 3aa0 3aa1 2
3aa6 3aa7 2 3aa3
3aa9 1 3ab7 2
3ab6 3ab7 1 3abf
1 3ac5 2 3ac7
3ac8 2 3ab4 3ac9
1 3ad0 1 3acb
2 3ae3 3ae5 3
3ae1 3ae2 3ae7 2
3af0 3af2 2 3af4
3af6 2 3af8 3afa
2 3afc 3afe 2
3b00 3b02 3 3b07
3b08 3b09 2 3b04
3b0b 2 3aef 3b0d
1 3b0f 1 3b11
2 3ada 3b12 1
3b16 1 3ad5 2
3ad3 3b1a 2 3aac
3b1d 1 3b20 2
3a92 3b21 2 3b24
3b23 1 3b25 1
3b29 2 3b27 3b29
1 3b2b 1 3b2f
1 3b3a 1 3b3c
2 3b3f 3b40 2
3b45 3b46 1 3b48
2 3b42 3b48 2
3b4c 3b4d 2 3b52
3b53 1 3b55 2
3b4f 3b55 2 3b5e
3b5f 1 3b63 2
3b61 3b63 1 3b68
1 3b6a 2 3b5c
3b6b 1 3b6d 2
3b85 3b86 1 3b8a
2 3b88 3b8a 2
3b8f 3b90 1 3b94
2 3b92 3b94 1
3b9c 2 3ba0 3ba1
1 3ba5 2 3ba3
3ba5 2 3baa 3bab
1 3bae 2 3bb1
3bb0 a 3b3d 3b6e
3b71 3b74 3b77 3b7a
3b7d 3b80 3b83 3bb2
2 3bb4 3bb5 2
3bbc 3bbd 2 3bc1
3bc2 2 3bc6 3bc7
2 3bcb 3bcc 2
3bd0 3bd1 2 3bd5
3bd6 2 3bda 3bdb
2 3bdf 3be0 d
3bb9 3bba 3bbf 3bc4
3bc9 3bce 3bd3 3bd8
3bdd 3be2 3be3 3be4
3be5 2 3bea 3beb
1 3bf1 2 3bed
3bf1 2 3bf6 3bfc
1 3c03 1 3bfe
2 3c16 3c18 3
3c14 3c15 3c1a 2
3c23 3c25 2 3c27
3c29 2 3c2b 3c2d
2 3c2f 3c31 2
3c33 3c35 3 3c3a
3c3b 3c3c 2 3c37
3c3e 2 3c22 3c40
1 3c42 1 3c44
2 3c0d 3c45 1
3c49 1 3c08 2
3c06 3c4d 2 3c5a
3c5c 3 3c58 3c59
3c5e 2 3c67 3c69
2 3c6b 3c6d 2
3c6f 3c71 1 3c79
2 3c7b 3c7c 2
3c73 3c7e 2 3c66
3c80 1 3c82 1
3c84 2 3c8e 3c90
3 3c8c 3c8d 3c92
2 3c9b 3c9d 2
3c9a 3c9f 1 3ca1
1 3ca3 2 3caa
3cab 4 3c50 3c85
3ca4 3cad 2 3cb1
3cb2 1 3cb6 2
3cb4 3cb6 2 3cbb
3cbc 3 3cbf 3cc2
3cc4 2 3cc7 3cc6
2 3ccd 3cce 1
3cd2 2 3cd0 3cd2
2 3cd9 3cda 1
3cde 2 3cdc 3cde
1 3ce5 2 3cec
3ced 2 3cef 3cf2
1 3cf5 2 3cf7
3cf8 2 3cd7 3cf9
2 3cfd 3cfe 1
3d04 2 3d00 3d04
2 3d0b 3d0c 1
3d10 2 3d0e 3d10
1 3d17 2 3d1e
3d1f 2 3d21 3d24
1 3d27 2 3d29
3d2a 2 3d09 3d2b
2 3d32 3d33 1
3d37 2 3d35 3d37
1 3d3e 2 3d45
3d46 2 3d48 3d4b
1 3d4e 2 3d50
3d51 2 3d30 3d52
3 3d54 3d2d 3d55
22 3d5c 3d5d 3d5e
3d5f 3d60 3d61 3d62
3d63 3d64 3d65 3d66
3d67 3d68 3d69 3d6a
3d6b 3d6c 3d6d 3d6e
3d6f 3d70 3d71 3d72
3d73 3d74 3d75 3d76
3d77 3d78 3d79 3d7a
3d7b 3d7c 3d7d 1
3d83 2 3d81 3d83
3 3d8a 3d8d 3d8f
1 3d94 2 3d92
3d94 3 3d9b 3d9e
3da0 1 3da3 2
3da9 3daa 1 3dae
2 3dac 3dae 2
3dc0 3dc5 1 3dcc
1 3dc7 2 3ddf
3de1 3 3ddd 3dde
3de3 2 3dec 3dee
2 3df0 3df2 2
3df4 3df6 2 3df8
3dfa 2 3dfc 3dfe
3 3e03 3e04 3e05
2 3e00 3e07 2
3deb 3e09 1 3e0b
1 3e0d 2 3dd6
3e0e 1 3e12 1
3dd1 2 3dcf 3e16
1 3e19 2 3e2b
3e30 1 3e37 1
3e32 2 3e4a 3e4c
3 3e48 3e49 3e4e
2 3e57 3e59 2
3e5b 3e5d 2 3e5f
3e61 2 3e63 3e65
2 3e67 3e69 3
3e6e 3e6f 3e70 2
3e6b 3e72 2 3e56
3e74 1 3e76 1
3e78 2 3e41 3e79
1 3e7d 1 3e3c
2 3e3a 3e81 1
3e84 2 3e87 3e88
1 3e89 2 3e8c
3e8d 1 3e91 2
3e8f 3e91 1 3e9c
2 3e9b 3e9c 1
3ea4 1 3eaa 2
3eac 3ead 2 3e99
3eae 1 3eb5 1
3eb0 2 3ec8 3eca
3 3ec6 3ec7 3ecc
2 3ed5 3ed7 2
3ed9 3edb 2 3edd
3edf 2 3ee1 3ee3
2 3ee5 3ee7 3
3eec 3eed 3eee 2
3ee9 3ef0 2 3ed4
3ef2 1 3ef4 1
3ef6 2 3ebf 3ef7
1 3efb 1 3eba
2 3eb8 3eff 2
3f0d 3f0e 6 3f09
3f0a 3f0b 3f10 3f11
3f12 2 3f1d 3f22
1 3f29 1 3f24
2 3f3c 3f3e 3
3f3a 3f3b 3f40 2
3f49 3f4b 2 3f4d
3f4f 2 3f51 3f53
2 3f55 3f57 2
3f59 3f5b 3 3f60
3f61 3f62 2 3f5d
3f64 2 3f48 3f66
1 3f68 1 3f6a
2 3f33 3f6b 1
3f6f 1 3f2e 2
3f2c 3f73 4 3f02
3f06 3f15 3f76 1
3f81 2 3f80 3f81
1 3f89 1 3f8f
2 3f91 3f92 2
3f7e 3f93 1 3f9a
1 3f95 2 3fad
3faf 3 3fab 3fac
3fb1 2 3fba 3fbc
2 3fbe 3fc0 2
3fc2 3fc4 2 3fc6
3fc8 2 3fca 3fcc
3 3fd1 3fd2 3fd3
2 3fce 3fd5 2
3fb9 3fd7 1 3fd9
1 3fdb 2 3fa4
3fdc 1 3fe0 1
3f9f 2 3f9d 3fe4
2 3ff2 3ff3 6
3fee 3fef 3ff0 3ff5
3ff6 3ff7 2 4002
4007 1 400e 1
4009 2 4021 4023
3 401f 4020 4025
2 402e 4030 2
4032 4034 2 4036
4038 2 403a 403c
2 403e 4040 3
4045 4046 4047 2
4042 4049 2 402d
404b 1 404d 1
404f 2 4018 4050
1 4054 1 4013
2 4011 4058 4
3fe7 3feb 3ffa 405b
2 405e 405f 2
4062 4063 1 4067
2 4065 4067 2
406c 406d 2 4072
4073 2 406f 4075
1 4078 1 407a
2 4060 407b 2
407d 407e 1 4086
2 4082 4086 3
408e 4091 4093 1
4095 2 407f 4096
3 4098 3da2 4099
2 409c 409d 1
40a1 2 409f 40a1
1 40ba 2 40b9
40ba 1 40c2 1
40c8 2 40ca 40cb
2 40b7 40cc 1
40d3 1 40ce 2
40e6 40e8 3 40e4
40e5 40ea 2 40f3
40f5 2 40f7 40f9
2 40fb 40fd 2
40ff 4101 2 4103
4105 3 410a 410b
410c 2 4107 410e
2 40f2 4110 1
4112 1 4114 2
40dd 4115 1 4119
1 40d8 2 40d6
411d 1 4120 1
4145 2 4144 4145
1 414d 1 4153
2 4155 4156 2
4142 4157 1 415e
1 4159 2 4171
4173 3 416f 4170
4175 2 417e 4180
2 4182 4184 2
4186 4188 2 418a
418c 2 418e 4190
3 4195 4196 4197
2 4192 4199 2
417d 419b 1 419d
1 419f 2 4168
41a0 1 41a4 1
4163 2 4161 41a8
1 41ab 2 41ae
41af 2 41b2 41b3
2 41b8 41b9 1
41bb 2 41b5 41bb
2 41c8 41c9 2
41cd 41ce 2 41d3
41d4 b 41c0 41c1
41c2 41c3 41c4 41c5
41c6 41cb 41d0 41d1
41d6 4 41e1 41e2
41e3 41e4 4 41d9
41de 41e7 41ec 1
41f6 2 41f5 41f6
1 41fe 1 4204
2 4206 4207 2
41f3 4208 1 420f
1 420a 2 4222
4224 3 4220 4221
4226 2 422f 4231
2 4233 4235 2
4237 4239 2 423b
423d 2 423f 4241
3 4246 4247 4248
2 4243 424a 2
422e 424c 1 424e
1 4250 2 4219
4251 1 4255 1
4214 2 4212 4259
2 425f 4260 1
4264 2 4262 4264
1 426d 2 426c
426d 1 4275 1
427b 2 427d 427e
2 426a 427f 1
4286 1 4281 2
4299 429b 3 4297
4298 429d 2 42a6
42a8 2 42aa 42ac
2 42ae 42b0 2
42b2 42b4 2 42b6
42b8 3 42bd 42be
42bf 2 42ba 42c1
2 42a5 42c3 1
42c5 1 42c7 2
4290 42c8 1 42cc
1 428b 2 4289
42d0 2 42dc 42dd
1 42ec 2 42eb
42ec 1 42f4 1
42fa 2 42fc 42fd
2 42e9 42fe 1
4305 1 4300 2
4318 431a 3 4316
4317 431c 2 4325
4327 2 4329 432b
2 432d 432f 2
4331 4333 2 4335
4337 3 433c 433d
433e 2 4339 4340
2 4324 4342 1
4344 1 4346 2
430f 4347 1 434b
1 430a 2 4308
434f 5 42d3 42d9
42e0 42e5 4352 1
436d 2 436c 436d
1 4375 1 437b
2 437d 437e 2
436a 437f 1 4386
1 4381 2 4399
439b 3 4397 4398
439d 2 43a6 43a8
2 43aa 43ac 2
43ae 43b0 2 43b2
43b4 2 43b6 43b8
3 43bd 43be 43bf
2 43ba 43c1 2
43a5 43c3 1 43c5
1 43c7 2 4390
43c8 1 43cc 1
438b 2 4389 43d0
1 43d3 2 43d6
43d7 2 425c 43d8
2 43da 43db 2
43e6 43e7 6 43e2
43e3 43e4 43e9 43ea
43eb f 39dd 39e0
39e3 3bb6 3be8 3cc8
3ccb 3d56 3d59 3d80
409a 41b0 43dc 43df
43ee 2 43f0 43f1
2 43f4 43f5 1
43f9 2 43f7 43f9
1 43fb 1 441a
2 4419 441a 1
4422 1 4428 2
442a 442b 2 4417
442c 1 4433 1
442e 2 4446 4448
3 4444 4445 444a
2 4453 4455 2
4457 4459 2 445b
445d 2 445f 4461
2 4463 4465 3
446a 446b 446c 2
4467 446e 2 4452
4470 1 4472 1
4474 2 443d 4475
1 4479 1 4438
2 4436 447d 1
4490 2 448f 4490
1 4498 1 449e
2 44a0 44a1 2
448d 44a2 1 44a9
1 44a4 2 44bc
44be 3 44ba 44bb
44c0 2 44c9 44cb
2 44cd 44cf 2
44d1 44d3 2 44d5
44d7 2 44d9 44db
3 44e0 44e1 44e2
2 44dd 44e4 2
44c8 44e6 1 44e8
1 44ea 2 44b3
44eb 1 44ef 1
44ae 2 44ac 44f3
1 4506 2 4505
4506 1 450e 1
4514 2 4516 4517
2 4503 4518 1
451f 1 451a 2
4532 4534 3 4530
4531 4536 2 453f
4541 2 4543 4545
2 4547 4549 2
454b 454d 2 454f
4551 3 4556 4557
4558 2 4553 455a
2 453e 455c 1
455e 1 4560 2
4529 4561 1 4565
1 4524 2 4522
4569 3 4480 44f6
456c 1 456f b
2bbd 2bc9 2bce 2c42
3307 342a 342d 349e
3531 43f2 4570 1
4572 1 4573 2
4577 4578 2 457d
457e 1 4582 2
4580 4582 2 4587
4588 1 4592 2
4591 4592 1 459a
1 45a0 2 45a2
45a3 2 458f 45a4
1 45ab 1 45a6
2 45be 45c0 3
45bc 45bd 45c2 2
45cb 45cd 2 45cf
45d1 2 45d3 45d5
2 45d7 45d9 2
45db 45dd 3 45e2
45e3 45e4 2 45df
45e6 2 45ca 45e8
1 45ea 1 45ec
2 45b5 45ed 1
45f1 1 45b0 2
45ae 45f5 1 4600
2 45ff 4600 1
4608 1 460e 2
4610 4611 2 45fd
4612 1 4619 1
4614 2 462c 462e
3 462a 462b 4630
2 4639 463b 2
463d 463f 2 4641
4643 2 4645 4647
2 4649 464b 3
4650 4651 4652 2
464d 4654 2 4638
4656 1 4658 1
465a 2 4623 465b
1 465f 1 461e
2 461c 4663 1
466e 2 466d 466e
1 4676 1 467c
2 467e 467f 2
466b 4680 1 4687
1 4682 2 469a
469c 3 4698 4699
469e 2 46a7 46a9
2 46ab 46ad 2
46af 46b1 2 46b3
46b5 2 46b7 46b9
3 46be 46bf 46c0
2 46bb 46c2 2
46a6 46c4 1 46c6
1 46c8 2 4691
46c9 1 46cd 1
468c 2 468a 46d1
1 46de 2 46dd
46de 1 46e6 1
46ec 2 46ee 46ef
2 46db 46f0 1
46f7 1 46f2 2
470a 470c 3 4708
4709 470e 2 4717
4719 2 471b 471d
2 471f 4721 2
4723 4725 2 4727
4729 3 472e 472f
4730 2 472b 4732
2 4716 4734 1
4736 1 4738 2
4701 4739 1 473d
1 46fc 2 46fa
4741 1 474c 2
474b 474c 1 4754
1 475a 2 475c
475d 2 4749 475e
1 4765 1 4760
2 4778 477a 3
4776 4777 477c 2
4785 4787 2 4789
478b 2 478d 478f
2 4791 4793 2
4795 4797 3 479c
479d 479e 2 4799
47a0 2 4784 47a2
1 47a4 1 47a6
2 476f 47a7 1
47ab 1 476a 2
4768 47af 1 47ba
2 47b9 47ba 1
47c2 1 47c8 2
47ca 47cb 2 47b7
47cc 1 47d3 1
47ce 2 47e6 47e8
3 47e4 47e5 47ea
2 47f3 47f5 2
47f7 47f9 2 47fb
47fd 2 47ff 4801
2 4803 4805 3
480a 480b 480c 2
4807 480e 2 47f2
4810 1 4812 1
4814 2 47dd 4815
1 4819 1 47d8
2 47d6 481d 7
458b 45f8 4666 46d4
4744 47b2 4820 2
4824 4825 1 4829
2 4827 4829 1
482e 1 4830 1
483e 2 483d 483e
1 4846 1 484c
2 484e 484f 2
483b 4850 1 4857
1 4852 2 486a
486c 3 4868 4869
486e 2 4877 4879
2 487b 487d 2
487f 4881 2 4883
4885 2 4887 4889
3 488e 488f 4890
2 488b 4892 2
4876 4894 1 4896
1 4898 2 4861
4899 1 489d 1
485c 2 485a 48a1
2 48b2 48b7 1
48be 1 48b9 2
48d1 48d3 3 48cf
48d0 48d5 2 48de
48e0 2 48e2 48e4
2 48e6 48e8 2
48ea 48ec 2 48ee
48f0 3 48f5 48f6
48f7 2 48f2 48f9
2 48dd 48fb 1
48fd 1 48ff 2
48c8 4900 1 4904
1 48c3 2 48c1
4908 1 4913 2
490f 4913 2 4926
492b 1 4932 1
492d 2 4945 4947
3 4943 4944 4949
2 4952 4954 2
4956 4958 2 495a
495c 2 495e 4960
2 4962 4964 3
4969 496a 496b 2
4966 496d 2 4951
496f 1 4971 1
4973 2 493c 4974
1 4978 1 4937
2 4935 497c 1
4987 2 4983 4987
2 498d 498e 2
4990 4993 1 499a
2 4996 499a 1
49ab 2 49aa 49ab
1 49b3 1 49b9
2 49bb 49bc 2
49a8 49bd 1 49c4
1 49bf 2 49d7
49d9 3 49d5 49d6
49db 2 49e4 49e6
2 49e8 49ea 2
49ec 49ee 2 49f0
49f2 2 49f4 49f6
3 49fb 49fc 49fd
2 49f8 49ff 2
49e3 4a01 1 4a03
1 4a05 2 49ce
4a06 1 4a0a 1
49c9 2 49c7 4a0e
2 499f 4a11 2
4a16 4a17 1 4a1d
2 4a19 4a1d 2
4a24 4a25 4 4a22
4a27 4a2a 4a2b 1
4a3f 2 4a3e 4a3f
1 4a47 1 4a4d
2 4a4f 4a50 2
4a3c 4a51 1 4a58
1 4a53 2 4a6b
4a6d 3 4a69 4a6a
4a6f 2 4a78 4a7a
2 4a7c 4a7e 2
4a80 4a82 2 4a84
4a86 2 4a88 4a8a
3 4a8f 4a90 4a91
2 4a8c 4a93 2
4a77 4a95 1 4a97
1 4a99 2 4a62
4a9a 1 4a9e 1
4a5d 2 4a5b 4aa2
2 4a2e 4aa5 1
4abc 2 4abb 4abc
1 4ac4 1 4aca
2 4acc 4acd 2
4ab9 4ace 1 4ad5
1 4ad0 2 4ae8
4aea 3 4ae6 4ae7
4aec 2 4af5 4af7
2 4af9 4afb 2
4afd 4aff 2 4b01
4b03 2 4b05 4b07
3 4b0c 4b0d 4b0e
2 4b09 4b10 2
4af4 4b12 1 4b14
1 4b16 2 4adf
4b17 1 4b1b 1
4ada 2 4ad8 4b1f
1 4b22 3 4b25
4aa8 4b26 1 4b2e
2 4b2a 4b2e 2
4b33 4b34 1 4b38
2 4b36 4b38 1
4b44 2 4b43 4b44
1 4b4c 1 4b52
2 4b54 4b55 2
4b41 4b56 1 4b5d
1 4b58 2 4b70
4b72 3 4b6e 4b6f
4b74 2 4b7d 4b7f
2 4b81 4b83 2
4b85 4b87 2 4b89
4b8b 2 4b8d 4b8f
3 4b94 4b95 4b96
2 4b91 4b98 2
4b7c 4b9a 1 4b9c
1 4b9e 2 4b67
4b9f 1 4ba3 1
4b62 2 4b60 4ba7
1 4baa 1 4bad
2 4b27 4bae 2
4bd2 4bd7 1 4bde
1 4bd9 2 4bf1
4bf3 3 4bef 4bf0
4bf5 2 4bfe 4c00
2 4c02 4c04 2
4c06 4c08 2 4c0a
4c0c 2 4c0e 4c10
3 4c15 4c16 4c17
2 4c12 4c19 2
4bfd 4c1b 1 4c1d
1 4c1f 2 4be8
4c20 1 4c24 1
4be3 2 4be1 4c28
1 4c33 2 4c2f
4c33 1 4c37 2
4c43 4c44 4 4c41
4c46 4c49 4c4a 1
4c54 2 4c53 4c54
1 4c5c 1 4c62
2 4c64 4c65 2
4c51 4c66 1 4c6d
1 4c68 2 4c80
4c82 3 4c7e 4c7f
4c84 2 4c8d 4c8f
2 4c91 4c93 2
4c95 4c97 2 4c99
4c9b 2 4c9d 4c9f
3 4ca4 4ca5 4ca6
2 4ca1 4ca8 2
4c8c 4caa 1 4cac
1 4cae 2 4c77
4caf 1 4cb3 1
4c72 2 4c70 4cb7
1 4cca 2 4cc9
4cca 1 4cd2 1
4cd8 2 4cda 4cdb
2 4cc7 4cdc 1
4ce3 1 4cde 2
4cf6 4cf8 3 4cf4
4cf5 4cfa 2 4d03
4d05 2 4d07 4d09
2 4d0b 4d0d 2
4d0f 4d11 2 4d13
4d15 3 4d1a 4d1b
4d1c 2 4d17 4d1e
2 4d02 4d20 1
4d22 1 4d24 2
4ced 4d25 1 4d29
1 4ce8 2 4ce6
4d2d 1 4d3d 2
4d3c 4d3d 1 4d45
1 4d4b 2 4d4d
4d4e 2 4d3a 4d4f
1 4d56 1 4d51
2 4d69 4d6b 3
4d67 4d68 4d6d 2
4d76 4d78 2 4d7a
4d7c 2 4d7e 4d80
2 4d82 4d84 2
4d86 4d88 3 4d8d
4d8e 4d8f 2 4d8a
4d91 2 4d75 4d93
1 4d95 1 4d97
2 4d60 4d98 1
4d9c 1 4d5b 2
4d59 4da0 4 4c4d
4cba 4d30 4da3 1
4db4 2 4db3 4db4
1 4dbc 1 4dc2
2 4dc4 4dc5 2
4db1 4dc6 1 4dcd
1 4dc8 2 4de0
4de2 3 4dde 4ddf
4de4 2 4ded 4def
2 4df1 4df3 2
4df5 4df7 2 4df9
4dfb 2 4dfd 4dff
3 4e04 4e05 4e06
2 4e01 4e08 2
4dec 4e0a 1 4e0c
1 4e0e 2 4dd7
4e0f 1 4e13 1
4dd2 2 4dd0 4e17
1 4e25 2 4e24
4e25 1 4e2d 1
4e33 2 4e35 4e36
2 4e22 4e37 1
4e3e 1 4e39 2
4e51 4e53 3 4e4f
4e50 4e55 2 4e5e
4e60 2 4e62 4e64
2 4e66 4e68 2
4e6a 4e6c 2 4e6e
4e70 3 4e75 4e76
4e77 2 4e72 4e79
2 4e5d 4e7b 1
4e7d 1 4e7f 2
4e48 4e80 1 4e84
1 4e43 2 4e41
4e88 2 4e1a 4e8b
2 4e8e 4e8f 2
4c2b 4e90 2 4e92
4e93 2 4e96 4e97
1 4e9d 2 4e99
4e9d 2 4ea1 4ea2
1 4ea8 2 4ea4
4ea8 1 4eb5 2
4eb4 4eb5 1 4ebd
1 4ec3 2 4ec5
4ec6 2 4eb2 4ec7
1 4ece 1 4ec9
2 4ee1 4ee3 3
4edf 4ee0 4ee5 2
4eee 4ef0 2 4ef2
4ef4 2 4ef6 4ef8
2 4efa 4efc 2
4efe 4f00 3 4f05
4f06 4f07 2 4f02
4f09 2 4eed 4f0b
1 4f0d 1 4f0f
2 4ed8 4f10 1
4f14 1 4ed3 2
4ed1 4f18 1 4f1b
1 4f1e 4 4919
497f 4e94 4f1f 1
4f2a 2 4f29 4f2a
1 4f32 1 4f38
2 4f3a 4f3b 2
4f27 4f3c 1 4f43
1 4f3e 2 4f56
4f58 3 4f54 4f55
4f5a 2 4f63 4f65
2 4f67 4f69 2
4f6b 4f6d 2 4f6f
4f71 2 4f73 4f75
3 4f7a 4f7b 4f7c
2 4f77 4f7e 2
4f62 4f80 1 4f82
1 4f84 2 4f4d
4f85 1 4f89 1
4f48 2 4f46 4f8d
1 4f98 2 4f97
4f98 1 4fa0 1
4fa6 2 4fa8 4fa9
2 4f95 4faa 1
4fb1 1 4fac 2
4fc4 4fc6 3 4fc2
4fc3 4fc8 2 4fd1
4fd3 2 4fd5 4fd7
2 4fd9 4fdb 2
4fdd 4fdf 2 4fe1
4fe3 3 4fe8 4fe9
4fea 2 4fe5 4fec
2 4fd0 4fee 1
4ff0 1 4ff2 2
4fbb 4ff3 1 4ff7
1 4fb6 2 4fb4
4ffb 3 5001 5002
5003 1 5007 2
5005 5007 1 500c
1 500e 2 5011
5012 1 5018 2
5014 5018 2 501c
501d 1 5023 2
501f 5023 1 5030
2 502f 5030 1
5038 1 503e 2
5040 5041 2 502d
5042 1 5049 1
5044 2 505c 505e
3 505a 505b 5060
2 5069 506b 2
506d 506f 2 5071
5073 2 5075 5077
2 5079 507b 3
5080 5081 5082 2
507d 5084 2 5068
5086 1 5088 1
508a 2 5053 508b
1 508f 1 504e
2 504c 5093 2
5096 509a 1 509c
5 4f23 4f90 4ffe
500f 509d 2 509f
50a0 2 50a3 50a4
1 50a8 2 50a6
50a8 2 50ac 50ad
1 50b1 2 50af
50b1 1 50b5 2
50c4 50c9 1 50d0
1 50cb 2 50e3
50e5 3 50e1 50e2
50e7 2 50f0 50f2
2 50f4 50f6 2
50f8 50fa 2 50fc
50fe 2 5100 5102
3 5107 5108 5109
2 5104 510b 2
50ef 510d 1 510f
1 5111 2 50da
5112 1 5116 1
50d5 2 50d3 511a
1 5125 2 5121
5125 2 512a 512b
1 512f 2 512d
512f 1 513d 2
513c 513d 1 5145
1 514b 2 514d
514e 2 513a 514f
1 5156 1 5151
2 5169 516b 3
5167 5168 516d 2
5176 5178 2 517a
517c 2 517e 5180
2 5182 5184 2
5186 5188 3 518d
518e 518f 2 518a
5191 2 5175 5193
1 5195 1 5197
2 5160 5198 1
519c 1 515b 2
5159 51a0 1 51a3
1 51ad 2 51a9
51ad 2 51b2 51b3
1 51b7 2 51b5
51b7 3 51c1 51c4
51c6 2 51c9 51c8
2 511d 51ca 1
51cc 2 51cf 51d0
1 51d6 2 51d2
51d6 2 51da 51db
1 51e1 2 51dd
51e1 2 51f1 51f2
1 51f6 2 51f4
51f6 2 51fa 51fb
1 51ff 2 51fd
51ff 1 5217 2
5216 5217 1 521f
1 5225 2 5227
5228 2 5214 5229
1 5230 1 522b
2 5243 5245 3
5241 5242 5247 2
5250 5252 2 5254
5256 2 5258 525a
2 525c 525e 2
5260 5262 3 5267
5268 5269 2 5264
526b 2 524f 526d
1 526f 1 5271
2 523a 5272 1
5276 1 5235 2
5233 527a 1 527d
1 529f 2 529e
529f 1 52a7 1
52ad 2 52af 52b0
2 529c 52b1 1
52b8 1 52b3 2
52cb 52cd 3 52c9
52ca 52cf 2 52d8
52da 2 52dc 52de
2 52e0 52e2 2
52e4 52e6 2 52e8
52ea 3 52ef 52f0
52f1 2 52ec 52f3
2 52d7 52f5 1
52f7 1 52f9 2
52c2 52fa 1 52fe
1 52bd 2 52bb
5302 1 5305 2
5308 5309 1 5311
2 530d 5311 2
5322 5327 1 532e
1 5329 2 5341
5343 3 533f 5340
5345 2 534e 5350
2 5352 5354 2
5356 5358 2 535a
535c 2 535e 5360
3 5365 5366 5367
2 5362 5369 2
534d 536b 1 536d
1 536f 2 5338
5370 1 5374 1
5333 2 5331 5378
2 537e 537f 1
5383 2 5381 5383
1 5387 1 5391
2 5390 5391 1
5399 1 539f 2
53a1 53a2 2 538e
53a3 1 53aa 1
53a5 2 53bd 53bf
3 53bb 53bc 53c1
2 53ca 53cc 2
53ce 53d0 2 53d2
53d4 2 53d6 53d8
2 53da 53dc 3
53e1 53e2 53e3 2
53de 53e5 2 53c9
53e7 1 53e9 1
53eb 2 53b4 53ec
1 53f0 1 53af
2 53ad 53f4 2
53fa 53fb 1 53ff
2 53fd 53ff 1
5402 1 5409 1
5412 1 5414 1
541a 2 541c 541d
1 5423 2 5425
5426 2 541f 5428
2 542b 542d 1
542f 2 543c 5441
1 5448 1 5443
2 545b 545d 3
5459 545a 545f 2
5468 546a 2 546c
546e 2 5470 5472
2 5474 5476 2
5478 547a 3 547f
5480 5481 2 547c
5483 2 5467 5485
1 5487 1 5489
2 5452 548a 1
548e 1 544d 2
544b 5492 2 54b4
54b9 1 54c0 1
54bb 2 54d3 54d5
3 54d1 54d2 54d7
2 54e0 54e2 2
54e4 54e6 2 54e8
54ea 2 54ec 54ee
2 54f0 54f2 3
54f7 54f8 54f9 2
54f4 54fb 2 54df
54fd 1 54ff 1
5501 2 54ca 5502
1 5506 1 54c5
2 54c3 550a 2
5510 5511 1 5515
2 5513 5515 2
551a 551b 2 5520
5521 2 551d 5523
2 552e 552f 2
5531 5532 2 5536
5537 2 553c 553d
1 553f 2 5539
553f 2 5546 5547
2 5549 554a 1
554c 1 554e 1
5576 2 5575 5576
1 557e 1 5584
2 5586 5587 2
5573 5588 1 558f
1 558a 2 55a2
55a4 3 55a0 55a1
55a6 2 55af 55b1
2 55b3 55b5 2
55b7 55b9 2 55bb
55bd 2 55bf 55c1
3 55c6 55c7 55c8
2 55c3 55ca 2
55ae 55cc 1 55ce
1 55d0 2 5599
55d1 1 55d5 1
5594 2 5592 55d9
5 5526 5529 5534
554f 55dc 1 55df
2 55e2 55e3 2
55e8 55e9 1 55eb
2 55e5 55eb 2
55f2 55f3 2 55f5
55f6 1 55f8 1
55fa 1 562c 2
562b 562c 1 5634
1 563a 2 563c
563d 2 5629 563e
1 5645 1 5640
2 5658 565a 3
5656 5657 565c 2
5665 5667 2 5669
566b 2 566d 566f
2 5671 5673 2
5675 5677 3 567c
567d 567e 2 5679
5680 2 5664 5682
1 5684 1 5686
2 564f 5687 1
568b 1 564a 2
5648 568f 2 5695
5696 1 569a 2
5698 569a 2 569f
56a0 2 56a5 56a6
2 56a2 56a8 2
56ad 56ae 2 56b3
56b4 1 56b6 2
56b0 56b6 2 56bb
56bc 2 56c1 56c2
2 56be 56c4 2
56c9 56ca 2 56cf
56d0 2 56d2 56d4
2 56cc 56d7 2
56c6 56da 2 56df
56e0 1 56e4 2
56e2 56e4 1 56f4
2 56f3 56f4 1
56fc 1 5702 2
5704 5705 2 56f1
5706 1 570d 1
5708 2 5720 5722
3 571e 571f 5724
2 572d 572f 2
5731 5733 2 5735
5737 2 5739 573b
2 573d 573f 3
5744 5745 5746 2
5741 5748 2 572c
574a 1 574c 1
574e 2 5717 574f
1 5753 1 5712
2 5710 5757 1
575a 1 575d 2
56dd 575e 1 5760
2 5768 576d 1
5774 1 576f 2
5787 5789 3 5785
5786 578b 2 5794
5796 2 5798 579a
2 579c 579e 2
57a0 57a2 2 57a4
57a6 3 57ab 57ac
57ad 2 57a8 57af
2 5793 57b1 1
57b3 1 57b5 2
577e 57b6 1 57ba
1 5779 2 5777
57be 3 56ab 5761
57c1 2 57c6 57c7
2 57cc 57cd 2
57c9 57cf 2 57d4
57d5 2 57da 57db
1 57dd 2 57d7
57dd 2 57e2 57e3
2 57e8 57e9 2
57ee 57ef 2 57f1
57f3 2 57eb 57f6
2 57e5 57f9 2
57fe 57ff 2 5804
5805 1 5807 2
5801 5807 1 5816
2 5815 5816 1
581e 1 5824 2
5826 5827 2 5813
5828 1 582f 1
582a 2 5842 5844
3 5840 5841 5846
2 584f 5851 2
5853 5855 2 5857
5859 2 585b 585d
2 585f 5861 3
5866 5867 5868 2
5863 586a 2 584e
586c 1 586e 1
5870 2 5839 5871
1 5875 1 5834
2 5832 5879 1
587c 1 587f 2
57fc 5880 1 5882
2 57d2 5883 2
5885 5886 a 53f7
5415 5432 5495 5499
550d 55e0 55fb 5692
5887 2 5889 588a
1 58b4 2 58b3
58b4 1 58bc 1
58c2 2 58c4 58c5
2 58b1 58c6 1
58cd 1 58c8 2
58e0 58e2 3 58de
58df 58e4 2 58ed
58ef 2 58f1 58f3
2 58f5 58f7 2
58f9 58fb 2 58fd
58ff 3 5904 5905
5906 2 5901 5908
2 58ec 590a 1
590c 1 590e 2
58d7 590f 1 5913
1 58d2 2 58d0
5917 1 5920 2
5922 5923 1 5929
2 592b 592c 2
5925 592e 2 5931
5933 1 5935 2
593e 593f 2 5941
5944 2 594e 594f
2 5953 5954 6
594a 594b 594c 5951
5956 5957 7 5317
537b 588b 591a 5938
5947 595a 1 595d
2 595f 5960 4
51ea 51ef 530a 5961
2 5967 5968 1
596c 2 596a 596c
2 5970 5971 1
5975 2 5973 5975
2 597b 597c 1
5980 2 597e 5980
2 5986 5987 1
598b 2 5989 598b
2 5995 5996 2
5992 5999 1 599b
2 599e 599f 1
59a3 2 59a1 59a3
2 59a8 59a9 2
59ae 59af 1 59b1
2 59ab 59b1 2
59b9 59ba 1 59bd
2 59c2 59c3 2
59c8 59c9 2 59c5
59cb 1 59cd 1
59d0 2 59d2 59d3
2 59d6 59d7 1
59db 2 59d9 59db
2 59e0 59e1 2
59e3 59e5 1 59e8
2 59ee 59ef 1
59f1 2 59f3 59f5
1 59f7 1 59fa
2 59fc 59fd 2
5a00 5a01 1 5a05
2 5a03 5a05 1
5a1d 2 5a1c 5a1d
1 5a25 1 5a2b
2 5a2d 5a2e 2
5a1a 5a2f 1 5a36
1 5a31 2 5a49
5a4b 3 5a47 5a48
5a4d 2 5a56 5a58
2 5a5a 5a5c 2
5a5e 5a60 2 5a62
5a64 2 5a66 5a68
3 5a6d 5a6e 5a6f
2 5a6a 5a71 2
5a55 5a73 1 5a75
1 5a77 2 5a40
5a78 1 5a7c 1
5a3b 2 5a39 5a80
1 5a83 1 5ab0
2 5aaf 5ab0 1
5ab8 1 5abe 2
5ac0 5ac1 2 5aad
5ac2 1 5ac9 1
5ac4 2 5adc 5ade
3 5ada 5adb 5ae0
2 5ae9 5aeb 2
5aed 5aef 2 5af1
5af3 2 5af5 5af7
2 5af9 5afb 3
5b00 5b01 5b02 2
5afd 5b04 2 5ae8
5b06 1 5b08 1
5b0a 2 5ad3 5b0b
1 5b0f 1 5ace
2 5acc 5b13 1
5b16 2 5b19 5b1a
2 5b20 5b21 1
5b27 2 5b23 5b27
1 5b2c 1 5b30
2 5b32 5b33 2
5b36 5b37 1 5b3b
2 5b39 5b3b 1
5b42 2 5b49 5b4a
2 5b4c 5b4f 1
5b52 2 5b54 5b55
22 5b5c 5b5d 5b5e
5b5f 5b60 5b61 5b62
5b63 5b64 5b65 5b66
5b67 5b68 5b69 5b6a
5b6b 5b6c 5b6d 5b6e
5b6f 5b70 5b71 5b72
5b73 5b74 5b75 5b76
5b77 5b78 5b79 5b7a
5b7b 5b7c 5b7d 1
5b83 2 5b81 5b83
3 5b8a 5b8d 5b8f
1 5b94 2 5b92
5b94 3 5b9b 5b9e
5ba0 2 5ba3 5ba2
b 5965 599c 59d4
59fe 5b1b 5b1e 5b34
5b56 5b59 5b80 5ba4
2 5ba6 5ba7 1
5bb3 2 5bb2 5bb3
1 5bbb 1 5bc1
2 5bc3 5bc4 2
5bb0 5bc5 1 5bcc
1 5bc7 2 5bdf
5be1 3 5bdd 5bde
5be3 2 5bec 5bee
2 5bf0 5bf2 2
5bf4 5bf6 2 5bf8
5bfa 2 5bfc 5bfe
3 5c03 5c04 5c05
2 5c00 5c07 2
5beb 5c09 1 5c0b
1 5c0d 2 5bd6
5c0e 1 5c12 1
5bd1 2 5bcf 5c16
2 5c1c 5c1d 1
5c21 2 5c1f 5c21
1 5c23 1 5c42
2 5c41 5c42 1
5c4a 1 5c50 2
5c52 5c53 2 5c3f
5c54 1 5c5b 1
5c56 2 5c6e 5c70
3 5c6c 5c6d 5c72
2 5c7b 5c7d 2
5c7f 5c81 2 5c83
5c85 2 5c87 5c89
2 5c8b 5c8d 3
5c92 5c93 5c94 2
5c8f 5c96 2 5c7a
5c98 1 5c9a 1
5c9c 2 5c65 5c9d
1 5ca1 1 5c60
2 5c5e 5ca5 1
5cb8 2 5cb7 5cb8
1 5cc0 1 5cc6
2 5cc8 5cc9 2
5cb5 5cca 1 5cd1
1 5ccc 2 5ce4
5ce6 3 5ce2 5ce3
5ce8 2 5cf1 5cf3
2 5cf5 5cf7 2
5cf9 5cfb 2 5cfd
5cff 2 5d01 5d03
3 5d08 5d09 5d0a
2 5d05 5d0c 2
5cf0 5d0e 1 5d10
1 5d12 2 5cdb
5d13 1 5d17 1
5cd6 2 5cd4 5d1b
1 5d2e 2 5d2d
5d2e 1 5d36 1
5d3c 2 5d3e 5d3f
2 5d2b 5d40 1
5d47 1 5d42 2
5d5a 5d5c 3 5d58
5d59 5d5e 2 5d67
5d69 2 5d6b 5d6d
2 5d6f 5d71 2
5d73 5d75 2 5d77
5d79 3 5d7e 5d7f
5d80 2 5d7b 5d82
2 5d66 5d84 1
5d86 1 5d88 2
5d51 5d89 1 5d8d
1 5d4c 2 5d4a
5d91 3 5ca8 5d1e
5d94 1 5d97 3
5d9e 5d9f 5da0 3
5da9 5daa 5dab 1
5db9 2 5db8 5db9
1 5dc1 1 5dc7
2 5dc9 5dca 2
5db6 5dcb 1 5dd2
1 5dcd 2 5de5
5de7 3 5de3 5de4
5de9 2 5df2 5df4
2 5df6 5df8 2
5dfa 5dfc 2 5dfe
5e00 2 5e02 5e04
3 5e09 5e0a 5e0b
2 5e06 5e0d 2
5df1 5e0f 1 5e11
1 5e13 2 5ddc
5e14 1 5e18 1
5dd7 2 5dd5 5e1c
2 5e22 5e23 1
5e27 2 5e25 5e27
2 5e2c 5e2d 1
5e31 2 5e2f 5e31
1 5e4b 2 5e4a
5e4b 1 5e53 1
5e59 2 5e5b 5e5c
2 5e48 5e5d 1
5e64 1 5e5f 2
5e77 5e79 3 5e75
5e76 5e7b 2 5e84
5e86 2 5e88 5e8a
2 5e8c 5e8e 2
5e90 5e92 2 5e94
5e96 3 5e9b 5e9c
5e9d 2 5e98 5e9f
2 5e83 5ea1 1
5ea3 1 5ea5 2
5e6e 5ea6 1 5eaa
1 5e69 2 5e67
5eae 1 5eb1 2
5eb6 5eb7 1 5ebb
2 5eb9 5ebb 1
5ece 2 5ecd 5ece
1 5ed6 1 5edc
2 5ede 5edf 2
5ecb 5ee0 1 5ee7
1 5ee2 2 5efa
5efc 3 5ef8 5ef9
5efe 2 5f07 5f09
2 5f0b 5f0d 2
5f0f 5f11 2 5f13
5f15 2 5f17 5f19
3 5f1e 5f1f 5f20
2 5f1b 5f22 2
5f06 5f24 1 5f26
1 5f28 2 5ef1
5f29 1 5f2d 1
5eec 2 5eea 5f31
2 5f38 5f39 2
5f34 5f3c 2 5f41
5f42 1 5f46 2
5f44 5f46 1 5f59
2 5f58 5f59 1
5f61 1 5f67 2
5f69 5f6a 2 5f56
5f6b 1 5f72 1
5f6d 2 5f85 5f87
3 5f83 5f84 5f89
2 5f92 5f94 2
5f96 5f98 2 5f9a
5f9c 2 5f9e 5fa0
2 5fa2 5fa4 3
5fa9 5faa 5fab 2
5fa6 5fad 2 5f91
5faf 1 5fb1 1
5fb3 2 5f7c 5fb4
1 5fb8 1 5f77
2 5f75 5fbc 2
5fc3 5fc4 2 5fbf
5fc7 1 5fd6 2
5fd5 5fd6 1 5fde
1 5fe4 2 5fe6
5fe7 2 5fd3 5fe8
1 5fef 1 5fea
2 6002 6004 3
6000 6001 6006 2
600f 6011 2 6013
6015 2 6017 6019
2 601b 601d 2
601f 6021 3 6026
6027 6028 2 6023
602a 2 600e 602c
1 602e 1 6030
2 5ff9 6031 1
6035 1 5ff4 2
5ff2 6039 2 6040
6041 2 6047 6048
3 603c 6044 604b
4 604d 5f3f 5fc9
604e a 51cd 5ba8
5c19 5d98 5d9b 5da3
5da6 5dae 5e1f 604f
1 6051 2 6055
6056 2 6058 605a
2 6060 6061 2
6066 6067 2 6063
6069 7 4831 48a4
490b 50a1 6052 605d
606c 2 606e 606f
3 6075 6076 6077
3 457b 6070 607a
2 607c 607d 1
607f 8 2ac4 2ad8
2ae7 2aea 2b49 2ba9
607e 6082 2 6088
608e 1 6095 1
6090 2 60a8 60aa
3 60a6 60a7 60ac
2 60b5 60b7 2
60b9 60bb 2 60bd
60bf 2 60c1 60c3
2 60c5 60c7 3
60cc 60cd 60ce 2
60c9 60d0 2 60b4
60d2 1 60d4 1
60d6 2 609f 60d7
1 60db 1 609a
2 6098 60df 2
60e5 60e6 1 60ea
2 60e8 60ea 2
60f5 60f7 3 60f3
60f4 60f9 2 6102
6104 2 6106 6108
2 610a 610c 1
6112 2 6114 6115
2 610e 6117 2
6119 611b 2 611d
611f 2 6121 6123
2 6125 6127 2
6101 6129 1 612b
1 612d 2 6137
6139 3 6135 6136
613b 2 6144 6146
2 6143 6148 1
614a 1 614c 2
6152 6153 3 6155
6156 6157 3 612e
614d 6159 1 615b
2 6161 6162 1
6166 2 6164 6166
2 616d 616e 2
6173 6174 1 6176
2 6170 6176 2
617b 617c 2 6181
6182 2 617e 6184
2 6189 618a 1
618e 2 618c 618e
2 6193 6194 1
6198 2 6196 6198
1 619e 2 61bf
61c0 1 61c4 2
61c2 61c4 2 61c9
61ca 1 61ce 2
61cc 61ce 1 61d6
2 61da 61db 1
61df 2 61dd 61df
2 61e4 61e5 1
61e8 2 61eb 61ea
2 61f2 61f3 2
61f7 61f8 2 61fc
61fd 2 6201 6202
2 6206 6207 2
620b 620c 2 6210
6211 2 6215 6216
d 61ef 61f0 61f5
61fa 61ff 6204 6209
620e 6213 6218 6219
621a 621b 2 6220
6221 1 6227 2
6223 6227 2 6232
6234 3 6230 6231
6236 2 623f 6241
2 6243 6245 2
6247 6249 1 6251
2 6253 6254 2
624b 6256 2 623e
6258 1 625a 1
625c 2 6266 6268
3 6264 6265 626a
2 6273 6275 2
6272 6277 1 6279
1 627b 2 6282
6283 3 625d 627c
6285 2 6289 628a
1 628e 2 628c
628e 2 6299 629b
3 6297 6298 629d
2 62a6 62a8 2
62aa 62ac 2 62ae
62b0 1 62b6 2
62b8 62b9 2 62b2
62bb 2 62bd 62bf
2 62c1 62c3 2
62c5 62c7 2 62c9
62cb 2 62a5 62cd
1 62cf 1 62d1
2 62db 62dd 3
62d9 62da 62df 2
62e8 62ea 2 62e7
62ec 1 62ee 1
62f0 2 62f6 62f7
3 62f9 62fa 62fb
3 62d2 62f1 62fd
2 6300 62ff 1
6319 2 6318 6319
1 6321 1 6327
2 6329 632a 2
6316 632b 1 6332
1 632d 2 6345
6347 3 6343 6344
6349 2 6352 6354
2 6356 6358 2
635a 635c 2 635e
6360 2 6362 6364
3 6369 636a 636b
2 6366 636d 2
6351 636f 1 6371
1 6373 2 633c
6374 1 6378 1
6337 2 6335 637c
2 6391 6392 1
6396 2 6394 6396
2 639e 639f 2
63a1 63a4 2 63a7
63aa 1 63ae 2
63b0 63b1 22 63b8
63b9 63ba 63bb 63bc
63bd 63be 63bf 63c0
63c1 63c2 63c3 63c4
63c5 63c6 63c7 63c8
63c9 63ca 63cb 63cc
63cd 63ce 63cf 63d0
63d1 63d2 63d3 63d4
63d5 63d6 63d7 63d8
63d9 1 63df 2
63dd 63df 2 63ea
63ec 3 63e8 63e9
63ee 2 63f7 63f9
2 63fb 63fd 2
63ff 6401 1 6409
2 640b 640c 2
6403 640e 2 6410
6412 2 6414 6416
2 6418 641a 2
641c 641e 2 63f6
6420 1 6422 1
6424 2 642e 6430
3 642c 642d 6432
2 643b 643d 2
643a 643f 1 6441
1 6443 3 644a
644b 644c 3 6425
6444 644e 1 6453
2 6451 6453 2
645e 6460 3 645c
645d 6462 2 646b
646d 2 646f 6471
2 6473 6475 1
647d 2 647f 6480
2 6477 6482 2
6484 6486 2 6488
648a 2 648c 648e
2 6490 6492 2
646a 6494 1 6496
1 6498 2 64a2
64a4 3 64a0 64a1
64a6 2 64af 64b1
2 64ae 64b3 1
64b5 1 64b7 3
64be 64bf 64c0 3
6499 64b8 64c2 1
64f0 2 64ef 64f0
1 64f8 1 64fe
2 6500 6501 2
64ed 6502 1 6509
1 6504 2 651c
651e 3 651a 651b
6520 2 6529 652b
2 652d 652f 2
6531 6533 2 6535
6537 2 6539 653b
3 6540 6541 6542
2 653d 6544 2
6528 6546 1 6548
1 654a 2 6513
654b 1 654f 1
650e 2 650c 6553
1 6556 3 6559
64c4 655a 17 61a8
61ab 61ae 61b1 61b4
61b7 61ba 61bd 61ec
621e 6301 6306 630b
637f 6383 6386 6389
638c 638f 63b2 63b5
63dc 655b 1 655d
2 6187 655e 2
6562 6563 1 6567
2 6565 6567 1
656a 1 657b 2
657a 657b 1 6583
1 6589 2 658b
658c 2 6578 658d
1 6594 1 658f
2 65a7 65a9 3
65a5 65a6 65ab 2
65b4 65b6 2 65b8
65ba 2 65bc 65be
2 65c0 65c2 2
65c4 65c6 3 65cb
65cc 65cd 2 65c8
65cf 2 65b3 65d1
1 65d3 1 65d5
2 659e 65d6 1
65da 1 6599 2
6597 65de 1 65e1
2 65e5 65e4 2
65ef 65f4 1 65fb
1 65f6 2 660e
6610 3 660c 660d
6612 2 661b 661d
2 661f 6621 2
6623 6625 2 6627
6629 2 662b 662d
3 6632 6633 6634
2 662f 6636 2
661a 6638 1 663a
1 663c 2 6605
663d 1 6641 1
6600 2 65fe 6645
2 664b 664c 1
6650 2 664e 6650
1 665f 2 665e
665f 1 6667 1
666d 2 666f 6670
2 665c 6671 1
6678 1 6673 2
668b 668d 3 6689
668a 668f 2 6698
669a 2 669c 669e
2 66a0 66a2 2
66a4 66a6 2 66a8
66aa 3 66af 66b0
66b1 2 66ac 66b3
2 6697 66b5 1
66b7 1 66b9 2
6682 66ba 1 66be
1 667d 2 667b
66c2 1 66c5 1
66c8 4 616b 65e6
6648 66c9 1 66cb
1 66d0 1 66e7
2 66e6 66e7 1
66ef 1 66f5 2
66f7 66f8 2 66e4
66f9 1 6700 1
66fb 2 6713 6715
3 6711 6712 6717
2 6720 6722 2
6724 6726 2 6728
672a 2 672c 672e
2 6730 6732 3
6737 6738 6739 2
6734 673b 2 671f
673d 1 673f 1
6741 2 670a 6742
1 6746 1 6705
2 6703 674a 2
6750 6751 1 6755
2 6753 6755 2
675f 6764 1 676b
1 6766 2 677e
6780 3 677c 677d
6782 2 678b 678d
2 678f 6791 2
6793 6795 2 6797
6799 2 679b 679d
3 67a2 67a3 67a4
2 679f 67a6 2
678a 67a8 1 67aa
1 67ac 2 6775
67ad 1 67b1 1
6770 2 676e 67b5
2 67bb 67bc 1
67c0 2 67be 67c0
1 67ce 2 67cd
67ce 1 67d6 1
67dc 2 67de 67df
2 67cb 67e0 1
67e7 1 67e2 2
67fa 67fc 3 67f8
67f9 67fe 2 6807
6809 2 680b 680d
2 680f 6811 2
6813 6815 2 6817
6819 3 681e 681f
6820 2 681b 6822
2 6806 6824 1
6826 1 6828 2
67f1 6829 1 682d
1 67ec 2 67ea
6831 1 683e 2
683d 683e 1 6846
1 684c 2 684e
684f 2 683b 6850
1 6857 1 6852
2 686a 686c 3
6868 6869 686e 2
6877 6879 2 687b
687d 2 687f 6881
2 6883 6885 2
6887 6889 3 688e
688f 6890 2 688b
6892 2 6876 6894
1 6896 1 6898
2 6861 6899 1
689d 1 685c 2
685a 68a1 2 6834
68a4 1 68a7 2
67b8 68a8 1 68aa
6 68b1 68b2 68b3
68b4 68b5 68b6 2
68d3 68d8 1 68df
1 68da 2 68f2
68f4 3 68f0 68f1
68f6 2 68ff 6901
2 6903 6905 2
6907 6909 2 690b
690d 2 690f 6911
3 6916 6917 6918
2 6913 691a 2
68fe 691c 1 691e
1 6920 2 68e9
6921 1 6925 1
68e4 2 68e2 6929
1 6934 2 6930
6934 1 6938 1
693f 1 6941 2
6944 6945 1 6949
2 6947 6949 1
695e 2 695d 695e
1 6966 1 696c
2 696e 696f 2
695b 6970 1 6977
1 6972 2 698a
698c 3 6988 6989
698e 2 6997 6999
2 699b 699d 2
699f 69a1 2 69a3
69a5 2 69a7 69a9
3 69ae 69af 69b0
2 69ab 69b2 2
6996 69b4 1 69b6
1 69b8 2 6981
69b9 1 69bd 1
697c 2 697a 69c1
1 69c4 1 69db
2 69da 69db 1
69e3 1 69e9 2
69eb 69ec 2 69d8
69ed 1 69f4 1
69ef 2 6a07 6a09
3 6a05 6a06 6a0b
2 6a14 6a16 2
6a18 6a1a 2 6a1c
6a1e 2 6a20 6a22
2 6a24 6a26 3
6a2b 6a2c 6a2d 2
6a28 6a2f 2 6a13
6a31 1 6a33 1
6a35 2 69fe 6a36
1 6a3a 1 69f9
2 69f7 6a3e 1
6a41 2 6a44 6a45
3 6a48 6a49 6a4a
1 6a4e 2 6a4c
6a4e 4 6a56 6a57
6a58 6a59 1 6a5c
1 6a5e 3 6942
6a46 6a5f 1 6a61
1 6a63 2 6a6c
6a6d 1 6a71 2
6a6f 6a71 1 6a79
1 6a7b 7 674d
68ab 68ae 68b9 692c
6a62 6a7c 1 6a7e
1 6a80 2 6a86
6a87 1 6a8b 2
6a89 6a8b 6 6a95
6a96 6a97 6a98 6a99
6a9a 2 6ab7 6abc
1 6ac3 1 6abe
2 6ad6 6ad8 3
6ad4 6ad5 6ada 2
6ae3 6ae5 2 6ae7
6ae9 2 6aeb 6aed
2 6aef 6af1 2
6af3 6af5 3 6afa
6afb 6afc 2 6af7
6afe 2 6ae2 6b00
1 6b02 1 6b04
2 6acd 6b05 1
6b09 1 6ac8 2
6ac6 6b0d 2 6b13
6b14 1 6b18 2
6b16 6b18 1 6b2d
2 6b2c 6b2d 1
6b35 1 6b3b 2
6b3d 6b3e 2 6b2a
6b3f 1 6b46 1
6b41 2 6b59 6b5b
3 6b57 6b58 6b5d
2 6b66 6b68 2
6b6a 6b6c 2 6b6e
6b70 2 6b72 6b74
2 6b76 6b78 3
6b7d 6b7e 6b7f 2
6b7a 6b81 2 6b65
6b83 1 6b85 1
6b87 2 6b50 6b88
1 6b8c 1 6b4b
2 6b49 6b90 1
6b93 1 6baa 2
6ba9 6baa 1 6bb2
1 6bb8 2 6bba
6bbb 2 6ba7 6bbc
1 6bc3 1 6bbe
2 6bd6 6bd8 3
6bd4 6bd5 6bda 2
6be3 6be5 2 6be7
6be9 2 6beb 6bed
2 6bef 6bf1 2
6bf3 6bf5 3 6bfa
6bfb 6bfc 2 6bf7
6bfe 2 6be2 6c00
1 6c02 1 6c04
2 6bcd 6c05 1
6c09 1 6bc8 2
6bc6 6c0d 1 6c10
2 6c13 6c14 3
6c17 6c18 6c19 1
6c1d 2 6c1b 6c1d
2 6c22 6c23 1
6c27 2 6c25 6c27
4 6c31 6c32 6c33
6c34 1 6c37 1
6c39 5 6a92 6a9d
6b10 6c15 6c3a 1
6c3c 1 6c40 1
6c46 2 6c44 6c46
1 6c5b 2 6c5a
6c5b 1 6c63 1
6c69 2 6c6b 6c6c
2 6c58 6c6d 1
6c74 1 6c6f 2
6c87 6c89 3 6c85
6c86 6c8b 2 6c94
6c96 2 6c98 6c9a
2 6c9c 6c9e 2
6ca0 6ca2 2 6ca4
6ca6 3 6cab 6cac
6cad 2 6ca8 6caf
2 6c93 6cb1 1
6cb3 1 6cb5 2
6c7e 6cb6 1 6cba
1 6c79 2 6c77
6cbe 1 6cc1 1
6cc4 1 6cca 2
6cc8 6cca 1 6cd1
1 6cd3 2 6cdd
6cdf 3 6cdb 6cdc
6ce1 2 6cea 6cec
2 6cee 6cf0 2
6cf2 6cf4 1 6cfc
2 6cfe 6cff 2
6cf6 6d01 2 6d03
6d05 2 6d07 6d09
2 6d0b 6d0d 2
6d0f 6d11 2 6ce9
6d13 1 6d15 1
6d17 3 6d1e 6d1f
6d20 5c 4e0 4ff
502 505 508 50b
50e 51b 53b 53e
541 544 547 54a
54f 562 567 5c4
63e 6a7 722 725
784 7fe 87d 8f8
959 9d4 a33 a45
abf ac2 acd ad8
ae3 b49 baf bb3
bbe e2e e31 e34
e37 e3a e3d e40
e43 e48 e5b f69
fc6 1026 108c 1690
1700 1711 1714 1717
171a 171f 179b 179e
17a1 1801 1805 186b
18cd 277e 2a81 2a8d
2a90 2a93 2a96 2a99
2a9c 2a9f 2aa2 2aa5
2aa8 6085 60e2 615c
615f 66cc 66cf 6a7f
6c3d 6c43 6cc5 6cd4
6d18 6d22 2 6d2f
6d31 3 6d2d 6d2e
6d33 2 6d3c 6d3e
2 6d3b 6d40 2
6d47 6d4b 2 6d4d
6d4f 2 6d51 6d55
2 6d46 6d57 2
6d42 6d59 1 6d5b
3 6d5c 6d67 6d6b
1 6d26 2 6d7e
6d80 3 6d7c 6d7d
6d82 2 6d8b 6d8d
2 6d8a 6d8f 2
6d96 6d98 2 6d9a
6d9c 3 6da1 6da2
6da3 2 6d9e 6da5
2 6d95 6da7 2
6d91 6da9 1 6dab
4 6d75 6dac 6db5
6db9 1 6dbd 1
6d70 2 6d6e 6dc1
7d 4e 58 5f
66 6d 74 7b
82 89 90 97
9e a5 ac b3
ba c1 c6 cb
d0 d5 dc e3
e8 ed f2 f9
100 105 10a 10f
114 11b 122 129
130 137 13d 143
149 14f 155 15b
161 167 16d 173
179 17f 185 18b
191 197 19d 1a3
1a9 1af 1b5 1bb
1c1 1c7 1cd 1d3
1d9 1df 1e5 1eb
1f1 1f7 1fd 203
209 20f 215 21b
221 227 22d 233
239 240 247 24d
253 25a 260 267
26e 274 27a 280
286 28c 292 298
29e 2a4 2aa 2b0
2b6 2bc 2c2 2c8
2cf 2d6 2dd 2e3
2ea 2f0 2f6 2fc
302 307 30c 312
318 31e 324 32a
32f 335 342 356
3ce 3d8 
1
4
0 
6dc8
0
1
280
14c
8e
0 1 1 1 1 5 1 7
1 9 1 b 1 d 1 f
1 11 1 13 1 15 1 17
1 19 1 1b 1 1d 1 1f
1 21 1 23 1 25 1 27
1 29 1 2b 1 2d 1 2f
1 31 1 33 1 35 1 37
1 39 1 3b 1 3d 1 3f
1 41 1 43 1 45 1 47
1 49 1 4b 1 4d 1 4f
1 51 1 53 1 55 1 57
1 59 1 5b 1 5d 1 5f
1 61 1 63 1 65 1 67
1 69 1 6b 1 6d 1 6f
70 6f 72 6f 74 6f 76 6f
78 6f 7a 6f 7c 6f 7e 6f
80 6f 82 6f 84 6f 86 6f
88 6f 8a 6f 8c 6f 8e 6f
90 6f 92 6f 94 6f 96 6f
98 6f 9a 6f 9c 6f 9e 6f
a0 6f a2 6f a4 6f a6 6f
a8 6f aa 6f ac 6f ae 6f
b0 6f b2 6f b4 6f b6 6f
b8 6f ba 6f bc 6f be 6f
c0 6f c2 6f c4 6f c6 6f
c8 6f ca 6f cc 6f ce 6f
d0 6f d2 6f d4 6f d6 6f
d8 6f da 6f dc 6f de 6f
e0 6f e2 6f e4 6f e6 6f
e8 6f ea 6f ec 6f ee 6f
f0 6f f2 6f f4 6f f6 6f
f8 6f fa 6f fc 6f fe 6f
100 6f 102 6f 104 6f 106 6f
108 6f 10a 6f 10c 6f 10e 6f
110 6f 112 6f 114 6f 116 6f
118 6f 11a 6f 11c 6f 11e 6f
120 6f 122 6f 124 6f 126 6f
128 1 12a 1 12c 1 12e 1
130 1 132 1 134 1 136 1
138 1 13a 1 13c 1 13e 1
140 1 142 1 144 1 146 1
148 1 14a 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3b 1 0
2e5 1 0
27c 1 0
33 1 0
25c 1 0
28e 1 0
309 1 0
294 1 0
2ec 1 0
37 1 0
111 1 0
5a 1 0
19f 1 0
24f 1 0
1bd 1 0
151 1 0
c8 1 0
84 1 0
269 1 0
2f 1 0
29a 1 0
2ac 1 0
262 1 0
92 1 0
27 1 0
2df 1 0
223 1 0
320 1 0
50 1 0
b 1 0
199 1 0
a0 1 0
23 1 0
1ff 1 0
f4 1 0
116 1 0
99 1 0
607f 6f 12a
1d5 1 0
10c 1 0
30e 1 0
1ed 1 0
1db 1 0
76 1 0
255 1 0
1b7 1 0
32c 1 0
1f3 1 0
46 1 0
1cf 1 0
13f 1 0
e5 1 0
35c 1 4
276 1 0
22f 1 0
211 1 0
15d 1 0
2c4 1 0
288 1 0
1b 1 0
17b 1 0
348 1 3
242 1 0
14b 1 0
102 1 0
cd 1 0
338 1 2
23b 1 0
c3 1 0
17 1 0
235 1 0
16f 1 0
2a0 1 0
8b 1 0
68 1 0
3 1 0
20b 1 0
2b8 1 0
2 0 1
304 1 0
1a5 1 0
2ca 1 0
282 1 0
314 1 0
12b 1 0
107 1 0
d2 1 0
270 1 0
163 1 0
2a6 1 0
1b1 1 0
145 1 0
139 1 0
2b 1 0
2d8 1 0
2d1 1 0
21d 1 0
a7 1 0
61 1 0
fb 1 0
331 1 0
f 1 0
7 1 0
175 1 0
169 1 0
326 1 0
1c3 1 0
18d 1 0
d7 1 0
2f2 1 0
229 1 0
205 1 0
bc 1 0
124 1 0
31a 1 0
2be 1 0
2b2 1 0
1f9 1 0
157 1 0
249 1 0
1e1 1 0
ea 1 0
b5 1 0
ae 1 0
1ab 1 0
7d 1 0
2fe 1 0
1c9 1 0
1f 1 0
217 1 0
1e7 1 0
ef 1 0
11d 1 0
187 1 0
6f 1 0
132 1 0
181 1 0
13 1 0
3d3 1 0
193 1 0
de 1 0
2f8 1 0
0

/
SHOW ERRORS FUNCTION SP_A_RESTOPROF;
ALTER FUNCTION SP_A_RESTOPROF COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_RATES
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_RATES ==
CREATE OR REPLACE FUNCTION SP_U_RATES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
5c
2 :e:
1FUNCTION:
1SP_U_RATES:
1ID001:
1VARCHAR2:
1REG_COST:
1NUMBER:
1SPEC_COST:
1REG_RATE:
1SPEC_RATE:
1RATE_ADJUSTMENT001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_RES_ID:
1H_REG_COST:
10:
1H_REG_RATE:
1H_SPEC_COST:
1H_SPEC_RATE:
1H_RATE_ADJUSTMENT:
1H_FLAG:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_RATES(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
134:
1+:
1FPUT:
1               ENTER:: SP_U_RATES(35) :: cplan.sql(14212) :: :
1IS NULL:
139:
1        RETURN_ERROR:: SP_U_RATES(40) :: cplan.sql(14217) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1 ID:: :
142:
1                EXIT:: SP_U_RATES(43) :: cplan.sql(14220) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1SC_STATE:
1FC_U_RATES:
1=:
1100:
14:
166:
1       RETURN_STATUS:: SP_U_RATES(67) :: cplan.sql(14244) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
116:
173:
1           EXCEPTION:: SP_U_RATES(74) :: cplan.sql(14251) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
185:
1           EXCEPTION:: SP_U_RATES(86) :: cplan.sql(14263) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2a9
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c a0 51 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :2 a0 6b :9 a0 a5
b d :2 a0 6b 7e 51 b4 2e
:2 a0 6b 51 d b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 a0 6b :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e :2 a0 6b b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :9 a0 12a e9 dd
:2 a0 65 b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c :7 a0 12a e9 dd :2 a0 65
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 68 4f 1d 17 b5 
2a9
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d 7c
a2 a6 aa ae b1 b5 d2 bd
c1 c4 c5 cd bc ef dd b9
e1 e2 ea dc 10b fa fe d9
106 f9 127 116 11a f6 122 115
143 132 136 112 13e 131 15f 14e
152 12e 15a 14d 17b 16a 16e 14a
176 169 197 186 18a 166 192 185
1b7 1a2 1a6 182 1aa 1b2 1a1 1be
1c2 19e 1c6 1ca 1ce 1d1 1d6 1d7
1 1d9 1de 1e2 1e6 1e9 1ee 1f2
1f6 1f9 1fe 1ff 201 206 209 20d
20e 213 218 21b 220 221 226 229
22d 22e 233 236 23b 23c 241 244
249 24a 24f 252 256 25a 25e 25f
261 266 267 269 26a 26f 272 277
278 27d 280 284 288 28c 28d 28f
294 295 297 298 29d 2a0 2a5 2a6
2ab 2ae 2b2 2b6 2ba 2bb 2bd 2c2
2c3 2c5 2c6 2cb 2ce 2d3 2d4 2d9
2dc 2e0 2e4 2e8 2e9 2eb 2f0 2f1
2f3 2f4 2f9 2fc 301 302 307 30a
30e 312 316 317 319 31e 31f 321
322 327 32a 32f 330 335 338 33d
33e 343 346 34a 34b 350 353 358
359 35e 361 366 367 36c 36d 372
374 378 37b 37f 383 386 38a 38e
391 394 399 39c 39f 3a2 3a3 3a8
3a9 1 3ab 3b0 3b4 3b8 3bb 3c0
3c5 3c8 3cc 3cd 3d2 3d3 3d8 3da
3de 3e1 3e5 3e8 3e9 3ee 3f1 3f5
3f9 3fc 400 404 407 40a 40f 412
415 418 419 41e 41f 1 421 426
42a 42e 431 436 43b 43e 442 443
448 44b 450 451 456 459 45e 45f
464 467 46b 46f 473 477 47a 47b
47d 482 483 485 486 48b 48e 493
494 499 49c 4a1 4a2 4a7 4aa 4ae
4af 4b4 4b7 4bc 4bd 4c2 4c3 4c8
4ca 4ce 4d1 4d5 4d9 4dc 4e0 4e4
4e7 4ea 4ef 4f2 4f5 4f8 4f9 4fe
4ff 1 501 506 50a 50e 511 516
51b 51e 522 523 528 529 52e 530
534 537 53b 53f 542 546 54a 54d
551 555 556 55b 55d 561 564 568
56b 56f 573 577 57b 57f 583 587
58b 58f 593 597 59b 59f 5a3 5a7
5ab 5af 5b3 5b7 5bb 5bf 5c3 5c7
5cb 5ce 5d2 5d6 5da 5de 5e2 5e6
5ea 5ee 5f2 5f3 5f5 5f9 5fd 601
604 607 60a 60b 610 614 618 61b
61e 622 624 628 62b 62f 633 636
63a 63e 641 644 649 64c 64f 652
653 658 659 1 65b 660 664 668
66b 670 675 678 67c 67d 682 685
68a 68b 690 693 698 699 69e 6a1
6a5 6a9 6ad 6b1 6b4 6b5 6b7 6bc
6bd 6bf 6c0 6c5 6c8 6cd 6ce 6d3
6d6 6db 6dc 6e1 6e4 6e8 6e9 6ee
6f1 6f6 6f7 6fc 6fd 702 704 708
70b 70f 713 716 71a 71e 721 725
729 72a 72f 731 735 739 73c 740
744 747 74b 74f 752 755 75a 75d
760 763 764 769 76a 1 76c 771
775 779 77c 781 786 789 78d 78e
793 794 799 79d 7a1 7a4 7a9 7ae
7b1 7b5 7b9 7bc 7bd 7c2 7c5 7ca
7cb 7d0 7d3 7d7 7db 7de 7df 7e4
7e5 7ea 7ec 7f0 7f3 7f7 7fb 7ff
803 807 80b 80f 813 817 823 828
82c 830 834 838 83a 83b 840 1
844 848 84c 84f 853 857 85b 85f
862 866 86a 86d 870 875 878 87b
87e 87f 884 885 1 887 88c 890
894 897 89c 8a1 8a4 8a8 8a9 8ae
8af 8b4 8b8 8bc 8bf 8c4 8c9 8cc
8d0 8d1 8d6 8d9 8de 8df 8e4 8e7
8eb 8ef 8f2 8f5 8f6 8f8 8f9 8fe
8ff 904 906 90a 90d 911 915 919
91d 921 925 929 935 93a 93e 942
946 94a 94c 950 952 95e 960 962
963 968 96c 96e 97a 97e 980 981
98a 
2a9
2
0 1 a 6 c :3 6 f :3 6
10 :3 6 f :3 6 10 :3 6 19 :3 6
10 :2 6 1 3 a 13 a :2 1
4 9 12 11 :2 9 :2 4 d 16
15 :2 d :2 4 :2 f 19 f :2 4 :2 f
19 f :2 4 :2 10 1a 10 :2 4 :2 10
1a 10 :2 4 :2 16 25 16 :2 4 :2 b
1a b :2 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 52 58 5b :2 52
69 7d 8 :2 69 d 10 :2 69 16
19 :2 69 b e :2 69 13 16 1f
27 :2 1f 32 :2 16 :2 69 b e :2 69
13 16 1f 27 :2 1f 33 :2 16 :2 69
b e :2 69 13 16 1f 27 :2 1f
32 :2 16 :2 69 b e :2 69 13 16
1f 27 :2 1f 33 :2 16 :2 69 b e
:2 69 13 16 1f 27 :2 1f 3c :2 16
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 28 2b :2 69 30 33 :2 69
:2 7 48 :2 4 7 :2 11 23 :2 2d 39
3c 4a 4c 4d :2 4a :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 50 :2 4
:4 8 7 a :2 14 26 :2 30 3c 40
4e 50 51 :2 4e :2 26 :3 a :2 10 15
21 5e 61 :2 21 6e 71 :2 21 75
78 :2 21 82 85 8e 96 :2 9f :2 8e
b0 :2 85 :2 21 b8 bb :2 21 c3 c6
:2 21 cb ce :2 21 d4 d7 :2 21 :2 a
54 :2 7 a :2 14 26 :2 30 3c 3f
4d 4f 50 :2 4d :2 26 :3 a :2 10 15
21 5e 61 :2 21 :2 a 53 :3 7 :2 12
26 :2 2f 3f 46 :2 7 17 :3 4 e
:2 4 c :2 4 10 :2 4 12 :2 4 13
:2 4 12 :2 4 13 :2 4 19 :2 4 :2 d
19 24 2a 36 43 4f 23 36
40 :2 19 4 7 :2 10 19 1b :2 19
7 :2 10 1c 7 1f :2 4 7 :2 11
23 :2 2d 39 3c 4a 4c 4d :2 4a
:2 23 :3 7 :2 d 12 1e 5b 5e :2 1e
6b 6e :2 1e 72 75 :2 1e 7f 82
8b 93 :2 9c :2 8b a7 :2 82 :2 1e af
b2 :2 1e ba bd :2 1e c2 c5 :2 1e
cb ce :2 1e :2 7 50 :3 4 :2 f 21
:2 2a 34 3b :2 4 1 9 12 9
a :2 14 26 :2 30 3c 40 4e 50
51 :2 4e :2 26 :3 a :2 10 15 21 5e
61 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 54 :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 4b 4d
4e :2 4b :2 23 :3 7 :2 d 12 1e 5b
5e :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 51 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
2a9
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 2 :4 a :2 1
:7 c :7 d :6 e :6 f
:6 10 :6 11 :6 12 :6 13
:7 15 :b 17 :11 18 19
:2 18 :2 19 :2 18 :2 19
:2 18 :2 1a :2 18 :9 1a
:2 18 :2 1b :2 18 :9 1b
:2 18 :2 1c :2 18 :9 1c
:2 18 :2 1d :2 18 :9 1d
:2 18 :2 1e :2 18 :9 1e
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :2 18 :2 1f
:2 18 :2 1f :4 18 :3 17
:11 22 :b 23 :3 22 :5 26
:11 27 :30 28 :3 27 :11 2a
:b 2b :3 2a :a 2d :3 26
:3 30 :3 33 :3 34 :3 35
:3 36 :3 37 :3 38 :3 39
:9 3b :3 3c :3 3b :7 3e
:5 3f :3 3e :11 42 :30 43
:3 42 :a 45 16 :3 48
:11 49 :b 4a :17 4b :3 49
:2 4d :3 4e :3 4f 50
4e 4d 4e :3 51
:3 48 :2 52 :5 54 :11 55
:b 56 :18 57 :3 55 :2 59
5a :3 5b 5c 5a
59 5a :3 5d :2 53
:6 52 47 :7 1 
98c
4
:3 0 1 :3 0 2
:a 0 2a4 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d 7c 0
b 6 :3 0 8
:7 0 11 10 :3 0
6 :3 0 9 :7 0
15 14 :3 0 11
:2 0 f b :3 0
a :7 0 19 18
:3 0 4 :3 0 c
:7 0 1d 1c :3 0
d :3 0 e :3 0
f :2 0 4 21
22 0 1f 23
0 2a4 2 24
:2 0 11 :2 0 1b
4 :3 0 11 :2 0
19 27 29 :6 0
2c 2a 0 2a2
0 10 :6 0 14
:2 0 1f 4 :3 0
1d 2e 30 :6 0
33 31 0 2a2
0 12 :6 0 14
:2 0 21 6 :3 0
35 :7 0 39 36
37 2a2 0 13
:6 0 14 :2 0 23
6 :3 0 3b :7 0
3f 3c 3d 2a2
0 15 :6 0 14
:2 0 25 6 :3 0
41 :7 0 45 42
43 2a2 0 16
:6 0 14 :2 0 27
6 :3 0 47 :7 0
4b 48 49 2a2
0 17 :6 0 14
:2 0 29 b :3 0
4d :7 0 51 4e
4f 2a2 0 18
:6 0 59 5a 0
2b b :3 0 53
:7 0 57 54 55
2a2 0 19 :6 0
5f 60 0 2d
e :3 0 f :2 0
4 5b :7 0 5e
5c 0 2a2 0
1a :6 0 1b :3 0
1c :3 0 1b :3 0
1d :3 0 62 63
0 2 :4 0 2f
64 66 61 68
67 :2 0 1e :3 0
1f :3 0 6a 6b
0 20 :4 0 1b
:3 0 21 :3 0 6e
6f 0 2 :4 0
31 70 72 22
:4 0 23 :2 0 24
:3 0 33 75 77
:3 0 25 :4 0 23
:2 0 26 :4 0 36
7a 7c :3 0 23
:2 0 3 :3 0 39
7e 80 :3 0 23
:2 0 26 :4 0 3c
82 84 :3 0 23
:2 0 27 :4 0 3f
86 88 :3 0 23
:2 0 28 :3 0 29
:3 0 5 :3 0 42
8c 8e 2a :4 0
44 8b 91 47
8a 93 :3 0 23
:2 0 27 :4 0 4a
95 97 :3 0 23
:2 0 28 :3 0 29
:3 0 7 :3 0 4d
9b 9d 2a :4 0
4f 9a a0 52
99 a2 :3 0 23
:2 0 27 :4 0 55
a4 a6 :3 0 23
:2 0 28 :3 0 29
:3 0 8 :3 0 58
aa ac 2a :4 0
5a a9 af 5d
a8 b1 :3 0 23
:2 0 27 :4 0 60
b3 b5 :3 0 23
:2 0 28 :3 0 29
:3 0 9 :3 0 63
b9 bb 2a :4 0
65 b8 be 68
b7 c0 :3 0 23
:2 0 27 :4 0 6b
c2 c4 :3 0 23
:2 0 28 :3 0 29
:3 0 a :3 0 6e
c8 ca 2a :4 0
70 c7 cd 73
c6 cf :3 0 23
:2 0 27 :4 0 76
d1 d3 :3 0 23
:2 0 26 :4 0 79
d5 d7 :3 0 23
:2 0 c :3 0 7c
d9 db :3 0 23
:2 0 26 :4 0 7f
dd df :3 0 23
:2 0 2b :4 0 82
e1 e3 :3 0 85
6c e5 :2 0 e7
8a e8 69 e7
0 e9 8c 0
202 1b :3 0 1c
:3 0 ea eb 0
1b :3 0 2c :3 0
ed ee 0 2d
:2 0 2 :4 0 2e
:2 0 2f :2 0 2d
:2 0 8e f3 f5
:3 0 91 ef f7
ec f9 f8 :2 0
1e :3 0 30 :3 0
fb fc 0 20
:4 0 31 :4 0 23
:2 0 24 :3 0 95
100 102 :3 0 98
fd 104 :2 0 106
9b 107 fa 106
0 108 9d 0
202 3 :3 0 32
:2 0 9f 10a 10b
:3 0 10c :2 0 1b
:3 0 1c :3 0 10e
10f 0 1b :3 0
2c :3 0 111 112
0 11 :2 0 2
:4 0 33 :2 0 2f
:2 0 2d :2 0 a1
117 119 :3 0 a4
113 11b 110 11d
11c :2 0 1e :3 0
30 :3 0 11f 120
0 20 :4 0 34
:4 0 23 :2 0 24
:3 0 a8 124 126
:3 0 23 :2 0 35
:4 0 ab 128 12a
:3 0 23 :2 0 36
:4 0 ae 12c 12e
:3 0 23 :2 0 28
:3 0 29 :3 0 37
:3 0 38 :3 0 133
134 0 b1 132
136 2a :4 0 b3
131 139 b6 130
13b :3 0 23 :2 0
39 :4 0 b9 13d
13f :3 0 23 :2 0
26 :4 0 bc 141
143 :3 0 23 :2 0
3 :3 0 bf 145
147 :3 0 23 :2 0
26 :4 0 c2 149
14b :3 0 c5 121
14d :2 0 14f c8
150 11e 14f 0
151 ca 0 17b
1b :3 0 1c :3 0
152 153 0 1b
:3 0 2c :3 0 155
156 0 2d :2 0
2 :4 0 3a :2 0
2f :2 0 2d :2 0
cc 15b 15d :3 0
cf 157 15f 154
161 160 :2 0 1e
:3 0 30 :3 0 163
164 0 20 :4 0
3b :4 0 23 :2 0
24 :3 0 d3 168
16a :3 0 d6 165
16c :2 0 16e d9
16f 162 16e 0
170 db 0 17b
3c :3 0 3d :3 0
171 172 0 37
:3 0 38 :3 0 174
175 0 3 :3 0
3e :3 0 dd 173
179 :2 0 17b e1
17c 10d 17b 0
17d e5 0 202
19 :3 0 2d :2 0
17e 17f 0 202
10 :3 0 3 :3 0
181 182 0 202
12 :3 0 c :3 0
184 185 0 202
13 :3 0 5 :3 0
187 188 0 202
16 :3 0 7 :3 0
18a 18b 0 202
15 :3 0 8 :3 0
18d 18e 0 202
17 :3 0 9 :3 0
190 191 0 202
18 :3 0 a :3 0
193 194 0 202
e :3 0 3f :3 0
196 197 0 40
:3 0 10 :3 0 13
:3 0 16 :3 0 15
:3 0 17 :3 0 18
:3 0 12 :3 0 19
:3 0 e7 199 1a2
198 1a3 0 202
e :3 0 3f :3 0
1a5 1a6 0 41
:2 0 42 :2 0 f2
1a8 1aa :3 0 e
:3 0 3f :3 0 1ac
1ad 0 14 :2 0
1ae 1af 0 1b1
f5 1b2 1ab 1b1
0 1b3 f7 0
202 1b :3 0 1c
:3 0 1b4 1b5 0
1b :3 0 2c :3 0
1b7 1b8 0 43
:2 0 2 :4 0 44
:2 0 2f :2 0 2d
:2 0 f9 1bd 1bf
:3 0 fc 1b9 1c1
1b6 1c3 1c2 :2 0
1e :3 0 30 :3 0
1c5 1c6 0 20
:4 0 45 :4 0 23
:2 0 24 :3 0 100
1ca 1cc :3 0 23
:2 0 35 :4 0 103
1ce 1d0 :3 0 23
:2 0 36 :4 0 106
1d2 1d4 :3 0 23
:2 0 28 :3 0 29
:3 0 e :3 0 3f
:3 0 1d9 1da 0
109 1d8 1dc 2a
:4 0 10b 1d7 1df
10e 1d6 1e1 :3 0
23 :2 0 39 :4 0
111 1e3 1e5 :3 0
23 :2 0 26 :4 0
114 1e7 1e9 :3 0
23 :2 0 3 :3 0
117 1eb 1ed :3 0
23 :2 0 26 :4 0
11a 1ef 1f1 :3 0
11d 1c7 1f3 :2 0
1f5 120 1f6 1c4
1f5 0 1f7 122
0 202 3c :3 0
46 :3 0 1f8 1f9
0 e :3 0 3f
:3 0 1fb 1fc 0
3 :3 0 3e :3 0
124 1fa 200 :2 0
202 128 2a3 e
:3 0 47 :2 0 4
203 204 0 1b
:3 0 1c :3 0 206
207 0 1b :3 0
2c :3 0 209 20a
0 48 :2 0 2
:4 0 49 :2 0 2f
:2 0 2d :2 0 138
20f 211 :3 0 13b
20b 213 208 215
214 :2 0 1e :3 0
30 :3 0 217 218
0 20 :4 0 4a
:4 0 23 :2 0 24
:3 0 13f 21c 21e
:3 0 142 219 220
:2 0 239 1e :3 0
30 :3 0 222 223
0 20 :4 0 4b
:4 0 23 :2 0 e
:3 0 4c :3 0 228
229 0 145 227
22b :3 0 23 :2 0
39 :4 0 148 22d
22f :3 0 23 :2 0
e :3 0 4d :3 0
232 233 0 14b
231 235 :3 0 14e
224 237 :2 0 239
151 23a 216 239
0 23b 154 0
24b 4e :3 0 1a
:3 0 e :3 0 4c
:3 0 4f :3 0 e
:3 0 4d :3 0 50
:3 0 51 :4 0 52
1 :a 0 247 :2 0
24b 23d 245 :2 0
d :3 0 1a :3 0
249 :2 0 24b 156
24d 15a 24c 24b
:2 0 2a1 53 :3 0
e :3 0 3f :3 0
250 251 0 54
:3 0 252 253 0
299 1b :3 0 1c
:3 0 255 256 0
1b :3 0 2c :3 0
258 259 0 48
:2 0 2 :4 0 55
:2 0 2f :2 0 2d
:2 0 15c 25e 260
:3 0 15f 25a 262
257 264 263 :2 0
1e :3 0 30 :3 0
266 267 0 20
:4 0 56 :4 0 23
:2 0 24 :3 0 163
26b 26d :3 0 166
268 26f :2 0 289
1e :3 0 30 :3 0
271 272 0 20
:4 0 57 :4 0 23
:2 0 54 :3 0 169
276 278 :3 0 23
:2 0 58 :4 0 16c
27a 27c :3 0 23
:2 0 59 :3 0 5a
:3 0 2d :2 0 5b
:2 0 16f 27f 283
173 27e 285 :3 0
176 273 287 :2 0
289 179 28a 265
289 0 28b 17c
0 299 4e :3 0
1a :3 0 4f :3 0
e :3 0 4d :3 0
50 :3 0 51 :4 0
5c 1 :a 0 295
:2 0 299 28d 293
:2 0 d :3 0 1a
:3 0 297 :2 0 299
17e 29c :3 0 29c
0 29c 29b 299
29a :6 0 29e 1
:3 0 183 2a0 185
29f 29e :2 0 2a1
187 :2 0 2a3 18a
2a3 2a2 202 2a1
:6 0 2a4 :2 0 2
24 2a3 2a7 :3 0
2a6 2a4 2a8 :8 0

194
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 7
6 a e 12
16 1a 1e 1
28 1 26 1
2f 1 2d 1
34 1 3a 1
40 1 46 1
4c 1 52 1
58 1 65 1
71 2 74 76
2 79 7b 2
7d 7f 2 81
83 2 85 87
1 8d 2 8f
90 2 89 92
2 94 96 1
9c 2 9e 9f
2 98 a1 2
a3 a5 1 ab
2 ad ae 2
a7 b0 2 b2
b4 1 ba 2
bc bd 2 b6
bf 2 c1 c3
1 c9 2 cb
cc 2 c5 ce
2 d0 d2 2
d4 d6 2 d8
da 2 dc de
2 e0 e2 4
6d 73 78 e4
1 e6 1 e8
2 f2 f4 3
f0 f1 f6 2
ff 101 2 fe
103 1 105 1
107 1 109 2
116 118 3 114
115 11a 2 123
125 2 127 129
2 12b 12d 1
135 2 137 138
2 12f 13a 2
13c 13e 2 140
142 2 144 146
2 148 14a 2
122 14c 1 14e
1 150 2 15a
15c 3 158 159
15e 2 167 169
2 166 16b 1
16d 1 16f 3
176 177 178 3
151 170 17a 1
17c 8 19a 19b
19c 19d 19e 19f
1a0 1a1 1 1a9
2 1a7 1a9 1
1b0 1 1b2 2
1bc 1be 3 1ba
1bb 1c0 2 1c9
1cb 2 1cd 1cf
2 1d1 1d3 1
1db 2 1dd 1de
2 1d5 1e0 2
1e2 1e4 2 1e6
1e8 2 1ea 1ec
2 1ee 1f0 2
1c8 1f2 1 1f4
1 1f6 3 1fd
1fe 1ff f e9
108 17d 180 183
186 189 18c 18f
192 195 1a4 1b3
1f7 201 2 20e
210 3 20c 20d
212 2 21b 21d
2 21a 21f 2
226 22a 2 22c
22e 2 230 234
2 225 236 2
221 238 1 23a
3 23b 246 24a
1 205 2 25d
25f 3 25b 25c
261 2 26a 26c
2 269 26e 2
275 277 2 279
27b 3 280 281
282 2 27d 284
2 274 286 2
270 288 1 28a
4 254 28b 294
298 1 29c 1
24f 2 24d 2a0
9 2b 32 38
3e 44 4a 50
56 5d 
1
4
0 
2a7
0
1
14
2
11
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
7 1 0
4c 1 0
13 1 0
1b 1 0
40 1 0
3a 1 0
3 1 0
f 1 0
26 1 0
b 1 0
2d 1 0
17 1 0
52 1 0
46 1 0
34 1 0
58 1 0
0

/
SHOW ERRORS FUNCTION SP_U_RATES;
ALTER FUNCTION SP_U_RATES COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_RATES_EDITED
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_RATES_EDITED ==
CREATE OR REPLACE FUNCTION SP_U_RATES_EDITED wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
74
2 :e:
1FUNCTION:
1SP_U_RATES_EDITED:
1ID001:
1VARCHAR2:
1RATES_EDITED001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_RESOURCE_ID:
1H_REG_COST:
1NUMBER:
10:
1H_SPEC_COST:
1H_REG_RATE:
1H_SPEC_RATE:
1H_FLAG:
1H_OLD_REG_COST:
1H_OLD_REG_SALE:
1H_OLD_SPEC_COST:
1H_OLD_SPEC_SALE:
1H_RATE_ID:
1H_RATE_ADJUSTMENT:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_RATES_EDITED(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
131:
1+:
1FPUT:
1               ENTER:: SP_U_RATES_EDITED(32) :: cplan.sql(14319) :: :
1REGULAR_COST:
1REGULAR_RATE:
1SPECIAL_COST:
1SPECIAL_RATE:
1RATE_ADJUSTMENT:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT REGULAR_COST, REGULAR_RATE,:n      SPECIAL_COST, SPECIAL_RATE, RATE_AD+
1JUSTMENT:n      INTO   h_old_reg_cost, h_old_reg_sale ,:n      h_old_spec_cos+
1t,h_old_spec_sale, h_rate_adjustment:n      FROM TASK_ASSIGNMENTS:n      WHER+
1E TSK_ASSIGNMENT_ID = id001:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
153:
1           EXCEPTION:: SP_U_RATES_EDITED(54) :: cplan.sql(14341) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1RATE_ID:
1RESOURCES:
1RESOURCE_ID:
1SELECT RATE_ID INTO h_rate_id:n      FROM RESOURCES:n      WHERE RESOURCE_ID +
1= res_id001:
170:
1           EXCEPTION:: SP_U_RATES_EDITED(71) :: cplan.sql(14358) :: :
1REGULAR_SALE:
1SPECIAL_SALE:
1RATES:
1SELECT REGULAR_COST, REGULAR_SALE,:n      SPECIAL_COST, SPECIAL_SALE:n      I+
1NTO   h_reg_cost, h_reg_rate ,:n      h_spec_cost,h_spec_rate:n      FROM RAT+
1ES:n      WHERE RATE_ID = h_rate_id:
190:
1           EXCEPTION:: SP_U_RATES_EDITED(91) :: cplan.sql(14378) :: :
1RATES_EDITED:
1BITAND:
1UPDATE TASK_ASSIGNMENTS:n      SET RATES_EDITED = BITAND(RATES_EDITED,rates_e+
1dited001):n      WHERE TSK_ASSIGNMENT_ID = id001:
1FOUND:
1TRUE:
1=:
1100:
1111:
1           EXCEPTION:: SP_U_RATES_EDITED(112) :: cplan.sql(14399) :: :
1>:
12:
1FC_U_RATES:
14:
1129:
1       RETURN_STATUS:: SP_U_RATES_EDITED(130) :: cplan.sql(14417) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1136:
1           EXCEPTION:: SP_U_RATES_EDITED(137) :: cplan.sql(14424) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1148:
1           EXCEPTION:: SP_U_RATES_EDITED(149) :: cplan.sql(14436) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
3b4
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d a0 51 d :d a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:b a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :7 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b 51 a5
b 5a 7e 51 b4 2e :2 a0 d
:2 a0 d b7 19 3c :3 a0 51 a5
b 51 a5 b 5a 7e 51 b4
2e :2 a0 d :2 a0 d b7 19 3c
:2 a0 6b :9 a0 a5 b d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 :2 a0 6b :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e :2 a0 6b b4 2e 7e 6e b4
2e 7e :2 a0 6b b4 2e a5 57
b7 19 3c :9 a0 12a e9 dd :2 a0
65 b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c :7 a0 12a e9 dd :2 a0 65 b7
a4 b1 11 4f b7 a6 9 a4
b1 11 68 4f 1d 17 b5 
3b4
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 bf ae b2 8d
ba ad db ca ce aa d6 c9
f7 e6 ea c6 f2 e5 113 102
106 e2 10e 101 12f 11e 122 fe
12a 11d 14b 13a 13e 11a 146 139
167 156 15a 136 162 155 183 172
176 152 17e 171 19f 18e 192 16e
19a 18d 1bc 1aa 18a 1ae 1af 1b7
1a9 1d8 1c7 1cb 1a6 1d3 1c6 1f8
1e3 1e7 1c3 1eb 1f3 1e2 1ff 203
1df 207 20b 20f 212 217 218 1
21a 21f 223 227 22a 22f 233 237
23a 23f 240 242 247 24a 24e 24f
254 259 25c 261 262 267 26a 26e
26f 274 277 27c 27d 282 285 28a
28b 290 293 297 29b 29f 2a0 2a2
2a7 2a8 2aa 2ab 2b0 2b3 2b8 2b9
2be 2c1 2c6 2c7 2cc 2cf 2d3 2d4
2d9 2dc 2e1 2e2 2e7 2ea 2ef 2f0
2f5 2f6 2fb 2fd 301 304 308 30c
30f 313 317 31a 31d 322 325 328
32b 32c 331 332 1 334 339 33d
341 344 349 34e 351 355 356 35b
35c 361 363 367 36a 36e 372 376
37a 37d 381 385 389 38d 391 395
399 39d 3a1 3a5 3a9 3ad 3b1 3b5
3c1 3c5 3c9 3cc 3d0 3d4 3d6 3da
3de 3e2 3e5 3e9 3ed 3ef 3f0 3f5
1 3f9 3fd 401 404 408 40c 410
414 417 41b 41f 422 425 42a 42d
430 433 434 439 43a 1 43c 441
445 449 44c 451 456 459 45d 45e
463 466 46b 46c 471 474 479 47a
47f 482 486 487 48c 48f 494 495
49a 49d 4a1 4a5 4a8 4ab 4ac 4ae
4af 4b4 4b5 4ba 4bc 4c0 4c3 4c5
4c9 4cb 4d7 4d9 4db 4dc 4e1 4e5
4e7 4f3 4f5 4f9 4fd 501 505 509
515 519 51d 520 524 528 52a 52e
532 536 539 53d 541 543 544 549
1 54d 551 555 558 55c 560 564
568 56b 56f 573 576 579 57e 581
584 587 588 58d 58e 1 590 595
599 59d 5a0 5a5 5aa 5ad 5b1 5b2
5b7 5ba 5bf 5c0 5c5 5c8 5cd 5ce
5d3 5d6 5da 5db 5e0 5e3 5e8 5e9
5ee 5f1 5f5 5f9 5fc 5ff 600 602
603 608 609 60e 610 614 617 619
61d 61f 62b 62d 62f 630 635 639
63b 647 649 64d 651 655 659 65d
661 665 669 66d 671 675 681 685
689 68c 690 694 696 69a 69e 6a2
6a5 6a9 6ad 6af 6b0 6b5 1 6b9
6bd 6c1 6c4 6c8 6cc 6d0 6d4 6d7
6db 6df 6e2 6e5 6ea 6ed 6f0 6f3
6f4 6f9 6fa 1 6fc 701 705 709
70c 711 716 719 71d 71e 723 726
72b 72c 731 734 739 73a 73f 742
746 747 74c 74f 754 755 75a 75d
761 765 768 76b 76c 76e 76f 774
775 77a 77c 780 783 785 789 78b
797 799 79b 79c 7a1 7a5 7a7 7b3
7b5 7b9 7bd 7c1 7c5 7c9 7cd 7d1
7dd 7e1 7e6 7ea 7ed 7ee 7f3 7f7
7fb 7fe 801 805 807 80b 80f 812
815 819 81b 81f 823 826 828 82c
830 834 837 83b 83f 841 842 847
1 84b 84f 853 856 85a 85e 862
866 869 86d 871 874 877 87c 87f
882 885 886 88b 88c 1 88e 893
897 89b 89e 8a3 8a8 8ab 8af 8b0
8b5 8b8 8bd 8be 8c3 8c6 8cb 8cc
8d1 8d4 8d8 8d9 8de 8e1 8e6 8e7
8ec 8ef 8f3 8f7 8fa 8fd 8fe 900
901 906 907 90c 90e 912 915 917
91b 91d 929 92b 92d 92e 933 937
939 945 947 94b 94f 953 956 957
959 95c 95d 95f 962 965 968 969
96e 972 976 97a 97e 982 986 988
98c 98f 993 997 99b 99e 99f 9a1
9a4 9a5 9a7 9aa 9ad 9b0 9b1 9b6
9ba 9be 9c2 9c6 9ca 9ce 9d0 9d4
9d7 9db 9df 9e2 9e6 9ea 9ee 9f2
9f6 9fa 9fe a02 a06 a07 a09 a0d
a11 a15 a18 a1c a20 a23 a26 a2b
a2e a31 a34 a35 a3a a3b 1 a3d
a42 a46 a4a a4d a52 a57 a5a a5e
a5f a64 a67 a6c a6d a72 a75 a7a
a7b a80 a83 a87 a8b a8f a93 a96
a97 a99 a9e a9f aa1 aa2 aa7 aaa
aaf ab0 ab5 ab8 abd abe ac3 ac6
aca acb ad0 ad3 ad8 ad9 ade adf
ae4 ae6 aea aed af1 af5 af8 afc
b00 b03 b07 b0b b0c b11 b13 b17
b1b b1e b22 b26 b29 b2d b31 b34
b37 b3c b3f b42 b45 b46 b4b b4c
1 b4e b53 b57 b5b b5e b63 b68
b6b b6f b70 b75 b76 b7b b7f b83
b86 b8b b90 b93 b97 b9b b9e b9f
ba4 ba7 bac bad bb2 bb5 bb9 bbd
bc0 bc1 bc6 bc7 bcc bce bd2 bd5
bd9 bdd be1 be5 be9 bed bf1 bf5
bf9 c05 c0a c0e c12 c16 c1a c1c
c1d c22 1 c26 c2a c2e c31 c35
c39 c3d c41 c44 c48 c4c c4f c52
c57 c5a c5d c60 c61 c66 c67 1
c69 c6e c72 c76 c79 c7e c83 c86
c8a c8b c90 c91 c96 c9a c9e ca1
ca6 cab cae cb2 cb3 cb8 cbb cc0
cc1 cc6 cc9 ccd cd1 cd4 cd7 cd8
cda cdb ce0 ce1 ce6 ce8 cec cef
cf3 cf7 cfb cff d03 d07 d0b d17
d1c d20 d24 d28 d2c d2e d32 d34
d40 d42 d44 d45 d4a d4e d50 d5c
d60 d62 d63 d6c 
3b4
2
0 1 a 6 c :3 6 16 :3 6
10 :2 6 1 3 a 13 a :2 1
4 9 12 11 :2 9 :2 4 12 1b
1a :2 12 :2 4 :2 f 19 f :2 4 :2 10
1a 10 :2 4 :2 f 19 f :2 4 :2 10
1a 10 :2 4 :2 b 1a b :2 4 :2 13
1d 13 :2 4 :2 13 1d 13 :2 4 :2 14
1e 14 :2 4 :2 14 1e 14 :2 4 e
17 16 :2 e :2 4 :2 16 25 16 :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 59 5f 62 :2 59 70 8b 8
:2 70 d 10 :2 70 16 19 :2 70 b
e :2 70 13 16 1f 27 :2 1f 39
:2 16 :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 28 2b :2 70 30 33
:2 70 :2 7 4f :2 4 7 :2 11 23 :2 2d
39 3c 51 53 54 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 57
:3 4 15 :2 4 e 4 e 1c 7
15 23 e 1e 7 17 28 c
d 21 :2 7 :2 10 1c 7 4 c
a :2 13 1f a 1a :2 7 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 58 5a 5b :2 58 :2 29 :3 d :2 13
18 24 68 6b :2 24 78 7b :2 24
7f 82 :2 24 8e 91 :2 24 99 9c
:2 24 a8 ab b2 bb be :2 ab :2 24
:2 d 5e :2 a :2 7 :4 13 :2 7 4 :3 1
e 1b c d 1b :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 58 5a 5b :2 58
:2 29 :3 d :2 13 18 24 68 6b :2 24
78 7b :2 24 7f 82 :2 24 8e 91
:2 24 99 9c :2 24 a8 ab b2 bb
be :2 ab :2 24 :2 d 5e :2 a :2 7 :4 13
:2 7 4 :3 1 e 1c 7 15 e
1a 7 13 c d 17 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 58 5a 5b
:2 58 :2 29 :3 d :2 13 18 24 68 6b
:2 24 78 7b :2 24 7f 82 :2 24 8e
91 :2 24 99 9c :2 24 a8 ab b2
bb be :2 ab :2 24 :2 d 5e :2 a :2 7
:4 13 :2 7 4 :3 1 e b 1a 21
2e d 21 7 e a 16 :3 14
a :2 13 1f a 1b a :2 13 1f
a :4 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 58 5b 5c
:2 58 :2 29 :3 d :2 13 18 24 69 6c
:2 24 79 7c :2 24 80 83 :2 24 8f
92 :2 24 9a 9d :2 24 a9 ac b3
bc bf :2 ac :2 24 :2 d 5f :2 a :2 7
:4 13 :2 7 4 :3 1 8 f 18 29
:2 f 2d :2 8 7 31 33 :2 31 7
19 :2 7 1a 7 35 :2 4 8 f
18 29 :2 f 2d :2 8 7 31 33
:2 31 7 19 :2 7 1a 7 35 :3 4
:2 d 19 24 2a 3a 4b 23 34
47 56 :2 19 4 7 :2 11 23 :2 2d
39 3c 51 54 55 :2 51 :2 23 :3 7
:2 d 12 1e 63 66 :2 1e 73 76
:2 1e 7a 7d :2 1e 87 8a 93 9b
:2 a4 :2 93 af :2 8a :2 1e b7 ba :2 1e
c2 c5 :2 1e ca cd :2 1e d3 d6
:2 1e :2 7 58 :3 4 :2 f 21 :2 2a 34
3b :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 55 58 59 :2 55
:2 26 :3 a :2 10 15 21 66 69 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
5c :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 52 55 56 :2 52
:2 23 :3 7 :2 d 12 1e 63 66 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 59 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
3b4
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :6 a :6 b
:6 c :6 d :6 e :6 f
:6 10 :6 11 :6 12 :7 13
:6 14 :7 16 :b 18 :11 19
1a :2 19 :2 1a :2 19
:2 1a :2 19 :2 1b :2 19
:9 1b :2 19 :2 1c :2 19
:2 1c :2 19 :2 1c :2 19
:2 1c :2 19 :2 1c :4 19
:3 18 :11 1f :b 20 :3 1f
:3 23 :3 25 :2 28 :3 29
:2 2a :3 2b 2c :2 2d
28 :5 2e 27 30
:5 31 :3 30 :2 32 :5 34
:11 35 :24 36 :3 35 :2 33
:6 32 2f :3 17 :2 3c
3d :2 3e 3c :5 3f
3b 41 :5 42 :3 41
:2 43 :5 45 :11 46 :24 47
:3 46 :2 44 :6 43 40
:3 17 :2 4d :2 4e :2 4f
:2 50 51 :2 52 4d
:5 53 4c 55 :5 56
:3 55 :2 57 :5 59 :11 5a
:24 5b :3 5a :2 58 :6 57
54 :3 17 61 :4 62
:2 63 61 :6 64 :5 65
64 :5 67 66 :3 64
60 6a :5 6b :3 6a
:2 6c :5 6e :11 6f :24 70
:3 6f :2 6d :6 6c 69
:3 17 :e 75 :3 76 :3 77
:3 75 :e 79 :3 7a :3 7b
:3 79 :8 7e :4 7f :3 7e
:11 81 :30 82 :3 81 :a 84
17 :3 87 :11 88 :b 89
:17 8a :3 88 :2 8c :3 8d
:3 8e 8f 8d 8c
8d :3 90 :3 87 :2 91
:5 93 :11 94 :b 95 :18 96
:3 94 :2 98 99 :3 9a
9b 99 98 99
:3 9c :2 92 :6 91 86
:7 1 
d6e
4
:3 0 1 :3 0 2
:a 0 3af 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 3af 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 3ad
0 b :6 0 10
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 3ad
0 d :6 0 10
:2 0 15 f :3 0
25 :7 0 29 26
27 3ad 0 e
:6 0 10 :2 0 17
f :3 0 2b :7 0
2f 2c 2d 3ad
0 11 :6 0 10
:2 0 19 f :3 0
31 :7 0 35 32
33 3ad 0 12
:6 0 10 :2 0 1b
f :3 0 37 :7 0
3b 38 39 3ad
0 13 :6 0 10
:2 0 1d 6 :3 0
3d :7 0 41 3e
3f 3ad 0 14
:6 0 10 :2 0 1f
f :3 0 43 :7 0
47 44 45 3ad
0 15 :6 0 10
:2 0 21 f :3 0
49 :7 0 4d 4a
4b 3ad 0 16
:6 0 10 :2 0 23
f :3 0 4f :7 0
53 50 51 3ad
0 17 :6 0 c
:2 0 25 f :3 0
55 :7 0 59 56
57 3ad 0 18
:6 0 10 :2 0 29
4 :3 0 27 5b
5d :6 0 60 5e
0 3ad 0 19
:6 0 68 69 0
2b 6 :3 0 62
:7 0 66 63 64
3ad 0 1a :6 0
6e 6f 0 2d
9 :3 0 a :2 0
4 6a :7 0 6d
6b 0 3ad 0
1b :6 0 1c :3 0
1d :3 0 1c :3 0
1e :3 0 71 72
0 2 :4 0 2f
73 75 70 77
76 :2 0 1f :3 0
20 :3 0 79 7a
0 21 :4 0 1c
:3 0 22 :3 0 7d
7e 0 2 :4 0
31 7f 81 23
:4 0 24 :2 0 25
:3 0 33 84 86
:3 0 26 :4 0 24
:2 0 27 :4 0 36
89 8b :3 0 24
:2 0 3 :3 0 39
8d 8f :3 0 24
:2 0 27 :4 0 3c
91 93 :3 0 24
:2 0 28 :4 0 3f
95 97 :3 0 24
:2 0 29 :3 0 2a
:3 0 5 :3 0 42
9b 9d 2b :4 0
44 9a a0 47
99 a2 :3 0 24
:2 0 28 :4 0 4a
a4 a6 :3 0 24
:2 0 27 :4 0 4d
a8 aa :3 0 24
:2 0 7 :3 0 50
ac ae :3 0 24
:2 0 27 :4 0 53
b0 b2 :3 0 24
:2 0 2c :4 0 56
b4 b6 :3 0 59
7b b8 :2 0 ba
5e bb 78 ba
0 bc 60 0
30d 1c :3 0 1d
:3 0 bd be 0
1c :3 0 2d :3 0
c0 c1 0 2e
:2 0 2 :4 0 2f
:2 0 30 :2 0 2e
:2 0 62 c6 c8
:3 0 65 c2 ca
bf cc cb :2 0
1f :3 0 31 :3 0
ce cf 0 21
:4 0 32 :4 0 24
:2 0 25 :3 0 69
d3 d5 :3 0 6c
d0 d7 :2 0 d9
6f da cd d9
0 db 71 0
30d d :3 0 7
:3 0 dc dd 0
30d 14 :3 0 10
:2 0 df e0 0
30d 33 :3 0 34
:3 0 35 :3 0 36
:3 0 37 :3 0 15
:3 0 16 :3 0 17
:3 0 18 :3 0 1a
:3 0 38 :3 0 39
:3 0 3 :4 0 3a
1 :8 0 f5 9
:3 0 3b :3 0 f0
f1 0 3c :3 0
f2 f3 0 f5
73 148 3d :3 0
9 :3 0 3b :3 0
f7 f8 0 3c
:3 0 f9 fa 0
fc 76 fe 78
fd fc :2 0 146
3e :3 0 9 :3 0
3b :3 0 101 102
0 3c :3 0 103
104 0 13e 1c
:3 0 1d :3 0 106
107 0 1c :3 0
2d :3 0 109 10a
0 3f :2 0 2
:4 0 40 :2 0 30
:2 0 2e :2 0 7a
10f 111 :3 0 7d
10b 113 108 115
114 :2 0 1f :3 0
31 :3 0 117 118
0 21 :4 0 41
:4 0 24 :2 0 25
:3 0 81 11c 11e
:3 0 24 :2 0 42
:4 0 84 120 122
:3 0 24 :2 0 43
:4 0 87 124 126
:3 0 24 :2 0 3c
:3 0 8a 128 12a
:3 0 24 :2 0 44
:4 0 8d 12c 12e
:3 0 24 :2 0 45
:3 0 46 :3 0 2e
:2 0 47 :2 0 90
131 135 94 130
137 :3 0 97 119
139 :2 0 13b 9a
13c 116 13b 0
13d 9c 0 13e
9e 141 :3 0 141
0 141 140 13e
13f :6 0 143 2
:3 0 a1 145 a3
144 143 :2 0 146
a5 :2 0 148 0
148 147 f5 146
:6 0 30d 1 :3 0
48 :3 0 19 :3 0
49 :3 0 4a :3 0
7 :4 0 4b 1
:8 0 155 9 :3 0
3b :3 0 150 151
0 3c :3 0 152
153 0 155 a8
1a8 3d :3 0 9
:3 0 3b :3 0 157
158 0 3c :3 0
159 15a 0 15c
ab 15e ad 15d
15c :2 0 1a6 3e
:3 0 9 :3 0 3b
:3 0 161 162 0
3c :3 0 163 164
0 19e 1c :3 0
1d :3 0 166 167
0 1c :3 0 2d
:3 0 169 16a 0
3f :2 0 2 :4 0
4c :2 0 30 :2 0
2e :2 0 af 16f
171 :3 0 b2 16b
173 168 175 174
:2 0 1f :3 0 31
:3 0 177 178 0
21 :4 0 4d :4 0
24 :2 0 25 :3 0
b6 17c 17e :3 0
24 :2 0 42 :4 0
b9 180 182 :3 0
24 :2 0 43 :4 0
bc 184 186 :3 0
24 :2 0 3c :3 0
bf 188 18a :3 0
24 :2 0 44 :4 0
c2 18c 18e :3 0
24 :2 0 45 :3 0
46 :3 0 2e :2 0
47 :2 0 c5 191
195 c9 190 197
:3 0 cc 179 199
:2 0 19b cf 19c
176 19b 0 19d
d1 0 19e d3
1a1 :3 0 1a1 0
1a1 1a0 19e 19f
:6 0 1a3 4 :3 0
d6 1a5 d8 1a4
1a3 :2 0 1a6 da
:2 0 1a8 0 1a8
1a7 155 1a6 :6 0
30d 1 :3 0 33
:3 0 4e :3 0 35
:3 0 4f :3 0 e
:3 0 12 :3 0 11
:3 0 13 :3 0 50
:3 0 48 :3 0 19
:4 0 51 1 :8 0
1bb 9 :3 0 3b
:3 0 1b6 1b7 0
3c :3 0 1b8 1b9
0 1bb dd 20e
3d :3 0 9 :3 0
3b :3 0 1bd 1be
0 3c :3 0 1bf
1c0 0 1c2 e0
1c4 e2 1c3 1c2
:2 0 20c 3e :3 0
9 :3 0 3b :3 0
1c7 1c8 0 3c
:3 0 1c9 1ca 0
204 1c :3 0 1d
:3 0 1cc 1cd 0
1c :3 0 2d :3 0
1cf 1d0 0 3f
:2 0 2 :4 0 52
:2 0 30 :2 0 2e
:2 0 e4 1d5 1d7
:3 0 e7 1d1 1d9
1ce 1db 1da :2 0
1f :3 0 31 :3 0
1dd 1de 0 21
:4 0 53 :4 0 24
:2 0 25 :3 0 eb
1e2 1e4 :3 0 24
:2 0 42 :4 0 ee
1e6 1e8 :3 0 24
:2 0 43 :4 0 f1
1ea 1ec :3 0 24
:2 0 3c :3 0 f4
1ee 1f0 :3 0 24
:2 0 44 :4 0 f7
1f2 1f4 :3 0 24
:2 0 45 :3 0 46
:3 0 2e :2 0 47
:2 0 fa 1f7 1fb
fe 1f6 1fd :3 0
101 1df 1ff :2 0
201 104 202 1dc
201 0 203 106
0 204 108 207
:3 0 207 0 207
206 204 205 :6 0
209 6 :3 0 10b
20b 10d 20a 209
:2 0 20c 10f :2 0
20e 0 20e 20d
1bb 20c :6 0 30d
1 :3 0 38 :3 0
54 :3 0 55 :3 0
54 :3 0 5 :3 0
39 :3 0 3 :4 0
56 1 :8 0 22d
57 :4 0 218 :3 0
58 :3 0 59 :2 0
114 21b 21c :3 0
9 :3 0 3b :3 0
21e 21f 0 10
:2 0 220 221 0
223 117 22a 9
:3 0 3b :3 0 224
225 0 5a :2 0
226 227 0 229
119 22b 21d 223
0 22c 0 229
0 22c 11b 0
22d 11e 280 3d
:3 0 9 :3 0 3b
:3 0 22f 230 0
3c :3 0 231 232
0 234 121 236
123 235 234 :2 0
27e 3e :3 0 9
:3 0 3b :3 0 239
23a 0 3c :3 0
23b 23c 0 276
1c :3 0 1d :3 0
23e 23f 0 1c
:3 0 2d :3 0 241
242 0 3f :2 0
2 :4 0 5b :2 0
30 :2 0 2e :2 0
125 247 249 :3 0
128 243 24b 240
24d 24c :2 0 1f
:3 0 31 :3 0 24f
250 0 21 :4 0
5c :4 0 24 :2 0
25 :3 0 12c 254
256 :3 0 24 :2 0
42 :4 0 12f 258
25a :3 0 24 :2 0
43 :4 0 132 25c
25e :3 0 24 :2 0
3c :3 0 135 260
262 :3 0 24 :2 0
44 :4 0 138 264
266 :3 0 24 :2 0
45 :3 0 46 :3 0
2e :2 0 47 :2 0
13b 269 26d 13f
268 26f :3 0 142
251 271 :2 0 273
145 274 24e 273
0 275 147 0
276 149 279 :3 0
279 0 279 278
276 277 :6 0 27b
8 :3 0 14c 27d
14e 27c 27b :2 0
27e 150 :2 0 280
0 280 27f 22d
27e :6 0 30d 1
:3 0 55 :3 0 29
:3 0 5 :3 0 10
:2 0 153 283 286
2e :2 0 156 282
289 28a :2 0 5d
:2 0 10 :2 0 15b
28c 28e :3 0 15
:3 0 e :3 0 290
291 0 296 17
:3 0 11 :3 0 293
294 0 296 15e
297 28f 296 0
298 161 0 30d
55 :3 0 29 :3 0
5 :3 0 10 :2 0
163 29a 29d 5e
:2 0 166 299 2a0
2a1 :2 0 5d :2 0
10 :2 0 16b 2a3
2a5 :3 0 16 :3 0
12 :3 0 2a7 2a8
0 2ad 18 :3 0
13 :3 0 2aa 2ab
0 2ad 16e 2ae
2a6 2ad 0 2af
171 0 30d 9
:3 0 3b :3 0 2b0
2b1 0 5f :3 0
b :3 0 15 :3 0
17 :3 0 16 :3 0
18 :3 0 1a :3 0
d :3 0 14 :3 0
173 2b3 2bc 2b2
2bd 0 30d 1c
:3 0 1d :3 0 2bf
2c0 0 1c :3 0
2d :3 0 2c2 2c3
0 60 :2 0 2
:4 0 61 :2 0 30
:2 0 2e :2 0 17c
2c8 2ca :3 0 17f
2c4 2cc 2c1 2ce
2cd :2 0 1f :3 0
31 :3 0 2d0 2d1
0 21 :4 0 62
:4 0 24 :2 0 25
:3 0 183 2d5 2d7
:3 0 24 :2 0 42
:4 0 186 2d9 2db
:3 0 24 :2 0 63
:4 0 189 2dd 2df
:3 0 24 :2 0 29
:3 0 2a :3 0 9
:3 0 3b :3 0 2e4
2e5 0 18c 2e3
2e7 2b :4 0 18e
2e2 2ea 191 2e1
2ec :3 0 24 :2 0
64 :4 0 194 2ee
2f0 :3 0 24 :2 0
27 :4 0 197 2f2
2f4 :3 0 24 :2 0
3 :3 0 19a 2f6
2f8 :3 0 24 :2 0
27 :4 0 19d 2fa
2fc :3 0 1a0 2d2
2fe :2 0 300 1a3
301 2cf 300 0
302 1a5 0 30d
65 :3 0 66 :3 0
303 304 0 9
:3 0 3b :3 0 306
307 0 3 :3 0
58 :3 0 1a7 305
30b :2 0 30d 1ab
3ae 9 :3 0 67
:2 0 4 30e 30f
0 1c :3 0 1d
:3 0 311 312 0
1c :3 0 2d :3 0
314 315 0 3f
:2 0 2 :4 0 68
:2 0 30 :2 0 2e
:2 0 1b9 31a 31c
:3 0 1bc 316 31e
313 320 31f :2 0
1f :3 0 31 :3 0
322 323 0 21
:4 0 69 :4 0 24
:2 0 25 :3 0 1c0
327 329 :3 0 1c3
324 32b :2 0 344
1f :3 0 31 :3 0
32d 32e 0 21
:4 0 6a :4 0 24
:2 0 9 :3 0 6b
:3 0 333 334 0
1c6 332 336 :3 0
24 :2 0 64 :4 0
1c9 338 33a :3 0
24 :2 0 9 :3 0
6c :3 0 33d 33e
0 1cc 33c 340
:3 0 1cf 32f 342
:2 0 344 1d2 345
321 344 0 346
1d5 0 356 6d
:3 0 1b :3 0 9
:3 0 6b :3 0 6e
:3 0 9 :3 0 6c
:3 0 6f :3 0 70
:4 0 71 1 :a 0
352 :2 0 356 348
350 :2 0 8 :3 0
1b :3 0 354 :2 0
356 1d7 358 1db
357 356 :2 0 3ac
3e :3 0 9 :3 0
3b :3 0 35b 35c
0 3c :3 0 35d
35e 0 3a4 1c
:3 0 1d :3 0 360
361 0 1c :3 0
2d :3 0 363 364
0 3f :2 0 2
:4 0 72 :2 0 30
:2 0 2e :2 0 1dd
369 36b :3 0 1e0
365 36d 362 36f
36e :2 0 1f :3 0
31 :3 0 371 372
0 21 :4 0 73
:4 0 24 :2 0 25
:3 0 1e4 376 378
:3 0 1e7 373 37a
:2 0 394 1f :3 0
31 :3 0 37c 37d
0 21 :4 0 43
:4 0 24 :2 0 3c
:3 0 1ea 381 383
:3 0 24 :2 0 44
:4 0 1ed 385 387
:3 0 24 :2 0 45
:3 0 46 :3 0 2e
:2 0 47 :2 0 1f0
38a 38e 1f4 389
390 :3 0 1f7 37e
392 :2 0 394 1fa
395 370 394 0
396 1fd 0 3a4
6d :3 0 1b :3 0
6e :3 0 9 :3 0
6c :3 0 6f :3 0
70 :4 0 74 1
:a 0 3a0 :2 0 3a4
398 39e :2 0 8
:3 0 1b :3 0 3a2
:2 0 3a4 1ff 3a7
:3 0 3a7 0 3a7
3a6 3a4 3a5 :6 0
3a9 1 :3 0 204
3ab 206 3aa 3a9
:2 0 3ac 208 :2 0
3ae 20b 3ae 3ad
30d 3ac :6 0 3af
:2 0 2 14 3ae
3b2 :3 0 3b1 3af
3b3 :8 0 
21a
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
24 1 2a 1
30 1 36 1
3c 1 42 1
48 1 4e 1
54 1 5c 1
5a 1 61 1
67 1 74 1
80 2 83 85
2 88 8a 2
8c 8e 2 90
92 2 94 96
1 9c 2 9e
9f 2 98 a1
2 a3 a5 2
a7 a9 2 ab
ad 2 af b1
2 b3 b5 4
7c 82 87 b7
1 b9 1 bb
2 c5 c7 3
c3 c4 c9 2
d2 d4 2 d1
d6 1 d8 1
da 2 ef f4
1 fb 1 f6
2 10e 110 3
10c 10d 112 2
11b 11d 2 11f
121 2 123 125
2 127 129 2
12b 12d 3 132
133 134 2 12f
136 2 11a 138
1 13a 1 13c
2 105 13d 1
141 1 100 2
fe 145 2 14f
154 1 15b 1
156 2 16e 170
3 16c 16d 172
2 17b 17d 2
17f 181 2 183
185 2 187 189
2 18b 18d 3
192 193 194 2
18f 196 2 17a
198 1 19a 1
19c 2 165 19d
1 1a1 1 160
2 15e 1a5 2
1b5 1ba 1 1c1
1 1bc 2 1d4
1d6 3 1d2 1d3
1d8 2 1e1 1e3
2 1e5 1e7 2
1e9 1eb 2 1ed
1ef 2 1f1 1f3
3 1f8 1f9 1fa
2 1f5 1fc 2
1e0 1fe 1 200
1 202 2 1cb
203 1 207 1
1c6 2 1c4 20b
1 21a 2 219
21a 1 222 1
228 2 22a 22b
2 217 22c 1
233 1 22e 2
246 248 3 244
245 24a 2 253
255 2 257 259
2 25b 25d 2
25f 261 2 263
265 3 26a 26b
26c 2 267 26e
2 252 270 1
272 1 274 2
23d 275 1 279
1 238 2 236
27d 2 284 285
2 287 288 1
28d 2 28b 28d
2 292 295 1
297 2 29b 29c
2 29e 29f 1
2a4 2 2a2 2a4
2 2a9 2ac 1
2ae 8 2b4 2b5
2b6 2b7 2b8 2b9
2ba 2bb 2 2c7
2c9 3 2c5 2c6
2cb 2 2d4 2d6
2 2d8 2da 2
2dc 2de 1 2e6
2 2e8 2e9 2
2e0 2eb 2 2ed
2ef 2 2f1 2f3
2 2f5 2f7 2
2f9 2fb 2 2d3
2fd 1 2ff 1
301 3 308 309
30a d bc db
de e1 148 1a8
20e 280 298 2af
2be 302 30c 2
319 31b 3 317
318 31d 2 326
328 2 325 32a
2 331 335 2
337 339 2 33b
33f 2 330 341
2 32c 343 1
345 3 346 351
355 1 310 2
368 36a 3 366
367 36c 2 375
377 2 374 379
2 380 382 2
384 386 3 38b
38c 38d 2 388
38f 2 37f 391
2 37b 393 1
395 4 35f 396
39f 3a3 1 3a7
1 35a 2 358
3ab e 1b 22
28 2e 34 3a
40 46 4c 52
58 5f 65 6c

1
4
0 
3b2
0
1
14
a
12
0 1 2 1 4 1 6 1
8 1 0 0 0 0 0 0
0 0 0 0 
42 1 0
54 1 0
61 1 0
5a 1 0
1d 1 0
b 1 0
2a 1 0
30 1 0
2 0 1
48 1 0
3 1 0
4e 1 0
16 1 0
3c 1 0
36 1 0
7 1 0
24 1 0
67 1 0
0

/
SHOW ERRORS FUNCTION SP_U_RATES_EDITED;
ALTER FUNCTION SP_U_RATES_EDITED COMPILE DEBUG;
/*
#Stored Procedure  :SP_U_TIMECODE2
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_U_TIMECODE2 ==
CREATE OR REPLACE FUNCTION SP_U_TIMECODE2 wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
56
2 :e:
1FUNCTION:
1SP_U_TIMECODE2:
1ASSIGN_ID:
1VARCHAR2:
1ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TEMP_SC_STATE:
1PLS_INTEGER:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_TIMECODE2(:
1':
1, :
1);:
1CHECK_TRACE:
11:
117:
1+:
1FPUT:
1               ENTER:: SP_U_TIMECODE2(18) :: cplan.sql(14478) :: :
1IS NULL:
18:
122:
1      RETURN_INVALID:: SP_U_TIMECODE2(23) :: cplan.sql(14483) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
125:
1                EXIT:: SP_U_TIMECODE2(26) :: cplan.sql(14486) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1TASK_ASSIGNMENTS:
1TIMECODE2_ID:
1TSK_ASSIGNMENT_ID:
1UPDATE TASK_ASSIGNMENTS SET TIMECODE2_ID = id001 WHERE TSK_ASSIGNMENT_ID = as+
1sign_id:
1FOUND:
1=:
1SC_STATE:
1100:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
145:
1           EXCEPTION:: SP_U_TIMECODE2(46) :: cplan.sql(14506) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
14:
151:
1       RETURN_STATUS:: SP_U_TIMECODE2(52) :: cplan.sql(14512) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
158:
1           EXCEPTION:: SP_U_TIMECODE2(59) :: cplan.sql(14519) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
170:
1           EXCEPTION:: SP_U_TIMECODE2(71) :: cplan.sql(14531) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
250
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a 52 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b a0 a5 57 b7 19
3c :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 a0 6b
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e a5 57 b7 19 3c :9 a0 12a
e9 dd :2 a0 65 b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c :7 a0 12a e9 dd
:2 a0 65 b7 a4 b1 11 4f b7
a6 9 a4 b1 11 68 4f 1d
17 b5 
250
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 71 5d 61 69 6c 5c
91 7c 80 59 84 8c 7b 98
9c 78 a0 a4 a8 ab b0 b1
1 b3 b8 bc c0 c3 c8 cc
d0 d3 d8 d9 db e0 e3 e7
e8 ed f2 f5 fa fb 100 103
107 108 10d 110 115 116 11b 11e
123 124 129 12c 131 132 137 13a
13e 13f 144 147 14c 14d 152 155
15a 15b 160 161 166 168 16c 16f
173 177 17a 17e 182 185 188 18d
190 193 196 197 19c 19d 1 19f
1a4 1a8 1ac 1af 1b4 1b9 1bc 1c0
1c1 1c6 1c7 1cc 1ce 1d2 1d5 1d9
1dc 1dd 1e2 1e5 1e8 1ec 1ef 1f0
1f5 1f8 1 1fb 200 204 208 20b
20f 213 216 219 21e 221 224 227
228 22d 22e 1 230 235 239 23d
240 245 24a 24d 251 252 257 25a
25f 260 265 268 26d 26e 273 276
27a 27e 282 286 289 28a 28c 291
292 294 295 29a 29b 2a0 2a2 2a6
2a9 2ad 2b1 2b4 2b8 2bc 2bf 2c2
2c7 2ca 2cd 2d0 2d1 2d6 2d7 1
2d9 2de 2e2 2e6 2e9 2ee 2f3 2f6
2fa 2fb 300 301 306 308 30c 30f
313 317 31a 31e 322 325 329 32a
32f 331 335 338 33c 340 344 348
34c 358 35c 361 365 368 369 36e
372 376 379 37c 380 382 386 38a
38d 390 394 396 39a 39e 3a1 3a3
3a7 3ab 3af 3b2 3b6 3ba 3bc 3bd
3c2 1 3c6 3ca 3ce 3d1 3d5 3d9
3dd 3e1 3e4 3e8 3ec 3ef 3f2 3f7
3fa 3fd 400 401 406 407 1 409
40e 412 416 419 41e 423 426 42a
42b 430 433 438 439 43e 441 446
447 44c 44f 453 454 459 45c 461
462 467 46a 46e 472 475 478 479
47b 47c 481 482 487 489 48d 490
492 496 498 4a4 4a6 4a8 4a9 4ae
4b2 4b4 4c0 4c2 4c6 4ca 4cd 4d1
4d5 4d8 4db 4e0 4e3 4e6 4e9 4ea
4ef 4f0 1 4f2 4f7 4fb 4ff 502
507 50c 50f 513 514 519 51c 521
522 527 52a 52f 530 535 538 53c
540 544 548 54b 54c 54e 553 554
556 557 55c 55f 564 565 56a 56d
572 573 578 57b 57f 580 585 588
58d 58e 593 594 599 59b 59f 5a2
5a6 5aa 5ad 5b1 5b5 5b8 5bc 5c0
5c1 5c6 5c8 5cc 5d0 5d3 5d7 5db
5de 5e2 5e6 5e9 5ec 5f1 5f4 5f7
5fa 5fb 600 601 1 603 608 60c
610 613 618 61d 620 624 625 62a
62b 630 634 638 63b 640 645 648
64c 650 653 654 659 65c 661 662
667 66a 66e 672 675 676 67b 67c
681 683 687 68a 68e 692 696 69a
69e 6a2 6a6 6aa 6ae 6ba 6bf 6c3
6c7 6cb 6cf 6d1 6d2 6d7 1 6db
6df 6e3 6e6 6ea 6ee 6f2 6f6 6f9
6fd 701 704 707 70c 70f 712 715
716 71b 71c 1 71e 723 727 72b
72e 733 738 73b 73f 740 745 746
74b 74f 753 756 75b 760 763 767
768 76d 770 775 776 77b 77e 782
786 789 78c 78d 78f 790 795 796
79b 79d 7a1 7a4 7a8 7ac 7b0 7b4
7b8 7bc 7c0 7cc 7d1 7d5 7d9 7dd
7e1 7e3 7e7 7e9 7f5 7f7 7f9 7fa
7ff 803 805 811 815 817 818 821 
250
2
0 1 a 6 10 :3 6 c :2 6
1 3 a 13 a :2 1 4 :2 14
23 14 :2 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 56 5c 5f :2 56
6d 85 8 :2 6d d 10 :2 6d 1a
1d :2 6d b e :2 6d 13 16 :2 6d
1b 1e :2 6d 24 27 :2 6d 2c 2f
:2 6d :2 7 4c :2 4 7 :2 11 23 :2 2d
39 3c 4e 50 51 :2 4e :2 23 :3 7
:2 d 12 1e 5f 62 :2 1e :2 7 54
:2 4 :4 9 8 7 :4 22 21 20 :2 7
a :2 14 26 :2 30 3c 3f 51 53
54 :2 51 :2 26 :3 a :2 10 15 21 62
65 :2 21 72 75 :2 21 79 7c :2 21
86 89 92 9a :2 a3 :2 92 b4 :2 89
:2 21 :2 a 57 :2 7 a :2 14 26 :2 30
3c 3f 51 53 54 :2 51 :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 :2 12 28 :2 31 41 :2 7 32 :2 4
e 23 32 3e 52 7 e a
16 :3 14 a :2 13 1f a 1b a
:2 13 1f a :4 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 55
57 58 :2 55 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 8b 8e :2 24 96 99 :2 24 a5
a8 af b8 bb :2 a8 :2 24 :2 d 5b
:2 a :2 7 :4 13 :2 7 4 :3 1 7 :2 11
23 :2 2d 39 3c 4e 50 51 :2 4e
:2 23 :3 7 :2 d 12 1e 5f 62 :2 1e
6f 72 :2 1e 76 79 :2 1e 83 86
8f 97 :2 a0 :2 8f ab :2 86 :2 1e b3
b6 :2 1e be c1 :2 1e c6 c9 :2 1e
d3 d6 :2 1e :2 7 54 :3 4 :2 f 21
:2 2a 34 3f :2 4 1 9 12 9
a :2 14 26 :2 30 3c 40 52 54
55 :2 52 :2 26 :3 a :2 10 15 21 62
65 :2 21 :3 a :2 10 15 39 5c 5f
:2 68 :2 39 76 79 :2 39 81 84 :2 8d
:2 39 :2 a 58 :3 7 c 15 1e 2c
a 13 1e f e 7 e 7
e 7 29 :2 4 :2 9 7 :2 10 1c
:2 7 :2 11 23 :2 2d 39 3d 4f 51
52 :2 4f :2 23 :3 7 :2 d 12 1e 5f
62 :2 1e :3 7 :2 d 12 36 42 45
:2 36 4d 50 :2 36 5c 5f 66 6f
72 :2 5f :2 36 :2 7 55 :2 4 7 c
1b a 13 1e f e 7 e
7 e 7 :2 4 :4 10 :2 4 :8 1 
250
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :6 7
:7 9 :b b :11 c d
:2 c :2 d :2 c :2 d
:2 c :2 e :2 c :2 e
:2 c :2 e :2 c :2 e
:2 c :2 e :4 c :3 b
:11 11 :b 12 :3 11 :e 15
:11 16 :20 17 :3 16 :11 19
:b 1a :3 19 :9 1c :3 15
:6 21 :6 22 :5 23 22
:5 25 24 :3 22 20
28 :5 29 :3 28 :2 2a
:5 2c :11 2d :24 2e :3 2d
:2 2b :6 2a 27 :3 a
:11 33 :30 34 :3 33 :a 36
a :3 39 :11 3a :b 3b
:17 3c :3 3a :2 3e :3 3f
:3 40 41 3f 3e
3f :3 42 :3 39 :2 43
:5 45 :11 46 :b 47 :18 48
:3 46 :2 4a 4b :3 4c
4d 4b 4a 4b
:3 4e :2 44 :6 43 38
:7 1 
823
4
:3 0 1 :3 0 2
:a 0 24b 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 4
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :3 0 8 :2 0
4 b f 0
24b 2 10 :2 0
19 1a 0 :2 a
:3 0 13 :7 0 b
:2 0 17 14 15
249 0 9 :6 0
1f 20 0 c
7 :3 0 8 :2 0
4 1b :7 0 1e
1c 0 249 0
c :6 0 d :3 0
e :3 0 d :3 0
f :3 0 22 23
0 2 :4 0 e
24 26 21 28
27 :2 0 10 :3 0
11 :3 0 2a 2b
0 12 :4 0 d
:3 0 13 :3 0 2e
2f 0 2 :4 0
10 30 32 14
:4 0 15 :2 0 16
:3 0 12 35 37
:3 0 17 :4 0 15
:2 0 18 :4 0 15
3a 3c :3 0 15
:2 0 3 :3 0 18
3e 40 :3 0 15
:2 0 18 :4 0 1b
42 44 :3 0 15
:2 0 19 :4 0 1e
46 48 :3 0 15
:2 0 18 :4 0 21
4a 4c :3 0 15
:2 0 5 :3 0 24
4e 50 :3 0 15
:2 0 18 :4 0 27
52 54 :3 0 15
:2 0 1a :4 0 2a
56 58 :3 0 2d
2c 5a :2 0 5c
32 5d 29 5c
0 5e 34 0
1a9 d :3 0 e
:3 0 5f 60 0
d :3 0 1b :3 0
62 63 0 1c
:2 0 2 :4 0 1d
:2 0 1e :2 0 1c
:2 0 36 68 6a
:3 0 39 64 6c
61 6e 6d :2 0
10 :3 0 1f :3 0
70 71 0 12
:4 0 20 :4 0 15
:2 0 16 :3 0 3d
75 77 :3 0 40
72 79 :2 0 7b
43 7c 6f 7b
0 7d 45 0
1a9 3 :3 0 21
:2 0 47 7f 80
:3 0 81 :2 0 82
:2 0 5 :3 0 21
:2 0 49 85 86
:3 0 87 :2 0 88
:2 0 83 8a 89
:2 0 d :3 0 e
:3 0 8c 8d 0
d :3 0 1b :3 0
8f 90 0 22
:2 0 2 :4 0 23
:2 0 1e :2 0 1c
:2 0 4b 95 97
:3 0 4e 91 99
8e 9b 9a :2 0
10 :3 0 1f :3 0
9d 9e 0 12
:4 0 24 :4 0 15
:2 0 16 :3 0 52
a2 a4 :3 0 15
:2 0 25 :4 0 55
a6 a8 :3 0 15
:2 0 26 :4 0 58
aa ac :3 0 15
:2 0 27 :3 0 28
:3 0 29 :3 0 2a
:3 0 b1 b2 0
5b b0 b4 2b
:4 0 5d af b7
60 ae b9 :3 0
63 9f bb :2 0
bd 66 be 9c
bd 0 bf 68
0 e8 d :3 0
e :3 0 c0 c1
0 d :3 0 1b
:3 0 c3 c4 0
1c :2 0 2 :4 0
2c :2 0 1e :2 0
1c :2 0 6a c9
cb :3 0 6d c5
cd c2 cf ce
:2 0 10 :3 0 1f
:3 0 d1 d2 0
12 :4 0 2d :4 0
15 :2 0 16 :3 0
71 d6 d8 :3 0
74 d3 da :2 0
dc 77 dd d0
dc 0 de 79
0 e8 2e :3 0
2f :3 0 df e0
0 29 :3 0 2a
:3 0 e2 e3 0
30 :3 0 7b e1
e6 :2 0 e8 7e
e9 8b e8 0
ea 82 0 1a9
31 :3 0 32 :3 0
5 :3 0 33 :3 0
3 :4 0 34 1
:8 0 106 35 :4 0
f1 :3 0 30 :3 0
36 :2 0 86 f4
f5 :3 0 7 :3 0
37 :3 0 f7 f8
0 b :2 0 f9
fa 0 fc 89
103 7 :3 0 37
:3 0 fd fe 0
38 :2 0 ff 100
0 102 8b 104
f6 fc 0 105
0 102 0 105
8d 0 106 90
159 39 :3 0 7
:3 0 37 :3 0 108
109 0 3a :3 0
10a 10b 0 10d
93 10f 95 10e
10d :2 0 157 3b
:3 0 7 :3 0 37
:3 0 112 113 0
3a :3 0 114 115
0 14f d :3 0
e :3 0 117 118
0 d :3 0 1b
:3 0 11a 11b 0
3c :2 0 2 :4 0
3d :2 0 1e :2 0
1c :2 0 97 120
122 :3 0 9a 11c
124 119 126 125
:2 0 10 :3 0 1f
:3 0 128 129 0
12 :4 0 3e :4 0
15 :2 0 16 :3 0
9e 12d 12f :3 0
15 :2 0 25 :4 0
a1 131 133 :3 0
15 :2 0 3f :4 0
a4 135 137 :3 0
15 :2 0 3a :3 0
a7 139 13b :3 0
15 :2 0 40 :4 0
aa 13d 13f :3 0
15 :2 0 41 :3 0
42 :3 0 1c :2 0
43 :2 0 ad 142
146 b1 141 148
:3 0 b4 12a 14a
:2 0 14c b7 14d
127 14c 0 14e
b9 0 14f bb
152 :3 0 152 0
152 151 14f 150
:6 0 154 2 :3 0
be 156 c0 155
154 :2 0 157 c2
:2 0 159 0 159
158 106 157 :6 0
1a9 1 :3 0 d
:3 0 e :3 0 15b
15c 0 d :3 0
1b :3 0 15e 15f
0 44 :2 0 2
:4 0 45 :2 0 1e
:2 0 1c :2 0 c5
164 166 :3 0 c8
160 168 15d 16a
169 :2 0 10 :3 0
1f :3 0 16c 16d
0 12 :4 0 46
:4 0 15 :2 0 16
:3 0 cc 171 173
:3 0 15 :2 0 25
:4 0 cf 175 177
:3 0 15 :2 0 26
:4 0 d2 179 17b
:3 0 15 :2 0 27
:3 0 28 :3 0 7
:3 0 37 :3 0 180
181 0 d5 17f
183 2b :4 0 d7
17e 186 da 17d
188 :3 0 15 :2 0
47 :4 0 dd 18a
18c :3 0 15 :2 0
18 :4 0 e0 18e
190 :3 0 15 :2 0
3 :3 0 e3 192
194 :3 0 15 :2 0
18 :4 0 e6 196
198 :3 0 e9 16e
19a :2 0 19c ec
19d 16b 19c 0
19e ee 0 1a9
2e :3 0 48 :3 0
19f 1a0 0 7
:3 0 37 :3 0 1a2
1a3 0 3 :3 0
30 :3 0 f0 1a1
1a7 :2 0 1a9 f4
24a 7 :3 0 49
:2 0 4 1aa 1ab
0 d :3 0 e
:3 0 1ad 1ae 0
d :3 0 1b :3 0
1b0 1b1 0 3c
:2 0 2 :4 0 4a
:2 0 1e :2 0 1c
:2 0 fb 1b6 1b8
:3 0 fe 1b2 1ba
1af 1bc 1bb :2 0
10 :3 0 1f :3 0
1be 1bf 0 12
:4 0 4b :4 0 15
:2 0 16 :3 0 102
1c3 1c5 :3 0 105
1c0 1c7 :2 0 1e0
10 :3 0 1f :3 0
1c9 1ca 0 12
:4 0 4c :4 0 15
:2 0 7 :3 0 4d
:3 0 1cf 1d0 0
108 1ce 1d2 :3 0
15 :2 0 47 :4 0
10b 1d4 1d6 :3 0
15 :2 0 7 :3 0
4e :3 0 1d9 1da
0 10e 1d8 1dc
:3 0 111 1cb 1de
:2 0 1e0 114 1e1
1bd 1e0 0 1e2
117 0 1f2 4f
:3 0 c :3 0 7
:3 0 4d :3 0 50
:3 0 7 :3 0 4e
:3 0 51 :3 0 52
:4 0 53 1 :a 0
1ee :2 0 1f2 1e4
1ec :2 0 6 :3 0
c :3 0 1f0 :2 0
1f2 119 1f4 11d
1f3 1f2 :2 0 248
3b :3 0 7 :3 0
37 :3 0 1f7 1f8
0 3a :3 0 1f9
1fa 0 240 d
:3 0 e :3 0 1fc
1fd 0 d :3 0
1b :3 0 1ff 200
0 3c :2 0 2
:4 0 54 :2 0 1e
:2 0 1c :2 0 11f
205 207 :3 0 122
201 209 1fe 20b
20a :2 0 10 :3 0
1f :3 0 20d 20e
0 12 :4 0 55
:4 0 15 :2 0 16
:3 0 126 212 214
:3 0 129 20f 216
:2 0 230 10 :3 0
1f :3 0 218 219
0 12 :4 0 3f
:4 0 15 :2 0 3a
:3 0 12c 21d 21f
:3 0 15 :2 0 40
:4 0 12f 221 223
:3 0 15 :2 0 41
:3 0 42 :3 0 1c
:2 0 43 :2 0 132
226 22a 136 225
22c :3 0 139 21a
22e :2 0 230 13c
231 20c 230 0
232 13f 0 240
4f :3 0 c :3 0
50 :3 0 7 :3 0
4e :3 0 51 :3 0
52 :4 0 56 1
:a 0 23c :2 0 240
234 23a :2 0 6
:3 0 c :3 0 23e
:2 0 240 141 243
:3 0 243 0 243
242 240 241 :6 0
245 1 :3 0 146
247 148 246 245
:2 0 248 14a :2 0
24a 14d 24a 249
1a9 248 :6 0 24b
:2 0 2 10 24a
24e :3 0 24d 24b
24f :8 0 
150
4
:3 0 1 3 1
7 2 6 a
1 12 1 18
1 25 1 31
2 34 36 2
39 3b 2 3d
3f 2 41 43
2 45 47 2
49 4b 2 4d
4f 2 51 53
2 55 57 4
2d 33 38 59
1 5b 1 5d
2 67 69 3
65 66 6b 2
74 76 2 73
78 1 7a 1
7c 1 7e 1
84 2 94 96
3 92 93 98
2 a1 a3 2
a5 a7 2 a9
ab 1 b3 2
b5 b6 2 ad
b8 2 a0 ba
1 bc 1 be
2 c8 ca 3
c6 c7 cc 2
d5 d7 2 d4
d9 1 db 1
dd 2 e4 e5
3 bf de e7
1 e9 1 f3
2 f2 f3 1
fb 1 101 2
103 104 2 f0
105 1 10c 1
107 2 11f 121
3 11d 11e 123
2 12c 12e 2
130 132 2 134
136 2 138 13a
2 13c 13e 3
143 144 145 2
140 147 2 12b
149 1 14b 1
14d 2 116 14e
1 152 1 111
2 10f 156 2
163 165 3 161
162 167 2 170
172 2 174 176
2 178 17a 1
182 2 184 185
2 17c 187 2
189 18b 2 18d
18f 2 191 193
2 195 197 2
16f 199 1 19b
1 19d 3 1a4
1a5 1a6 6 5e
7d ea 159 19e
1a8 2 1b5 1b7
3 1b3 1b4 1b9
2 1c2 1c4 2
1c1 1c6 2 1cd
1d1 2 1d3 1d5
2 1d7 1db 2
1cc 1dd 2 1c8
1df 1 1e1 3
1e2 1ed 1f1 1
1ac 2 204 206
3 202 203 208
2 211 213 2
210 215 2 21c
21e 2 220 222
3 227 228 229
2 224 22b 2
21b 22d 2 217
22f 1 231 4
1fb 232 23b 23f
1 243 1 1f6
2 1f4 247 2
16 1d 
1
4
0 
24e
0
1
14
4
5
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
12 1 0
7 1 0
3 1 0
18 1 0
0

/
SHOW ERRORS FUNCTION SP_U_TIMECODE2;
ALTER FUNCTION SP_U_TIMECODE2 COMPILE DEBUG;
/*
#Stored Procedure  :SP_S_PROFILE
#Short Description :
#Description       :
#Table Name        :
#Parameters        :
 $$bitflag       Description
   0	-  WBS Project global view: Resources  Profile with Competencies  Skills
   1	-  WBS Project global view: Resources  Profiles
   6	-  CRI Project global view: Resources  Profiles
   2,3	-  WBS  CRI - Assignments View
   4	-  WBS  CRI - All assignments with effort (no participants, no project assignments) in the current project
   5	-  WBS  CRI - All participants (no effort) in the current project
   8	-  WBS  CRI - All assignments (effort, participants, project assignments) in the current project
   9	-  WBS  CRI - All assignments for a Resource / Profile under a element (project, deliverable, task)
   7	-  WBS Project Assignments
   11	-  DOC Assignments View (SC_TABLE_DOC, SC_TABLE_POL_DOC, SC_TABLE_RES_DOC, SC_TABLE_AST_DOC,SC_TABLE_CLN_DOC,SC_TABLE_VDR_DOC)
   12	-  WBS  CRI - display nickname for All assignments (effort, participants, project assignments) in the current project
   13	-  Returns nickname for All assignments (effort, participants, project assignments) in the current pool
#Returns           :
#Errors            :
*/
Prompt == FUNCTION SP_S_PROFILE ==
CREATE OR REPLACE FUNCTION SP_S_PROFILE wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
220
2 :e:
1FUNCTION:
1SP_S_PROFILE:
1ID001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_RANK:
1200:
1H_ID:
132:
1H_REC_USER:
1H_PROJECT_ID:
1H_IN:
1255:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_PER_DAY:
1H_TYPE_ID:
1H_COUNT:
1H_TEMP_SC_STATE:
1H_LEVEL_STATE:
1H_CQ_RESID:
1H_CQ_OWNER:
1C7751A:
1C7751B:
1C7751C:
1C7751T:
1C7751D:
1C7751E:
1C7751F:
1C7751G:
1C7751H:
1C7751J:
1C7751L:
1C7751M:
1C7751N:
1C77513N:
1CLN_AST_RES:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_S_PROFILE(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
177:
1+:
1FPUT:
1               ENTER:: SP_S_PROFILE(78) :: cplan.sql(14648) :: :
1IS NULL:
186:
1        RETURN_ERROR:: SP_S_PROFILE(87) :: cplan.sql(14657) :: :
1 :
1STATE:: :
1PMO_CNST:
1INVALID_PARAMS:
1 ID:: :
189:
1                EXIT:: SP_S_PROFILE(90) :: cplan.sql(14660) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1=:
12:
13:
1B:
1PROJECT_ID:
1TYPE_ID:
1A:
1MINUTE_PER_DAY:
1LEVEL_STATE:
1TMT_WBS:
1ELEMENT_ID:
1SELECT B.PROJECT_ID, B.TYPE_ID, COALESCE(A.MINUTE_PER_DAY, 480), B.LEVEL_STAT+
1E:n         INTO h_project_id, h_type_id, h_per_day, h_level_state:n         +
1FROM TMT_WBS A, TMT_WBS B WHERE B.ELEMENT_ID = h_id AND A.ELEMENT_ID = B.PROJ+
1ECT_ID:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1114:
1           EXCEPTION:: SP_S_PROFILE(115) :: cplan.sql(14685) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1TMT_CRI:
1SELECT B.PROJECT_ID, B.TYPE_ID, COALESCE(A.MINUTE_PER_DAY, 480):n            +
1INTO h_project_id, h_type_id, h_per_day:n            FROM TMT_WBS A, TMT_CRI +
1B WHERE B.ELEMENT_ID = h_id AND A.ELEMENT_ID = B.PROJECT_ID:
1133:
1           EXCEPTION:: SP_S_PROFILE(134) :: cplan.sql(14704) :: :
1TMT_POOLS:
1SELECT 480 INTO h_per_day FROM TMT_POOLS WHERE ELEMENT_ID = h_id:
1150:
1           EXCEPTION:: SP_S_PROFILE(151) :: cplan.sql(14721) :: :
1157:
1        RETURN_ERROR:: SP_S_PROFILE(158) :: cplan.sql(14728) :: :
1160:
1                EXIT:: SP_S_PROFILE(161) :: cplan.sql(14731) :: :
1ELSIF:
110:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID INTO h_project_id:n         FROM TASK_ASSIGNMENTS WHERE TSK+
1_ASSIGNMENT_ID = h_id:
1178:
1           EXCEPTION:: SP_S_PROFILE(179) :: cplan.sql(14749) :: :
1185:
1        RETURN_ERROR:: SP_S_PROFILE(186) :: cplan.sql(14756) :: :
1188:
1                EXIT:: SP_S_PROFILE(189) :: cplan.sql(14759) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480), LEVEL_STATE INTO h_per_day, h_level_sta+
1te:n         FROM TMT_WBS WHERE ELEMENT_ID = h_id:
1204:
1           EXCEPTION:: SP_S_PROFILE(205) :: cplan.sql(14775) :: :
113:
1RANK:
1SELECT RANK INTO h_rank FROM TMT_POOLS WHERE ELEMENT_ID = h_id:
1219:
1           EXCEPTION:: SP_S_PROFILE(220) :: cplan.sql(14790) :: :
1226:
1        RETURN_ERROR:: SP_S_PROFILE(227) :: cplan.sql(14797) :: :
1229:
1                EXIT:: SP_S_PROFILE(230) :: cplan.sql(14800) :: :
1480:
1!=:
1SC_SRCH_PARTICIPANT:
111:
1SC_ASSET_ASSIGNED_RESOURCES:
1SC_CLIENT_ASSIGNED_RESOURCES:
1SELECT COALESCE(MINUTE_PER_DAY, 480), LEVEL_STATE INTO h_per_day, h_level_sta+
1te:n         FROM TMT_WBS WHERE ELEMENT_ID = id001:
1249:
1           EXCEPTION:: SP_S_PROFILE(250) :: cplan.sql(14820) :: :
1256:
1        RETURN_ERROR:: SP_S_PROFILE(257) :: cplan.sql(14827) :: :
1259:
1                EXIT:: SP_S_PROFILE(260) :: cplan.sql(14830) :: :
1EXECUTE:
1IMMEDIATE:
1DELETE FROM PMO_TMP_ASGNDRES_INFO:
1PMO_TMP_ASGNDRES_INFO:
1RESOURCE_ID:
1PARENT_ID:
1RATE_ID:
1PROFICIENCY_LEVEL_ID:
1PREFERENCE_LEVEL_ID:
1EXPERIENCE_ID:
1LAST_USED_DATETIME:
1R:
1RESOURCE_ASSIGNMENTS:
1JOIN:
1TMT_COMPETENCIES:
1RESOURCE_TYPE:
1INSERT INTO PMO_TMP_ASGNDRES_INFO:n         (:n         RESOURCE_ID,:n       +
1  PARENT_ID,:n         RATE_ID,:n         PROFICIENCY_LEVEL_ID,:n         PRE+
1FERENCE_LEVEL_ID,:n         EXPERIENCE_ID,:n         LAST_USED_DATETIME:n    +
1     ):n         SELECT DISTINCT:n         a.RESOURCE_ID,:n         r.PARENT_+
1ID,:n         r.RATE_ID,:n         r.PROFICIENCY_LEVEL_ID,:n         r.PREFER+
1ENCE_LEVEL_ID,:n         r.EXPERIENCE_ID,:n         r.LAST_USED_DATETIME:n   +
1      FROM RESOURCE_ASSIGNMENTS a JOIN TMT_COMPETENCIES r ON a.RESOURCE_ID=r.+
1RESOURCE_ID:n         WHERE PROJECT_ID = h_id AND RESOURCE_TYPE = '0':
1FOUND:
1100:
1305:
1           EXCEPTION:: SP_S_PROFILE(306) :: cplan.sql(14876) :: :
1DELETE FROM PMO_TMP_PROF_INFO:
1PMO_TMP_PROF_INFO:
1PROFILE_ID:
1INSERT INTO PMO_TMP_PROF_INFO (PROFILE_ID):n         SELECT DISTINCT RESOURCE+
1_ID:n         FROM RESOURCE_ASSIGNMENTS:n         WHERE PROJECT_ID = h_id AND+
1 RESOURCE_TYPE = '1':
1331:
1           EXCEPTION:: SP_S_PROFILE(332) :: cplan.sql(14902) :: :
1OPEN:
1TA:
1RES:
1RES_TYPE:
1P:
1FULL_NAME:
1ELEMENT_NAME:
1STATUS1_ID:
1E_MAIL_ADDRESS:
1D:
1ROLE_NAME:
1LAST_USED:
1RC:
1REGULAR_COST:
1REGULAR_SALE:
1SPECIAL_COST:
1SPECIAL_SALE:
1OBJECTIVES:
1LOGON_NAME:
1RPM_LOGON_NAME:
1NICK_NAME:
1WORK_LOCATION:
1WORK_PHONE:
1RESOURCES:
1C:
1LEFT:
1OUTER:
1RATES:
1PRF:
1PROFILE_NAME:
1PROFILES:
1ROLE_ID:
1RESOURCE_ASSIGN_SKILLS:
1S:
1RES_ASSIGNMENT_ID:
1SKILL_ID:
1RESOURCE_ASSIGN_ROLES:
1SELECT CASE WHEN EXISTS(SELECT * FROM TASK_ASSIGNMENTS ta WHERE ta.PROJECT_ID+
1=h_id AND ta.RESOURCE_ID = RES.RESOURCE_ID) THEN 13 ELSE 185 END AS RES_TYPE,+
1:n      RES.RESOURCE_ID, p.FULL_NAME AS ELEMENT_NAME, p.STATUS1_ID, p.E_MAIL_+
1ADDRESS, d.TYPE_ID, d.ELEMENT_NAME AS ROLE_NAME,:n      RES.PROFICIENCY_LEVEL+
1_ID, RES.PREFERENCE_LEVEL_ID, RES.EXPERIENCE_ID, RES.LAST_USED_DATETIME AS LA+
1ST_USED,rc.REGULAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE, '' A+
1S OBJECTIVES,'' AS RANK,:n      p.LOGON_NAME AS RPM_LOGON_NAME, p.NICK_NAME, +
1p.WORK_LOCATION, p.WORK_PHONE:n      FROM PMO_TMP_ASGNDRES_INFO RES :n      J+
1OIN RESOURCES p ON RES.RESOURCE_ID=p.RESOURCE_ID:n      JOIN TMT_COMPETENCIES+
1 c ON c.ELEMENT_ID=RES.PARENT_ID:n      JOIN TMT_COMPETENCIES d ON d.ELEMENT_+
1ID=c.PARENT_ID:n      LEFT OUTER JOIN RATES rc ON rc.RATE_ID=RES.RATE_ID:n   +
1   :n      UNION ALL:n      :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID AS R+
1ESOURCE_ID, p.PROFILE_NAME AS ELEMENT_NAME, 0 AS STATUS1_ID, '' AS E_MAIL_ADD+
1RESS,:n      c.TYPE_ID, c.ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_LEV+
1EL_ID, r.PREFERENCE_LEVEL_ID,r.EXPERIENCE_ID,r.LAST_USED_DATETIME AS LAST_USE+
1D,:n      rc.REGULAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE,'' +
1AS OBJECTIVES,'' AS RANK,:n      '' AS RPM_LOGON_NAME, '' AS NICK_NAME, 0 AS +
1WORK_LOCATION, '' AS WORK_PHONE:n      FROM PMO_TMP_PROF_INFO PRF  JOIN PROFI+
1LES p ON PRF.PROFILE_ID=p.PROFILE_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES +
1r ON p.ROLE_ID=r.ELEMENT_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES c ON c.EL+
1EMENT_ID=r.PARENT_ID:n      LEFT OUTER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID+
1:n      :n      UNION ALL:n      :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID+
1 AS RESOURCE_ID,p.PROFILE_NAME AS ELEMENT_NAME,0 AS STATUS1_ID,'' AS E_MAIL_A+
1DDRESS,:n      c.TYPE_ID, c.ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_L+
1EVEL_ID, r.PREFERENCE_LEVEL_ID, r.EXPERIENCE_ID, r.LAST_USED_DATETIME AS LAST+
1_USED,:n      rc.REGULAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE+
1, '' AS OBJECTIVES,'' AS RANK,:n      '' AS RPM_LOGON_NAME, '' AS NICK_NAME, +
10 AS WORK_LOCATION, '' AS WORK_PHONE:n      FROM PMO_TMP_PROF_INFO PRF JOIN P+
1ROFILES p ON PRF.PROFILE_ID=p.PROFILE_ID:n      JOIN RESOURCE_ASSIGN_SKILLS s+
1 ON p.PROFILE_ID=s.RES_ASSIGNMENT_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES +
1r ON s.SKILL_ID=r.ELEMENT_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES c ON c.E+
1LEMENT_ID=r.PARENT_ID:n      LEFT OUTER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID+
1:n      :n      UNION ALL:n      :n      SELECT 41 AS RES_TYPE,PRF.PROFILE_ID+
1 AS RESOURCE_ID,p.PROFILE_NAME AS ELEMENT_NAME,0 AS STATUS1_ID,'' AS E_MAIL_A+
1DDRESS,:n      c.TYPE_ID, c.ELEMENT_NAME AS ROLE_NAME,:n      r.PROFICIENCY_L+
1EVEL_ID, r.PREFERENCE_LEVEL_ID, r.EXPERIENCE_ID, r.LAST_USED_DATETIME AS LAST+
1_USED,:n      rc.REGULAR_COST,rc.REGULAR_SALE,rc.SPECIAL_COST,rc.SPECIAL_SALE+
1, '' AS OBJECTIVES,'' AS RANK,:n      '' AS RPM_LOGON_NAME, '' AS NICK_NAME, +
10 AS WORK_LOCATION, '' AS WORK_PHONE:n      FROM PMO_TMP_PROF_INFO PRF JOIN P+
1ROFILES p ON PRF.PROFILE_ID=p.PROFILE_ID:n      JOIN RESOURCE_ASSIGN_ROLES s +
1ON p.PROFILE_ID=s.RES_ASSIGNMENT_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES r+
1 ON s.ROLE_ID=r.ELEMENT_ID:n      LEFT OUTER JOIN TMT_COMPETENCIES c ON c.ELE+
1MENT_ID=r.PARENT_ID:n      LEFT OUTER JOIN RATES rc ON rc.RATE_ID=r.RATE_ID:n+
1      ORDER BY RES_TYPE, RESOURCE_ID, TYPE_ID:
1385:
1                EXIT:: SP_S_PROFILE(386) :: cplan.sql(14956) :: :
16:
1DELETE FROM PMO_TMP_RES_DATA:
1PMO_TMP_RES_DATA:
1RA:
1PROJECT_ASSIGNMENT_ID:
1T:
1TASK_ID:
1INSERT INTO PMO_TMP_RES_DATA (RESOURCE_ID, TYPE_ID):n         SELECT DISTINCT+
1:n         ra.RESOURCE_ID,:n         CASE WHEN ta.TSK_ASSIGNMENT_ID IS NuLL T+
1HEN 185 ELSE 13 END AS TYPE_ID:n         FROM RESOURCE_ASSIGNMENTS ra LEFT OU+
1TER JOIN TASK_ASSIGNMENTS ta ON ta.PROJECT_ID=h_id AND ra.RESOURCE_ID = ta.RE+
1SOURCE_ID:n         WHERE ra.PROJECT_ID=h_id AND ra.RESOURCE_TYPE='0' AND ta.+
1PROJECT_ASSIGNMENT_ID IS NuLL AND:n         NOT EXISTS(SELECT * FROM TASK_ASS+
1IGNMENTS t WHERE ra.RESOURCE_ID = t.RESOURCE_ID AND t.TASK_ID=h_id):
1414:
1           EXCEPTION:: SP_S_PROFILE(415) :: cplan.sql(14985) :: :
1FC_U_CREATETMPTABLE:
1PMO_TMP_CPLN01_TEMP:
1ELEMENT_TYPE:
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME):n         SELECT DIS+
1TINCT r.PROFILE_ID ,r.PROFILE_NAME:n         FROM RESOURCE_ASSIGNMENTS a JOIN+
1 PROFILES r ON a.RESOURCE_TYPE='1' AND r.PROFILE_ID=a.RESOURCE_ID :n         +
1JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.ROLE_ID:n         JOIN TMT_COMPETEN+
1CIES d ON d.ELEMENT_ID=c.PARENT_ID :n         JOIN TASK_ASSIGNMENTS t ON t.RE+
1S_ASSIGNMENT_ID=a.RES_ASSIGNMENT_ID AND t.PROJECT_ASSIGNMENT_ID IS NuLL:n    +
1     WHERE a.PROJECT_ID=h_id AND a.ELEMENT_TYPE>1:
1441:
1           EXCEPTION:: SP_S_PROFILE(442) :: cplan.sql(15012) :: :
1TO_TIMESTAMP:
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_EFFORT:
1START_DATE:
1FINISH_DATE:
1WORK:
1REMAINING:
1T_UNIT:
1BEST_START:
1BEST_FINISH:
1CALENDAR:
1PLANNED_WORK:
1PERIOD_AVAILABILITY:
1ASSIGN_STRING:
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, p.FULL_NAME AS EL+
1EMENT_NAME,a.TYPE_ID,p.E_MAIL_ADDRESS,:n      TO_TIMESTAMP('1899-12-31 00::00+
1::00') AS PLANNED_START, TO_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_FIN+
1ISH,0 AS PLANNED_EFFORT,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS STAR+
1T_DATE, TO_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DATE, 0 AS WORK, 0 AS+
1 REMAINING,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,'' AS BEST_START,'' AS BES+
1T_FINISH,:n      0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, +
1'' AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,:n      p.LOGON_NAME AS RPM_+
1LOGON_NAME, p.NICK_NAME, p.WORK_LOCATION, p.WORK_PHONE:n      FROM PMO_TMP_RE+
1S_DATA a JOIN RESOURCES p ON a.RESOURCE_ID=p.RESOURCE_ID:n      :n      UNION+
1 ALL:n      :n      SELECT ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, ELEMENT_NAME,4+
11 AS TYPE_ID,'' AS E_MAIL_ADDRESS,:n      TO_TIMESTAMP('1899-12-31 00::00::00+
1') AS PLANNED_START, TO_TIMESTAMP('1899-12-31 00::00::00') AS PLANNED_FINISH,+
10 AS PLANNED_EFFORT,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS START_DA+
1TE, TO_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DATE, 0 AS WORK, 0 AS REM+
1AINING,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  A+
1S BEST_FINISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' +
1AS ASSIGN_STRING, '' AS OBJECTIVES,'' AS RANK,:n      '' AS RPM_LOGON_NAME, '+
1' AS NICK_NAME, 0 AS WORK_LOCATION, '' AS WORK_PHONE:n      FROM PMO_TMP_CPLN+
101_TEMP:n      ORDER BY TYPE_ID:
1463:
1                EXIT:: SP_S_PROFILE(464) :: cplan.sql(15034) :: :
1PARTICIPANT:
1START_DT:
1FINISH_DT:
1SECURITY_ID:
1G:
1SECURITY_NAME:
1CRI_SECURITY_ID:
1G2:
1CRI_SECURITY_NAME:
1REGULAR_RATE:
1SPECIAL_RATE:
1FS_LABOR_CODE:
1REC_STATUS:
1TIMECODE2_ID:
1TC:
1TIMECODE2:
1C_EFFORT:
1C_UNIT:
1C_CONTOUR:
1CONTOUR_TYPE:
1C_OCCURRENCE:
1BILLABLE:
1ASSIGNMENT_DELAY:
1TMT_GLOBAL_SECURITY:
1TMT_TIMECODES:
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID,:n      a.PROFILE_ID, p.PROFILE_NAME +
1AS ELEMENT_NAME,41 AS TYPE_ID,a.RES_ASSIGNMENT_ID, a.PARTICIPANT, t.PLANNED_S+
1TART,t.PLANNED_FINISH,:n      t.PLANNED_WORK,t.START_DT,t.FINISH_DT,h_per_day+
1 AS MINUTE_PER_DAY, a.WORK_LOCATION, a.SECURITY_ID, g.ELEMENT_NAME AS SECURIT+
1Y_NAME,:n      COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, +
1g2.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SPECIAL+
1_COST,t.SPECIAL_RATE,'' AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,:n     +
1 t.PROJECT_ASSIGNMENT_ID,t.TIMECODE2_ID,TC.ELEMENT_NAME AS TIMECODE2, t.T_UNI+
1T, t.C_EFFORT, t.C_UNIT, t.C_CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, BILLABL+
1E,:n      t.ASSIGNMENT_DELAY:n      FROM RESOURCE_ASSIGNMENTS a LEFT OUTER JO+
1IN TASK_ASSIGNMENTS t ON t.TASK_ID = h_id AND a.RES_ASSIGNMENT_ID = t.RES_ASS+
1IGNMENT_ID:n      LEFT OUTER JOIN PROFILES p ON a.RESOURCE_ID = p.PROFILE_ID +
1LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=g.ELEMENT_ID:n      LE+
1FT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY+
1_ID)=g2.ELEMENT_ID:n      LEFT OUTER JOIN TMT_TIMECODES TC ON TC.ELEMENT_ID= +
1t.TIMECODE2_ID:n      WHERE a.ELEMENT_ID = h_id AND a.RESOURCE_TYPE='1' ORDER+
1 BY ELEMENT_NAME:
1479:
1                EXIT:: SP_S_PROFILE(480) :: cplan.sql(15050) :: :
1:
1DESCRIPTION:
1TMT_WBS_ATTRIBUTES:
1SELECT COALESCE(DESCRIPTION, '') INTO h_cq_owner FROM TMT_WBS_ATTRIBUTES :n  +
1       WHERE PARENT_ID = 'RPM_CQ_WBS_ATTR_VALUE_CQ_A_RES__' :n         AND EL+
1EMENT_ID = h_id:
1           EXCEPTION:: SP_S_PROFILE(501) :: cplan.sql(15071) :: :
1PMO_ORASTD:
1STRCMP:
1SELECT COALESCE(DESCRIPTION, '') INTO h_cq_owner FROM TMT_WBS_ATTRIBUTES :n  +
1          WHERE PARENT_ID = 'RPM_CQ_WBS_ATTR_VALUE_CQ_OWNER__' :n            +
1AND ELEMENT_ID = h_id:
1521:
1           EXCEPTION:: SP_S_PROFILE(522) :: cplan.sql(15092) :: :
1SELECT RESOURCE_ID INTO h_cq_resid :n               FROM RESOURCES WHERE LOGO+
1N_NAME = h_cq_owner:
1543:
1           EXCEPTION:: SP_S_PROFILE(544) :: cplan.sql(15114) :: :
1SELECT RESOURCE_ID INTO h_cq_resid :n            FROM RESOURCES WHERE LOGON_N+
1AME = h_cq_owner:
1561:
1           EXCEPTION:: SP_S_PROFILE(562) :: cplan.sql(15132) :: :
1ISTASK:
1COUNT:
1SELECT COUNT(*) INTO h_count FROM TASK_ASSIGNMENTS WHERE PROJECT_ID = h_proje+
1ct_id AND TASK_ID = h_id:
1580:
1           EXCEPTION:: SP_S_PROFILE(581) :: cplan.sql(15151) :: :
1DUAL:
1BIT_FLAG:
1SELECT COUNT('X') INTO h_count FROM DUAL WHERE EXISTS (:n               SELEC+
1T 'X' FROM TASK_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND TASK_ID = h_i+
1d AND BIT_FLAG = '0'):
1600:
1           EXCEPTION:: SP_S_PROFILE(601) :: cplan.sql(15171) :: :
1TIMESHEET_APPROVAL_STATUS:
1APV:
1TO_DATE:
1ACTUAL_START:
1WEEK_OF:
1SELECT COUNT('X') INTO h_count FROM DUAL WHERE EXISTS (:n                  SE+
1LECT 'X' FROM TASK_ASSIGNMENTS ta JOIN TIMESHEET_APPROVAL_STATUS apv:n       +
1           ON apv.ELEMENT_ID = ta.PROJECT_ID AND apv.RESOURCE_ID = ta.RESOURC+
1E_ID:n                  WHERE ta.PROJECT_ID = h_project_id AND ta.TASK_ID = h+
1_id AND:n                  (TO_DATE(SubStr(ta.ACTUAL_START, 1, 10)) - 7     )+
1 <= apv.WEEK_OF):
1620:
1           EXCEPTION:: SP_S_PROFILE(621) :: cplan.sql(15191) :: :
1SD:
1FD:
1SCHED_EFFORT:
1WORK_TODATE:
1UNITS_PERCENT:
1PLANNED_PERCENT:
1MILESTONE_PERCENT:
1TRUNC:
1TO_NUMBER:
1WORK_PERCENT:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1FORECAST_START:
1FORECAST_FINISH:
1ETC:
1ACTUAL_FINISH:
1ACTUAL:
1PROPOSED_START:
1PROPOSED_FINISH:
1PROPOSED_EFFORT:
1PROPOSED_WORK:
1CLOB_DATA:
1EMPTYLOB:
1BASELINE1_START:
1BASELINE1_FINISH:
1BASELINE1_EFFORT:
1BASELINE1_WORK:
1TIMECODE2_NAME:
1CAPITAL_EXPENSE:
1RATE_ADJUSTMENT:
1ASSIGN_COUNT:
1DURATION:
1LEVEL_START:
1LEVEL_FINISH:
1LEVEL_DURATION:
1LEVEL_EFFORT:
1PERCENT_DISCRETE:
1TOP_ID:
1LEVEL_AFFECTED_FLAG:
1LABOR_COST_CC_ID:
1LABOR_COST_CC_NAME:
1LABOR_REVENUE_CC_ID:
1LABOR_REVENUE_CC_NAME:
1DEFAULT_LABOR_FLAG:
1CONTRACT_ID:
1CONTRACT_NAME:
1EXTERNAL_ID:
1CQ_RESOURCE_ID:
1CQ_LOGON_NAME:
1CQ_TASK_ID:
1BASELINE3_START:
1BASELINE3_FINISH:
1BASELINE3_EFFORT:
1BASELINE3_WORK:
1SCHED_FINISH:
1SC_UFS:
1SC_FS:
1SC_SS:
1SC_FF:
1SC_SF:
1SCHED_START:
1SCHED_WORK:
1ASSIGN_UNITS:
1UNITS_MSP:
1PLANNED_UNITS:
1SCHED_DURATION:
1PLANNED_DURATION:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1EC:
1CC:
1CTR:
1AP:
1TMT_CHARGECODES:
1TMT_CONTRACTS:
1SELECT t.ELEMENT_ID, a.RESOURCE_ID,:n         t.ELEMENT_NAME, :n         t.TY+
1PE_ID, '' AS RES_ASSIGNMENT_ID, a.PARTICIPANT, t.START_DT,t.FINISH_DT,:n     +
1    t.SD, t.FD, t.START_DT AS PLANNED_START, t.FINISH_DT AS PLANNED_FINISH,:n+
1         t.SCHED_EFFORT + t.PLANNED_EFFORT AS PLANNED_WORK, t.SCHED_EFFORT + +
1t.PLANNED_EFFORT - t.WORK_TODATE AS REMAINING,:n         0 UNITS_PERCENT, 0 A+
1S PLANNED_PERCENT, t.MILESTONE_PERCENT,:n         CASE WHEN t.WORK_TODATE = 0+
1 THEN 0 ELSE Trunc((TO_NUMBER(t.WORK_TODATE)/TO_NUMBER(t.SCHED_EFFORT + t.PLA+
1NNED_EFFORT))*10000) END AS WORK_PERCENT,:n         TO_TIMESTAMP('1899-12-31 +
100::00::00') AS BAK_START_DT,TO_TIMESTAMP('1899-12-31 00::00::00') AS BAK_FIN+
1ISH_DT,0 AS BAK_WORK,:n         t.FORECAST_START,t.FORECAST_FINISH,t.ETC, t.A+
1CTUAL_START,t.ACTUAL_FINISH,:n         t.WORK_TODATE AS ACTUAL,t.PROPOSED_STA+
1RT, t.PROPOSED_FINISH, t.PROPOSED_EFFORT AS PROPOSED_WORK,:n         h_per_da+
1y AS MINUTE_PER_DAY, :n         0 AS WORK_LOCATION, :n         '' AS SECURITY+
1_ID, '' AS SECURITY_NAME,:n         '' AS CRI_SECURITY_ID, '' AS CRI_SECURITY+
1_NAME, 0.00 AS REGULAR_COST,0.00 AS REGULAR_RATE,0.00 AS SPECIAL_COST,0.00 AS+
1 SPECIAL_RATE,:n         '' AS FS_LABOR_CODE,t.REC_STATUS,(SELECT CLOB_DATA F+
1ROM EMPTYLOB) AS ASSIGN_STRING,t.BASELINE1_START,t.BASELINE1_FINISH,t.BASELIN+
1E1_EFFORT AS BASELINE1_WORK,:n         '' AS PROJECT_ASSIGNMENT_ID,'' AS TIME+
1CODE2_ID, '' AS TIMECODE2_NAME, 0 AS T_UNIT, 0 AS C_EFFORT, 0 AS C_UNIT, 0 AS+
1 C_CONTOUR, 0 AS CONTOUR_TYPE, 0 AS C_OCCURRENCE, 0 AS BILLABLE, T.CAPITAL_EX+
1PENSE AS CAPITAL_EXPENSE,:n         0 AS ASSIGNMENT_DELAY, h_bit_flag AS BIT_+
1FLAG, 0 AS RATE_ADJUSTMENT, t.ASSIGN_COUNT, t.DURATION,:n         CASE WHEN h+
1_level_state = 1 THEN t.LEVEL_START ELSE TO_TIMESTAMP('1899-12-31 00::00::00'+
1) END AS LEVEL_START,:n         CASE WHEN h_level_state = 1 THEN t.LEVEL_FINI+
1SH ELSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_FINISH,:n         +
1CASE WHEN h_level_state = 1 THEN t.LEVEL_DURATION ELSE 0 END AS LEVEL_EFFORT,+
1 t.WORK_PERCENT AS PERCENT_DISCRETE, 0 as TOP_ID, '0' AS LEVEL_AFFECTED_FLAG,+
1:n         '' AS LABOR_COST_CC_ID, '' AS LABOR_COST_CC_NAME, '' AS LABOR_REVE+
1NUE_CC_ID, '' AS LABOR_REVENUE_CC_NAME, 'N' AS DEFAULT_LABOR_FLAG,:n         +
1'' AS CONTRACT_ID, '' AS CONTRACT_NAME, '' AS EXTERNAL_ID,:n         t.ELEMEN+
1T_NAME AS RPM_LOGON_NAME, h_cq_resid AS CQ_RESOURCE_ID, :n         h_cq_owner+
1 AS CQ_LOGON_NAME, h_id AS CQ_TASK_ID,:n         '' AS E_MAIL_ADDRESS, '' AS +
1WORK_PHONE, '' AS NICK_NAME, '' AS PROFILE_NAME,t.BASELINE3_START,t.BASELINE3+
1_FINISH,t.BASELINE3_EFFORT AS BASELINE3_WORK :n         FROM TMT_WBS t :n    +
1     LEFT JOIN RESOURCE_ASSIGNMENTS a ON a.ELEMENT_ID = t.ELEMENT_ID :n      +
1   AND a.RESOURCE_ID = h_rec_user:n         LEFT OUTER JOIN TMT_GLOBAL_SECURI+
1TY g ON a.SECURITY_ID=g.ELEMENT_ID:n         WHERE t.PROJECT_ID = h_project_i+
1d :n         AND t.ELEMENT_ID = h_id:n         :n         UNION ALL:n        +
1 :n         SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIG+
1NMENT_ID ELSE a.RES_ASSIGNMENT_ID END AS ELEMENT_ID, a.RESOURCE_ID,:n        +
1 CASE WHEN a.RESOURCE_TYPE='1' THEN (SELECT p.PROFILE_NAME FROM PROFILES p WH+
1ERE a.RESOURCE_ID = p.PROFILE_ID):n         ELSE (SELECT r.FULL_NAME FROM RES+
1OURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID) END AS ELEMENT_NAME,:n         +
1CASE WHEN a.RESOURCE_TYPE='1' THEN 41 WHEN t.TSK_ASSIGNMENT_ID IS NuLL THEN 1+
185 ELSE 13 END AS TYPE_ID,:n         a.RES_ASSIGNMENT_ID, a.PARTICIPANT, t.ST+
1ART_DT, COALESCE(PLANNED_FINISH,SCHED_FINISH) AS FINISH_DT,:n         CASE WH+
1EN t.SD = pmo_cnst.SC_UFS OR t.SD = pmo_cnst.SC_FS THEN pmo_cnst.SC_SS ELSE t+
1.SD END AS SD, CASE WHEN t.FD = pmo_cnst.SC_FF THEN pmo_cnst.SC_SF ELSE t.FD +
1END AS FD, :n         COALESCE(PLANNED_START,SCHED_START) AS PLANNED_START, C+
1OALESCE(PLANNED_FINISH,SCHED_FINISH) AS PLANNED_FINISH,:n         CASE WHEN t+
1.BIT_FLAG = '2' THEN t.SCHED_WORK ELSE t.PLANNED_WORK END AS PLANNED_WORK,:n +
1        CASE WHEN t.BIT_FLAG = '2' THEN t.SCHED_WORK - t.WORK_TODATE ELSE t.P+
1LANNED_WORK END AS REMAINING,:n         CASE WHEN t.ASSIGN_UNITS > t.UNITS_MS+
1P THEN t.ASSIGN_UNITS ELSE t.UNITS_MSP END AS UNITS_PERCENT,:n         t.PLAN+
1NED_UNITS AS PLANNED_PERCENT,:n         0 AS MILESTONE_PERCENT,:n         CAS+
1E WHEN t.WORK_TODATE = 0 THEN 0 ELSE Trunc((TO_NUMBER(t.WORK_TODATE)/TO_NUMBE+
1R(PLANNED_WORK+SCHED_WORK))*10000) END AS WORK_PERCENT,:n         t.BAK_START+
1_DT,t.BAK_FINISH_DT,t.BAK_WORK,:n         t.FORECAST_START,t.FORECAST_FINISH,+
1t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n         t.WORK_TODATE AS ACTUAL,PROP+
1OSED_START, PROPOSED_FINISH, PROPOSED_WORK,:n         h_per_day AS MINUTE_PER+
1_DAY, :n         CASE WHEN a.RESOURCE_TYPE='1' THEN a.WORK_LOCATION:n        +
1 ELSE (SELECT R.WORK_LOCATION FROM RESOURCES R WHERE a.RESOURCE_ID = R.RESOUR+
1CE_ID) END AS WORK_LOCATION,:n         a.SECURITY_ID, g.ELEMENT_NAME AS SECUR+
1ITY_NAME,:n         COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY+
1_ID, g2.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SP+
1ECIAL_COST,t.SPECIAL_RATE,:n         CASE WHEN a.RESOURCE_TYPE='0' THEN (SELE+
1CT r.FS_LABOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n   +
1      ELSE '' END AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,t.BASELINE1_S+
1TART,t.BASELINE1_FINISH,t.BASELINE1_WORK,:n         t.PROJECT_ASSIGNMENT_ID,t+
1.TIMECODE2_ID, TC.ELEMENT_NAME AS TIMECODE2_NAME, t.T_UNIT, t.C_EFFORT, t.C_U+
1NIT, t.C_CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, t.BILLABLE, t.CAPITAL_EXPEN+
1SE,:n         t.ASSIGNMENT_DELAY, CASE WHEN t.BIT_FLAG IS NuLL THEN '' WHEN t+
1.BIT_FLAG = '0' THEN '1' ELSE '2' END AS BIT_FLAG, t.RATE_ADJUSTMENT, 0 AS AS+
1SIGN_COUNT, :n         CASE WHEN t.BIT_FLAG = '2' THEN t.SCHED_DURATION ELSE +
1t.PLANNED_DURATION END AS DURATION,:n         CASE WHEN h_level_state = 1 THE+
1N COALESCE(t.LEVEL_START,t.UNRESOLVED_START) ELSE TO_TIMESTAMP('1899-12-31 00+
1::00::00') END AS LEVEL_START,:n         CASE WHEN h_level_state = 1 THEN COA+
1LESCE(t.LEVEL_FINISH,t.UNRESOLVED_FINISH) ELSE TO_TIMESTAMP('1899-12-31 00::0+
10::00') END AS LEVEL_FINISH,:n         CASE WHEN h_level_state = 1 THEN CASE +
1WHEN t.LEVEL_EFFORT = 0 THEN t.ETC ELSE t.LEVEL_EFFORT END ELSE 0 END AS LEVE+
1L_EFFORT, t.MILESTONE_PERCENT AS PERCENT_DISCRETE, 1 as TOP_ID, '0' AS LEVEL_+
1AFFECTED_FLAG,:n         T.LABOR_COST_CC_ID,:n         EC.ELEMENT_NAME AS LAB+
1OR_COST_CC_NAME,:n         T.LABOR_REVENUE_CC_ID,:n         CC.ELEMENT_NAME A+
1S LABOR_REVENUE_CC_NAME, T.DEFAULT_LABOR_FLAG,:n         T.CONTRACT_ID, CTR.E+
1LEMENT_NAME AS CONTRACT_NAME,:n         CASE WHEN a.RESOURCE_TYPE= '0' THEN (+
1SELECT r.EXTERNAL_ID FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID) EL+
1SE '' END AS EXTERNAL_ID,:n         CASE WHEN a.RESOURCE_TYPE='1' THEN (SELEC+
1T p.PROFILE_NAME FROM PROFILES p WHERE a.RESOURCE_ID = p.PROFILE_ID):n       +
1  ELSE (SELECT r.LOGON_NAME FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE+
1_ID) END AS RPM_LOGON_NAME,:n         h_cq_resid AS CQ_RESOURCE_ID, :n       +
1  h_cq_owner AS CQ_LOGON_NAME, h_id AS CQ_TASK_ID,:n         CASE WHEN a.RESO+
1URCE_TYPE='1' THEN '' :n         ELSE (SELECT R.E_MAIL_ADDRESS FROM RESOURCES+
1 R WHERE a.RESOURCE_ID = R.RESOURCE_ID) END AS E_MAIL_ADDRESS,:n         CASE+
1 WHEN a.RESOURCE_TYPE='1' THEN '' :n         ELSE (SELECT R.WORK_PHONE FROM R+
1ESOURCES R WHERE a.RESOURCE_ID = R.RESOURCE_ID) END AS WORK_PHONE,:n         +
1CASE WHEN a.RESOURCE_TYPE='1' THEN '' :n         ELSE (SELECT R.NICK_NAME FRO+
1M RESOURCES R WHERE a.RESOURCE_ID = R.RESOURCE_ID) END AS NICK_NAME,:n       +
1  CASE WHEN a.RESOURCE_TYPE='0' THEN p.PROFILE_NAME WHEN a.RESOURCE_TYPE='1' +
1THEN ap.PROFILE_NAME ELSE '' END AS PROFILE_NAME,:n         t.BASELINE3_START+
1,t.BASELINE3_FINISH,t.BASELINE3_WORK:n         FROM RESOURCE_ASSIGNMENTS a :n+
1         LEFT OUTER JOIN TASK_ASSIGNMENTS t ON a.RES_ASSIGNMENT_ID = t.RES_AS+
1SIGNMENT_ID:n         LEFT OUTER JOIN PROFILES p ON p.PROFILE_ID=a.PROFILE_ID+
1 :n         LEFT OUTER JOIN PROFILES ap ON a.RESOURCE_ID = ap.PROFILE_ID:n   +
1      LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=g.ELEMENT_ID:n  +
1       LEFT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESCE(a.CRI_SECURITY_ID,a+
1.SECURITY_ID)=g2.ELEMENT_ID:n         LEFT OUTER JOIN TMT_TIMECODES TC ON TC.+
1ELEMENT_ID= t.TIMECODE2_ID:n         LEFT OUTER JOIN TMT_CHARGECODES EC ON EC+
1.ELEMENT_ID = T.LABOR_COST_CC_ID:n         LEFT OUTER JOIN TMT_CHARGECODES CC+
1 ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_ID:n         LEFT OUTER JOIN TMT_CONTR+
1ACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT_ID:n         WHERE a.PROJECT_ID = h_p+
1roject_id AND a.ELEMENT_ID = h_id AND a.REC_STATUS NOT IN ('L','D'):n        +
1 :n         ORDER BY TOP_ID, ELEMENT_NAME:
1735:
1                EXIT:: SP_S_PROFILE(736) :: cplan.sql(15306) :: :
1TMT_ORGANIZATIONS:
1SC_PROFILE:
1SC_POOLS:
1SC_ORGANIZATION:
1SC_RESOURCE:
1BEST:
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID,a.RESOURCE_ID,:n         CASE WHEN a.+
1RESOURCE_TYPE='0' THEN (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.RESOURCE_+
1ID = r.RESOURCE_ID):n         WHEN a.RESOURCE_TYPE='1' THEN ap.PROFILE_NAME +
1:n         WHEN a.RESOURCE_TYPE='2' THEN (SELECT p.ELEMENT_NAME FROM TMT_POOL+
1S p WHERE a.RESOURCE_ID = p.ELEMENT_ID):n         ELSE (SELECT p.ELEMENT_NAME+
1 FROM TMT_ORGANIZATIONS p WHERE a.RESOURCE_ID = p.ELEMENT_ID) END AS ELEMENT_+
1NAME,:n         CASE WHEN a.RESOURCE_TYPE='1' THEN pmo_cnst.SC_PROFILE:n     +
1    WHEN a.RESOURCE_TYPE='2' THEN pmo_cnst.SC_POOLS :n         WHEN a.RESOURC+
1E_TYPE='3' THEN pmo_cnst.SC_ORGANIZATION :n         WHEN t.TSK_ASSIGNMENT_ID +
1IS NuLL THEN 185 ELSE pmo_cnst.SC_RESOURCE END AS TYPE_ID,:n         a.RES_AS+
1SIGNMENT_ID, a.PARTICIPANT, t.START_DT,t.FINISH_DT,:n         t.SD, t.FD, COA+
1LESCE(PLANNED_START,SCHED_START) AS PLANNED_START, COALESCE(PLANNED_FINISH,SC+
1HED_FINISH) AS PLANNED_FINISH,:n         t.BEST AS PLANNED_WORK, CASE WHEN t.+
1BIT_FLAG = '2' THEN t.SCHED_WORK ELSE t.PLANNED_WORK END AS REMAINING,:n     +
1    t.UNITS_MSP AS UNITS_PERCENT,:n         t.PLANNED_UNITS AS PLANNED_PERCEN+
1T,:n         t.MILESTONE_PERCENT, 0 AS WORK_PERCENT,:n         t.BAK_START_DT+
1,t.BAK_FINISH_DT,t.BAK_WORK,:n         t.FORECAST_START,t.FORECAST_FINISH,t.E+
1TC, t.ACTUAL_START,t.ACTUAL_FINISH,:n         t.WORK_TODATE AS ACTUAL,PROPOSE+
1D_START, PROPOSED_FINISH, PROPOSED_WORK,:n         h_per_day AS MINUTE_PER_DA+
1Y, :n         CASE WHEN a.RESOURCE_TYPE='1' THEN a.WORK_LOCATION:n         EL+
1SE (SELECT R.WORK_LOCATION FROM RESOURCES R WHERE a.RESOURCE_ID = R.RESOURCE_+
1ID) END AS WORK_LOCATION,:n         a.SECURITY_ID, g.ELEMENT_NAME AS SECURITY+
1_NAME,:n         COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID+
1, g2.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SPECI+
1AL_COST,t.SPECIAL_RATE,:n         CASE WHEN a.RESOURCE_TYPE='0' THEN (SELECT +
1r.FS_LABOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n      +
1   ELSE '' END AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,t.BASELINE1_STAR+
1T,t.BASELINE1_FINISH,t.BASELINE1_WORK,:n         t.PROJECT_ASSIGNMENT_ID,t.TI+
1MECODE2_ID, TC.ELEMENT_NAME AS TIMECODE2_NAME, t.T_UNIT, t.C_EFFORT, t.C_UNIT+
1, t.C_CONTOUR, t.CONTOUR_TYPE, t.C_OCCURRENCE, t.BILLABLE, t.CAPITAL_EXPENSE,+
1:n         t.ASSIGNMENT_DELAY, CASE WHEN t.BIT_FLAG IS NuLL THEN '' WHEN t.BI+
1T_FLAG = '0' THEN '1' ELSE '2' END AS BIT_FLAG, t.RATE_ADJUSTMENT, 0 AS ASSIG+
1N_COUNT, 0 AS DURATION,:n         t.LEVEL_START, t.LEVEL_FINISH, t.LEVEL_EFFO+
1RT, t.MILESTONE_PERCENT AS PERCENT_DISCRETE, 0 as TOP_ID,:n         CASE WHEN+
1 t.TSK_ASSIGNMENT_ID IS NOT NuLL AND t.PROJECT_ASSIGNMENT_ID = t.TSK_ASSIGNME+
1NT_ID AND (t.LEVEL_START <> t.UNRESOLVED_START OR t.LEVEL_FINISH <> t.UNRESOL+
1VED_FINISH) THEN '1' ELSE '0' END AS LEVEL_AFFECTED_FLAG,:n         T.LABOR_C+
1OST_CC_ID,:n         EC.ELEMENT_NAME AS LABOR_COST_CC_NAME,:n         T.LABOR+
1_REVENUE_CC_ID,:n         CC.ELEMENT_NAME AS LABOR_REVENUE_CC_NAME, T.DEFAULT+
1_LABOR_FLAG,:n         T.CONTRACT_ID, CTR.ELEMENT_NAME AS CONTRACT_NAME,:n   +
1      CASE WHEN a.RESOURCE_TYPE= '0' THEN (SELECT r.EXTERNAL_ID FROM RESOURCE+
1S r WHERE a.RESOURCE_ID = r.RESOURCE_ID) ELSE '' END AS EXTERNAL_ID,:n       +
1  CASE WHEN a.RESOURCE_TYPE='1' THEN (SELECT p.PROFILE_NAME FROM PROFILES p W+
1HERE a.RESOURCE_ID = p.PROFILE_ID):n         ELSE (SELECT r.LOGON_NAME FROM R+
1ESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID) END AS RPM_LOGON_NAME,:n     +
1    h_cq_resid AS CQ_RESOURCE_ID, :n         h_cq_owner AS CQ_LOGON_NAME, h_i+
1d AS CQ_TASK_ID,:n         CASE WHEN a.RESOURCE_TYPE='1' THEN '' :n         E+
1LSE (SELECT R.WORK_PHONE FROM RESOURCES R WHERE a.RESOURCE_ID = R.RESOURCE_ID+
1) END AS WORK_PHONE,:n         CASE WHEN a.RESOURCE_TYPE='1' THEN '' :n      +
1   ELSE (SELECT R.NICK_NAME FROM RESOURCES R WHERE a.RESOURCE_ID = R.RESOURCE+
1_ID) END AS NICK_NAME,:n         CASE WHEN a.RESOURCE_TYPE='0' THEN p.PROFILE+
1_NAME WHEN a.RESOURCE_TYPE='1' THEN ap.PROFILE_NAME ELSE '' END AS PROFILE_NA+
1ME,:n         t.BASELINE3_START,t.BASELINE3_FINISH,t.BASELINE3_WORK:n        +
1 FROM RESOURCE_ASSIGNMENTS a LEFT OUTER JOIN TASK_ASSIGNMENTS t ON a.RES_ASSI+
1GNMENT_ID = t.RES_ASSIGNMENT_ID:n         LEFT OUTER JOIN PROFILES p ON p.PRO+
1FILE_ID=a.PROFILE_ID:n         LEFT OUTER JOIN PROFILES ap ON a.RESOURCE_ID =+
1 ap.PROFILE_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_+
1ID=g.ELEMENT_ID:n         LEFT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESCE(+
1a.CRI_SECURITY_ID,a.SECURITY_ID)=g2.ELEMENT_ID:n         LEFT OUTER JOIN TMT_+
1TIMECODES TC ON TC.ELEMENT_ID= t.TIMECODE2_ID:n         LEFT OUTER JOIN TMT_C+
1HARGECODES EC ON EC.ELEMENT_ID = T.LABOR_COST_CC_ID:n         LEFT OUTER JOIN+
1 TMT_CHARGECODES CC ON CC.ELEMENT_ID = T.LABOR_REVENUE_CC_ID:n         LEFT O+
1UTER JOIN TMT_CONTRACTS CTR ON CTR.ELEMENT_ID = T.CONTRACT_ID:n         WHERE+
1 a.REC_STATUS NOT IN ('L','D') AND a.ELEMENT_ID = h_id:n         ORDER BY TYP+
1E_ID, ELEMENT_NAME:
1798:
1                EXIT:: SP_S_PROFILE(799) :: cplan.sql(15369) :: :
14:
1DELETE FROM PMO_TMP_RES_SET:
1PMO_TMP_RES_SET:
1MIN:
1MAX:
1SUM:
1INSERT INTO PMO_TMP_RES_SET:n         (:n         RESOURCE_ID,:n         RESO+
1URCE_TYPE ,:n         PLANNED_START ,:n         PLANNED_FINISH ,:n         PL+
1ANNED_EFFORT ,:n         START_DATE ,:n         FINISH_DATE ,:n         WORK +
1,:n         REMAINING:n         ):n         SELECT:n         RESOURCE_ID,:n  +
1       RESOURCE_TYPE,:n         MIN(PLANNED_START) AS PLANNED_START,:n       +
1  MAX(PLANNED_FINISH) AS PLANNED_FINISH,:n         SUM(PLANNED_WORK) AS PLANN+
1ED_EFFORT,:n         MIN(SCHED_START) AS START_DATE,:n         MAX(SCHED_FINI+
1SH) AS FINISH_DATE,:n         SUM(SCHED_WORK) AS WORK,:n         SUM(ETC) AS +
1REMAINING:n         FROM TASK_ASSIGNMENTS WHERE PROJECT_ID=h_id AND PROJECT_A+
1SSIGNMENT_ID IS NuLL GROUP BY RESOURCE_ID, RESOURCE_TYPE:
1843:
1           EXCEPTION:: SP_S_PROFILE(844) :: cplan.sql(15414) :: :
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME, PLANNED_START, PLANN+
1ED_FINISH, PLANNED_EFFORT,START_DATE, FINISH_DATE,:n         WORK, REMAINING)+
1:n         SELECT DISTINCT r.PROFILE_ID,r.PROFILE_NAME,:n         a.PLANNED_S+
1TART, a.PLANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK,+
1 a.REMAINING:n         FROM PMO_TMP_RES_SET a JOIN PROFILES r ON a.RESOURCE_T+
1YPE='1' AND r.PROFILE_ID=a.RESOURCE_ID JOIN TMT_COMPETENCIES c ON c.ELEMENT_I+
1D=r.ROLE_ID:n         JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID:
1869:
1           EXCEPTION:: SP_S_PROFILE(870) :: cplan.sql(15440) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, :n      p.FULL_NA+
1ME AS ELEMENT_NAME,:n      13 AS TYPE_ID,:n      p.E_MAIL_ADDRESS,:n      a.P+
1LANNED_START, a.PLANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE,+
1 a.WORK, a.REMAINING,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BE+
1ST_START,'' AS BEST_FINISH, 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVA+
1ILABILITY, '' AS ASSIGN_STRING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,+
1:n      p.LOGON_NAME AS RPM_LOGON_NAME, p.NICK_NAME, p.WORK_LOCATION, p.WORK_+
1PHONE:n      FROM PMO_TMP_RES_SET a :n      JOIN RESOURCES p ON a.RESOURCE_TY+
1PE = '0' AND a.RESOURCE_ID=p.RESOURCE_ID:n      :n      UNION ALL:n      :n  +
1    SELECT ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, :n      ELEMENT_NAME,:n      4+
11 AS TYPE_ID,:n      '' AS E_MAIL_ADDRESS,:n      PLANNED_START, PLANNED_FINI+
1SH,PLANNED_EFFORT,   START_DATE, FINISH_DATE, WORK, REMAINING,0 AS T_UNIT,h_p+
1er_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  AS BEST_FINISH,0 AS CAL+
1ENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STRING,'' AS+
1 FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      '' AS RPM_LOGON_NAME, '' +
1AS NICK_NAME, 0 AS WORK_LOCATION, '' AS WORK_PHONE:n      FROM PMO_TMP_CPLN01+
1_TEMP ORDER BY TYPE_ID:
1895:
1                EXIT:: SP_S_PROFILE(896) :: cplan.sql(15466) :: :
15:
1939:
1           EXCEPTION:: SP_S_PROFILE(940) :: cplan.sql(15510) :: :
1INSERT INTO PMO_TMP_CPLN01_TEMP(ELEMENT_ID,ELEMENT_NAME, RESOURCE_TYPE, TYPE_+
1ID, E_MAIL_ADDRESS, PLANNED_START, PLANNED_FINISH, PLANNED_EFFORT,START_DATE,+
1 FINISH_DATE,:n         WORK, REMAINING, FS_LABOR_CODE):n         SELECT DIST+
1INCT r.PROFILE_ID ,r.PROFILE_NAME ,'1',41 ,'',:n         a.PLANNED_START, a.P+
1LANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAIN+
1ING,:n         '':n         FROM PMO_TMP_RES_SET a JOIN PROFILES r ON a.RESOU+
1RCE_TYPE='1' AND r.PROFILE_ID=a.RESOURCE_ID JOIN TMT_COMPETENCIES c ON c.ELEM+
1ENT_ID=r.ROLE_ID:n         JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_I+
1D:n         :n         UNION ALL:n         :n         SELECT DISTINCT ra.RESO+
1URCE_ID ,p.FULL_NAME ,'0',185 ,p.E_MAIL_ADDRESS,:n         TO_TIMESTAMP('1899+
1-12-31 00::00::00') , TO_TIMESTAMP('1899-12-31 00::00::00') ,0 ,:n         TO+
1_TIMESTAMP('1899-12-31 00::00::00') , TO_TIMESTAMP('1899-12-31 00::00::00') ,+
1 0 , 0 ,p.FS_LABOR_CODE:n         FROM RESOURCE_ASSIGNMENTS ra, RESOURCES p:n+
1         WHERE ra.PROJECT_ID=h_id AND ra.RESOURCE_ID = p.RESOURCE_ID:n       +
1  AND NOT EXISTS(SELECT ta.TSK_ASSIGNMENT_ID FROM TASK_ASSIGNMENTS ta:n      +
1   WHERE ta.RES_ASSIGNMENT_ID IN (SELECT a.RES_ASSIGNMENT_ID:n         FROM R+
1ESOURCE_ASSIGNMENTS a WHERE a.PROJECT_ID = ra.PROJECT_ID AND a.RESOURCE_ID = +
1ra.RESOURCE_ID)):
1977:
1           EXCEPTION:: SP_S_PROFILE(978) :: cplan.sql(15548) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, :n      p.FULL_NA+
1ME AS ELEMENT_NAME,13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.+
1PLANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAI+
1NING,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS B+
1EST_FINISH, 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS+
1 ASSIGN_STRING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      p.LOGON_N+
1AME AS RPM_LOGON_NAME, p.NICK_NAME, p.WORK_LOCATION, p.WORK_PHONE:n      FROM+
1 PMO_TMP_RES_SET a JOIN RESOURCES p ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_I+
1D=p.RESOURCE_ID:n      :n      UNION ALL:n      SELECT ELEMENT_ID,'' AS RES_A+
1SSIGNMENT_ID, :n      ELEMENT_NAME,TYPE_ID,E_MAIL_ADDRESS,:n      PLANNED_STA+
1RT, PLANNED_FINISH,PLANNED_EFFORT,   START_DATE, FINISH_DATE, WORK, REMAINING+
1,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  AS BEST+
1_FINISH,0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASS+
1IGN_STRING, FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      '' AS RPM_LOGO+
1N_NAME, '' AS NICK_NAME, 0 AS WORK_LOCATION, '' AS WORK_PHONE:n      FROM PMO+
1_TMP_CPLN01_TEMP WHERE RESOURCE_TYPE='1' AND TYPE_ID = 41:n      :n      UNIO+
1N ALL:n      :n      SELECT t.ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, :n      t.E+
1LEMENT_NAME,t.TYPE_ID,t.E_MAIL_ADDRESS,:n      t.PLANNED_START, t.PLANNED_FIN+
1ISH, t.PLANNED_EFFORT,:n      t.START_DATE, t.FINISH_DATE, t.WORK, t.REMAININ+
1G, 0 AS T_UNIT, h_per_day AS MINUTE_PER_DAY,'' AS BEST_START,'' AS BEST_FINIS+
1H,:n      0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS A+
1SSIGN_STRING, t.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      p.LOGON_NA+
1ME AS RPM_LOGON_NAME, p.NICK_NAME, p.WORK_LOCATION, p.WORK_PHONE:n      FROM +
1PMO_TMP_CPLN01_TEMP t, RESOURCES P:n      WHERE t.RESOURCE_TYPE = '0' AND t.T+
1YPE_ID = 185:n      AND t.ELEMENT_ID = p.RESOURCE_ID :n      ORDER BY TYPE_ID+
1 DESC, ELEMENT_NAME:
11010:
1                EXIT:: SP_S_PROFILE(1011) :: cplan.sql(15581) :: :
17:
1PLANNED_REMAINING:
1PA:
1LEVEL_PLANNED_START:
1LEVEL_PLANNED_FINISH:
1LEVEL_SCHED_START:
1LEVEL_SCHED_FINISH:
1ESTIMATED_BASELINE1_START:
1ESTIMATED_BASELINE1_FINISH:
1ESTIMATED_BASELINE1_EFFORT:
1ESTIMATED_BASELINE3_START:
1ESTIMATED_BASELINE3_FINISH:
1ESTIMATED_BASELINE3_EFFORT:
1PROJECT_ASSIGNMENTS:
1SELECT t.RESOURCE_ID AS ELEMENT_ID, t.RES_ASSIGNMENT_ID, p.FULL_NAME AS ELEME+
1NT_NAME, 13 AS TYPE_ID,p.E_MAIL_ADDRESS,:n      b.PLANNED_START, b.PLANNED_FI+
1NISH, b.BEST AS PLANNED_EFFORT, b.PLANNED_WORK AS PLANNED_REMAINING, a.BAK_ST+
1ART_DT AS START_DATE, a.BAK_FINISH_DT AS FINISH_DATE,:n      a.BEST AS WORK, +
1a.SCHED_WORK AS REMAINING, h_per_day AS MINUTE_PER_DAY,'' AS BEST_START, '' A+
1S BEST_FINISH,:n      0 AS CALENDAR,0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILI+
1TY, (SELECT CLOB_DATA FROM EMPTYLOB) AS ASSIGN_STRING,p.FS_LABOR_CODE, '' AS +
1OBJECTIVES,'' AS RANK,:n      pa.REGULAR_COST, pa.REGULAR_RATE, pa.SPECIAL_CO+
1ST, pa.SPECIAL_RATE, pa.DESCRIPTION,:n      pa.LEVEL_PLANNED_START, pa.LEVEL_+
1PLANNED_FINISH, pa.LEVEL_SCHED_START, pa.LEVEL_SCHED_FINISH,:n      pa.ESTIMA+
1TED_BASELINE1_START, pa.ESTIMATED_BASELINE1_FINISH, pa.ESTIMATED_BASELINE1_EF+
1FORT,:n      pa.ESTIMATED_BASELINE3_START, pa.ESTIMATED_BASELINE3_FINISH, pa.+
1ESTIMATED_BASELINE3_EFFORT, P.EXTERNAL_ID,:n      p.LOGON_NAME AS RPM_LOGON_N+
1AME, p.NICK_NAME, p.WORK_LOCATION, p.WORK_PHONE:n      FROM RESOURCE_ASSIGNME+
1NTS t :n      JOIN PROJECT_ASSIGNMENTS pa ON pa.PROJECT_ID = h_id AND pa.RESO+
1URCE_ID = t.RESOURCE_ID:n      LEFT JOIN TASK_ASSIGNMENTS a ON a.RES_ASSIGNME+
1NT_ID=t.RES_ASSIGNMENT_ID AND a.BIT_FLAG='2':n      LEFT JOIN TASK_ASSIGNMENT+
1S b ON b.RES_ASSIGNMENT_ID=t.RES_ASSIGNMENT_ID AND b.BIT_FLAG='0':n      JOIN+
1 RESOURCES p ON t.RESOURCE_ID=p.RESOURCE_ID:n      WHERE t.ELEMENT_ID=h_id AN+
1D t.RESOURCE_TYPE='0' AND (a.TSK_ASSIGNMENT_ID IS NOT NuLL OR b.TSK_ASSIGNMEN+
1T_ID IS NOT NuLL):n      :n      UNION ALL:n      :n      SELECT t.RESOURCE_I+
1D AS ELEMENT_ID, a.RES_ASSIGNMENT_ID, p.PROFILE_NAME AS ELEMENT_NAME, 41 AS T+
1YPE_ID,'' AS E_MAIL_ADDRESS,:n      t.PLANNED_START, t.PLANNED_FINISH,t.BEST +
1AS PLANNED_EFFORT,t.PLANNED_WORK AS PLANNED_REMAINING,TO_TIMESTAMP('1899-12-3+
11 00::00::00') AS START_DATE, TO_TIMESTAMP('1899-12-31 00::00::00') AS FINISH+
1_DATE,:n      0 AS WORK,0 AS REMAINING,h_per_day AS MINUTE_PER_DAY,'' AS BEST+
1_START, '' AS BEST_FINISH,:n      0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERI+
1OD_AVAILABILITY, t.ASSIGN_STRING,'' AS FS_LABOR_CODE, '' AS OBJECTIVES,'' AS +
1RANK,:n      pa.REGULAR_COST, pa.REGULAR_RATE, pa.SPECIAL_COST, pa.SPECIAL_RA+
1TE, pa.DESCRIPTION,:n      pa.LEVEL_PLANNED_START, pa.LEVEL_PLANNED_FINISH, p+
1a.LEVEL_SCHED_START, pa.LEVEL_SCHED_FINISH,:n      pa.ESTIMATED_BASELINE1_STA+
1RT, pa.ESTIMATED_BASELINE1_FINISH, pa.ESTIMATED_BASELINE1_EFFORT,:n      pa.E+
1STIMATED_BASELINE3_START, pa.ESTIMATED_BASELINE3_FINISH, pa.ESTIMATED_BASELIN+
1E3_EFFORT, '' AS EXTERNAL_ID,:n      '' AS RPM_LOGON_NAME, '' AS NICK_NAME, 0+
1 AS WORK_LOCATION, '' AS WORK_PHONE:n      FROM RESOURCE_ASSIGNMENTS a :n    +
1  JOIN PROFILES p ON a.RESOURCE_ID=p.PROFILE_ID:n      JOIN TASK_ASSIGNMENTS +
1t ON t.RES_ASSIGNMENT_ID=a.RES_ASSIGNMENT_ID:n      JOIN PROJECT_ASSIGNMENTS +
1pa ON pa.PROJECT_ID = h_id AND pa.RESOURCE_ID = a.RESOURCE_ID:n      WHERE a.+
1ELEMENT_ID=h_id AND a.RESOURCE_TYPE='1':n      ORDER BY TYPE_ID DESC, ELEMENT+
1_NAME:
11114:
1                EXIT:: SP_S_PROFILE(1115) :: cplan.sql(15685) :: :
18:
1DELETE FROM PMO_TMP_PRJ_INFO:
1PMO_TMP_PRJ_INFO:
1PRJ_PLANNED_START:
1PRJ_PLANNED_FINISH:
1PRJ_SCHED_START:
1PRJ_SCHED_FINISH:
1SCHED_REMAINING:
1INSERT INTO PMO_TMP_PRJ_INFO:n         (RESOURCE_ID,:n         RESOURCE_TYPE,+
1:n         PRJ_PLANNED_START,:n         PRJ_PLANNED_FINISH,:n         PLANNED+
1_REMAINING,:n         PLANNED_EFFORT,:n         PRJ_SCHED_START ,:n         P+
1RJ_SCHED_FINISH,:n         SCHED_REMAINING,:n         WORK,:n         TYPE_ID+
1:n         ):n         SELECT:n         RESOURCE_ID,:n         RESOURCE_TYPE,+
1:n         MIN(PLANNED_START)  AS PRJ_PLANNED_START,:n         MAX(PLANNED_FI+
1NISH) AS PRJ_PLANNED_FINISH,:n         SUM(PLANNED_WORK)   AS PLANNED_REMAINI+
1NG,:n         SUM(CASE WHEN BIT_FLAG='0' THEN BEST ELSE 0 END) AS PLANNED_EFF+
1ORT,:n         MIN(SCHED_START)    AS PRJ_SCHED_START,:n         MAX(SCHED_FI+
1NISH)   AS PRJ_SCHED_FINISH,:n         SUM(SCHED_WORK)     AS SCHED_REMAINING+
1,:n         SUM(CASE WHEN BIT_FLAG='2' THEN BEST ELSE 0 END) AS WORK, 13:n   +
1      FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_ID=h_id AND TASK_ID=h_id+
1:n         GROUP BY RESOURCE_ID, RESOURCE_TYPE:
11162:
1           EXCEPTION:: SP_S_PROFILE(1163) :: cplan.sql(15733) :: :
1DELETE FROM PMO_TMP_RES_INFO:
1PMO_TMP_RES_INFO:
1INSERT INTO PMO_TMP_RES_INFO:n         (:n         RESOURCE_ID,:n         RES+
1OURCE_TYPE,:n         PLANNED_START,:n         PLANNED_FINISH,:n         PLAN+
1NED_EFFORT,:n         START_DATE,:n         FINISH_DATE,:n         WORK,:n   +
1      REMAINING,:n         PRJ_PLANNED_START,:n         PRJ_PLANNED_FINISH,:n+
1         PLANNED_REMAINING,:n         PRJ_SCHED_START,:n         PRJ_SCHED_FI+
1NISH,:n         SCHED_REMAINING,:n         LEVEL_PLANNED_START,:n         LEV+
1EL_PLANNED_FINISH,:n         LEVEL_SCHED_START,:n         LEVEL_SCHED_FINISH,+
1:n         ESTIMATED_BASELINE1_START,:n         ESTIMATED_BASELINE1_FINISH,:n+
1         ESTIMATED_BASELINE1_EFFORT,:n         ESTIMATED_BASELINE3_START,:n  +
1       ESTIMATED_BASELINE3_FINISH,:n         ESTIMATED_BASELINE3_EFFORT,:n   +
1      REGULAR_COST,:n         REGULAR_RATE,:n         SPECIAL_COST,:n        +
1 SPECIAL_RATE,:n         TYPE_ID,:n         DESCRIPTION:n         ):n        +
1 SELECT:n         a.RESOURCE_ID,      a.RESOURCE_TYPE,        a.PLANNED_START+
1,        a.PLANNED_FINISH,:n         a.PLANNED_WORK,     a.SCHED_START,      +
1    a.SCHED_FINISH,         a.SCHED_WORK,:n         a.ETC,              b.PRJ+
1_PLANNED_START,    b.PRJ_PLANNED_FINISH,   b.PLANNED_REMAINING,:n         b.P+
1RJ_SCHED_START,  b.PRJ_SCHED_FINISH,     b.SCHED_REMAINING,:n         a.LEVEL+
1_PLANNED_START, a.LEVEL_PLANNED_FINISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FI+
1NISH,:n         a.ESTIMATED_BASELINE1_START, a.ESTIMATED_BASELINE1_FINISH, a.+
1ESTIMATED_BASELINE1_EFFORT,:n         a.ESTIMATED_BASELINE3_START, a.ESTIMATE+
1D_BASELINE3_FINISH, a.ESTIMATED_BASELINE3_EFFORT,:n         a.REGULAR_COST,  +
1   a.REGULAR_RATE,         a.SPECIAL_COST,         a.SPECIAL_RATE,:n         +
1COALESCE(b.TYPE_ID,CASE WHEN (a.PLANNED_WORK+a.SCHED_WORK) = 0 THEN 185 ELSE +
113 END), a.DESCRIPTION:n         FROM PROJECT_ASSIGNMENTS a :n         LEFT O+
1UTER JOIN PMO_TMP_PRJ_INFO b ON a.RESOURCE_ID = b.RESOURCE_ID:n         WHERE+
1 a.PROJECT_ID=h_id:
11232:
1           EXCEPTION:: SP_S_PROFILE(1233) :: cplan.sql(15803) :: :
1RI:
1UPDATE PMO_TMP_RES_INFO RI SET TYPE_ID = 13 WHERE TYPE_ID = 185 AND EXISTS(:n+
1         SELECT TASK_ID FROM TASK_ASSIGNMENTS T WHERE T.PROJECT_ID=h_id AND T+
1.RESOURCE_ID = RI.RESOURCE_ID AND T.RESOURCE_TYPE = '0'):
11253:
1           EXCEPTION:: SP_S_PROFILE(1254) :: cplan.sql(15824) :: :
1SELECT a.RESOURCE_ID AS ELEMENT_ID,'' AS RES_ASSIGNMENT_ID, :n      p.FULL_NA+
1ME AS ELEMENT_NAME, a.TYPE_ID, p.E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PL+
1ANNED_FINISH,a.PLANNED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINI+
1NG,0 AS T_UNIT,h_per_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,'' AS BES+
1T_FINISH, 0 AS CALENDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS A+
1SSIGN_STRING,p.FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      CASE WHEN a+
1.PRJ_PLANNED_START IS NOT NuLL OR a.PRJ_SCHED_START IS NOT NuLL THEN a.RESOUR+
1CE_ID ELSE '' END AS PROJECT_ASSIGNMENT_ID, a.PRJ_PLANNED_START, a.PRJ_PLANNE+
1D_FINISH, a.PLANNED_REMAINING, a.PRJ_SCHED_START, a.PRJ_SCHED_FINISH, a.SCHED+
1_REMAINING,:n      h_id AS PROJECT_ID,:n      a.LEVEL_PLANNED_START, a.LEVEL_+
1PLANNED_FINISH, a.LEVEL_SCHED_START, a.LEVEL_SCHED_FINISH,:n      a.ESTIMATED+
1_BASELINE1_START, a.ESTIMATED_BASELINE1_FINISH, a.ESTIMATED_BASELINE1_EFFORT,+
1:n      a.ESTIMATED_BASELINE3_START, a.ESTIMATED_BASELINE3_FINISH, a.ESTIMATE+
1D_BASELINE3_EFFORT,:n      a.REGULAR_COST, a.REGULAR_RATE, a.SPECIAL_COST, a.+
1SPECIAL_RATE, a.DESCRIPTION, p.EXTERNAL_ID,:n      p.LOGON_NAME AS RPM_LOGON_+
1NAME , p.NICK_NAME, p.WORK_LOCATION, p.WORK_PHONE:n      FROM PMO_TMP_RES_INF+
1O a :n      JOIN RESOURCES p ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RES+
1OURCE_ID:n      :n      UNION ALL:n      :n      SELECT  r.PROFILE_ID AS ELEM+
1ENT_ID,'' AS RES_ASSIGNMENT_ID, :n      r.PROFILE_NAME AS ELEMENT_NAME,41 AS +
1TYPE_ID,'' AS E_MAIL_ADDRESS,:n      a.PLANNED_START, a.PLANNED_FINISH,a.PLAN+
1NED_EFFORT, a.START_DATE, a.FINISH_DATE, a.WORK, a.REMAINING,0 AS T_UNIT,h_pe+
1r_day AS MINUTE_PER_DAY,:n      '' AS BEST_START,''  AS BEST_FINISH,0 AS CALE+
1NDAR, 0 AS PLANNED_WORK, 0 AS PERIOD_AVAILABILITY, '' AS ASSIGN_STRING,'' AS +
1FS_LABOR_CODE, '' AS OBJECTIVES,'' AS RANK,:n      CASE WHEN a.PRJ_PLANNED_ST+
1ART IS NOT NuLL OR a.PRJ_SCHED_START IS NOT NuLL THEN a.RESOURCE_ID ELSE '' E+
1ND AS PROJECT_ASSIGNMENT_ID, a.PRJ_PLANNED_START, a.PRJ_PLANNED_FINISH, a.PLA+
1NNED_REMAINING, a.PRJ_SCHED_START, a.PRJ_SCHED_FINISH, a.SCHED_REMAINING,:n  +
1    h_id AS PROJECT_ID,:n      a.LEVEL_PLANNED_START, a.LEVEL_PLANNED_FINISH,+
1 a.LEVEL_SCHED_START, a.LEVEL_SCHED_FINISH,:n      a.ESTIMATED_BASELINE1_STAR+
1T, a.ESTIMATED_BASELINE1_FINISH, a.ESTIMATED_BASELINE1_EFFORT,:n      a.ESTIM+
1ATED_BASELINE3_START, a.ESTIMATED_BASELINE3_FINISH, a.ESTIMATED_BASELINE3_EFF+
1ORT,:n      a.REGULAR_COST, a.REGULAR_RATE, a.SPECIAL_COST, a.SPECIAL_RATE, a+
1.DESCRIPTION, '' AS EXTERNAL_ID,:n      '' AS RPM_LOGON_NAME, '' AS NICK_NAME+
1, 0 AS WORK_LOCATION, '' AS WORK_PHONE               :n      FROM PMO_TMP_RES+
1_INFO a :n      JOIN PROFILES r ON a.RESOURCE_TYPE='1' AND r.PROFILE_ID=a.RES+
1OURCE_ID:n      JOIN TMT_COMPETENCIES c ON c.ELEMENT_ID=r.ROLE_ID:n      JOIN+
1 TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID:
11290:
1                EXIT:: SP_S_PROFILE(1291) :: cplan.sql(15861) :: :
1SELECT PROFILE_NAME INTO h_in FROM PROFILES WHERE PROFILE_ID = h_id:
11306:
1           EXCEPTION:: SP_S_PROFILE(1307) :: cplan.sql(15877) :: :
1SC_SQL_SUCCESS:
1ROLE_TYPE:
1ORG_ID:
1ORG:
1ORG_NAME:
1GEO_ID:
1GEO:
1GEO_NAME:
1POOL_ID:
1POOL:
1POOL_NAME:
1TMT_GEOGRAPHIES:
1DS:
1CS:
1STRINGCONCAT:
1RTRIM:
1SELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAME,41 AS TYPE_ID,30 AS ROLE_TYPE+
1, p.ROLE_ID, h_in AS ROLE_NAME,:n         ORG_ID, org.ELEMENT_NAME AS ORG_NAM+
1E, GEO_ID, geo.ELEMENT_NAME AS GEO_NAME, POOL_ID, pool.ELEMENT_NAME AS POOL_N+
1AME:n         FROM PROFILES p:n         LEFT JOIN TMT_ORGANIZATIONS org ON or+
1g.ELEMENT_ID  = ORG_ID:n         LEFT JOIN TMT_GEOGRAPHIES geo   ON geo.ELEME+
1NT_ID  = GEO_ID:n         LEFT JOIN TMT_POOLS pool        ON pool.ELEMENT_ID +
1= POOL_ID:n         WHERE p.PROFILE_ID = h_id:n         :n         UNION ALL+
1:n         :n         SELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAME,41 AS T+
1YPE_ID,ds.TYPE_ID AS ROLE_TYPE,:n         cs.ELEMENT_ID AS ROLE_ID, PMO_ORAST+
1D.StringConcat(PMO_ORASTD.StringConcat(RTRIM(ds.ELEMENT_NAME), ', '), RTRIM(c+
1s.ELEMENT_NAME)) AS ROLE_NAME,:n         '' ORG_ID, '' AS ORG_NAME, '' GEO_ID+
1, '' AS GEO_NAME, '' POOL_ID, '' AS POOL_NAME:n         FROM RESOURCE_ASSIGN_+
1ROLES r LEFT OUTER JOIN TMT_COMPETENCIES cs ON r.ROLE_ID=cs.ELEMENT_ID:n     +
1    LEFT OUTER JOIN TMT_COMPETENCIES ds ON ds.ELEMENT_ID=cs.PARENT_ID WHERE r+
1.RES_ASSIGNMENT_ID=h_id:n         :n         UNION ALL:n         :n         S+
1ELECT h_id AS ELEMENT_ID, h_in AS ELEMENT_NAME,41 AS TYPE_ID,ds.TYPE_ID AS RO+
1LE_TYPE,:n         cs.ELEMENT_ID AS ROLE_ID, PMO_ORASTD.StringConcat(PMO_ORAS+
1TD.StringConcat(RTRIM(ds.ELEMENT_NAME), ', '), RTRIM(cs.ELEMENT_NAME)) AS ROL+
1E_NAME,:n         '' ORG_ID, '' AS ORG_NAME, '' GEO_ID, '' AS GEO_NAME, '' PO+
1OL_ID, '' AS POOL_NAME:n         FROM RESOURCE_ASSIGN_SKILLS s LEFT OUTER JOI+
1N TMT_COMPETENCIES cs ON s.SKILL_ID=cs.ELEMENT_ID:n         LEFT OUTER JOIN T+
1MT_COMPETENCIES ds ON ds.ELEMENT_ID=cs.PARENT_ID WHERE s.RES_ASSIGNMENT_ID=h_+
1id:n         ORDER BY ELEMENT_ID,TYPE_ID:
11337:
1                EXIT:: SP_S_PROFILE(1338) :: cplan.sql(15908) :: :
1SELECT CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL THEN t.TSK_ASSIGNMENT_ID ELS+
1E a.RES_ASSIGNMENT_ID END AS ELEMENT_ID, a.RESOURCE_ID,:n      :n      CASE W+
1HEN a.RESOURCE_TYPE='1' THEN (SELECT p.PROFILE_NAME FROM PROFILES p WHERE a.R+
1ESOURCE_ID = p.PROFILE_ID):n      ELSE (SELECT r.FULL_NAME FROM RESOURCES r W+
1HERE a.RESOURCE_ID = r.RESOURCE_ID) END AS ELEMENT_NAME,:n      :n      CASE +
1WHEN t.TSK_ASSIGNMENT_ID IS NuLL THEN 185 WHEN a.RESOURCE_TYPE='1' THEN 41 EL+
1SE 13 END AS TYPE_ID,:n      a.RES_ASSIGNMENT_ID, a.PARTICIPANT, t.START_DT, +
1COALESCE(PLANNED_FINISH,SCHED_FINISH) AS FINISH_DT,:n      t.SD, t.FD, COALES+
1CE(PLANNED_START,SCHED_START) AS PLANNED_START, COALESCE(PLANNED_FINISH,SCHED+
1_FINISH) AS PLANNED_FINISH,:n      CASE WHEN BIT_FLAG = '2' THEN SCHED_WORK E+
1LSE PLANNED_WORK END AS PLANNED_WORK,:n      CASE WHEN BIT_FLAG = '2' THEN SC+
1HED_WORK - WORK_TODATE ELSE PLANNED_WORK END AS REMAINING,:n      CASE WHEN t+
1.ASSIGN_UNITS > t.UNITS_MSP THEN t.ASSIGN_UNITS ELSE t.UNITS_MSP END AS UNITS+
1_PERCENT,:n      t.PLANNED_UNITS AS PLANNED_PERCENT,:n      0 AS MILESTONE_PE+
1RCENT,:n      CASE WHEN t.WORK_TODATE = 0 THEN 0 ELSE Trunc((TO_NUMBER(t.WORK+
1_TODATE)/TO_NUMBER(PLANNED_WORK+SCHED_WORK))*10000) END AS WORK_PERCENT,:n   +
1   t.BAK_START_DT,t.BAK_FINISH_DT,t.BAK_WORK,:n      t.FORECAST_START,t.FOREC+
1AST_FINISH,t.ETC, t.ACTUAL_START,t.ACTUAL_FINISH,:n      t.WORK_TODATE AS ACT+
1UAL,PROPOSED_START, PROPOSED_FINISH, PROPOSED_WORK,:n      h_per_day AS MINUT+
1E_PER_DAY, :n      CASE WHEN a.RESOURCE_TYPE='1' THEN a.WORK_LOCATION:n      +
1ELSE (SELECT R.WORK_LOCATION FROM RESOURCES R WHERE a.RESOURCE_ID = R.RESOURC+
1E_ID) END AS WORK_LOCATION,:n      a.SECURITY_ID, g.ELEMENT_NAME AS SECURITY_+
1NAME,:n      COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, g2+
1.ELEMENT_NAME AS CRI_SECURITY_NAME, t.REGULAR_COST,t.REGULAR_RATE,t.SPECIAL_C+
1OST,t.SPECIAL_RATE,:n      CASE WHEN a.RESOURCE_TYPE='0' THEN (SELECT r.FS_LA+
1BOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n      ELSE ''+
1 END AS FS_LABOR_CODE,a.REC_STATUS,t.ASSIGN_STRING,t.BASELINE1_START,t.BASELI+
1NE1_FINISH,t.BASELINE1_WORK,:n      t.PROJECT_ASSIGNMENT_ID,t.TIMECODE2_ID, T+
1C.ELEMENT_NAME AS TIMECODE2_NAME, t.T_UNIT, t.C_EFFORT, t.C_UNIT, t.C_CONTOUR+
1, t.CONTOUR_TYPE, t.C_OCCURRENCE, t.BILLABLE, t.CAPITAL_EXPENSE,:n      t.ASS+
1IGNMENT_DELAY, CASE WHEN t.BIT_FLAG IS NuLL THEN '' WHEN t.BIT_FLAG = '0' THE+
1N '1' ELSE '2' END AS BIT_FLAG, t.RATE_ADJUSTMENT, 0 AS ASSIGN_COUNT, :n     +
1 CASE WHEN BIT_FLAG = '2' THEN SCHED_DURATION ELSE PLANNED_DURATION END AS DU+
1RATION,:n      CASE WHEN h_level_state = 1 THEN COALESCE(t.LEVEL_START,t.UNRE+
1SOLVED_START) ELSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_START,+
1:n      CASE WHEN h_level_state = 1 THEN COALESCE(t.LEVEL_FINISH,t.UNRESOLVED+
1_FINISH) ELSE TO_TIMESTAMP('1899-12-31 00::00::00') END AS LEVEL_FINISH,:n   +
1   CASE WHEN h_level_state = 1 THEN CASE WHEN t.LEVEL_EFFORT = 0 THEN t.ETC E+
1LSE t.LEVEL_EFFORT END ELSE 0 END AS LEVEL_EFFORT, t.MILESTONE_PERCENT AS PER+
1CENT_DISCRETE, 0 as TOP_ID,:n      CASE WHEN t.TSK_ASSIGNMENT_ID IS NOT NuLL +
1AND t.PROJECT_ASSIGNMENT_ID = t.TSK_ASSIGNMENT_ID AND (t.LEVEL_START <> t.UNR+
1ESOLVED_START OR t.LEVEL_FINISH <> t.UNRESOLVED_FINISH) THEN '1' ELSE '0' END+
1 AS LEVEL_AFFECTED_FLAG,:n      T.LABOR_COST_CC_ID,:n      EC.ELEMENT_NAME AS+
1 LABOR_COST_CC_NAME,:n      T.LABOR_REVENUE_CC_ID,:n      CC.ELEMENT_NAME AS +
1LABOR_REVENUE_CC_NAME, T.DEFAULT_LABOR_FLAG,:n      T.CONTRACT_ID, CTR.ELEMEN+
1T_NAME AS CONTRACT_NAME,:n      CASE WHEN a.RESOURCE_TYPE='1' THEN '' :n     +
1 ELSE (SELECT r.LOGON_NAME FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_+
1ID) END	AS RPM_LOGON_NAME,:n      CASE WHEN a.RESOURCE_TYPE='1' THEN '' :n   +
1   ELSE (SELECT r.NICK_NAME FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE+
1_ID) END	AS NICK_NAME,:n      CASE WHEN a.RESOURCE_TYPE='1' THEN '' :n      E+
1LSE (SELECT r.E_MAIL_ADDRESS FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURC+
1E_ID) END	AS E_MAIL_ADDRESS,:n      CASE WHEN a.RESOURCE_TYPE='1' THEN '':n  +
1    ELSE (SELECT r.WORK_PHONE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOUR+
1CE_ID) END	AS WORK_PHONE,:n      CASE WHEN a.RESOURCE_TYPE='0' THEN p.PROFILE+
1_NAME WHEN a.RESOURCE_TYPE='1' THEN ap.PROFILE_NAME ELSE '' END AS PROFILE_NA+
1ME,:n      t.BASELINE3_START,t.BASELINE3_FINISH,t.BASELINE3_WORK :n      FROM+
1 RESOURCE_ASSIGNMENTS a :n      JOIN TASK_ASSIGNMENTS t ON t.TSK_ASSIGNMENT_I+
1D = h_id :n      AND a.RES_ASSIGNMENT_ID = t.RES_ASSIGNMENT_ID:n      LEFT OU+
1TER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=g.ELEMENT_ID:n      LEFT OUTE+
1R JOIN TMT_GLOBAL_SECURITY g2 ON COALESCE(a.CRI_SECURITY_ID,a.SECURITY_ID)=g2+
1.ELEMENT_ID:n      LEFT OUTER JOIN TMT_TIMECODES TC ON TC.ELEMENT_ID= t.TIMEC+
1ODE2_ID:n      LEFT OUTER JOIN TMT_CHARGECODES EC ON EC.ELEMENT_ID = T.LABOR_+
1COST_CC_ID:n      LEFT OUTER JOIN TMT_CHARGECODES CC ON CC.ELEMENT_ID = T.LAB+
1OR_REVENUE_CC_ID:n      LEFT OUTER JOIN TMT_CONTRACTS CTR ON CTR.ELEMENT_ID =+
1 T.CONTRACT_ID:n      LEFT OUTER JOIN PROFILES p ON p.PROFILE_ID=a.PROFILE_ID+
1:n      LEFT OUTER JOIN PROFILES ap ON a.RESOURCE_ID = ap.PROFILE_ID:n      O+
1RDER BY TYPE_ID DESC, ELEMENT_NAME:
11401:
1                EXIT:: SP_S_PROFILE(1402) :: cplan.sql(15972) :: :
1ACCEPTED_DATE:
1DELAY:
1SELECT a.RES_ASSIGNMENT_ID AS ELEMENT_ID, a.RESOURCE_ID,:n      CASE WHEN a.R+
1ESOURCE_TYPE='0' THEN (SELECT r.FULL_NAME FROM RESOURCES r WHERE a.RESOURCE_I+
1D = r.RESOURCE_ID):n      WHEN a.RESOURCE_TYPE='2' THEN (SELECT p.ELEMENT_NAM+
1E FROM TMT_POOLS p WHERE a.RESOURCE_ID = p.ELEMENT_ID):n      ELSE (SELECT p.+
1ELEMENT_NAME FROM TMT_ORGANIZATIONS p WHERE a.RESOURCE_ID = p.ELEMENT_ID) END+
1 AS ELEMENT_NAME,:n      CASE WHEN a.RESOURCE_TYPE='2' THEN pmo_cnst.SC_POOLS+
1:n      WHEN a.RESOURCE_TYPE='3' THEN pmo_cnst.SC_ORGANIZATION :n      ELSE 1+
185 END AS TYPE_ID,  :n      a.RES_ASSIGNMENT_ID, a.PARTICIPANT, TO_TIMESTAMP(+
1'1899-12-31 00::00::00') AS PLANNED_START, TO_TIMESTAMP('1899-12-31 00::00::0+
10') AS PLANNED_FINISH,:n      0 AS PLANNED_WORK,TO_TIMESTAMP('1899-12-31 00::+
100::00') AS START_DT,TO_TIMESTAMP('1899-12-31 00::00::00') AS FINISH_DT,:n   +
1   TO_TIMESTAMP('1899-12-31 00::00::00') AS SCHED_START,TO_TIMESTAMP('1899-12+
1-31 00::00::00') AS SCHED_FINISH, 0 AS SCHED_WORK,:n      TO_TIMESTAMP('1899-+
112-31 00::00::00') AS BAK_START_DT,TO_TIMESTAMP('1899-12-31 00::00::00') AS B+
1AK_FINISH_DT, 0 AS BAK_WORK,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS +
1FORECAST_START,TO_TIMESTAMP('1899-12-31 00::00::00') AS FORECAST_FINISH,0 AS +
1ETC,:n      TO_TIMESTAMP('1899-12-31 00::00::00') AS ACTUAL_START,TO_TIMESTAM+
1P('1899-12-31 00::00::00') AS ACTUAL_FINISH,:n      0 AS ACTUAL,h_per_day AS +
1MINUTE_PER_DAY,:n      CASE WHEN a.RESOURCE_TYPE='0' THEN (SELECT R.WORK_LOCA+
1TION FROM RESOURCES R WHERE a.RESOURCE_ID = R.RESOURCE_ID) :n      ELSE a.WOR+
1K_LOCATION END AS WORK_LOCATION,:n      TO_TIMESTAMP('1899-12-31 00::00::00')+
1 AS ACCEPTED_DATE,:n      a.SECURITY_ID, g.ELEMENT_NAME AS SECURITY_NAME, COA+
1LESCE(a.CRI_SECURITY_ID,a.SECURITY_ID) AS CRI_SECURITY_ID, g2.ELEMENT_NAME AS+
1 CRI_SECURITY_NAME,:n      0 AS REGULAR_COST,0 AS REGULAR_RATE,0 AS SPECIAL_C+
1OST, 0 AS SPECIAL_RATE,:n      CASE WHEN a.RESOURCE_TYPE='0' THEN (SELECT r.F+
1S_LABOR_CODE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_ID):n      ELS+
1E '' END AS FS_LABOR_CODE,:n      a.REC_STATUS,'' AS ASSIGN_STRING,:n      TO+
1_TIMESTAMP('1899-12-31 00::00::00') AS BASELINE1_START,TO_TIMESTAMP('1899-12-+
131 00::00::00') AS BASELINE1_FINISH,0 AS BASELINE1_WORK,:n      '' AS PROJECT+
1_ASSIGNMENT_ID, '' AS TIMECODE2_ID, '' AS TIMECODE2_NAME, 0 AS T_UNIT,:n     +
1 0 AS C_EFFORT, 0 AS C_UNIT, 0 AS C_CONTOUR, 0 AS CONTOUR_TYPE, 0 AS C_OCCURR+
1ENCE, 0 AS BILLABLE,:n      0 AS DELAY,:n      CASE WHEN a.RESOURCE_TYPE='0' +
1THEN (SELECT r.LOGON_NAME FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_I+
1D) :n      ELSE '' END	AS RPM_LOGON_NAME,:n      CASE WHEN a.RESOURCE_TYPE='0+
1' THEN (SELECT r.NICK_NAME FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURCE_+
1ID) :n      ELSE ''  END AS NICK_NAME,:n      CASE WHEN a.RESOURCE_TYPE='0' T+
1HEN (SELECT r.E_MAIL_ADDRESS FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOURC+
1E_ID):n      ELSE '' END	AS E_MAIL_ADDRESS,:n      CASE WHEN a.RESOURCE_TYPE=+
1'0' THEN (SELECT r.WORK_PHONE FROM RESOURCES r WHERE a.RESOURCE_ID = r.RESOUR+
1CE_ID):n      ELSE '' END	AS WORK_PHONE:n      FROM RESOURCE_ASSIGNMENTS a:n +
1     LEFT OUTER JOIN TMT_GLOBAL_SECURITY g ON a.SECURITY_ID=g.ELEMENT_ID:n   +
1   LEFT OUTER JOIN TMT_GLOBAL_SECURITY g2 ON COALESCE(a.CRI_SECURITY_ID,a.SEC+
1URITY_ID)=g2.ELEMENT_ID:n      WHERE a.REC_STATUS NOT IN ('L','D') AND a.ELEM+
1ENT_ID = h_id:n      ORDER BY TYPE_ID DESC, ELEMENT_NAME:
11445:
1                EXIT:: SP_S_PROFILE(1446) :: cplan.sql(16016) :: :
112:
1DELETE FROM PMO_TMP_RTA:
1PMO_TMP_RTA:
1PA_FLAG:
1TABLE_TYPE:
1SC_TABLE_WBS:
1INSERT INTO PMO_TMP_RTA (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n         SELEC+
1T RESOURCE_ID, RESOURCE_TYPE, 'N' AS PA_FLAG:n         FROM TASK_ASSIGNMENTS+
1:n         WHERE PROJECT_ID = h_id AND:n         PROJECT_ASSIGNMENT_ID IS NuL+
1L AND:n         TABLE_TYPE = pmo_cnst.SC_TABLE_WBS:n         GROUP BY RESOURC+
1E_ID, RESOURCE_TYPE:
11475:
1           EXCEPTION:: SP_S_PROFILE(1476) :: cplan.sql(16046) :: :
1DELETE FROM PMO_TMP_CP_PRJ:
1PMO_TMP_CP_PRJ:
1INSERT INTO PMO_TMP_CP_PRJ (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n         SE+
1LECT  RESOURCE_ID, RESOURCE_TYPE, 'Y' AS PA_FLAG:n         FROM TASK_ASSIGNME+
1NTS:n         WHERE PROJECT_ID = h_id AND:n         TASK_ID = h_id:n         +
1GROUP BY RESOURCE_ID, RESOURCE_TYPE:
11503:
1           EXCEPTION:: SP_S_PROFILE(1504) :: cplan.sql(16074) :: :
1DELETE FROM PMO_TMP_RESOURCE_DATA:
1PMO_TMP_RESOURCE_DATA:
1INSERT INTO PMO_TMP_RESOURCE_DATA (RESOURCE_ID, RESOURCE_TYPE, PA_FLAG):n    +
1     SELECT a.RESOURCE_ID, a.RESOURCE_TYPE, a.PA_FLAG:n         FROM PMO_TMP_+
1RTA a LEFT OUTER JOIN PMO_TMP_CP_PRJ b ON a.RESOURCE_ID=b.RESOURCE_ID:n      +
1   UNION:n         SELECT b.RESOURCE_ID, b.RESOURCE_TYPE, b.PA_FLAG:n        +
1 FROM PMO_TMP_CP_PRJ b LEFT OUTER JOIN PMO_TMP_RTA a ON a.RESOURCE_ID=b.RESOU+
1RCE_ID:
11531:
1           EXCEPTION:: SP_S_PROFILE(1532) :: cplan.sql(16102) :: :
1PRJ:
1RD:
1SELECT a.RESOURCE_ID AS ELEMENT_ID, p.FULL_NAME AS ELEMENT_NAME,13 AS TYPE_ID+
1, p.NICK_NAME, a.PA_FLAG,:n      p.LOGON_NAME AS RPM_LOGON_NAME, p.E_MAIL_ADD+
1RESS, p.WORK_LOCATION, P.WORK_PHONE:n      FROM PMO_TMP_RESOURCE_DATA a JOIN +
1RESOURCES p ON a.RESOURCE_TYPE = '0' AND a.RESOURCE_ID=p.RESOURCE_ID:n      L+
1EFT OUTER JOIN PMO_TMP_CP_PRJ PRJ ON a.RESOURCE_ID=PRJ.RESOURCE_ID:n      :n +
1     UNION ALL:n      :n      SELECT DISTINCT r.PROFILE_ID AS ELEMENT_ID, r.P+
1ROFILE_NAME AS ELEMENT_NAME,41 AS TYPE_ID, ' ' AS NICK_NAME, a.PA_FLAG,:n    +
1  '' AS RPM_LOGON_NAME,'' AS E_MAIL_ADDRESS, 0 AS WORK_LOCATION, '' AS WORK_P+
1HONE:n      FROM PMO_TMP_RESOURCE_DATA a JOIN PROFILES r ON a.RESOURCE_TYPE =+
1 '1' AND r.PROFILE_ID = a.RESOURCE_ID:n      JOIN TMT_COMPETENCIES c ON c.ELE+
1MENT_ID=r.ROLE_ID:n      JOIN TMT_COMPETENCIES d ON d.ELEMENT_ID=c.PARENT_ID+
1:n      LEFT OUTER JOIN PMO_TMP_CP_PRJ PRJ ON a.RESOURCE_ID=PRJ.RESOURCE_ID:n+
1      :n      UNION ALL:n      :n      SELECT DISTINCT ra.RESOURCE_ID AS ELEM+
1ENT_ID, p.FULL_NAME AS ELEMENT_NAME, 185 AS TYPE_ID, p.NICK_NAME, 'N' AS PA_F+
1LAG,:n      p.LOGON_NAME AS RPM_LOGON_NAME, p.E_MAIL_ADDRESS, p.WORK_LOCATION+
1, P.WORK_PHONE:n      FROM RESOURCE_ASSIGNMENTS ra, RESOURCES p:n      WHERE +
1ra.PROJECT_ID=h_id AND:n      ra.RESOURCE_ID = p.RESOURCE_ID AND:n      NOT E+
1XISTS(SELECT rd.RESOURCE_ID FROM PMO_TMP_RESOURCE_DATA rd WHERE ra.RESOURCE_I+
1D = rd.RESOURCE_ID):n      ORDER BY TYPE_ID DESC, ELEMENT_NAME:
11560:
1                EXIT:: SP_S_PROFILE(1561) :: cplan.sql(16131) :: :
1%%:
1SELECT t.ELEMENT_ID, p.FULL_NAME AS ELEMENT_NAME,13 AS TYPE_ID, p.NICK_NAME, +
1'N' AS PA_FLAG,:n      p.LOGON_NAME AS RPM_LOGON_NAME, P.E_MAIL_ADDRESS, p.WO+
1RK_LOCATION, p.WORK_PHONE:n      FROM TMT_POOLS t JOIN RESOURCES p:n      ON +
1t.ELEMENT_ID = p.RESOURCE_ID:n      WHERE t.TYPE_ID = 13:n      AND t.RANK LI+
1KE h_rank:n      ORDER BY ELEMENT_NAME:
11576:
1                EXIT:: SP_S_PROFILE(1577) :: cplan.sql(16147) :: :
1SELECT R.RESOURCE_ID AS ELEMENT_ID, R.FULL_NAME AS ELEMENT_NAME,pmo_cnst.SC_R+
1ESOURCE AS TYPE_ID, R.NICK_NAME, 'N' AS PA_FLAG,:n      R.LOGON_NAME AS RPM_L+
1OGON_NAME, R.E_MAIL_ADDRESS, R.WORK_LOCATION, R.WORK_PHONE:n      FROM PROJEC+
1T_ASSIGNMENTS RA, RESOURCES R:n      WHERE RA.PROJECT_ID = h_id:n      AND RA+
1.RESOURCE_ID = R.RESOURCE_ID:n      ORDER BY ELEMENT_NAME:
11591:
1                EXIT:: SP_S_PROFILE(1592) :: cplan.sql(16162) :: :
11596:
1       RETURN_STATUS:: SP_S_PROFILE(1597) :: cplan.sql(16167) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
11605:
1           EXCEPTION:: SP_S_PROFILE(1606) :: cplan.sql(16176) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
11617:
1           EXCEPTION:: SP_S_PROFILE(1618) :: cplan.sql(16188) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
245a
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
a3 :2 a0 6b 1c 81 b0 a3 :2 a0
6b 1c 81 b0 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :2 a0 d :2 a0 d :2 a0
d :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e 5a 52 10 :18 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:15 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :4 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 19 3c b7 19 3c a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c :8 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c a0
51 d a0 b7 19 :2 a0 51 a5
b a0 7e a0 6b b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 51 a5 b a0
7e a0 6b b4 2e 5a a 10
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a 10 :8 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6e 11e
11d :2 a0 6b 51 d :22 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6e 11e
11d :2 a0 6b 51 d :7 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :142 a0 12a e9
dd :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 65 a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e 5a 52 10 :2 a0 6e 11e 11d
:2 a0 6b 51 d :26 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 b4
2e d :2e a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :56 a0 12a e9 dd :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 65 a0 b7 19 :2 a0 51
a5 b 7e 51 b4 2e :8d a0 12a
e9 dd :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 65 a0
b7 19 :2 a0 51 a5 b 7e 51
b4 2e a0 6e d :7 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 6b a0 6e a5 b 7e 51
b4 2e 5a 52 10 :7 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:2 a0 6b a0 6e a5 b 7e 51
b4 2e 5a 52 10 a0 6e d
b7 :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :5 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :3 a0 51 a5 b
a5 b 7e 51 b4 2e a0 51
d :7 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 51 a5 b 7e
51 b4 2e a0 6e d b7 a0
51 d :9 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :1c a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e a0 6e
d b7 a0 6e d b7 :2 19 3c
b7 a0 6e d b7 :2 19 3c b7
:2 19 3c :292 a0 12a e9 dd :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 65 b7 :1a6 a0 12a e9 dd
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 65 b7 :2 19 3c
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6e 11e 11d :2 a0
6b 51 d :27 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 b4 2e
d :35 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :59 a0 12a e9 dd :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 65 a0 b7 19 :2 a0 51 a5
b 7e 51 b4 2e :2 a0 6e 11e
11d :2 a0 6b 51 d :27 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
b4 2e d :62 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :95 a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e :f4 a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6e 11e 11d :2 a0
6b 51 d :2f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6e 11e 11d :2 a0
6b 51 d :71 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :10 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :e5 a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b a0 7e a0 6b b4
2e :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :9a a0 12a e9 dd
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 65 b7 19 3c
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :19e a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e :d9 a0
12a e9 dd :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 65
a0 b7 19 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6e 11e 11d :2 a0
6b 51 d :10 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6e 11e 11d :2 a0
6b 51 d :e a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6e 11e 11d :2 a0
6b 51 d :26 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :82 a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 a0 b7 19 :2 a0
51 a5 b 7e 51 b4 2e :3 a0
7e 6e b4 2e :2 51 a5 b d
:23 a0 12a e9 dd :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
65 a0 b7 19 :2 a0 51 a5 b
a0 7e a0 6b b4 2e 5a :2 a0
51 a5 b a0 7e a0 6b b4
2e 5a 52 10 :23 a0 12a e9 dd
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 65 b7 19 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
:2 a0 a5 57 b7 :2 19 3c b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
245a
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
133 122 126 101 12e 121 14f 13e
142 11e 14a 13d 16b 15a 15e 13a
166 159 187 176 17a 156 182 175
1a3 192 196 172 19e 191 1bf 1ae
1b2 18e 1ba 1ad 1dc 1ca 1aa 1ce
1cf 1d7 1c9 1f9 1e7 1c6 1eb 1ec
1f4 1e6 219 204 208 1e3 20c 214
203 239 224 228 200 22c 234 223
259 244 248 220 24c 254 243 279
264 268 240 26c 274 263 299 284
288 260 28c 294 283 2b9 2a4 2a8
280 2ac 2b4 2a3 2d9 2c4 2c8 2a0
2cc 2d4 2c3 2f9 2e4 2e8 2c0 2ec
2f4 2e3 319 304 308 2e0 30c 314
303 339 324 328 300 32c 334 323
359 344 348 320 34c 354 343 379
364 368 340 36c 374 363 399 384
388 360 38c 394 383 3b9 3a4 3a8
380 3ac 3b4 3a3 3d9 3c4 3c8 3a0
3cc 3d4 3c3 3f9 3e4 3e8 3c0 3ec
3f4 3e3 400 404 3e0 408 40c 410
413 418 419 1 41b 420 424 428
42b 430 434 438 43b 440 441 443
448 44b 44f 450 455 45a 45d 462
463 468 46b 46f 470 475 478 47d
47e 483 486 48b 48c 491 494 498
49c 4a0 4a1 4a3 4a8 4a9 4ab 4ac
4b1 4b4 4b9 4ba 4bf 4c2 4c7 4c8
4cd 4d0 4d4 4d5 4da 4dd 4e2 4e3
4e8 4eb 4f0 4f1 4f6 4f7 4fc 4fe
502 505 509 50d 510 514 518 51b
51e 523 526 529 52c 52d 532 533
1 535 53a 53e 542 545 54a 54f
552 556 557 55c 55d 562 564 568
56b 56f 572 573 578 57b 57f 583
586 58a 58e 591 594 599 59c 59f
5a2 5a3 5a8 5a9 1 5ab 5b0 5b4
5b8 5bb 5c0 5c5 5c8 5cc 5cd 5d2
5d5 5da 5db 5e0 5e3 5e8 5e9 5ee
5f1 5f5 5f9 5fd 601 604 605 607
60c 60d 60f 610 615 618 61d 61e
623 626 62b 62c 631 634 638 639
63e 641 646 647 64c 64d 652 654
658 65b 65f 663 666 66a 66e 671
674 679 67c 67f 682 683 688 689
1 68b 690 694 698 69b 6a0 6a5
6a8 6ac 6ad 6b2 6b3 6b8 6ba 6be
6c1 6c5 6c9 6cc 6d0 6d4 6d7 6db
6df 6e0 6e5 6e7 6eb 6ee 6f2 6f6
6fa 6fe 702 706 70a 70e 712 716
71a 71d 71e 720 723 726 727 72c
72f 733 737 73a 73b 73d 740 743
744 749 1 74c 751 755 759 75d
761 765 769 76d 771 775 779 77d
781 785 789 78d 791 795 799 79d
7a1 7a5 7a9 7ad 7b1 7bd 7c1 7c5
7c8 7cc 7d0 7d2 7d6 7da 7de 7e1
7e5 7e9 7eb 7ec 7f1 1 7f5 7f9
7fd 800 804 808 80c 810 813 817
81b 81e 821 826 829 82c 82f 830
835 836 1 838 83d 841 845 848
84d 852 855 859 85a 85f 862 867
868 86d 870 875 876 87b 87e 882
883 888 88b 890 891 896 899 89d
8a1 8a4 8a7 8a8 8aa 8ab 8b0 8b1
8b6 8b8 8bc 8bf 8c1 8c5 8c7 8d3
8d5 8d7 8d8 8dd 8e1 8e3 8ef 8f1
8f5 8f9 8fc 900 903 907 90a 90b
910 913 917 91b 91f 923 927 92b
92f 933 937 93b 93f 943 947 94b
94f 953 957 95b 95f 963 967 973
977 97b 97e 982 986 988 98c 990
994 997 99b 99f 9a1 9a2 9a7 1
9ab 9af 9b3 9b6 9ba 9be 9c2 9c6
9c9 9cd 9d1 9d4 9d7 9dc 9df 9e2
9e5 9e6 9eb 9ec 1 9ee 9f3 9f7
9fb 9fe a03 a08 a0b a0f a10 a15
a18 a1d a1e a23 a26 a2b a2c a31
a34 a38 a39 a3e a41 a46 a47 a4c
a4f a53 a57 a5a a5d a5e a60 a61
a66 a67 a6c a6e a72 a75 a77 a7b
a7d a89 a8b a8d a8e a93 a97 a99
aa5 aa7 aab aaf ab2 ab6 ab9 abd
ac0 ac1 ac6 ac9 acd ad1 ad5 ad9
ae5 ae9 aed af0 af4 af8 afa afe
b02 b06 b09 b0d b11 b13 b14 b19
1 b1d b21 b25 b28 b2c b30 b34
b38 b3b b3f b43 b46 b49 b4e b51
b54 b57 b58 b5d b5e 1 b60 b65
b69 b6d b70 b75 b7a b7d b81 b82
b87 b8a b8f b90 b95 b98 b9d b9e
ba3 ba6 baa bab bb0 bb3 bb8 bb9
bbe bc1 bc5 bc9 bcc bcf bd0 bd2
bd3 bd8 bd9 bde be0 be4 be7 be9
bed bef bfb bfd bff c00 c05 c09
c0b c17 c19 c1d c21 c24 c28 c2b
c2f c32 c33 c38 c3b c3f c43 c46
c4a c4e c51 c54 c59 c5c c5f c62
c63 c68 c69 1 c6b c70 c74 c78
c7b c80 c85 c88 c8c c8d c92 c95
c9a c9b ca0 ca3 ca8 ca9 cae cb1
cb5 cb9 cbd cc1 cc4 cc5 cc7 ccc
ccd ccf cd0 cd5 cd8 cdd cde ce3
ce6 ceb cec cf1 cf4 cf8 cf9 cfe
d01 d06 d07 d0c d0d d12 d14 d18
d1b d1f d23 d26 d2a d2e d31 d34
d39 d3c d3f d42 d43 d48 d49 1
d4b d50 d54 d58 d5b d60 d65 d68
d6c d6d d72 d73 d78 d7a d7e d81
d85 d89 d8c d90 d94 d97 d9b d9f
da0 da5 da7 dab dae db0 db4 db7
db9 dbd dc0 dc4 dc6 dca dce dd1
dd2 dd4 dd7 dda ddb de0 de4 de8
dec df0 df4 e00 e04 e08 e0b e0f
e13 e15 e19 e1d e21 e24 e28 e2c
e2e e2f e34 1 e38 e3c e40 e43
e47 e4b e4f e53 e56 e5a e5e e61
e64 e69 e6c e6f e72 e73 e78 e79
1 e7b e80 e84 e88 e8b e90 e95
e98 e9c e9d ea2 ea5 eaa eab eb0
eb3 eb8 eb9 ebe ec1 ec5 ec6 ecb
ece ed3 ed4 ed9 edc ee0 ee4 ee7
eea eeb eed eee ef3 ef4 ef9 efb
eff f02 f04 f08 f0a f16 f18 f1a
f1b f20 f24 f26 f32 f34 f38 f3c
f3f f43 f46 f4a f4d f4e f53 f56
f5a f5e f61 f65 f69 f6c f6f f74
f77 f7a f7d f7e f83 f84 1 f86
f8b f8f f93 f96 f9b fa0 fa3 fa7
fa8 fad fb0 fb5 fb6 fbb fbe fc3
fc4 fc9 fcc fd0 fd4 fd8 fdc fdf
fe0 fe2 fe7 fe8 fea feb ff0 ff3
ff8 ff9 ffe 1001 1006 1007 100c 100f
1013 1014 1019 101c 1021 1022 1027 1028
102d 102f 1033 1036 103a 103e 1041 1045
1049 104c 104f 1054 1057 105a 105d 105e
1063 1064 1 1066 106b 106f 1073 1076
107b 1080 1083 1087 1088 108d 108e 1093
1095 1099 109c 10a0 10a4 10a7 10ab 10af
10b2 10b6 10ba 10bb 10c0 10c2 10c6 10c9
10cd 10d1 10d5 10d9 10dd 10e1 10e5 10e9
10f5 10f9 10fd 1100 1104 1108 110a 110e
1112 1116 1119 111d 1121 1123 1124 1129
1 112d 1131 1135 1138 113c 1140 1144
1148 114b 114f 1153 1156 1159 115e 1161
1164 1167 1168 116d 116e 1 1170 1175
1179 117d 1180 1185 118a 118d 1191 1192
1197 119a 119f 11a0 11a5 11a8 11ad 11ae
11b3 11b6 11ba 11bb 11c0 11c3 11c8 11c9
11ce 11d1 11d5 11d9 11dc 11df 11e0 11e2
11e3 11e8 11e9 11ee 11f0 11f4 11f7 11f9
11fd 11ff 120b 120d 120f 1210 1215 1219
121b 1227 1229 122d 122f 1233 1237 123b
123e 123f 1241 1244 1247 1248 124d 1251
1255 1259 125d 1261 126d 1271 1275 1278
127c 1280 1282 1286 128a 128e 1291 1295
1299 129b 129c 12a1 1 12a5 12a9 12ad
12b0 12b4 12b8 12bc 12c0 12c3 12c7 12cb
12ce 12d1 12d6 12d9 12dc 12df 12e0 12e5
12e6 1 12e8 12ed 12f1 12f5 12f8 12fd
1302 1305 1309 130a 130f 1312 1317 1318
131d 1320 1325 1326 132b 132e 1332 1333
1338 133b 1340 1341 1346 1349 134d 1351
1354 1357 1358 135a 135b 1360 1361 1366
1368 136c 136f 1371 1375 1377 1383 1385
1387 1388 138d 1391 1393 139f 13a1 13a5
13a9 13ac 13b0 13b3 13b7 13ba 13bb 13c0
13c3 13c7 13cb 13ce 13d2 13d6 13d9 13dc
13e1 13e4 13e7 13ea 13eb 13f0 13f1 1
13f3 13f8 13fc 1400 1403 1408 140d 1410
1414 1415 141a 141d 1422 1423 1428 142b
1430 1431 1436 1439 143d 1441 1445 1449
144c 144d 144f 1454 1455 1457 1458 145d
1460 1465 1466 146b 146e 1473 1474 1479
147c 1480 1481 1486 1489 148e 148f 1494
1495 149a 149c 14a0 14a3 14a7 14ab 14ae
14b2 14b6 14b9 14bc 14c1 14c4 14c7 14ca
14cb 14d0 14d1 1 14d3 14d8 14dc 14e0
14e3 14e8 14ed 14f0 14f4 14f5 14fa 14fb
1500 1502 1506 1509 150d 1511 1514 1518
151c 151f 1523 1527 1528 152d 152f 1533
1536 153a 153d 1541 1545 1547 154b 154f
1553 1556 1557 1559 155d 1560 1564 1567
1568 156d 1570 1574 1578 157b 157c 157e
1581 1584 1585 158a 1 158d 1592 1596
159a 159d 159e 15a0 15a4 15a7 15ab 15ae
15af 15b4 1 15b7 15bc 15c0 15c4 15c7
15c8 15ca 15ce 15d1 15d5 15d8 15d9 15de
1 15e1 15e6 15ea 15ee 15f2 15f6 15fa
15fe 1602 1606 1612 1616 161a 161d 1621
1625 1627 162b 162f 1633 1636 163a 163e
1640 1641 1646 1 164a 164e 1652 1655
1659 165d 1661 1665 1668 166c 1670 1673
1676 167b 167e 1681 1684 1685 168a 168b
1 168d 1692 1696 169a 169d 16a2 16a7
16aa 16ae 16af 16b4 16b7 16bc 16bd 16c2
16c5 16ca 16cb 16d0 16d3 16d7 16d8 16dd
16e0 16e5 16e6 16eb 16ee 16f2 16f6 16f9
16fc 16fd 16ff 1700 1705 1706 170b 170d
1711 1714 1716 171a 171c 1728 172a 172c
172d 1732 1736 1738 1744 1746 174a 174e
1751 1755 1758 175c 175f 1760 1765 1768
176c 1770 1773 1777 177b 177e 1781 1786
1789 178c 178f 1790 1795 1796 1 1798
179d 17a1 17a5 17a8 17ad 17b2 17b5 17b9
17ba 17bf 17c2 17c7 17c8 17cd 17d0 17d5
17d6 17db 17de 17e2 17e6 17ea 17ee 17f1
17f2 17f4 17f9 17fa 17fc 17fd 1802 1805
180a 180b 1810 1813 1818 1819 181e 1821
1825 1826 182b 182e 1833 1834 1839 183a
183f 1841 1845 1848 184c 1850 1853 1857
185b 185e 1861 1866 1869 186c 186f 1870
1875 1876 1 1878 187d 1881 1885 1888
188d 1892 1895 1899 189a 189f 18a0 18a5
18a7 18ab 18ae 18b2 18b6 18b9 18bd 18c1
18c4 18c8 18cc 18cd 18d2 18d4 18d8 18db
18dd 18e1 18e5 18e8 18ec 18f0 18f3 18f4
18f6 18f9 18fc 18fd 1902 1906 190a 190f
1914 1918 191c 1920 1923 1926 192a 192e
1932 1936 193a 193e 1942 1946 194a 194e
1952 1956 195a 195e 1962 1966 196a 196e
1972 1976 197a 197e 1982 1986 198a 198e
1992 1996 199a 199e 19a2 19a6 19aa 19ae
19b2 19be 19c2 19c7 19cb 19ce 19cf 19d4
19d8 19dc 19df 19e2 19e6 19e8 19ec 19f0
19f3 19f6 19fa 19fc 1a00 1a04 1a07 1a09
1a0d 1a11 1a15 1a18 1a1c 1a20 1a22 1a23
1a28 1 1a2c 1a30 1a34 1a37 1a3b 1a3f
1a43 1a47 1a4a 1a4e 1a52 1a55 1a58 1a5d
1a60 1a63 1a66 1a67 1a6c 1a6d 1 1a6f
1a74 1a78 1a7c 1a7f 1a84 1a89 1a8c 1a90
1a91 1a96 1a99 1a9e 1a9f 1aa4 1aa7 1aac
1aad 1ab2 1ab5 1ab9 1aba 1abf 1ac2 1ac7
1ac8 1acd 1ad0 1ad4 1ad8 1adb 1ade 1adf
1ae1 1ae2 1ae7 1ae8 1aed 1aef 1af3 1af6
1af8 1afc 1afe 1b0a 1b0c 1b0e 1b0f 1b14
1b18 1b1a 1b26 1b28 1b2c 1b30 1b35 1b3a
1b3e 1b42 1b46 1b49 1b4c 1b50 1b54 1b58
1b5c 1b60 1b64 1b68 1b6c 1b78 1b7c 1b81
1b85 1b88 1b89 1b8e 1b92 1b96 1b99 1b9c
1ba0 1ba2 1ba6 1baa 1bad 1bb0 1bb4 1bb6
1bba 1bbe 1bc1 1bc3 1bc7 1bcb 1bcf 1bd2
1bd6 1bda 1bdc 1bdd 1be2 1 1be6 1bea
1bee 1bf1 1bf5 1bf9 1bfd 1c01 1c04 1c08
1c0c 1c0f 1c12 1c17 1c1a 1c1d 1c20 1c21
1c26 1c27 1 1c29 1c2e 1c32 1c36 1c39
1c3e 1c43 1c46 1c4a 1c4b 1c50 1c53 1c58
1c59 1c5e 1c61 1c66 1c67 1c6c 1c6f 1c73
1c74 1c79 1c7c 1c81 1c82 1c87 1c8a 1c8e
1c92 1c95 1c98 1c99 1c9b 1c9c 1ca1 1ca2
1ca7 1ca9 1cad 1cb0 1cb2 1cb6 1cb8 1cc4
1cc6 1cc8 1cc9 1cce 1cd2 1cd4 1ce0 1ce2
1ce6 1cea 1cee 1cf2 1cf6 1cfa 1cfe 1d02
1d06 1d0a 1d0e 1d12 1d16 1d1a 1d1e 1d22
1d26 1d2a 1d2e 1d32 1d36 1d3a 1d3e 1d42
1d46 1d4a 1d4e 1d52 1d56 1d5a 1d5e 1d62
1d66 1d6a 1d6e 1d72 1d76 1d7a 1d7e 1d82
1d86 1d8a 1d8e 1d92 1d96 1d9a 1d9e 1da2
1da6 1daa 1dae 1db2 1db6 1dba 1dbe 1dc2
1dc6 1dca 1dce 1dd2 1dd6 1dda 1dde 1de2
1de6 1dea 1dee 1df2 1df6 1dfa 1dfe 1e02
1e06 1e0a 1e0e 1e12 1e16 1e1a 1e1e 1e22
1e26 1e2a 1e2e 1e32 1e36 1e3a 1e3e 1e42
1e46 1e4a 1e4e 1e52 1e56 1e5a 1e5e 1e62
1e66 1e6a 1e6e 1e72 1e76 1e7a 1e7e 1e82
1e86 1e8a 1e8e 1e92 1e96 1e9a 1e9e 1ea2
1ea6 1eaa 1eae 1eb2 1eb6 1eba 1ebe 1ec2
1ec6 1eca 1ece 1ed2 1ed6 1eda 1ede 1ee2
1ee6 1eea 1eee 1ef2 1ef6 1efa 1efe 1f02
1f06 1f0a 1f0e 1f12 1f16 1f1a 1f1e 1f22
1f26 1f2a 1f2e 1f32 1f36 1f3a 1f3e 1f42
1f46 1f4a 1f4e 1f52 1f56 1f5a 1f5e 1f62
1f66 1f6a 1f6e 1f72 1f76 1f7a 1f7e 1f82
1f86 1f8a 1f8e 1f92 1f96 1f9a 1f9e 1fa2
1fa6 1faa 1fae 1fb2 1fb6 1fba 1fbe 1fc2
1fc6 1fca 1fce 1fd2 1fd6 1fda 1fde 1fe2
1fe6 1fea 1fee 1ff2 1ff6 1ffa 1ffe 2002
2006 200a 200e 2012 2016 201a 201e 2022
2026 202a 202e 2032 2036 203a 203e 2042
2046 204a 204e 2052 2056 205a 205e 2062
2066 206a 206e 2072 2076 207a 207e 2082
2086 208a 208e 2092 2096 209a 209e 20a2
20a6 20aa 20ae 20b2 20b6 20ba 20be 20c2
20c6 20ca 20ce 20d2 20d6 20da 20de 20e2
20e6 20ea 20ee 20f2 20f6 20fa 20fe 2102
2106 210a 210e 2112 2116 211a 211e 2122
2126 212a 212e 2132 2136 213a 213e 2142
2146 214a 214e 2152 2156 215a 215e 2162
2166 216a 216e 2172 2176 217a 217e 2182
2186 218a 218e 2192 2196 219a 219e 21a2
21a6 21aa 21ae 21b2 21b6 21ba 21be 21c2
21c6 21ca 21ce 21d2 21d6 21da 21de 21e2
21e6 21ea 21f6 21fb 21ff 2203 2207 220a
220e 2212 2215 2218 221d 2220 2223 2226
2227 222c 222d 1 222f 2234 2238 223c
223f 2244 2249 224c 2250 2251 2256 2257
225c 225e 2262 2265 2269 226d 2271 2275
2277 227b 227f 2282 2283 2285 2288 228b
228c 2291 2294 2298 229c 229f 22a0 22a2
22a5 22a8 22a9 22ae 1 22b1 22b6 22ba
22be 22c3 22c8 22cc 22d0 22d4 22d7 22da
22de 22e2 22e6 22ea 22ee 22f2 22f6 22fa
22fe 2302 2306 230a 230e 2312 2316 231a
231e 2322 2326 232a 232e 2332 2336 233a
233e 2342 2346 234a 234e 2352 2356 235a
235e 2362 2366 236a 236e 2372 2376 2382
2386 238b 238f 2392 2393 2398 239c 23a0
23a3 23a6 23aa 23ac 23b0 23b4 23b7 23ba
23be 23c0 23c4 23c8 23cb 23cd 23d1 23d5
23d9 23dc 23e0 23e4 23e6 23e7 23ec 1
23f0 23f4 23f8 23fb 23ff 2403 2407 240b
240e 2412 2416 2419 241c 2421 2424 2427
242a 242b 2430 2431 1 2433 2438 243c
2440 2443 2448 244d 2450 2454 2455 245a
245d 2462 2463 2468 246b 2470 2471 2476
2479 247d 247e 2483 2486 248b 248c 2491
2494 2498 249c 249f 24a2 24a3 24a5 24a6
24ab 24ac 24b1 24b3 24b7 24ba 24bc 24c0
24c2 24ce 24d0 24d2 24d3 24d8 24dc 24de
24ea 24ec 24f0 24f4 24f7 24fb 24fc 2501
2505 2509 250d 2511 2515 2519 251d 2521
2525 2529 252d 2531 2535 2539 253d 2541
2545 2549 254d 2551 2555 2559 255d 2561
2565 2569 256d 2571 2575 2579 257d 2581
2585 2589 258d 2591 2595 2599 259d 25a1
25a5 25a9 25ad 25b1 25b5 25b9 25bd 25c9
25cd 25d2 25d6 25d9 25da 25df 25e3 25e7
25ea 25ed 25f1 25f3 25f7 25fb 25fe 2601
2605 2607 260b 260f 2612 2614 2618 261c
2620 2623 2627 262b 262d 262e 2633 1
2637 263b 263f 2642 2646 264a 264e 2652
2655 2659 265d 2660 2663 2668 266b 266e
2671 2672 2677 2678 1 267a 267f 2683
2687 268a 268f 2694 2697 269b 269c 26a1
26a4 26a9 26aa 26af 26b2 26b7 26b8 26bd
26c0 26c4 26c5 26ca 26cd 26d2 26d3 26d8
26db 26df 26e3 26e6 26e9 26ea 26ec 26ed
26f2 26f3 26f8 26fa 26fe 2701 2703 2707
2709 2715 2717 2719 271a 271f 2723 2725
2731 2733 2737 273b 273f 2743 2747 274b
274f 2753 2757 275b 275f 2763 2767 276b
276f 2773 2777 277b 277f 2783 2787 278b
278f 2793 2797 279b 279f 27a3 27a7 27ab
27af 27b3 27b7 27bb 27bf 27c3 27c7 27cb
27cf 27d3 27d7 27db 27df 27e3 27e7 27eb
27ef 27f3 27f7 27fb 27ff 2803 2807 280b
280f 2813 2817 281b 281f 2823 2827 282b
282f 2833 2837 283b 283f 2843 2847 284b
284f 2853 2857 285b 285f 2863 2867 286b
286f 2873 2877 287b 287f 2883 2887 288b
2897 289c 28a0 28a4 28a8 28ab 28af 28b3
28b6 28b9 28be 28c1 28c4 28c7 28c8 28cd
28ce 1 28d0 28d5 28d9 28dd 28e0 28e5
28ea 28ed 28f1 28f2 28f7 28f8 28fd 28ff
2903 2906 290a 290e 2912 2916 2918 291c
2920 2924 2927 2928 292a 292d 2930 2931
2936 293a 293e 2942 2946 294a 294e 2952
2956 295a 295e 2962 2966 296a 296e 2972
2976 297a 297e 2982 2986 298a 298e 2992
2996 299a 299e 29a2 29a6 29aa 29ae 29b2
29b6 29ba 29be 29c2 29c6 29ca 29ce 29d2
29d6 29da 29de 29e2 29e6 29ea 29ee 29f2
29f6 29fa 29fe 2a02 2a06 2a0a 2a0e 2a12
2a16 2a1a 2a1e 2a22 2a26 2a2a 2a2e 2a32
2a36 2a3a 2a3e 2a42 2a46 2a4a 2a4e 2a52
2a56 2a5a 2a5e 2a62 2a66 2a6a 2a6e 2a72
2a76 2a7a 2a7e 2a82 2a86 2a8a 2a8e 2a92
2a96 2a9a 2a9e 2aa2 2aa6 2aaa 2aae 2ab2
2ab6 2aba 2abe 2ac2 2ac6 2aca 2ace 2ad2
2ad6 2ada 2ade 2ae2 2ae6 2aea 2aee 2af2
2af6 2afa 2afe 2b02 2b06 2b0a 2b0e 2b12
2b16 2b1a 2b1e 2b22 2b26 2b2a 2b2e 2b32
2b36 2b3a 2b3e 2b42 2b46 2b4a 2b4e 2b52
2b56 2b5a 2b5e 2b62 2b66 2b6a 2b76 2b7b
2b7f 2b83 2b87 2b8a 2b8e 2b92 2b95 2b98
2b9d 2ba0 2ba3 2ba6 2ba7 2bac 2bad 1
2baf 2bb4 2bb8 2bbc 2bbf 2bc4 2bc9 2bcc
2bd0 2bd1 2bd6 2bd7 2bdc 2bde 2be2 2be5
2be9 2bed 2bf1 2bf5 2bf7 2bfb 2bff 2c03
2c06 2c07 2c09 2c0c 2c0f 2c10 2c15 2c19
2c1e 2c22 2c26 2c2a 2c2e 2c32 2c36 2c3a
2c3e 2c4a 2c4e 2c52 2c55 2c59 2c5d 2c5f
2c63 2c67 2c6b 2c6e 2c72 2c76 2c78 2c79
2c7e 1 2c82 2c86 2c8a 2c8d 2c91 2c95
2c99 2c9d 2ca0 2ca4 2ca8 2cab 2cae 2cb3
2cb6 2cb9 2cbc 2cbd 2cc2 2cc3 1 2cc5
2cca 2cce 2cd2 2cd5 2cda 2cdf 2ce2 2ce6
2ce7 2cec 2cef 2cf4 2cf5 2cfa 2cfd 2d02
2d03 2d08 2d0b 2d0f 2d10 2d15 2d18 2d1d
2d1e 2d23 2d26 2d2a 2d2e 2d31 2d34 2d35
2d37 2d38 2d3d 2d3e 2d43 2d45 2d49 2d4c
2d4e 2d52 2d54 2d60 2d62 2d64 2d65 2d6a
2d6e 2d70 2d7c 2d7e 2d82 2d86 2d89 2d8d
2d90 2d94 2d97 2d98 2d9d 2da0 2da4 2da8
2dab 2daf 2db4 2db5 2db7 2dba 2dbd 2dbe
2dc3 1 2dc6 2dcb 2dcf 2dd3 2dd7 2ddb
2ddf 2de3 2de7 2df3 2df7 2dfb 2dfe 2e02
2e06 2e08 2e0c 2e10 2e14 2e17 2e1b 2e1f
2e21 2e22 2e27 1 2e2b 2e2f 2e33 2e36
2e3a 2e3e 2e42 2e46 2e49 2e4d 2e51 2e54
2e57 2e5c 2e5f 2e62 2e65 2e66 2e6b 2e6c
1 2e6e 2e73 2e77 2e7b 2e7e 2e83 2e88
2e8b 2e8f 2e90 2e95 2e98 2e9d 2e9e 2ea3
2ea6 2eab 2eac 2eb1 2eb4 2eb8 2eb9 2ebe
2ec1 2ec6 2ec7 2ecc 2ecf 2ed3 2ed7 2eda
2edd 2ede 2ee0 2ee1 2ee6 2ee7 2eec 2eee
2ef2 2ef5 2ef7 2efb 2efd 2f09 2f0b 2f0d
2f0e 2f13 2f17 2f19 2f25 2f27 2f2b 2f2f
2f32 2f36 2f39 2f3d 2f40 2f41 2f46 2f49
2f4d 2f51 2f54 2f58 2f5d 2f5e 2f60 2f63
2f66 2f67 2f6c 1 2f6f 2f74 2f78 2f7d
2f81 2f83 2f87 2f8b 2f8f 2f93 2f97 2fa3
2fa7 2fab 2fae 2fb2 2fb6 2fb8 2fbc 2fc0
2fc4 2fc7 2fcb 2fcf 2fd1 2fd2 2fd7 1
2fdb 2fdf 2fe3 2fe6 2fea 2fee 2ff2 2ff6
2ff9 2ffd 3001 3004 3007 300c 300f 3012
3015 3016 301b 301c 1 301e 3023 3027
302b 302e 3033 3038 303b 303f 3040 3045
3048 304d 304e 3053 3056 305b 305c 3061
3064 3068 3069 306e 3071 3076 3077 307c
307f 3083 3087 308a 308d 308e 3090 3091
3096 3097 309c 309e 30a2 30a5 30a7 30ab
30ad 30b9 30bb 30bd 30be 30c3 30c7 30c9
30d5 30d7 30d9 30dd 30e1 30e4 30e6 30ea
30ee 30f2 30f6 30fa 3106 310a 310e 3111
3115 3119 311b 311f 3123 3127 312a 312e
3132 3134 3135 313a 1 313e 3142 3146
3149 314d 3151 3155 3159 315c 3160 3164
3167 316a 316f 3172 3175 3178 3179 317e
317f 1 3181 3186 318a 318e 3191 3196
319b 319e 31a2 31a3 31a8 31ab 31b0 31b1
31b6 31b9 31be 31bf 31c4 31c7 31cb 31cc
31d1 31d4 31d9 31da 31df 31e2 31e6 31ea
31ed 31f0 31f1 31f3 31f4 31f9 31fa 31ff
3201 3205 3208 320a 320e 3210 321c 321e
3220 3221 3226 322a 322c 3238 323a 323c
3240 3244 3247 324b 324f 3253 3256 3257
3259 325a 325c 325f 3262 3263 3268 326c
326f 3273 3277 327b 327f 3283 3287 328b
328f 329b 329f 32a3 32a6 32aa 32ae 32b0
32b4 32b8 32bc 32bf 32c3 32c7 32c9 32ca
32cf 1 32d3 32d7 32db 32de 32e2 32e6
32ea 32ee 32f1 32f5 32f9 32fc 32ff 3304
3307 330a 330d 330e 3313 3314 1 3316
331b 331f 3323 3326 332b 3330 3333 3337
3338 333d 3340 3345 3346 334b 334e 3353
3354 3359 335c 3360 3361 3366 3369 336e
336f 3374 3377 337b 337f 3382 3385 3386
3388 3389 338e 338f 3394 3396 339a 339d
339f 33a3 33a5 33b1 33b3 33b5 33b6 33bb
33bf 33c1 33cd 33cf 33d3 33d7 33da 33db
33dd 33e0 33e3 33e4 33e9 33ed 33f2 33f6
33f8 33fc 33ff 3403 3407 340b 340f 3413
3417 341b 341f 3423 3427 3433 3437 343b
343e 3442 3446 3448 344c 3450 3454 3457
345b 345f 3461 3462 3467 1 346b 346f
3473 3476 347a 347e 3482 3486 3489 348d
3491 3494 3497 349c 349f 34a2 34a5 34a6
34ab 34ac 1 34ae 34b3 34b7 34bb 34be
34c3 34c8 34cb 34cf 34d0 34d5 34d8 34dd
34de 34e3 34e6 34eb 34ec 34f1 34f4 34f8
34f9 34fe 3501 3506 3507 350c 350f 3513
3517 351a 351d 351e 3520 3521 3526 3527
352c 352e 3532 3535 3537 353b 353d 3549
354b 354d 354e 3553 3557 3559 3565 3567
356b 356f 3572 3573 3575 3578 357b 357c
3581 3585 3589 358d 3591 3595 3599 359d
35a1 35a5 35a9 35ad 35b1 35b5 35b9 35bd
35c1 35c5 35c9 35cd 35d1 35d5 35d9 35dd
35e1 35e5 35e9 35ed 35f1 35fd 3601 3605
3608 360c 3610 3612 3616 361a 361e 3621
3625 3629 362b 362c 3631 1 3635 3639
363d 3640 3644 3648 364c 3650 3653 3657
365b 365e 3661 3666 3669 366c 366f 3670
3675 3676 1 3678 367d 3681 3685 3688
368d 3692 3695 3699 369a 369f 36a2 36a7
36a8 36ad 36b0 36b5 36b6 36bb 36be 36c2
36c3 36c8 36cb 36d0 36d1 36d6 36d9 36dd
36e1 36e4 36e7 36e8 36ea 36eb 36f0 36f1
36f6 36f8 36fc 36ff 3701 3705 3707 3713
3715 3717 3718 371d 3721 3723 372f 3731
3735 3739 373c 373d 373f 3742 3745 3746
374b 374f 3754 3758 375a 375e 3763 3767
3769 376d 3771 3774 3776 377a 377f 3783
3785 3789 378d 3790 3792 3796 379a 379d
37a1 37a5 37a9 37ad 37b1 37b5 37b9 37bd
37c1 37c5 37c9 37cd 37d1 37d5 37d9 37dd
37e1 37e5 37e9 37ed 37f1 37f5 37f9 37fd
3801 3805 3809 380d 3811 3815 3819 381d
3821 3825 3829 382d 3831 3835 3839 383d
3841 3845 3849 384d 3851 3855 3859 385d
3861 3865 3869 386d 3871 3875 3879 387d
3881 3885 3889 388d 3891 3895 3899 389d
38a1 38a5 38a9 38ad 38b1 38b5 38b9 38bd
38c1 38c5 38c9 38cd 38d1 38d5 38d9 38dd
38e1 38e5 38e9 38ed 38f1 38f5 38f9 38fd
3901 3905 3909 390d 3911 3915 3919 391d
3921 3925 3929 392d 3931 3935 3939 393d
3941 3945 3949 394d 3951 3955 3959 395d
3961 3965 3969 396d 3971 3975 3979 397d
3981 3985 3989 398d 3991 3995 3999 399d
39a1 39a5 39a9 39ad 39b1 39b5 39b9 39bd
39c1 39c5 39c9 39cd 39d1 39d5 39d9 39dd
39e1 39e5 39e9 39ed 39f1 39f5 39f9 39fd
3a01 3a05 3a09 3a0d 3a11 3a15 3a19 3a1d
3a21 3a25 3a29 3a2d 3a31 3a35 3a39 3a3d
3a41 3a45 3a49 3a4d 3a51 3a55 3a59 3a5d
3a61 3a65 3a69 3a6d 3a71 3a75 3a79 3a7d
3a81 3a85 3a89 3a8d 3a91 3a95 3a99 3a9d
3aa1 3aa5 3aa9 3aad 3ab1 3ab5 3ab9 3abd
3ac1 3ac5 3ac9 3acd 3ad1 3ad5 3ad9 3add
3ae1 3ae5 3ae9 3aed 3af1 3af5 3af9 3afd
3b01 3b05 3b09 3b0d 3b11 3b15 3b19 3b1d
3b21 3b25 3b29 3b2d 3b31 3b35 3b39 3b3d
3b41 3b45 3b49 3b4d 3b51 3b55 3b59 3b5d
3b61 3b65 3b69 3b6d 3b71 3b75 3b79 3b7d
3b81 3b85 3b89 3b8d 3b91 3b95 3b99 3b9d
3ba1 3ba5 3ba9 3bad 3bb1 3bb5 3bb9 3bbd
3bc1 3bc5 3bc9 3bcd 3bd1 3bd5 3bd9 3bdd
3be1 3be5 3be9 3bed 3bf1 3bf5 3bf9 3bfd
3c01 3c05 3c09 3c0d 3c11 3c15 3c19 3c1d
3c21 3c25 3c29 3c2d 3c31 3c35 3c39 3c3d
3c41 3c45 3c49 3c4d 3c51 3c55 3c59 3c5d
3c61 3c65 3c69 3c6d 3c71 3c75 3c79 3c7d
3c81 3c85 3c89 3c8d 3c91 3c95 3c99 3c9d
3ca1 3ca5 3ca9 3cad 3cb1 3cb5 3cb9 3cbd
3cc1 3cc5 3cc9 3ccd 3cd1 3cd5 3cd9 3cdd
3ce1 3ce5 3ce9 3ced 3cf1 3cf5 3cf9 3cfd
3d01 3d05 3d09 3d0d 3d11 3d15 3d19 3d1d
3d21 3d25 3d29 3d2d 3d31 3d35 3d39 3d3d
3d41 3d45 3d49 3d4d 3d51 3d55 3d59 3d5d
3d61 3d65 3d69 3d6d 3d71 3d75 3d79 3d7d
3d81 3d85 3d89 3d8d 3d91 3d95 3d99 3d9d
3da1 3da5 3da9 3dad 3db1 3db5 3db9 3dbd
3dc1 3dc5 3dc9 3dcd 3dd1 3dd5 3dd9 3ddd
3de1 3de5 3de9 3ded 3df1 3df5 3df9 3dfd
3e01 3e05 3e09 3e0d 3e11 3e15 3e19 3e1d
3e21 3e25 3e29 3e2d 3e31 3e35 3e39 3e3d
3e41 3e45 3e49 3e4d 3e51 3e55 3e59 3e5d
3e61 3e65 3e69 3e6d 3e71 3e75 3e79 3e7d
3e81 3e85 3e89 3e8d 3e91 3e95 3e99 3e9d
3ea1 3ea5 3ea9 3ead 3eb1 3eb5 3eb9 3ebd
3ec1 3ec5 3ec9 3ecd 3ed1 3ed5 3ed9 3edd
3ee1 3ee5 3ee9 3eed 3ef1 3ef5 3ef9 3efd
3f01 3f05 3f09 3f0d 3f11 3f15 3f19 3f1d
3f21 3f25 3f29 3f2d 3f31 3f35 3f39 3f3d
3f41 3f45 3f49 3f4d 3f51 3f55 3f59 3f5d
3f61 3f65 3f69 3f6d 3f71 3f75 3f79 3f7d
3f81 3f85 3f89 3f8d 3f91 3f95 3f99 3f9d
3fa1 3fa5 3fa9 3fad 3fb1 3fb5 3fb9 3fbd
3fc1 3fc5 3fc9 3fcd 3fd1 3fd5 3fd9 3fdd
3fe1 3fe5 3fe9 3fed 3ff1 3ff5 3ff9 3ffd
4001 4005 4009 400d 4011 4015 4019 401d
4021 4025 4029 402d 4031 4035 4039 403d
4041 4045 4049 404d 4051 4055 4059 405d
4061 4065 4069 406d 4071 4075 4079 407d
4081 4085 4089 408d 4091 4095 4099 409d
40a1 40a5 40a9 40ad 40b1 40b5 40b9 40bd
40c1 40c5 40c9 40cd 40d1 40d5 40d9 40dd
40e1 40e5 40e9 40ed 40f1 40f5 40f9 40fd
4101 4105 4109 410d 4111 4115 4119 411d
4121 4125 4129 412d 4131 4135 4139 413d
4141 4145 4149 414d 4151 4155 4159 415d
4161 4165 4169 416d 4171 4175 4179 417d
4181 4185 4189 418d 4191 4195 4199 419d
41a1 41a5 41a9 41ad 41b1 41b5 41b9 41bd
41c1 41c5 41c9 41cd 41d1 41d5 41d9 41dd
41e1 41e5 41f1 41f6 41fa 41fe 4202 4205
4209 420d 4210 4213 4218 421b 421e 4221
4222 4227 4228 1 422a 422f 4233 4237
423a 423f 4244 4247 424b 424c 4251 4252
4257 4259 425d 4260 4264 4268 426c 426e
4272 4276 427a 427e 4282 4286 428a 428e
4292 4296 429a 429e 42a2 42a6 42aa 42ae
42b2 42b6 42ba 42be 42c2 42c6 42ca 42ce
42d2 42d6 42da 42de 42e2 42e6 42ea 42ee
42f2 42f6 42fa 42fe 4302 4306 430a 430e
4312 4316 431a 431e 4322 4326 432a 432e
4332 4336 433a 433e 4342 4346 434a 434e
4352 4356 435a 435e 4362 4366 436a 436e
4372 4376 437a 437e 4382 4386 438a 438e
4392 4396 439a 439e 43a2 43a6 43aa 43ae
43b2 43b6 43ba 43be 43c2 43c6 43ca 43ce
43d2 43d6 43da 43de 43e2 43e6 43ea 43ee
43f2 43f6 43fa 43fe 4402 4406 440a 440e
4412 4416 441a 441e 4422 4426 442a 442e
4432 4436 443a 443e 4442 4446 444a 444e
4452 4456 445a 445e 4462 4466 446a 446e
4472 4476 447a 447e 4482 4486 448a 448e
4492 4496 449a 449e 44a2 44a6 44aa 44ae
44b2 44b6 44ba 44be 44c2 44c6 44ca 44ce
44d2 44d6 44da 44de 44e2 44e6 44ea 44ee
44f2 44f6 44fa 44fe 4502 4506 450a 450e
4512 4516 451a 451e 4522 4526 452a 452e
4532 4536 453a 453e 4542 4546 454a 454e
4552 4556 455a 455e 4562 4566 456a 456e
4572 4576 457a 457e 4582 4586 458a 458e
4592 4596 459a 459e 45a2 45a6 45aa 45ae
45b2 45b6 45ba 45be 45c2 45c6 45ca 45ce
45d2 45d6 45da 45de 45e2 45e6 45ea 45ee
45f2 45f6 45fa 45fe 4602 4606 460a 460e
4612 4616 461a 461e 4622 4626 462a 462e
4632 4636 463a 463e 4642 4646 464a 464e
4652 4656 465a 465e 4662 4666 466a 466e
4672 4676 467a 467e 4682 4686 468a 468e
4692 4696 469a 469e 46a2 46a6 46aa 46ae
46b2 46b6 46ba 46be 46c2 46c6 46ca 46ce
46d2 46d6 46da 46de 46e2 46e6 46ea 46ee
46f2 46f6 46fa 46fe 4702 4706 470a 470e
4712 4716 471a 471e 4722 4726 472a 472e
4732 4736 473a 473e 4742 4746 474a 474e
4752 4756 475a 475e 4762 4766 476a 476e
4772 4776 477a 477e 4782 4786 478a 478e
4792 4796 479a 479e 47a2 47a6 47aa 47ae
47b2 47b6 47ba 47be 47c2 47c6 47ca 47ce
47d2 47d6 47da 47de 47e2 47e6 47ea 47ee
47f2 47f6 47fa 47fe 4802 4806 480a 480e
4812 4816 481a 481e 4822 4826 482a 482e
4832 4836 483a 483e 4842 4846 484a 484e
4852 4856 485a 485e 4862 4866 486a 486e
4872 4876 487a 487e 4882 4886 488a 488e
4892 4896 489a 489e 48a2 48a6 48aa 48ae
48b2 48b6 48ba 48be 48c2 48c6 48ca 48ce
48d2 48d6 48da 48de 48e2 48e6 48ea 48ee
48f2 48f6 48fa 48fe 4902 4906 4912 4917
491b 491f 4923 4926 492a 492e 4931 4934
4939 493c 493f 4942 4943 4948 4949 1
494b 4950 4954 4958 495b 4960 4965 4968
496c 496d 4972 4973 4978 497a 497e 4981
4985 4989 498d 498f 4993 4997 499a 499e
49a0 49a4 49a8 49ac 49af 49b0 49b2 49b5
49b8 49b9 49be 49c2 49c6 49cb 49d0 49d4
49d8 49dc 49df 49e2 49e6 49ea 49ee 49f2
49f6 49fa 49fe 4a02 4a06 4a0a 4a0e 4a12
4a16 4a1a 4a1e 4a22 4a26 4a2a 4a2e 4a32
4a36 4a3a 4a3e 4a42 4a46 4a4a 4a4e 4a52
4a56 4a5a 4a5e 4a62 4a66 4a6a 4a6e 4a72
4a76 4a7a 4a7e 4a82 4a8e 4a92 4a97 4a9b
4a9e 4a9f 4aa4 4aa8 4aac 4aaf 4ab2 4ab6
4ab8 4abc 4ac0 4ac3 4ac6 4aca 4acc 4ad0
4ad4 4ad7 4ad9 4add 4ae1 4ae5 4ae8 4aec
4af0 4af2 4af3 4af8 1 4afc 4b00 4b04
4b07 4b0b 4b0f 4b13 4b17 4b1a 4b1e 4b22
4b25 4b28 4b2d 4b30 4b33 4b36 4b37 4b3c
4b3d 1 4b3f 4b44 4b48 4b4c 4b4f 4b54
4b59 4b5c 4b60 4b61 4b66 4b69 4b6e 4b6f
4b74 4b77 4b7c 4b7d 4b82 4b85 4b89 4b8a
4b8f 4b92 4b97 4b98 4b9d 4ba0 4ba4 4ba8
4bab 4bae 4baf 4bb1 4bb2 4bb7 4bb8 4bbd
4bbf 4bc3 4bc6 4bc8 4bcc 4bce 4bda 4bdc
4bde 4bdf 4be4 4be8 4bea 4bf6 4bf8 4bfc
4c00 4c03 4c07 4c08 4c0d 4c11 4c15 4c19
4c1d 4c21 4c25 4c29 4c2d 4c31 4c35 4c39
4c3d 4c41 4c45 4c49 4c4d 4c51 4c55 4c59
4c5d 4c61 4c65 4c69 4c6d 4c71 4c75 4c79
4c7d 4c81 4c85 4c89 4c8d 4c91 4c95 4c99
4c9d 4ca1 4ca5 4ca9 4cad 4cb1 4cb5 4cb9
4cbd 4cc1 4cc5 4cc9 4ccd 4cd1 4cd5 4cd9
4cdd 4ce1 4ce5 4cf1 4cf5 4cfa 4cfe 4d01
4d02 4d07 4d0b 4d0f 4d12 4d15 4d19 4d1b
4d1f 4d23 4d26 4d29 4d2d 4d2f 4d33 4d37
4d3a 4d3c 4d40 4d44 4d48 4d4b 4d4f 4d53
4d55 4d56 4d5b 1 4d5f 4d63 4d67 4d6a
4d6e 4d72 4d76 4d7a 4d7d 4d81 4d85 4d88
4d8b 4d90 4d93 4d96 4d99 4d9a 4d9f 4da0
1 4da2 4da7 4dab 4daf 4db2 4db7 4dbc
4dbf 4dc3 4dc4 4dc9 4dcc 4dd1 4dd2 4dd7
4dda 4ddf 4de0 4de5 4de8 4dec 4ded 4df2
4df5 4dfa 4dfb 4e00 4e03 4e07 4e0b 4e0e
4e11 4e12 4e14 4e15 4e1a 4e1b 4e20 4e22
4e26 4e29 4e2b 4e2f 4e31 4e3d 4e3f 4e41
4e42 4e47 4e4b 4e4d 4e59 4e5b 4e5f 4e63
4e67 4e6b 4e6f 4e73 4e77 4e7b 4e7f 4e83
4e87 4e8b 4e8f 4e93 4e97 4e9b 4e9f 4ea3
4ea7 4eab 4eaf 4eb3 4eb7 4ebb 4ebf 4ec3
4ec7 4ecb 4ecf 4ed3 4ed7 4edb 4edf 4ee3
4ee7 4eeb 4eef 4ef3 4ef7 4efb 4eff 4f03
4f07 4f0b 4f0f 4f13 4f17 4f1b 4f1f 4f23
4f27 4f2b 4f2f 4f33 4f37 4f3b 4f3f 4f43
4f47 4f4b 4f4f 4f53 4f57 4f5b 4f5f 4f63
4f67 4f6b 4f6f 4f73 4f77 4f7b 4f7f 4f83
4f87 4f8b 4f8f 4f93 4f97 4f9b 4f9f 4fa3
4fa7 4fab 4faf 4fb3 4fb7 4fbb 4fbf 4fcb
4fd0 4fd4 4fd8 4fdc 4fdf 4fe3 4fe7 4fea
4fed 4ff2 4ff5 4ff8 4ffb 4ffc 5001 5002
1 5004 5009 500d 5011 5014 5019 501e
5021 5025 5026 502b 502c 5031 5033 5037
503a 503e 5042 5046 504a 504c 5050 5054
5058 505b 505c 505e 5061 5064 5065 506a
506e 5072 5077 507c 5080 5084 5088 508b
508e 5092 5096 509a 509e 50a2 50a6 50aa
50ae 50b2 50b6 50ba 50be 50c2 50c6 50ca
50ce 50d2 50d6 50da 50de 50e2 50e6 50ea
50ee 50f2 50f6 50fa 50fe 5102 5106 510a
510e 5112 5116 511a 511e 5122 5126 512a
512e 513a 513e 5143 5147 514a 514b 5150
5154 5158 515b 515e 5162 5164 5168 516c
516f 5172 5176 5178 517c 5180 5183 5185
5189 518d 5191 5194 5198 519c 519e 519f
51a4 1 51a8 51ac 51b0 51b3 51b7 51bb
51bf 51c3 51c6 51ca 51ce 51d1 51d4 51d9
51dc 51df 51e2 51e3 51e8 51e9 1 51eb
51f0 51f4 51f8 51fb 5200 5205 5208 520c
520d 5212 5215 521a 521b 5220 5223 5228
5229 522e 5231 5235 5236 523b 523e 5243
5244 5249 524c 5250 5254 5257 525a 525b
525d 525e 5263 5264 5269 526b 526f 5272
5274 5278 527a 5286 5288 528a 528b 5290
5294 5296 52a2 52a4 52a8 52ac 52af 52b3
52b4 52b9 52bd 52c1 52c5 52c9 52cd 52d1
52d5 52d9 52dd 52e1 52e5 52e9 52ed 52f1
52f5 52f9 52fd 5301 5305 5309 530d 5311
5315 5319 531d 5321 5325 5329 532d 5331
5335 5339 533d 5341 5345 5349 534d 5351
5355 5359 535d 5361 5365 5369 536d 5371
5375 5379 537d 5381 5385 5389 538d 5391
5395 5399 539d 53a1 53a5 53a9 53ad 53b1
53b5 53b9 53bd 53c1 53c5 53c9 53cd 53d1
53d5 53d9 53dd 53e1 53e5 53e9 53ed 53f1
53f5 53f9 53fd 5401 5405 5409 540d 5411
5415 5419 541d 5421 5425 5429 542d 5431
5435 5439 543d 5441 5445 5451 5455 545a
545e 5461 5462 5467 546b 546f 5472 5475
5479 547b 547f 5483 5486 5489 548d 548f
5493 5497 549a 549c 54a0 54a4 54a8 54ab
54af 54b3 54b5 54b6 54bb 1 54bf 54c3
54c7 54ca 54ce 54d2 54d6 54da 54dd 54e1
54e5 54e8 54eb 54f0 54f3 54f6 54f9 54fa
54ff 5500 1 5502 5507 550b 550f 5512
5517 551c 551f 5523 5524 5529 552c 5531
5532 5537 553a 553f 5540 5545 5548 554c
554d 5552 5555 555a 555b 5560 5563 5567
556b 556e 5571 5572 5574 5575 557a 557b
5580 5582 5586 5589 558b 558f 5591 559d
559f 55a1 55a2 55a7 55ab 55ad 55b9 55bb
55bf 55c3 55c7 55cb 55cf 55d3 55d7 55db
55df 55e3 55e7 55eb 55ef 55f3 55f7 55fb
55ff 5603 5607 560b 560f 5613 5617 561b
561f 5623 5627 562b 562f 5633 5637 563b
563f 5643 5647 564b 564f 5653 5657 565b
565f 5663 5667 566b 566f 5673 5677 567b
567f 5683 5687 568b 568f 5693 5697 569b
569f 56a3 56a7 56ab 56af 56b3 56b7 56bb
56bf 56c3 56c7 56cb 56cf 56d3 56d7 56db
56df 56e3 56e7 56eb 56ef 56f3 56f7 56fb
56ff 5703 5707 570b 570f 5713 5717 571b
571f 5723 5727 572b 572f 5733 5737 573b
573f 5743 5747 574b 574f 5753 5757 575b
575f 5763 5767 576b 576f 5773 5777 577b
577f 5783 5787 578b 578f 5793 5797 579b
579f 57a3 57a7 57ab 57af 57b3 57b7 57bb
57bf 57c3 57c7 57cb 57cf 57d3 57d7 57db
57df 57e3 57e7 57eb 57ef 57f3 57f7 57fb
57ff 5803 5807 580b 580f 581b 5820 5824
5828 582c 582f 5833 5837 583a 583d 5842
5845 5848 584b 584c 5851 5852 1 5854
5859 585d 5861 5864 5869 586e 5871 5875
5876 587b 587c 5881 5883 5887 588a 588e
5892 5896 589a 589c 58a0 58a4 58a8 58ab
58ac 58ae 58b1 58b4 58b5 58ba 58be 58c2
58c6 58ca 58ce 58d2 58d6 58da 58de 58e2
58e6 58ea 58ee 58f2 58f6 58fa 58fe 5902
5906 590a 590e 5912 5916 591a 591e 5922
5926 592a 592e 5932 5936 593a 593e 5942
5946 594a 594e 5952 5956 595a 595e 5962
5966 596a 596e 5972 5976 597a 597e 5982
5986 598a 598e 5992 5996 599a 599e 59a2
59a6 59aa 59ae 59b2 59b6 59ba 59be 59c2
59c6 59ca 59ce 59d2 59d6 59da 59de 59e2
59e6 59ea 59ee 59f2 59f6 59fa 59fe 5a02
5a06 5a0a 5a0e 5a12 5a16 5a1a 5a1e 5a22
5a26 5a2a 5a2e 5a32 5a36 5a3a 5a3e 5a42
5a46 5a4a 5a4e 5a52 5a56 5a5a 5a5e 5a62
5a66 5a6a 5a6e 5a72 5a76 5a7a 5a7e 5a82
5a86 5a8a 5a8e 5a92 5a96 5a9a 5a9e 5aa2
5aa6 5aaa 5aae 5ab2 5ab6 5aba 5abe 5ac2
5ac6 5aca 5ace 5ad2 5ad6 5ada 5ade 5ae2
5ae6 5aea 5aee 5af2 5af6 5afa 5afe 5b02
5b06 5b0a 5b0e 5b12 5b16 5b1a 5b1e 5b22
5b26 5b2a 5b2e 5b32 5b36 5b3a 5b3e 5b42
5b46 5b4a 5b4e 5b52 5b56 5b5a 5b5e 5b62
5b66 5b6a 5b6e 5b72 5b76 5b7a 5b7e 5b82
5b86 5b8a 5b8e 5b92 5b96 5b9a 5b9e 5ba2
5ba6 5baa 5bae 5bb2 5bb6 5bba 5bbe 5bc2
5bc6 5bca 5bce 5bd2 5bd6 5bda 5bde 5be2
5be6 5bea 5bee 5bf2 5bf6 5bfa 5bfe 5c02
5c06 5c0a 5c0e 5c12 5c16 5c1a 5c1e 5c22
5c26 5c2a 5c2e 5c32 5c36 5c3a 5c3e 5c42
5c46 5c4a 5c4e 5c52 5c56 5c5a 5c5e 5c62
5c66 5c6a 5c6e 5c72 5c76 5c7a 5c7e 5c82
5c86 5c8a 5c96 5c9b 5c9f 5ca3 5ca7 5caa
5cae 5cb2 5cb5 5cb8 5cbd 5cc0 5cc3 5cc6
5cc7 5ccc 5ccd 1 5ccf 5cd4 5cd8 5cdc
5cdf 5ce4 5ce9 5cec 5cf0 5cf1 5cf6 5cf7
5cfc 5cfe 5d02 5d05 5d09 5d0d 5d11 5d15
5d17 5d1b 5d1f 5d23 5d26 5d27 5d29 5d2c
5d2f 5d30 5d35 5d39 5d3d 5d42 5d47 5d4b
5d4f 5d53 5d56 5d59 5d5d 5d61 5d65 5d69
5d6d 5d71 5d75 5d79 5d7d 5d81 5d85 5d89
5d8d 5d91 5d95 5d99 5d9d 5da1 5da5 5da9
5dad 5db1 5db5 5db9 5dbd 5dc1 5dc5 5dc9
5dcd 5dd1 5dd5 5dd9 5ddd 5de1 5de5 5de9
5ded 5df1 5df5 5df9 5dfd 5e01 5e05 5e09
5e0d 5e11 5e15 5e19 5e25 5e29 5e2e 5e32
5e35 5e36 5e3b 5e3f 5e43 5e46 5e49 5e4d
5e4f 5e53 5e57 5e5a 5e5d 5e61 5e63 5e67
5e6b 5e6e 5e70 5e74 5e78 5e7c 5e7f 5e83
5e87 5e89 5e8a 5e8f 1 5e93 5e97 5e9b
5e9e 5ea2 5ea6 5eaa 5eae 5eb1 5eb5 5eb9
5ebc 5ebf 5ec4 5ec7 5eca 5ecd 5ece 5ed3
5ed4 1 5ed6 5edb 5edf 5ee3 5ee6 5eeb
5ef0 5ef3 5ef7 5ef8 5efd 5f00 5f05 5f06
5f0b 5f0e 5f13 5f14 5f19 5f1c 5f20 5f21
5f26 5f29 5f2e 5f2f 5f34 5f37 5f3b 5f3f
5f42 5f45 5f46 5f48 5f49 5f4e 5f4f 5f54
5f56 5f5a 5f5d 5f5f 5f63 5f65 5f71 5f73
5f75 5f76 5f7b 5f7f 5f81 5f8d 5f8f 5f93
5f97 5f9c 5fa1 5fa5 5fa9 5fad 5fb0 5fb3
5fb7 5fbb 5fbf 5fc3 5fc7 5fcb 5fcf 5fd3
5fd7 5fdb 5fdf 5fe3 5fe7 5feb 5fef 5ff3
5ff7 5ffb 5fff 6003 6007 600b 600f 6013
6017 601b 601f 6023 6027 602b 602f 6033
6037 603b 603f 6043 6047 604b 604f 6053
6057 605b 605f 6063 6067 606b 606f 6073
6077 607b 607f 6083 6087 608b 608f 6093
6097 609b 609f 60a3 60a7 60ab 60af 60b3
60b7 60bb 60bf 60c3 60c7 60cb 60cf 60d3
60d7 60db 60df 60e3 60e7 60eb 60ef 60f3
60f7 60fb 60ff 6103 6107 610b 610f 6113
6117 611b 611f 6123 6127 612b 612f 6133
6137 613b 613f 6143 6147 614b 614f 6153
6157 615b 615f 6163 6167 616b 616f 6173
6177 617b 6187 618b 6190 6194 6197 6198
619d 61a1 61a5 61a8 61ab 61af 61b1 61b5
61b9 61bc 61bf 61c3 61c5 61c9 61cd 61d0
61d2 61d6 61da 61de 61e1 61e5 61e9 61eb
61ec 61f1 1 61f5 61f9 61fd 6200 6204
6208 620c 6210 6213 6217 621b 621e 6221
6226 6229 622c 622f 6230 6235 6236 1
6238 623d 6241 6245 6248 624d 6252 6255
6259 625a 625f 6262 6267 6268 626d 6270
6275 6276 627b 627e 6282 6283 6288 628b
6290 6291 6296 6299 629d 62a1 62a4 62a7
62a8 62aa 62ab 62b0 62b1 62b6 62b8 62bc
62bf 62c1 62c5 62c7 62d3 62d5 62d7 62d8
62dd 62e1 62e3 62ef 62f1 62f5 62f9 62fd
6301 6305 6309 630d 6311 6315 6319 631d
6321 6325 6329 632d 6331 633d 6341 6346
634a 634d 634e 6353 6357 635b 635e 6361
6365 6367 636b 636f 6372 6375 6379 637b
637f 6383 6386 6388 638c 6390 6394 6397
639b 639f 63a1 63a2 63a7 1 63ab 63af
63b3 63b6 63ba 63be 63c2 63c6 63c9 63cd
63d1 63d4 63d7 63dc 63df 63e2 63e5 63e6
63eb 63ec 1 63ee 63f3 63f7 63fb 63fe
6403 6408 640b 640f 6410 6415 6418 641d
641e 6423 6426 642b 642c 6431 6434 6438
6439 643e 6441 6446 6447 644c 644f 6453
6457 645a 645d 645e 6460 6461 6466 6467
646c 646e 6472 6475 6477 647b 647d 6489
648b 648d 648e 6493 6497 6499 64a5 64a7
64ab 64af 64b3 64b7 64bb 64bf 64c3 64c7
64cb 64cf 64d3 64d7 64db 64df 64e3 64e7
64eb 64ef 64f3 64f7 64fb 64ff 6503 6507
650b 650f 6513 6517 651b 651f 6523 6527
652b 652f 6533 6537 653b 653f 6543 6547
654b 654f 6553 6557 655b 655f 6563 6567
656b 656f 6573 6577 657b 657f 6583 6587
658b 658f 6593 6597 659b 659f 65a3 65a7
65ab 65af 65b3 65b7 65bb 65bf 65c3 65c7
65cb 65cf 65d3 65d7 65db 65df 65e3 65e7
65eb 65ef 65f3 65f7 65fb 65ff 6603 6607
660b 660f 6613 6617 661b 661f 6623 6627
662b 662f 6633 6637 663b 663f 6643 6647
664b 664f 6653 6657 665b 665f 6663 6667
666b 666f 6673 6677 667b 667f 6683 6687
668b 668f 6693 6697 669b 669f 66a3 66a7
66ab 66af 66b3 66b7 66bb 66bf 66c3 66c7
66cb 66cf 66d3 66d7 66db 66df 66e3 66e7
66eb 66ef 66f3 66f7 66fb 66ff 6703 6707
670b 670f 6713 6717 671b 671f 6723 6727
672b 672f 6733 6737 673b 673f 6743 6747
674b 674f 6753 6757 675b 675f 6763 6767
676b 676f 6773 6777 677b 677f 6783 6787
678b 678f 6793 6797 679b 679f 67a3 67a7
67ab 67af 67b3 67b7 67bb 67bf 67c3 67c7
67cb 67cf 67d3 67d7 67db 67df 67e3 67e7
67eb 67ef 67f3 67f7 67fb 67ff 6803 6807
680b 680f 6813 6817 681b 681f 6823 6827
682b 682f 6833 6837 683b 6847 684c 6850
6854 6858 685b 685f 6863 6866 6869 686e
6871 6874 6877 6878 687d 687e 1 6880
6885 6889 688d 6890 6895 689a 689d 68a1
68a2 68a7 68a8 68ad 68af 68b3 68b6 68ba
68be 68c2 68c6 68c8 68cc 68d0 68d4 68d7
68d8 68da 68de 68e1 68e5 68e8 68e9 68ee
68f2 68f6 68fa 68fe 6902 690e 6912 6916
6919 691d 6921 6923 6927 692b 692f 6932
6936 693a 693c 693d 6942 1 6946 694a
694e 6951 6955 6959 695d 6961 6964 6968
696c 696f 6972 6977 697a 697d 6980 6981
6986 6987 1 6989 698e 6992 6996 6999
699e 69a3 69a6 69aa 69ab 69b0 69b3 69b8
69b9 69be 69c1 69c6 69c7 69cc 69cf 69d3
69d4 69d9 69dc 69e1 69e2 69e7 69ea 69ee
69f2 69f5 69f8 69f9 69fb 69fc 6a01 6a02
6a07 6a09 6a0d 6a10 6a12 6a16 6a18 6a24
6a26 6a28 6a29 6a2e 6a32 6a34 6a40 6a42
6a46 6a4a 6a4d 6a51 6a54 6a58 6a5b 6a5c
6a61 6a64 6a68 6a6c 6a70 6a74 6a78 6a7c
6a80 6a84 6a88 6a8c 6a90 6a94 6a98 6a9c
6aa0 6aa4 6aa8 6aac 6ab0 6ab4 6ab8 6abc
6ac0 6ac4 6ac8 6acc 6ad0 6ad4 6ad8 6adc
6ae0 6ae4 6ae8 6aec 6af0 6af4 6af8 6afc
6b00 6b04 6b08 6b0c 6b10 6b14 6b18 6b1c
6b20 6b24 6b28 6b2c 6b30 6b34 6b38 6b3c
6b40 6b44 6b48 6b4c 6b50 6b54 6b58 6b5c
6b60 6b64 6b68 6b6c 6b70 6b74 6b78 6b7c
6b80 6b84 6b88 6b8c 6b90 6b94 6b98 6b9c
6ba0 6ba4 6ba8 6bac 6bb0 6bb4 6bb8 6bbc
6bc0 6bc4 6bc8 6bcc 6bd0 6bd4 6bd8 6bdc
6be0 6be4 6be8 6bec 6bf0 6bf4 6bf8 6bfc
6c00 6c04 6c08 6c0c 6c10 6c14 6c18 6c1c
6c20 6c24 6c28 6c2c 6c30 6c34 6c38 6c3c
6c40 6c44 6c48 6c4c 6c50 6c54 6c58 6c5c
6c60 6c64 6c68 6c6c 6c70 6c74 6c78 6c7c
6c80 6c84 6c88 6c8c 6c90 6c94 6c98 6c9c
6ca0 6ca4 6ca8 6cac 6cb0 6cb4 6cb8 6cbc
6cc0 6cc4 6cc8 6ccc 6cd8 6cdd 6ce1 6ce5
6ce9 6cec 6cf0 6cf4 6cf7 6cfa 6cff 6d02
6d05 6d08 6d09 6d0e 6d0f 1 6d11 6d16
6d1a 6d1e 6d21 6d26 6d2b 6d2e 6d32 6d33
6d38 6d39 6d3e 6d40 6d44 6d47 6d4b 6d4f
6d53 6d55 6d59 6d5c 6d60 6d62 6d66 6d6a
6d6e 6d71 6d72 6d74 6d77 6d7a 6d7b 6d80
6d84 6d88 6d8c 6d90 6d94 6d98 6d9c 6da0
6da4 6da8 6dac 6db0 6db4 6db8 6dbc 6dc0
6dc4 6dc8 6dcc 6dd0 6dd4 6dd8 6ddc 6de0
6de4 6de8 6dec 6df0 6df4 6df8 6dfc 6e00
6e04 6e08 6e0c 6e10 6e14 6e18 6e1c 6e20
6e24 6e28 6e2c 6e30 6e34 6e38 6e3c 6e40
6e44 6e48 6e4c 6e50 6e54 6e58 6e5c 6e60
6e64 6e68 6e6c 6e70 6e74 6e78 6e7c 6e80
6e84 6e88 6e8c 6e90 6e94 6e98 6e9c 6ea0
6ea4 6ea8 6eac 6eb0 6eb4 6eb8 6ebc 6ec0
6ec4 6ec8 6ecc 6ed0 6ed4 6ed8 6edc 6ee0
6ee4 6ee8 6eec 6ef0 6ef4 6ef8 6efc 6f00
6f04 6f08 6f0c 6f10 6f14 6f18 6f1c 6f20
6f24 6f28 6f2c 6f30 6f34 6f38 6f3c 6f40
6f44 6f48 6f4c 6f50 6f54 6f58 6f5c 6f60
6f64 6f68 6f6c 6f70 6f74 6f78 6f7c 6f80
6f84 6f88 6f8c 6f90 6f94 6f98 6f9c 6fa0
6fa4 6fa8 6fac 6fb0 6fb4 6fb8 6fbc 6fc0
6fc4 6fc8 6fcc 6fd0 6fd4 6fd8 6fdc 6fe0
6fe4 6fe8 6fec 6ff0 6ff4 6ff8 6ffc 7000
7004 7008 700c 7010 7014 7018 701c 7020
7024 7028 702c 7030 7034 7038 703c 7040
7044 7048 704c 7050 7054 7058 705c 7060
7064 7068 706c 7070 7074 7078 707c 7080
7084 7088 708c 7090 7094 7098 709c 70a0
70a4 70a8 70ac 70b0 70b4 70b8 70bc 70c0
70c4 70c8 70cc 70d0 70d4 70d8 70dc 70e0
70e4 70e8 70ec 70f0 70f4 70f8 70fc 7100
7104 7108 710c 7110 7114 7118 711c 7120
7124 7128 712c 7130 7134 7138 713c 7140
7144 7148 714c 7150 7154 7158 715c 7160
7164 7168 716c 7170 7174 7178 717c 7180
7184 7188 718c 7190 7194 7198 719c 71a0
71a4 71a8 71ac 71b0 71b4 71b8 71bc 71c0
71c4 71c8 71cc 71d0 71d4 71d8 71dc 71e0
71e4 71e8 71ec 71f0 71f4 71f8 71fc 7200
7204 7208 720c 7210 7214 7218 721c 7220
7224 7228 722c 7230 7234 7238 723c 7240
7244 7248 724c 7250 7254 7258 725c 7260
7264 7268 726c 7270 7274 7278 727c 7280
7284 7288 728c 7290 7294 7298 729c 72a0
72a4 72a8 72ac 72b0 72b4 72b8 72bc 72c0
72c4 72c8 72cc 72d0 72d4 72d8 72dc 72e0
72e4 72e8 72ec 72f0 72f4 72f8 72fc 7300
7304 7308 730c 7310 7314 7318 731c 7320
7324 7328 732c 7330 7334 7338 733c 7340
7344 7348 734c 7350 7354 7358 735c 7360
7364 7368 736c 7370 7374 7378 737c 7380
7384 7388 738c 7390 7394 7398 739c 73a0
73a4 73a8 73ac 73b0 73b4 73b8 73bc 73c0
73c4 73c8 73cc 73d0 73d4 73d8 73dc 73e0
73e4 73e8 73ec 73f0 73f4 73f8 7404 7409
740d 7411 7415 7418 741c 7420 7423 7426
742b 742e 7431 7434 7435 743a 743b 1
743d 7442 7446 744a 744d 7452 7457 745a
745e 745f 7464 7465 746a 746c 7470 7473
7477 747b 747f 7483 7485 7489 748d 7491
7494 7495 7497 749a 749d 749e 74a3 74a7
74ab 74af 74b3 74b7 74bb 74bf 74c3 74c7
74cb 74cf 74d3 74d7 74db 74df 74e3 74e7
74eb 74ef 74f3 74f7 74fb 74ff 7503 7507
750b 750f 7513 7517 751b 751f 7523 7527
752b 752f 7533 7537 753b 753f 7543 7547
754b 754f 7553 7557 755b 755f 7563 7567
756b 756f 7573 7577 757b 757f 7583 7587
758b 758f 7593 7597 759b 759f 75a3 75a7
75ab 75af 75b3 75b7 75bb 75bf 75c3 75c7
75cb 75cf 75d3 75d7 75db 75df 75e3 75e7
75eb 75ef 75f3 75f7 75fb 75ff 7603 7607
760b 760f 7613 7617 761b 761f 7623 7627
762b 762f 7633 7637 763b 763f 7643 7647
764b 764f 7653 7657 765b 765f 7663 7667
766b 766f 7673 7677 767b 767f 7683 7687
768b 768f 7693 7697 769b 769f 76a3 76a7
76ab 76af 76b3 76b7 76bb 76bf 76c3 76c7
76cb 76cf 76d3 76d7 76db 76df 76e3 76e7
76eb 76ef 76f3 76f7 76fb 76ff 7703 7707
770b 770f 7713 7717 771b 771f 7723 7727
772b 772f 7733 7737 773b 773f 7743 7747
774b 774f 7753 7757 775b 775f 7763 7767
776b 776f 7773 7777 777b 777f 7783 7787
778b 778f 7793 7797 779b 779f 77a3 77a7
77ab 77af 77b3 77b7 77bb 77bf 77c3 77c7
77cb 77cf 77d3 77d7 77db 77df 77e3 77e7
77eb 77ef 77f3 77f7 77fb 77ff 7803 7807
7813 7818 781c 7820 7824 7827 782b 782f
7832 7835 783a 783d 7840 7843 7844 7849
784a 1 784c 7851 7855 7859 785c 7861
7866 7869 786d 786e 7873 7874 7879 787b
787f 7882 7886 788a 788e 7892 7894 7898
789c 78a0 78a3 78a4 78a6 78a9 78ac 78ad
78b2 78b6 78ba 78bf 78c4 78c8 78cc 78d0
78d3 78d6 78da 78de 78e2 78e6 78ea 78ee
78f2 78f6 78fa 78fe 7902 7906 790a 790e
7912 7916 791a 7926 792a 792f 7933 7936
7937 793c 7940 7944 7947 794a 794e 7950
7954 7958 795b 795e 7962 7964 7968 796c
796f 7971 7975 7979 797d 7980 7984 7988
798a 798b 7990 1 7994 7998 799c 799f
79a3 79a7 79ab 79af 79b2 79b6 79ba 79bd
79c0 79c5 79c8 79cb 79ce 79cf 79d4 79d5
1 79d7 79dc 79e0 79e4 79e7 79ec 79f1
79f4 79f8 79f9 79fe 7a01 7a06 7a07 7a0c
7a0f 7a14 7a15 7a1a 7a1d 7a21 7a22 7a27
7a2a 7a2f 7a30 7a35 7a38 7a3c 7a40 7a43
7a46 7a47 7a49 7a4a 7a4f 7a50 7a55 7a57
7a5b 7a5e 7a60 7a64 7a66 7a72 7a74 7a76
7a77 7a7c 7a80 7a82 7a8e 7a90 7a94 7a98
7a9d 7aa2 7aa6 7aaa 7aae 7ab1 7ab4 7ab8
7abc 7ac0 7ac4 7ac8 7acc 7ad0 7ad4 7ad8
7adc 7ae0 7ae4 7ae8 7aec 7af0 7afc 7b00
7b05 7b09 7b0c 7b0d 7b12 7b16 7b1a 7b1d
7b20 7b24 7b26 7b2a 7b2e 7b31 7b34 7b38
7b3a 7b3e 7b42 7b45 7b47 7b4b 7b4f 7b53
7b56 7b5a 7b5e 7b60 7b61 7b66 1 7b6a
7b6e 7b72 7b75 7b79 7b7d 7b81 7b85 7b88
7b8c 7b90 7b93 7b96 7b9b 7b9e 7ba1 7ba4
7ba5 7baa 7bab 1 7bad 7bb2 7bb6 7bba
7bbd 7bc2 7bc7 7bca 7bce 7bcf 7bd4 7bd7
7bdc 7bdd 7be2 7be5 7bea 7beb 7bf0 7bf3
7bf7 7bf8 7bfd 7c00 7c05 7c06 7c0b 7c0e
7c12 7c16 7c19 7c1c 7c1d 7c1f 7c20 7c25
7c26 7c2b 7c2d 7c31 7c34 7c36 7c3a 7c3c
7c48 7c4a 7c4c 7c4d 7c52 7c56 7c58 7c64
7c66 7c6a 7c6e 7c73 7c78 7c7c 7c80 7c84
7c87 7c8a 7c8e 7c92 7c96 7c9a 7c9e 7ca2
7ca6 7caa 7cae 7cb2 7cb6 7cba 7cbe 7cc2
7cc6 7cca 7cce 7cd2 7cd6 7cda 7cde 7ce2
7ce6 7cea 7cee 7cf2 7cf6 7cfa 7cfe 7d02
7d06 7d0a 7d0e 7d12 7d16 7d1a 7d1e 7d22
7d26 7d32 7d36 7d3b 7d3f 7d42 7d43 7d48
7d4c 7d50 7d53 7d56 7d5a 7d5c 7d60 7d64
7d67 7d6a 7d6e 7d70 7d74 7d78 7d7b 7d7d
7d81 7d85 7d89 7d8c 7d90 7d94 7d96 7d97
7d9c 1 7da0 7da4 7da8 7dab 7daf 7db3
7db7 7dbb 7dbe 7dc2 7dc6 7dc9 7dcc 7dd1
7dd4 7dd7 7dda 7ddb 7de0 7de1 1 7de3
7de8 7dec 7df0 7df3 7df8 7dfd 7e00 7e04
7e05 7e0a 7e0d 7e12 7e13 7e18 7e1b 7e20
7e21 7e26 7e29 7e2d 7e2e 7e33 7e36 7e3b
7e3c 7e41 7e44 7e48 7e4c 7e4f 7e52 7e53
7e55 7e56 7e5b 7e5c 7e61 7e63 7e67 7e6a
7e6c 7e70 7e72 7e7e 7e80 7e82 7e83 7e88
7e8c 7e8e 7e9a 7e9c 7ea0 7ea4 7ea8 7eac
7eb0 7eb4 7eb8 7ebc 7ec0 7ec4 7ec8 7ecc
7ed0 7ed4 7ed8 7edc 7ee0 7ee4 7ee8 7eec
7ef0 7ef4 7ef8 7efc 7f00 7f04 7f08 7f0c
7f10 7f14 7f18 7f1c 7f20 7f24 7f28 7f2c
7f30 7f34 7f38 7f3c 7f40 7f44 7f48 7f4c
7f50 7f54 7f58 7f5c 7f60 7f64 7f68 7f6c
7f70 7f74 7f78 7f7c 7f80 7f84 7f88 7f8c
7f90 7f94 7f98 7f9c 7fa0 7fa4 7fa8 7fac
7fb0 7fb4 7fb8 7fbc 7fc0 7fc4 7fc8 7fcc
7fd0 7fd4 7fd8 7fdc 7fe0 7fe4 7fe8 7fec
7ff0 7ff4 7ff8 7ffc 8000 8004 8008 800c
8010 8014 8018 801c 8020 8024 8028 802c
8030 8034 8038 803c 8040 8044 8048 804c
8050 8054 8058 805c 8060 8064 8068 806c
8070 8074 8078 807c 8080 8084 8088 808c
8090 8094 8098 809c 80a0 80a4 80b0 80b5
80b9 80bd 80c1 80c4 80c8 80cc 80cf 80d2
80d7 80da 80dd 80e0 80e1 80e6 80e7 1
80e9 80ee 80f2 80f6 80f9 80fe 8103 8106
810a 810b 8110 8111 8116 8118 811c 811f
8123 8127 812b 812f 8131 8135 8139 813d
8140 8141 8143 8146 8149 814a 814f 8153
8157 815b 815e 8163 8164 8169 816c 816f
8170 8172 8176 817a 817e 8182 8186 818a
818e 8192 8196 819a 819e 81a2 81a6 81aa
81ae 81b2 81b6 81ba 81be 81c2 81c6 81ca
81ce 81d2 81d6 81da 81de 81e2 81e6 81ea
81ee 81f2 81f6 81fa 81fe 8202 820e 8213
8217 821b 821f 8222 8226 822a 822d 8230
8235 8238 823b 823e 823f 8244 8245 1
8247 824c 8250 8254 8257 825c 8261 8264
8268 8269 826e 826f 8274 8276 827a 827d
8281 8285 8289 828d 828f 8293 8297 829b
829e 829f 82a1 82a5 82a8 82ac 82af 82b0
82b5 82b8 82bc 82c0 82c3 82c4 82c6 82ca
82cd 82d1 82d4 82d5 82da 1 82dd 82e2
82e6 82ea 82ee 82f2 82f6 82fa 82fe 8302
8306 830a 830e 8312 8316 831a 831e 8322
8326 832a 832e 8332 8336 833a 833e 8342
8346 834a 834e 8352 8356 835a 835e 8362
8366 836a 836e 837a 837f 8383 8387 838b
838e 8392 8396 8399 839c 83a1 83a4 83a7
83aa 83ab 83b0 83b1 1 83b3 83b8 83bc
83c0 83c3 83c8 83cd 83d0 83d4 83d5 83da
83db 83e0 83e2 83e6 83e9 83ed 83f1 83f5
83f7 83fb 83ff 8403 8406 840a 840e 8411
8414 8419 841c 841f 8422 8423 8428 8429
1 842b 8430 8434 8438 843b 8440 8445
8448 844c 844d 8452 8455 845a 845b 8460
8463 8468 8469 846e 8471 8475 8479 847d
8481 8484 8485 8487 848c 848d 848f 8490
8495 8498 849d 849e 84a3 84a6 84ab 84ac
84b1 84b4 84b8 84b9 84be 84c1 84c6 84c7
84cc 84cd 84d2 84d4 84d8 84db 84df 84e3
84e6 84ea 84ee 84f1 84f5 84f9 84fa 84ff
8501 8505 8509 850c 850e 8512 8516 8519
851d 8521 8524 8528 852c 852f 8532 8537
853a 853d 8540 8541 8546 8547 1 8549
854e 8552 8556 8559 855e 8563 8566 856a
856b 8570 8571 8576 857a 857e 8581 8586
858b 858e 8592 8596 8599 859a 859f 85a2
85a7 85a8 85ad 85b0 85b4 85b8 85bb 85bc
85c1 85c2 85c7 85c9 85cd 85d0 85d4 85d8
85dc 85e0 85e4 85e8 85ec 85f0 85f4 8600
8605 8609 860d 8611 8615 8617 8618 861d
1 8621 8625 8629 862c 8630 8634 8638
863c 863f 8643 8647 864a 864d 8652 8655
8658 865b 865c 8661 8662 1 8664 8669
866d 8671 8674 8679 867e 8681 8685 8686
868b 868c 8691 8695 8699 869c 86a1 86a6
86a9 86ad 86ae 86b3 86b6 86bb 86bc 86c1
86c4 86c8 86cc 86cf 86d2 86d3 86d5 86d6
86db 86dc 86e1 86e3 86e7 86ea 86ee 86f2
86f6 86fa 86fe 8702 8706 8712 8717 871b
871f 8723 8727 8729 872d 872f 873b 873d
873f 8740 8745 8749 874b 8757 875b 875d
875e 8767 
245a
2
0 1 a 6 c :3 6 11 :3 6
10 :2 6 1 3 a 13 a :2 1
4 b 14 13 :2 b :2 4 9 12
11 :2 9 :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 9 12 11
:2 9 :2 4 f 18 17 :2 f :2 4 :2 e
1d e :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 14
23 14 :2 4 :2 12 21 12 :2 4 f
18 17 :2 f :2 4 f 18 17 :2 f
4 7 e 17 :3 e :2 7 e 17
:3 e :2 7 e 17 :3 e :2 7 e 17
:3 e :2 7 e 17 :3 e :2 7 e 17
:3 e :2 7 e 17 :3 e :2 7 e 17
:3 e :2 7 e 17 :3 e :2 7 e 17
:3 e :2 7 e 17 :3 e :2 7 e 17
:3 e :2 7 e 17 :3 e :2 7 f 18
:3 f :2 7 13 1c :3 13 7 4 e
17 :3 e 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
54 5a 5d :2 54 6b 81 8 :2 6b
d 10 :2 6b 16 19 :2 6b b e
:2 6b 13 16 1f 27 :2 1f 34 :2 16
:2 6b b e :2 6b 13 16 :2 6b 1b
1e :2 6b 28 2b :2 6b 30 33 :2 6b
:2 7 4a :2 4 7 :2 11 23 :2 2d 39
3c 4c 4e 4f :2 4c :2 23 :3 7 :2 d
12 1e 5d 60 :2 1e :2 7 52 :2 4
:4 8 7 a :2 14 26 :2 30 3c 40
50 52 53 :2 50 :2 26 :3 a :2 10 15
21 60 63 :2 21 70 73 :2 21 77
7a :2 21 84 87 90 98 :2 a1 :2 90
b2 :2 87 :2 21 ba bd :2 21 c5 c8
:2 21 cd d0 :2 21 d6 d9 :2 21 :2 a
56 :2 7 a :2 14 26 :2 30 3c 3f
4f 51 52 :2 4f :2 26 :3 a :2 10 15
21 60 63 :2 21 :2 a 55 :3 7 :2 12
26 :2 2f 3f 46 :2 7 17 :3 4 c
:2 4 11 :2 4 12 4 8 11 1c
:2 8 1f 21 :2 1f 7 28 31 3c
:2 28 3f 41 :2 3f 27 :2 7 11 13
1f 21 2a 33 35 4b 4d f
1d 28 33 f 17 1a 22 2a
2c 39 42 44 51 53 :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 77 7a :2 27 7e 81 :2 27 8d
90 :2 27 98 9b :2 27 a7 aa b1
ba bd :2 aa :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 44 b :2 14 1f 1d
:2 28 :2 1d a 14 16 22 24 2d
36 38 12 20 2b 12 1a 1d
25 2d 2f 3c 45 47 54 56
:2 d :2 16 22 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 59
5c 5d :2 59 :2 2f :3 13 :2 19 1e 2a
6a 6d :2 2a 7a 7d :2 2a 81 84
:2 2a 90 93 :2 2a 9b 9e :2 2a aa
ad b4 bd c0 :2 ad :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 38 e :2 17
22 20 :2 2b :2 20 d 20 2f 3f
4c :2 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5c 5f 60 :2 5c :2 32 :3 16 :2 1c 21
2d 6d 70 :2 2d 7d 80 :2 2d 84
87 :2 2d 93 96 :2 2d 9e a1 :2 2d
ad b0 b7 c0 c3 :2 b0 :2 2d :2 16
63 :2 13 :2 10 :4 1c :2 10 d :3 3b 11
:2 1a 25 23 :2 2e :2 23 10 13 :2 1d
2f :2 39 45 49 59 5c 5d :2 59
:2 2f :3 13 :2 19 1e 2a 6a 6d :2 2a
7a 7d :2 2a 81 84 :2 2a 8e 91
9a a2 :2 ab :2 9a bc :2 91 :2 2a c4
c7 :2 2a cf d2 :2 2a d7 da :2 2a
df e2 :2 2a :2 13 60 :2 10 13 :2 1d
2f :2 39 45 48 58 5b 5c :2 58
:2 2f :3 13 :2 19 1e 2a 6a 6d :2 2a
:2 13 5f :3 10 :2 1b 2f :2 38 48 4e
:2 10 3e :2 d 3b :2 a 38 :2 7 4
44 a 13 1e :2 a 21 23 :2 21
11 21 f 26 3a :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 67 6a :2 27
77 7a :2 27 7e 81 :2 27 8d 90
:2 27 98 9b :2 27 a7 aa b1 ba
bd :2 aa :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 26 b :2 14 1f 1d :2 28
:2 1d a d :2 17 29 :2 33 3f 43
53 56 57 :2 53 :2 29 :3 d :2 13 18
24 64 67 :2 24 74 77 :2 24 7b
7e :2 24 88 8b 94 9c :2 a5 :2 94
b6 :2 8b :2 24 be c1 :2 24 c9 cc
:2 24 d1 d4 :2 24 da dd :2 24 :2 d
5a :2 a d :2 17 29 :2 33 3f 42
52 55 56 :2 52 :2 29 :3 d :2 13 18
24 64 67 :2 24 :2 d 59 :3 a :2 15
29 :2 32 42 49 :2 a 38 :2 7 11
1a 30 41 4c f 1d 2a :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 26 4 26 44
a 13 1e :2 a 21 23 :2 21 11
1b 27 37 44 :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 67 6a :2 27 77
7a :2 27 7e 81 :2 27 8d 90 :2 27
98 9b :2 27 a7 aa b1 ba bd
:2 aa :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 26 b :2 14 1f 1d :2 28 :2 1d
a d :2 17 29 :2 33 3f 43 53
56 57 :2 53 :2 29 :3 d :2 13 18 24
64 67 :2 24 74 77 :2 24 7b 7e
:2 24 88 8b 94 9c :2 a5 :2 94 b6
:2 8b :2 24 be c1 :2 24 c9 cc :2 24
d1 d4 :2 24 da dd :2 24 :2 d 5a
:2 a d :2 17 29 :2 33 3f 42 52
55 56 :2 52 :2 29 :3 d :2 13 18 24
64 67 :2 24 :2 d 59 :3 a :2 15 29
:2 32 42 49 :2 a 38 :3 7 14 7
4 26 44 b 14 1f :2 b 25
22 :2 2e :2 22 a 48 51 5c :2 48
5f 62 :2 5f 47 :2 a 16 1f 2a
:2 16 30 2d :2 39 :2 2d 15 :2 a 5b
11 1c :2 5b 22 1f :2 2b :2 1f 5a
:2 a 11 1a 30 41 4c f 1d
2a :2 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 77 7a :2 27 7e
81 :2 27 8d 90 :2 27 98 9b :2 27
a7 aa b1 ba bd :2 aa :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 49 b
:2 14 1f 1d :2 28 :2 1d a d :2 17
29 :2 33 3f 43 53 56 57 :2 53
:2 29 :3 d :2 13 18 24 64 67 :2 24
74 77 :2 24 7b 7e :2 24 88 8b
94 9c :2 a5 :2 94 b6 :2 8b :2 24 be
c1 :2 24 c9 cc :2 24 d1 d4 :2 24
da dd :2 24 :2 d 5a :2 a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 64 67 :2 24
:2 d 59 :3 a :2 15 29 :2 32 42 49
:2 a 38 :2 7 49 44 :2 4 7 10
1b :2 7 1e 20 :2 1e 7 f 19
:3 7 :2 10 1c 7 16 :8 a c a
c a c a c a c a
c a c f 24 26 2b 3c
41 43 4f 51 10 1d 26 a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 56 59 5a :2 56 :2 2c :3 10 :2 16
1b 27 67 6a :2 27 77 7a :2 27
7e 81 :2 27 8d 90 :2 27 98 9b
:2 27 a7 aa b1 ba bd :2 aa :2 27
:2 10 5d :2 d :2 a :4 16 :2 a 7 :3 22
7 f 19 :3 7 :2 10 1c 7 16
29 1a f 10 1d 26 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 77 7a :2 27 7e
81 :2 27 8d 90 :2 27 98 9b :2 27
a7 aa b1 ba bd :2 aa :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 22 7
c 3d 4e 57 5a 65 6e 71
7f 83 a8 7 b 18 1a 27
35 37 43 45 55 57 60 62
72 7 b 21 25 3a 3e 4d
51 67 71 74 81 84 91 94
a1 a4 b8 c9 7 9 17 27
29 34 36 45 47 c 22 7
c 16 1b 1f 2b 2d 7 c
1d 22 24 2f 33 7 c 1d
22 24 2f 31 7 c 12 17
1d 23 26 2e 32 14 1d 21
2f 3c 3e 4e 61 73 7 9
12 14 24 7 9 1f 21 35
37 45 47 5d 7 a 17 1a
27 2a 37 3a 4d 5e d 23
33 48 c 1e 23 28 31 36
3a 45 47 7 c 12 17 28
2d 2f 37 39 7 c 12 17
28 2d 2f 3a 3c 7 c 12
17 1d 23 26 2e 30 14 1d
21 2f 3b 3d 4d 5f 70 7
9 12 14 24 7 9 1f 21
36 38 47 49 5f 7 a 17
1a 27 2a 37 3a 4e 5f d
23 33 48 c 1e 22 27 30
35 39 44 46 7 c 23 28
2a 35 37 7 c 12 17 28
2d 2f 38 3a 7 c 12 17
28 2d 2f 3a 3c 7 c 12
17 1d 23 26 2e 30 14 1d
21 2f 3b 3d 4d 5f 70 7
9 12 14 24 7 9 1f 21
36 38 47 49 5f 7 a 17
1a 27 2a 37 3a 4e 5f d
23 33 48 c 1e 22 27 30
35 39 44 46 7 c 22 27
29 34 36 7 c 12 17 28
2d 2f 37 39 7 c 12 17
28 2d 2f 3a 3c 7 c 12
17 1d 23 26 2e 30 10 1a
27 17 7 17 a :2 14 26 :2 30
3c 3f 4f 52 53 :2 4f :2 26 :3 a
:2 10 15 21 61 64 :2 21 :2 a 56
:3 7 e 7 4 22 b 14 1f
:2 b 22 24 :2 22 a 2b 34 3f
:2 2b 42 44 :2 42 2a :2 a 7 f
19 :3 7 :2 10 1c 7 16 28 35
a d 14 17 49 f 24 27
2c 32 37 48 4e 51 5c 65
68 76 79 10 13 1e 27 2a
40 43 23 34 3c 3f 4d 4f
5f 61 69 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 77 7a :2 27 7e 81 :2 27 8d
90 :2 27 98 9b :2 27 a7 aa b1
ba bd :2 aa :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 47 7 :2 10 :3 1c 7
16 2a 35 1a 1c 28 2a f
24 26 2b 34 39 3b 51 53
5e 60 a f 20 25 27 32
34 a f 20 25 27 32 34
a f 20 25 27 39 3b 51
53 10 12 1d 26 28 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 77 7a :2 27 7e
81 :2 27 8d 90 :2 27 98 9b :2 27
a7 aa b1 ba bd :2 aa :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :3 47 7
c 1e 20 2f 40 53 55 62
6f 71 79 7b 7 2e 3d 64
78 7 2e 3a 61 73 7e 8d
94 a1 b6 c7 c 1b 2e 49
5e 6f 7 9 17 27 29 34
36 45 47 c 1d 1f 24 2e
33 35 41 43 e 1f 32 45
53 7 2e 3d 64 78 7 2e
3a 61 73 7e 8d 94 a1 d
1f 30 3f 52 6d 82 93 d
23 33 48 c 10 17 7 17
a :2 14 26 :2 30 3c 3f 4f 52
53 :2 4f :2 26 :3 a :2 10 15 21 61
64 :2 21 :2 a 56 :3 7 e 7 4
47 22 a 13 1e :2 a 21 23
:2 21 7 c 28 2a 4d 4f 66
68 81 7 9 15 17 27 3a
42 44 57 59 66 68 76 78
7 9 16 18 21 23 2d 3a
4a 4c 5b 5d 6a 6c 7c 7
10 12 22 24 34 45 48 58
6b 6d 7a 7c 89 8b 98 9a
ad bb bd c8 ca 7 9 1f
21 2e 31 41 4c 4e 56 58
62 64 6c 6e 79 7b 89 8b
99 7 9 c 21 23 28 2e
33 44 49 4b 55 5e 60 74
76 7 c 12 17 20 25 27
35 37 42 47 4d 52 66 6b
6d 79 7b 7 c 12 17 2b
31 3a 3c 4c 4e 5b 5e 7
c 12 17 25 2b 2e 3a 3c
d f 1c 25 27 42 17 7
17 a :2 14 26 :2 30 3c 3f 4f
52 53 :2 4f :2 26 :3 a :2 10 15 21
61 64 :2 21 :2 a 56 :3 7 e 7
4 25 22 a 13 1e :2 a 21
23 :2 21 7 15 7 11 1a 30
40 10 e 1b :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 67 6a :2 27 77
7a :2 27 7e 81 :2 27 8d 90 :2 27
98 9b :2 27 a7 aa b1 ba bd
:2 aa :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 25 b :2 14 1f 1d :2 28 :2 1d
a 3c :2 47 4e 5a :2 3c 5e 60
:2 5e 3b :2 a 14 1d 33 43 13
11 1e :2 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 59 5c 5d :2 59 :2 2f :3 13 :2 19
1e 2a 6a 6d :2 2a 7a 7d :2 2a
81 84 :2 2a 90 93 :2 2a 9b 9e
:2 2a aa ad b4 bd c0 :2 ad :2 2a
:2 13 60 :2 10 :2 d :4 19 :2 d a :3 63
e :2 17 22 20 :2 2b :2 20 d 3f
:2 4a 51 5d :2 3f 61 63 :2 61 3e
:3 d 1b d 66 17 28 15 25
32 :2 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5c 5f 60 :2 5c :2 32 :3 16 :2 1c 21
2d 6d 70 :2 2d 7d 80 :2 2d 84
87 :2 2d 93 96 :2 2d 9e a1 :2 2d
ad b0 b7 c0 c3 :2 b0 :2 2d :2 16
63 :2 13 :2 10 :4 1c :2 10 d :7 a 63
14 25 12 22 2f :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 59 5c 5d :2 59
:2 2f :3 13 :2 19 1e 2a 6a 6d :2 2a
7a 7d :2 2a 81 84 :2 2a 90 93
:2 2a 9b 9e :2 2a aa ad b4 bd
c0 :2 ad :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :7 7 a 11 1a 25 :2 11
:2 a 29 2c :2 29 a 15 a 14
22 2f 46 53 64 6e :2 d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 59 5c 5d
:2 59 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 90
93 :2 2a 9b 9e :2 2a aa ad b4
bd c0 :2 ad :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :3 2e d 16 1f :2 d
22 24 :2 22 d 1b d 26 d
18 d 17 27 34 20 37 44
55 5f 68 :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 5c 5f 60 :2 5c :2 32 :3 16
:2 1c 21 2d 6d 70 :2 2d 7d 80
:2 2d 84 87 :2 2d 93 96 :2 2d 9e
a1 :2 2d ad b0 b7 c0 c3 :2 b0
:2 2d :2 16 63 :2 13 :2 10 :4 1c :2 10 d
:3 a 10 19 22 :2 10 25 27 :2 25
1a 2a 37 23 34 37 3c 56
16 1a 27 2a 39 3d 4b 4e
19 1c 29 3a 3d 47 14 1c
23 26 49 4d :2 13 :2 1c 28 13
10 18 16 :2 1f 2b 16 26 :2 13
:2 18 16 :2 1f 2b 16 19 :2 23 35
:2 3f 4b 4f 5f 62 63 :2 5f :2 35
:3 19 :2 1f 24 30 70 73 :2 30 80
83 :2 30 87 8a :2 30 96 99 :2 30
a1 a4 :2 30 b0 b3 ba c3 c6
:2 b3 :2 30 :2 19 66 :2 16 :2 13 :4 1f :2 13
10 :3 29 13 1c 25 :2 13 28 2a
:2 28 13 21 13 2c 13 21 13
:4 10 29 10 1e 10 :4 d :5 a f
21 23 2f 31 a c a c
1b 2e 30 3d 3f 48 4a a
c 10 12 16 18 24 33 35
42 a c 1b 1d 2f 3d 3f
4e 50 61 63 72 c 20 31
33 14 16 32 39 43 45 52
5c 5e 6d 6f 8e a 31 3e
65 78 a c 1b 1d 2d 2f
34 36 43 45 a c 1b 22
24 34 36 47 49 5c a 17
f 10 23 10 27 42 57 6c
81 10 1e 20 33 42 4f 5d
5f 6f 71 82 84 98 10 2c
40 55 62 71 7e 8e a1 b4
be c0 d3 f 21 2f 3e 4f
51 5f 61 14 2b 2d 3e 69
14 2b 2d 3f 6a 14 2b 2d
4a 58 5a 6a 81 90 10 28
42 5d 7b 10 23 38 a c
1c 2c 3a a 18 27 2f 10
26 38 49 56 58 68 6a 7b
7d 91 f 17 a f 14 29
2e 30 3d 3f e 10 1e a
f 15 1a 2e 33 35 41 43
10 12 1f e 10 1d 1b 1d
40 42 59 5b 74 80 82 14
16 35 37 49 52 5a 5c 6a
6c 17 19 28 32 3a 3c 4a
4c 60 14 16 35 37 69 a
c 1f 21 2e 30 3a 43 52
63 14 16 1b 24 2e 30 35
3e 49 52 5d 5f 69 77 79
7e 87 92 9b a6 a8 b2 a
13 21 31 40 49 58 69 14
16 2a 2c 3c 3e 52 14 16
2a 2c 39 3b 4c 4e 62 14
16 25 27 36 38 4a 4c 5d
a c 1d f 14 16 32 39
43 45 52 5c 69 84 a c
19 1b 29 2b a c 1b 1d
2d 2f 34 36 43 45 a c
1b 22 32 43 a 17 14 16
2d 2f 17 19 2c 36 3e 40
4e 50 64 a c 19 1b 2b
a 13 15 25 27 37 48 4b
5b 6e 70 7d 7f 8c 8e 9b
9d 14 16 35 37 4a 54 5c
5e 6c 6e 19 27 29 34 36
44 46 56 58 69 6b a c
22 24 32 35 45 55 57 5f
61 6b 6d 75 77 82 84 92
94 a2 a4 ae b0 a c 28
2a 48 4a 72 7c 7e 94 14
16 2a 2c 40 42 5a 14 2b
34 36 42 44 5b 86 14 2b
34 36 43 45 5d 88 14 35
37 4d 4f 58 5a 79 87 89
9e b5 c4 a c a d 1d
a c a d 1d 34 36 a
c 19 1d 2d 14 16 36 38
49 53 5b 5d 6b 6d 89 14
16 35 37 49 52 5a 5c 6a
6c 17 19 29 33 3b 3d 4b
4d 61 a 18 a 18 27 2f
14 16 17 19 2d 37 3f 41
4f 51 65 14 16 17 19 29
33 3b 3d 4b 4d 61 14 16
17 19 28 32 3a 3c 4a 4c
60 14 16 2d 2f 41 43 5a
5d 79 a c 1c 1e 2f 31
f 24 a f 15 1a 2b 30
32 46 48 a f 15 1a 23
28 2a 35 37 a f 15 1a
23 29 2b 39 3c a f 15
1a 2e 33 35 41 43 a f
15 1a 2e 34 3d 3f 4f 51
5e 61 a f 15 1a 28 2e
31 3d 3f a f 15 1a 2a
30 33 40 42 a f 15 1a
2a 30 33 40 42 a f 15
1a 28 2f 33 40 42 10 12
1f 30 32 3f 48 4a 13 1b
1a a 1a d :2 17 29 :2 33 3f
42 52 55 56 :2 52 :2 29 :3 d :2 13
18 24 64 67 :2 24 :2 d 59 :3 a
11 a 2e a f 2b 2d 50
52 69 6b 84 8f 91 14 16
35 37 46 50 58 5a 68 6a
f 11 28 2b f 11 30 32
44 4e 56 58 66 68 17 19
2b 3d 45 47 55 57 6a 14
16 2d 36 f 11 28 31 f
11 28 31 f 11 39 42 55
a c 1f 21 2e 30 39 3b
a c 10 12 16 1f 2d 3d
4c 55 64 75 a c 14 2c
2e 42 44 54 56 6a a c
19 a c 1d a c 24 a
c 19 1b 29 2b a c 1b
1d 2d 2f 34 36 43 45 a
c 1b 22 32 43 a 17 14
16 2d 2f 17 19 2c 36 3e
40 4e 50 64 a c 19 1b
2b a 13 15 25 27 37 48
4b 5b 6e 70 7d 7f 8c 8e
9b 9d 14 16 35 37 4a 54
5c 5e 6c 6e 19 27 29 34
36 44 46 56 58 69 6b a
c 22 24 32 35 45 55 57
5f 61 6b 6d 75 77 82 84
92 94 a2 a4 ae b0 a c
28 2a 48 4a 72 7c 7e 94
a7 a c 19 1b 29 2b 39
3b 50 67 14 16 38 3a 52
54 6b 6d 7c 7e 92 94 a4
a6 d2 a c a d 1d a
c a d 1d 34 36 a c
19 1d 2d 14 16 36 38 49
53 5b 5d 6b 6d 89 14 16
35 37 49 52 5a 5c 6a 6c
17 19 29 33 3b 3d 4b 4d
61 a 18 a 18 27 2f 14
16 17 19 29 33 3b 3d 4b
4d 61 14 16 17 19 28 32
3a 3c 4a 4c 60 14 16 2d
2f 41 43 5a 5d 79 a c
1c 1e 2f 31 f 24 26 2b
31 36 47 4c 4e 62 64 a
f 15 1a 23 28 2a 35 37
a f 15 1a 23 29 2b 39
3c a f 15 1a 2e 33 35
41 43 a f 15 1a 2e 34
3d 3f 4f 51 5e 61 a f
15 1a 28 2e 31 3d 3f a
f 15 1a 2a 30 33 40 42
a f 15 1a 2a 30 33 40
42 a f 15 1a 28 2f 33
40 42 10 12 32 34 41 13
1c 1a a 1a d :2 17 29 :2 33
3f 42 52 55 56 :2 52 :2 29 :3 d
:2 13 18 24 64 67 :2 24 :2 d 59
:3 a 11 a :4 7 4 25 22 a
13 1e :2 a 21 23 :2 21 7 f
19 :3 7 :2 10 1c 7 16 :c a e
20 a e 21 a e 1f a
e 1e a e 1f a e 1d
a e 16 f 26 31 3a 61
6e a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 59 5a :2 56 :2 2c
:3 10 :2 16 1b 27 67 6a :2 27 77
7a :2 27 7e 81 :2 27 8d 90 :2 27
98 9b :2 27 a7 aa b1 ba bd
:2 aa :2 27 :2 10 5d :2 d :2 a :4 16 :2 a
7 :3 25 7 :2 10 :3 1c 7 16 2a
35 43 52 62 71 7d a 10
1a 1c 27 29 a c 1b 1d
2c 2e 3e 40 4c 4e 5b 5d
63 65 f 1f 21 26 2f 34
36 4c 4e 59 5b 67 6c 7d
82 84 8f 91 a f 20 25
27 32 34 a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 77 7a :2 27 7e 81 :2 27 8d
90 :2 27 98 9b :2 27 a7 aa b1
ba bd :2 aa :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 25 7 c 1e 20
2f 40 7 9 16 d 7 9
7 9 18 1a 29 2b 3b 3d
49 4b 58 5a 60 62 71 78
85 d 1e 30 3f 52 6d 7b
7d 92 a3 7 9 17 27 29
34 36 45 47 c 1c 7 c
16 1b 1d 35 37 43 45 e
1f 7 :2 d 7 16 25 37 43
50 56 65 6c 79 d 1f 30
3f 52 6d 81 96 a7 d 23
33 48 c 29 17 7 17 a
:2 14 26 :2 30 3c 3f 4f 52 53
:2 4f :2 26 :3 a :2 10 15 21 61 64
:2 21 :2 a 56 :3 7 e 7 4 25
22 a 13 1e :2 a 21 23 :2 21
7 f 19 :3 7 :2 10 1c 7 16
:c a e 20 a e 21 a e
1f a e 1e a e 1f a
e 1d a e 16 f 26 31
3a 61 6e a 11 d 19 :3 17
d :2 16 22 d 1e d :2 16 22
d :4 a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 77 7a :2 27 7e 81 :2 27 8d
90 :2 27 98 9b :2 27 a7 aa b1
ba bd :2 aa :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 25 7 :2 10 :3 1c 7
16 2a 35 43 52 5b 6b 7a
8a 99 a5 a 10 1b 1a 1c
28 2a a c 1b 1d 2c 2e
3e 40 4c 4e 5b 5d 63 65
f 1f 21 26 2f 34 36 4c
4e 59 5b 67 6c 7d 82 84
8f 91 a f 20 25 27 32
34 1a 1d 2a 2c 40 42 a
30 a 30 5d 5f f 24 28
32 10 13 1e 27 2a 38 3a
20 23 3a 4b 10 13 30 32
f 24 2c 2e 3b 3e 4d 4f
5d 60 a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 59 5a :2 56
:2 2c :3 10 :2 16 1b 27 67 6a :2 27
77 7a :2 27 7e 81 :2 27 8d 90
:2 27 98 9b :2 27 a7 aa b1 ba
bd :2 aa :2 27 :2 10 5d :2 d :2 a :4 16
:2 a 7 :3 25 7 c 1e 20 2f
40 7 9 16 29 31 33 7
9 18 1a 29 2b 3b 3d 49
4b 58 5a 60 62 71 78 85
d 1e 30 3f 52 6d 7b 7d
92 a3 7 9 17 27 29 34
36 45 47 c 1c 1e 23 2d
32 34 4c 4e 5a 5c e 1f
7 14 1c 7 16 25 37 43
50 56 65 6c 79 d 1f 30
3f 52 6d 7c 91 a2 d 23
33 48 c 26 3c e 10 21
7 9 16 18 20 22 7 9
18 1a 2a 2c 7 9 15 17
24 26 2c 2e 3e 46 53 68
79 c 1b 2e 49 58 5a 6f
80 7 9 17 27 29 34 36
45 47 c 20 23 2d d f
27 29 b d 1a 1c 10 1e
17 7 17 a :2 14 26 :2 30 3c
3f 4f 53 54 :2 4f :2 26 :3 a :2 10
15 21 62 65 :2 21 :2 a 57 :3 7
e 7 4 25 22 a 13 1e
:2 a 21 23 :2 21 7 c 1e 20
2f 3b 3d 50 52 5f 73 7b
7d 7 9 18 1a 2a 2c 34
44 46 56 69 6b 7b 87 89
9a 7 9 11 17 19 27 32
3f 54 66 c 1a 2d 4a 59
66 74 76 8b 9c 7 a 18
1b 29 2c 3a 3d 4b 4e 7
a 1f 22 38 3b 4e 51 7
a 25 28 44 47 7 a 25
28 44 47 63 65 7 9 17
27 29 34 36 45 47 c 21
7 c 20 26 29 36 3f 42
50 52 7 c 11 22 27 29
3b 3d 53 55 7 c 11 22
27 29 3b 3d 53 55 7 c
16 1b 1d 29 2b d f 1a
23 25 3c 3e 5f 61 e 10
1f 2b 2d 40 42 52 66 74
7 9 18 1a 29 2b 33 42
44 54 66 8d 99 c0 c 16
20 2d 42 54 c 1b 2e 43
45 59 6e 7f 7 a 18 1b
29 2c 3a 3d 4b 4e 7 a
1f 22 38 3b 4e 51 7 a
25 28 44 47 7 a 25 28
44 47 69 d 23 33 48 c
21 7 c 15 1a 1c 28 2a
7 c 1d 22 24 36 38 7
c 20 26 29 36 3f 42 50
52 d f 1a 23 25 10 1e
17 7 17 a :2 14 26 :2 30 3c
3f 4f 53 54 :2 4f :2 26 :3 a :2 10
15 21 62 65 :2 21 :2 a 57 :3 7
e 7 4 25 22 a 13 1e
:2 a 21 23 :2 21 7 f 19 :3 7
:2 10 1c 7 16 b :d a e 21
a e 21 a e 21 a 18
2a 3e a e 21 a e 21
a e 21 a 18 2a 3e f
10 1b 24 2c 13 20 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 5a 5b :2 56 :2 2c :3 10 :2 16 1b
27 68 6b :2 27 78 7b :2 27 7f
82 :2 27 8e 91 :2 27 99 9c :2 27
a8 ab b2 bb be :2 ab :2 27 :2 10
5e :2 d :2 a :4 16 :2 a 7 :3 25 7
f 19 :3 7 :2 10 1c 7 16 :20 a
c 1e 20 36 38 4e 50 a
c 1e 20 36 38 4e 50 a
c 1e 20 36 38 4e 50 a
c 1e 20 36 38 a c 21
23 39 3b 4e 50 a c 27
29 45 47 a c 27 29 45
47 a c 1e 20 36 38 4e
50 a 13 15 28 2a 37 39
60 62 f 23 a f 15 1a
2b 30 32 40 42 10 12 1d
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 56 5a 5b :2 56 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5e :2 d :2 a :4 16 :2 a 7
:3 25 11 22 29 3c 11 1e 2f
37 39 44 4d 4f 5d 60 70
72 a 11 d 19 :3 17 d :2 16
22 d 1e d :2 16 22 d :4 a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 56 5a 5b :2 56 :2 2c
:3 10 :2 16 1b 27 68 6b :2 27 78
7b :2 27 7f 82 :2 27 8e 91 :2 27
99 9c :2 27 a8 ab b2 bb be
:2 ab :2 27 :2 10 5e :2 d :2 a :4 16 :2 a
7 :3 25 7 c 1e 20 2f 40
7 9 16 24 26 2f 31 7
9 18 1a 29 2b 3b 3d 49
4b 58 5a 60 62 71 78 85
d 1e 30 3f 52 6d 7b 7d
92 a3 11 13 34 36 57 59
74 8b 8d a0 a2 b6 b8 cb
cd de e0 f2 f4 7 f 7
9 1e 20 36 38 4b 4d 7
9 24 26 42 44 7 9 24
26 42 44 7 9 17 19 27
29 37 39 47 49 56 58 7
9 17 28 2a 35 37 46 48
c 1d 7 c 16 1b 1d 35
37 43 45 f 11 1f 30 7
9 19 2c 3a 7 9 18 1a
29 2b 3b 3d 49 4b 58 5a
60 62 71 78 85 d 1f 30
3f 52 6d 81 96 a7 11 13
34 36 57 59 74 8b 8d a0
a2 b6 b8 cb cd de e0 f2
f4 7 f 7 9 1e 20 36
38 4b 4d 7 9 24 26 42
44 7 9 24 26 42 44 7
9 17 19 27 29 37 39 47
49 5c d 23 33 48 c 1d
7 c 15 1a 1c 32 34 3f
41 7 c 1d 22 24 2f 31
7 c 1d 22 24 2f 31 17
7 17 a :2 14 26 :2 30 3c 3f
4f 53 54 :2 4f :2 26 :3 a :2 10 15
21 62 65 :2 21 :2 a 57 :3 7 e
7 4 25 22 a 13 1e :2 a
23 21 :2 2c :2 21 11 23 2d 3c
49 :2 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 5a 5b :2 56 :2 2c :3 10 :2 16 1b
27 68 6b :2 27 78 7b :2 27 7f
82 :2 27 8e 91 :2 27 99 9c :2 27
a8 ab b2 bb be :2 ab :2 27 :2 10
5e :2 d :2 a :4 16 :2 a 7 :3 40 b
:2 14 1f 1d :2 28 :2 1d :2 a f 21
29 35 3d 50 5e 69 6b 74
7c a 12 16 26 30 38 3c
4c 56 5f 64 74 f 18 a
f 14 26 2d 31 3f a f
14 24 2d 31 3f a f 14
1e 2d 32 3f 10 12 1f 11
19 25 2d 40 48 4b 56 a
d 1b 24 2f 3c 47 54 5a
5d 73 79 7c 8e d 1b 28
36 43 52 f 25 27 2c 32
37 48 4e 50 58 5b a f
15 1a 2b 31 34 3f 42 52
54 66 11 19 25 2d 40 48
4b 56 a d 1b 24 2f 3c
47 54 5a 5d 73 79 7c 8e
d 1b 28 36 43 52 f 26
28 2d 33 38 49 4f 51 5a
5d a f 15 1a 2b 31 34
3f 42 52 54 66 13 1e 1a
a 1a d :2 17 29 :2 33 3f 42
52 56 57 :2 52 :2 29 :3 d :2 13 18
24 65 68 :2 24 :2 d 5a :3 a 11
a 38 :2 7 4 40 22 a 13
1e :2 a 21 23 :2 21 7 c 28
2a 4d 4f 66 68 81 8d 8f
11 13 32 34 46 4f 57 59
67 69 14 16 25 2f 37 39
47 49 5d 11 13 3b 3d 66
7 9 1c 1e 2b 2d 37 40
4f 60 7 9 d f 13 1c
2a 3a 49 52 61 72 11 25
35 49 11 25 32 43 57 11
13 22 24 33 35 47 49 5a
7 9 1a c 11 13 2f 36
40 42 4f 59 66 81 7 9
16 18 26 28 7 9 18 1a
2a 2c 31 33 40 42 7 9
18 1f 2f 40 7 14 11 13
2a 2c 14 16 29 33 3b 3d
4b 4d 61 7 9 16 18 28
7 10 12 22 24 34 45 48
58 6b 6d 7a 7c 89 8b 98
9a 11 13 32 34 47 51 59
5b 69 6b 16 24 26 31 33
41 43 53 55 66 68 7 9
1f 21 2f 32 42 52 54 5c
5e 68 6a 72 74 7f 81 8f
91 9f a1 ab ad 7 9 25
27 45 47 6f 79 7b 91 11
25 39 51 11 28 31 33 3f
41 58 83 11 28 31 33 40
42 5a 85 11 32 34 4a 4c
55 57 76 84 86 9b b2 11
13 35 37 4f 51 68 6a 79
7b 8f 91 a1 a3 cf 7 9
7 a 1a 7 9 7 a 1a
31 33 7 9 16 1a 2a 11
13 14 16 26 30 38 3a 48
4a 5e 11 13 14 16 25 2f
37 39 47 49 5d 11 13 14
16 2a 34 3c 3e 4c 4e 62
11 13 14 16 26 30 38 3a
48 4a 5e 11 13 2a 2c 3e
40 57 5a 76 7 9 19 1b
2c 2e c 21 7 c 1d 22
24 38 b d 21 23 7 c
12 17 2b 30 32 3e 40 7
c 12 17 2b 31 3a 3c 4c
4e 5b 5e 7 c 12 17 25
2b 2e 3a 3c 7 c 12 17
27 2d 30 3d 3f 7 c 12
17 27 2d 30 3d 3f 7 c
12 17 25 2c 30 3d 3f 7
c 12 17 20 25 27 32 34
7 c 12 17 20 26 28 36
39 10 1e 17 7 17 a :2 14
26 :2 30 3c 3f 4f 53 54 :2 4f
:2 26 :3 a :2 10 15 21 62 65 :2 21
:2 a 57 :3 7 e 7 4 26 22
a 13 1e :2 a 21 23 :2 21 7
c 1e 20 35 41 43 11 13
32 34 43 4d 55 57 65 67
c e 2d 2f 41 4b 53 55
63 65 14 16 28 3a 42 44
52 54 67 11 13 2a 33 c
e 25 2e 17 7 9 1c 1e
2b 52 61 88 c 19 40 49
70 7 2e 3a 61 74 7 2e
3b 62 76 7 2e 3d 64 79
7 2e 3b 62 c 13 20 11
13 32 34 47 51 59 5b 69
6b c e 23 7 2e 7 9
16 18 28 37 40 42 52 54
64 75 78 88 c 1e 30 43
11 13 32 34 47 51 59 5b
69 6b 16 7 9 1a 7 2e
3e 65 7b d 2a 3e 53 c
1b 28 38 4b 5e c 11 13
32 34 44 4e 56 58 66 68
16 11 13 32 34 43 4d 55
57 65 67 17 11 13 32 34
48 52 5a 5c 6a 6c 16 11
13 32 34 44 4e 56 58 66
68 16 c 21 7 c 12 17
2b 30 32 3e 40 7 c 12
17 2b 31 3a 3c 4c 4e 5b
5e d f 2f 31 3e 10 1e
17 7 17 a :2 14 26 :2 30 3c
3f 4f 53 54 :2 4f :2 26 :3 a :2 10
15 21 62 65 :2 21 :2 a 57 :3 7
e 7 4 26 22 a 13 1e
:2 a 21 23 :2 21 7 f 19 :3 7
:2 10 1c 7 16 23 30 3f 11
1e 34 f 10 1d :2 a 17 20
13 20 a 11 d 19 :3 17 d
:2 16 22 d 1e d :2 16 22 d
:4 a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 56 5a 5b :2 56
:2 2c :3 10 :2 16 1b 27 68 6b :2 27
78 7b :2 27 7f 82 :2 27 8e 91
:2 27 99 9c :2 27 a8 ab b2 bb
be :2 ab :2 27 :2 10 5e :2 d :2 a :4 16
:2 a 7 :3 26 7 f 19 :3 7 :2 10
1c 7 16 26 33 42 12 1f
35 f 10 1d a 14 13 20
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 56 5a 5b :2 56 :2 2c :3 10
:2 16 1b 27 68 6b :2 27 78 7b
:2 27 7f 82 :2 27 8e 91 :2 27 99
9c :2 27 a8 ab b2 bb be :2 ab
:2 27 :2 10 5e :2 d :2 a :4 16 :2 a 7
:3 26 7 f 19 :3 7 :2 10 1c 7
16 2d 3a 49 11 13 20 22
31 33 f 1b 1d 22 28 2d
3c 41 43 4f 51 11 13 20
22 31 33 f 1e 20 25 2b
30 3c 41 43 4f 51 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 5a 5b :2 56 :2 2c :3 10 :2 16 1b
27 68 6b :2 27 78 7b :2 27 7f
82 :2 27 8e 91 :2 27 99 9c :2 27
a8 ab b2 bb be :2 ab :2 27 :2 10
5e :2 d :2 a :4 16 :2 a 7 :3 26 7
c 1e 20 2f 3b 3d 4a 5d
66 68 73 75 7 9 17 27
29 39 3b 4a 4c c 22 24
29 33 38 3a 52 54 60 62
7 c 12 17 26 2d 2f 3b
3f 17 19 27 33 35 45 58
68 73 75 d 22 37 4c c
22 24 29 32 37 39 51 53
60 62 7 c 1d 22 24 2f
31 7 c 1d 22 24 2f 31
7 c 12 17 26 2d 2f 3b
3f 17 1a 29 35 37 44 59
62 64 76 7 9 17 27 29
39 3b 4a 4c c 21 25 2f
d 10 1b 7 a 18 1a 19
1c 2d 43 4c 4f 5d 60 10
1e 17 7 17 a :2 14 26 :2 30
3c 3f 4f 53 54 :2 4f :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 e 7 4 26 22 a 13
1e :2 a 21 23 :2 21 7 11 18
1f 22 :2 18 28 2b :2 11 :2 7 c
1f 21 2d 2f 3c 4f 58 5a
6c 7 9 17 27 29 39 3b
4a 4c c 16 18 1d 27 a
c 19 1b d f b d 17
10 18 7 18 a :2 14 26 :2 30
3c 3f 4f 53 54 :2 4f :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 e 7 4 26 22 b 14
1f :2 b 24 22 :2 2d :2 22 a 4e
11 1c :2 4e 21 1f :2 2a :2 1f 4d
:2 a 7 c 23 25 34 40 42
4f 5c 65 74 7d 7f 91 7
9 17 27 29 39 3b 4a 4c
c 20 24 2e d 10 1d b
e 1c 1e 10 1c 7 1c a
:2 14 26 :2 30 3c 3f 4f 53 54
:2 4f :2 26 :3 a :2 10 15 21 62 65
:2 21 :2 a 57 :3 7 e 7 48 22
a :2 14 26 :2 30 3c 3f 4f 53
54 :2 4f :2 26 :3 a :2 10 15 21 62
65 :2 21 72 75 :2 21 79 7c :2 21
86 89 92 9a :2 a3 :2 92 b4 :2 89
:2 21 bc bf :2 21 c7 ca :2 21 cf
d2 :2 21 d8 db :2 21 :2 a 57 :3 7
:2 12 24 :2 2d 3d 44 :2 7 :4 4 1
9 12 9 a :2 14 26 :2 30 3c
40 50 54 55 :2 50 :2 26 :3 a :2 10
15 21 62 65 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 58 :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 4d 51 52 :2 4d :2 23 :3 7 :2 d
12 1e 5f 62 :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 55
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
245a
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :6 e :6 f
:6 10 :6 11 :6 12 :6 13
:7 14 :7 15 :7 18 :7 1b
:7 1e :7 21 :7 24 :7 27
:7 2a :7 2d :7 30 :7 33
:7 36 :7 39 :7 3c :7 3f
:7 42 :7 44 :b 46 :11 47
48 :2 47 :2 48 :2 47
:2 48 :2 47 :2 49 :2 47
:9 49 :2 47 :2 4a :2 47
:2 4a :2 47 :2 4a :2 47
:2 4a :2 47 :2 4a :4 47
:3 46 :11 4d :b 4e :3 4d
:5 55 :11 56 :30 57 :3 56
:11 59 :b 5a :3 59 :a 5c
:3 55 :3 61 :3 62 :3 63
:16 66 :9 68 :4 69 :b 6a
68 :5 6b 67 6d
:5 6e :3 6d :2 6f :5 71
:11 72 :24 73 :3 72 :2 70
:6 6f 6c :3 66 :a 79
:7 7b :3 7c :b 7d 7b
:5 7e 7a 80 :5 81
:3 80 :2 82 :5 84 :11 85
:24 86 :3 85 :2 83 :6 82
7f :3 79 :a 8c :5 8e
:5 8f 8d 91 :5 92
:3 91 :2 93 :5 95 :11 96
:24 97 :3 96 :2 94 :6 93
90 :3 8c :a 9c :11 9d
:30 9e :3 9d :11 a0 :b a1
:3 a0 :a a3 :3 9c :3 8c
:3 79 a7 66 :9 a7
:2 a9 :3 aa a9 :5 ab
a8 ad :5 ae :3 ad
:2 af :5 b1 :11 b2 :24 b3
:3 b2 :2 b0 :6 af ac
:3 a7 :a b8 :11 b9 :30 ba
:3 b9 :11 bc :b bd :3 bc
:a bf :3 b8 :5 c3 :3 c4
c3 :5 c5 c2 c7
:5 c8 :3 c7 :2 c9 :5 cb
:11 cc :24 cd :3 cc :2 ca
:6 c9 c6 :3 a7 d1
a7 66 :9 d1 :6 d3
:5 d4 d2 d6 :5 d7
:3 d6 :2 d8 :5 da :11 db
:24 dc :3 db :2 d9 :6 d8
d5 :3 d1 :a e1 :11 e2
:30 e3 :3 e2 :11 e5 :b e6
:3 e5 :a e8 :3 e1 :3 eb
ec d1 66 :18 ec
:c ed :2 ec ed :2 ee
:2 ed :6 ee ed :2 ec
:5 f0 :3 f1 f0 :5 f2
ef f4 :5 f5 :3 f4
:2 f6 :5 f8 :11 f9 :24 fa
:3 f9 :2 f7 :6 f6 f3
:3 ee :a ff :11 100 :30 101
:3 100 :11 103 :b 104 :3 103
:a 106 :3 ff ee :3 66
:9 10c :5 10e :5 10f 112
114 115 116 117
118 119 11a :2 11d
:2 11e :2 11f :2 120 :2 121
:2 122 :2 123 :9 124 :3 125
112 :6 126 :5 127 126
:5 129 128 :3 126 111
12c :5 12d :3 12c :2 12e
:5 130 :11 131 :24 132 :3 131
:2 12f :6 12e 12b :3 10c
:5 138 :5 139 :2 13c 13d
13e :3 13f 13c :6 140
:5 141 140 :5 143 142
:3 140 13b 146 :5 147
:3 146 :2 148 :5 14a :11 14b
:24 14c :3 14b :2 149 :6 148
145 :3 10c :c 151 :e 152
:13 153 :9 154 :2 155 :7 156
:7 157 :7 158 :9 159 :9 15d
:5 15e :9 15f :a 160 :4 161
:9 162 :9 163 :9 164 :9 165
:9 169 :5 16a :9 16b :a 16c
:4 16d :9 16e :7 16f :9 170
:9 171 :9 172 :9 176 :5 177
:9 178 :a 179 :4 17a :9 17b
:7 17c :9 17d :9 17e :9 17f
:3 180 :3 151 :11 181 :b 182
:3 181 :3 184 186 10c
:16 186 :5 188 :5 189 :3 18c
:2 18e :3 18f :e 190 :7 191
:9 192 18c :6 193 :5 194
193 :5 196 195 :3 193
18b 199 :5 19a :3 199
:2 19b :5 19d :11 19e :24 19f
:3 19e :2 19c :6 19b 198
:3 186 :7 1a4 :3 1a7 :4 1a8
:b 1a9 :7 1aa :7 1ab :9 1ac
:5 1ad 1a7 :6 1ae :5 1af
1ae :5 1b1 1b0 :3 1ae
1a6 1b4 :5 1b5 :3 1b4
:2 1b6 :5 1b8 :11 1b9 :24 1ba
:3 1b9 :2 1b7 :6 1b6 1b3
:3 186 :d 1bf :5 1c0 :b 1c1
:6 1c2 :9 1c3 :9 1c4 :5 1c8
:5 1c9 :9 1ca :8 1cb :4 1cc
1cd 1ce :3 1bf :11 1cf
:b 1d0 :3 1cf :3 1d2 1d3
186 10c :9 1d3 :9 1d4
:e 1d5 :f 1d6 :16 1d7 :14 1d8
:2 1d9 :e 1da :12 1db :c 1dc
:9 1dd :6 1de :3 1d4 :11 1df
:b 1e0 :3 1df :3 1e2 1e3
1d3 10c :9 1e3 :3 1e8
:4 1ea 1eb :2 1ec 1ea
:5 1ed 1e9 1ef :5 1f0
:3 1ef :2 1f1 :5 1f3 :11 1f4
:24 1f5 :3 1f4 :2 1f2 :6 1f1
1ee :3 1e3 :18 1fc :4 1ff
200 :2 201 1ff :5 202
1fe 204 :5 205 :3 204
:2 206 :5 208 :11 209 :24 20a
:3 209 :2 207 :6 206 203
:3 1fc :18 210 :3 212 210
:2 216 :3 217 216 :5 218
215 21a :5 21b :3 21a
:2 21c :5 21e :11 21f :24 220
:3 21f :2 21d :6 21c 219
:4 213 :3 210 1fc :2 228
:3 229 228 :5 22a 227
22c :5 22d :3 22c :2 22e
:5 230 :11 231 :24 232 :3 231
:2 22f :6 22e 22b :4 225
:3 1fc :c 239 :3 23a :8 23c
:5 23d 23b 23f :5 240
:3 23f :2 241 :5 243 :11 244
:24 245 :3 244 :2 242 :6 241
23e :3 239 :9 24a :3 24b
24a :3 24d :3 24f :6 250
24f :5 251 24e 253
:5 254 :3 253 :2 255 :5 257
:11 258 :24 259 :3 258 :2 256
:6 255 252 :3 24c :9 25e
:3 260 :5 261 :8 262 :6 263
:6 264 260 :5 265 25f
267 :5 268 :3 267 :2 269
:5 26b :11 26c :24 26d :3 26c
:2 26a :6 269 266 :3 25e
:9 272 :3 273 272 :3 275
274 :3 272 25e :3 278
277 :3 25e 24c :3 24a
:6 281 :2 282 :9 283 :a 284
:c 285 :4 286 :c 287 :5 288
:a 289 :a 28a :2 28b 28c
:2 28d :6 28e :d 28f :d 290
:8 291 :5 292 :5 293 :9 294
:5 295 :3 296 :5 297 :4 298
:b 299 :2 29a :8 29b :3 29c
:9 29d :3 29e :3 29f :9 2a3
:a 2a4 :9 2a5 :5 2a6 :a 2a7
:16 2a8 :8 2a9 :7 2aa :9 2ab
:9 2ac :3 2ad 2ae :a 2af
:6 2b0 :a 2b1 :6 2b2 :2 2b3
:4 2b4 :9 2b5 :5 2b6 :11 2b7
:a 2b8 :b 2b9 :17 2ba :a 2bb
:7 2bc :8 2bd :8 2be :d 2bf
:2 2c0 :3 2c1 :2 2c2 :5 2c3
:5 2c4 :b 2c5 :a 2c6 :9 2c7
:2 2c8 :4 2c9 :2 2ca :9 2cb
:2 2cc :9 2cd :2 2ce :9 2cf
:9 2d0 :6 2d1 :2 2d2 :9 2d3
:9 2d4 :9 2d5 :9 2d6 :c 2d7
:9 2d8 :9 2d9 :9 2da :9 2db
:8 2dc :2 2de :3 281 :11 2df
:b 2e0 :3 2df :3 2e2 239
:b 2e6 :a 2e7 :4 2e8 :a 2e9
:9 2ea :4 2eb :4 2ec :4 2ed
:5 2ee :8 2ef :c 2f0 :a 2f1
:3 2f2 :3 2f3 :3 2f4 :6 2f5
:a 2f6 :6 2f7 :2 2f8 :4 2f9
:9 2fa :5 2fb :11 2fc :a 2fd
:b 2fe :17 2ff :b 300 :a 301
:f 302 :2 303 :3 304 :2 305
:5 306 :5 307 :b 308 :a 309
:9 30a :2 30b :4 30c :2 30d
:9 30e :2 30f :9 310 :9 311
:6 312 :b 313 :9 314 :9 315
:9 316 :c 317 :9 318 :9 319
:9 31a :9 31b :5 31c :2 31d
:3 2e6 :11 31e :b 31f :3 31e
:3 321 2e3 :3 239 323
1e3 10c :9 323 :5 325
:5 326 329 32b 32c
32d 32e 32f 330
331 332 333 336
337 :3 338 :3 339 :3 33a
:3 33b :3 33c :3 33d :3 33e
:6 33f 329 :6 340 :5 341
340 :5 343 342 :3 340
328 346 :5 347 :3 346
:2 348 :5 34a :11 34b :24 34c
:3 34b :2 349 :6 348 345
:3 323 :7 351 :8 354 :2 355
:4 356 :e 357 :12 358 :7 359
354 :6 35a :5 35b 35a
:5 35d 35c :3 35a 353
360 :5 361 :3 360 :2 362
:5 364 :11 365 :24 366 :3 365
:2 363 :6 362 35f :3 323
:6 36b :3 36c 36d :2 36e
:11 36f :a 370 :9 371 :2 372
:9 373 :2 377 378 379
37a :a 37b :9 37c :4 37d
:2 37e :3 36b :11 37f :b 380
:3 37f :3 382 383 323
10c :9 383 :5 385 :5 386
389 38b 38c 38d
38e 38f 390 391
392 393 396 397
:3 398 :3 399 :3 39a :3 39b
:3 39c :3 39d :3 39e :6 39f
389 :6 3a0 :5 3a1 3a0
:5 3a3 3a2 :3 3a0 388
3a6 :5 3a7 :3 3a6 :2 3a8
:5 3aa :11 3ab :24 3ac :3 3ab
:2 3a9 :6 3a8 3a5 :3 383
:7 3b1 :b 3b4 :3 3b5 :4 3b6
:e 3b7 :12 3b9 :7 3ba :6 3be
:2 3bf :4 3c0 :4 3c1 :7 3c2
:4 3c3 :4 3c4 :a 3c5 3b4
:6 3c6 :5 3c7 3c6 :5 3c9
3c8 :3 3c6 3b3 3cc
:5 3cd :3 3cc :2 3ce :5 3d0
:11 3d1 :24 3d2 :3 3d1 :2 3cf
:6 3ce 3cb :3 383 :6 3d7
:6 3d8 :11 3d9 :a 3da :9 3db
:b 3dc :2 3df :3 3e0 :a 3e1
:9 3e2 :4 3e3 :3 3e4 :3 3e8
:6 3e9 :6 3ea :d 3eb :8 3ec
:9 3ed :4 3ee :4 3ef :4 3f0
:2 3f1 :3 3d7 :11 3f2 :b 3f3
:3 3f2 :3 3f5 438 383
10c :9 438 :d 439 :10 43a
:a 43b :a 43c :a 43d :8 43e
:6 43f :8 440 :9 441 :2 442
:a 443 :a 444 :a 445 :7 446
:9 447 :a 44b :e 44c :6 44d
:8 44e :a 44f :8 450 :6 451
:7 452 :4 453 :2 454 :7 455
:7 456 :a 457 :5 458 :2 459
:3 439 :11 45a :b 45b :3 45a
:3 45d 45e 438 10c
:9 45e :5 460 :5 461 464
465 466 467 468
469 46a 46b 46c
46d 46e 46f 472
473 :3 474 :3 475 :3 476
:4 477 :3 478 :3 479 :3 47a
:4 47b 47c :4 47d :2 47e
464 :6 47f :5 480 47f
:5 482 481 :3 47f 463
485 :5 486 :3 485 :2 487
:5 489 :11 48a :24 48b :3 48a
:2 488 :6 487 484 :3 45e
:5 492 :5 493 496 498
499 49a 49b 49c
49d 49e 49f 4a0
4a1 4a2 4a3 4a4
4a5 4a6 4a7 4a8
4a9 4aa 4ab 4ac
4ad 4ae 4af 4b0
4b1 4b2 4b3 4b4
4b5 4b6 :8 4b9 :8 4ba
:8 4bb :6 4bc :8 4bd :6 4be
:6 4bf :8 4c0 :9 4c1 :2 4c2
:9 4c3 :3 4c4 496 :6 4c5
:5 4c6 4c5 :5 4c8 4c7
:3 4c5 495 4cb :5 4cc
:3 4cb :2 4cd :5 4cf :11 4d0
:24 4d1 :3 4d0 :2 4ce :6 4cd
4ca :3 45e :4 4d8 :c 4d9
4d8 :6 4da :5 4db 4da
:5 4dd 4dc :3 4da 4d7
4e0 :5 4e1 :3 4e0 :2 4e2
:5 4e4 :11 4e5 :24 4e6 :3 4e5
:2 4e3 :6 4e2 4df :3 45e
:6 4eb :7 4ec :11 4ed :a 4ee
:13 4ef :2 4f0 :8 4f1 :6 4f2
:6 4f3 :c 4f4 :9 4f5 :2 4f6
:9 4f7 :4 4fb :5 4fc :11 4fd
:9 4fe :13 4ff :2 500 :8 501
:6 502 :6 503 :b 504 :4 505
:2 506 :9 507 :7 508 :7 509
:3 4eb :11 50a :b 50b :3 50a
:3 50d 510 45e 10c
:b 510 :6 512 :5 513 511
515 :5 516 :3 515 :2 517
:5 519 :11 51a :24 51b :3 51a
:2 518 :6 517 514 :3 510
:a 520 :c 521 :c 522 :2 523
:7 524 :7 525 :7 526 :3 527
:8 52b :e 52c :6 52d :b 52e
:c 52f :8 533 :e 534 :6 535
:b 536 :c 537 :2 538 :3 521
:11 539 :b 53a :3 539 :3 53c
:3 520 53e 510 10c
:9 53e :b 53f :a 541 :9 542
:5 544 :a 545 :c 546 :4 547
:5 548 :9 549 :3 54a 54b
:a 54c :6 54d :a 54e :6 54f
:2 550 :4 551 :9 552 :5 553
:11 554 :a 555 :b 556 :17 557
:a 558 :4 559 :8 55a :8 55b
:c 55c :f 55d :2 55e :3 55f
:2 560 :5 561 :5 562 :2 563
:9 564 :2 565 :9 566 :2 567
:9 568 :2 569 :9 56a :9 56b
:6 56c :2 56d :6 56e :4 56f
:9 570 :c 571 :9 572 :9 573
:9 574 :9 575 :9 576 :9 577
:2 578 :3 53f :11 579 :b 57a
:3 579 :3 57c 57d 53e
10c :9 57d :7 57e :a 57f
:a 580 :9 581 :4 582 :4 583
584 :8 585 :5 586 :5 587
:5 588 :5 589 :4 58a :3 58b
:a 58c :3 58d :2 58e :e 58f
:4 590 :a 591 592 :3 593
:5 594 :4 595 :6 596 597
:a 598 599 :a 59a 59b
:a 59c 59d :a 59e 59f
:2 5a0 :9 5a1 :c 5a2 :5 5a3
:2 5a4 :3 57e :11 5a5 :b 5a6
:3 5a5 :3 5a8 5a9 57d
10c :9 5a9 :5 5ad :5 5ae
:4 5b1 :3 5b2 5b3 :2 5b4
5b5 :3 5b6 :2 5b7 5b1
:6 5b8 :5 5b9 5b8 :5 5bb
5ba :3 5b8 5b0 5be
:5 5bf :3 5be :2 5c0 :5 5c2
:11 5c3 :24 5c4 :3 5c3 :2 5c1
:6 5c0 5bd :3 5a9 :5 5ca
:5 5cb :4 5ce :3 5cf 5d0
:2 5d1 :2 5d2 :2 5d3 5ce
:6 5d4 :5 5d5 5d4 :5 5d7
5d6 :3 5d4 5cd 5da
:5 5db :3 5da :2 5dc :5 5de
:11 5df :24 5e0 :3 5df :2 5dd
:6 5dc 5d9 :3 5a9 :5 5e6
:5 5e7 :4 5ea :6 5eb :b 5ec
:6 5ee :b 5ef 5ea :6 5f0
:5 5f1 5f0 :5 5f3 5f2
:3 5f0 5e9 5f6 :5 5f7
:3 5f6 :2 5f8 :5 5fa :11 5fb
:24 5fc :3 5fb :2 5f9 :6 5f8
5f5 :3 5a9 :d 601 :9 602
:b 603 :9 604 :a 608 :4 609
:b 60a :7 60b :7 60c :9 60d
:a 611 :9 612 :4 613 :3 614
:4 615 :8 616 :2 617 :3 601
:11 618 :b 619 :3 618 :3 61b
61c 5a9 10c :9 61c
:c 61f :b 621 :9 622 :5 623
:4 624 :2 625 :3 626 627
:3 621 :11 628 :b 629 :3 628
:3 62b 62c 61c 10c
:d 62c :2 62d :2 62c :6 62d
:3 62c :e 631 :9 632 :4 633
:3 634 :4 635 636 :3 631
:11 637 :b 638 :3 637 :3 63a
62d 10c :11 63c :30 63d
:3 63c :a 63f 63b :3 10c
45 :3 644 :11 645 :b 646
:17 647 :3 645 :2 649 :3 64a
:3 64b 64c 64a 649
64a :3 64d :3 644 :2 64e
:5 650 :11 651 :b 652 :18 653
:3 651 :2 655 656 :3 657
658 656 655 656
:3 659 :2 64f :6 64e 643
:7 1 
8769
4
:3 0 1 :3 0 2
:a 0 2455 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 2455 2 14
:2 0 e :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 2453
0 b :6 0 e
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 2453
0 d :6 0 e
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 2453
0 f :6 0 12
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 2453
0 10 :6 0 14
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 2453
0 11 :6 0 16
:2 0 23 4 :3 0
21 3a 3c :6 0
3f 3d 0 2453
0 13 :6 0 16
:2 0 25 6 :3 0
41 :7 0 45 42
43 2453 0 15
:6 0 16 :2 0 27
6 :3 0 47 :7 0
4b 48 49 2453
0 17 :6 0 16
:2 0 29 6 :3 0
4d :7 0 51 4e
4f 2453 0 18
:6 0 16 :2 0 2b
6 :3 0 53 :7 0
57 54 55 2453
0 19 :6 0 16
:2 0 2d 6 :3 0
59 :7 0 5d 5a
5b 2453 0 1a
:6 0 e :2 0 2f
6 :3 0 5f :7 0
63 60 61 2453
0 1b :6 0 12
:2 0 33 4 :3 0
31 65 67 :6 0
6a 68 0 2453
0 1c :6 0 73
74 0 37 4
:3 0 35 6c 6e
:6 0 71 6f 0
2453 0 1d :6 0
7a 7b 0 39
9 :3 0 a :2 0
4 75 :7 0 78
76 0 2453 0
1e :6 0 81 82
0 3b 9 :3 0
a :2 0 4 7c
:7 0 7f 7d 0
2453 0 1f :6 0
88 89 0 3d
9 :3 0 a :2 0
4 83 :7 0 86
84 0 2453 0
20 :6 0 8f 90
0 3f 9 :3 0
a :2 0 4 8a
:7 0 8d 8b 0
2453 0 21 :6 0
96 97 0 41
9 :3 0 a :2 0
4 91 :7 0 94
92 0 2453 0
22 :6 0 9d 9e
0 43 9 :3 0
a :2 0 4 98
:7 0 9b 99 0
2453 0 23 :6 0
a4 a5 0 45
9 :3 0 a :2 0
4 9f :7 0 a2
a0 0 2453 0
24 :6 0 ab ac
0 47 9 :3 0
a :2 0 4 a6
:7 0 a9 a7 0
2453 0 25 :6 0
b2 b3 0 49
9 :3 0 a :2 0
4 ad :7 0 b0
ae 0 2453 0
26 :6 0 b9 ba
0 4b 9 :3 0
a :2 0 4 b4
:7 0 b7 b5 0
2453 0 27 :6 0
c0 c1 0 4d
9 :3 0 a :2 0
4 bb :7 0 be
bc 0 2453 0
28 :6 0 c7 c8
0 4f 9 :3 0
a :2 0 4 c2
:7 0 c5 c3 0
2453 0 29 :6 0
ce cf 0 51
9 :3 0 a :2 0
4 c9 :7 0 cc
ca 0 2453 0
2a :6 0 d5 d6
0 53 9 :3 0
a :2 0 4 d0
:7 0 d3 d1 0
2453 0 2b :6 0
dc dd 0 55
9 :3 0 a :2 0
4 d7 :7 0 da
d8 0 2453 0
2c :6 0 e2 e3
0 57 9 :3 0
a :2 0 4 de
:7 0 e1 df 0
2453 0 2d :6 0
2e :3 0 2f :3 0
2e :3 0 30 :3 0
e5 e6 0 2
:4 0 59 e7 e9
e4 eb ea :2 0
31 :3 0 32 :3 0
ed ee 0 33
:4 0 2e :3 0 34
:3 0 f1 f2 0
2 :4 0 5b f3
f5 35 :4 0 36
:2 0 37 :3 0 5d
f8 fa :3 0 38
:4 0 36 :2 0 39
:4 0 60 fd ff
:3 0 36 :2 0 3
:3 0 63 101 103
:3 0 36 :2 0 39
:4 0 66 105 107
:3 0 36 :2 0 3a
:4 0 69 109 10b
:3 0 36 :2 0 3b
:3 0 3c :3 0 5
:3 0 6c 10f 111
3d :4 0 6e 10e
114 71 10d 116
:3 0 36 :2 0 3a
:4 0 74 118 11a
:3 0 36 :2 0 39
:4 0 77 11c 11e
:3 0 36 :2 0 7
:3 0 7a 120 122
:3 0 36 :2 0 39
:4 0 7d 124 126
:3 0 36 :2 0 3e
:4 0 80 128 12a
:3 0 83 ef 12c
:2 0 12e 88 12f
ec 12e 0 130
8a 0 23b3 2e
:3 0 2f :3 0 131
132 0 2e :3 0
3f :3 0 134 135
0 14 :2 0 2
:4 0 40 :2 0 41
:2 0 14 :2 0 8c
13a 13c :3 0 8f
136 13e 133 140
13f :2 0 31 :3 0
42 :3 0 142 143
0 33 :4 0 43
:4 0 36 :2 0 37
:3 0 93 147 149
:3 0 96 144 14b
:2 0 14d 99 14e
141 14d 0 14f
9b 0 23b3 3
:3 0 44 :2 0 9d
151 152 :3 0 153
:2 0 2e :3 0 2f
:3 0 155 156 0
2e :3 0 3f :3 0
158 159 0 e
:2 0 2 :4 0 45
:2 0 41 :2 0 14
:2 0 9f 15e 160
:3 0 a2 15a 162
157 164 163 :2 0
31 :3 0 42 :3 0
166 167 0 33
:4 0 46 :4 0 36
:2 0 37 :3 0 a6
16b 16d :3 0 36
:2 0 47 :4 0 a9
16f 171 :3 0 36
:2 0 48 :4 0 ac
173 175 :3 0 36
:2 0 3b :3 0 3c
:3 0 49 :3 0 4a
:3 0 17a 17b 0
af 179 17d 3d
:4 0 b1 178 180
b4 177 182 :3 0
36 :2 0 4b :4 0
b7 184 186 :3 0
36 :2 0 39 :4 0
ba 188 18a :3 0
36 :2 0 3 :3 0
bd 18c 18e :3 0
36 :2 0 39 :4 0
c0 190 192 :3 0
c3 168 194 :2 0
196 c6 197 165
196 0 198 c8
0 1c2 2e :3 0
2f :3 0 199 19a
0 2e :3 0 3f
:3 0 19c 19d 0
14 :2 0 2 :4 0
4c :2 0 41 :2 0
14 :2 0 ca 1a2
1a4 :3 0 cd 19e
1a6 19b 1a8 1a7
:2 0 31 :3 0 42
:3 0 1aa 1ab 0
33 :4 0 4d :4 0
36 :2 0 37 :3 0
d1 1af 1b1 :3 0
d4 1ac 1b3 :2 0
1b5 d7 1b6 1a9
1b5 0 1b7 d9
0 1c2 4e :3 0
4f :3 0 1b8 1b9
0 49 :3 0 4a
:3 0 1bb 1bc 0
3 :3 0 50 :3 0
db 1ba 1c0 :2 0
1c2 df 1c3 154
1c2 0 1c4 e3
0 23b3 d :3 0
3 :3 0 1c5 1c6
0 23b3 15 :3 0
5 :3 0 1c8 1c9
0 23b3 f :3 0
7 :3 0 1cb 1cc
0 23b3 3b :3 0
15 :3 0 16 :2 0
e5 1ce 1d1 51
:2 0 52 :2 0 ea
1d3 1d5 :3 0 1d6
:2 0 3b :3 0 15
:3 0 16 :2 0 ed
1d8 1db 51 :2 0
53 :2 0 f2 1dd
1df :3 0 1e0 :2 0
1d7 1e2 1e1 :2 0
54 :3 0 55 :3 0
54 :3 0 56 :3 0
3b :3 0 57 :3 0
58 :3 0 54 :3 0
59 :3 0 10 :3 0
18 :3 0 17 :3 0
1b :3 0 5a :3 0
57 :3 0 5a :3 0
54 :3 0 54 :3 0
5b :3 0 d :3 0
57 :3 0 5b :3 0
54 :3 0 55 :4 0
5c 1 :8 0 202
9 :3 0 5d :3 0
1fd 1fe 0 5e
:3 0 1ff 200 0
202 f5 255 5f
:3 0 9 :3 0 5d
:3 0 204 205 0
5e :3 0 206 207
0 209 f8 20b
fa 20a 209 :2 0
253 60 :3 0 9
:3 0 5d :3 0 20e
20f 0 5e :3 0
210 211 0 24b
2e :3 0 2f :3 0
213 214 0 2e
:3 0 3f :3 0 216
217 0 61 :2 0
2 :4 0 62 :2 0
41 :2 0 14 :2 0
fc 21c 21e :3 0
ff 218 220 215
222 221 :2 0 31
:3 0 42 :3 0 224
225 0 33 :4 0
63 :4 0 36 :2 0
37 :3 0 103 229
22b :3 0 36 :2 0
47 :4 0 106 22d
22f :3 0 36 :2 0
64 :4 0 109 231
233 :3 0 36 :2 0
5e :3 0 10c 235
237 :3 0 36 :2 0
65 :4 0 10f 239
23b :3 0 36 :2 0
66 :3 0 67 :3 0
14 :2 0 68 :2 0
112 23e 242 116
23d 244 :3 0 119
226 246 :2 0 248
11c 249 223 248
0 24a 11e 0
24b 120 24e :3 0
24e 0 24e 24d
24b 24c :6 0 250
2 :3 0 123 252
125 251 250 :2 0
253 127 :2 0 255
0 255 254 202
253 :6 0 3bb 1
:3 0 9 :3 0 5d
:3 0 257 258 0
9 :3 0 51 :2 0
69 :3 0 25a 25c
0 12c 25b 25e
:3 0 25f :2 0 54
:3 0 55 :3 0 54
:3 0 56 :3 0 3b
:3 0 57 :3 0 58
:3 0 10 :3 0 18
:3 0 17 :3 0 5a
:3 0 57 :3 0 6a
:3 0 54 :3 0 54
:3 0 5b :3 0 d
:3 0 57 :3 0 5b
:3 0 54 :3 0 55
:4 0 6b 1 :8 0
27c 9 :3 0 5d
:3 0 277 278 0
5e :3 0 279 27a
0 27c 12f 2cf
5f :3 0 9 :3 0
5d :3 0 27e 27f
0 5e :3 0 280
281 0 283 132
285 134 284 283
:2 0 2cd 60 :3 0
9 :3 0 5d :3 0
288 289 0 5e
:3 0 28a 28b 0
2c5 2e :3 0 2f
:3 0 28d 28e 0
2e :3 0 3f :3 0
290 291 0 61
:2 0 2 :4 0 6c
:2 0 41 :2 0 14
:2 0 136 296 298
:3 0 139 292 29a
28f 29c 29b :2 0
31 :3 0 42 :3 0
29e 29f 0 33
:4 0 6d :4 0 36
:2 0 37 :3 0 13d
2a3 2a5 :3 0 36
:2 0 47 :4 0 140
2a7 2a9 :3 0 36
:2 0 64 :4 0 143
2ab 2ad :3 0 36
:2 0 5e :3 0 146
2af 2b1 :3 0 36
:2 0 65 :4 0 149
2b3 2b5 :3 0 36
:2 0 66 :3 0 67
:3 0 14 :2 0 68
:2 0 14c 2b8 2bc
150 2b7 2be :3 0
153 2a0 2c0 :2 0
2c2 156 2c3 29d
2c2 0 2c4 158
0 2c5 15a 2c8
:3 0 2c8 0 2c8
2c7 2c5 2c6 :6 0
2ca 4 :3 0 15d
2cc 15f 2cb 2ca
:2 0 2cd 161 :2 0
2cf 0 2cf 2ce
27c 2cd :6 0 3b7
1 :3 0 9 :3 0
5d :3 0 2d1 2d2
0 9 :3 0 51
:2 0 69 :3 0 2d4
2d6 0 166 2d5
2d8 :3 0 2d9 :2 0
17 :3 0 6e :3 0
5b :3 0 d :4 0
6f 1 :8 0 2e5
9 :3 0 5d :3 0
2e0 2e1 0 5e
:3 0 2e2 2e3 0
2e5 169 338 5f
:3 0 9 :3 0 5d
:3 0 2e7 2e8 0
5e :3 0 2e9 2ea
0 2ec 16c 2ee
16e 2ed 2ec :2 0
336 60 :3 0 9
:3 0 5d :3 0 2f1
2f2 0 5e :3 0
2f3 2f4 0 32e
2e :3 0 2f :3 0
2f6 2f7 0 2e
:3 0 3f :3 0 2f9
2fa 0 61 :2 0
2 :4 0 70 :2 0
41 :2 0 14 :2 0
170 2ff 301 :3 0
173 2fb 303 2f8
305 304 :2 0 31
:3 0 42 :3 0 307
308 0 33 :4 0
71 :4 0 36 :2 0
37 :3 0 177 30c
30e :3 0 36 :2 0
47 :4 0 17a 310
312 :3 0 36 :2 0
64 :4 0 17d 314
316 :3 0 36 :2 0
5e :3 0 180 318
31a :3 0 36 :2 0
65 :4 0 183 31c
31e :3 0 36 :2 0
66 :3 0 67 :3 0
14 :2 0 68 :2 0
186 321 325 18a
320 327 :3 0 18d
309 329 :2 0 32b
190 32c 306 32b
0 32d 192 0
32e 194 331 :3 0
331 0 331 330
32e 32f :6 0 333
6 :3 0 197 335
199 334 333 :2 0
336 19b :2 0 338
0 338 337 2e5
336 :6 0 3b4 1
:3 0 9 :3 0 5d
:3 0 33a 33b 0
9 :3 0 51 :2 0
69 :3 0 33d 33f
0 1a0 33e 341
:3 0 342 :2 0 2e
:3 0 2f :3 0 344
345 0 2e :3 0
3f :3 0 347 348
0 e :2 0 2
:4 0 72 :2 0 41
:2 0 14 :2 0 1a3
34d 34f :3 0 1a6
349 351 346 353
352 :2 0 31 :3 0
42 :3 0 355 356
0 33 :4 0 73
:4 0 36 :2 0 37
:3 0 1aa 35a 35c
:3 0 36 :2 0 47
:4 0 1ad 35e 360
:3 0 36 :2 0 48
:4 0 1b0 362 364
:3 0 36 :2 0 3b
:3 0 3c :3 0 49
:3 0 4a :3 0 369
36a 0 1b3 368
36c 3d :4 0 1b5
367 36f 1b8 366
371 :3 0 36 :2 0
4b :4 0 1bb 373
375 :3 0 36 :2 0
39 :4 0 1be 377
379 :3 0 36 :2 0
d :3 0 1c1 37b
37d :3 0 36 :2 0
39 :4 0 1c4 37f
381 :3 0 1c7 357
383 :2 0 385 1ca
386 354 385 0
387 1cc 0 3b1
2e :3 0 2f :3 0
388 389 0 2e
:3 0 3f :3 0 38b
38c 0 14 :2 0
2 :4 0 74 :2 0
41 :2 0 14 :2 0
1ce 391 393 :3 0
1d1 38d 395 38a
397 396 :2 0 31
:3 0 42 :3 0 399
39a 0 33 :4 0
75 :4 0 36 :2 0
37 :3 0 1d5 39e
3a0 :3 0 1d8 39b
3a2 :2 0 3a4 1db
3a5 398 3a4 0
3a6 1dd 0 3b1
4e :3 0 4f :3 0
3a7 3a8 0 49
:3 0 4a :3 0 3aa
3ab 0 d :3 0
50 :3 0 1df 3a9
3af :2 0 3b1 1e3
3b2 343 3b1 0
3b3 1e7 0 3b4
1e9 3b5 2da 3b4
0 3b6 1ec 0
3b7 1ee 3b8 260
3b7 0 3b9 1f1
0 3bb 76 :3 0
1f3 701 3b :3 0
15 :3 0 16 :2 0
1f6 3bc 3bf 51
:2 0 77 :2 0 1fb
3c1 3c3 :3 0 55
:3 0 10 :3 0 78
:3 0 79 :3 0 d
:4 0 7a 1 :8 0
3d0 9 :3 0 5d
:3 0 3cb 3cc 0
5e :3 0 3cd 3ce
0 3d0 1fe 423
5f :3 0 9 :3 0
5d :3 0 3d2 3d3
0 5e :3 0 3d4
3d5 0 3d7 201
3d9 203 3d8 3d7
:2 0 421 60 :3 0
9 :3 0 5d :3 0
3dc 3dd 0 5e
:3 0 3de 3df 0
419 2e :3 0 2f
:3 0 3e1 3e2 0
2e :3 0 3f :3 0
3e4 3e5 0 61
:2 0 2 :4 0 7b
:2 0 41 :2 0 14
:2 0 205 3ea 3ec
:3 0 208 3e6 3ee
3e3 3f0 3ef :2 0
31 :3 0 42 :3 0
3f2 3f3 0 33
:4 0 7c :4 0 36
:2 0 37 :3 0 20c
3f7 3f9 :3 0 36
:2 0 47 :4 0 20f
3fb 3fd :3 0 36
:2 0 64 :4 0 212
3ff 401 :3 0 36
:2 0 5e :3 0 215
403 405 :3 0 36
:2 0 65 :4 0 218
407 409 :3 0 36
:2 0 66 :3 0 67
:3 0 14 :2 0 68
:2 0 21b 40c 410
21f 40b 412 :3 0
222 3f4 414 :2 0
416 225 417 3f1
416 0 418 227
0 419 229 41c
:3 0 41c 0 41c
41b 419 41a :6 0
41e 8 :3 0 22c
420 22e 41f 41e
:2 0 421 230 :2 0
423 0 423 422
3d0 421 :6 0 503
1 :3 0 9 :3 0
5d :3 0 425 426
0 9 :3 0 51
:2 0 69 :3 0 428
42a 0 235 429
42c :3 0 42d :2 0
2e :3 0 2f :3 0
42f 430 0 2e
:3 0 3f :3 0 432
433 0 e :2 0
2 :4 0 7d :2 0
41 :2 0 14 :2 0
238 438 43a :3 0
23b 434 43c 431
43e 43d :2 0 31
:3 0 42 :3 0 440
441 0 33 :4 0
7e :4 0 36 :2 0
37 :3 0 23f 445
447 :3 0 36 :2 0
47 :4 0 242 449
44b :3 0 36 :2 0
48 :4 0 245 44d
44f :3 0 36 :2 0
3b :3 0 3c :3 0
49 :3 0 4a :3 0
454 455 0 248
453 457 3d :4 0
24a 452 45a 24d
451 45c :3 0 36
:2 0 4b :4 0 250
45e 460 :3 0 36
:2 0 39 :4 0 253
462 464 :3 0 36
:2 0 3 :3 0 256
466 468 :3 0 36
:2 0 39 :4 0 259
46a 46c :3 0 25c
442 46e :2 0 470
25f 471 43f 470
0 472 261 0
49c 2e :3 0 2f
:3 0 473 474 0
2e :3 0 3f :3 0
476 477 0 14
:2 0 2 :4 0 7f
:2 0 41 :2 0 14
:2 0 263 47c 47e
:3 0 266 478 480
475 482 481 :2 0
31 :3 0 42 :3 0
484 485 0 33
:4 0 80 :4 0 36
:2 0 37 :3 0 26a
489 48b :3 0 26d
486 48d :2 0 48f
270 490 483 48f
0 491 272 0
49c 4e :3 0 4f
:3 0 492 493 0
49 :3 0 4a :3 0
495 496 0 3
:3 0 50 :3 0 274
494 49a :2 0 49c
278 49d 42e 49c
0 49e 27c 0
503 3b :3 0 58
:3 0 59 :3 0 17
:3 0 1b :3 0 5a
:3 0 5b :3 0 d
:4 0 81 1 :8 0
4ad 9 :3 0 5d
:3 0 4a8 4a9 0
5e :3 0 4aa 4ab
0 4ad 27e 500
5f :3 0 9 :3 0
5d :3 0 4af 4b0
0 5e :3 0 4b1
4b2 0 4b4 281
4b6 283 4b5 4b4
:2 0 4fe 60 :3 0
9 :3 0 5d :3 0
4b9 4ba 0 5e
:3 0 4bb 4bc 0
4f6 2e :3 0 2f
:3 0 4be 4bf 0
2e :3 0 3f :3 0
4c1 4c2 0 61
:2 0 2 :4 0 82
:2 0 41 :2 0 14
:2 0 285 4c7 4c9
:3 0 288 4c3 4cb
4c0 4cd 4cc :2 0
31 :3 0 42 :3 0
4cf 4d0 0 33
:4 0 83 :4 0 36
:2 0 37 :3 0 28c
4d4 4d6 :3 0 36
:2 0 47 :4 0 28f
4d8 4da :3 0 36
:2 0 64 :4 0 292
4dc 4de :3 0 36
:2 0 5e :3 0 295
4e0 4e2 :3 0 36
:2 0 65 :4 0 298
4e4 4e6 :3 0 36
:2 0 66 :3 0 67
:3 0 14 :2 0 68
:2 0 29b 4e9 4ed
29f 4e8 4ef :3 0
2a2 4d1 4f1 :2 0
4f3 2a5 4f4 4ce
4f3 0 4f5 2a7
0 4f6 2a9 4f9
:3 0 4f9 0 4f9
4f8 4f6 4f7 :6 0
4fb a :3 0 2ac
4fd 2ae 4fc 4fb
:2 0 4fe 2b0 :2 0
500 0 500 4ff
4ad 4fe :6 0 503
1 :3 0 76 :3 0
2b3 504 3c4 503
0 702 3b :3 0
15 :3 0 16 :2 0
2b7 505 508 51
:2 0 84 :2 0 2bc
50a 50c :3 0 85
:3 0 b :3 0 6e
:3 0 5b :3 0 d
:4 0 86 1 :8 0
519 9 :3 0 5d
:3 0 514 515 0
5e :3 0 516 517
0 519 2bf 56c
5f :3 0 9 :3 0
5d :3 0 51b 51c
0 5e :3 0 51d
51e 0 520 2c2
522 2c4 521 520
:2 0 56a 60 :3 0
9 :3 0 5d :3 0
525 526 0 5e
:3 0 527 528 0
562 2e :3 0 2f
:3 0 52a 52b 0
2e :3 0 3f :3 0
52d 52e 0 61
:2 0 2 :4 0 87
:2 0 41 :2 0 14
:2 0 2c6 533 535
:3 0 2c9 52f 537
52c 539 538 :2 0
31 :3 0 42 :3 0
53b 53c 0 33
:4 0 88 :4 0 36
:2 0 37 :3 0 2cd
540 542 :3 0 36
:2 0 47 :4 0 2d0
544 546 :3 0 36
:2 0 64 :4 0 2d3
548 54a :3 0 36
:2 0 5e :3 0 2d6
54c 54e :3 0 36
:2 0 65 :4 0 2d9
550 552 :3 0 36
:2 0 66 :3 0 67
:3 0 14 :2 0 68
:2 0 2dc 555 559
2e0 554 55b :3 0
2e3 53d 55d :2 0
55f 2e6 560 53a
55f 0 561 2e8
0 562 2ea 565
:3 0 565 0 565
564 562 563 :6 0
567 c :3 0 2ed
569 2ef 568 567
:2 0 56a 2f1 :2 0
56c 0 56c 56b
519 56a :6 0 5ec
1 :3 0 9 :3 0
5d :3 0 56e 56f
0 9 :3 0 51
:2 0 69 :3 0 571
573 0 2f6 572
575 :3 0 576 :2 0
2e :3 0 2f :3 0
578 579 0 2e
:3 0 3f :3 0 57b
57c 0 e :2 0
2 :4 0 89 :2 0
41 :2 0 14 :2 0
2f9 581 583 :3 0
2fc 57d 585 57a
587 586 :2 0 31
:3 0 42 :3 0 589
58a 0 33 :4 0
8a :4 0 36 :2 0
37 :3 0 300 58e
590 :3 0 36 :2 0
47 :4 0 303 592
594 :3 0 36 :2 0
48 :4 0 306 596
598 :3 0 36 :2 0
3b :3 0 3c :3 0
49 :3 0 4a :3 0
59d 59e 0 309
59c 5a0 3d :4 0
30b 59b 5a3 30e
59a 5a5 :3 0 36
:2 0 4b :4 0 311
5a7 5a9 :3 0 36
:2 0 39 :4 0 314
5ab 5ad :3 0 36
:2 0 3 :3 0 317
5af 5b1 :3 0 36
:2 0 39 :4 0 31a
5b3 5b5 :3 0 31d
58b 5b7 :2 0 5b9
320 5ba 588 5b9
0 5bb 322 0
5e5 2e :3 0 2f
:3 0 5bc 5bd 0
2e :3 0 3f :3 0
5bf 5c0 0 14
:2 0 2 :4 0 8b
:2 0 41 :2 0 14
:2 0 324 5c5 5c7
:3 0 327 5c1 5c9
5be 5cb 5ca :2 0
31 :3 0 42 :3 0
5cd 5ce 0 33
:4 0 8c :4 0 36
:2 0 37 :3 0 32b
5d2 5d4 :3 0 32e
5cf 5d6 :2 0 5d8
331 5d9 5cc 5d8
0 5da 333 0
5e5 4e :3 0 4f
:3 0 5db 5dc 0
49 :3 0 4a :3 0
5de 5df 0 3
:3 0 50 :3 0 335
5dd 5e3 :2 0 5e5
339 5e6 577 5e5
0 5e7 33d 0
5ec 17 :3 0 8d
:2 0 5e8 5e9 0
5ec 76 :3 0 33f
5ed 50d 5ec 0
702 3b :3 0 15
:3 0 16 :2 0 343
5ee 5f1 49 :3 0
8e :2 0 8f :3 0
5f3 5f5 0 348
5f4 5f7 :3 0 5f8
:2 0 3b :3 0 15
:3 0 16 :2 0 34b
5fa 5fd 8e :2 0
90 :2 0 350 5ff
601 :3 0 602 :2 0
5f9 604 603 :2 0
3b :3 0 15 :3 0
16 :2 0 353 606
609 49 :3 0 8e
:2 0 91 :3 0 60b
60d 0 358 60c
60f :3 0 610 :2 0
605 612 611 :2 0
3b :3 0 15 :3 0
16 :2 0 35b 614
617 49 :3 0 8e
:2 0 92 :3 0 619
61b 0 360 61a
61d :3 0 61e :2 0
613 620 61f :2 0
3b :3 0 58 :3 0
59 :3 0 17 :3 0
1b :3 0 5a :3 0
5b :3 0 3 :4 0
93 1 :8 0 630
9 :3 0 5d :3 0
62b 62c 0 5e
:3 0 62d 62e 0
630 363 683 5f
:3 0 9 :3 0 5d
:3 0 632 633 0
5e :3 0 634 635
0 637 366 639
368 638 637 :2 0
681 60 :3 0 9
:3 0 5d :3 0 63c
63d 0 5e :3 0
63e 63f 0 679
2e :3 0 2f :3 0
641 642 0 2e
:3 0 3f :3 0 644
645 0 61 :2 0
2 :4 0 94 :2 0
41 :2 0 14 :2 0
36a 64a 64c :3 0
36d 646 64e 643
650 64f :2 0 31
:3 0 42 :3 0 652
653 0 33 :4 0
95 :4 0 36 :2 0
37 :3 0 371 657
659 :3 0 36 :2 0
47 :4 0 374 65b
65d :3 0 36 :2 0
64 :4 0 377 65f
661 :3 0 36 :2 0
5e :3 0 37a 663
665 :3 0 36 :2 0
65 :4 0 37d 667
669 :3 0 36 :2 0
66 :3 0 67 :3 0
14 :2 0 68 :2 0
380 66c 670 384
66b 672 :3 0 387
654 674 :2 0 676
38a 677 651 676
0 678 38c 0
679 38e 67c :3 0
67c 0 67c 67b
679 67a :6 0 67e
e :3 0 391 680
393 67f 67e :2 0
681 395 :2 0 683
0 683 682 630
681 :6 0 6ff 1
:3 0 9 :3 0 5d
:3 0 685 686 0
9 :3 0 51 :2 0
69 :3 0 688 68a
0 39a 689 68c
:3 0 68d :2 0 2e
:3 0 2f :3 0 68f
690 0 2e :3 0
3f :3 0 692 693
0 e :2 0 2
:4 0 96 :2 0 41
:2 0 14 :2 0 39d
698 69a :3 0 3a0
694 69c 691 69e
69d :2 0 31 :3 0
42 :3 0 6a0 6a1
0 33 :4 0 97
:4 0 36 :2 0 37
:3 0 3a4 6a5 6a7
:3 0 36 :2 0 47
:4 0 3a7 6a9 6ab
:3 0 36 :2 0 48
:4 0 3aa 6ad 6af
:3 0 36 :2 0 3b
:3 0 3c :3 0 49
:3 0 4a :3 0 6b4
6b5 0 3ad 6b3
6b7 3d :4 0 3af
6b2 6ba 3b2 6b1
6bc :3 0 36 :2 0
4b :4 0 3b5 6be
6c0 :3 0 36 :2 0
39 :4 0 3b8 6c2
6c4 :3 0 36 :2 0
3 :3 0 3bb 6c6
6c8 :3 0 36 :2 0
39 :4 0 3be 6ca
6cc :3 0 3c1 6a2
6ce :2 0 6d0 3c4
6d1 69f 6d0 0
6d2 3c6 0 6fc
2e :3 0 2f :3 0
6d3 6d4 0 2e
:3 0 3f :3 0 6d6
6d7 0 14 :2 0
2 :4 0 98 :2 0
41 :2 0 14 :2 0
3c8 6dc 6de :3 0
3cb 6d8 6e0 6d5
6e2 6e1 :2 0 31
:3 0 42 :3 0 6e4
6e5 0 33 :4 0
99 :4 0 36 :2 0
37 :3 0 3cf 6e9
6eb :3 0 3d2 6e6
6ed :2 0 6ef 3d5
6f0 6e3 6ef 0
6f1 3d7 0 6fc
4e :3 0 4f :3 0
6f2 6f3 0 49
:3 0 4a :3 0 6f5
6f6 0 3 :3 0
50 :3 0 3d9 6f4
6fa :2 0 6fc 3dd
6fd 68e 6fc 0
6fe 3e1 0 6ff
3e3 700 621 6ff
0 702 1e3 3bb
0 702 3e6 0
23b3 3b :3 0 15
:3 0 16 :2 0 3eb
703 706 51 :2 0
16 :2 0 3f0 708
70a :3 0 9a :3 0
9b :3 0 9c :4 0
70e :4 0 70f :2 0
987 9 :3 0 5d
:3 0 711 712 0
16 :2 0 713 714
0 987 9d :3 0
9e :3 0 9f :3 0
a0 :3 0 a1 :3 0
a2 :3 0 a3 :3 0
a4 :3 0 57 :3 0
9e :3 0 a5 :3 0
9f :3 0 a5 :3 0
a0 :3 0 a5 :3 0
a1 :3 0 a5 :3 0
a2 :3 0 a5 :3 0
a3 :3 0 a5 :3 0
a4 :3 0 a6 :3 0
57 :3 0 a7 :3 0
a8 :3 0 a5 :3 0
57 :3 0 9e :3 0
a5 :3 0 9e :3 0
55 :3 0 d :3 0
a9 :4 0 aa 1
:8 0 74e ab :4 0
739 :3 0 50 :3 0
51 :2 0 3f5 73c
73d :3 0 9 :3 0
5d :3 0 73f 740
0 16 :2 0 741
742 0 744 3f8
74b 9 :3 0 5d
:3 0 745 746 0
ac :2 0 747 748
0 74a 3fa 74c
73e 744 0 74d
0 74a 0 74d
3fc 0 74e 3ff
7a1 5f :3 0 9
:3 0 5d :3 0 750
751 0 5e :3 0
752 753 0 755
402 757 404 756
755 :2 0 79f 60
:3 0 9 :3 0 5d
:3 0 75a 75b 0
5e :3 0 75c 75d
0 797 2e :3 0
2f :3 0 75f 760
0 2e :3 0 3f
:3 0 762 763 0
61 :2 0 2 :4 0
ad :2 0 41 :2 0
14 :2 0 406 768
76a :3 0 409 764
76c 761 76e 76d
:2 0 31 :3 0 42
:3 0 770 771 0
33 :4 0 ae :4 0
36 :2 0 37 :3 0
40d 775 777 :3 0
36 :2 0 47 :4 0
410 779 77b :3 0
36 :2 0 64 :4 0
413 77d 77f :3 0
36 :2 0 5e :3 0
416 781 783 :3 0
36 :2 0 65 :4 0
419 785 787 :3 0
36 :2 0 66 :3 0
67 :3 0 14 :2 0
68 :2 0 41c 78a
78e 420 789 790
:3 0 423 772 792
:2 0 794 426 795
76f 794 0 796
428 0 797 42a
79a :3 0 79a 0
79a 799 797 798
:6 0 79c 10 :3 0
42d 79e 42f 79d
79c :2 0 79f 431
:2 0 7a1 0 7a1
7a0 74e 79f :6 0
987 1 :3 0 9a
:3 0 9b :3 0 af
:4 0 7a5 :4 0 7a6
:2 0 987 9 :3 0
5d :3 0 7a8 7a9
0 16 :2 0 7aa
7ab 0 987 b0
:3 0 b1 :3 0 9e
:3 0 a6 :3 0 55
:3 0 d :3 0 a9
:4 0 b2 1 :8 0
7ca ab :4 0 7b5
:3 0 50 :3 0 51
:2 0 436 7b8 7b9
:3 0 9 :3 0 5d
:3 0 7bb 7bc 0
16 :2 0 7bd 7be
0 7c0 439 7c7
9 :3 0 5d :3 0
7c1 7c2 0 ac
:2 0 7c3 7c4 0
7c6 43b 7c8 7ba
7c0 0 7c9 0
7c6 0 7c9 43d
0 7ca 440 81d
5f :3 0 9 :3 0
5d :3 0 7cc 7cd
0 5e :3 0 7ce
7cf 0 7d1 443
7d3 445 7d2 7d1
:2 0 81b 60 :3 0
9 :3 0 5d :3 0
7d6 7d7 0 5e
:3 0 7d8 7d9 0
813 2e :3 0 2f
:3 0 7db 7dc 0
2e :3 0 3f :3 0
7de 7df 0 61
:2 0 2 :4 0 b3
:2 0 41 :2 0 14
:2 0 447 7e4 7e6
:3 0 44a 7e0 7e8
7dd 7ea 7e9 :2 0
31 :3 0 42 :3 0
7ec 7ed 0 33
:4 0 b4 :4 0 36
:2 0 37 :3 0 44e
7f1 7f3 :3 0 36
:2 0 47 :4 0 451
7f5 7f7 :3 0 36
:2 0 64 :4 0 454
7f9 7fb :3 0 36
:2 0 5e :3 0 457
7fd 7ff :3 0 36
:2 0 65 :4 0 45a
801 803 :3 0 36
:2 0 66 :3 0 67
:3 0 14 :2 0 68
:2 0 45d 806 80a
461 805 80c :3 0
464 7ee 80e :2 0
810 467 811 7eb
810 0 812 469
0 813 46b 816
:3 0 816 0 816
815 813 814 :6 0
818 12 :3 0 46e
81a 470 819 818
:2 0 81b 472 :2 0
81d 0 81d 81c
7ca 81b :6 0 987
1 :3 0 b5 :3 0
1e :3 0 78 :3 0
b6 :3 0 b6 :3 0
55 :3 0 d :3 0
b6 :3 0 9e :3 0
b7 :3 0 9e :3 0
b8 :3 0 b7 :3 0
9e :3 0 b9 :3 0
ba :3 0 bb :3 0
b9 :3 0 bc :3 0
b9 :3 0 bd :3 0
be :3 0 56 :3 0
be :3 0 bb :3 0
bf :3 0 b7 :3 0
a1 :3 0 b7 :3 0
a2 :3 0 b7 :3 0
a3 :3 0 b7 :3 0
a4 :3 0 c0 :3 0
c1 :3 0 c2 :3 0
c1 :3 0 c3 :3 0
c1 :3 0 c4 :3 0
c1 :3 0 c5 :3 0
c6 :3 0 85 :3 0
b9 :3 0 c7 :3 0
c8 :3 0 b9 :3 0
c9 :3 0 b9 :3 0
ca :3 0 b9 :3 0
cb :3 0 9d :3 0
b7 :3 0 a7 :3 0
cc :3 0 b9 :3 0
b7 :3 0 9e :3 0
b9 :3 0 9e :3 0
a7 :3 0 a8 :3 0
cd :3 0 cd :3 0
5b :3 0 b7 :3 0
9f :3 0 a7 :3 0
a8 :3 0 be :3 0
be :3 0 5b :3 0
cd :3 0 9f :3 0
ce :3 0 cf :3 0
a7 :3 0 d0 :3 0
c1 :3 0 c1 :3 0
a0 :3 0 b7 :3 0
a0 :3 0 b8 :3 0
d1 :3 0 b1 :3 0
9e :3 0 b9 :3 0
d2 :3 0 bb :3 0
bc :3 0 bd :3 0
cd :3 0 56 :3 0
cd :3 0 bb :3 0
bf :3 0 a5 :3 0
a1 :3 0 a5 :3 0
a2 :3 0 a5 :3 0
a3 :3 0 a5 :3 0
a4 :3 0 c0 :3 0
c1 :3 0 c2 :3 0
c1 :3 0 c3 :3 0
c1 :3 0 c4 :3 0
c1 :3 0 c5 :3 0
c6 :3 0 85 :3 0
c8 :3 0 c9 :3 0
ca :3 0 cb :3 0
b0 :3 0 d1 :3 0
a7 :3 0 d3 :3 0
b9 :3 0 d1 :3 0
b1 :3 0 b9 :3 0
b1 :3 0 ce :3 0
cf :3 0 a7 :3 0
a8 :3 0 a5 :3 0
b9 :3 0 d4 :3 0
a5 :3 0 5b :3 0
ce :3 0 cf :3 0
a7 :3 0 a8 :3 0
cd :3 0 cd :3 0
5b :3 0 a5 :3 0
9f :3 0 ce :3 0
cf :3 0 a7 :3 0
d0 :3 0 c1 :3 0
c1 :3 0 a0 :3 0
a5 :3 0 a0 :3 0
b8 :3 0 d1 :3 0
b1 :3 0 9e :3 0
b9 :3 0 d2 :3 0
bb :3 0 bc :3 0
bd :3 0 cd :3 0
56 :3 0 cd :3 0
bb :3 0 bf :3 0
a5 :3 0 a1 :3 0
a5 :3 0 a2 :3 0
a5 :3 0 a3 :3 0
a5 :3 0 a4 :3 0
c0 :3 0 c1 :3 0
c2 :3 0 c1 :3 0
c3 :3 0 c1 :3 0
c4 :3 0 c1 :3 0
c5 :3 0 c6 :3 0
85 :3 0 c8 :3 0
c9 :3 0 ca :3 0
cb :3 0 b0 :3 0
d1 :3 0 a7 :3 0
d3 :3 0 b9 :3 0
d1 :3 0 b1 :3 0
b9 :3 0 b1 :3 0
a7 :3 0 d5 :3 0
d6 :3 0 b9 :3 0
b1 :3 0 d6 :3 0
d7 :3 0 ce :3 0
cf :3 0 a7 :3 0
a8 :3 0 a5 :3 0
d6 :3 0 d8 :3 0
a5 :3 0 5b :3 0
ce :3 0 cf :3 0
a7 :3 0 a8 :3 0
cd :3 0 cd :3 0
5b :3 0 a5 :3 0
9f :3 0 ce :3 0
cf :3 0 a7 :3 0
d0 :3 0 c1 :3 0
c1 :3 0 a0 :3 0
a5 :3 0 a0 :3 0
b8 :3 0 d1 :3 0
b1 :3 0 9e :3 0
b9 :3 0 d2 :3 0
bb :3 0 bc :3 0
bd :3 0 cd :3 0
56 :3 0 cd :3 0
bb :3 0 bf :3 0
a5 :3 0 a1 :3 0
a5 :3 0 a2 :3 0
a5 :3 0 a3 :3 0
a5 :3 0 a4 :3 0
c0 :3 0 c1 :3 0
c2 :3 0 c1 :3 0
c3 :3 0 c1 :3 0
c4 :3 0 c1 :3 0
c5 :3 0 c6 :3 0
85 :3 0 c8 :3 0
c9 :3 0 ca :3 0
cb :3 0 b0 :3 0
d1 :3 0 a7 :3 0
d3 :3 0 b9 :3 0
d1 :3 0 b1 :3 0
b9 :3 0 b1 :3 0
a7 :3 0 d9 :3 0
d6 :3 0 b9 :3 0
b1 :3 0 d6 :3 0
d7 :3 0 ce :3 0
cf :3 0 a7 :3 0
a8 :3 0 a5 :3 0
d6 :3 0 d4 :3 0
a5 :3 0 5b :3 0
ce :3 0 cf :3 0
a7 :3 0 a8 :3 0
cd :3 0 cd :3 0
5b :3 0 a5 :3 0
9f :3 0 ce :3 0
cf :3 0 a7 :3 0
d0 :3 0 c1 :3 0
c1 :3 0 a0 :3 0
a5 :3 0 a0 :3 0
b8 :3 0 9e :3 0
56 :4 0 da 1
:a 0 963 :2 0 987
820 961 :2 0 2e
:3 0 2f :3 0 964
965 0 2e :3 0
3f :3 0 967 968
0 14 :2 0 2
:4 0 db :2 0 41
:2 0 14 :2 0 475
96d 96f :3 0 478
969 971 966 973
972 :2 0 31 :3 0
42 :3 0 975 976
0 33 :4 0 dc
:4 0 36 :2 0 37
:3 0 47c 97a 97c
:3 0 47f 977 97e
:2 0 980 482 981
974 980 0 982
484 0 987 8
:3 0 1e :3 0 984
:2 0 987 76 :3 0
486 23b0 3b :3 0
15 :3 0 16 :2 0
490 988 98b 51
:2 0 14 :2 0 495
98d 98f :3 0 990
:2 0 3b :3 0 15
:3 0 16 :2 0 498
992 995 51 :2 0
dd :2 0 49d 997
999 :3 0 99a :2 0
991 99c 99b :2 0
9a :3 0 9b :3 0
de :4 0 9a0 :4 0
9a1 :2 0 b55 9
:3 0 5d :3 0 9a3
9a4 0 16 :2 0
9a5 9a6 0 b55
df :3 0 9e :3 0
56 :3 0 e0 :3 0
9e :3 0 b6 :3 0
79 :3 0 56 :3 0
a6 :3 0 e0 :3 0
ce :3 0 cf :3 0
a7 :3 0 78 :3 0
b6 :3 0 b6 :3 0
55 :3 0 d :3 0
e0 :3 0 9e :3 0
b6 :3 0 9e :3 0
e0 :3 0 55 :3 0
d :3 0 e0 :3 0
a9 :3 0 b6 :3 0
e1 :3 0 78 :3 0
e2 :3 0 e0 :3 0
9e :3 0 e2 :3 0
9e :3 0 e2 :3 0
e3 :3 0 d :4 0
e4 1 :8 0 9e4
ab :4 0 9cf :3 0
50 :3 0 51 :2 0
4a2 9d2 9d3 :3 0
9 :3 0 5d :3 0
9d5 9d6 0 16
:2 0 9d7 9d8 0
9da 4a5 9e1 9
:3 0 5d :3 0 9db
9dc 0 ac :2 0
9dd 9de 0 9e0
4a7 9e2 9d4 9da
0 9e3 0 9e0
0 9e3 4a9 0
9e4 4ac a37 5f
:3 0 9 :3 0 5d
:3 0 9e6 9e7 0
5e :3 0 9e8 9e9
0 9eb 4af 9ed
4b1 9ec 9eb :2 0
a35 60 :3 0 9
:3 0 5d :3 0 9f0
9f1 0 5e :3 0
9f2 9f3 0 a2d
2e :3 0 2f :3 0
9f5 9f6 0 2e
:3 0 3f :3 0 9f8
9f9 0 61 :2 0
2 :4 0 e5 :2 0
41 :2 0 14 :2 0
4b3 9fe a00 :3 0
4b6 9fa a02 9f7
a04 a03 :2 0 31
:3 0 42 :3 0 a06
a07 0 33 :4 0
e6 :4 0 36 :2 0
37 :3 0 4ba a0b
a0d :3 0 36 :2 0
47 :4 0 4bd a0f
a11 :3 0 36 :2 0
64 :4 0 4c0 a13
a15 :3 0 36 :2 0
5e :3 0 4c3 a17
a19 :3 0 36 :2 0
65 :4 0 4c6 a1b
a1d :3 0 36 :2 0
66 :3 0 67 :3 0
14 :2 0 68 :2 0
4c9 a20 a24 4cd
a1f a26 :3 0 4d0
a08 a28 :2 0 a2a
4d3 a2b a05 a2a
0 a2c 4d5 0
a2d 4d7 a30 :3 0
a30 0 a30 a2f
a2d a2e :6 0 a32
14 :3 0 4da a34
4dc a33 a32 :2 0
a35 4de :2 0 a37
0 a37 a36 9e4
a35 :6 0 b55 1
:3 0 9 :3 0 5d
:3 0 a39 a3a 0
e7 :4 0 a3c a3d
:3 0 a3b a3e 0
b55 e8 :3 0 5b
:3 0 bb :3 0 a5
:3 0 b1 :3 0 a5
:3 0 d2 :3 0 a6
:3 0 57 :3 0 a7
:3 0 d3 :3 0 a5
:3 0 57 :3 0 a9
:3 0 a5 :3 0 b1
:3 0 57 :3 0 9e
:3 0 a7 :3 0 a8
:3 0 cd :3 0 cd
:3 0 5b :3 0 a5
:3 0 d4 :3 0 a7
:3 0 a8 :3 0 be
:3 0 be :3 0 5b
:3 0 cd :3 0 9f
:3 0 a7 :3 0 78
:3 0 e2 :3 0 e2
:3 0 d7 :3 0 57
:3 0 d7 :3 0 e2
:3 0 e1 :3 0 57
:3 0 55 :3 0 d
:3 0 57 :3 0 e9
:4 0 ea 1 :8 0
a84 ab :4 0 a6f
:3 0 50 :3 0 51
:2 0 4e3 a72 a73
:3 0 9 :3 0 5d
:3 0 a75 a76 0
16 :2 0 a77 a78
0 a7a 4e6 a81
9 :3 0 5d :3 0
a7b a7c 0 ac
:2 0 a7d a7e 0
a80 4e8 a82 a74
a7a 0 a83 0
a80 0 a83 4ea
0 a84 4ed ad7
5f :3 0 9 :3 0
5d :3 0 a86 a87
0 5e :3 0 a88
a89 0 a8b 4f0
a8d 4f2 a8c a8b
:2 0 ad5 60 :3 0
9 :3 0 5d :3 0
a90 a91 0 5e
:3 0 a92 a93 0
acd 2e :3 0 2f
:3 0 a95 a96 0
2e :3 0 3f :3 0
a98 a99 0 61
:2 0 2 :4 0 eb
:2 0 41 :2 0 14
:2 0 4f4 a9e aa0
:3 0 4f7 a9a aa2
a97 aa4 aa3 :2 0
31 :3 0 42 :3 0
aa6 aa7 0 33
:4 0 ec :4 0 36
:2 0 37 :3 0 4fb
aab aad :3 0 36
:2 0 47 :4 0 4fe
aaf ab1 :3 0 36
:2 0 64 :4 0 501
ab3 ab5 :3 0 36
:2 0 5e :3 0 504
ab7 ab9 :3 0 36
:2 0 65 :4 0 507
abb abd :3 0 36
:2 0 66 :3 0 67
:3 0 14 :2 0 68
:2 0 50a ac0 ac4
50e abf ac6 :3 0
511 aa8 ac8 :2 0
aca 514 acb aa5
aca 0 acc 516
0 acd 518 ad0
:3 0 ad0 0 ad0
acf acd ace :6 0
ad2 16 :3 0 51b
ad4 51d ad3 ad2
:2 0 ad5 51f :2 0
ad7 0 ad7 ad6
a84 ad5 :6 0 b55
1 :3 0 b5 :3 0
1f :3 0 57 :3 0
9e :3 0 5b :3 0
d7 :3 0 b9 :3 0
ba :3 0 bb :3 0
57 :3 0 56 :3 0
b9 :3 0 bd :3 0
ed :3 0 ee :3 0
ed :3 0 ef :3 0
f0 :3 0 ed :3 0
f1 :3 0 ed :3 0
f2 :3 0 f3 :3 0
f4 :3 0 f5 :3 0
17 :3 0 58 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 fb :3 0
c6 :3 0 85 :3 0
b9 :3 0 c7 :3 0
c8 :3 0 b9 :3 0
c9 :3 0 b9 :3 0
ca :3 0 b9 :3 0
cb :3 0 df :3 0
57 :3 0 a7 :3 0
cc :3 0 b9 :3 0
57 :3 0 9e :3 0
b9 :3 0 9e :3 0
5b :3 0 d7 :3 0
bb :3 0 56 :3 0
bd :3 0 ed :3 0
ee :3 0 ed :3 0
ef :3 0 f0 :3 0
ed :3 0 f1 :3 0
ed :3 0 f2 :3 0
f3 :3 0 f4 :3 0
f5 :3 0 17 :3 0
58 :3 0 f6 :3 0
f7 :3 0 f8 :3 0
f9 :3 0 fa :3 0
fb :3 0 c6 :3 0
85 :3 0 c8 :3 0
c9 :3 0 ca :3 0
cb :3 0 e8 :3 0
56 :4 0 fc 1
:a 0 b31 :2 0 b55
ada b2f :2 0 2e
:3 0 2f :3 0 b32
b33 0 2e :3 0
3f :3 0 b35 b36
0 14 :2 0 2
:4 0 fd :2 0 41
:2 0 14 :2 0 522
b3b b3d :3 0 525
b37 b3f b34 b41
b40 :2 0 31 :3 0
42 :3 0 b43 b44
0 33 :4 0 fe
:4 0 36 :2 0 37
:3 0 529 b48 b4a
:3 0 52c b45 b4c
:2 0 b4e 52f b4f
b42 b4e 0 b50
531 0 b55 8
:3 0 1f :3 0 b52
:2 0 b55 76 :3 0
533 b56 99d b55
0 23b2 3b :3 0
15 :3 0 16 :2 0
53c b57 b5a 51
:2 0 52 :2 0 541
b5c b5e :3 0 b5
:3 0 20 :3 0 e2
:3 0 79 :3 0 e2
:3 0 79 :3 0 57
:3 0 d7 :3 0 5b
:3 0 57 :3 0 b1
:3 0 b9 :3 0 d2
:3 0 bb :3 0 56
:3 0 57 :3 0 d7
:3 0 57 :3 0 ff
:3 0 e2 :3 0 ee
:3 0 e2 :3 0 ef
:3 0 e2 :3 0 f9
:3 0 e2 :3 0 100
:3 0 e2 :3 0 101
:3 0 17 :3 0 58
:3 0 57 :3 0 ca
:3 0 57 :3 0 102
:3 0 103 :3 0 bb
:3 0 104 :3 0 3b
:3 0 57 :3 0 105
:3 0 57 :3 0 102
:3 0 105 :3 0 106
:3 0 bb :3 0 107
:3 0 e2 :3 0 c2
:3 0 e2 :3 0 108
:3 0 e2 :3 0 c4
:3 0 e2 :3 0 109
:3 0 10a :3 0 57
:3 0 10b :3 0 e2
:3 0 fb :3 0 e2
:3 0 e1 :3 0 e2
:3 0 10c :3 0 10d
:3 0 bb :3 0 10e
:3 0 e2 :3 0 f5
:3 0 e2 :3 0 10f
:3 0 e2 :3 0 110
:3 0 e2 :3 0 111
:3 0 e2 :3 0 112
:3 0 e2 :3 0 113
:3 0 114 :3 0 e2
:3 0 115 :3 0 a6
:3 0 57 :3 0 ce
:3 0 cf :3 0 a7
:3 0 78 :3 0 e2
:3 0 e2 :3 0 e3
:3 0 d :3 0 57
:3 0 d7 :3 0 e2
:3 0 d7 :3 0 ce
:3 0 cf :3 0 a7
:3 0 d3 :3 0 b9
:3 0 57 :3 0 9e
:3 0 b9 :3 0 b1
:3 0 ce :3 0 cf
:3 0 a7 :3 0 116
:3 0 103 :3 0 57
:3 0 102 :3 0 103
:3 0 5b :3 0 ce
:3 0 cf :3 0 a7
:3 0 116 :3 0 106
:3 0 3b :3 0 57
:3 0 105 :3 0 57
:3 0 102 :3 0 106
:3 0 5b :3 0 ce
:3 0 cf :3 0 a7
:3 0 117 :3 0 10d
:3 0 10d :3 0 5b
:3 0 e2 :3 0 10c
:3 0 57 :3 0 5b
:3 0 d :3 0 57
:3 0 a9 :3 0 bb
:4 0 118 1 :a 0
bef :2 0 c13 b61
bed :2 0 2e :3 0
2f :3 0 bf0 bf1
0 2e :3 0 3f
:3 0 bf3 bf4 0
14 :2 0 2 :4 0
119 :2 0 41 :2 0
14 :2 0 544 bf9
bfb :3 0 547 bf5
bfd bf2 bff bfe
:2 0 31 :3 0 42
:3 0 c01 c02 0
33 :4 0 11a :4 0
36 :2 0 37 :3 0
54b c06 c08 :3 0
54e c03 c0a :2 0
c0c 551 c0d c00
c0c 0 c0e 553
0 c13 8 :3 0
20 :3 0 c10 :2 0
c13 76 :3 0 555
c14 b5f c13 0
23b2 3b :3 0 15
:3 0 16 :2 0 559
c15 c18 51 :2 0
53 :2 0 55e c1a
c1c :3 0 1c :3 0
11b :4 0 c1e c1f
0 13ef 3b :3 0
11c :3 0 1d :3 0
11d :3 0 9f :3 0
5b :3 0 d :4 0
11e 1 :8 0 c2e
9 :3 0 5d :3 0
c29 c2a 0 5e
:3 0 c2b c2c 0
c2e 561 c81 5f
:3 0 9 :3 0 5d
:3 0 c30 c31 0
5e :3 0 c32 c33
0 c35 564 c37
566 c36 c35 :2 0
c7f 60 :3 0 9
:3 0 5d :3 0 c3a
c3b 0 5e :3 0
c3c c3d 0 c77
2e :3 0 2f :3 0
c3f c40 0 2e
:3 0 3f :3 0 c42
c43 0 61 :2 0
2 :4 0 68 :2 0
41 :2 0 14 :2 0
568 c48 c4a :3 0
56b c44 c4c c41
c4e c4d :2 0 31
:3 0 42 :3 0 c50
c51 0 33 :4 0
11f :4 0 36 :2 0
37 :3 0 56f c55
c57 :3 0 36 :2 0
47 :4 0 572 c59
c5b :3 0 36 :2 0
64 :4 0 575 c5d
c5f :3 0 36 :2 0
5e :3 0 578 c61
c63 :3 0 36 :2 0
65 :4 0 57b c65
c67 :3 0 36 :2 0
66 :3 0 67 :3 0
14 :2 0 68 :2 0
57e c6a c6e 582
c69 c70 :3 0 585
c52 c72 :2 0 c74
588 c75 c4f c74
0 c76 58a 0
c77 58c c7a :3 0
c7a 0 c7a c79
c77 c78 :6 0 c7c
18 :3 0 58f c7e
591 c7d c7c :2 0
c7f 593 :2 0 c81
0 c81 c80 c2e
c7f :6 0 13ef 1
:3 0 9 :3 0 5d
:3 0 c83 c84 0
9 :3 0 51 :2 0
69 :3 0 c86 c88
0 598 c87 c8a
:3 0 c8b :2 0 120
:3 0 121 :3 0 c8d
c8e 0 1d :3 0
11b :4 0 59b c8f
c92 51 :2 0 16
:2 0 5a0 c94 c96
:3 0 c97 :2 0 c8c
c99 c98 :2 0 3b
:3 0 11c :3 0 1d
:3 0 11d :3 0 9f
:3 0 5b :3 0 d
:4 0 122 1 :8 0
ca8 9 :3 0 5d
:3 0 ca3 ca4 0
5e :3 0 ca5 ca6
0 ca8 5a3 cfb
5f :3 0 9 :3 0
5d :3 0 caa cab
0 5e :3 0 cac
cad 0 caf 5a6
cb1 5a8 cb0 caf
:2 0 cf9 60 :3 0
9 :3 0 5d :3 0
cb4 cb5 0 5e
:3 0 cb6 cb7 0
cf1 2e :3 0 2f
:3 0 cb9 cba 0
2e :3 0 3f :3 0
cbc cbd 0 61
:2 0 2 :4 0 123
:2 0 41 :2 0 14
:2 0 5aa cc2 cc4
:3 0 5ad cbe cc6
cbb cc8 cc7 :2 0
31 :3 0 42 :3 0
cca ccb 0 33
:4 0 124 :4 0 36
:2 0 37 :3 0 5b1
ccf cd1 :3 0 36
:2 0 47 :4 0 5b4
cd3 cd5 :3 0 36
:2 0 64 :4 0 5b7
cd7 cd9 :3 0 36
:2 0 5e :3 0 5ba
cdb cdd :3 0 36
:2 0 65 :4 0 5bd
cdf ce1 :3 0 36
:2 0 66 :3 0 67
:3 0 14 :2 0 68
:2 0 5c0 ce4 ce8
5c4 ce3 cea :3 0
5c7 ccc cec :2 0
cee 5ca cef cc9
cee 0 cf0 5cc
0 cf1 5ce cf4
:3 0 cf4 0 cf4
cf3 cf1 cf2 :6 0
cf6 1a :3 0 5d1
cf8 5d3 cf7 cf6
:2 0 cf9 5d5 :2 0
cfb 0 cfb cfa
ca8 cf9 :6 0 d7d
1 :3 0 9 :3 0
5d :3 0 cfd cfe
0 9 :3 0 51
:2 0 69 :3 0 d00
d02 0 5da d01
d04 :3 0 d05 :2 0
120 :3 0 121 :3 0
d07 d08 0 1d
:3 0 11b :4 0 5dd
d09 d0c 51 :2 0
16 :2 0 5e2 d0e
d10 :3 0 d11 :2 0
d06 d13 d12 :2 0
1c :3 0 11b :4 0
d15 d16 0 d18
5e5 d7a 9e :3 0
1c :3 0 cc :3 0
c7 :3 0 1d :4 0
125 1 :8 0 d24
9 :3 0 5d :3 0
d1f d20 0 5e
:3 0 d21 d22 0
d24 5e7 d77 5f
:3 0 9 :3 0 5d
:3 0 d26 d27 0
5e :3 0 d28 d29
0 d2b 5ea d2d
5ec d2c d2b :2 0
d75 60 :3 0 9
:3 0 5d :3 0 d30
d31 0 5e :3 0
d32 d33 0 d6d
2e :3 0 2f :3 0
d35 d36 0 2e
:3 0 3f :3 0 d38
d39 0 61 :2 0
2 :4 0 126 :2 0
41 :2 0 14 :2 0
5ee d3e d40 :3 0
5f1 d3a d42 d37
d44 d43 :2 0 31
:3 0 42 :3 0 d46
d47 0 33 :4 0
127 :4 0 36 :2 0
37 :3 0 5f5 d4b
d4d :3 0 36 :2 0
47 :4 0 5f8 d4f
d51 :3 0 36 :2 0
64 :4 0 5fb d53
d55 :3 0 36 :2 0
5e :3 0 5fe d57
d59 :3 0 36 :2 0
65 :4 0 601 d5b
d5d :3 0 36 :2 0
66 :3 0 67 :3 0
14 :2 0 68 :2 0
604 d60 d64 608
d5f d66 :3 0 60b
d48 d68 :2 0 d6a
60e d6b d45 d6a
0 d6c 610 0
d6d 612 d70 :3 0
d70 0 d70 d6f
d6d d6e :6 0 d72
1c :3 0 615 d74
617 d73 d72 :2 0
d75 619 :2 0 d77
0 d77 d76 d24
d75 :6 0 d79 1
:3 0 61c d7b d14
d18 0 d7c 0
d79 0 d7c 61e
0 d7d 621 ddf
9e :3 0 1c :3 0
cc :3 0 c7 :3 0
1d :4 0 128 1
:8 0 d89 9 :3 0
5d :3 0 d84 d85
0 5e :3 0 d86
d87 0 d89 624
ddc 5f :3 0 9
:3 0 5d :3 0 d8b
d8c 0 5e :3 0
d8d d8e 0 d90
627 d92 629 d91
d90 :2 0 dda 60
:3 0 9 :3 0 5d
:3 0 d95 d96 0
5e :3 0 d97 d98
0 dd2 2e :3 0
2f :3 0 d9a d9b
0 2e :3 0 3f
:3 0 d9d d9e 0
61 :2 0 2 :4 0
129 :2 0 41 :2 0
14 :2 0 62b da3
da5 :3 0 62e d9f
da7 d9c da9 da8
:2 0 31 :3 0 42
:3 0 dab dac 0
33 :4 0 12a :4 0
36 :2 0 37 :3 0
632 db0 db2 :3 0
36 :2 0 47 :4 0
635 db4 db6 :3 0
36 :2 0 64 :4 0
638 db8 dba :3 0
36 :2 0 5e :3 0
63b dbc dbe :3 0
36 :2 0 65 :4 0
63e dc0 dc2 :3 0
36 :2 0 66 :3 0
67 :3 0 14 :2 0
68 :2 0 641 dc5
dc9 645 dc4 dcb
:3 0 648 dad dcd
:2 0 dcf 64b dd0
daa dcf 0 dd1
64d 0 dd2 64f
dd5 :3 0 dd5 0
dd5 dd4 dd2 dd3
:6 0 dd7 1e :3 0
652 dd9 654 dd8
dd7 :2 0 dda 656
:2 0 ddc 0 ddc
ddb d89 dda :6 0
dde 1 :3 0 659
de0 c9a d7d 0
de1 0 dde 0
de1 65b 0 13ef
12b :3 0 3b :3 0
18 :3 0 16 :2 0
65e de3 de6 661
de2 de8 8e :2 0
16 :2 0 665 dea
dec :3 0 19 :3 0
16 :2 0 dee def
0 121e 12c :3 0
19 :3 0 78 :3 0
55 :3 0 10 :3 0
e3 :3 0 d :4 0
12d 1 :8 0 dfe
9 :3 0 5d :3 0
df9 dfa 0 5e
:3 0 dfb dfc 0
dfe 668 e51 5f
:3 0 9 :3 0 5d
:3 0 e00 e01 0
5e :3 0 e02 e03
0 e05 66b e07
66d e06 e05 :2 0
e4f 60 :3 0 9
:3 0 5d :3 0 e0a
e0b 0 5e :3 0
e0c e0d 0 e47
2e :3 0 2f :3 0
e0f e10 0 2e
:3 0 3f :3 0 e12
e13 0 61 :2 0
2 :4 0 12e :2 0
41 :2 0 14 :2 0
66f e18 e1a :3 0
672 e14 e1c e11
e1e e1d :2 0 31
:3 0 42 :3 0 e20
e21 0 33 :4 0
12f :4 0 36 :2 0
37 :3 0 676 e25
e27 :3 0 36 :2 0
47 :4 0 679 e29
e2b :3 0 36 :2 0
64 :4 0 67c e2d
e2f :3 0 36 :2 0
5e :3 0 67f e31
e33 :3 0 36 :2 0
65 :4 0 682 e35
e37 :3 0 36 :2 0
66 :3 0 67 :3 0
14 :2 0 68 :2 0
685 e3a e3e 689
e39 e40 :3 0 68c
e22 e42 :2 0 e44
68f e45 e1f e44
0 e46 691 0
e47 693 e4a :3 0
e4a 0 e4a e49
e47 e48 :6 0 e4c
20 :3 0 696 e4e
698 e4d e4c :2 0
e4f 69a :2 0 e51
0 e51 e50 dfe
e4f :6 0 121e 1
:3 0 3b :3 0 19
:3 0 16 :2 0 69d
e53 e56 51 :2 0
16 :2 0 6a2 e58
e5a :3 0 13 :3 0
14 :4 0 e5c e5d
0 e5f 6a5 f64
19 :3 0 16 :2 0
e60 e61 0 f63
12c :3 0 19 :3 0
130 :3 0 78 :3 0
55 :3 0 10 :3 0
e3 :3 0 d :3 0
131 :4 0 132 1
:8 0 e72 9 :3 0
5d :3 0 e6d e6e
0 5e :3 0 e6f
e70 0 e72 6a7
ec5 5f :3 0 9
:3 0 5d :3 0 e74
e75 0 5e :3 0
e76 e77 0 e79
6aa e7b 6ac e7a
e79 :2 0 ec3 60
:3 0 9 :3 0 5d
:3 0 e7e e7f 0
5e :3 0 e80 e81
0 ebb 2e :3 0
2f :3 0 e83 e84
0 2e :3 0 3f
:3 0 e86 e87 0
61 :2 0 2 :4 0
133 :2 0 41 :2 0
14 :2 0 6ae e8c
e8e :3 0 6b1 e88
e90 e85 e92 e91
:2 0 31 :3 0 42
:3 0 e94 e95 0
33 :4 0 134 :4 0
36 :2 0 37 :3 0
6b5 e99 e9b :3 0
36 :2 0 47 :4 0
6b8 e9d e9f :3 0
36 :2 0 64 :4 0
6bb ea1 ea3 :3 0
36 :2 0 5e :3 0
6be ea5 ea7 :3 0
36 :2 0 65 :4 0
6c1 ea9 eab :3 0
36 :2 0 66 :3 0
67 :3 0 14 :2 0
68 :2 0 6c4 eae
eb2 6c8 ead eb4
:3 0 6cb e96 eb6
:2 0 eb8 6ce eb9
e93 eb8 0 eba
6d0 0 ebb 6d2
ebe :3 0 ebe 0
ebe ebd ebb ebc
:6 0 ec0 22 :3 0
6d5 ec2 6d7 ec1
ec0 :2 0 ec3 6d9
:2 0 ec5 0 ec5
ec4 e72 ec3 :6 0
f63 1 :3 0 3b
:3 0 19 :3 0 16
:2 0 6dc ec7 eca
51 :2 0 16 :2 0
6e1 ecc ece :3 0
12c :3 0 19 :3 0
130 :3 0 78 :3 0
b6 :3 0 a7 :3 0
135 :3 0 136 :3 0
136 :3 0 5b :3 0
b6 :3 0 55 :3 0
136 :3 0 9e :3 0
b6 :3 0 9e :3 0
b6 :3 0 55 :3 0
10 :3 0 b6 :3 0
e3 :3 0 d :3 0
137 :3 0 66 :3 0
b6 :3 0 138 :3 0
136 :3 0 139 :4 0
13a 1 :8 0 ef2
9 :3 0 5d :3 0
eed eee 0 5e
:3 0 eef ef0 0
ef2 6e4 f45 5f
:3 0 9 :3 0 5d
:3 0 ef4 ef5 0
5e :3 0 ef6 ef7
0 ef9 6e7 efb
6e9 efa ef9 :2 0
f43 60 :3 0 9
:3 0 5d :3 0 efe
eff 0 5e :3 0
f00 f01 0 f3b
2e :3 0 2f :3 0
f03 f04 0 2e
:3 0 3f :3 0 f06
f07 0 61 :2 0
2 :4 0 13b :2 0
41 :2 0 14 :2 0
6eb f0c f0e :3 0
6ee f08 f10 f05
f12 f11 :2 0 31
:3 0 42 :3 0 f14
f15 0 33 :4 0
13c :4 0 36 :2 0
37 :3 0 6f2 f19
f1b :3 0 36 :2 0
47 :4 0 6f5 f1d
f1f :3 0 36 :2 0
64 :4 0 6f8 f21
f23 :3 0 36 :2 0
5e :3 0 6fb f25
f27 :3 0 36 :2 0
65 :4 0 6fe f29
f2b :3 0 36 :2 0
66 :3 0 67 :3 0
14 :2 0 68 :2 0
701 f2e f32 705
f2d f34 :3 0 708
f16 f36 :2 0 f38
70b f39 f13 f38
0 f3a 70d 0
f3b 70f f3e :3 0
f3e 0 f3e f3d
f3b f3c :6 0 f40
24 :3 0 712 f42
714 f41 f40 :2 0
f43 716 :2 0 f45
0 f45 f44 ef2
f43 :6 0 f5b 1
:3 0 3b :3 0 19
:3 0 16 :2 0 719
f47 f4a 51 :2 0
16 :2 0 71e f4c
f4e :3 0 13 :3 0
52 :4 0 f50 f51
0 f53 721 f58
13 :3 0 14 :4 0
f54 f55 0 f57
723 f59 f4f f53
0 f5a 0 f57
0 f5a 725 0
f5b 728 f60 13
:3 0 14 :4 0 f5c
f5d 0 f5f 72b
f61 ecf f5b 0
f62 0 f5f 0
f62 72d 0 f63
730 f65 e5b e5f
0 f66 0 f63
0 f66 734 0
121e b5 :3 0 21
:3 0 e2 :3 0 5b
:3 0 57 :3 0 9e
:3 0 e2 :3 0 bb
:3 0 e2 :3 0 56
:3 0 d7 :3 0 57
:3 0 ff :3 0 e2
:3 0 100 :3 0 e2
:3 0 101 :3 0 e2
:3 0 13d :3 0 e2
:3 0 13e :3 0 e2
:3 0 100 :3 0 ee
:3 0 e2 :3 0 101
:3 0 ef :3 0 e2
:3 0 13f :3 0 e2
:3 0 f0 :3 0 f9
:3 0 e2 :3 0 13f
:3 0 e2 :3 0 f0
:3 0 e2 :3 0 140
:3 0 f4 :3 0 141
:3 0 142 :3 0 e2
:3 0 143 :3 0 e2
:3 0 140 :3 0 144
:3 0 145 :3 0 e2
:3 0 140 :3 0 145
:3 0 e2 :3 0 13f
:3 0 e2 :3 0 f0
:3 0 146 :3 0 ed
:3 0 147 :3 0 ed
:3 0 148 :3 0 149
:3 0 e2 :3 0 14a
:3 0 e2 :3 0 14b
:3 0 e2 :3 0 14c
:3 0 e2 :3 0 138
:3 0 e2 :3 0 14d
:3 0 e2 :3 0 140
:3 0 14e :3 0 e2
:3 0 14f :3 0 e2
:3 0 150 :3 0 e2
:3 0 151 :3 0 152
:3 0 17 :3 0 58
:3 0 ca :3 0 102
:3 0 104 :3 0 105
:3 0 107 :3 0 c2
:3 0 108 :3 0 c4
:3 0 109 :3 0 10a
:3 0 e2 :3 0 10b
:3 0 153 :3 0 154
:3 0 fb :3 0 e2
:3 0 155 :3 0 e2
:3 0 156 :3 0 e2
:3 0 157 :3 0 158
:3 0 e1 :3 0 10c
:3 0 159 :3 0 f5
:3 0 10f :3 0 110
:3 0 111 :3 0 112
:3 0 113 :3 0 114
:3 0 e2 :3 0 15a
:3 0 15a :3 0 115
:3 0 13 :3 0 131
:3 0 15b :3 0 e2
:3 0 15c :3 0 e2
:3 0 15d :3 0 1b
:3 0 e2 :3 0 15e
:3 0 ed :3 0 15e
:3 0 1b :3 0 e2
:3 0 15f :3 0 ed
:3 0 15f :3 0 1b
:3 0 e2 :3 0 160
:3 0 161 :3 0 e2
:3 0 146 :3 0 162
:3 0 163 :3 0 164
:3 0 165 :3 0 166
:3 0 167 :3 0 168
:3 0 169 :3 0 16a
:3 0 16b :3 0 16c
:3 0 e2 :3 0 bb
:3 0 c8 :3 0 1c
:3 0 16d :3 0 1d
:3 0 16e :3 0 d
:3 0 16f :3 0 bd
:3 0 cb :3 0 c9
:3 0 d2 :3 0 e2
:3 0 170 :3 0 e2
:3 0 171 :3 0 e2
:3 0 172 :3 0 173
:3 0 5a :3 0 e2
:3 0 ce :3 0 a7
:3 0 a6 :3 0 57
:3 0 57 :3 0 5b
:3 0 e2 :3 0 5b
:3 0 57 :3 0 9e
:3 0 f :3 0 ce
:3 0 cf :3 0 a7
:3 0 116 :3 0 103
:3 0 57 :3 0 102
:3 0 103 :3 0 5b
:3 0 e2 :3 0 55
:3 0 10 :3 0 e2
:3 0 5b :3 0 d
:3 0 e2 :3 0 79
:3 0 e2 :3 0 79
:3 0 57 :3 0 d7
:3 0 5b :3 0 57
:3 0 9e :3 0 57
:3 0 a9 :3 0 b9
:3 0 d2 :3 0 d3
:3 0 b9 :3 0 57
:3 0 9e :3 0 b9
:3 0 b1 :3 0 a5
:3 0 ba :3 0 cc
:3 0 a5 :3 0 57
:3 0 9e :3 0 a5
:3 0 9e :3 0 bb
:3 0 57 :3 0 a9
:3 0 e2 :3 0 79
:3 0 56 :3 0 57
:3 0 d7 :3 0 57
:3 0 ff :3 0 e2
:3 0 100 :3 0 3b
:3 0 ef :3 0 174
:3 0 101 :3 0 e2
:3 0 13d :3 0 49
:3 0 175 :3 0 e2
:3 0 13d :3 0 49
:3 0 176 :3 0 49
:3 0 177 :3 0 e2
:3 0 13d :3 0 13d
:3 0 e2 :3 0 13e
:3 0 49 :3 0 178
:3 0 49 :3 0 179
:3 0 e2 :3 0 13e
:3 0 13e :3 0 3b
:3 0 ee :3 0 17a
:3 0 ee :3 0 3b
:3 0 ef :3 0 174
:3 0 ef :3 0 e2
:3 0 131 :3 0 e2
:3 0 17b :3 0 e2
:3 0 f9 :3 0 f9
:3 0 e2 :3 0 131
:3 0 e2 :3 0 17b
:3 0 e2 :3 0 140
:3 0 e2 :3 0 f9
:3 0 f4 :3 0 e2
:3 0 17c :3 0 e2
:3 0 17d :3 0 e2
:3 0 17c :3 0 e2
:3 0 17d :3 0 141
:3 0 e2 :3 0 17e
:3 0 142 :3 0 143
:3 0 e2 :3 0 140
:3 0 144 :3 0 145
:3 0 e2 :3 0 140
:3 0 145 :3 0 f9
:3 0 17b :3 0 146
:3 0 e2 :3 0 147
:3 0 e2 :3 0 148
:3 0 e2 :3 0 149
:3 0 e2 :3 0 14a
:3 0 e2 :3 0 14b
:3 0 e2 :3 0 14c
:3 0 e2 :3 0 138
:3 0 e2 :3 0 14d
:3 0 e2 :3 0 140
:3 0 14e :3 0 14f
:3 0 150 :3 0 152
:3 0 17 :3 0 58
:3 0 57 :3 0 a9
:3 0 57 :3 0 ca
:3 0 a5 :3 0 ca
:3 0 cc :3 0 a5
:3 0 57 :3 0 9e
:3 0 a5 :3 0 9e
:3 0 ca :3 0 57
:3 0 102 :3 0 103
:3 0 bb :3 0 104
:3 0 3b :3 0 57
:3 0 105 :3 0 57
:3 0 102 :3 0 105
:3 0 106 :3 0 bb
:3 0 107 :3 0 e2
:3 0 c2 :3 0 e2
:3 0 108 :3 0 e2
:3 0 c4 :3 0 e2
:3 0 109 :3 0 57
:3 0 a9 :3 0 a5
:3 0 10a :3 0 cc
:3 0 a5 :3 0 57
:3 0 9e :3 0 a5
:3 0 9e :3 0 10a
:3 0 57 :3 0 10b
:3 0 e2 :3 0 fb
:3 0 e2 :3 0 155
:3 0 e2 :3 0 156
:3 0 e2 :3 0 158
:3 0 e2 :3 0 e1
:3 0 e2 :3 0 10c
:3 0 10d :3 0 bb
:3 0 159 :3 0 e2
:3 0 f5 :3 0 e2
:3 0 10f :3 0 e2
:3 0 110 :3 0 e2
:3 0 111 :3 0 e2
:3 0 112 :3 0 e2
:3 0 113 :3 0 e2
:3 0 114 :3 0 e2
:3 0 15a :3 0 e2
:3 0 115 :3 0 e2
:3 0 131 :3 0 e2
:3 0 131 :3 0 131
:3 0 e2 :3 0 15b
:3 0 15c :3 0 e2
:3 0 131 :3 0 e2
:3 0 17f :3 0 e2
:3 0 180 :3 0 15d
:3 0 1b :3 0 3b
:3 0 e2 :3 0 15e
:3 0 e2 :3 0 181
:3 0 ed :3 0 15e
:3 0 1b :3 0 3b
:3 0 e2 :3 0 15f
:3 0 e2 :3 0 182
:3 0 ed :3 0 15f
:3 0 1b :3 0 e2
:3 0 161 :3 0 e2
:3 0 14c :3 0 e2
:3 0 161 :3 0 161
:3 0 e2 :3 0 143
:3 0 162 :3 0 163
:3 0 164 :3 0 e2
:3 0 165 :3 0 183
:3 0 bb :3 0 166
:3 0 e2 :3 0 167
:3 0 184 :3 0 bb
:3 0 168 :3 0 e2
:3 0 169 :3 0 e2
:3 0 16a :3 0 185
:3 0 bb :3 0 16b
:3 0 57 :3 0 a9
:3 0 a5 :3 0 16c
:3 0 cc :3 0 a5
:3 0 57 :3 0 9e
:3 0 a5 :3 0 9e
:3 0 16c :3 0 57
:3 0 a9 :3 0 b9
:3 0 d2 :3 0 d3
:3 0 b9 :3 0 57
:3 0 9e :3 0 b9
:3 0 b1 :3 0 a5
:3 0 c7 :3 0 cc
:3 0 a5 :3 0 57
:3 0 9e :3 0 a5
:3 0 9e :3 0 c8
:3 0 1c :3 0 16d
:3 0 1d :3 0 16e
:3 0 d :3 0 16f
:3 0 57 :3 0 a9
:3 0 a5 :3 0 bd
:3 0 cc :3 0 a5
:3 0 57 :3 0 9e
:3 0 a5 :3 0 9e
:3 0 bd :3 0 57
:3 0 a9 :3 0 a5
:3 0 cb :3 0 cc
:3 0 a5 :3 0 57
:3 0 9e :3 0 a5
:3 0 9e :3 0 cb
:3 0 57 :3 0 a9
:3 0 a5 :3 0 c9
:3 0 cc :3 0 a5
:3 0 57 :3 0 9e
:3 0 a5 :3 0 9e
:3 0 c9 :3 0 57
:3 0 a9 :3 0 b9
:3 0 d2 :3 0 57
:3 0 a9 :3 0 186
:3 0 d2 :3 0 d2
:3 0 e2 :3 0 170
:3 0 e2 :3 0 171
:3 0 e2 :3 0 173
:3 0 a6 :3 0 57
:3 0 ce :3 0 cf
:3 0 a7 :3 0 78
:3 0 e2 :3 0 57
:3 0 d7 :3 0 e2
:3 0 d7 :3 0 ce
:3 0 cf :3 0 a7
:3 0 d3 :3 0 b9
:3 0 b9 :3 0 b1
:3 0 57 :3 0 b1
:3 0 ce :3 0 cf
:3 0 a7 :3 0 d3
:3 0 186 :3 0 57
:3 0 9e :3 0 186
:3 0 b1 :3 0 ce
:3 0 cf :3 0 a7
:3 0 116 :3 0 103
:3 0 57 :3 0 102
:3 0 103 :3 0 5b
:3 0 ce :3 0 cf
:3 0 a7 :3 0 116
:3 0 106 :3 0 3b
:3 0 57 :3 0 105
:3 0 57 :3 0 102
:3 0 106 :3 0 5b
:3 0 ce :3 0 cf
:3 0 a7 :3 0 117
:3 0 10d :3 0 10d
:3 0 5b :3 0 e2
:3 0 10c :3 0 ce
:3 0 cf :3 0 a7
:3 0 187 :3 0 183
:3 0 183 :3 0 5b
:3 0 e2 :3 0 165
:3 0 ce :3 0 cf
:3 0 a7 :3 0 187
:3 0 184 :3 0 184
:3 0 5b :3 0 e2
:3 0 167 :3 0 ce
:3 0 cf :3 0 a7
:3 0 188 :3 0 185
:3 0 185 :3 0 5b
:3 0 e2 :3 0 16a
:3 0 57 :3 0 55
:3 0 10 :3 0 57
:3 0 5b :3 0 d
:3 0 57 :3 0 10b
:3 0 163 :3 0 bb
:4 0 189 1 :a 0
11fb :2 0 121e f68
11f9 :2 0 2e :3 0
2f :3 0 11fc 11fd
0 2e :3 0 3f
:3 0 11ff 1200 0
14 :2 0 2 :4 0
18a :2 0 41 :2 0
14 :2 0 737 1205
1207 :3 0 73a 1201
1209 11fe 120b 120a
:2 0 31 :3 0 42
:3 0 120d 120e 0
33 :4 0 18b :4 0
36 :2 0 37 :3 0
73e 1212 1214 :3 0
741 120f 1216 :2 0
1218 744 1219 120c
1218 0 121a 746
0 121e 8 :3 0
21 :3 0 121c :2 0
121e 748 13eb b5
:3 0 22 :3 0 e2
:3 0 79 :3 0 e2
:3 0 79 :3 0 57
:3 0 d7 :3 0 5b
:3 0 57 :3 0 9e
:3 0 57 :3 0 a9
:3 0 a5 :3 0 ba
:3 0 cc :3 0 a5
:3 0 57 :3 0 9e
:3 0 a5 :3 0 9e
:3 0 57 :3 0 a9
:3 0 186 :3 0 d2
:3 0 57 :3 0 a9
:3 0 b9 :3 0 bb
:3 0 6e :3 0 b9
:3 0 57 :3 0 9e
:3 0 b9 :3 0 5b
:3 0 b9 :3 0 bb
:3 0 18c :3 0 b9
:3 0 57 :3 0 9e
:3 0 b9 :3 0 5b
:3 0 bb :3 0 57
:3 0 a9 :3 0 49
:3 0 18d :3 0 57
:3 0 a9 :3 0 49
:3 0 18e :3 0 57
:3 0 a9 :3 0 49
:3 0 18f :3 0 e2
:3 0 79 :3 0 49
:3 0 190 :3 0 56
:3 0 57 :3 0 d7
:3 0 57 :3 0 ff
:3 0 e2 :3 0 100
:3 0 e2 :3 0 101
:3 0 e2 :3 0 13d
:3 0 e2 :3 0 13e
:3 0 3b :3 0 ee
:3 0 17a :3 0 ee
:3 0 3b :3 0 ef
:3 0 174 :3 0 ef
:3 0 e2 :3 0 191
:3 0 f9 :3 0 e2
:3 0 131 :3 0 e2
:3 0 17b :3 0 e2
:3 0 f9 :3 0 f4
:3 0 e2 :3 0 17d
:3 0 141 :3 0 e2
:3 0 17e :3 0 142
:3 0 e2 :3 0 143
:3 0 146 :3 0 e2
:3 0 147 :3 0 e2
:3 0 148 :3 0 e2
:3 0 149 :3 0 e2
:3 0 14a :3 0 e2
:3 0 14b :3 0 e2
:3 0 14c :3 0 e2
:3 0 138 :3 0 e2
:3 0 14d :3 0 e2
:3 0 140 :3 0 14e
:3 0 14f :3 0 150
:3 0 152 :3 0 17
:3 0 58 :3 0 57
:3 0 a9 :3 0 57
:3 0 ca :3 0 a5
:3 0 ca :3 0 cc
:3 0 a5 :3 0 57
:3 0 9e :3 0 a5
:3 0 9e :3 0 ca
:3 0 57 :3 0 102
:3 0 103 :3 0 bb
:3 0 104 :3 0 3b
:3 0 57 :3 0 105
:3 0 57 :3 0 102
:3 0 105 :3 0 106
:3 0 bb :3 0 107
:3 0 e2 :3 0 c2
:3 0 e2 :3 0 108
:3 0 e2 :3 0 c4
:3 0 e2 :3 0 109
:3 0 57 :3 0 a9
:3 0 a5 :3 0 10a
:3 0 cc :3 0 a5
:3 0 57 :3 0 9e
:3 0 a5 :3 0 9e
:3 0 10a :3 0 57
:3 0 10b :3 0 e2
:3 0 fb :3 0 e2
:3 0 155 :3 0 e2
:3 0 156 :3 0 e2
:3 0 158 :3 0 e2
:3 0 e1 :3 0 e2
:3 0 10c :3 0 10d
:3 0 bb :3 0 159
:3 0 e2 :3 0 f5
:3 0 e2 :3 0 10f
:3 0 e2 :3 0 110
:3 0 e2 :3 0 111
:3 0 e2 :3 0 112
:3 0 e2 :3 0 113
:3 0 e2 :3 0 114
:3 0 e2 :3 0 15a
:3 0 e2 :3 0 115
:3 0 e2 :3 0 131
:3 0 e2 :3 0 131
:3 0 131 :3 0 e2
:3 0 15b :3 0 15c
:3 0 15d :3 0 e2
:3 0 15e :3 0 e2
:3 0 15f :3 0 e2
:3 0 161 :3 0 e2
:3 0 143 :3 0 162
:3 0 163 :3 0 e2
:3 0 79 :3 0 e2
:3 0 e1 :3 0 e2
:3 0 79 :3 0 e2
:3 0 15e :3 0 e2
:3 0 181 :3 0 e2
:3 0 15f :3 0 e2
:3 0 182 :3 0 164
:3 0 e2 :3 0 165
:3 0 183 :3 0 bb
:3 0 166 :3 0 e2
:3 0 167 :3 0 184
:3 0 bb :3 0 168
:3 0 e2 :3 0 169
:3 0 e2 :3 0 16a
:3 0 185 :3 0 bb
:3 0 16b :3 0 57
:3 0 a9 :3 0 a5
:3 0 16c :3 0 cc
:3 0 a5 :3 0 57
:3 0 9e :3 0 a5
:3 0 9e :3 0 16c
:3 0 57 :3 0 a9
:3 0 b9 :3 0 d2
:3 0 d3 :3 0 b9
:3 0 57 :3 0 9e
:3 0 b9 :3 0 b1
:3 0 a5 :3 0 c7
:3 0 cc :3 0 a5
:3 0 57 :3 0 9e
:3 0 a5 :3 0 9e
:3 0 c8 :3 0 1c
:3 0 16d :3 0 1d
:3 0 16e :3 0 d
:3 0 16f :3 0 57
:3 0 a9 :3 0 a5
:3 0 cb :3 0 cc
:3 0 a5 :3 0 57
:3 0 9e :3 0 a5
:3 0 9e :3 0 cb
:3 0 57 :3 0 a9
:3 0 a5 :3 0 c9
:3 0 cc :3 0 a5
:3 0 57 :3 0 9e
:3 0 a5 :3 0 9e
:3 0 c9 :3 0 57
:3 0 a9 :3 0 b9
:3 0 d2 :3 0 57
:3 0 a9 :3 0 186
:3 0 d2 :3 0 d2
:3 0 e2 :3 0 170
:3 0 e2 :3 0 171
:3 0 e2 :3 0 173
:3 0 a6 :3 0 57
:3 0 ce :3 0 cf
:3 0 a7 :3 0 78
:3 0 e2 :3 0 57
:3 0 d7 :3 0 e2
:3 0 d7 :3 0 ce
:3 0 cf :3 0 a7
:3 0 d3 :3 0 b9
:3 0 b9 :3 0 b1
:3 0 57 :3 0 b1
:3 0 ce :3 0 cf
:3 0 a7 :3 0 d3
:3 0 186 :3 0 57
:3 0 9e :3 0 186
:3 0 b1 :3 0 ce
:3 0 cf :3 0 a7
:3 0 116 :3 0 103
:3 0 57 :3 0 102
:3 0 103 :3 0 5b
:3 0 ce :3 0 cf
:3 0 a7 :3 0 116
:3 0 106 :3 0 3b
:3 0 57 :3 0 105
:3 0 57 :3 0 102
:3 0 106 :3 0 5b
:3 0 ce :3 0 cf
:3 0 a7 :3 0 117
:3 0 10d :3 0 10d
:3 0 5b :3 0 e2
:3 0 10c :3 0 ce
:3 0 cf :3 0 a7
:3 0 187 :3 0 183
:3 0 183 :3 0 5b
:3 0 e2 :3 0 165
:3 0 ce :3 0 cf
:3 0 a7 :3 0 187
:3 0 184 :3 0 184
:3 0 5b :3 0 e2
:3 0 167 :3 0 ce
:3 0 cf :3 0 a7
:3 0 188 :3 0 185
:3 0 185 :3 0 5b
:3 0 e2 :3 0 16a
:3 0 57 :3 0 10b
:3 0 57 :3 0 5b
:3 0 d :3 0 56
:3 0 bb :4 0 192
1 :a 0 13c7 :2 0
13ea 1220 13c5 :2 0
2e :3 0 2f :3 0
13c8 13c9 0 2e
:3 0 3f :3 0 13cb
13cc 0 14 :2 0
2 :4 0 193 :2 0
41 :2 0 14 :2 0
74f 13d1 13d3 :3 0
752 13cd 13d5 13ca
13d7 13d6 :2 0 31
:3 0 42 :3 0 13d9
13da 0 33 :4 0
194 :4 0 36 :2 0
37 :3 0 756 13de
13e0 :3 0 759 13db
13e2 :2 0 13e4 75c
13e5 13d8 13e4 0
13e6 75e 0 13ea
8 :3 0 22 :3 0
13e8 :2 0 13ea 760
13ec ded 121e 0
13ed 0 13ea 0
13ed 764 0 13ef
76 :3 0 767 13f0
c1d 13ef 0 23b2
3b :3 0 15 :3 0
16 :2 0 76c 13f1
13f4 51 :2 0 195
:2 0 771 13f6 13f8
:3 0 9a :3 0 9b
:3 0 196 :4 0 13fc
:4 0 13fd :2 0 15bc
9 :3 0 5d :3 0
13ff 1400 0 16
:2 0 1401 1402 0
15bc 197 :3 0 9e
:3 0 a9 :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 f4
:3 0 9e :3 0 a9
:3 0 198 :3 0 ee
:3 0 ee :3 0 199
:3 0 ef :3 0 ef
:3 0 19a :3 0 f9
:3 0 f0 :3 0 198
:3 0 17a :3 0 f1
:3 0 199 :3 0 174
:3 0 f2 :3 0 19a
:3 0 17b :3 0 f3
:3 0 19a :3 0 14c
:3 0 f4 :3 0 78
:3 0 55 :3 0 d
:3 0 e1 :3 0 9e
:3 0 a9 :4 0 19b
1 :8 0 1441 ab
:4 0 142c :3 0 50
:3 0 51 :2 0 776
142f 1430 :3 0 9
:3 0 5d :3 0 1432
1433 0 16 :2 0
1434 1435 0 1437
779 143e 9 :3 0
5d :3 0 1438 1439
0 ac :2 0 143a
143b 0 143d 77b
143f 1431 1437 0
1440 0 143d 0
1440 77d 0 1441
780 1494 5f :3 0
9 :3 0 5d :3 0
1443 1444 0 5e
:3 0 1445 1446 0
1448 783 144a 785
1449 1448 :2 0 1492
60 :3 0 9 :3 0
5d :3 0 144d 144e
0 5e :3 0 144f
1450 0 148a 2e
:3 0 2f :3 0 1452
1453 0 2e :3 0
3f :3 0 1455 1456
0 61 :2 0 2
:4 0 19c :2 0 41
:2 0 14 :2 0 787
145b 145d :3 0 78a
1457 145f 1454 1461
1460 :2 0 31 :3 0
42 :3 0 1463 1464
0 33 :4 0 19d
:4 0 36 :2 0 37
:3 0 78e 1468 146a
:3 0 36 :2 0 47
:4 0 791 146c 146e
:3 0 36 :2 0 64
:4 0 794 1470 1472
:3 0 36 :2 0 5e
:3 0 797 1474 1476
:3 0 36 :2 0 65
:4 0 79a 1478 147a
:3 0 36 :2 0 66
:3 0 67 :3 0 14
:2 0 68 :2 0 79d
147d 1481 7a1 147c
1483 :3 0 7a4 1465
1485 :2 0 1487 7a7
1488 1462 1487 0
1489 7a9 0 148a
7ab 148d :3 0 148d
0 148d 148c 148a
148b :6 0 148f 26
:3 0 7ae 1491 7b0
1490 148f :2 0 1492
7b2 :2 0 1494 0
1494 1493 1441 1492
:6 0 15bc 1 :3 0
9 :3 0 5d :3 0
1496 1497 0 e7
:4 0 1499 149a :3 0
1498 149b 0 15bc
e8 :3 0 5b :3 0
bb :3 0 ee :3 0
ef :3 0 f0 :3 0
f1 :3 0 f2 :3 0
f3 :3 0 f4 :3 0
a5 :3 0 b1 :3 0
a5 :3 0 d2 :3 0
57 :3 0 ee :3 0
57 :3 0 ef :3 0
57 :3 0 f0 :3 0
57 :3 0 f1 :3 0
57 :3 0 f2 :3 0
57 :3 0 f3 :3 0
57 :3 0 f4 :3 0
197 :3 0 57 :3 0
a7 :3 0 d3 :3 0
a5 :3 0 57 :3 0
a9 :3 0 a5 :3 0
b1 :3 0 57 :3 0
9e :3 0 a7 :3 0
a8 :3 0 cd :3 0
cd :3 0 5b :3 0
a5 :3 0 d4 :3 0
a7 :3 0 a8 :3 0
be :3 0 be :3 0
5b :3 0 cd :3 0
9f :4 0 19e 1
:8 0 14e8 ab :4 0
14d3 :3 0 50 :3 0
51 :2 0 7b7 14d6
14d7 :3 0 9 :3 0
5d :3 0 14d9 14da
0 16 :2 0 14db
14dc 0 14de 7ba
14e5 9 :3 0 5d
:3 0 14df 14e0 0
ac :2 0 14e1 14e2
0 14e4 7bc 14e6
14d8 14de 0 14e7
0 14e4 0 14e7
7be 0 14e8 7c1
153b 5f :3 0 9
:3 0 5d :3 0 14ea
14eb 0 5e :3 0
14ec 14ed 0 14ef
7c4 14f1 7c6 14f0
14ef :2 0 1539 60
:3 0 9 :3 0 5d
:3 0 14f4 14f5 0
5e :3 0 14f6 14f7
0 1531 2e :3 0
2f :3 0 14f9 14fa
0 2e :3 0 3f
:3 0 14fc 14fd 0
61 :2 0 2 :4 0
19f :2 0 41 :2 0
14 :2 0 7c8 1502
1504 :3 0 7cb 14fe
1506 14fb 1508 1507
:2 0 31 :3 0 42
:3 0 150a 150b 0
33 :4 0 1a0 :4 0
36 :2 0 37 :3 0
7cf 150f 1511 :3 0
36 :2 0 47 :4 0
7d2 1513 1515 :3 0
36 :2 0 64 :4 0
7d5 1517 1519 :3 0
36 :2 0 5e :3 0
7d8 151b 151d :3 0
36 :2 0 65 :4 0
7db 151f 1521 :3 0
36 :2 0 66 :3 0
67 :3 0 14 :2 0
68 :2 0 7de 1524
1528 7e2 1523 152a
:3 0 7e5 150c 152c
:2 0 152e 7e8 152f
1509 152e 0 1530
7ea 0 1531 7ec
1534 :3 0 1534 0
1534 1533 1531 1532
:6 0 1536 28 :3 0
7ef 1538 7f1 1537
1536 :2 0 1539 7f3
:2 0 153b 0 153b
153a 14e8 1539 :6 0
15bc 1 :3 0 b5
:3 0 23 :3 0 57
:3 0 9e :3 0 5b
:3 0 d7 :3 0 b9
:3 0 ba :3 0 bb
:3 0 56 :3 0 b9
:3 0 bd :3 0 57
:3 0 ee :3 0 57
:3 0 ef :3 0 57
:3 0 f0 :3 0 57
:3 0 f1 :3 0 57
:3 0 f2 :3 0 57
:3 0 f3 :3 0 57
:3 0 f4 :3 0 f5
:3 0 17 :3 0 58
:3 0 f6 :3 0 f7
:3 0 f8 :3 0 f9
:3 0 fa :3 0 fb
:3 0 b9 :3 0 10a
:3 0 c6 :3 0 85
:3 0 b9 :3 0 c7
:3 0 c8 :3 0 b9
:3 0 c9 :3 0 b9
:3 0 ca :3 0 b9
:3 0 cb :3 0 197
:3 0 57 :3 0 a7
:3 0 cc :3 0 b9
:3 0 57 :3 0 a9
:3 0 57 :3 0 9e
:3 0 b9 :3 0 9e
:3 0 5b :3 0 d7
:3 0 bb :3 0 56
:3 0 bd :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 f4
:3 0 f5 :3 0 17
:3 0 58 :3 0 f6
:3 0 f7 :3 0 f8
:3 0 f9 :3 0 fa
:3 0 fb :3 0 10a
:3 0 c6 :3 0 85
:3 0 c8 :3 0 c9
:3 0 ca :3 0 cb
:3 0 e8 :3 0 56
:4 0 1a1 1 :a 0
1598 :2 0 15bc 153e
1596 :2 0 2e :3 0
2f :3 0 1599 159a
0 2e :3 0 3f
:3 0 159c 159d 0
14 :2 0 2 :4 0
1a2 :2 0 41 :2 0
14 :2 0 7f6 15a2
15a4 :3 0 7f9 159e
15a6 159b 15a8 15a7
:2 0 31 :3 0 42
:3 0 15aa 15ab 0
33 :4 0 1a3 :4 0
36 :2 0 37 :3 0
7fd 15af 15b1 :3 0
800 15ac 15b3 :2 0
15b5 803 15b6 15a9
15b5 0 15b7 805
0 15bc 8 :3 0
23 :3 0 15b9 :2 0
15bc 76 :3 0 807
15bd 13f9 15bc 0
23b2 3b :3 0 15
:3 0 16 :2 0 810
15be 15c1 51 :2 0
1a4 :2 0 815 15c3
15c5 :3 0 9a :3 0
9b :3 0 196 :4 0
15c9 :4 0 15ca :2 0
17f2 9 :3 0 5d
:3 0 15cc 15cd 0
16 :2 0 15ce 15cf
0 17f2 197 :3 0
9e :3 0 a9 :3 0
ee :3 0 ef :3 0
f0 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
f4 :3 0 9e :3 0
a9 :3 0 198 :3 0
ee :3 0 ee :3 0
199 :3 0 ef :3 0
ef :3 0 19a :3 0
f9 :3 0 f0 :3 0
198 :3 0 17a :3 0
f1 :3 0 199 :3 0
174 :3 0 f2 :3 0
19a :3 0 17b :3 0
f3 :3 0 19a :3 0
14c :3 0 f4 :3 0
78 :3 0 55 :3 0
d :3 0 e1 :3 0
9e :3 0 a9 :4 0
19b 1 :8 0 160e
ab :4 0 15f9 :3 0
50 :3 0 51 :2 0
81a 15fc 15fd :3 0
9 :3 0 5d :3 0
15ff 1600 0 16
:2 0 1601 1602 0
1604 81d 160b 9
:3 0 5d :3 0 1605
1606 0 ac :2 0
1607 1608 0 160a
81f 160c 15fe 1604
0 160d 0 160a
0 160d 821 0
160e 824 1661 5f
:3 0 9 :3 0 5d
:3 0 1610 1611 0
5e :3 0 1612 1613
0 1615 827 1617
829 1616 1615 :2 0
165f 60 :3 0 9
:3 0 5d :3 0 161a
161b 0 5e :3 0
161c 161d 0 1657
2e :3 0 2f :3 0
161f 1620 0 2e
:3 0 3f :3 0 1622
1623 0 61 :2 0
2 :4 0 1a5 :2 0
41 :2 0 14 :2 0
82b 1628 162a :3 0
82e 1624 162c 1621
162e 162d :2 0 31
:3 0 42 :3 0 1630
1631 0 33 :4 0
1a6 :4 0 36 :2 0
37 :3 0 832 1635
1637 :3 0 36 :2 0
47 :4 0 835 1639
163b :3 0 36 :2 0
64 :4 0 838 163d
163f :3 0 36 :2 0
5e :3 0 83b 1641
1643 :3 0 36 :2 0
65 :4 0 83e 1645
1647 :3 0 36 :2 0
66 :3 0 67 :3 0
14 :2 0 68 :2 0
841 164a 164e 845
1649 1650 :3 0 848
1632 1652 :2 0 1654
84b 1655 162f 1654
0 1656 84d 0
1657 84f 165a :3 0
165a 0 165a 1659
1657 1658 :6 0 165c
2a :3 0 852 165e
854 165d 165c :2 0
165f 856 :2 0 1661
0 1661 1660 160e
165f :6 0 17f2 1
:3 0 9 :3 0 5d
:3 0 1663 1664 0
e7 :4 0 1666 1667
:3 0 1665 1668 0
17f2 e8 :3 0 5b
:3 0 bb :3 0 a9
:3 0 56 :3 0 bd
:3 0 ee :3 0 ef
:3 0 f0 :3 0 f1
:3 0 f2 :3 0 f3
:3 0 f4 :3 0 10a
:3 0 a5 :3 0 b1
:3 0 a5 :3 0 d2
:3 0 57 :3 0 ee
:3 0 57 :3 0 ef
:3 0 57 :3 0 f0
:3 0 57 :3 0 f1
:3 0 57 :3 0 f2
:3 0 57 :3 0 f3
:3 0 57 :3 0 f4
:3 0 197 :3 0 57
:3 0 a7 :3 0 d3
:3 0 a5 :3 0 57
:3 0 a9 :3 0 a5
:3 0 b1 :3 0 57
:3 0 9e :3 0 a7
:3 0 a8 :3 0 cd
:3 0 cd :3 0 5b
:3 0 a5 :3 0 d4
:3 0 a7 :3 0 a8
:3 0 be :3 0 be
:3 0 5b :3 0 cd
:3 0 9f :3 0 e0
:3 0 9e :3 0 b9
:3 0 ba :3 0 b9
:3 0 bd :3 0 ed
:3 0 ed :3 0 ed
:3 0 ed :3 0 b9
:3 0 10a :3 0 a6
:3 0 e0 :3 0 cc
:3 0 b9 :3 0 e0
:3 0 55 :3 0 d
:3 0 e0 :3 0 9e
:3 0 b9 :3 0 9e
:3 0 b6 :3 0 79
:3 0 78 :3 0 b6
:3 0 b6 :3 0 d7
:3 0 57 :3 0 d7
:3 0 a6 :3 0 57
:3 0 57 :3 0 55
:3 0 e0 :3 0 55
:3 0 57 :3 0 9e
:3 0 e0 :3 0 9e
:4 0 1a7 1 :8 0
16e2 ab :4 0 16cd
:3 0 50 :3 0 51
:2 0 85b 16d0 16d1
:3 0 9 :3 0 5d
:3 0 16d3 16d4 0
16 :2 0 16d5 16d6
0 16d8 85e 16df
9 :3 0 5d :3 0
16d9 16da 0 ac
:2 0 16db 16dc 0
16de 860 16e0 16d2
16d8 0 16e1 0
16de 0 16e1 862
0 16e2 865 1735
5f :3 0 9 :3 0
5d :3 0 16e4 16e5
0 5e :3 0 16e6
16e7 0 16e9 868
16eb 86a 16ea 16e9
:2 0 1733 60 :3 0
9 :3 0 5d :3 0
16ee 16ef 0 5e
:3 0 16f0 16f1 0
172b 2e :3 0 2f
:3 0 16f3 16f4 0
2e :3 0 3f :3 0
16f6 16f7 0 61
:2 0 2 :4 0 1a8
:2 0 41 :2 0 14
:2 0 86c 16fc 16fe
:3 0 86f 16f8 1700
16f5 1702 1701 :2 0
31 :3 0 42 :3 0
1704 1705 0 33
:4 0 1a9 :4 0 36
:2 0 37 :3 0 873
1709 170b :3 0 36
:2 0 47 :4 0 876
170d 170f :3 0 36
:2 0 64 :4 0 879
1711 1713 :3 0 36
:2 0 5e :3 0 87c
1715 1717 :3 0 36
:2 0 65 :4 0 87f
1719 171b :3 0 36
:2 0 66 :3 0 67
:3 0 14 :2 0 68
:2 0 882 171e 1722
886 171d 1724 :3 0
889 1706 1726 :2 0
1728 88c 1729 1703
1728 0 172a 88e
0 172b 890 172e
:3 0 172e 0 172e
172d 172b 172c :6 0
1730 2c :3 0 893
1732 895 1731 1730
:2 0 1733 897 :2 0
1735 0 1735 1734
16e2 1733 :6 0 17f2
1 :3 0 b5 :3 0
24 :3 0 57 :3 0
9e :3 0 5b :3 0
d7 :3 0 b9 :3 0
ba :3 0 bb :3 0
56 :3 0 b9 :3 0
bd :3 0 57 :3 0
ee :3 0 57 :3 0
ef :3 0 57 :3 0
f0 :3 0 57 :3 0
f1 :3 0 57 :3 0
f2 :3 0 57 :3 0
f3 :3 0 57 :3 0
f4 :3 0 f5 :3 0
17 :3 0 58 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 f9 :3 0
fa :3 0 fb :3 0
b9 :3 0 10a :3 0
c6 :3 0 85 :3 0
b9 :3 0 c7 :3 0
c8 :3 0 b9 :3 0
c9 :3 0 b9 :3 0
ca :3 0 b9 :3 0
cb :3 0 197 :3 0
57 :3 0 a7 :3 0
cc :3 0 b9 :3 0
57 :3 0 a9 :3 0
57 :3 0 9e :3 0
b9 :3 0 9e :3 0
5b :3 0 d7 :3 0
bb :3 0 56 :3 0
bd :3 0 ee :3 0
ef :3 0 f0 :3 0
f1 :3 0 f2 :3 0
f3 :3 0 f4 :3 0
f5 :3 0 17 :3 0
58 :3 0 f6 :3 0
f7 :3 0 f8 :3 0
f9 :3 0 fa :3 0
fb :3 0 10a :3 0
c6 :3 0 85 :3 0
c8 :3 0 c9 :3 0
ca :3 0 cb :3 0
e8 :3 0 a9 :3 0
56 :3 0 e2 :3 0
5b :3 0 d7 :3 0
e2 :3 0 bb :3 0
e2 :3 0 56 :3 0
e2 :3 0 bd :3 0
e2 :3 0 ee :3 0
e2 :3 0 ef :3 0
e2 :3 0 f0 :3 0
e2 :3 0 f1 :3 0
e2 :3 0 f2 :3 0
e2 :3 0 f3 :3 0
e2 :3 0 f4 :3 0
f5 :3 0 17 :3 0
58 :3 0 f6 :3 0
f7 :3 0 f8 :3 0
f9 :3 0 fa :3 0
fb :3 0 e2 :3 0
10a :3 0 c6 :3 0
85 :3 0 b9 :3 0
c7 :3 0 c8 :3 0
b9 :3 0 c9 :3 0
b9 :3 0 ca :3 0
b9 :3 0 cb :3 0
e8 :3 0 e2 :3 0
cc :3 0 b9 :3 0
e2 :3 0 a9 :3 0
e2 :3 0 56 :3 0
e2 :3 0 5b :3 0
b9 :3 0 9e :3 0
56 :3 0 bb :4 0
1aa 1 :a 0 17ce
:2 0 17f2 1738 17cc
:2 0 2e :3 0 2f
:3 0 17cf 17d0 0
2e :3 0 3f :3 0
17d2 17d3 0 14
:2 0 2 :4 0 1ab
:2 0 41 :2 0 14
:2 0 89a 17d8 17da
:3 0 89d 17d4 17dc
17d1 17de 17dd :2 0
31 :3 0 42 :3 0
17e0 17e1 0 33
:4 0 1ac :4 0 36
:2 0 37 :3 0 8a1
17e5 17e7 :3 0 8a4
17e2 17e9 :2 0 17eb
8a7 17ec 17df 17eb
0 17ed 8a9 0
17f2 8 :3 0 24
:3 0 17ef :2 0 17f2
76 :3 0 8ab 17f3
15c6 17f2 0 23b2
3b :3 0 15 :3 0
16 :2 0 8b4 17f4
17f7 51 :2 0 1ad
:2 0 8b9 17f9 17fb
:3 0 b5 :3 0 25
:3 0 e2 :3 0 9e
:3 0 5b :3 0 e2
:3 0 d7 :3 0 b9
:3 0 ba :3 0 bb
:3 0 56 :3 0 b9
:3 0 bd :3 0 54
:3 0 ee :3 0 54
:3 0 ef :3 0 54
:3 0 191 :3 0 f0
:3 0 54 :3 0 f9
:3 0 1ae :3 0 57
:3 0 147 :3 0 f1
:3 0 57 :3 0 148
:3 0 f2 :3 0 57
:3 0 191 :3 0 f3
:3 0 57 :3 0 17b
:3 0 f4 :3 0 17
:3 0 58 :3 0 f6
:3 0 f7 :3 0 f8
:3 0 f9 :3 0 fa
:3 0 153 :3 0 154
:3 0 fb :3 0 b9
:3 0 10a :3 0 c6
:3 0 85 :3 0 1af
:3 0 c2 :3 0 1af
:3 0 108 :3 0 1af
:3 0 c4 :3 0 1af
:3 0 109 :3 0 1af
:3 0 11c :3 0 1af
:3 0 1b0 :3 0 1af
:3 0 1b1 :3 0 1af
:3 0 1b2 :3 0 1af
:3 0 1b3 :3 0 1af
:3 0 1b4 :3 0 1af
:3 0 1b5 :3 0 1af
:3 0 1b6 :3 0 1af
:3 0 1b7 :3 0 1af
:3 0 1b8 :3 0 1af
:3 0 1b9 :3 0 b9
:3 0 16c :3 0 b9
:3 0 c7 :3 0 c8
:3 0 b9 :3 0 c9
:3 0 b9 :3 0 ca
:3 0 b9 :3 0 cb
:3 0 a6 :3 0 e2
:3 0 a7 :3 0 1ba
:3 0 1af :3 0 1af
:3 0 55 :3 0 d
:3 0 1af :3 0 9e
:3 0 e2 :3 0 9e
:3 0 ce :3 0 a7
:3 0 78 :3 0 57
:3 0 57 :3 0 d7
:3 0 e2 :3 0 d7
:3 0 57 :3 0 131
:3 0 ce :3 0 a7
:3 0 78 :3 0 54
:3 0 54 :3 0 d7
:3 0 e2 :3 0 d7
:3 0 54 :3 0 131
:3 0 a7 :3 0 cc
:3 0 b9 :3 0 e2
:3 0 9e :3 0 b9
:3 0 9e :3 0 e2
:3 0 5b :3 0 d
:3 0 e2 :3 0 a9
:3 0 57 :3 0 79
:3 0 54 :3 0 79
:3 0 e2 :3 0 9e
:3 0 5b :3 0 57
:3 0 d7 :3 0 b9
:3 0 d2 :3 0 bb
:3 0 56 :3 0 bd
:3 0 e2 :3 0 ee
:3 0 e2 :3 0 ef
:3 0 e2 :3 0 191
:3 0 f0 :3 0 e2
:3 0 f9 :3 0 1ae
:3 0 ed :3 0 f1
:3 0 ed :3 0 f2
:3 0 f3 :3 0 f4
:3 0 17 :3 0 58
:3 0 f6 :3 0 f7
:3 0 f8 :3 0 f9
:3 0 fa :3 0 e2
:3 0 fb :3 0 10a
:3 0 c6 :3 0 85
:3 0 1af :3 0 c2
:3 0 1af :3 0 108
:3 0 1af :3 0 c4
:3 0 1af :3 0 109
:3 0 1af :3 0 11c
:3 0 1af :3 0 1b0
:3 0 1af :3 0 1b1
:3 0 1af :3 0 1b2
:3 0 1af :3 0 1b3
:3 0 1af :3 0 1b4
:3 0 1af :3 0 1b5
:3 0 1af :3 0 1b6
:3 0 1af :3 0 1b7
:3 0 1af :3 0 1b8
:3 0 1af :3 0 1b9
:3 0 16c :3 0 c8
:3 0 c9 :3 0 ca
:3 0 cb :3 0 a6
:3 0 57 :3 0 a7
:3 0 d3 :3 0 b9
:3 0 57 :3 0 9e
:3 0 b9 :3 0 b1
:3 0 a7 :3 0 78
:3 0 e2 :3 0 e2
:3 0 d7 :3 0 57
:3 0 d7 :3 0 a7
:3 0 1ba :3 0 1af
:3 0 1af :3 0 55
:3 0 d :3 0 1af
:3 0 9e :3 0 57
:3 0 9e :3 0 57
:3 0 5b :3 0 d
:3 0 57 :3 0 a9
:3 0 56 :3 0 bb
:4 0 1bb 1 :a 0
18f3 :2 0 1917 17fe
18f1 :2 0 2e :3 0
2f :3 0 18f4 18f5
0 2e :3 0 3f
:3 0 18f7 18f8 0
14 :2 0 2 :4 0
1bc :2 0 41 :2 0
14 :2 0 8bc 18fd
18ff :3 0 8bf 18f9
1901 18f6 1903 1902
:2 0 31 :3 0 42
:3 0 1905 1906 0
33 :4 0 1bd :4 0
36 :2 0 37 :3 0
8c3 190a 190c :3 0
8c6 1907 190e :2 0
1910 8c9 1911 1904
1910 0 1912 8cb
0 1917 8 :3 0
25 :3 0 1914 :2 0
1917 76 :3 0 8cd
1918 17fc 1917 0
23b2 3b :3 0 15
:3 0 16 :2 0 8d1
1919 191c 51 :2 0
1be :2 0 8d6 191e
1920 :3 0 9a :3 0
9b :3 0 1bf :4 0
1924 :4 0 1925 :2 0
1c32 9 :3 0 5d
:3 0 1927 1928 0
16 :2 0 1929 192a
0 1c32 1c0 :3 0
9e :3 0 a9 :3 0
1c1 :3 0 1c2 :3 0
1ae :3 0 f0 :3 0
1c3 :3 0 1c4 :3 0
1c5 :3 0 f3 :3 0
56 :3 0 9e :3 0
a9 :3 0 198 :3 0
ee :3 0 1c1 :3 0
199 :3 0 ef :3 0
1c2 :3 0 19a :3 0
f9 :3 0 1ae :3 0
19a :3 0 131 :3 0
191 :3 0 f0 :3 0
198 :3 0 17a :3 0
1c3 :3 0 199 :3 0
174 :3 0 1c4 :3 0
19a :3 0 17b :3 0
1c5 :3 0 19a :3 0
131 :3 0 191 :3 0
f3 :3 0 78 :3 0
55 :3 0 d :3 0
e3 :3 0 d :3 0
9e :3 0 a9 :4 0
1c6 1 :8 0 1971
ab :4 0 195c :3 0
50 :3 0 51 :2 0
8db 195f 1960 :3 0
9 :3 0 5d :3 0
1962 1963 0 16
:2 0 1964 1965 0
1967 8de 196e 9
:3 0 5d :3 0 1968
1969 0 ac :2 0
196a 196b 0 196d
8e0 196f 1961 1967
0 1970 0 196d
0 1970 8e2 0
1971 8e5 19c4 5f
:3 0 9 :3 0 5d
:3 0 1973 1974 0
5e :3 0 1975 1976
0 1978 8e8 197a
8ea 1979 1978 :2 0
19c2 60 :3 0 9
:3 0 5d :3 0 197d
197e 0 5e :3 0
197f 1980 0 19ba
2e :3 0 2f :3 0
1982 1983 0 2e
:3 0 3f :3 0 1985
1986 0 61 :2 0
2 :4 0 1c7 :2 0
41 :2 0 14 :2 0
8ec 198b 198d :3 0
8ef 1987 198f 1984
1991 1990 :2 0 31
:3 0 42 :3 0 1993
1994 0 33 :4 0
1c8 :4 0 36 :2 0
37 :3 0 8f3 1998
199a :3 0 36 :2 0
47 :4 0 8f6 199c
199e :3 0 36 :2 0
64 :4 0 8f9 19a0
19a2 :3 0 36 :2 0
5e :3 0 8fc 19a4
19a6 :3 0 36 :2 0
65 :4 0 8ff 19a8
19aa :3 0 36 :2 0
66 :3 0 67 :3 0
14 :2 0 68 :2 0
902 19ad 19b1 906
19ac 19b3 :3 0 909
1995 19b5 :2 0 19b7
90c 19b8 1992 19b7
0 19b9 90e 0
19ba 910 19bd :3 0
19bd 0 19bd 19bc
19ba 19bb :6 0 19bf
2e :3 0 913 19c1
915 19c0 19bf :2 0
19c2 917 :2 0 19c4
0 19c4 19c3 1971
19c2 :6 0 1c32 1
:3 0 9a :3 0 9b
:3 0 1c9 :4 0 19c8
:4 0 19c9 :2 0 1c32
9 :3 0 5d :3 0
19cb 19cc 0 16
:2 0 19cd 19ce 0
1c32 1ca :3 0 9e
:3 0 a9 :3 0 ee
:3 0 ef :3 0 f0
:3 0 f1 :3 0 f2
:3 0 f3 :3 0 f4
:3 0 1c1 :3 0 1c2
:3 0 1ae :3 0 1c3
:3 0 1c4 :3 0 1c5
:3 0 1b0 :3 0 1b1
:3 0 1b2 :3 0 1b3
:3 0 1b4 :3 0 1b5
:3 0 1b6 :3 0 1b7
:3 0 1b8 :3 0 1b9
:3 0 c2 :3 0 108
:3 0 c4 :3 0 109
:3 0 56 :3 0 11c
:3 0 57 :3 0 9e
:3 0 57 :3 0 a9
:3 0 57 :3 0 ee
:3 0 57 :3 0 ef
:3 0 57 :3 0 f9
:3 0 57 :3 0 17a
:3 0 57 :3 0 174
:3 0 57 :3 0 17b
:3 0 57 :3 0 14c
:3 0 54 :3 0 1c1
:3 0 54 :3 0 1c2
:3 0 54 :3 0 1ae
:3 0 54 :3 0 1c3
:3 0 54 :3 0 1c4
:3 0 54 :3 0 1c5
:3 0 57 :3 0 1b0
:3 0 57 :3 0 1b1
:3 0 57 :3 0 1b2
:3 0 57 :3 0 1b3
:3 0 57 :3 0 1b4
:3 0 57 :3 0 1b5
:3 0 57 :3 0 1b6
:3 0 57 :3 0 1b7
:3 0 57 :3 0 1b8
:3 0 57 :3 0 1b9
:3 0 57 :3 0 c2
:3 0 57 :3 0 108
:3 0 57 :3 0 c4
:3 0 57 :3 0 109
:3 0 3b :3 0 54
:3 0 56 :3 0 57
:3 0 f9 :3 0 57
:3 0 17b :3 0 57
:3 0 11c :3 0 1ba
:3 0 57 :3 0 ce
:3 0 cf :3 0 a7
:3 0 1c0 :3 0 54
:3 0 57 :3 0 9e
:3 0 54 :3 0 9e
:3 0 57 :3 0 55
:3 0 d :4 0 1cb
1 :8 0 1a57 ab
:4 0 1a42 :3 0 50
:3 0 51 :2 0 91c
1a45 1a46 :3 0 9
:3 0 5d :3 0 1a48
1a49 0 16 :2 0
1a4a 1a4b 0 1a4d
91f 1a54 9 :3 0
5d :3 0 1a4e 1a4f
0 ac :2 0 1a50
1a51 0 1a53 921
1a55 1a47 1a4d 0
1a56 0 1a53 0
1a56 923 0 1a57
926 1aaa 5f :3 0
9 :3 0 5d :3 0
1a59 1a5a 0 5e
:3 0 1a5b 1a5c 0
1a5e 929 1a60 92b
1a5f 1a5e :2 0 1aa8
60 :3 0 9 :3 0
5d :3 0 1a63 1a64
0 5e :3 0 1a65
1a66 0 1aa0 2e
:3 0 2f :3 0 1a68
1a69 0 2e :3 0
3f :3 0 1a6b 1a6c
0 61 :2 0 2
:4 0 1cc :2 0 41
:2 0 14 :2 0 92d
1a71 1a73 :3 0 930
1a6d 1a75 1a6a 1a77
1a76 :2 0 31 :3 0
42 :3 0 1a79 1a7a
0 33 :4 0 1cd
:4 0 36 :2 0 37
:3 0 934 1a7e 1a80
:3 0 36 :2 0 47
:4 0 937 1a82 1a84
:3 0 36 :2 0 64
:4 0 93a 1a86 1a88
:3 0 36 :2 0 5e
:3 0 93d 1a8a 1a8c
:3 0 36 :2 0 65
:4 0 940 1a8e 1a90
:3 0 36 :2 0 66
:3 0 67 :3 0 14
:2 0 68 :2 0 943
1a93 1a97 947 1a92
1a99 :3 0 94a 1a7b
1a9b :2 0 1a9d 94d
1a9e 1a78 1a9d 0
1a9f 94f 0 1aa0
951 1aa3 :3 0 1aa3
0 1aa3 1aa2 1aa0
1aa1 :6 0 1aa5 30
:3 0 954 1aa7 956
1aa6 1aa5 :2 0 1aa8
958 :2 0 1aaa 0
1aaa 1aa9 1a57 1aa8
:6 0 1c32 1 :3 0
1ca :3 0 1ce :3 0
56 :3 0 56 :3 0
e3 :3 0 78 :3 0
e2 :3 0 e2 :3 0
55 :3 0 d :3 0
e2 :3 0 9e :3 0
1ce :3 0 9e :3 0
e2 :3 0 a9 :4 0
1cf 1 :8 0 1ad2
ab :4 0 1abd :3 0
50 :3 0 51 :2 0
95d 1ac0 1ac1 :3 0
9 :3 0 5d :3 0
1ac3 1ac4 0 16
:2 0 1ac5 1ac6 0
1ac8 960 1acf 9
:3 0 5d :3 0 1ac9
1aca 0 ac :2 0
1acb 1acc 0 1ace
962 1ad0 1ac2 1ac8
0 1ad1 0 1ace
0 1ad1 964 0
1ad2 967 1b25 5f
:3 0 9 :3 0 5d
:3 0 1ad4 1ad5 0
5e :3 0 1ad6 1ad7
0 1ad9 96a 1adb
96c 1ada 1ad9 :2 0
1b23 60 :3 0 9
:3 0 5d :3 0 1ade
1adf 0 5e :3 0
1ae0 1ae1 0 1b1b
2e :3 0 2f :3 0
1ae3 1ae4 0 2e
:3 0 3f :3 0 1ae6
1ae7 0 61 :2 0
2 :4 0 1d0 :2 0
41 :2 0 14 :2 0
96e 1aec 1aee :3 0
971 1ae8 1af0 1ae5
1af2 1af1 :2 0 31
:3 0 42 :3 0 1af4
1af5 0 33 :4 0
1d1 :4 0 36 :2 0
37 :3 0 975 1af9
1afb :3 0 36 :2 0
47 :4 0 978 1afd
1aff :3 0 36 :2 0
64 :4 0 97b 1b01
1b03 :3 0 36 :2 0
5e :3 0 97e 1b05
1b07 :3 0 36 :2 0
65 :4 0 981 1b09
1b0b :3 0 36 :2 0
66 :3 0 67 :3 0
14 :2 0 68 :2 0
984 1b0e 1b12 988
1b0d 1b14 :3 0 98b
1af6 1b16 :2 0 1b18
98e 1b19 1af3 1b18
0 1b1a 990 0
1b1b 992 1b1e :3 0
1b1e 0 1b1e 1b1d
1b1b 1b1c :6 0 1b20
32 :3 0 995 1b22
997 1b21 1b20 :2 0
1b23 999 :2 0 1b25
0 1b25 1b24 1ad2
1b23 :6 0 1c32 1
:3 0 b5 :3 0 26
:3 0 57 :3 0 9e
:3 0 5b :3 0 d7
:3 0 b9 :3 0 ba
:3 0 bb :3 0 57
:3 0 56 :3 0 b9
:3 0 bd :3 0 57
:3 0 ee :3 0 57
:3 0 ef :3 0 57
:3 0 f0 :3 0 57
:3 0 f1 :3 0 57
:3 0 f2 :3 0 57
:3 0 f3 :3 0 57
:3 0 f4 :3 0 f5
:3 0 17 :3 0 58
:3 0 f6 :3 0 f7
:3 0 f8 :3 0 f9
:3 0 fa :3 0 fb
:3 0 b9 :3 0 10a
:3 0 c6 :3 0 85
:3 0 57 :3 0 1c1
:3 0 57 :3 0 1c3
:3 0 57 :3 0 9e
:3 0 e1 :3 0 57
:3 0 1c1 :3 0 57
:3 0 1c2 :3 0 57
:3 0 1ae :3 0 57
:3 0 1c3 :3 0 57
:3 0 1c4 :3 0 57
:3 0 1c5 :3 0 d
:3 0 55 :3 0 57
:3 0 1b0 :3 0 57
:3 0 1b1 :3 0 57
:3 0 1b2 :3 0 57
:3 0 1b3 :3 0 57
:3 0 1b4 :3 0 57
:3 0 1b5 :3 0 57
:3 0 1b6 :3 0 57
:3 0 1b7 :3 0 57
:3 0 1b8 :3 0 57
:3 0 1b9 :3 0 57
:3 0 c2 :3 0 57
:3 0 108 :3 0 57
:3 0 c4 :3 0 57
:3 0 109 :3 0 57
:3 0 11c :3 0 b9
:3 0 16c :3 0 b9
:3 0 c7 :3 0 c8
:3 0 b9 :3 0 c9
:3 0 b9 :3 0 ca
:3 0 b9 :3 0 cb
:3 0 1ca :3 0 57
:3 0 a7 :3 0 cc
:3 0 b9 :3 0 57
:3 0 a9 :3 0 57
:3 0 9e :3 0 b9
:3 0 9e :3 0 a5
:3 0 b1 :3 0 5b
:3 0 d7 :3 0 a5
:3 0 d2 :3 0 bb
:3 0 56 :3 0 bd
:3 0 57 :3 0 ee
:3 0 57 :3 0 ef
:3 0 57 :3 0 f0
:3 0 57 :3 0 f1
:3 0 57 :3 0 f2
:3 0 57 :3 0 f3
:3 0 57 :3 0 f4
:3 0 f5 :3 0 17
:3 0 58 :3 0 f6
:3 0 f7 :3 0 f8
:3 0 f9 :3 0 fa
:3 0 fb :3 0 10a
:3 0 c6 :3 0 85
:3 0 57 :3 0 1c1
:3 0 57 :3 0 1c3
:3 0 57 :3 0 9e
:3 0 e1 :3 0 57
:3 0 1c1 :3 0 57
:3 0 1c2 :3 0 57
:3 0 1ae :3 0 57
:3 0 1c3 :3 0 57
:3 0 1c4 :3 0 57
:3 0 1c5 :3 0 d
:3 0 55 :3 0 57
:3 0 1b0 :3 0 57
:3 0 1b1 :3 0 57
:3 0 1b2 :3 0 57
:3 0 1b3 :3 0 57
:3 0 1b4 :3 0 57
:3 0 1b5 :3 0 57
:3 0 1b6 :3 0 57
:3 0 1b7 :3 0 57
:3 0 1b8 :3 0 57
:3 0 1b9 :3 0 57
:3 0 c2 :3 0 57
:3 0 108 :3 0 57
:3 0 c4 :3 0 57
:3 0 109 :3 0 57
:3 0 11c :3 0 16c
:3 0 c8 :3 0 c9
:3 0 ca :3 0 cb
:3 0 1ca :3 0 57
:3 0 a7 :3 0 d3
:3 0 a5 :3 0 57
:3 0 a9 :3 0 a5
:3 0 b1 :3 0 57
:3 0 9e :3 0 a7
:3 0 a8 :3 0 cd
:3 0 cd :3 0 5b
:3 0 a5 :3 0 d4
:3 0 a7 :3 0 a8
:3 0 be :3 0 be
:3 0 5b :3 0 cd
:3 0 9f :4 0 1d2
1 :a 0 1c0e :2 0
1c32 1b28 1c0c :2 0
2e :3 0 2f :3 0
1c0f 1c10 0 2e
:3 0 3f :3 0 1c12
1c13 0 14 :2 0
2 :4 0 1d3 :2 0
41 :2 0 14 :2 0
99c 1c18 1c1a :3 0
99f 1c14 1c1c 1c11
1c1e 1c1d :2 0 31
:3 0 42 :3 0 1c20
1c21 0 33 :4 0
1d4 :4 0 36 :2 0
37 :3 0 9a3 1c25
1c27 :3 0 9a6 1c22
1c29 :2 0 1c2b 9a9
1c2c 1c1f 1c2b 0
1c2d 9ab 0 1c32
8 :3 0 26 :3 0
1c2f :2 0 1c32 76
:3 0 9ad 1c33 1921
1c32 0 23b2 3b
:3 0 15 :3 0 16
:2 0 9b8 1c34 1c37
49 :3 0 51 :2 0
8f :3 0 1c39 1c3b
0 9bd 1c3a 1c3d
:3 0 d2 :3 0 11
:3 0 d3 :3 0 b1
:3 0 d :4 0 1d5
1 :8 0 1c4a 9
:3 0 5d :3 0 1c45
1c46 0 5e :3 0
1c47 1c48 0 1c4a
9c0 1c9d 5f :3 0
9 :3 0 5d :3 0
1c4c 1c4d 0 5e
:3 0 1c4e 1c4f 0
1c51 9c3 1c53 9c5
1c52 1c51 :2 0 1c9b
60 :3 0 9 :3 0
5d :3 0 1c56 1c57
0 5e :3 0 1c58
1c59 0 1c93 2e
:3 0 2f :3 0 1c5b
1c5c 0 2e :3 0
3f :3 0 1c5e 1c5f
0 61 :2 0 2
:4 0 1d6 :2 0 41
:2 0 14 :2 0 9c7
1c64 1c66 :3 0 9ca
1c60 1c68 1c5d 1c6a
1c69 :2 0 31 :3 0
42 :3 0 1c6c 1c6d
0 33 :4 0 1d7
:4 0 36 :2 0 37
:3 0 9ce 1c71 1c73
:3 0 36 :2 0 47
:4 0 9d1 1c75 1c77
:3 0 36 :2 0 64
:4 0 9d4 1c79 1c7b
:3 0 36 :2 0 5e
:3 0 9d7 1c7d 1c7f
:3 0 36 :2 0 65
:4 0 9da 1c81 1c83
:3 0 36 :2 0 66
:3 0 67 :3 0 14
:2 0 68 :2 0 9dd
1c86 1c8a 9e1 1c85
1c8c :3 0 9e4 1c6e
1c8e :2 0 1c90 9e7
1c91 1c6b 1c90 0
1c92 9e9 0 1c93
9eb 1c96 :3 0 1c96
0 1c96 1c95 1c93
1c94 :6 0 1c98 34
:3 0 9ee 1c9a 9f0
1c99 1c98 :2 0 1c9b
9f2 :2 0 1c9d 0
1c9d 1c9c 1c4a 1c9b
:6 0 1d6c 1 :3 0
9 :3 0 5d :3 0
1c9f 1ca0 0 9
:3 0 51 :2 0 1d8
:3 0 1ca2 1ca4 0
9f7 1ca3 1ca6 :3 0
1ca7 :2 0 b5 :3 0
27 :3 0 d :3 0
5b :3 0 11 :3 0
bb :3 0 56 :3 0
1d9 :3 0 b9 :3 0
d4 :3 0 11 :3 0
bf :3 0 1da :3 0
1db :3 0 bb :3 0
1dc :3 0 1dd :3 0
1de :3 0 bb :3 0
1df :3 0 1e0 :3 0
1e1 :3 0 bb :3 0
1e2 :3 0 d3 :3 0
b9 :3 0 ce :3 0
a7 :3 0 18c :3 0
1db :3 0 1db :3 0
5b :3 0 1da :3 0
ce :3 0 a7 :3 0
1e3 :3 0 1de :3 0
1de :3 0 5b :3 0
1dd :3 0 ce :3 0
a7 :3 0 6e :3 0
1e1 :3 0 1e1 :3 0
5b :3 0 1e0 :3 0
b9 :3 0 b1 :3 0
d :3 0 d :3 0
5b :3 0 11 :3 0
bb :3 0 56 :3 0
1e4 :3 0 56 :3 0
1d9 :3 0 1e5 :3 0
5b :3 0 d4 :3 0
120 :3 0 1e6 :3 0
120 :3 0 1e6 :3 0
1e7 :3 0 1e4 :3 0
bb :3 0 1e7 :3 0
1e5 :3 0 bb :3 0
bf :3 0 1da :3 0
1dc :3 0 1dd :3 0
1df :3 0 1e0 :3 0
1e2 :3 0 d9 :3 0
a5 :3 0 ce :3 0
cf :3 0 a7 :3 0
a8 :3 0 1e5 :3 0
a5 :3 0 d4 :3 0
1e5 :3 0 5b :3 0
ce :3 0 cf :3 0
a7 :3 0 a8 :3 0
1e4 :3 0 1e4 :3 0
5b :3 0 1e5 :3 0
9f :3 0 a5 :3 0
d7 :3 0 d :3 0
d :3 0 5b :3 0
11 :3 0 bb :3 0
56 :3 0 1e4 :3 0
56 :3 0 1d9 :3 0
1e5 :3 0 5b :3 0
d4 :3 0 120 :3 0
1e6 :3 0 120 :3 0
1e6 :3 0 1e7 :3 0
1e4 :3 0 bb :3 0
1e7 :3 0 1e5 :3 0
bb :3 0 bf :3 0
1da :3 0 1dc :3 0
1dd :3 0 1df :3 0
1e0 :3 0 1e2 :3 0
d5 :3 0 d6 :3 0
ce :3 0 cf :3 0
a7 :3 0 a8 :3 0
1e5 :3 0 d6 :3 0
d8 :3 0 1e5 :3 0
5b :3 0 ce :3 0
cf :3 0 a7 :3 0
a8 :3 0 1e4 :3 0
1e4 :3 0 5b :3 0
1e5 :3 0 9f :3 0
d6 :3 0 d7 :3 0
d :3 0 5b :3 0
56 :4 0 1e8 1
:a 0 1d45 :2 0 1d68
1caa 1d43 :2 0 2e
:3 0 2f :3 0 1d46
1d47 0 2e :3 0
3f :3 0 1d49 1d4a
0 14 :2 0 2
:4 0 1e9 :2 0 41
:2 0 14 :2 0 9fa
1d4f 1d51 :3 0 9fd
1d4b 1d53 1d48 1d55
1d54 :2 0 31 :3 0
42 :3 0 1d57 1d58
0 33 :4 0 1ea
:4 0 36 :2 0 37
:3 0 a01 1d5c 1d5e
:3 0 a04 1d59 1d60
:2 0 1d62 a07 1d63
1d56 1d62 0 1d64
a09 0 1d68 8
:3 0 27 :3 0 1d66
:2 0 1d68 a0b 1d69
1ca8 1d68 0 1d6a
a0f 0 1d6c 76
:3 0 a11 1d6d 1c3e
1d6c 0 23b2 3b
:3 0 15 :3 0 16
:2 0 a14 1d6e 1d71
51 :2 0 77 :2 0
a19 1d73 1d75 :3 0
b5 :3 0 28 :3 0
e2 :3 0 79 :3 0
e2 :3 0 79 :3 0
57 :3 0 d7 :3 0
5b :3 0 57 :3 0
9e :3 0 57 :3 0
a9 :3 0 b9 :3 0
d2 :3 0 d3 :3 0
b9 :3 0 57 :3 0
9e :3 0 b9 :3 0
b1 :3 0 a5 :3 0
ba :3 0 cc :3 0
a5 :3 0 57 :3 0
9e :3 0 a5 :3 0
9e :3 0 bb :3 0
e2 :3 0 79 :3 0
57 :3 0 a9 :3 0
56 :3 0 57 :3 0
d7 :3 0 57 :3 0
ff :3 0 e2 :3 0
100 :3 0 3b :3 0
ef :3 0 174 :3 0
101 :3 0 e2 :3 0
13d :3 0 e2 :3 0
13e :3 0 3b :3 0
ee :3 0 17a :3 0
ee :3 0 3b :3 0
ef :3 0 174 :3 0
ef :3 0 131 :3 0
17b :3 0 f9 :3 0
f9 :3 0 131 :3 0
17b :3 0 140 :3 0
f9 :3 0 f4 :3 0
e2 :3 0 17c :3 0
e2 :3 0 17d :3 0
e2 :3 0 17c :3 0
e2 :3 0 17d :3 0
141 :3 0 e2 :3 0
17e :3 0 142 :3 0
143 :3 0 e2 :3 0
140 :3 0 144 :3 0
145 :3 0 e2 :3 0
140 :3 0 145 :3 0
f9 :3 0 17b :3 0
146 :3 0 e2 :3 0
147 :3 0 e2 :3 0
148 :3 0 e2 :3 0
149 :3 0 e2 :3 0
14a :3 0 e2 :3 0
14b :3 0 e2 :3 0
14c :3 0 e2 :3 0
138 :3 0 e2 :3 0
14d :3 0 e2 :3 0
140 :3 0 14e :3 0
14f :3 0 150 :3 0
152 :3 0 17 :3 0
58 :3 0 57 :3 0
a9 :3 0 57 :3 0
ca :3 0 a5 :3 0
ca :3 0 cc :3 0
a5 :3 0 57 :3 0
9e :3 0 a5 :3 0
9e :3 0 ca :3 0
57 :3 0 102 :3 0
103 :3 0 bb :3 0
104 :3 0 3b :3 0
57 :3 0 105 :3 0
57 :3 0 102 :3 0
105 :3 0 106 :3 0
bb :3 0 107 :3 0
e2 :3 0 c2 :3 0
e2 :3 0 108 :3 0
e2 :3 0 c4 :3 0
e2 :3 0 109 :3 0
57 :3 0 a9 :3 0
a5 :3 0 10a :3 0
cc :3 0 a5 :3 0
57 :3 0 9e :3 0
a5 :3 0 9e :3 0
10a :3 0 57 :3 0
10b :3 0 e2 :3 0
fb :3 0 e2 :3 0
155 :3 0 e2 :3 0
156 :3 0 e2 :3 0
158 :3 0 e2 :3 0
e1 :3 0 e2 :3 0
10c :3 0 10d :3 0
bb :3 0 159 :3 0
e2 :3 0 f5 :3 0
e2 :3 0 10f :3 0
e2 :3 0 110 :3 0
e2 :3 0 111 :3 0
e2 :3 0 112 :3 0
e2 :3 0 113 :3 0
e2 :3 0 114 :3 0
e2 :3 0 15a :3 0
e2 :3 0 115 :3 0
e2 :3 0 131 :3 0
e2 :3 0 131 :3 0
131 :3 0 e2 :3 0
15b :3 0 15c :3 0
131 :3 0 17f :3 0
180 :3 0 15d :3 0
1b :3 0 3b :3 0
e2 :3 0 15e :3 0
e2 :3 0 181 :3 0
ed :3 0 15e :3 0
1b :3 0 3b :3 0
e2 :3 0 15f :3 0
e2 :3 0 182 :3 0
ed :3 0 15f :3 0
1b :3 0 e2 :3 0
161 :3 0 e2 :3 0
14c :3 0 e2 :3 0
161 :3 0 161 :3 0
e2 :3 0 143 :3 0
162 :3 0 163 :3 0
e2 :3 0 79 :3 0
e2 :3 0 e1 :3 0
e2 :3 0 79 :3 0
e2 :3 0 15e :3 0
e2 :3 0 181 :3 0
e2 :3 0 15f :3 0
e2 :3 0 182 :3 0
164 :3 0 e2 :3 0
165 :3 0 183 :3 0
bb :3 0 166 :3 0
e2 :3 0 167 :3 0
184 :3 0 bb :3 0
168 :3 0 e2 :3 0
169 :3 0 e2 :3 0
16a :3 0 185 :3 0
bb :3 0 16b :3 0
57 :3 0 a9 :3 0
a5 :3 0 c7 :3 0
cc :3 0 a5 :3 0
57 :3 0 9e :3 0
a5 :3 0 9e :3 0
c8 :3 0 57 :3 0
a9 :3 0 a5 :3 0
c9 :3 0 cc :3 0
a5 :3 0 57 :3 0
9e :3 0 a5 :3 0
9e :3 0 c9 :3 0
57 :3 0 a9 :3 0
a5 :3 0 bd :3 0
cc :3 0 a5 :3 0
57 :3 0 9e :3 0
a5 :3 0 9e :3 0
bd :3 0 57 :3 0
a9 :3 0 a5 :3 0
cb :3 0 cc :3 0
a5 :3 0 57 :3 0
9e :3 0 a5 :3 0
9e :3 0 cb :3 0
57 :3 0 a9 :3 0
b9 :3 0 d2 :3 0
57 :3 0 a9 :3 0
186 :3 0 d2 :3 0
d2 :3 0 e2 :3 0
170 :3 0 e2 :3 0
171 :3 0 e2 :3 0
173 :3 0 a6 :3 0
57 :3 0 a7 :3 0
78 :3 0 e2 :3 0
e2 :3 0 79 :3 0
d :3 0 57 :3 0
d7 :3 0 e2 :3 0
d7 :3 0 ce :3 0
cf :3 0 a7 :3 0
116 :3 0 103 :3 0
57 :3 0 102 :3 0
103 :3 0 5b :3 0
ce :3 0 cf :3 0
a7 :3 0 116 :3 0
106 :3 0 3b :3 0
57 :3 0 105 :3 0
57 :3 0 102 :3 0
106 :3 0 5b :3 0
ce :3 0 cf :3 0
a7 :3 0 117 :3 0
10d :3 0 10d :3 0
5b :3 0 e2 :3 0
10c :3 0 ce :3 0
cf :3 0 a7 :3 0
187 :3 0 183 :3 0
183 :3 0 5b :3 0
e2 :3 0 165 :3 0
ce :3 0 cf :3 0
a7 :3 0 187 :3 0
184 :3 0 184 :3 0
5b :3 0 e2 :3 0
167 :3 0 ce :3 0
cf :3 0 a7 :3 0
188 :3 0 185 :3 0
185 :3 0 5b :3 0
e2 :3 0 16a :3 0
ce :3 0 cf :3 0
a7 :3 0 d3 :3 0
b9 :3 0 b9 :3 0
b1 :3 0 57 :3 0
b1 :3 0 ce :3 0
cf :3 0 a7 :3 0
d3 :3 0 186 :3 0
57 :3 0 9e :3 0
186 :3 0 b1 :3 0
56 :3 0 bb :4 0
1eb 1 :a 0 1f17
:2 0 1f3b 1d78 1f15
:2 0 2e :3 0 2f
:3 0 1f18 1f19 0
2e :3 0 3f :3 0
1f1b 1f1c 0 14
:2 0 2 :4 0 1ec
:2 0 41 :2 0 14
:2 0 a1c 1f21 1f23
:3 0 a1f 1f1d 1f25
1f1a 1f27 1f26 :2 0
31 :3 0 42 :3 0
1f29 1f2a 0 33
:4 0 1ed :4 0 36
:2 0 37 :3 0 a23
1f2e 1f30 :3 0 a26
1f2b 1f32 :2 0 1f34
a29 1f35 1f28 1f34
0 1f36 a2b 0
1f3b 8 :3 0 28
:3 0 1f38 :2 0 1f3b
76 :3 0 a2d 1f3c
1d76 1f3b 0 23b2
3b :3 0 15 :3 0
16 :2 0 a31 1f3d
1f40 51 :2 0 90
:2 0 a36 1f42 1f44
:3 0 b5 :3 0 29
:3 0 57 :3 0 d7
:3 0 5b :3 0 57
:3 0 9e :3 0 57
:3 0 a9 :3 0 a5
:3 0 ba :3 0 cc
:3 0 a5 :3 0 57
:3 0 9e :3 0 a5
:3 0 9e :3 0 57
:3 0 a9 :3 0 b9
:3 0 bb :3 0 6e
:3 0 b9 :3 0 57
:3 0 9e :3 0 b9
:3 0 5b :3 0 b9
:3 0 bb :3 0 18c
:3 0 b9 :3 0 57
:3 0 9e :3 0 b9
:3 0 5b :3 0 bb
:3 0 57 :3 0 a9
:3 0 49 :3 0 18e
:3 0 57 :3 0 a9
:3 0 49 :3 0 18f
:3 0 56 :3 0 57
:3 0 d7 :3 0 57
:3 0 ff :3 0 ed
:3 0 ee :3 0 ed
:3 0 ef :3 0 f9
:3 0 ed :3 0 100
:3 0 ed :3 0 101
:3 0 ed :3 0 17a
:3 0 ed :3 0 174
:3 0 17b :3 0 ed
:3 0 147 :3 0 ed
:3 0 148 :3 0 149
:3 0 ed :3 0 14a
:3 0 ed :3 0 14b
:3 0 14c :3 0 ed
:3 0 138 :3 0 ed
:3 0 14d :3 0 14e
:3 0 17 :3 0 58
:3 0 57 :3 0 a9
:3 0 a5 :3 0 ca
:3 0 cc :3 0 a5
:3 0 57 :3 0 9e
:3 0 a5 :3 0 9e
:3 0 57 :3 0 ca
:3 0 ca :3 0 ed
:3 0 1ee :3 0 57
:3 0 102 :3 0 103
:3 0 bb :3 0 104
:3 0 3b :3 0 57
:3 0 105 :3 0 57
:3 0 102 :3 0 105
:3 0 106 :3 0 bb
:3 0 107 :3 0 c2
:3 0 108 :3 0 c4
:3 0 109 :3 0 57
:3 0 a9 :3 0 a5
:3 0 10a :3 0 cc
:3 0 a5 :3 0 57
:3 0 9e :3 0 a5
:3 0 9e :3 0 10a
:3 0 57 :3 0 10b
:3 0 fb :3 0 ed
:3 0 155 :3 0 ed
:3 0 156 :3 0 158
:3 0 e1 :3 0 10c
:3 0 159 :3 0 f5
:3 0 10f :3 0 110
:3 0 111 :3 0 112
:3 0 113 :3 0 114
:3 0 1ef :3 0 57
:3 0 a9 :3 0 a5
:3 0 c7 :3 0 cc
:3 0 a5 :3 0 57
:3 0 9e :3 0 a5
:3 0 9e :3 0 c8
:3 0 57 :3 0 a9
:3 0 a5 :3 0 c9
:3 0 cc :3 0 a5
:3 0 57 :3 0 9e
:3 0 a5 :3 0 9e
:3 0 c9 :3 0 57
:3 0 a9 :3 0 a5
:3 0 bd :3 0 cc
:3 0 a5 :3 0 57
:3 0 9e :3 0 a5
:3 0 9e :3 0 bd
:3 0 57 :3 0 a9
:3 0 a5 :3 0 cb
:3 0 cc :3 0 a5
:3 0 57 :3 0 9e
:3 0 a5 :3 0 9e
:3 0 cb :3 0 a6
:3 0 57 :3 0 ce
:3 0 cf :3 0 a7
:3 0 116 :3 0 103
:3 0 57 :3 0 102
:3 0 103 :3 0 5b
:3 0 ce :3 0 cf
:3 0 a7 :3 0 116
:3 0 106 :3 0 3b
:3 0 57 :3 0 105
:3 0 57 :3 0 102
:3 0 106 :3 0 5b
:3 0 57 :3 0 10b
:3 0 57 :3 0 5b
:3 0 d :3 0 56
:3 0 bb :4 0 1f0
1 :a 0 2021 :2 0
2045 1f47 201f :2 0
2e :3 0 2f :3 0
2022 2023 0 2e
:3 0 3f :3 0 2025
2026 0 14 :2 0
2 :4 0 1f1 :2 0
41 :2 0 14 :2 0
a39 202b 202d :3 0
a3c 2027 202f 2024
2031 2030 :2 0 31
:3 0 42 :3 0 2033
2034 0 33 :4 0
1f2 :4 0 36 :2 0
37 :3 0 a40 2038
203a :3 0 a43 2035
203c :2 0 203e a46
203f 2032 203e 0
2040 a48 0 2045
8 :3 0 29 :3 0
2042 :2 0 2045 76
:3 0 a4a 2046 1f45
2045 0 23b2 3b
:3 0 15 :3 0 16
:2 0 a4e 2047 204a
51 :2 0 1f3 :2 0
a53 204c 204e :3 0
9a :3 0 9b :3 0
1f4 :4 0 2052 :4 0
2053 :2 0 229b 9
:3 0 5d :3 0 2055
2056 0 16 :2 0
2057 2058 0 229b
1f5 :3 0 9e :3 0
a9 :3 0 1f6 :3 0
9e :3 0 a9 :3 0
1f6 :3 0 78 :3 0
55 :3 0 d :3 0
e1 :3 0 1f7 :3 0
49 :3 0 1f8 :3 0
9e :3 0 a9 :4 0
1f9 1 :8 0 2080
ab :4 0 206b :3 0
50 :3 0 51 :2 0
a58 206e 206f :3 0
9 :3 0 5d :3 0
2071 2072 0 16
:2 0 2073 2074 0
2076 a5b 207d 9
:3 0 5d :3 0 2077
2078 0 ac :2 0
2079 207a 0 207c
a5d 207e 2070 2076
0 207f 0 207c
0 207f a5f 0
2080 a62 20d3 5f
:3 0 9 :3 0 5d
:3 0 2082 2083 0
5e :3 0 2084 2085
0 2087 a65 2089
a67 2088 2087 :2 0
20d1 60 :3 0 9
:3 0 5d :3 0 208c
208d 0 5e :3 0
208e 208f 0 20c9
2e :3 0 2f :3 0
2091 2092 0 2e
:3 0 3f :3 0 2094
2095 0 61 :2 0
2 :4 0 1fa :2 0
41 :2 0 14 :2 0
a69 209a 209c :3 0
a6c 2096 209e 2093
20a0 209f :2 0 31
:3 0 42 :3 0 20a2
20a3 0 33 :4 0
1fb :4 0 36 :2 0
37 :3 0 a70 20a7
20a9 :3 0 36 :2 0
47 :4 0 a73 20ab
20ad :3 0 36 :2 0
64 :4 0 a76 20af
20b1 :3 0 36 :2 0
5e :3 0 a79 20b3
20b5 :3 0 36 :2 0
65 :4 0 a7c 20b7
20b9 :3 0 36 :2 0
66 :3 0 67 :3 0
14 :2 0 68 :2 0
a7f 20bc 20c0 a83
20bb 20c2 :3 0 a86
20a4 20c4 :2 0 20c6
a89 20c7 20a1 20c6
0 20c8 a8b 0
20c9 a8d 20cc :3 0
20cc 0 20cc 20cb
20c9 20ca :6 0 20ce
36 :3 0 a90 20d0
a92 20cf 20ce :2 0
20d1 a94 :2 0 20d3
0 20d3 20d2 2080
20d1 :6 0 229b 1
:3 0 9a :3 0 9b
:3 0 1fc :4 0 20d7
:4 0 20d8 :2 0 229b
9 :3 0 5d :3 0
20da 20db 0 16
:2 0 20dc 20dd 0
229b 1fd :3 0 9e
:3 0 a9 :3 0 1f6
:3 0 9e :3 0 a9
:3 0 1f6 :3 0 78
:3 0 55 :3 0 d
:3 0 e3 :3 0 d
:3 0 9e :3 0 a9
:4 0 1fe 1 :8 0
2103 ab :4 0 20ee
:3 0 50 :3 0 51
:2 0 a99 20f1 20f2
:3 0 9 :3 0 5d
:3 0 20f4 20f5 0
16 :2 0 20f6 20f7
0 20f9 a9c 2100
9 :3 0 5d :3 0
20fa 20fb 0 ac
:2 0 20fc 20fd 0
20ff a9e 2101 20f3
20f9 0 2102 0
20ff 0 2102 aa0
0 2103 aa3 2156
5f :3 0 9 :3 0
5d :3 0 2105 2106
0 5e :3 0 2107
2108 0 210a aa6
210c aa8 210b 210a
:2 0 2154 60 :3 0
9 :3 0 5d :3 0
210f 2110 0 5e
:3 0 2111 2112 0
214c 2e :3 0 2f
:3 0 2114 2115 0
2e :3 0 3f :3 0
2117 2118 0 61
:2 0 2 :4 0 1ff
:2 0 41 :2 0 14
:2 0 aaa 211d 211f
:3 0 aad 2119 2121
2116 2123 2122 :2 0
31 :3 0 42 :3 0
2125 2126 0 33
:4 0 200 :4 0 36
:2 0 37 :3 0 ab1
212a 212c :3 0 36
:2 0 47 :4 0 ab4
212e 2130 :3 0 36
:2 0 64 :4 0 ab7
2132 2134 :3 0 36
:2 0 5e :3 0 aba
2136 2138 :3 0 36
:2 0 65 :4 0 abd
213a 213c :3 0 36
:2 0 66 :3 0 67
:3 0 14 :2 0 68
:2 0 ac0 213f 2143
ac4 213e 2145 :3 0
ac7 2127 2147 :2 0
2149 aca 214a 2124
2149 0 214b acc
0 214c ace 214f
:3 0 214f 0 214f
214e 214c 214d :6 0
2151 38 :3 0 ad1
2153 ad3 2152 2151
:2 0 2154 ad5 :2 0
2156 0 2156 2155
2103 2154 :6 0 229b
1 :3 0 9a :3 0
9b :3 0 201 :4 0
215a :4 0 215b :2 0
229b 9 :3 0 5d
:3 0 215d 215e 0
16 :2 0 215f 2160
0 229b 202 :3 0
9e :3 0 a9 :3 0
1f6 :3 0 57 :3 0
9e :3 0 57 :3 0
a9 :3 0 57 :3 0
1f6 :3 0 1f5 :3 0
57 :3 0 ce :3 0
cf :3 0 a7 :3 0
1fd :3 0 54 :3 0
57 :3 0 9e :3 0
54 :3 0 9e :3 0
54 :3 0 9e :3 0
54 :3 0 a9 :3 0
54 :3 0 1f6 :3 0
1fd :3 0 54 :3 0
ce :3 0 cf :3 0
a7 :3 0 1f5 :3 0
57 :3 0 57 :3 0
9e :3 0 54 :3 0
9e :4 0 203 1
:8 0 219e ab :4 0
2189 :3 0 50 :3 0
51 :2 0 ada 218c
218d :3 0 9 :3 0
5d :3 0 218f 2190
0 16 :2 0 2191
2192 0 2194 add
219b 9 :3 0 5d
:3 0 2195 2196 0
ac :2 0 2197 2198
0 219a adf 219c
218e 2194 0 219d
0 219a 0 219d
ae1 0 219e ae4
21f1 5f :3 0 9
:3 0 5d :3 0 21a0
21a1 0 5e :3 0
21a2 21a3 0 21a5
ae7 21a7 ae9 21a6
21a5 :2 0 21ef 60
:3 0 9 :3 0 5d
:3 0 21aa 21ab 0
5e :3 0 21ac 21ad
0 21e7 2e :3 0
2f :3 0 21af 21b0
0 2e :3 0 3f
:3 0 21b2 21b3 0
61 :2 0 2 :4 0
204 :2 0 41 :2 0
14 :2 0 aeb 21b8
21ba :3 0 aee 21b4
21bc 21b1 21be 21bd
:2 0 31 :3 0 42
:3 0 21c0 21c1 0
33 :4 0 205 :4 0
36 :2 0 37 :3 0
af2 21c5 21c7 :3 0
36 :2 0 47 :4 0
af5 21c9 21cb :3 0
36 :2 0 64 :4 0
af8 21cd 21cf :3 0
36 :2 0 5e :3 0
afb 21d1 21d3 :3 0
36 :2 0 65 :4 0
afe 21d5 21d7 :3 0
36 :2 0 66 :3 0
67 :3 0 14 :2 0
68 :2 0 b01 21da
21de b05 21d9 21e0
:3 0 b08 21c2 21e2
:2 0 21e4 b0b 21e5
21bf 21e4 0 21e6
b0d 0 21e7 b0f
21ea :3 0 21ea 0
21ea 21e9 21e7 21e8
:6 0 21ec 3a :3 0
b12 21ee b14 21ed
21ec :2 0 21ef b16
:2 0 21f1 0 21f1
21f0 219e 21ef :6 0
229b 1 :3 0 b5
:3 0 2a :3 0 57
:3 0 9e :3 0 5b
:3 0 b9 :3 0 ba
:3 0 bb :3 0 56
:3 0 b9 :3 0 c9
:3 0 57 :3 0 1f6
:3 0 b9 :3 0 c7
:3 0 c8 :3 0 b9
:3 0 bd :3 0 b9
:3 0 ca :3 0 b9
:3 0 cb :3 0 202
:3 0 57 :3 0 a7
:3 0 cc :3 0 b9
:3 0 57 :3 0 a9
:3 0 57 :3 0 9e
:3 0 b9 :3 0 9e
:3 0 ce :3 0 cf
:3 0 a7 :3 0 1fd
:3 0 206 :3 0 57
:3 0 9e :3 0 206
:3 0 9e :3 0 a5
:3 0 b1 :3 0 5b
:3 0 a5 :3 0 d2
:3 0 bb :3 0 56
:3 0 c9 :3 0 57
:3 0 1f6 :3 0 c8
:3 0 bd :3 0 ca
:3 0 cb :3 0 202
:3 0 57 :3 0 a7
:3 0 d3 :3 0 a5
:3 0 57 :3 0 a9
:3 0 a5 :3 0 b1
:3 0 57 :3 0 9e
:3 0 a7 :3 0 a8
:3 0 cd :3 0 cd
:3 0 5b :3 0 a5
:3 0 d4 :3 0 a7
:3 0 a8 :3 0 be
:3 0 be :3 0 5b
:3 0 cd :3 0 9f
:3 0 ce :3 0 cf
:3 0 a7 :3 0 1fd
:3 0 206 :3 0 57
:3 0 9e :3 0 206
:3 0 9e :3 0 e0
:3 0 9e :3 0 5b
:3 0 b9 :3 0 ba
:3 0 bb :3 0 56
:3 0 b9 :3 0 c9
:3 0 1f6 :3 0 b9
:3 0 c7 :3 0 c8
:3 0 b9 :3 0 bd
:3 0 b9 :3 0 ca
:3 0 b9 :3 0 cb
:3 0 a6 :3 0 e0
:3 0 cc :3 0 b9
:3 0 e0 :3 0 55
:3 0 d :3 0 e0
:3 0 9e :3 0 b9
:3 0 9e :3 0 207
:3 0 9e :3 0 202
:3 0 207 :3 0 e0
:3 0 9e :3 0 207
:3 0 9e :3 0 56
:3 0 bb :4 0 208
1 :a 0 2277 :2 0
229b 21f4 2275 :2 0
2e :3 0 2f :3 0
2278 2279 0 2e
:3 0 3f :3 0 227b
227c 0 14 :2 0
2 :4 0 209 :2 0
41 :2 0 14 :2 0
b19 2281 2283 :3 0
b1c 227d 2285 227a
2287 2286 :2 0 31
:3 0 42 :3 0 2289
228a 0 33 :4 0
20a :4 0 36 :2 0
37 :3 0 b20 228e
2290 :3 0 b23 228b
2292 :2 0 2294 b26
2295 2288 2294 0
2296 b28 0 229b
8 :3 0 2a :3 0
2298 :2 0 229b 76
:3 0 b2a 229c 204f
229b 0 23b2 3b
:3 0 15 :3 0 16
:2 0 b37 229d 22a0
51 :2 0 84 :2 0
b3c 22a2 22a4 :3 0
b :3 0 66 :3 0
b :3 0 36 :2 0
20b :4 0 b3f 22a9
22ab :3 0 14 :2 0
c :2 0 b42 22a7
22af 22a6 22b0 0
22fb b5 :3 0 2b
:3 0 e2 :3 0 5b
:3 0 b9 :3 0 ba
:3 0 bb :3 0 56
:3 0 b9 :3 0 c9
:3 0 1f6 :3 0 b9
:3 0 c7 :3 0 c8
:3 0 b9 :3 0 bd
:3 0 b9 :3 0 ca
:3 0 b9 :3 0 cb
:3 0 6e :3 0 e2
:3 0 a7 :3 0 cc
:3 0 b9 :3 0 e2
:3 0 5b :3 0 b9
:3 0 9e :3 0 e2
:3 0 56 :3 0 e2
:3 0 85 :3 0 b
:3 0 bb :4 0 20c
1 :a 0 22d7 :2 0
22fb 22b3 22d5 :2 0
2e :3 0 2f :3 0
22d8 22d9 0 2e
:3 0 3f :3 0 22db
22dc 0 14 :2 0
2 :4 0 20d :2 0
41 :2 0 14 :2 0
b46 22e1 22e3 :3 0
b49 22dd 22e5 22da
22e7 22e6 :2 0 31
:3 0 42 :3 0 22e9
22ea 0 33 :4 0
20e :4 0 36 :2 0
37 :3 0 b4d 22ee
22f0 :3 0 b50 22eb
22f2 :2 0 22f4 b53
22f5 22e8 22f4 0
22f6 b55 0 22fb
8 :3 0 2b :3 0
22f8 :2 0 22fb 76
:3 0 b57 22fc 22a5
22fb 0 23b2 3b
:3 0 15 :3 0 16
:2 0 b5c 22fd 2300
49 :3 0 51 :2 0
91 :3 0 2302 2304
0 b61 2303 2306
:3 0 2307 :2 0 3b
:3 0 15 :3 0 16
:2 0 b64 2309 230c
49 :3 0 51 :2 0
92 :3 0 230e 2310
0 b69 230f 2312
:3 0 2313 :2 0 2308
2315 2314 :2 0 b5
:3 0 2c :3 0 a5
:3 0 9e :3 0 5b
:3 0 a5 :3 0 ba
:3 0 bb :3 0 49
:3 0 190 :3 0 56
:3 0 a5 :3 0 c9
:3 0 1f6 :3 0 a5
:3 0 c7 :3 0 c8
:3 0 a5 :3 0 bd
:3 0 a5 :3 0 ca
:3 0 a5 :3 0 cb
:3 0 1ba :3 0 e0
:3 0 cc :3 0 a5
:3 0 e0 :3 0 55
:3 0 d :3 0 e0
:3 0 9e :3 0 a5
:3 0 9e :3 0 bb
:4 0 20f 1 :a 0
233c :2 0 235f 2318
233a :2 0 2e :3 0
2f :3 0 233d 233e
0 2e :3 0 3f
:3 0 2340 2341 0
14 :2 0 2 :4 0
210 :2 0 41 :2 0
14 :2 0 b6c 2346
2348 :3 0 b6f 2342
234a 233f 234c 234b
:2 0 31 :3 0 42
:3 0 234e 234f 0
33 :4 0 211 :4 0
36 :2 0 37 :3 0
b73 2353 2355 :3 0
b76 2350 2357 :2 0
2359 b79 235a 234d
2359 0 235b b7b
0 235f 8 :3 0
2c :3 0 235d :2 0
235f b7d 2360 2316
235f 0 23b2 2e
:3 0 2f :3 0 2361
2362 0 2e :3 0
3f :3 0 2364 2365
0 195 :2 0 2
:4 0 212 :2 0 41
:2 0 14 :2 0 b81
236a 236c :3 0 b84
2366 236e 2363 2370
236f :2 0 31 :3 0
42 :3 0 2372 2373
0 33 :4 0 213
:4 0 36 :2 0 37
:3 0 b88 2377 2379
:3 0 36 :2 0 47
:4 0 b8b 237b 237d
:3 0 36 :2 0 48
:4 0 b8e 237f 2381
:3 0 36 :2 0 3b
:3 0 3c :3 0 49
:3 0 4a :3 0 2386
2387 0 b91 2385
2389 3d :4 0 b93
2384 238c b96 2383
238e :3 0 36 :2 0
4b :4 0 b99 2390
2392 :3 0 36 :2 0
39 :4 0 b9c 2394
2396 :3 0 36 :2 0
3 :3 0 b9f 2398
239a :3 0 36 :2 0
39 :4 0 ba2 239c
239e :3 0 ba5 2374
23a0 :2 0 23a2 ba8
23a3 2371 23a2 0
23a4 baa 0 23af
4e :3 0 214 :3 0
23a5 23a6 0 49
:3 0 4a :3 0 23a8
23a9 0 3 :3 0
50 :3 0 bac 23a7
23ad :2 0 23af bb0
23b1 70b 987 0
23b2 0 23af 0
23b2 bb3 0 23b3
bc3 2454 9 :3 0
215 :2 0 4 23b4
23b5 0 2e :3 0
2f :3 0 23b7 23b8
0 2e :3 0 3f
:3 0 23ba 23bb 0
61 :2 0 2 :4 0
216 :2 0 41 :2 0
14 :2 0 bcc 23c0
23c2 :3 0 bcf 23bc
23c4 23b9 23c6 23c5
:2 0 31 :3 0 42
:3 0 23c8 23c9 0
33 :4 0 217 :4 0
36 :2 0 37 :3 0
bd3 23cd 23cf :3 0
bd6 23ca 23d1 :2 0
23ea 31 :3 0 42
:3 0 23d3 23d4 0
33 :4 0 218 :4 0
36 :2 0 9 :3 0
219 :3 0 23d9 23da
0 bd9 23d8 23dc
:3 0 36 :2 0 4b
:4 0 bdc 23de 23e0
:3 0 36 :2 0 9
:3 0 21a :3 0 23e3
23e4 0 bdf 23e2
23e6 :3 0 be2 23d5
23e8 :2 0 23ea be5
23eb 23c7 23ea 0
23ec be8 0 23fc
b5 :3 0 2d :3 0
9 :3 0 219 :3 0
21b :3 0 9 :3 0
21a :3 0 21c :3 0
130 :4 0 21d 1
:a 0 23f8 :2 0 23fc
23ee 23f6 :2 0 8
:3 0 2d :3 0 23fa
:2 0 23fc bea 23fe
bee 23fd 23fc :2 0
2452 60 :3 0 9
:3 0 5d :3 0 2401
2402 0 5e :3 0
2403 2404 0 244a
2e :3 0 2f :3 0
2406 2407 0 2e
:3 0 3f :3 0 2409
240a 0 61 :2 0
2 :4 0 21e :2 0
41 :2 0 14 :2 0
bf0 240f 2411 :3 0
bf3 240b 2413 2408
2415 2414 :2 0 31
:3 0 42 :3 0 2417
2418 0 33 :4 0
21f :4 0 36 :2 0
37 :3 0 bf7 241c
241e :3 0 bfa 2419
2420 :2 0 243a 31
:3 0 42 :3 0 2422
2423 0 33 :4 0
64 :4 0 36 :2 0
5e :3 0 bfd 2427
2429 :3 0 36 :2 0
65 :4 0 c00 242b
242d :3 0 36 :2 0
66 :3 0 67 :3 0
14 :2 0 68 :2 0
c03 2430 2434 c07
242f 2436 :3 0 c0a
2424 2438 :2 0 243a
c0d 243b 2416 243a
0 243c c10 0
244a b5 :3 0 2d
:3 0 21b :3 0 9
:3 0 21a :3 0 21c
:3 0 130 :4 0 220
1 :a 0 2446 :2 0
244a 243e 2444 :2 0
8 :3 0 2d :3 0
2448 :2 0 244a c12
244d :3 0 244d 0
244d 244c 244a 244b
:6 0 244f 1 :3 0
c17 2451 c19 2450
244f :2 0 2452 c1b
:2 0 2454 c1e 2454
2453 23b3 2452 :6 0
2455 :2 0 2 14
2454 2458 :3 0 2457
2455 2459 :8 0 
c3d
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
40 1 46 1
4c 1 52 1
58 1 5e 1
66 1 64 1
6d 1 6b 1
72 1 79 1
80 1 87 1
8e 1 95 1
9c 1 a3 1
aa 1 b1 1
b8 1 bf 1
c6 1 cd 1
d4 1 db 1
e8 1 f4 2
f7 f9 2 fc
fe 2 100 102
2 104 106 2
108 10a 1 110
2 112 113 2
10c 115 2 117
119 2 11b 11d
2 11f 121 2
123 125 2 127
129 4 f0 f6
fb 12b 1 12d
1 12f 2 139
13b 3 137 138
13d 2 146 148
2 145 14a 1
14c 1 14e 1
150 2 15d 15f
3 15b 15c 161
2 16a 16c 2
16e 170 2 172
174 1 17c 2
17e 17f 2 176
181 2 183 185
2 187 189 2
18b 18d 2 18f
191 2 169 193
1 195 1 197
2 1a1 1a3 3
19f 1a0 1a5 2
1ae 1b0 2 1ad
1b2 1 1b4 1
1b6 3 1bd 1be
1bf 3 198 1b7
1c1 1 1c3 2
1cf 1d0 1 1d4
2 1d2 1d4 2
1d9 1da 1 1de
2 1dc 1de 2
1fc 201 1 208
1 203 2 21b
21d 3 219 21a
21f 2 228 22a
2 22c 22e 2
230 232 2 234
236 2 238 23a
3 23f 240 241
2 23c 243 2
227 245 1 247
1 249 2 212
24a 1 24e 1
20d 2 20b 252
1 25d 2 259
25d 2 276 27b
1 282 1 27d
2 295 297 3
293 294 299 2
2a2 2a4 2 2a6
2a8 2 2aa 2ac
2 2ae 2b0 2
2b2 2b4 3 2b9
2ba 2bb 2 2b6
2bd 2 2a1 2bf
1 2c1 1 2c3
2 28c 2c4 1
2c8 1 287 2
285 2cc 1 2d7
2 2d3 2d7 2
2df 2e4 1 2eb
1 2e6 2 2fe
300 3 2fc 2fd
302 2 30b 30d
2 30f 311 2
313 315 2 317
319 2 31b 31d
3 322 323 324
2 31f 326 2
30a 328 1 32a
1 32c 2 2f5
32d 1 331 1
2f0 2 2ee 335
1 340 2 33c
340 2 34c 34e
3 34a 34b 350
2 359 35b 2
35d 35f 2 361
363 1 36b 2
36d 36e 2 365
370 2 372 374
2 376 378 2
37a 37c 2 37e
380 2 358 382
1 384 1 386
2 390 392 3
38e 38f 394 2
39d 39f 2 39c
3a1 1 3a3 1
3a5 3 3ac 3ad
3ae 3 387 3a6
3b0 1 3b2 2
338 3b3 1 3b5
2 2cf 3b6 1
3b8 2 255 3b9
2 3bd 3be 1
3c2 2 3c0 3c2
2 3ca 3cf 1
3d6 1 3d1 2
3e9 3eb 3 3e7
3e8 3ed 2 3f6
3f8 2 3fa 3fc
2 3fe 400 2
402 404 2 406
408 3 40d 40e
40f 2 40a 411
2 3f5 413 1
415 1 417 2
3e0 418 1 41c
1 3db 2 3d9
420 1 42b 2
427 42b 2 437
439 3 435 436
43b 2 444 446
2 448 44a 2
44c 44e 1 456
2 458 459 2
450 45b 2 45d
45f 2 461 463
2 465 467 2
469 46b 2 443
46d 1 46f 1
471 2 47b 47d
3 479 47a 47f
2 488 48a 2
487 48c 1 48e
1 490 3 497
498 499 3 472
491 49b 1 49d
2 4a7 4ac 1
4b3 1 4ae 2
4c6 4c8 3 4c4
4c5 4ca 2 4d3
4d5 2 4d7 4d9
2 4db 4dd 2
4df 4e1 2 4e3
4e5 3 4ea 4eb
4ec 2 4e7 4ee
2 4d2 4f0 1
4f2 1 4f4 2
4bd 4f5 1 4f9
1 4b8 2 4b6
4fd 3 423 49e
500 2 506 507
1 50b 2 509
50b 2 513 518
1 51f 1 51a
2 532 534 3
530 531 536 2
53f 541 2 543
545 2 547 549
2 54b 54d 2
54f 551 3 556
557 558 2 553
55a 2 53e 55c
1 55e 1 560
2 529 561 1
565 1 524 2
522 569 1 574
2 570 574 2
580 582 3 57e
57f 584 2 58d
58f 2 591 593
2 595 597 1
59f 2 5a1 5a2
2 599 5a4 2
5a6 5a8 2 5aa
5ac 2 5ae 5b0
2 5b2 5b4 2
58c 5b6 1 5b8
1 5ba 2 5c4
5c6 3 5c2 5c3
5c8 2 5d1 5d3
2 5d0 5d5 1
5d7 1 5d9 3
5e0 5e1 5e2 3
5bb 5da 5e4 1
5e6 3 56c 5e7
5ea 2 5ef 5f0
1 5f6 2 5f2
5f6 2 5fb 5fc
1 600 2 5fe
600 2 607 608
1 60e 2 60a
60e 2 615 616
1 61c 2 618
61c 2 62a 62f
1 636 1 631
2 649 64b 3
647 648 64d 2
656 658 2 65a
65c 2 65e 660
2 662 664 2
666 668 3 66d
66e 66f 2 66a
671 2 655 673
1 675 1 677
2 640 678 1
67c 1 63b 2
639 680 1 68b
2 687 68b 2
697 699 3 695
696 69b 2 6a4
6a6 2 6a8 6aa
2 6ac 6ae 1
6b6 2 6b8 6b9
2 6b0 6bb 2
6bd 6bf 2 6c1
6c3 2 6c5 6c7
2 6c9 6cb 2
6a3 6cd 1 6cf
1 6d1 2 6db
6dd 3 6d9 6da
6df 2 6e8 6ea
2 6e7 6ec 1
6ee 1 6f0 3
6f7 6f8 6f9 3
6d2 6f1 6fb 1
6fd 2 683 6fe
4 701 504 5ed
700 2 704 705
1 709 2 707
709 1 73b 2
73a 73b 1 743
1 749 2 74b
74c 2 738 74d
1 754 1 74f
2 767 769 3
765 766 76b 2
774 776 2 778
77a 2 77c 77e
2 780 782 2
784 786 3 78b
78c 78d 2 788
78f 2 773 791
1 793 1 795
2 75e 796 1
79a 1 759 2
757 79e 1 7b7
2 7b6 7b7 1
7bf 1 7c5 2
7c7 7c8 2 7b4
7c9 1 7d0 1
7cb 2 7e3 7e5
3 7e1 7e2 7e7
2 7f0 7f2 2
7f4 7f6 2 7f8
7fa 2 7fc 7fe
2 800 802 3
807 808 809 2
804 80b 2 7ef
80d 1 80f 1
811 2 7da 812
1 816 1 7d5
2 7d3 81a 2
96c 96e 3 96a
96b 970 2 979
97b 2 978 97d
1 97f 1 981
9 710 715 7a1
7a7 7ac 81d 962
982 985 2 989
98a 1 98e 2
98c 98e 2 993
994 1 998 2
996 998 1 9d1
2 9d0 9d1 1
9d9 1 9df 2
9e1 9e2 2 9ce
9e3 1 9ea 1
9e5 2 9fd 9ff
3 9fb 9fc a01
2 a0a a0c 2
a0e a10 2 a12
a14 2 a16 a18
2 a1a a1c 3
a21 a22 a23 2
a1e a25 2 a09
a27 1 a29 1
a2b 2 9f4 a2c
1 a30 1 9ef
2 9ed a34 1
a71 2 a70 a71
1 a79 1 a7f
2 a81 a82 2
a6e a83 1 a8a
1 a85 2 a9d
a9f 3 a9b a9c
aa1 2 aaa aac
2 aae ab0 2
ab2 ab4 2 ab6
ab8 2 aba abc
3 ac1 ac2 ac3
2 abe ac5 2
aa9 ac7 1 ac9
1 acb 2 a94
acc 1 ad0 1
a8f 2 a8d ad4
2 b3a b3c 3
b38 b39 b3e 2
b47 b49 2 b46
b4b 1 b4d 1
b4f 8 9a2 9a7
a37 a3f ad7 b30
b50 b53 2 b58
b59 1 b5d 2
b5b b5d 2 bf8
bfa 3 bf6 bf7
bfc 2 c05 c07
2 c04 c09 1
c0b 1 c0d 3
bee c0e c11 2
c16 c17 1 c1b
2 c19 c1b 2
c28 c2d 1 c34
1 c2f 2 c47
c49 3 c45 c46
c4b 2 c54 c56
2 c58 c5a 2
c5c c5e 2 c60
c62 2 c64 c66
3 c6b c6c c6d
2 c68 c6f 2
c53 c71 1 c73
1 c75 2 c3e
c76 1 c7a 1
c39 2 c37 c7e
1 c89 2 c85
c89 2 c90 c91
1 c95 2 c93
c95 2 ca2 ca7
1 cae 1 ca9
2 cc1 cc3 3
cbf cc0 cc5 2
cce cd0 2 cd2
cd4 2 cd6 cd8
2 cda cdc 2
cde ce0 3 ce5
ce6 ce7 2 ce2
ce9 2 ccd ceb
1 ced 1 cef
2 cb8 cf0 1
cf4 1 cb3 2
cb1 cf8 1 d03
2 cff d03 2
d0a d0b 1 d0f
2 d0d d0f 1
d17 2 d1e d23
1 d2a 1 d25
2 d3d d3f 3
d3b d3c d41 2
d4a d4c 2 d4e
d50 2 d52 d54
2 d56 d58 2
d5a d5c 3 d61
d62 d63 2 d5e
d65 2 d49 d67
1 d69 1 d6b
2 d34 d6c 1
d70 1 d2f 2
d2d d74 1 d77
2 d7a d7b 2
cfb d7c 2 d83
d88 1 d8f 1
d8a 2 da2 da4
3 da0 da1 da6
2 daf db1 2
db3 db5 2 db7
db9 2 dbb dbd
2 dbf dc1 3
dc6 dc7 dc8 2
dc3 dca 2 dae
dcc 1 dce 1
dd0 2 d99 dd1
1 dd5 1 d94
2 d92 dd9 1
ddc 2 ddf de0
2 de4 de5 1
de7 1 deb 2
de9 deb 2 df8
dfd 1 e04 1
dff 2 e17 e19
3 e15 e16 e1b
2 e24 e26 2
e28 e2a 2 e2c
e2e 2 e30 e32
2 e34 e36 3
e3b e3c e3d 2
e38 e3f 2 e23
e41 1 e43 1
e45 2 e0e e46
1 e4a 1 e09
2 e07 e4e 2
e54 e55 1 e59
2 e57 e59 1
e5e 2 e6c e71
1 e78 1 e73
2 e8b e8d 3
e89 e8a e8f 2
e98 e9a 2 e9c
e9e 2 ea0 ea2
2 ea4 ea6 2
ea8 eaa 3 eaf
eb0 eb1 2 eac
eb3 2 e97 eb5
1 eb7 1 eb9
2 e82 eba 1
ebe 1 e7d 2
e7b ec2 2 ec8
ec9 1 ecd 2
ecb ecd 2 eec
ef1 1 ef8 1
ef3 2 f0b f0d
3 f09 f0a f0f
2 f18 f1a 2
f1c f1e 2 f20
f22 2 f24 f26
2 f28 f2a 3
f2f f30 f31 2
f2c f33 2 f17
f35 1 f37 1
f39 2 f02 f3a
1 f3e 1 efd
2 efb f42 2
f48 f49 1 f4d
2 f4b f4d 1
f52 1 f56 2
f58 f59 2 f45
f5a 1 f5e 2
f60 f61 3 e62
ec5 f62 2 f64
f65 2 1204 1206
3 1202 1203 1208
2 1211 1213 2
1210 1215 1 1217
1 1219 6 df0
e51 f66 11fa 121a
121d 2 13d0 13d2
3 13ce 13cf 13d4
2 13dd 13df 2
13dc 13e1 1 13e3
1 13e5 3 13c6
13e6 13e9 2 13eb
13ec 4 c20 c81
de1 13ed 2 13f2
13f3 1 13f7 2
13f5 13f7 1 142e
2 142d 142e 1
1436 1 143c 2
143e 143f 2 142b
1440 1 1447 1
1442 2 145a 145c
3 1458 1459 145e
2 1467 1469 2
146b 146d 2 146f
1471 2 1473 1475
2 1477 1479 3
147e 147f 1480 2
147b 1482 2 1466
1484 1 1486 1
1488 2 1451 1489
1 148d 1 144c
2 144a 1491 1
14d5 2 14d4 14d5
1 14dd 1 14e3
2 14e5 14e6 2
14d2 14e7 1 14ee
1 14e9 2 1501
1503 3 14ff 1500
1505 2 150e 1510
2 1512 1514 2
1516 1518 2 151a
151c 2 151e 1520
3 1525 1526 1527
2 1522 1529 2
150d 152b 1 152d
1 152f 2 14f8
1530 1 1534 1
14f3 2 14f1 1538
2 15a1 15a3 3
159f 15a0 15a5 2
15ae 15b0 2 15ad
15b2 1 15b4 1
15b6 8 13fe 1403
1494 149c 153b 1597
15b7 15ba 2 15bf
15c0 1 15c4 2
15c2 15c4 1 15fb
2 15fa 15fb 1
1603 1 1609 2
160b 160c 2 15f8
160d 1 1614 1
160f 2 1627 1629
3 1625 1626 162b
2 1634 1636 2
1638 163a 2 163c
163e 2 1640 1642
2 1644 1646 3
164b 164c 164d 2
1648 164f 2 1633
1651 1 1653 1
1655 2 161e 1656
1 165a 1 1619
2 1617 165e 1
16cf 2 16ce 16cf
1 16d7 1 16dd
2 16df 16e0 2
16cc 16e1 1 16e8
1 16e3 2 16fb
16fd 3 16f9 16fa
16ff 2 1708 170a
2 170c 170e 2
1710 1712 2 1714
1716 2 1718 171a
3 171f 1720 1721
2 171c 1723 2
1707 1725 1 1727
1 1729 2 16f2
172a 1 172e 1
16ed 2 16eb 1732
2 17d7 17d9 3
17d5 17d6 17db 2
17e4 17e6 2 17e3
17e8 1 17ea 1
17ec 8 15cb 15d0
1661 1669 1735 17cd
17ed 17f0 2 17f5
17f6 1 17fa 2
17f8 17fa 2 18fc
18fe 3 18fa 18fb
1900 2 1909 190b
2 1908 190d 1
190f 1 1911 3
18f2 1912 1915 2
191a 191b 1 191f
2 191d 191f 1
195e 2 195d 195e
1 1966 1 196c
2 196e 196f 2
195b 1970 1 1977
1 1972 2 198a
198c 3 1988 1989
198e 2 1997 1999
2 199b 199d 2
199f 19a1 2 19a3
19a5 2 19a7 19a9
3 19ae 19af 19b0
2 19ab 19b2 2
1996 19b4 1 19b6
1 19b8 2 1981
19b9 1 19bd 1
197c 2 197a 19c1
1 1a44 2 1a43
1a44 1 1a4c 1
1a52 2 1a54 1a55
2 1a41 1a56 1
1a5d 1 1a58 2
1a70 1a72 3 1a6e
1a6f 1a74 2 1a7d
1a7f 2 1a81 1a83
2 1a85 1a87 2
1a89 1a8b 2 1a8d
1a8f 3 1a94 1a95
1a96 2 1a91 1a98
2 1a7c 1a9a 1
1a9c 1 1a9e 2
1a67 1a9f 1 1aa3
1 1a62 2 1a60
1aa7 1 1abf 2
1abe 1abf 1 1ac7
1 1acd 2 1acf
1ad0 2 1abc 1ad1
1 1ad8 1 1ad3
2 1aeb 1aed 3
1ae9 1aea 1aef 2
1af8 1afa 2 1afc
1afe 2 1b00 1b02
2 1b04 1b06 2
1b08 1b0a 3 1b0f
1b10 1b11 2 1b0c
1b13 2 1af7 1b15
1 1b17 1 1b19
2 1ae2 1b1a 1
1b1e 1 1add 2
1adb 1b22 2 1c17
1c19 3 1c15 1c16
1c1b 2 1c24 1c26
2 1c23 1c28 1
1c2a 1 1c2c a
1926 192b 19c4 19ca
19cf 1aaa 1b25 1c0d
1c2d 1c30 2 1c35
1c36 1 1c3c 2
1c38 1c3c 2 1c44
1c49 1 1c50 1
1c4b 2 1c63 1c65
3 1c61 1c62 1c67
2 1c70 1c72 2
1c74 1c76 2 1c78
1c7a 2 1c7c 1c7e
2 1c80 1c82 3
1c87 1c88 1c89 2
1c84 1c8b 2 1c6f
1c8d 1 1c8f 1
1c91 2 1c5a 1c92
1 1c96 1 1c55
2 1c53 1c9a 1
1ca5 2 1ca1 1ca5
2 1d4e 1d50 3
1d4c 1d4d 1d52 2
1d5b 1d5d 2 1d5a
1d5f 1 1d61 1
1d63 3 1d44 1d64
1d67 1 1d69 2
1c9d 1d6a 2 1d6f
1d70 1 1d74 2
1d72 1d74 2 1f20
1f22 3 1f1e 1f1f
1f24 2 1f2d 1f2f
2 1f2c 1f31 1
1f33 1 1f35 3
1f16 1f36 1f39 2
1f3e 1f3f 1 1f43
2 1f41 1f43 2
202a 202c 3 2028
2029 202e 2 2037
2039 2 2036 203b
1 203d 1 203f
3 2020 2040 2043
2 2048 2049 1
204d 2 204b 204d
1 206d 2 206c
206d 1 2075 1
207b 2 207d 207e
2 206a 207f 1
2086 1 2081 2
2099 209b 3 2097
2098 209d 2 20a6
20a8 2 20aa 20ac
2 20ae 20b0 2
20b2 20b4 2 20b6
20b8 3 20bd 20be
20bf 2 20ba 20c1
2 20a5 20c3 1
20c5 1 20c7 2
2090 20c8 1 20cc
1 208b 2 2089
20d0 1 20f0 2
20ef 20f0 1 20f8
1 20fe 2 2100
2101 2 20ed 2102
1 2109 1 2104
2 211c 211e 3
211a 211b 2120 2
2129 212b 2 212d
212f 2 2131 2133
2 2135 2137 2
2139 213b 3 2140
2141 2142 2 213d
2144 2 2128 2146
1 2148 1 214a
2 2113 214b 1
214f 1 210e 2
210c 2153 1 218b
2 218a 218b 1
2193 1 2199 2
219b 219c 2 2188
219d 1 21a4 1
219f 2 21b7 21b9
3 21b5 21b6 21bb
2 21c4 21c6 2
21c8 21ca 2 21cc
21ce 2 21d0 21d2
2 21d4 21d6 3
21db 21dc 21dd 2
21d8 21df 2 21c3
21e1 1 21e3 1
21e5 2 21ae 21e6
1 21ea 1 21a9
2 21a7 21ee 2
2280 2282 3 227e
227f 2284 2 228d
228f 2 228c 2291
1 2293 1 2295
c 2054 2059 20d3
20d9 20de 2156 215c
2161 21f1 2276 2296
2299 2 229e 229f
1 22a3 2 22a1
22a3 2 22a8 22aa
3 22ac 22ad 22ae
2 22e0 22e2 3
22de 22df 22e4 2
22ed 22ef 2 22ec
22f1 1 22f3 1
22f5 4 22b1 22d6
22f6 22f9 2 22fe
22ff 1 2305 2
2301 2305 2 230a
230b 1 2311 2
230d 2311 2 2345
2347 3 2343 2344
2349 2 2352 2354
2 2351 2356 1
2358 1 235a 3
233b 235b 235e 2
2369 236b 3 2367
2368 236d 2 2376
2378 2 237a 237c
2 237e 2380 1
2388 2 238a 238b
2 2382 238d 2
238f 2391 2 2393
2395 2 2397 2399
2 239b 239d 2
2375 239f 1 23a1
1 23a3 3 23aa
23ab 23ac 2 23a4
23ae f 23b0 b56
c14 13f0 15bd 17f3
1918 1c33 1d6d 1f3c
2046 229c 22fc 2360
23b1 8 130 14f
1c4 1c7 1ca 1cd
702 23b2 2 23bf
23c1 3 23bd 23be
23c3 2 23cc 23ce
2 23cb 23d0 2
23d7 23db 2 23dd
23df 2 23e1 23e5
2 23d6 23e7 2
23d2 23e9 1 23eb
3 23ec 23f7 23fb
1 23b6 2 240e
2410 3 240c 240d
2412 2 241b 241d
2 241a 241f 2
2426 2428 2 242a
242c 3 2431 2432
2433 2 242e 2435
2 2425 2437 2
2421 2439 1 243b
4 2405 243c 2445
2449 1 244d 1
2400 2 23fe 2451
1e 1b 22 29
30 37 3e 44
4a 50 56 5c
62 69 70 77
7e 85 8c 93
9a a1 a8 af
b6 bd c4 cb
d2 d9 e0 
1
4
0 
2458
0
1
50
3c
22
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 1 36 1
38 1 3a 1 5353 4749 5f4e 4b53
4c49 534c 7320 4f20 204e 2e70 5250 464f
4c49 5f45 4449 733d 522e 5345 415f 5353

d4 1 0
b 1 0
cd 1 0
52 1 0
2 0 1
72 1 0
79 1 0
80 1 0
58 1 0
8e 1 0
4c 1 0
95 1 0
9c 1 0
a3 1 0
aa 1 0
b1 1 0
3 1 0
b8 1 0
bf 1 0
c6 1 0
87 1 0
40 1 0
1d 1 0
16 1 0
5e 1 0
6b 1 0
39 1 0
32 1 0
2b 1 0
46 1 0
7 1 0
24 1 0
64 1 0
db 1 0
0

/
SHOW ERRORS FUNCTION SP_S_PROFILE;
ALTER FUNCTION SP_S_PROFILE COMPILE DEBUG;
/*********************************************************************************************************************************************/
Prompt == FUNCTION FC_U_NAMES ==
CREATE OR REPLACE FUNCTION FC_U_NAMES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
6f
2 :e:
1FUNCTION:
1FC_U_NAMES:
1A_ELEMENT_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1H_FULL_NAME:
1A_PARTICIPANT_ID:
1SH_H_TABLE_TYPE:
1PLS_INTEGER:
1RETURN:
1H_TABLE_TYPE:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_NAMES(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
119:
1+:
1FPUT:
1               ENTER:: FC_U_NAMES(20) :: cplan.sql(16224) :: :
1PMO_CNST:
1SC_TABLE_SCD:
1TMT_ASSIGNED_SCORECARDS:
1ASSIGN_NAMES:
1INSTR:
1REPLACE:
1LENGTH:
1ELEMENT_ID:
1UPDATE TMT_ASSIGNED_SCORECARDS SET ASSIGN_NAMES =:n            CASE:n        +
1    WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_ful+
1l_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            +
1ELSE:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_+
1NAMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIG+
1N_NAMES:n            END:n            END:n            WHERE ELEMENT_ID = a_e+
1lement_id:
1FOUND:
1TRUE:
1=:
1PMO_DB2M:
1SC_STATE:
10:
1100:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
148:
1           EXCEPTION:: FC_U_NAMES(49) :: cplan.sql(16253) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_TABLE_POL:
1TMT_POOLS:
1MANAGER_ID:
1UPDATE TMT_POOLS SET MANAGER_ID = a_participant_id, ASSIGN_NAMES =:n         +
1   CASE:n            WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n     +
1       THEN h_full_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', +
1''):n            ELSE:n            CASE:n            WHEN LENGTH(h_full_name)+
1 + LENGTH(ASSIGN_NAMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_nam+
1e || ';' || ASSIGN_NAMES:n            END:n            END:n            WHERE+
1 ELEMENT_ID = a_element_id:
180:
1           EXCEPTION:: FC_U_NAMES(81) :: cplan.sql(16285) :: :
1SC_TABLE_CRI:
1TMT_CRI:
1UPDATE TMT_CRI SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || ';' ||+
1 REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n          +
1  CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2040 TH+
1EN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n       +
1     END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1111:
1           EXCEPTION:: FC_U_NAMES(112) :: cplan.sql(16316) :: :
1SC_TABLE_DOC:
1TMT_DOCUMENTS:
1UPDATE TMT_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            WHEN I+
1nStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || +
1';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n    +
1        CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2+
1040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n +
1           END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1143:
1           EXCEPTION:: FC_U_NAMES(144) :: cplan.sql(16348) :: :
1SC_TABLE_POL_DOC:
1TMT_POOL_DOCUMENTS:
1UPDATE TMT_POOL_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            W+
1HEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_nam+
1e || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE+
1:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAME+
1S) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NA+
1MES:n            END:n            END:n            WHERE ELEMENT_ID = a_eleme+
1nt_id:
1175:
1           EXCEPTION:: FC_U_NAMES(176) :: cplan.sql(16380) :: :
1SC_TABLE_RES_DOC:
1TMT_RESOURCE_DOCUMENTS:
1UPDATE TMT_RESOURCE_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n         +
1   WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full+
1_name || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            E+
1LSE:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_N+
1AMES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN+
1_NAMES:n            END:n            END:n            WHERE ELEMENT_ID = a_el+
1ement_id:
1207:
1           EXCEPTION:: FC_U_NAMES(208) :: cplan.sql(16412) :: :
1SC_TABLE_AST_DOC:
1TMT_ASSET_DOCUMENTS:
1UPDATE TMT_ASSET_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n            +
1WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_na+
1me || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE+
1:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAME+
1S) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NA+
1MES:n            END:n            END:n            WHERE ELEMENT_ID = a_eleme+
1nt_id:
1239:
1           EXCEPTION:: FC_U_NAMES(240) :: cplan.sql(16444) :: :
1SC_TABLE_CLN_DOC:
1TMT_CLIENT_DOCUMENTS:
1UPDATE TMT_CLIENT_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n           +
1 WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_n+
1ame || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELS+
1E:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAM+
1ES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_N+
1AMES:n            END:n            END:n            WHERE ELEMENT_ID = a_elem+
1ent_id:
1271:
1           EXCEPTION:: FC_U_NAMES(272) :: cplan.sql(16476) :: :
1SC_TABLE_VDR_DOC:
1TMT_VENDOR_DOCUMENTS:
1UPDATE TMT_VENDOR_DOCUMENTS SET ASSIGN_NAMES =:n            CASE:n           +
1 WHEN InStr( ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_n+
1ame || ';' || REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELS+
1E:n            CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAM+
1ES) > 2040 THEN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_N+
1AMES:n            END:n            END:n            WHERE ELEMENT_ID = a_elem+
1ent_id:
1303:
1           EXCEPTION:: FC_U_NAMES(304) :: cplan.sql(16508) :: :
1TMT_WBS:
1UPDATE TMT_WBS SET ASSIGN_NAMES =:n            CASE:n            WHEN InStr( +
1ASSIGN_NAMES, h_full_name || ';') > 0:n            THEN h_full_name || ';' ||+
1 REPLACE( ASSIGN_NAMES, h_full_name || ';', ''):n            ELSE:n          +
1  CASE:n            WHEN LENGTH(h_full_name) + LENGTH(ASSIGN_NAMES) > 2040 TH+
1EN ASSIGN_NAMES:n            ELSE h_full_name || ';' || ASSIGN_NAMES:n       +
1     END:n            END:n            WHERE ELEMENT_ID = a_element_id:
1335:
1           EXCEPTION:: FC_U_NAMES(336) :: cplan.sql(16540) :: :
1343:
1                EXIT:: FC_U_NAMES(344) :: cplan.sql(16548) :: :
1STATE:: :
0

0
0
5fc
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 8f
a0 b0 3d b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a6 9 :2 a0 6b
:14 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a6 9 :2 a0 6b :12 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 a6 9
:2 a0 6b :12 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a6 9 :2 a0 6b :12 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
a6 9 :2 a0 6b :12 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a6 9 :2 a0
6b :12 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 a6 9 :2 a0 6b :12 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 a6
9 :2 a0 6b :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a6 9 :12 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 9
a4 14 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
5fc
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 73 6f 37
7b 6e 80 84 88 8c a9 94
98 a0 a4 6b 90 b0 b4 b7
bb bf c2 c7 c8 1 ca cf
d3 d7 da df e3 e7 ea ef
f0 f2 f7 fa fe ff 104 109
10c 111 112 117 11a 11e 11f 124
127 12c 12d 132 135 13a 13b 140
143 148 149 14e 151 155 156 15b
15e 163 164 169 16c 171 172 177
17a 17f 180 185 188 18c 18d 192
195 19a 19b 1a0 1a3 1a8 1a9 1ae
1b1 1b5 1b9 1bd 1be 1c0 1c5 1c6
1c8 1c9 1ce 1d1 1d6 1d7 1dc 1dd
1e2 1e4 1e8 1eb 1ef 1f3 1f6 1fa
1fe 201 204 209 20c 20f 212 213
218 219 1 21b 220 224 228 22b
230 235 238 23c 23d 242 243 248
24a 24e 251 255 259 25d 260 264
268 26c 270 274 278 27c 280 284
288 28c 290 294 298 29c 2a0 2a4
2a8 2b4 2b8 2bd 2c1 2c4 2c5 2ca
2ce 2d2 2d5 2d8 2dc 2de 2e2 2e6
2e9 2ec 2f0 2f2 2f6 2fa 2fd 2ff
303 307 30b 30e 312 316 318 319
31e 1 322 326 32a 32d 331 335
339 33d 340 344 348 34b 34e 353
356 359 35c 35d 362 363 1 365
36a 36e 372 375 37a 37f 382 386
387 38c 38f 394 395 39a 39d 3a2
3a3 3a8 3ab 3af 3b0 3b5 3b8 3bd
3be 3c3 3c6 3ca 3ce 3d1 3d4 3d5
3d7 3d8 3dd 3de 3e3 3e5 3e9 3ec
3ee 3f2 3f4 400 402 404 405 40a
40e 410 41c 41e 420 421 426 42a
42e 431 435 439 43d 441 445 449
44d 451 455 459 45d 461 465 469
46d 471 475 479 47d 481 48d 491
496 49a 49d 49e 4a3 4a7 4ab 4ae
4b1 4b5 4b7 4bb 4bf 4c2 4c5 4c9
4cb 4cf 4d3 4d6 4d8 4dc 4e0 4e4
4e7 4eb 4ef 4f1 4f2 4f7 1 4fb
4ff 503 506 50a 50e 512 516 519
51d 521 524 527 52c 52f 532 535
536 53b 53c 1 53e 543 547 54b
54e 553 558 55b 55f 560 565 568
56d 56e 573 576 57b 57c 581 584
588 589 58e 591 596 597 59c 59f
5a3 5a7 5aa 5ad 5ae 5b0 5b1 5b6
5b7 5bc 5be 5c2 5c5 5c7 5cb 5cd
5d9 5db 5dd 5de 5e3 5e7 5e9 5f5
5f7 5f9 5fa 5ff 603 607 60a 60e
612 616 61a 61e 622 626 62a 62e
632 636 63a 63e 642 646 64a 64e
652 65e 662 667 66b 66e 66f 674
678 67c 67f 682 686 688 68c 690
693 696 69a 69c 6a0 6a4 6a7 6a9
6ad 6b1 6b5 6b8 6bc 6c0 6c2 6c3
6c8 1 6cc 6d0 6d4 6d7 6db 6df
6e3 6e7 6ea 6ee 6f2 6f5 6f8 6fd
700 703 706 707 70c 70d 1 70f
714 718 71c 71f 724 729 72c 730
731 736 739 73e 73f 744 747 74c
74d 752 755 759 75a 75f 762 767
768 76d 770 774 778 77b 77e 77f
781 782 787 788 78d 78f 793 796
798 79c 79e 7aa 7ac 7ae 7af 7b4
7b8 7ba 7c6 7c8 7ca 7cb 7d0 7d4
7d8 7db 7df 7e3 7e7 7eb 7ef 7f3
7f7 7fb 7ff 803 807 80b 80f 813
817 81b 81f 823 82f 833 838 83c
83f 840 845 849 84d 850 853 857
859 85d 861 864 867 86b 86d 871
875 878 87a 87e 882 886 889 88d
891 893 894 899 1 89d 8a1 8a5
8a8 8ac 8b0 8b4 8b8 8bb 8bf 8c3
8c6 8c9 8ce 8d1 8d4 8d7 8d8 8dd
8de 1 8e0 8e5 8e9 8ed 8f0 8f5
8fa 8fd 901 902 907 90a 90f 910
915 918 91d 91e 923 926 92a 92b
930 933 938 939 93e 941 945 949
94c 94f 950 952 953 958 959 95e
960 964 967 969 96d 96f 97b 97d
97f 980 985 989 98b 997 999 99b
99c 9a1 9a5 9a9 9ac 9b0 9b4 9b8
9bc 9c0 9c4 9c8 9cc 9d0 9d4 9d8
9dc 9e0 9e4 9e8 9ec 9f0 9f4 a00
a04 a09 a0d a10 a11 a16 a1a a1e
a21 a24 a28 a2a a2e a32 a35 a38
a3c a3e a42 a46 a49 a4b a4f a53
a57 a5a a5e a62 a64 a65 a6a 1
a6e a72 a76 a79 a7d a81 a85 a89
a8c a90 a94 a97 a9a a9f aa2 aa5
aa8 aa9 aae aaf 1 ab1 ab6 aba
abe ac1 ac6 acb ace ad2 ad3 ad8
adb ae0 ae1 ae6 ae9 aee aef af4
af7 afb afc b01 b04 b09 b0a b0f
b12 b16 b1a b1d b20 b21 b23 b24
b29 b2a b2f b31 b35 b38 b3a b3e
b40 b4c b4e b50 b51 b56 b5a b5c
b68 b6a b6c b6d b72 b76 b7a b7d
b81 b85 b89 b8d b91 b95 b99 b9d
ba1 ba5 ba9 bad bb1 bb5 bb9 bbd
bc1 bc5 bd1 bd5 bda bde be1 be2
be7 beb bef bf2 bf5 bf9 bfb bff
c03 c06 c09 c0d c0f c13 c17 c1a
c1c c20 c24 c28 c2b c2f c33 c35
c36 c3b 1 c3f c43 c47 c4a c4e
c52 c56 c5a c5d c61 c65 c68 c6b
c70 c73 c76 c79 c7a c7f c80 1
c82 c87 c8b c8f c92 c97 c9c c9f
ca3 ca4 ca9 cac cb1 cb2 cb7 cba
cbf cc0 cc5 cc8 ccc ccd cd2 cd5
cda cdb ce0 ce3 ce7 ceb cee cf1
cf2 cf4 cf5 cfa cfb d00 d02 d06
d09 d0b d0f d11 d1d d1f d21 d22
d27 d2b d2d d39 d3b d3d d3e d43
d47 d4b d4e d52 d56 d5a d5e d62
d66 d6a d6e d72 d76 d7a d7e d82
d86 d8a d8e d92 d96 da2 da6 dab
daf db2 db3 db8 dbc dc0 dc3 dc6
dca dcc dd0 dd4 dd7 dda dde de0
de4 de8 deb ded df1 df5 df9 dfc
e00 e04 e06 e07 e0c 1 e10 e14
e18 e1b e1f e23 e27 e2b e2e e32
e36 e39 e3c e41 e44 e47 e4a e4b
e50 e51 1 e53 e58 e5c e60 e63
e68 e6d e70 e74 e75 e7a e7d e82
e83 e88 e8b e90 e91 e96 e99 e9d
e9e ea3 ea6 eab eac eb1 eb4 eb8
ebc ebf ec2 ec3 ec5 ec6 ecb ecc
ed1 ed3 ed7 eda edc ee0 ee2 eee
ef0 ef2 ef3 ef8 efc efe f0a f0c
f0e f0f f14 f18 f1c f1f f23 f27
f2b f2f f33 f37 f3b f3f f43 f47
f4b f4f f53 f57 f5b f5f f63 f67
f73 f77 f7c f80 f83 f84 f89 f8d
f91 f94 f97 f9b f9d fa1 fa5 fa8
fab faf fb1 fb5 fb9 fbc fbe fc2
fc6 fca fcd fd1 fd5 fd7 fd8 fdd
1 fe1 fe5 fe9 fec ff0 ff4 ff8
ffc fff 1003 1007 100a 100d 1012 1015
1018 101b 101c 1021 1022 1 1024 1029
102d 1031 1034 1039 103e 1041 1045 1046
104b 104e 1053 1054 1059 105c 1061 1062
1067 106a 106e 106f 1074 1077 107c 107d
1082 1085 1089 108d 1090 1093 1094 1096
1097 109c 109d 10a2 10a4 10a8 10ab 10ad
10b1 10b3 10bf 10c1 10c3 10c4 10c9 10cd
10cf 10db 10dd 10df 10e0 10e5 10e9 10ed
10f0 10f4 10f8 10fc 1100 1104 1108 110c
1110 1114 1118 111c 1120 1124 1128 112c
1130 1134 1138 1144 1148 114d 1151 1154
1155 115a 115e 1162 1165 1168 116c 116e
1172 1176 1179 117c 1180 1182 1186 118a
118d 118f 1193 1197 119b 119e 11a2 11a6
11a8 11a9 11ae 1 11b2 11b6 11ba 11bd
11c1 11c5 11c9 11cd 11d0 11d4 11d8 11db
11de 11e3 11e6 11e9 11ec 11ed 11f2 11f3
1 11f5 11fa 11fe 1202 1205 120a 120f
1212 1216 1217 121c 121f 1224 1225 122a
122d 1232 1233 1238 123b 123f 1240 1245
1248 124d 124e 1253 1256 125a 125e 1261
1264 1265 1267 1268 126d 126e 1273 1275
1279 127c 127e 1282 1284 1290 1292 1294
1295 129a 129e 12a0 12ac 12ae 12b0 12b1
12b6 12ba 12be 12c2 12c6 12ca 12ce 12d2
12d6 12da 12de 12e2 12e6 12ea 12ee 12f2
12f6 12fa 12fe 130a 130e 1313 1317 131a
131b 1320 1324 1328 132b 132e 1332 1334
1338 133c 133f 1342 1346 1348 134c 1350
1353 1355 1359 135d 1361 1364 1368 136c
136e 136f 1374 1 1378 137c 1380 1383
1387 138b 138f 1393 1396 139a 139e 13a1
13a4 13a9 13ac 13af 13b2 13b3 13b8 13b9
1 13bb 13c0 13c4 13c8 13cb 13d0 13d5
13d8 13dc 13dd 13e2 13e5 13ea 13eb 13f0
13f3 13f8 13f9 13fe 1401 1405 1406 140b
140e 1413 1414 1419 141c 1420 1424 1427
142a 142b 142d 142e 1433 1434 1439 143b
143f 1442 1444 1448 144a 1456 1458 145a
145b 1460 1464 1466 1472 1474 1476 147b
147f 1484 1488 148c 148f 1493 1497 149a
149d 14a2 14a5 14a8 14ab 14ac 14b1 14b2
1 14b4 14b9 14bd 14c1 14c4 14c9 14ce
14d1 14d5 14d6 14db 14de 14e3 14e4 14e9
14ec 14f1 14f2 14f7 14fa 14fe 1502 1505
1506 150b 150c 1511 1513 1517 151a 151e
1522 1526 1529 152d 152f 1533 1535 1541
1545 1547 1548 1551 
5fc
2
0 1 a 6 16 1a 21 :3 6
15 19 20 :3 6 1a 1e 25 :3 6
16 :2 6 1 3 a :2 1 4 :2 11
20 11 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
52 58 5b :2 52 69 7d 8 :2 69
d 10 :2 69 1d 20 :2 69 b e
:2 69 13 16 :2 69 1b 1e :2 69 2a
2d :2 69 b e :2 69 13 16 :2 69
1b 1e :2 69 2f 32 :2 69 b e
:2 69 13 16 1f 27 :2 1f 39 :2 16
:2 69 41 44 :2 69 :2 7 48 :2 4 7
:2 11 23 :2 2d 39 3c 4a 4c 4d
:2 4a :2 23 :3 7 :2 d 12 1e 5b 5e
:2 1e :2 7 50 :2 4 9 c :2 15 14
30 12 19 27 12 28 31 3f
12 19 28 2f 49 12 28 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 57 59 5a :2 57 :2 2f
:3 13 :2 19 1e 2a 67 6a :2 2a 77
7a :2 2a 7e 81 :2 2a 8d 90 :2 2a
98 9b :2 2a a7 aa b1 ba bd
:2 aa :2 2a :2 13 5d :2 10 :2 d :4 19 :2 d
a :4 22 :2 7 c :2 15 14 22 2f
41 12 19 27 12 28 31 3f
12 19 28 2f 49 12 28 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 57 59 5a :2 57 :2 2f
:3 13 :2 19 1e 2a 67 6a :2 2a 77
7a :2 2a 7e 81 :2 2a 8d 90 :2 2a
98 9b :2 2a a7 aa b1 ba bd
:2 aa :2 2a :2 13 5d :2 10 :2 d :4 19 :2 d
a :4 22 :2 7 c :2 15 14 20 12
19 27 12 28 31 3f 12 19
28 2f 49 12 28 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5e :2 10 :2 d :4 19 :2 d a :4 22
:2 7 c :2 15 14 26 12 19 27
12 28 31 3f 12 19 28 2f
49 12 28 13 20 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 57
5a 5b :2 57 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5e
:2 10 :2 d :4 19 :2 d a :4 22 :2 7 c
:2 15 14 2b 12 19 27 12 28
31 3f 12 19 28 2f 49 12
28 13 20 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 57 5a 5b
:2 57 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5e :2 10 :2 d
:4 19 :2 d a :4 26 :2 7 c :2 15 14
2f 12 19 27 12 28 31 3f
12 19 28 2f 49 12 28 13
20 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 57 5a 5b :2 57 :2 2f
:3 13 :2 19 1e 2a 68 6b :2 2a 78
7b :2 2a 7f 82 :2 2a 8e 91 :2 2a
99 9c :2 2a a8 ab b2 bb be
:2 ab :2 2a :2 13 5e :2 10 :2 d :4 19 :2 d
a :4 26 :2 7 c :2 15 14 2c 12
19 27 12 28 31 3f 12 19
28 2f 49 12 28 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5e :2 10 :2 d :4 19 :2 d a :4 26
:2 7 c :2 15 14 2d 12 19 27
12 28 31 3f 12 19 28 2f
49 12 28 13 20 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 57
5a 5b :2 57 :2 2f :3 13 :2 19 1e 2a
68 6b :2 2a 78 7b :2 2a 7f 82
:2 2a 8e 91 :2 2a 99 9c :2 2a a8
ab b2 bb be :2 ab :2 2a :2 13 5e
:2 10 :2 d :4 19 :2 d a :4 26 :2 7 c
:2 15 14 2d 12 19 27 12 28
31 3f 12 19 28 2f 49 12
28 13 20 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 57 5a 5b
:2 57 :2 2f :3 13 :2 19 1e 2a 68 6b
:2 2a 78 7b :2 2a 7f 82 :2 2a 8e
91 :2 2a 99 9c :2 2a a8 ab b2
bb be :2 ab :2 2a :2 13 5e :2 10 :2 d
:4 19 :2 d a :4 26 :2 7 14 20 12
19 27 12 28 31 3f 12 19
28 2f 49 12 28 13 20 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 57 5a 5b :2 57 :2 2f :3 13 :2 19
1e 2a 68 6b :2 2a 78 7b :2 2a
7f 82 :2 2a 8e 91 :2 2a 99 9c
:2 2a a8 ab b2 bb be :2 ab :2 2a
:2 13 5e :2 10 :2 d :4 19 :2 d a :4 7
:3 4 7 :2 11 23 :2 2d 39 3c 4a
4d 4e :2 4a :2 23 :3 7 :2 d 12 1e
5c 5f :2 1e 6c 6f :2 1e 73 76
:2 1e 80 83 :2 8c :2 1e :2 7 51 :3 4
b :2 14 4 :9 1 
5fc
4
0 :2 1 :6 3 :6 4
:6 5 :4 6 2 :2 7
:2 1 :6 9 :b b :11 c
d :2 c :2 d :2 c
:2 d :2 c :2 e :2 c
:2 e :2 c :2 e :2 c
:2 e :2 c :2 f :2 c
:2 f :2 c :2 f :2 c
:2 f :2 c :2 10 :2 c
:9 10 :2 c :2 10 :4 c
:3 b :11 13 :b 14 :3 13
17 :3 18 :2 1a :3 1c
:4 1d :5 20 :2 21 :2 24
1a :6 25 :5 26 25
:5 28 27 :3 25 19
2b :5 2c :3 2b :2 2d
:5 2f :11 30 :24 31 :3 30
:2 2e :6 2d 2a :6 18
:3 38 :4 3a :3 3c :4 3d
:5 40 :2 41 :2 44 3a
:6 45 :5 46 45 :5 48
47 :3 45 39 4b
:5 4c :3 4b :2 4d :5 4f
:11 50 :24 51 :3 50 :2 4e
:6 4d 4a :6 38 :3 57
:2 59 :3 5b :4 5c :5 5f
:2 60 :2 63 59 :6 64
:5 65 64 :5 67 66
:3 64 58 6a :5 6b
:3 6a :2 6c :5 6e :11 6f
:24 70 :3 6f :2 6d :6 6c
69 :6 57 :3 77 :2 79
:3 7b :4 7c :5 7f :2 80
:2 83 79 :6 84 :5 85
84 :5 87 86 :3 84
78 8a :5 8b :3 8a
:2 8c :5 8e :11 8f :24 90
:3 8f :2 8d :6 8c 89
:6 77 :3 97 :2 99 :3 9b
:4 9c :5 9f :2 a0 :2 a3
99 :6 a4 :5 a5 a4
:5 a7 a6 :3 a4 98
aa :5 ab :3 aa :2 ac
:5 ae :11 af :24 b0 :3 af
:2 ad :6 ac a9 :6 97
:3 b7 :2 b9 :3 bb :4 bc
:5 bf :2 c0 :2 c3 b9
:6 c4 :5 c5 c4 :5 c7
c6 :3 c4 b8 ca
:5 cb :3 ca :2 cc :5 ce
:11 cf :24 d0 :3 cf :2 cd
:6 cc c9 :6 b7 :3 d7
:2 d9 :3 db :4 dc :5 df
:2 e0 :2 e3 d9 :6 e4
:5 e5 e4 :5 e7 e6
:3 e4 d8 ea :5 eb
:3 ea :2 ec :5 ee :11 ef
:24 f0 :3 ef :2 ed :6 ec
e9 :6 d7 :3 f7 :2 f9
:3 fb :4 fc :5 ff :2 100
:2 103 f9 :6 104 :5 105
104 :5 107 106 :3 104
f8 10a :5 10b :3 10a
:2 10c :5 10e :11 10f :24 110
:3 10f :2 10d :6 10c 109
:6 f7 :3 117 :2 119 :3 11b
:4 11c :5 11f :2 120 :2 123
119 :6 124 :5 125 124
:5 127 126 :3 124 118
12a :5 12b :3 12a :2 12c
:5 12e :11 12f :24 130 :3 12f
:2 12d :6 12c 129 :6 117
:2 139 :3 13b :4 13c :5 13f
:2 140 :2 143 139 :6 144
:5 145 144 :5 147 146
:3 144 138 14a :5 14b
:3 14a :2 14c :5 14e :11 14f
:24 150 :3 14f :2 14d :6 14c
149 :4 137 :3 17 :11 157
:19 158 :3 157 :5 15a :2 a
:7 1 
1553
4
:3 0 1 :3 0 2
:a 0 5f7 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
6 :3 0 8 :5 0
1 13 12 :3 0
10 90 0 b
a :3 0 9 :7 0
17 16 :3 0 b
:3 0 a :3 0 19
1b 0 5f7 2
1c :2 0 d :3 0
a :3 0 1f :7 0
9 :3 0 23 20
21 5f5 0 c
:6 0 e :3 0 24
25 0 d :3 0
f :3 0 27 28
0 2 :4 0 12
29 2b 26 2d
2c :2 0 10 :3 0
11 :3 0 2f 30
0 12 :4 0 d
:3 0 13 :3 0 33
34 0 2 :4 0
14 35 37 14
:4 0 15 :2 0 16
:3 0 16 3a 3c
:3 0 17 :4 0 15
:2 0 18 :4 0 19
3f 41 :3 0 15
:2 0 3 :3 0 1c
43 45 :3 0 15
:2 0 18 :4 0 1f
47 49 :3 0 15
:2 0 19 :4 0 22
4b 4d :3 0 15
:2 0 18 :4 0 25
4f 51 :3 0 15
:2 0 7 :3 0 28
53 55 :3 0 15
:2 0 18 :4 0 2b
57 59 :3 0 15
:2 0 19 :4 0 2e
5b 5d :3 0 15
:2 0 18 :4 0 31
5f 61 :3 0 15
:2 0 8 :3 0 34
63 65 :3 0 15
:2 0 18 :4 0 37
67 69 :3 0 15
:2 0 19 :4 0 3a
6b 6d :3 0 15
:2 0 1a :3 0 1b
:3 0 9 :3 0 3d
71 73 1c :4 0
3f 70 76 42
6f 78 :3 0 15
:2 0 1d :4 0 45
7a 7c :3 0 48
31 7e :2 0 80
4d 81 2e 80
0 82 4f 0
5f3 d :3 0 e
:3 0 83 84 0
d :3 0 1e :3 0
86 87 0 1f
:2 0 2 :4 0 20
:2 0 21 :2 0 1f
:2 0 51 8c 8e
:3 0 54 88 90
85 92 91 :2 0
10 :3 0 22 :3 0
94 95 0 12
:4 0 23 :4 0 15
:2 0 16 :3 0 58
99 9b :3 0 5b
96 9d :2 0 9f
5e a0 93 9f
0 a1 60 0
5f3 c :3 0 24
:3 0 25 :3 0 a3
a4 0 26 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 2c 1
:8 0 ce 2d :4 0
b9 :3 0 2e :3 0
2f :2 0 64 bc
bd :3 0 30 :3 0
31 :3 0 bf c0
0 32 :2 0 c1
c2 0 c4 67
cb 30 :3 0 31
:3 0 c5 c6 0
33 :2 0 c7 c8
0 ca 69 cc
be c4 0 cd
0 ca 0 cd
6b 0 ce 6e
121 34 :3 0 30
:3 0 31 :3 0 d0
d1 0 35 :3 0
d2 d3 0 d5
71 d7 73 d6
d5 :2 0 11f 36
:3 0 30 :3 0 31
:3 0 da db 0
35 :3 0 dc dd
0 117 d :3 0
e :3 0 df e0
0 d :3 0 1e
:3 0 e2 e3 0
37 :2 0 2 :4 0
38 :2 0 21 :2 0
1f :2 0 75 e8
ea :3 0 78 e4
ec e1 ee ed
:2 0 10 :3 0 22
:3 0 f0 f1 0
12 :4 0 39 :4 0
15 :2 0 16 :3 0
7c f5 f7 :3 0
15 :2 0 3a :4 0
7f f9 fb :3 0
15 :2 0 3b :4 0
82 fd ff :3 0
15 :2 0 35 :3 0
85 101 103 :3 0
15 :2 0 3c :4 0
88 105 107 :3 0
15 :2 0 3d :3 0
3e :3 0 1f :2 0
3f :2 0 8b 10a
10e 8f 109 110
:3 0 92 f2 112
:2 0 114 95 115
ef 114 0 116
97 0 117 99
11a :3 0 11a 0
11a 119 117 118
:6 0 11c 2 :3 0
9c 11e 9e 11d
11c :2 0 11f a0
:2 0 121 0 121
120 ce 11f :6 0
123 1 :3 0 a3
125 a5 124 123
:2 0 5bf 24 :3 0
40 :3 0 126 127
0 41 :3 0 42
:3 0 8 :3 0 27
:3 0 28 :3 0 27
:3 0 7 :3 0 7
:3 0 29 :3 0 27
:3 0 7 :3 0 2a
:3 0 7 :3 0 2a
:3 0 27 :3 0 27
:3 0 7 :3 0 27
:3 0 2b :3 0 3
:4 0 43 1 :8 0
153 2d :4 0 13e
:3 0 2e :3 0 2f
:2 0 a9 141 142
:3 0 30 :3 0 31
:3 0 144 145 0
32 :2 0 146 147
0 149 ac 150
30 :3 0 31 :3 0
14a 14b 0 33
:2 0 14c 14d 0
14f ae 151 143
149 0 152 0
14f 0 152 b0
0 153 b3 1a6
34 :3 0 30 :3 0
31 :3 0 155 156
0 35 :3 0 157
158 0 15a b6
15c b8 15b 15a
:2 0 1a4 36 :3 0
30 :3 0 31 :3 0
15f 160 0 35
:3 0 161 162 0
19c d :3 0 e
:3 0 164 165 0
d :3 0 1e :3 0
167 168 0 37
:2 0 2 :4 0 44
:2 0 21 :2 0 1f
:2 0 ba 16d 16f
:3 0 bd 169 171
166 173 172 :2 0
10 :3 0 22 :3 0
175 176 0 12
:4 0 45 :4 0 15
:2 0 16 :3 0 c1
17a 17c :3 0 15
:2 0 3a :4 0 c4
17e 180 :3 0 15
:2 0 3b :4 0 c7
182 184 :3 0 15
:2 0 35 :3 0 ca
186 188 :3 0 15
:2 0 3c :4 0 cd
18a 18c :3 0 15
:2 0 3d :3 0 3e
:3 0 1f :2 0 3f
:2 0 d0 18f 193
d4 18e 195 :3 0
d7 177 197 :2 0
199 da 19a 174
199 0 19b dc
0 19c de 19f
:3 0 19f 0 19f
19e 19c 19d :6 0
1a1 4 :3 0 e1
1a3 e3 1a2 1a1
:2 0 1a4 e5 :2 0
1a6 0 1a6 1a5
153 1a4 :6 0 1a8
1 :3 0 e8 1aa
ea 1a9 1a8 :2 0
5bf 24 :3 0 46
:3 0 1ab 1ac 0
47 :3 0 27 :3 0
28 :3 0 27 :3 0
7 :3 0 7 :3 0
29 :3 0 27 :3 0
7 :3 0 2a :3 0
7 :3 0 2a :3 0
27 :3 0 27 :3 0
7 :3 0 27 :3 0
2b :3 0 3 :4 0
48 1 :8 0 1d6
2d :4 0 1c1 :3 0
2e :3 0 2f :2 0
ee 1c4 1c5 :3 0
30 :3 0 31 :3 0
1c7 1c8 0 32
:2 0 1c9 1ca 0
1cc f1 1d3 30
:3 0 31 :3 0 1cd
1ce 0 33 :2 0
1cf 1d0 0 1d2
f3 1d4 1c6 1cc
0 1d5 0 1d2
0 1d5 f5 0
1d6 f8 229 34
:3 0 30 :3 0 31
:3 0 1d8 1d9 0
35 :3 0 1da 1db
0 1dd fb 1df
fd 1de 1dd :2 0
227 36 :3 0 30
:3 0 31 :3 0 1e2
1e3 0 35 :3 0
1e4 1e5 0 21f
d :3 0 e :3 0
1e7 1e8 0 d
:3 0 1e :3 0 1ea
1eb 0 37 :2 0
2 :4 0 49 :2 0
21 :2 0 1f :2 0
ff 1f0 1f2 :3 0
102 1ec 1f4 1e9
1f6 1f5 :2 0 10
:3 0 22 :3 0 1f8
1f9 0 12 :4 0
4a :4 0 15 :2 0
16 :3 0 106 1fd
1ff :3 0 15 :2 0
3a :4 0 109 201
203 :3 0 15 :2 0
3b :4 0 10c 205
207 :3 0 15 :2 0
35 :3 0 10f 209
20b :3 0 15 :2 0
3c :4 0 112 20d
20f :3 0 15 :2 0
3d :3 0 3e :3 0
1f :2 0 3f :2 0
115 212 216 119
211 218 :3 0 11c
1fa 21a :2 0 21c
11f 21d 1f7 21c
0 21e 121 0
21f 123 222 :3 0
222 0 222 221
21f 220 :6 0 224
6 :3 0 126 226
128 225 224 :2 0
227 12a :2 0 229
0 229 228 1d6
227 :6 0 22b 1
:3 0 12d 22d 12f
22c 22b :2 0 5bf
24 :3 0 4b :3 0
22e 22f 0 4c
:3 0 27 :3 0 28
:3 0 27 :3 0 7
:3 0 7 :3 0 29
:3 0 27 :3 0 7
:3 0 2a :3 0 7
:3 0 2a :3 0 27
:3 0 27 :3 0 7
:3 0 27 :3 0 2b
:3 0 3 :4 0 4d
1 :8 0 259 2d
:4 0 244 :3 0 2e
:3 0 2f :2 0 133
247 248 :3 0 30
:3 0 31 :3 0 24a
24b 0 32 :2 0
24c 24d 0 24f
136 256 30 :3 0
31 :3 0 250 251
0 33 :2 0 252
253 0 255 138
257 249 24f 0
258 0 255 0
258 13a 0 259
13d 2ac 34 :3 0
30 :3 0 31 :3 0
25b 25c 0 35
:3 0 25d 25e 0
260 140 262 142
261 260 :2 0 2aa
36 :3 0 30 :3 0
31 :3 0 265 266
0 35 :3 0 267
268 0 2a2 d
:3 0 e :3 0 26a
26b 0 d :3 0
1e :3 0 26d 26e
0 37 :2 0 2
:4 0 4e :2 0 21
:2 0 1f :2 0 144
273 275 :3 0 147
26f 277 26c 279
278 :2 0 10 :3 0
22 :3 0 27b 27c
0 12 :4 0 4f
:4 0 15 :2 0 16
:3 0 14b 280 282
:3 0 15 :2 0 3a
:4 0 14e 284 286
:3 0 15 :2 0 3b
:4 0 151 288 28a
:3 0 15 :2 0 35
:3 0 154 28c 28e
:3 0 15 :2 0 3c
:4 0 157 290 292
:3 0 15 :2 0 3d
:3 0 3e :3 0 1f
:2 0 3f :2 0 15a
295 299 15e 294
29b :3 0 161 27d
29d :2 0 29f 164
2a0 27a 29f 0
2a1 166 0 2a2
168 2a5 :3 0 2a5
0 2a5 2a4 2a2
2a3 :6 0 2a7 8
:3 0 16b 2a9 16d
2a8 2a7 :2 0 2aa
16f :2 0 2ac 0
2ac 2ab 259 2aa
:6 0 2ae 1 :3 0
172 2b0 174 2af
2ae :2 0 5bf 24
:3 0 50 :3 0 2b1
2b2 0 51 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 52 1
:8 0 2dc 2d :4 0
2c7 :3 0 2e :3 0
2f :2 0 178 2ca
2cb :3 0 30 :3 0
31 :3 0 2cd 2ce
0 32 :2 0 2cf
2d0 0 2d2 17b
2d9 30 :3 0 31
:3 0 2d3 2d4 0
33 :2 0 2d5 2d6
0 2d8 17d 2da
2cc 2d2 0 2db
0 2d8 0 2db
17f 0 2dc 182
32f 34 :3 0 30
:3 0 31 :3 0 2de
2df 0 35 :3 0
2e0 2e1 0 2e3
185 2e5 187 2e4
2e3 :2 0 32d 36
:3 0 30 :3 0 31
:3 0 2e8 2e9 0
35 :3 0 2ea 2eb
0 325 d :3 0
e :3 0 2ed 2ee
0 d :3 0 1e
:3 0 2f0 2f1 0
37 :2 0 2 :4 0
53 :2 0 21 :2 0
1f :2 0 189 2f6
2f8 :3 0 18c 2f2
2fa 2ef 2fc 2fb
:2 0 10 :3 0 22
:3 0 2fe 2ff 0
12 :4 0 54 :4 0
15 :2 0 16 :3 0
190 303 305 :3 0
15 :2 0 3a :4 0
193 307 309 :3 0
15 :2 0 3b :4 0
196 30b 30d :3 0
15 :2 0 35 :3 0
199 30f 311 :3 0
15 :2 0 3c :4 0
19c 313 315 :3 0
15 :2 0 3d :3 0
3e :3 0 1f :2 0
3f :2 0 19f 318
31c 1a3 317 31e
:3 0 1a6 300 320
:2 0 322 1a9 323
2fd 322 0 324
1ab 0 325 1ad
328 :3 0 328 0
328 327 325 326
:6 0 32a a :3 0
1b0 32c 1b2 32b
32a :2 0 32d 1b4
:2 0 32f 0 32f
32e 2dc 32d :6 0
331 1 :3 0 1b7
333 1b9 332 331
:2 0 5bf 24 :3 0
55 :3 0 334 335
0 56 :3 0 27
:3 0 28 :3 0 27
:3 0 7 :3 0 7
:3 0 29 :3 0 27
:3 0 7 :3 0 2a
:3 0 7 :3 0 2a
:3 0 27 :3 0 27
:3 0 7 :3 0 27
:3 0 2b :3 0 3
:4 0 57 1 :8 0
35f 2d :4 0 34a
:3 0 2e :3 0 2f
:2 0 1bd 34d 34e
:3 0 30 :3 0 31
:3 0 350 351 0
32 :2 0 352 353
0 355 1c0 35c
30 :3 0 31 :3 0
356 357 0 33
:2 0 358 359 0
35b 1c2 35d 34f
355 0 35e 0
35b 0 35e 1c4
0 35f 1c7 3b2
34 :3 0 30 :3 0
31 :3 0 361 362
0 35 :3 0 363
364 0 366 1ca
368 1cc 367 366
:2 0 3b0 36 :3 0
30 :3 0 31 :3 0
36b 36c 0 35
:3 0 36d 36e 0
3a8 d :3 0 e
:3 0 370 371 0
d :3 0 1e :3 0
373 374 0 37
:2 0 2 :4 0 58
:2 0 21 :2 0 1f
:2 0 1ce 379 37b
:3 0 1d1 375 37d
372 37f 37e :2 0
10 :3 0 22 :3 0
381 382 0 12
:4 0 59 :4 0 15
:2 0 16 :3 0 1d5
386 388 :3 0 15
:2 0 3a :4 0 1d8
38a 38c :3 0 15
:2 0 3b :4 0 1db
38e 390 :3 0 15
:2 0 35 :3 0 1de
392 394 :3 0 15
:2 0 3c :4 0 1e1
396 398 :3 0 15
:2 0 3d :3 0 3e
:3 0 1f :2 0 3f
:2 0 1e4 39b 39f
1e8 39a 3a1 :3 0
1eb 383 3a3 :2 0
3a5 1ee 3a6 380
3a5 0 3a7 1f0
0 3a8 1f2 3ab
:3 0 3ab 0 3ab
3aa 3a8 3a9 :6 0
3ad c :3 0 1f5
3af 1f7 3ae 3ad
:2 0 3b0 1f9 :2 0
3b2 0 3b2 3b1
35f 3b0 :6 0 3b4
1 :3 0 1fc 3b6
1fe 3b5 3b4 :2 0
5bf 24 :3 0 5a
:3 0 3b7 3b8 0
5b :3 0 27 :3 0
28 :3 0 27 :3 0
7 :3 0 7 :3 0
29 :3 0 27 :3 0
7 :3 0 2a :3 0
7 :3 0 2a :3 0
27 :3 0 27 :3 0
7 :3 0 27 :3 0
2b :3 0 3 :4 0
5c 1 :8 0 3e2
2d :4 0 3cd :3 0
2e :3 0 2f :2 0
202 3d0 3d1 :3 0
30 :3 0 31 :3 0
3d3 3d4 0 32
:2 0 3d5 3d6 0
3d8 205 3df 30
:3 0 31 :3 0 3d9
3da 0 33 :2 0
3db 3dc 0 3de
207 3e0 3d2 3d8
0 3e1 0 3de
0 3e1 209 0
3e2 20c 435 34
:3 0 30 :3 0 31
:3 0 3e4 3e5 0
35 :3 0 3e6 3e7
0 3e9 20f 3eb
211 3ea 3e9 :2 0
433 36 :3 0 30
:3 0 31 :3 0 3ee
3ef 0 35 :3 0
3f0 3f1 0 42b
d :3 0 e :3 0
3f3 3f4 0 d
:3 0 1e :3 0 3f6
3f7 0 37 :2 0
2 :4 0 5d :2 0
21 :2 0 1f :2 0
213 3fc 3fe :3 0
216 3f8 400 3f5
402 401 :2 0 10
:3 0 22 :3 0 404
405 0 12 :4 0
5e :4 0 15 :2 0
16 :3 0 21a 409
40b :3 0 15 :2 0
3a :4 0 21d 40d
40f :3 0 15 :2 0
3b :4 0 220 411
413 :3 0 15 :2 0
35 :3 0 223 415
417 :3 0 15 :2 0
3c :4 0 226 419
41b :3 0 15 :2 0
3d :3 0 3e :3 0
1f :2 0 3f :2 0
229 41e 422 22d
41d 424 :3 0 230
406 426 :2 0 428
233 429 403 428
0 42a 235 0
42b 237 42e :3 0
42e 0 42e 42d
42b 42c :6 0 430
e :3 0 23a 432
23c 431 430 :2 0
433 23e :2 0 435
0 435 434 3e2
433 :6 0 437 1
:3 0 241 439 243
438 437 :2 0 5bf
24 :3 0 5f :3 0
43a 43b 0 60
:3 0 27 :3 0 28
:3 0 27 :3 0 7
:3 0 7 :3 0 29
:3 0 27 :3 0 7
:3 0 2a :3 0 7
:3 0 2a :3 0 27
:3 0 27 :3 0 7
:3 0 27 :3 0 2b
:3 0 3 :4 0 61
1 :8 0 465 2d
:4 0 450 :3 0 2e
:3 0 2f :2 0 247
453 454 :3 0 30
:3 0 31 :3 0 456
457 0 32 :2 0
458 459 0 45b
24a 462 30 :3 0
31 :3 0 45c 45d
0 33 :2 0 45e
45f 0 461 24c
463 455 45b 0
464 0 461 0
464 24e 0 465
251 4b8 34 :3 0
30 :3 0 31 :3 0
467 468 0 35
:3 0 469 46a 0
46c 254 46e 256
46d 46c :2 0 4b6
36 :3 0 30 :3 0
31 :3 0 471 472
0 35 :3 0 473
474 0 4ae d
:3 0 e :3 0 476
477 0 d :3 0
1e :3 0 479 47a
0 37 :2 0 2
:4 0 62 :2 0 21
:2 0 1f :2 0 258
47f 481 :3 0 25b
47b 483 478 485
484 :2 0 10 :3 0
22 :3 0 487 488
0 12 :4 0 63
:4 0 15 :2 0 16
:3 0 25f 48c 48e
:3 0 15 :2 0 3a
:4 0 262 490 492
:3 0 15 :2 0 3b
:4 0 265 494 496
:3 0 15 :2 0 35
:3 0 268 498 49a
:3 0 15 :2 0 3c
:4 0 26b 49c 49e
:3 0 15 :2 0 3d
:3 0 3e :3 0 1f
:2 0 3f :2 0 26e
4a1 4a5 272 4a0
4a7 :3 0 275 489
4a9 :2 0 4ab 278
4ac 486 4ab 0
4ad 27a 0 4ae
27c 4b1 :3 0 4b1
0 4b1 4b0 4ae
4af :6 0 4b3 10
:3 0 27f 4b5 281
4b4 4b3 :2 0 4b6
283 :2 0 4b8 0
4b8 4b7 465 4b6
:6 0 4ba 1 :3 0
286 4bc 288 4bb
4ba :2 0 5bf 24
:3 0 64 :3 0 4bd
4be 0 65 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 66 1
:8 0 4e8 2d :4 0
4d3 :3 0 2e :3 0
2f :2 0 28c 4d6
4d7 :3 0 30 :3 0
31 :3 0 4d9 4da
0 32 :2 0 4db
4dc 0 4de 28f
4e5 30 :3 0 31
:3 0 4df 4e0 0
33 :2 0 4e1 4e2
0 4e4 291 4e6
4d8 4de 0 4e7
0 4e4 0 4e7
293 0 4e8 296
53b 34 :3 0 30
:3 0 31 :3 0 4ea
4eb 0 35 :3 0
4ec 4ed 0 4ef
299 4f1 29b 4f0
4ef :2 0 539 36
:3 0 30 :3 0 31
:3 0 4f4 4f5 0
35 :3 0 4f6 4f7
0 531 d :3 0
e :3 0 4f9 4fa
0 d :3 0 1e
:3 0 4fc 4fd 0
37 :2 0 2 :4 0
67 :2 0 21 :2 0
1f :2 0 29d 502
504 :3 0 2a0 4fe
506 4fb 508 507
:2 0 10 :3 0 22
:3 0 50a 50b 0
12 :4 0 68 :4 0
15 :2 0 16 :3 0
2a4 50f 511 :3 0
15 :2 0 3a :4 0
2a7 513 515 :3 0
15 :2 0 3b :4 0
2aa 517 519 :3 0
15 :2 0 35 :3 0
2ad 51b 51d :3 0
15 :2 0 3c :4 0
2b0 51f 521 :3 0
15 :2 0 3d :3 0
3e :3 0 1f :2 0
3f :2 0 2b3 524
528 2b7 523 52a
:3 0 2ba 50c 52c
:2 0 52e 2bd 52f
509 52e 0 530
2bf 0 531 2c1
534 :3 0 534 0
534 533 531 532
:6 0 536 12 :3 0
2c4 538 2c6 537
536 :2 0 539 2c8
:2 0 53b 0 53b
53a 4e8 539 :6 0
53d 1 :3 0 2cb
53f 2cd 53e 53d
:2 0 5bf 69 :3 0
27 :3 0 28 :3 0
27 :3 0 7 :3 0
7 :3 0 29 :3 0
27 :3 0 7 :3 0
2a :3 0 7 :3 0
2a :3 0 27 :3 0
27 :3 0 7 :3 0
27 :3 0 2b :3 0
3 :4 0 6a 1
:8 0 568 2d :4 0
553 :3 0 2e :3 0
2f :2 0 2d1 556
557 :3 0 30 :3 0
31 :3 0 559 55a
0 32 :2 0 55b
55c 0 55e 2d4
565 30 :3 0 31
:3 0 55f 560 0
33 :2 0 561 562
0 564 2d6 566
558 55e 0 567
0 564 0 567
2d8 0 568 2db
5bb 34 :3 0 30
:3 0 31 :3 0 56a
56b 0 35 :3 0
56c 56d 0 56f
2de 571 2e0 570
56f :2 0 5b9 36
:3 0 30 :3 0 31
:3 0 574 575 0
35 :3 0 576 577
0 5b1 d :3 0
e :3 0 579 57a
0 d :3 0 1e
:3 0 57c 57d 0
37 :2 0 2 :4 0
6b :2 0 21 :2 0
1f :2 0 2e2 582
584 :3 0 2e5 57e
586 57b 588 587
:2 0 10 :3 0 22
:3 0 58a 58b 0
12 :4 0 6c :4 0
15 :2 0 16 :3 0
2e9 58f 591 :3 0
15 :2 0 3a :4 0
2ec 593 595 :3 0
15 :2 0 3b :4 0
2ef 597 599 :3 0
15 :2 0 35 :3 0
2f2 59b 59d :3 0
15 :2 0 3c :4 0
2f5 59f 5a1 :3 0
15 :2 0 3d :3 0
3e :3 0 1f :2 0
3f :2 0 2f8 5a4
5a8 2fc 5a3 5aa
:3 0 2ff 58c 5ac
:2 0 5ae 302 5af
589 5ae 0 5b0
304 0 5b1 306
5b4 :3 0 5b4 0
5b4 5b3 5b1 5b2
:6 0 5b6 14 :3 0
309 5b8 30b 5b7
5b6 :2 0 5b9 30d
:2 0 5bb 0 5bb
5ba 568 5b9 :6 0
5bd 1 :3 0 310
5be 0 5bd :2 0
5bf 312 :2 0 5c0
a2 5bf 0 5f3
0 d :3 0 e
:3 0 5c1 5c2 0
d :3 0 1e :3 0
5c4 5c5 0 1f
:2 0 2 :4 0 6d
:2 0 21 :2 0 1f
:2 0 31d 5ca 5cc
:3 0 320 5c6 5ce
5c3 5d0 5cf :2 0
10 :3 0 22 :3 0
5d2 5d3 0 12
:4 0 6e :4 0 15
:2 0 16 :3 0 324
5d7 5d9 :3 0 15
:2 0 3a :4 0 327
5db 5dd :3 0 15
:2 0 6f :4 0 32a
5df 5e1 :3 0 15
:2 0 30 :3 0 31
:3 0 5e4 5e5 0
32d 5e3 5e7 :3 0
330 5d4 5e9 :2 0
5eb 333 5ec 5d1
5eb 0 5ed 335
0 5f3 b :3 0
30 :3 0 31 :3 0
5ef 5f0 0 5f1
:2 0 5f3 337 5f6
:3 0 5f6 33d 5f6
5f5 5f3 5f4 :6 0
5f7 :2 0 2 1c
5f6 5fa :3 0 5f9
5f7 5fb :8 0 
33f
4
:3 0 1 3 1
9 1 f 1
15 4 8 e
14 18 1 1e
1 2a 1 36
2 39 3b 2
3e 40 2 42
44 2 46 48
2 4a 4c 2
4e 50 2 52
54 2 56 58
2 5a 5c 2
5e 60 2 62
64 2 66 68
2 6a 6c 1
72 2 74 75
2 6e 77 2
79 7b 4 32
38 3d 7d 1
7f 1 81 2
8b 8d 3 89
8a 8f 2 98
9a 2 97 9c
1 9e 1 a0
1 bb 2 ba
bb 1 c3 1
c9 2 cb cc
2 b8 cd 1
d4 1 cf 2
e7 e9 3 e5
e6 eb 2 f4
f6 2 f8 fa
2 fc fe 2
100 102 2 104
106 3 10b 10c
10d 2 108 10f
2 f3 111 1
113 1 115 2
de 116 1 11a
1 d9 2 d7
11e 1 121 1
a5 1 140 2
13f 140 1 148
1 14e 2 150
151 2 13d 152
1 159 1 154
2 16c 16e 3
16a 16b 170 2
179 17b 2 17d
17f 2 181 183
2 185 187 2
189 18b 3 190
191 192 2 18d
194 2 178 196
1 198 1 19a
2 163 19b 1
19f 1 15e 2
15c 1a3 1 1a6
1 128 1 1c3
2 1c2 1c3 1
1cb 1 1d1 2
1d3 1d4 2 1c0
1d5 1 1dc 1
1d7 2 1ef 1f1
3 1ed 1ee 1f3
2 1fc 1fe 2
200 202 2 204
206 2 208 20a
2 20c 20e 3
213 214 215 2
210 217 2 1fb
219 1 21b 1
21d 2 1e6 21e
1 222 1 1e1
2 1df 226 1
229 1 1ad 1
246 2 245 246
1 24e 1 254
2 256 257 2
243 258 1 25f
1 25a 2 272
274 3 270 271
276 2 27f 281
2 283 285 2
287 289 2 28b
28d 2 28f 291
3 296 297 298
2 293 29a 2
27e 29c 1 29e
1 2a0 2 269
2a1 1 2a5 1
264 2 262 2a9
1 2ac 1 230
1 2c9 2 2c8
2c9 1 2d1 1
2d7 2 2d9 2da
2 2c6 2db 1
2e2 1 2dd 2
2f5 2f7 3 2f3
2f4 2f9 2 302
304 2 306 308
2 30a 30c 2
30e 310 2 312
314 3 319 31a
31b 2 316 31d
2 301 31f 1
321 1 323 2
2ec 324 1 328
1 2e7 2 2e5
32c 1 32f 1
2b3 1 34c 2
34b 34c 1 354
1 35a 2 35c
35d 2 349 35e
1 365 1 360
2 378 37a 3
376 377 37c 2
385 387 2 389
38b 2 38d 38f
2 391 393 2
395 397 3 39c
39d 39e 2 399
3a0 2 384 3a2
1 3a4 1 3a6
2 36f 3a7 1
3ab 1 36a 2
368 3af 1 3b2
1 336 1 3cf
2 3ce 3cf 1
3d7 1 3dd 2
3df 3e0 2 3cc
3e1 1 3e8 1
3e3 2 3fb 3fd
3 3f9 3fa 3ff
2 408 40a 2
40c 40e 2 410
412 2 414 416
2 418 41a 3
41f 420 421 2
41c 423 2 407
425 1 427 1
429 2 3f2 42a
1 42e 1 3ed
2 3eb 432 1
435 1 3b9 1
452 2 451 452
1 45a 1 460
2 462 463 2
44f 464 1 46b
1 466 2 47e
480 3 47c 47d
482 2 48b 48d
2 48f 491 2
493 495 2 497
499 2 49b 49d
3 4a2 4a3 4a4
2 49f 4a6 2
48a 4a8 1 4aa
1 4ac 2 475
4ad 1 4b1 1
470 2 46e 4b5
1 4b8 1 43c
1 4d5 2 4d4
4d5 1 4dd 1
4e3 2 4e5 4e6
2 4d2 4e7 1
4ee 1 4e9 2
501 503 3 4ff
500 505 2 50e
510 2 512 514
2 516 518 2
51a 51c 2 51e
520 3 525 526
527 2 522 529
2 50d 52b 1
52d 1 52f 2
4f8 530 1 534
1 4f3 2 4f1
538 1 53b 1
4bf 1 555 2
554 555 1 55d
1 563 2 565
566 2 552 567
1 56e 1 569
2 581 583 3
57f 580 585 2
58e 590 2 592
594 2 596 598
2 59a 59c 2
59e 5a0 3 5a5
5a6 5a7 2 5a2
5a9 2 58d 5ab
1 5ad 1 5af
2 578 5b0 1
5b4 1 573 2
571 5b8 1 5bb
a 125 1aa 22d
2b0 333 3b6 439
4bc 53f 5be 2
5c9 5cb 3 5c7
5c8 5cd 2 5d6
5d8 2 5da 5dc
2 5de 5e0 2
5e2 5e6 2 5d5
5e8 1 5ea 1
5ec 5 82 a1
5c0 5ed 5f2 1
22 
1
4
0 
5fa
0
1
28
15
6
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

2 0 1
f 1 0
3 1 0
1e 1 0
9 1 0
15 1 0
0

/
SHOW ERRORS FUNCTION FC_U_NAMES;
ALTER FUNCTION FC_U_NAMES COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_WP_DATES ==
CREATE OR REPLACE FUNCTION SP_U_WP_DATES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ef
2 :e:
1FUNCTION:
1SP_U_WP_DATES:
1ASSIGN_ID:
1VARCHAR2:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_PROJECT_ID:
1H_ACTUAL_START:
1H_START_DATE:
1H_FINISH_DATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_SD:
1DATE:
1H_FD:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_BILLABLE:
1PLS_INTEGER:
10:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DAYOFYEAR:
1H_LAST_SUBMITTED:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_TRANSFED_CRI:
1H_TASK_ID:
1H_RES_ID:
1H_REC_USER:
1H_EFFORT:
1H_CONTOUR:
1H_DELAY:
1H_PERCENT_UNITS:
1H_WORK_PERCENT:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_WORK:
1H_SKIP:
1H_LAST_DAY:
1H_MINUTES:
1H_PER_DAY:
1H_WORK_TYPE:
1H_ASSIGN_COUNT:
1H_DURATION:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_SCHED_EFFORT:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_DATES(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1);:
1CHECK_TRACE:
174:
1+:
1FPUT:
1               ENTER:: SP_U_WP_DATES(75) :: cplan.sql(16638) :: :
1PROJECT_ASSIGNMENT_ID:
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1LAST_SUBMITTED:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1UNITS_MSP:
1ACTUAL_START:
1WORK_TODATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1ASSIGNMENT_DELAY:
1LAST_SCHED_MIN:
1TO_DATE:
1SUBSTR:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ASSIGNMENT_ID, PROJECT_ID, RESOURCE_ID,:n      RESOURCE_TYPE, +
1BIT_FLAG, LAST_SUBMITTED, C_CONTOUR, C_EFFORT, T_UNIT, C_UNIT,:n      UNITS_M+
1SP, ACTUAL_START, WORK_TODATE, UNRESOLVED_START, UNRESOLVED_FINISH,:n      CA+
1SE WHEN BIT_FLAG = '0' THEN PLANNED_WORK ELSE SCHED_WORK END, ASSIGNMENT_DELA+
1Y, LAST_SCHED_MIN,:n      TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(S+
1ubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n      REGULAR_C+
1OST, SPECIAL_COST, REGULAR_RATE, SPECIAL_RATE,:n      B_REGULAR_COST, B_SPECI+
1AL_COST, B_REGULAR_RATE, B_SPECIAL_RATE,:n      MILESTONE_PERCENT, TASK_ID:n +
1     INTO h_prj_assign_id, h_project_id, h_res_id,:n      h_res_type, h_bit_f+
1lag, h_last_submitted, h_contour, h_work, h_eunit, h_unit,:n      h_percent_u+
1nits, h_actual_start, h_work_todate, h_start_date, h_finish_date,:n      h_ef+
1fort, h_delay, h_last_day,:n      h_SD, h_FD, h_billable, h_capital_expense,+
1:n      h_reg_cost, h_spec_cost, h_reg_sale, h_spec_sale,:n      h_b_reg_cost+
1, h_b_spec_cost, h_b_reg_sale, h_b_spec_sale,:n      h_work_percent, h_task_i+
1d:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID = h_tsk_assignm+
1ent_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1110:
1           EXCEPTION:: SP_U_WP_DATES(111) :: cplan.sql(16674) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1118:
1        RETURN_ERROR:: SP_U_WP_DATES(119) :: cplan.sql(16682) :: :
1STATE:: :
1TO_CHAR:
1PMO_CNST:
1RECORD_NOT_FOUND:
1 ID:: :
1121:
1                EXIT:: SP_U_WP_DATES(122) :: cplan.sql(16685) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1>:
1!=:
1134:
1        RETURN_ERROR:: SP_U_WP_DATES(135) :: cplan.sql(16698) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1137:
1                EXIT:: SP_U_WP_DATES(138) :: cplan.sql(16701) :: :
1MINUTE_PER_DAY:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, MINUTE_PER_DAY:n         INTO h_project_id, h_per_day:n   +
1      FROM TMT_WBS WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1155:
1           EXCEPTION:: SP_U_WP_DATES(156) :: cplan.sql(16719) :: :
18:
1167:
1      RETURN_INVALID:: SP_U_WP_DATES(168) :: cplan.sql(16731) :: :
1INVALID_PARAMS:
1170:
1                EXIT:: SP_U_WP_DATES(171) :: cplan.sql(16734) :: :
1PMO_RETURN_INVALID_SP:
1FC_U_TDY_LAST_ACTUAL:
1FC_DEL_NOACTUAL:
12:
1DB2TIMESTAMP:
1TIME:
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n         INTO h_start_date:n         FRO+
1M DUAL:
1205:
1           EXCEPTION:: SP_U_WP_DATES(206) :: cplan.sql(16769) :: :
1-:
1FC_RESCHEDULE:
1222:
1        RETURN_ERROR:: SP_U_WP_DATES(223) :: cplan.sql(16786) :: :
1TASK_ASSIGNMENT_ERROR:
1225:
1                EXIT:: SP_U_WP_DATES(226) :: cplan.sql(16789) :: :
1BAK_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n              BAK_ASSIGN_STRING = NULL:n        +
1 WHERE TSK_ASSIGNMENT_ID = H_TSK_ASSIGNMENT_ID:
1CONSIDER:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_SCHED_BIT:
1SC_PLANNED_BIT:
1BAK_START_DT:
1SCHED_START:
1PLANNED_START:
1BAK_FINISH_DT:
1SCHED_FINISH:
1PLANNED_FINISH:
1ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,(pmo_cnst.SC_SCHED_BIT+pmo_cnst.SC_PLANNED_BIT)),:n         BAK_START_+
1DT = COALESCE(SCHED_START,PLANNED_START), BAK_FINISH_DT = COALESCE(SCHED_FINI+
1SH,PLANNED_FINISH),:n         BAK_ASSIGN_STRING = ASSIGN_STRING:n         WHE+
1RE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1FOUND:
1100:
1251:
1           EXCEPTION:: SP_U_WP_DATES(252) :: cplan.sql(16815) :: :
1FC_ROLLUP:
1259:
1        RETURN_ERROR:: SP_U_WP_DATES(260) :: cplan.sql(16823) :: :
1262:
1                EXIT:: SP_U_WP_DATES(263) :: cplan.sql(16826) :: :
14:
1268:
1       RETURN_STATUS:: SP_U_WP_DATES(269) :: cplan.sql(16832) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1275:
1           EXCEPTION:: SP_U_WP_DATES(276) :: cplan.sql(16839) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1287:
1           EXCEPTION:: SP_U_WP_DATES(288) :: cplan.sql(16851) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
7df
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6e 7e a0 b4 2e 7e
6e b4 2e 6e a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 6e a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:2 a0 d :49 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c a0
7e b4 2e 5a a0 7e b4 2e
5a a 10 :2 a0 d :2 a0 d :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d a0
51 d b7 :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b a0
a5 57 b7 :2 19 3c b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
5a a0 7e b4 2e :2 5a a 10
:9 a0 51 a5 b d b7 19 3c
a0 7e b4 2e 5a :4 a0 51 a5
b d b7 :2 a0 :2 51 a5 b 7e
6e b4 2e :4 a0 51 a5 b d
b7 :4 a0 51 a5 b d b7 :2 19
3c b7 :2 19 3c a0 7e b4 2e
5a :a a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e d b7
19 3c a0 51 d :a a0 51 a5
b :2 a0 51 a5 b a5 b d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:4 a0 12a :16 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c :3 a0 a5 b
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 51 a5 b :2 a0 a5
57 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 a0 6b
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e a5 57 b7 19 3c :9 a0 12a
e9 dd :2 a0 65 b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c :7 a0 12a e9 dd
:2 a0 65 b7 a4 b1 11 4f b7
a6 9 a4 b1 11 68 4f 1d
17 b5 
7df
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 98 83 87 8a 8b 93
82 b5 a3 7f a7 a8 b0 a2
d2 c0 9f c4 c5 cd bf ee
dd e1 e9 bc 106 f5 f9 101
dc 122 111 115 11d d9 13a 129
12d 135 110 156 145 149 151 10d
16e 15d 161 169 144 18a 179 17d
185 141 1a6 191 195 198 199 1a1
178 1c3 1b1 175 1b5 1b6 1be 1b0
1df 1ce 1d2 1ad 1da 1cd 1fb 1ea
1ee 1ca 1f6 1e9 217 206 20a 1e6
212 205 233 222 226 22e 202 24b
23a 23e 246 221 267 256 25a 21e
262 255 283 272 276 252 27e 271
29f 28e 292 26e 29a 28d 2bb 2aa
2ae 28a 2b6 2a9 2d8 2c6 2a6 2ca
2cb 2d3 2c5 2f5 2e3 2c2 2e7 2e8
2f0 2e2 312 300 2df 304 305 30d
2ff 32e 31d 321 2fc 329 31c 34a
339 33d 319 345 338 366 355 359
335 361 354 382 371 375 351 37d
370 39e 38d 391 36d 399 38c 3ba
3a9 3ad 389 3b5 3a8 3d6 3c5 3c9
3a5 3d1 3c4 3f2 3e1 3e5 3c1 3ed
3e0 40e 3fd 401 3dd 409 3fc 42a
419 41d 3f9 425 418 446 435 439
415 441 434 462 451 455 431 45d
450 47e 46d 471 44d 479 46c 49a
489 48d 469 495 488 4b6 4a5 4a9
485 4b1 4a4 4d2 4c1 4c5 4a1 4cd
4c0 4ee 4dd 4e1 4bd 4e9 4dc 50a
4f9 4fd 4d9 505 4f8 526 515 519
4f5 521 514 542 531 535 511 53d
530 55e 54d 551 52d 559 54c 57a
569 56d 549 575 568 596 585 589
565 591 584 5b2 5a1 5a5 581 5ad
5a0 5ce 5bd 5c1 59d 5c9 5bc 5ea
5d9 5dd 5b9 5e5 5d8 606 5f5 5f9
5d5 601 5f4 622 611 615 5f1 61d
610 63e 62d 631 60d 639 62c 65a
649 64d 629 655 648 67a 665 669
645 66d 675 664 681 685 661 689
68d 691 694 699 69a 1 69c 6a1
6a5 6a9 6ac 6b1 6b5 6b9 6bc 6c1
6c2 6c4 6c9 6cc 6d0 6d1 6d6 6db
6de 6e3 6e4 6e9 6ec 6f0 6f1 6f6
6f9 6fe 6ff 704 707 70c 70d 712
715 719 71d 722 725 729 72a 72f
732 737 738 73d 742 743 745 74a
74b 74d 74e 753 756 75b 75c 761
764 768 76c 771 774 778 779 77e
781 786 787 78c 791 792 794 799
79a 79c 79d 7a2 7a5 7aa 7ab 7b0
7b3 7b8 7b9 7be 7c1 7c5 7c6 7cb
7ce 7d3 7d4 7d9 7dc 7e1 7e2 7e7
7e8 7ed 7ef 7f3 7f6 7fa 7fe 801
805 809 80c 80f 814 817 81a 81d
81e 823 824 1 826 82b 82f 833
836 83b 840 843 847 848 84d 84e
853 855 859 85c 860 864 868 86c
870 874 878 87c 880 884 888 88c
890 894 898 89c 8a0 8a4 8a8 8ac
8b0 8b4 8b8 8bc 8c0 8c4 8c8 8cc
8d0 8d4 8d8 8dc 8e0 8e4 8e8 8ec
8f0 8f4 8f8 8fc 900 904 908 90c
910 914 918 91c 920 924 928 92c
930 934 938 93c 940 944 948 94c
950 954 958 95c 960 964 968 96c
970 974 978 97c 980 984 988 98c
990 994 998 9a4 9a8 9ac 9af 9b3
9b7 9b9 9bd 9c1 9c5 9c8 9cc 9d0
9d2 9d3 9d8 1 9dc 9e0 9e4 9e7
9eb 9ef 9f3 9f7 9fa 9fe a02 a05
a08 a0d a10 a13 a16 a17 a1c a1d
1 a1f a24 a28 a2c a2f a34 a39
a3c a40 a41 a46 a49 a4e a4f a54
a57 a5c a5d a62 a65 a69 a6a a6f
a72 a77 a78 a7d a80 a84 a88 a8b
a8e a8f a91 a92 a97 a98 a9d a9f
aa3 aa6 aa8 aac aae aba abc abe
abf ac4 ac8 aca ad6 ad8 adc ae0
ae3 ae7 aea aee af1 af2 af7 afa
afe b02 b05 b09 b0d b10 b13 b18
b1b b1e b21 b22 b27 b28 1 b2a
b2f b33 b37 b3a b3f b44 b47 b4b
b4c b51 b54 b59 b5a b5f b62 b67
b68 b6d b70 b74 b78 b7c b80 b83
b84 b86 b8b b8c b8e b8f b94 b97
b9c b9d ba2 ba5 baa bab bb0 bb3
bb7 bb8 bbd bc0 bc5 bc6 bcb bcc
bd1 bd3 bd7 bda bde be2 be5 be9
bed bf0 bf3 bf8 bfb bfe c01 c02
c07 c08 1 c0a c0f c13 c17 c1a
c1f c24 c27 c2b c2c c31 c32 c37
c39 c3d c40 c44 c48 c4b c4f c53
c56 c5a c5e c5f c64 c66 c6a c6d
c71 c74 c75 c7a c7d c81 c84 c85
c8a 1 c8d c92 c96 c9a c9e ca2
ca6 caa cae cb2 cb5 cb9 cbd cc0
cc1 cc3 cc6 cc9 cca ccf cd2 cd6
cda cdd ce1 ce5 ce8 ce9 ceb cee
cf1 cf2 cf7 1 cfa cff d03 d07
d0a d0e d12 d15 d18 d1d d20 d23
d26 d27 d2c d2d 1 d2f d34 d38
d3c d3f d44 d49 d4c d50 d51 d56
d59 d5e d5f d64 d67 d6c d6d d72
d75 d79 d7d d81 d85 d88 d89 d8b
d90 d91 d93 d94 d99 d9c da1 da2
da7 daa daf db0 db5 db8 dbc dbd
dc2 dc5 dca dcb dd0 dd1 dd6 dd8
ddc ddf de3 de7 dea dee df2 df5
df8 dfd e00 e03 e06 e07 e0c e0d
1 e0f e14 e18 e1c e1f e24 e29
e2c e30 e31 e36 e37 e3c e3e e42
e45 e49 e4d e50 e54 e58 e5b e5f
e63 e64 e69 e6b e6f e72 e76 e7a
e7e e82 e86 e8a e8e e92 e96 ea2
ea6 eaa ead eb1 eb5 eb7 ebb ebf
ec3 ec6 eca ece ed0 ed1 ed6 1
eda ede ee2 ee5 ee9 eed ef1 ef5
ef8 efc f00 f03 f06 f0b f0e f11
f14 f15 f1a f1b 1 f1d f22 f26
f2a f2d f32 f37 f3a f3e f3f f44
f47 f4c f4d f52 f55 f5a f5b f60
f63 f67 f68 f6d f70 f75 f76 f7b
f7e f82 f86 f89 f8c f8d f8f f90
f95 f96 f9b f9d fa1 fa4 fa6 faa
fac fb8 fba fbc fbd fc2 fc6 fc8
fd4 fd6 fda fde fe1 fe5 fe9 fec
fed fef ff2 ff5 ff6 ffb fff 1003
1007 100b 100e 1012 1014 1018 101c 101f
1023 1027 102a 102d 1032 1035 1038 103b
103c 1041 1042 1 1044 1049 104d 1051
1054 1059 105e 1061 1065 1066 106b 106e
1073 1074 1079 107c 1081 1082 1087 108a
108e 1092 1096 109a 109d 109e 10a0 10a5
10a6 10a8 10a9 10ae 10af 10b4 10b6 10ba
10bd 10c1 10c5 10c8 10cc 10d0 10d3 10d6
10db 10de 10e1 10e4 10e5 10ea 10eb 1
10ed 10f2 10f6 10fa 10fd 1102 1107 110a
110e 110f 1114 1115 111a 111c 1120 1123
1127 112b 112e 1132 1136 1139 113d 113e
1143 1145 1149 114d 1150 1152 1156 1159
115d 1161 1164 1165 1167 116a 116d 116e
1173 1176 117a 117d 117e 1183 1186 1
1189 118e 1192 1196 119a 119e 11a2 11a6
11aa 11ae 11b2 11b5 11b6 11b8 11bc 11be
11c2 11c5 11c9 11cc 11cd 11d2 11d5 11d9
11dd 11e1 11e5 11e8 11e9 11eb 11ef 11f1
11f5 11f9 11fc 11ff 1200 1202 1205 120a
120b 1210 1214 1218 121c 1220 1223 1224
1226 122a 122c 1230 1234 1238 123c 123f
1240 1242 1246 1248 124c 1250 1253 1255
1259 125d 1260 1264 1267 1268 126d 1270
1274 1278 127c 1280 1284 1288 128c 1290
1294 1298 12a4 12a8 12ac 12af 12b3 12b7
12b9 12bd 12c1 12c5 12c8 12cc 12d0 12d2
12d3 12d8 1 12dc 12e0 12e4 12e7 12eb
12ef 12f3 12f7 12fa 12fe 1302 1305 1308
130d 1310 1313 1316 1317 131c 131d 1
131f 1324 1328 132c 132f 1334 1339 133c
1340 1341 1346 1349 134e 134f 1354 1357
135c 135d 1362 1365 1369 136a 136f 1372
1377 1378 137d 1380 1384 1388 138b 138e
138f 1391 1392 1397 1398 139d 139f 13a3
13a6 13a8 13ac 13ae 13ba 13bc 13be 13bf
13c4 13c8 13ca 13d6 13d8 13dc 13e0 13e4
13e7 13e8 13ea 13ed 13f1 13f5 13f8 13f9
13fb 13fc 1401 1405 1407 140b 140e 1412
1415 1419 141d 1421 1425 1429 142d 1431
1435 1439 143d 1441 1444 1445 1447 144b
144f 1452 1453 1455 1456 1458 145c 1460
1464 1467 1468 146a 146d 1470 1471 1476
147a 147e 1481 1485 1489 148c 148f 1494
1497 149a 149d 149e 14a3 14a4 1 14a6
14ab 14af 14b3 14b6 14bb 14c0 14c3 14c7
14c8 14cd 14d0 14d5 14d6 14db 14de 14e3
14e4 14e9 14ec 14f0 14f4 14f8 14fc 14ff
1500 1502 1507 1508 150a 150b 1510 1513
1518 1519 151e 1521 1526 1527 152c 152f
1533 1534 1539 153c 1541 1542 1547 1548
154d 154f 1553 1556 155a 155e 1561 1565
1569 156c 156f 1574 1577 157a 157d 157e
1583 1584 1 1586 158b 158f 1593 1596
159b 15a0 15a3 15a7 15a8 15ad 15ae 15b3
15b5 15b9 15bc 15c0 15c4 15c7 15cb 15cf
15d2 15d6 15da 15db 15e0 15e2 15e6 15ea
15ee 15f2 15fe 1602 1606 160a 160e 1612
1616 161a 161e 1622 1626 162a 162e 1632
1636 163a 163e 1642 1646 164a 164e 1652
1656 1662 1666 166b 166f 1672 1673 1678
167c 1680 1683 1686 168a 168c 1690 1694
1697 169a 169e 16a0 16a4 16a8 16ab 16ad
16b1 16b5 16b9 16bc 16c0 16c4 16c6 16c7
16cc 1 16d0 16d4 16d8 16db 16df 16e3
16e7 16eb 16ee 16f2 16f6 16f9 16fc 1701
1704 1707 170a 170b 1710 1711 1 1713
1718 171c 1720 1723 1728 172d 1730 1734
1735 173a 173d 1742 1743 1748 174b 1750
1751 1756 1759 175d 175e 1763 1766 176b
176c 1771 1774 1778 177c 177f 1782 1783
1785 1786 178b 178c 1791 1793 1797 179a
179c 17a0 17a2 17ae 17b0 17b2 17b3 17b8
17bc 17be 17ca 17cc 17ce 17d2 17d6 17d9
17dd 17e1 17e5 17e6 17e8 17ec 17f0 17f4
17f7 17fb 17ff 1802 1805 180a 180d 1810
1813 1814 1819 181a 1 181c 1821 1825
1829 182c 1831 1836 1839 183d 183e 1843
1846 184b 184c 1851 1854 1859 185a 185f
1862 1866 186a 186e 186f 1871 1876 1877
1879 187a 187f 1882 1887 1888 188d 1890
1895 1896 189b 189e 18a2 18a3 18a8 18ab
18b0 18b1 18b6 18b7 18bc 18be 18c2 18c5
18c9 18cd 18d0 18d4 18d8 18db 18de 18e3
18e6 18e9 18ec 18ed 18f2 18f3 1 18f5
18fa 18fe 1902 1905 190a 190f 1912 1916
1917 191c 191d 1922 1924 1928 192b 192f
1933 1936 193a 193e 1941 1942 1944 1948
194c 194d 1952 1956 195a 195d 1961 1965
1968 196b 1970 1973 1976 1979 197a 197f
1980 1 1982 1987 198b 198f 1992 1997
199c 199f 19a3 19a4 19a9 19ac 19b1 19b2
19b7 19ba 19bf 19c0 19c5 19c8 19cc 19d0
19d4 19d8 19db 19dc 19de 19e3 19e4 19e6
19e7 19ec 19ef 19f4 19f5 19fa 19fd 1a02
1a03 1a08 1a0b 1a0f 1a10 1a15 1a18 1a1d
1a1e 1a23 1a24 1a29 1a2b 1a2f 1a32 1a36
1a3a 1a3d 1a41 1a45 1a48 1a4c 1a50 1a51
1a56 1a58 1a5c 1a60 1a63 1a67 1a6b 1a6e
1a72 1a76 1a79 1a7c 1a81 1a84 1a87 1a8a
1a8b 1a90 1a91 1 1a93 1a98 1a9c 1aa0
1aa3 1aa8 1aad 1ab0 1ab4 1ab5 1aba 1abb
1ac0 1ac4 1ac8 1acb 1ad0 1ad5 1ad8 1adc
1ae0 1ae3 1ae4 1ae9 1aec 1af1 1af2 1af7
1afa 1afe 1b02 1b05 1b06 1b0b 1b0c 1b11
1b13 1b17 1b1a 1b1e 1b22 1b26 1b2a 1b2e
1b32 1b36 1b3a 1b3e 1b4a 1b4f 1b53 1b57
1b5b 1b5f 1b61 1b62 1b67 1 1b6b 1b6f
1b73 1b76 1b7a 1b7e 1b82 1b86 1b89 1b8d
1b91 1b94 1b97 1b9c 1b9f 1ba2 1ba5 1ba6
1bab 1bac 1 1bae 1bb3 1bb7 1bbb 1bbe
1bc3 1bc8 1bcb 1bcf 1bd0 1bd5 1bd6 1bdb
1bdf 1be3 1be6 1beb 1bf0 1bf3 1bf7 1bf8
1bfd 1c00 1c05 1c06 1c0b 1c0e 1c12 1c16
1c19 1c1c 1c1d 1c1f 1c20 1c25 1c26 1c2b
1c2d 1c31 1c34 1c38 1c3c 1c40 1c44 1c48
1c4c 1c50 1c5c 1c61 1c65 1c69 1c6d 1c71
1c73 1c77 1c79 1c85 1c87 1c89 1c8a 1c8f
1c93 1c95 1ca1 1ca5 1ca7 1ca8 1cb1 
7df
2
0 1 a 6 10 :3 6 16 :3 6
17 :3 6 10 :2 6 1 3 a 13
a :2 1 4 18 21 20 :2 18 :2 4
14 1d 1c :2 14 :2 4 11 1a 19
:2 11 :2 4 :3 13 :2 4 :3 11 :2 4 :3 12 :2 4
:3 12 :2 4 :3 13 :2 4 :3 9 :2 4 :3 9 :2 4
f 18 17 :2 f :2 4 f 18 17
:2 f :2 4 :2 f 1e f :2 4 :2 16 25
16 :2 4 :2 11 20 11 :2 4 :3 10 :2 4
:3 15 :2 4 :2 12 21 12 :2 4 :2 d 1c
d :2 4 :2 11 20 11 :2 4 :2 13 22
13 :2 4 e 17 16 :2 e :2 4 d
16 15 :2 d :2 4 f 18 17 :2 f
:2 4 :2 d 1c d :2 4 :2 e 1d e
:2 4 :2 c 1b c :2 4 :2 14 23 14
:2 4 :2 13 22 13 :2 4 :2 12 21 12
:2 4 :2 11 20 11 :2 4 :2 b 1a b
:2 4 :2 b 1a b :2 4 :2 f 1e f
:2 4 :2 e 1d e :2 4 :2 e 1d e
:2 4 :2 10 1f 10 :2 4 :2 13 22 13
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 c 1b c
:2 4 :2 b 1a b :2 4 :2 13 22 13
:2 4 :2 14 23 14 :2 4 :2 f 1e f
:2 4 :2 f 19 f :2 4 :2 f 19 f
:2 4 :2 10 1a 10 :2 4 :2 10 1a 10
:2 4 :2 11 1b 11 :2 4 :2 11 1b 11
:2 4 :2 12 1c 12 :2 4 :2 12 1c 12
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 55 5b 5e :2 55 6c 83
8 :2 6c d 10 :2 6c 1a 1d :2 6c
b e :2 6c 13 16 1f 26 2b
2e :2 26 3e 41 :2 26 46 :2 1f 4f
:2 16 :2 6c b e :2 6c 13 16 1f
26 2b 2e :2 26 3f 42 :2 26 47
:2 1f 50 :2 16 :2 6c b e :2 6c 13
16 :2 6c 1b 1e :2 6c 28 2b :2 6c
30 33 :2 6c :2 7 4b :2 4 7 :2 11
23 :2 2d 39 3c 4d 4f 50 :2 4d
:2 23 :3 7 :2 d 12 1e 5e 61 :2 1e
:2 7 53 :3 4 1b :2 4 12 4 e
25 31 7 16 20 30 3b 45
4d 7 12 20 2d 3f 11 25
37 47 59 7 f 16 31 39
40 5c 66 7 15 23 31 7
17 27 37 7 1a c 1d 2b
7 13 1f 31 3c 44 4d 7
18 28 37 45 7 11 1a 7
d 13 1f 7 13 20 2c 7
15 24 32 7 17 c d 21
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 54
57 58 :2 54 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 8b 8e :2 24 96 99 :2 24 a5
a8 af b8 bb :2 a8 :2 24 :2 d 5b
:2 a :2 7 :4 13 :2 7 4 :3 1 8 :2 11
1c 1a :2 25 :2 1a 7 a :2 14 26
:2 30 3c 40 51 54 55 :2 51 :2 26
:3 a :2 10 15 21 62 65 :2 21 72
75 :2 21 79 7c :2 21 86 89 92
9a :2 a3 :2 92 b6 :2 89 :2 21 be c1
:2 21 c9 cc :2 21 d1 d4 :2 21 e8
eb :2 21 :2 a 58 :2 7 a :2 14 26
:2 30 3c 3f 50 53 54 :2 50 :2 26
:3 a :2 10 15 21 62 65 :2 21 :2 a
57 :3 7 :2 12 26 :2 2f 41 f :2 7
35 :2 4 :4 8 7 :4 2a 29 :3 7 18
:2 7 19 7 b :2 16 1e 2d 3d
:2 b 41 43 :2 41 a 4b :2 56 d
1d 2c :2 4b 30 33 :2 30 4a :2 a
d :2 17 29 :2 33 3f 43 54 57
58 :2 54 :2 29 :3 d :2 13 18 24 65
68 :2 24 75 78 :2 24 7c 7f :2 24
89 8c 95 9d :2 a6 :2 95 c3 :2 8c
:2 24 cb ce :2 24 d6 d9 :2 24 de
e1 :2 24 f5 f8 :2 24 :2 d 5b :2 a
d :2 17 29 :2 33 3f 42 53 56
57 :2 53 :2 29 :3 d :2 13 18 24 65
68 :2 24 :2 d 5a :3 a :2 15 29 :2 32
4e 12 :2 a 36 :2 7 11 1d f
1d f 1d 2a 3b 48 :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 57 5a 5b
:2 57 :2 2c :3 10 :2 16 1b 27 68 6b
:2 27 78 7b :2 27 7f 82 :2 27 8e
91 :2 27 99 9c :2 27 a8 ab b2
bb be :2 ab :2 27 :2 10 5e :2 d :2 a
:4 16 :2 a 7 :3 48 a :2 15 1d 2c
3a :2 a 3e 41 :2 3e a 1a :2 a
15 a 43 d :2 17 29 :2 33 3f
42 53 56 57 :2 53 :2 29 :3 d :2 13
18 24 65 68 :2 24 75 78 :2 24
7c 7f :2 24 89 8c 95 9d :2 a6
:2 95 b7 :2 8c :2 24 :2 d 5a :2 a d
:2 17 29 :2 33 3f 42 53 56 57
:2 53 :2 29 :3 d :2 13 18 24 65 68
:2 24 :2 d 5a :3 a :2 15 2b :2 34 44
:2 a :4 7 48 :2 4 8 11 1d :2 8
20 22 :2 20 7 :4 2b 2a 29 :3 7
15 2a 38 43 4d 26 3b 4d
59 :2 15 7 4a :2 4 :4 8 :2 7 1a
2a 38 4d :2 1a 7 25 a 11
1d 20 :2 a 23 25 :2 23 a 1d
2d 3b 50 :2 1d a 29 a 1d
2d 3b 50 :2 1d a :4 7 :4 4 :4 8
7 11 1c 29 31 38 53 5e
63 :2 f :2 a :2 13 1f a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 57 5a 5b :2 57 :2 2c :3 10 :2 16
1b 27 68 6b :2 27 78 7b :2 27
7f 82 :2 27 8e 91 :2 27 99 9c
:2 27 a8 ab b2 bb be :2 ab :2 27
:2 10 5e :2 d :2 a :4 16 :2 a 7 :3 26
7 13 1c 26 :2 13 29 2b 34
43 :2 2b :2 13 7 26 :3 4 12 :2 4
17 25 3a 48 52 5e 24 30
39 42 :2 30 46 4f 60 :2 46 :2 17
4 7 10 21 :2 7 24 27 :2 24
a :2 14 26 :2 30 3c 40 51 54
55 :2 51 :2 26 :3 a :2 10 15 21 62
65 :2 21 72 75 :2 21 79 7c :2 21
86 89 92 9a :2 a3 :2 92 bb :2 89
:2 21 c3 c6 :2 21 ce d1 :2 21 d6
d9 :2 21 ed f0 :2 21 :2 a 58 :2 7
a :2 14 26 :2 30 3c 3f 50 53
54 :2 50 :2 26 :3 a :2 10 15 21 62
65 :2 21 :2 a 57 :3 7 :2 12 26 :2 2f
46 f :2 7 29 e f 10 24
7 11 26 34 42 4b 52 5f
68 75 7e a 19 22 2e 3e
4e 57 64 a 1e 10 24 a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 57 5a 5b :2 57 :2 2c :3 10 :2 16
1b 27 68 6b :2 27 78 7b :2 27
7f 82 :2 27 8e 91 :2 27 99 9c
:2 27 a8 ab b2 bb be :2 ab :2 27
:2 10 5e :2 d :2 a :4 16 :2 a 7 :8 4
12 1c :2 12 4 7 :2 11 23 :2 2d
39 3d 4e 51 52 :2 4e :2 23 :3 7
:2 d 12 1e 5f 62 :2 1e 6f 72
:2 1e 76 79 :2 1e 83 86 8f 97
:2 8f a4 :2 86 :2 1e ac af :2 1e b7
ba :2 1e bf c2 :2 1e d6 d9 :2 1e
:2 7 55 :2 4 7 :2 11 23 :2 2d 39
3c 4d 50 51 :2 4d :2 23 :3 7 :2 d
12 1e 5f 62 :2 1e :2 7 54 :3 4
:2 f 23 2c 38 :2 23 3c c :2 4
7 :2 11 23 :2 2d 39 3c 4d 50
51 :2 4d :2 23 :3 7 :2 d 12 1e 5f
62 :2 1e 6f 72 :2 1e 76 79 :2 1e
83 86 8f 97 :2 a0 :2 8f ab :2 86
:2 1e b3 b6 :2 1e be c1 :2 1e c6
c9 :2 1e dd e0 :2 1e :2 7 54 :3 4
:2 f 21 :2 2a 34 49 :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
51 54 55 :2 51 :2 26 :3 a :2 10 15
21 62 65 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 58 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4e 51 52 :2 4e :2 23 :3 7 :2 d 12
1e 5f 62 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 55 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
7df
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 9 :7 a :7 b
:5 c :5 d :5 e :5 f
:5 10 :5 11 :5 12 :7 13
:7 14 :6 15 :6 16 :6 17
:5 18 :5 19 :6 1a :6 1b
:6 1c :6 1d :7 1e :7 1f
:7 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :7 40
:b 42 :11 43 44 :2 43
:2 44 :2 43 :2 44 :2 43
:2 45 :2 43 :12 45 :2 43
:2 46 :2 43 :12 46 :2 43
:2 47 :2 43 :2 47 :2 43
:2 47 :2 43 :2 47 :2 43
:2 47 :4 43 :3 42 :11 4a
:b 4b :3 4a :3 51 :3 52
:3 55 :7 56 :5 57 :5 58
:8 59 :4 5a :4 5b :2 5c
:3 5d :7 5e :5 5f :3 60
:4 61 :4 62 :4 63 :2 64
65 :2 66 55 :5 67
54 69 :5 6a :3 69
:2 6b :5 6d :11 6e :24 6f
:3 6e :2 6c :6 6b 68
:3 41 :a 75 :11 76 :30 77
:3 76 :11 79 :b 7a :3 79
:7 7c 7d :2 7c :3 75
:c 80 :3 81 :3 82 :10 84
:3 85 :2 84 :4 85 :3 84
:11 86 :30 87 :3 86 :11 89
:b 8a :3 89 :7 8c 8d
:2 8c 85 :2 84 :2 91
:2 92 :5 93 91 :5 94
90 96 :5 97 :3 96
:2 98 :5 9a :11 9b :24 9c
:3 9b :2 99 :6 98 95
:3 80 :c a3 :3 a4 :3 a5
a3 :11 a7 :20 a8 :3 a7
:11 aa :b ab :3 aa :9 ad
a6 :3 a3 :3 80 :12 b1
:6 b2 :4 b3 :3 b2 :3 b1
:5 b7 :8 b8 b7 :a ba
:8 bb ba :8 bd bc
:3 ba b9 :3 b7 :5 c1
:8 c3 c4 c5 c3
:5 c6 c2 c8 :5 c9
:3 c8 :2 ca :5 cc :11 cd
:24 ce :3 cd :2 cb :6 ca
c7 :3 c1 :f d3 :3 c1
:3 d8 :7 d9 :b da :3 d9
:9 dd :11 de :30 df :3 de
:11 e1 :b e2 :3 e1 :7 e4
e5 :2 e4 dd e7
e8 :2 e9 e7 :a ec
:8 ed :2 ee :2 ef ec
:6 f0 :5 f1 f0 :5 f3
f2 :3 f0 eb f6
:5 f7 :3 f6 :2 f8 :5 fa
:11 fb :24 fc :3 fb :2 f9
:6 f8 f5 :4 e6 :3 dd
:6 102 :11 103 :2e 104 :3 103
:11 106 :b 107 :3 106 :9 109
10a :2 109 :11 10c :30 10d
:3 10c :a 10f 41 :3 112
:11 113 :b 114 :17 115 :3 113
:2 117 :3 118 :3 119 11a
118 117 118 :3 11b
:3 112 :2 11c :5 11e :11 11f
:b 120 :18 121 :3 11f :2 123
124 :3 125 126 124
123 124 :3 127 :2 11d
:6 11c 111 :7 1 
1cb3
4
:3 0 1 :3 0 2
:a 0 7da 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 15 16 0
b 4 :3 0 8
:7 0 11 10 :3 0
9 :3 0 a :3 0
b :2 0 4 13
17 0 7da 2
18 :2 0 d :2 0
12 4 :3 0 d
:2 0 10 1b 1d
:6 0 20 1e 0
7d8 0 c :6 0
d :2 0 16 4
:3 0 14 22 24
:6 0 27 25 0
7d8 0 e :6 0
1c d9 0 1a
4 :3 0 18 29
2b :6 0 2e 2c
0 7d8 0 f
:6 0 20 10d 0
1e 6 :3 0 30
:7 0 33 31 0
7d8 0 10 :6 0
6 :3 0 35 :7 0
38 36 0 7d8
0 11 :6 0 24
141 0 22 6
:3 0 3a :7 0 3d
3b 0 7d8 0
12 :6 0 6 :3 0
3f :7 0 42 40
0 7d8 0 13
:6 0 28 175 0
26 6 :3 0 44
:7 0 47 45 0
7d8 0 14 :6 0
16 :3 0 49 :7 0
4c 4a 0 7d8
0 15 :6 0 19
:2 0 2c 16 :3 0
4e :7 0 51 4f
0 7d8 0 17
:6 0 4 :3 0 19
:2 0 2a 53 55
:6 0 58 56 0
7d8 0 18 :6 0
1d :2 0 30 4
:3 0 2e 5a 5c
:6 0 5f 5d 0
7d8 0 1a :6 0
1d :2 0 32 1c
:3 0 61 :7 0 65
62 63 7d8 0
1b :6 0 1d :2 0
34 1c :3 0 67
:7 0 6b 68 69
7d8 0 1e :6 0
38 21e 0 36
1c :3 0 6d :7 0
71 6e 6f 7d8
0 1f :6 0 1d
:2 0 3a 16 :3 0
73 :7 0 76 74
0 7d8 0 20
:6 0 16 :3 0 78
:7 0 7b 79 0
7d8 0 21 :6 0
1d :2 0 3c 1c
:3 0 7d :7 0 81
7e 7f 7d8 0
22 :6 0 1d :2 0
3e 1c :3 0 83
:7 0 87 84 85
7d8 0 23 :6 0
1d :2 0 40 1c
:3 0 89 :7 0 8d
8a 8b 7d8 0
24 :6 0 d :2 0
42 1c :3 0 8f
:7 0 93 90 91
7d8 0 25 :6 0
d :2 0 46 4
:3 0 44 95 97
:6 0 9a 98 0
7d8 0 26 :6 0
d :2 0 4a 4
:3 0 48 9c 9e
:6 0 a1 9f 0
7d8 0 27 :6 0
1d :2 0 4e 4
:3 0 4c a3 a5
:6 0 a8 a6 0
7d8 0 28 :6 0
1d :2 0 50 1c
:3 0 aa :7 0 ae
ab ac 7d8 0
29 :6 0 1d :2 0
52 1c :3 0 b0
:7 0 b4 b1 b2
7d8 0 2a :6 0
1d :2 0 54 1c
:3 0 b6 :7 0 ba
b7 b8 7d8 0
2b :6 0 1d :2 0
56 1c :3 0 bc
:7 0 c0 bd be
7d8 0 2c :6 0
1d :2 0 58 1c
:3 0 c2 :7 0 c6
c3 c4 7d8 0
2d :6 0 1d :2 0
5a 1c :3 0 c8
:7 0 cc c9 ca
7d8 0 2e :6 0
1d :2 0 5c 1c
:3 0 ce :7 0 d2
cf d0 7d8 0
2f :6 0 1d :2 0
5e 1c :3 0 d4
:7 0 d8 d5 d6
7d8 0 30 :6 0
1d :2 0 60 1c
:3 0 da :7 0 de
db dc 7d8 0
31 :6 0 1d :2 0
62 1c :3 0 e0
:7 0 e4 e1 e2
7d8 0 32 :6 0
1d :2 0 64 1c
:3 0 e6 :7 0 ea
e7 e8 7d8 0
33 :6 0 1d :2 0
66 1c :3 0 ec
:7 0 f0 ed ee
7d8 0 34 :6 0
1d :2 0 68 1c
:3 0 f2 :7 0 f6
f3 f4 7d8 0
35 :6 0 1d :2 0
6a 1c :3 0 f8
:7 0 fc f9 fa
7d8 0 36 :6 0
1d :2 0 6c 1c
:3 0 fe :7 0 102
ff 100 7d8 0
37 :6 0 1d :2 0
6e 1c :3 0 104
:7 0 108 105 106
7d8 0 38 :6 0
1d :2 0 70 1c
:3 0 10a :7 0 10e
10b 10c 7d8 0
39 :6 0 1d :2 0
72 1c :3 0 110
:7 0 114 111 112
7d8 0 3a :6 0
1d :2 0 74 1c
:3 0 116 :7 0 11a
117 118 7d8 0
3b :6 0 1d :2 0
76 1c :3 0 11c
:7 0 120 11d 11e
7d8 0 3c :6 0
1d :2 0 78 1c
:3 0 122 :7 0 126
123 124 7d8 0
3d :6 0 1d :2 0
7a 1c :3 0 128
:7 0 12c 129 12a
7d8 0 3e :6 0
1d :2 0 7c 40
:3 0 12e :7 0 132
12f 130 7d8 0
3f :6 0 1d :2 0
7e 40 :3 0 134
:7 0 138 135 136
7d8 0 41 :6 0
1d :2 0 80 40
:3 0 13a :7 0 13e
13b 13c 7d8 0
42 :6 0 1d :2 0
82 40 :3 0 140
:7 0 144 141 142
7d8 0 43 :6 0
1d :2 0 84 40
:3 0 146 :7 0 14a
147 148 7d8 0
44 :6 0 1d :2 0
86 40 :3 0 14c
:7 0 150 14d 14e
7d8 0 45 :6 0
1d :2 0 88 40
:3 0 152 :7 0 156
153 154 7d8 0
46 :6 0 15e 15f
0 8a 40 :3 0
158 :7 0 15c 159
15a 7d8 0 47
:6 0 164 165 0
8c a :3 0 b
:2 0 4 160 :7 0
163 161 0 7d8
0 48 :6 0 49
:3 0 4a :3 0 49
:3 0 4b :3 0 167
168 0 2 :4 0
8e 169 16b 166
16d 16c :2 0 4c
:3 0 4d :3 0 16f
170 0 4e :4 0
49 :3 0 4f :3 0
173 174 0 2
:4 0 90 175 177
50 :4 0 51 :2 0
52 :3 0 92 17a
17c :3 0 53 :4 0
51 :2 0 54 :4 0
95 17f 181 :3 0
51 :2 0 3 :3 0
98 183 185 :3 0
51 :2 0 54 :4 0
9b 187 189 :3 0
51 :2 0 55 :4 0
9e 18b 18d :3 0
51 :2 0 56 :3 0
57 :3 0 54 :4 0
51 :2 0 5 :3 0
a1 193 195 :3 0
51 :2 0 54 :4 0
a4 197 199 :3 0
58 :4 0 a7 191
19c 59 :4 0 aa
190 19f ad 18f
1a1 :3 0 51 :2 0
55 :4 0 b0 1a3
1a5 :3 0 51 :2 0
56 :3 0 57 :3 0
54 :4 0 51 :2 0
7 :3 0 b3 1ab
1ad :3 0 51 :2 0
54 :4 0 b6 1af
1b1 :3 0 58 :4 0
b9 1a9 1b4 59
:4 0 bc 1a8 1b7
bf 1a7 1b9 :3 0
51 :2 0 55 :4 0
c2 1bb 1bd :3 0
51 :2 0 54 :4 0
c5 1bf 1c1 :3 0
51 :2 0 8 :3 0
c8 1c3 1c5 :3 0
51 :2 0 54 :4 0
cb 1c7 1c9 :3 0
51 :2 0 5a :4 0
ce 1cb 1cd :3 0
d1 171 1cf :2 0
1d1 d6 1d2 16e
1d1 0 1d3 d8
0 738 49 :3 0
4a :3 0 1d4 1d5
0 49 :3 0 5b
:3 0 1d7 1d8 0
19 :2 0 2 :4 0
5c :2 0 5d :2 0
19 :2 0 da 1dd
1df :3 0 dd 1d9
1e1 1d6 1e3 1e2
:2 0 4c :3 0 5e
:3 0 1e5 1e6 0
4e :4 0 5f :4 0
51 :2 0 52 :3 0
e1 1ea 1ec :3 0
e4 1e7 1ee :2 0
1f0 e7 1f1 1e4
1f0 0 1f2 e9
0 738 c :3 0
3 :3 0 1f3 1f4
0 738 28 :3 0
8 :3 0 1f6 1f7
0 738 60 :3 0
61 :3 0 62 :3 0
63 :3 0 64 :3 0
65 :3 0 66 :3 0
67 :3 0 68 :3 0
69 :3 0 6a :3 0
6b :3 0 6c :3 0
6d :3 0 6e :3 0
64 :3 0 6f :3 0
70 :3 0 71 :3 0
72 :3 0 73 :3 0
74 :3 0 6d :3 0
73 :3 0 74 :3 0
6e :3 0 75 :3 0
76 :3 0 77 :3 0
78 :3 0 79 :3 0
7a :3 0 7b :3 0
7c :3 0 7d :3 0
7e :3 0 7f :3 0
80 :3 0 e :3 0
f :3 0 27 :3 0
1a :3 0 18 :3 0
21 :3 0 2a :3 0
30 :3 0 3a :3 0
3b :3 0 2c :3 0
10 :3 0 2e :3 0
11 :3 0 12 :3 0
29 :3 0 2b :3 0
32 :3 0 15 :3 0
17 :3 0 1b :3 0
1e :3 0 3f :3 0
42 :3 0 41 :3 0
43 :3 0 44 :3 0
46 :3 0 45 :3 0
47 :3 0 2d :3 0
26 :3 0 81 :3 0
82 :3 0 c :4 0
83 1 :8 0 248
a :3 0 84 :3 0
243 244 0 85
:3 0 245 246 0
248 eb 29b 86
:3 0 a :3 0 84
:3 0 24a 24b 0
85 :3 0 24c 24d
0 24f ee 251
f0 250 24f :2 0
299 87 :3 0 a
:3 0 84 :3 0 254
255 0 85 :3 0
256 257 0 291
49 :3 0 4a :3 0
259 25a 0 49
:3 0 5b :3 0 25c
25d 0 88 :2 0
2 :4 0 89 :2 0
5d :2 0 19 :2 0
f2 262 264 :3 0
f5 25e 266 25b
268 267 :2 0 4c
:3 0 5e :3 0 26a
26b 0 4e :4 0
8a :4 0 51 :2 0
52 :3 0 f9 26f
271 :3 0 51 :2 0
8b :4 0 fc 273
275 :3 0 51 :2 0
8c :4 0 ff 277
279 :3 0 51 :2 0
85 :3 0 102 27b
27d :3 0 51 :2 0
8d :4 0 105 27f
281 :3 0 51 :2 0
74 :3 0 8e :3 0
19 :2 0 8f :2 0
108 284 288 10c
283 28a :3 0 10f
26c 28c :2 0 28e
112 28f 269 28e
0 290 114 0
291 116 294 :3 0
294 0 294 293
291 292 :6 0 296
2 :3 0 119 298
11b 297 296 :2 0
299 11d :2 0 29b
0 29b 29a 248
299 :6 0 738 1
:3 0 a :3 0 84
:3 0 29d 29e 0
a :3 0 90 :2 0
91 :3 0 2a0 2a2
0 122 2a1 2a4
:3 0 2a5 :2 0 49
:3 0 4a :3 0 2a7
2a8 0 49 :3 0
5b :3 0 2aa 2ab
0 d :2 0 2
:4 0 92 :2 0 5d
:2 0 19 :2 0 125
2b0 2b2 :3 0 128
2ac 2b4 2a9 2b6
2b5 :2 0 4c :3 0
5e :3 0 2b8 2b9
0 4e :4 0 93
:4 0 51 :2 0 52
:3 0 12c 2bd 2bf
:3 0 51 :2 0 8b
:4 0 12f 2c1 2c3
:3 0 51 :2 0 94
:4 0 132 2c5 2c7
:3 0 51 :2 0 56
:3 0 95 :3 0 96
:3 0 97 :3 0 2cc
2cd 0 135 2cb
2cf 59 :4 0 137
2ca 2d2 13a 2c9
2d4 :3 0 51 :2 0
98 :4 0 13d 2d6
2d8 :3 0 51 :2 0
54 :4 0 140 2da
2dc :3 0 51 :2 0
c :3 0 143 2de
2e0 :3 0 51 :2 0
54 :4 0 146 2e2
2e4 :3 0 149 2ba
2e6 :2 0 2e8 14c
2e9 2b7 2e8 0
2ea 14e 0 314
49 :3 0 4a :3 0
2eb 2ec 0 49
:3 0 5b :3 0 2ee
2ef 0 19 :2 0
2 :4 0 99 :2 0
5d :2 0 19 :2 0
150 2f4 2f6 :3 0
153 2f0 2f8 2ed
2fa 2f9 :2 0 4c
:3 0 5e :3 0 2fc
2fd 0 4e :4 0
9a :4 0 51 :2 0
52 :3 0 157 301
303 :3 0 15a 2fe
305 :2 0 307 15d
308 2fb 307 0
309 15f 0 314
9b :3 0 9c :3 0
30a 30b 0 96
:3 0 97 :3 0 30d
30e 0 c :3 0
9d :3 0 161 30c
312 :2 0 314 165
315 2a6 314 0
316 169 0 738
5 :3 0 9e :2 0
16b 318 319 :3 0
31a :2 0 7 :3 0
9e :2 0 16d 31d
31e :3 0 31f :2 0
31b 321 320 :2 0
13 :3 0 5 :3 0
323 324 0 48c
14 :3 0 7 :3 0
326 327 0 48c
9f :3 0 a0 :3 0
329 32a 0 13
:3 0 14 :3 0 a1
:2 0 16f 32b 32f
a2 :2 0 1d :2 0
175 331 333 :3 0
334 :2 0 9f :3 0
a0 :3 0 336 337
0 14 :3 0 12
:3 0 a1 :2 0 178
338 33c a3 :2 0
1d :2 0 17e 33e
340 :3 0 341 :2 0
335 343 342 :2 0
49 :3 0 4a :3 0
345 346 0 49
:3 0 5b :3 0 348
349 0 d :2 0
2 :4 0 a4 :2 0
5d :2 0 19 :2 0
181 34e 350 :3 0
184 34a 352 347
354 353 :2 0 4c
:3 0 5e :3 0 356
357 0 4e :4 0
a5 :4 0 51 :2 0
52 :3 0 188 35b
35d :3 0 51 :2 0
8b :4 0 18b 35f
361 :3 0 51 :2 0
94 :4 0 18e 363
365 :3 0 51 :2 0
56 :3 0 95 :3 0
96 :3 0 a6 :3 0
36a 36b 0 191
369 36d 59 :4 0
193 368 370 196
367 372 :3 0 51
:2 0 98 :4 0 199
374 376 :3 0 51
:2 0 54 :4 0 19c
378 37a :3 0 51
:2 0 c :3 0 19f
37c 37e :3 0 51
:2 0 54 :4 0 1a2
380 382 :3 0 1a5
358 384 :2 0 386
1a8 387 355 386
0 388 1aa 0
3b2 49 :3 0 4a
:3 0 389 38a 0
49 :3 0 5b :3 0
38c 38d 0 19
:2 0 2 :4 0 a7
:2 0 5d :2 0 19
:2 0 1ac 392 394
:3 0 1af 38e 396
38b 398 397 :2 0
4c :3 0 5e :3 0
39a 39b 0 4e
:4 0 a8 :4 0 51
:2 0 52 :3 0 1b3
39f 3a1 :3 0 1b6
39c 3a3 :2 0 3a5
1b9 3a6 399 3a5
0 3a7 1bb 0
3b2 9b :3 0 9c
:3 0 3a8 3a9 0
96 :3 0 a6 :3 0
3ab 3ac 0 c
:3 0 9d :3 0 1bd
3aa 3b0 :2 0 3b2
1c1 3b3 344 3b2
0 3b4 1c5 0
48c 61 :3 0 a9
:3 0 f :3 0 34
:3 0 aa :3 0 61
:3 0 f :3 0 ab
:3 0 26 :4 0 ac
1 :8 0 3c4 a
:3 0 84 :3 0 3bf
3c0 0 85 :3 0
3c1 3c2 0 3c4
1c7 417 86 :3 0
a :3 0 84 :3 0
3c6 3c7 0 85
:3 0 3c8 3c9 0
3cb 1ca 3cd 1cc
3cc 3cb :2 0 415
87 :3 0 a :3 0
84 :3 0 3d0 3d1
0 85 :3 0 3d2
3d3 0 40d 49
:3 0 4a :3 0 3d5
3d6 0 49 :3 0
5b :3 0 3d8 3d9
0 88 :2 0 2
:4 0 ad :2 0 5d
:2 0 19 :2 0 1ce
3de 3e0 :3 0 1d1
3da 3e2 3d7 3e4
3e3 :2 0 4c :3 0
5e :3 0 3e6 3e7
0 4e :4 0 ae
:4 0 51 :2 0 52
:3 0 1d5 3eb 3ed
:3 0 51 :2 0 8b
:4 0 1d8 3ef 3f1
:3 0 51 :2 0 8c
:4 0 1db 3f3 3f5
:3 0 51 :2 0 85
:3 0 1de 3f7 3f9
:3 0 51 :2 0 8d
:4 0 1e1 3fb 3fd
:3 0 51 :2 0 74
:3 0 8e :3 0 19
:2 0 8f :2 0 1e4
400 404 1e8 3ff
406 :3 0 1eb 3e8
408 :2 0 40a 1ee
40b 3e5 40a 0
40c 1f0 0 40d
1f2 410 :3 0 410
0 410 40f 40d
40e :6 0 412 4
:3 0 1f5 414 1f7
413 412 :2 0 415
1f9 :2 0 417 0
417 416 3c4 415
:6 0 48c 1 :3 0
9f :3 0 a0 :3 0
419 41a 0 13
:3 0 11 :3 0 a1
:2 0 1fc 41b 41f
a3 :2 0 1d :2 0
202 421 423 :3 0
11 :3 0 13 :3 0
425 426 0 42b
2b :3 0 1d :2 0
428 429 0 42b
205 489 49 :3 0
4a :3 0 42c 42d
0 49 :3 0 5b
:3 0 42f 430 0
af :2 0 2 :4 0
b0 :2 0 5d :2 0
19 :2 0 208 435
437 :3 0 20b 431
439 42e 43b 43a
:2 0 4c :3 0 5e
:3 0 43d 43e 0
4e :4 0 b1 :4 0
51 :2 0 52 :3 0
20f 442 444 :3 0
51 :2 0 8b :4 0
212 446 448 :3 0
51 :2 0 94 :4 0
215 44a 44c :3 0
51 :2 0 56 :3 0
95 :3 0 96 :3 0
b2 :3 0 451 452
0 218 450 454
59 :4 0 21a 44f
457 21d 44e 459
:3 0 220 43f 45b
:2 0 45d 223 45e
43c 45d 0 45f
225 0 488 49
:3 0 4a :3 0 460
461 0 49 :3 0
5b :3 0 463 464
0 19 :2 0 2
:4 0 b3 :2 0 5d
:2 0 19 :2 0 227
469 46b :3 0 22a
465 46d 462 46f
46e :2 0 4c :3 0
5e :3 0 471 472
0 4e :4 0 b4
:4 0 51 :2 0 52
:3 0 22e 476 478
:3 0 231 473 47a
:2 0 47c 234 47d
470 47c 0 47e
236 0 488 9b
:3 0 b5 :3 0 47f
480 0 96 :3 0
b2 :3 0 482 483
0 9d :3 0 238
481 486 :2 0 488
23b 48a 424 42b
0 48b 0 488
0 48b 23f 0
48c 242 48d 322
48c 0 48e 248
0 738 56 :3 0
32 :3 0 1d :2 0
24a 48f 492 a2
:2 0 1d :2 0 24f
494 496 :3 0 497
:2 0 21 :3 0 9e
:2 0 252 49a 49b
:3 0 49c :2 0 49d
:2 0 498 49f 49e
:2 0 3e :3 0 b6
:3 0 f :3 0 26
:3 0 27 :3 0 e
:3 0 c :3 0 21
:3 0 32 :3 0 1d
:2 0 254 4a2 4ab
4a1 4ac 0 4ae
25d 4af 4a0 4ae
0 4b0 25f 0
738 e :3 0 9e
:2 0 261 4b2 4b3
:3 0 4b4 :2 0 3d
:3 0 b7 :3 0 f
:3 0 c :3 0 b8
:2 0 263 4b7 4bb
4b6 4bc 0 4be
267 4df 74 :3 0
18 :3 0 19 :2 0
19 :2 0 269 4bf
4c3 90 :2 0 b8
:4 0 26f 4c5 4c7
:3 0 3d :3 0 b7
:3 0 f :3 0 c
:3 0 1d :2 0 272
4ca 4ce 4c9 4cf
0 4d1 276 4db
3d :3 0 b7 :3 0
f :3 0 c :3 0
19 :2 0 278 4d3
4d7 4d2 4d8 0
4da 27c 4dc 4c8
4d1 0 4dd 0
4da 0 4dd 27e
0 4de 281 4e0
4b5 4be 0 4e1
0 4de 0 4e1
283 0 738 21
:3 0 9e :2 0 286
4e3 4e4 :3 0 4e5
:2 0 9f :3 0 b9
:3 0 73 :3 0 74
:3 0 21 :3 0 9f
:3 0 ba :3 0 11
:3 0 11 :3 0 bb
:4 0 bc 1 :8 0
4f7 a :3 0 84
:3 0 4f2 4f3 0
85 :3 0 4f4 4f5
0 4f7 288 54a
86 :3 0 a :3 0
84 :3 0 4f9 4fa
0 85 :3 0 4fb
4fc 0 4fe 28b
500 28d 4ff 4fe
:2 0 548 87 :3 0
a :3 0 84 :3 0
503 504 0 85
:3 0 505 506 0
540 49 :3 0 4a
:3 0 508 509 0
49 :3 0 5b :3 0
50b 50c 0 88
:2 0 2 :4 0 bd
:2 0 5d :2 0 19
:2 0 28f 511 513
:3 0 292 50d 515
50a 517 516 :2 0
4c :3 0 5e :3 0
519 51a 0 4e
:4 0 be :4 0 51
:2 0 52 :3 0 296
51e 520 :3 0 51
:2 0 8b :4 0 299
522 524 :3 0 51
:2 0 8c :4 0 29c
526 528 :3 0 51
:2 0 85 :3 0 29f
52a 52c :3 0 51
:2 0 8d :4 0 2a2
52e 530 :3 0 51
:2 0 74 :3 0 8e
:3 0 19 :2 0 8f
:2 0 2a5 533 537
2a9 532 539 :3 0
2ac 51b 53b :2 0
53d 2af 53e 518
53d 0 53f 2b1
0 540 2b3 543
:3 0 543 0 543
542 540 541 :6 0
545 6 :3 0 2b6
547 2b8 546 545
:2 0 548 2ba :2 0
54a 0 54a 549
4f7 548 :6 0 55b
1 :3 0 29 :3 0
56 :3 0 29 :3 0
1d :2 0 2bd 54d
550 bf :2 0 56
:3 0 2e :3 0 1d
:2 0 2c0 553 556
2c3 552 558 :3 0
54c 559 0 55b
2c6 55c 4e6 55b
0 55d 2c9 0
738 3e :3 0 b8
:2 0 55e 55f 0
738 3d :3 0 c0
:3 0 c :3 0 11
:3 0 29 :3 0 3e
:3 0 2a :3 0 28
:3 0 56 :3 0 2b
:3 0 1d :2 0 2cb
569 56c 56 :3 0
2c :3 0 1d :2 0
2ce 56e 571 2d1
562 573 561 574
0 738 56 :3 0
3d :3 0 1d :2 0
2da 576 579 a3
:2 0 1d :2 0 2df
57b 57d :3 0 49
:3 0 4a :3 0 57f
580 0 49 :3 0
5b :3 0 582 583
0 d :2 0 2
:4 0 c1 :2 0 5d
:2 0 19 :2 0 2e2
588 58a :3 0 2e5
584 58c 581 58e
58d :2 0 4c :3 0
5e :3 0 590 591
0 4e :4 0 c2
:4 0 51 :2 0 52
:3 0 2e9 595 597
:3 0 51 :2 0 8b
:4 0 2ec 599 59b
:3 0 51 :2 0 94
:4 0 2ef 59d 59f
:3 0 51 :2 0 56
:3 0 95 :3 0 96
:3 0 c3 :3 0 5a4
5a5 0 2f2 5a3
5a7 59 :4 0 2f4
5a2 5aa 2f7 5a1
5ac :3 0 51 :2 0
98 :4 0 2fa 5ae
5b0 :3 0 51 :2 0
54 :4 0 2fd 5b2
5b4 :3 0 51 :2 0
c :3 0 300 5b6
5b8 :3 0 51 :2 0
54 :4 0 303 5ba
5bc :3 0 306 592
5be :2 0 5c0 309
5c1 58f 5c0 0
5c2 30b 0 5ec
49 :3 0 4a :3 0
5c3 5c4 0 49
:3 0 5b :3 0 5c6
5c7 0 19 :2 0
2 :4 0 c4 :2 0
5d :2 0 19 :2 0
30d 5cc 5ce :3 0
310 5c8 5d0 5c5
5d2 5d1 :2 0 4c
:3 0 5e :3 0 5d4
5d5 0 4e :4 0
c5 :4 0 51 :2 0
52 :3 0 314 5d9
5db :3 0 317 5d6
5dd :2 0 5df 31a
5e0 5d3 5df 0
5e1 31c 0 5ec
9b :3 0 9c :3 0
5e2 5e3 0 96
:3 0 c3 :3 0 5e5
5e6 0 c :3 0
9d :3 0 31e 5e4
5ea :2 0 5ec 322
674 81 :3 0 c6
:3 0 82 :3 0 c
:4 0 c7 1 :8 0
673 81 :3 0 c8
:3 0 c9 :3 0 ca
:3 0 cb :3 0 c9
:3 0 96 :3 0 cc
:3 0 96 :3 0 cd
:3 0 ce :3 0 56
:3 0 cf :3 0 d0
:3 0 d1 :3 0 56
:3 0 d2 :3 0 d3
:3 0 c6 :3 0 d4
:3 0 82 :3 0 c
:4 0 d5 1 :8 0
61e d6 :4 0 609
:3 0 9d :3 0 90
:2 0 328 60c 60d
:3 0 a :3 0 84
:3 0 60f 610 0
1d :2 0 611 612
0 614 32b 61b
a :3 0 84 :3 0
615 616 0 d7
:2 0 617 618 0
61a 32d 61c 60e
614 0 61d 0
61a 0 61d 32f
0 61e 332 671
86 :3 0 a :3 0
84 :3 0 620 621
0 85 :3 0 622
623 0 625 335
627 337 626 625
:2 0 66f 87 :3 0
a :3 0 84 :3 0
62a 62b 0 85
:3 0 62c 62d 0
667 49 :3 0 4a
:3 0 62f 630 0
49 :3 0 5b :3 0
632 633 0 88
:2 0 2 :4 0 d8
:2 0 5d :2 0 19
:2 0 339 638 63a
:3 0 33c 634 63c
631 63e 63d :2 0
4c :3 0 5e :3 0
640 641 0 4e
:4 0 d9 :4 0 51
:2 0 52 :3 0 340
645 647 :3 0 51
:2 0 8b :4 0 343
649 64b :3 0 51
:2 0 8c :4 0 346
64d 64f :3 0 51
:2 0 85 :3 0 349
651 653 :3 0 51
:2 0 8d :4 0 34c
655 657 :3 0 51
:2 0 74 :3 0 8e
:3 0 19 :2 0 8f
:2 0 34f 65a 65e
353 659 660 :3 0
356 642 662 :2 0
664 359 665 63f
664 0 666 35b
0 667 35d 66a
:3 0 66a 0 66a
669 667 668 :6 0
66c 8 :3 0 360
66e 362 66d 66c
:2 0 66f 364 :2 0
671 0 671 670
61e 66f :6 0 673
1 :3 0 367 675
57e 5ec 0 676
0 673 0 676
36a 0 738 3e
:3 0 da :3 0 f
:3 0 36d 678 67a
677 67b 0 738
49 :3 0 4a :3 0
67d 67e 0 49
:3 0 5b :3 0 680
681 0 d :2 0
2 :4 0 db :2 0
5d :2 0 19 :2 0
36f 686 688 :3 0
372 682 68a 67f
68c 68b :2 0 4c
:3 0 5e :3 0 68e
68f 0 4e :4 0
dc :4 0 51 :2 0
52 :3 0 376 693
695 :3 0 51 :2 0
8b :4 0 379 697
699 :3 0 51 :2 0
94 :4 0 37c 69b
69d :3 0 51 :2 0
56 :3 0 95 :3 0
3e :3 0 37f 6a1
6a3 59 :4 0 381
6a0 6a6 384 69f
6a8 :3 0 51 :2 0
98 :4 0 387 6aa
6ac :3 0 51 :2 0
54 :4 0 38a 6ae
6b0 :3 0 51 :2 0
c :3 0 38d 6b2
6b4 :3 0 51 :2 0
54 :4 0 390 6b6
6b8 :3 0 393 690
6ba :2 0 6bc 396
6bd 68d 6bc 0
6be 398 0 738
49 :3 0 4a :3 0
6bf 6c0 0 49
:3 0 5b :3 0 6c2
6c3 0 19 :2 0
2 :4 0 dd :2 0
5d :2 0 19 :2 0
39a 6c8 6ca :3 0
39d 6c4 6cc 6c1
6ce 6cd :2 0 4c
:3 0 5e :3 0 6d0
6d1 0 4e :4 0
de :4 0 51 :2 0
52 :3 0 3a1 6d5
6d7 :3 0 3a4 6d2
6d9 :2 0 6db 3a7
6dc 6cf 6db 0
6dd 3a9 0 738
9b :3 0 9c :3 0
6de 6df 0 56
:3 0 3e :3 0 1d
:2 0 3ab 6e1 6e4
c :3 0 9d :3 0
3ae 6e0 6e8 :2 0
738 49 :3 0 4a
:3 0 6ea 6eb 0
49 :3 0 5b :3 0
6ed 6ee 0 df
:2 0 2 :4 0 e0
:2 0 5d :2 0 19
:2 0 3b2 6f3 6f5
:3 0 3b5 6ef 6f7
6ec 6f9 6f8 :2 0
4c :3 0 5e :3 0
6fb 6fc 0 4e
:4 0 e1 :4 0 51
:2 0 52 :3 0 3b9
700 702 :3 0 51
:2 0 8b :4 0 3bc
704 706 :3 0 51
:2 0 94 :4 0 3bf
708 70a :3 0 51
:2 0 56 :3 0 95
:3 0 a :3 0 84
:3 0 70f 710 0
3c2 70e 712 59
:4 0 3c4 70d 715
3c7 70c 717 :3 0
51 :2 0 98 :4 0
3ca 719 71b :3 0
51 :2 0 54 :4 0
3cd 71d 71f :3 0
51 :2 0 c :3 0
3d0 721 723 :3 0
51 :2 0 54 :4 0
3d3 725 727 :3 0
3d6 6fd 729 :2 0
72b 3d9 72c 6fa
72b 0 72d 3db
0 738 9b :3 0
e2 :3 0 72e 72f
0 a :3 0 84
:3 0 731 732 0
c :3 0 9d :3 0
3dd 730 736 :2 0
738 3e1 7d9 a
:3 0 e3 :2 0 4
739 73a 0 49
:3 0 4a :3 0 73c
73d 0 49 :3 0
5b :3 0 73f 740
0 88 :2 0 2
:4 0 e4 :2 0 5d
:2 0 19 :2 0 3f5
745 747 :3 0 3f8
741 749 73e 74b
74a :2 0 4c :3 0
5e :3 0 74d 74e
0 4e :4 0 e5
:4 0 51 :2 0 52
:3 0 3fc 752 754
:3 0 3ff 74f 756
:2 0 76f 4c :3 0
5e :3 0 758 759
0 4e :4 0 e6
:4 0 51 :2 0 a
:3 0 e7 :3 0 75e
75f 0 402 75d
761 :3 0 51 :2 0
98 :4 0 405 763
765 :3 0 51 :2 0
a :3 0 e8 :3 0
768 769 0 408
767 76b :3 0 40b
75a 76d :2 0 76f
40e 770 74c 76f
0 771 411 0
781 e9 :3 0 48
:3 0 a :3 0 e7
:3 0 ea :3 0 a
:3 0 e8 :3 0 eb
:3 0 bb :4 0 ec
1 :a 0 77d :2 0
781 773 77b :2 0
9 :3 0 48 :3 0
77f :2 0 781 413
783 417 782 781
:2 0 7d7 87 :3 0
a :3 0 84 :3 0
786 787 0 85
:3 0 788 789 0
7cf 49 :3 0 4a
:3 0 78b 78c 0
49 :3 0 5b :3 0
78e 78f 0 88
:2 0 2 :4 0 ed
:2 0 5d :2 0 19
:2 0 419 794 796
:3 0 41c 790 798
78d 79a 799 :2 0
4c :3 0 5e :3 0
79c 79d 0 4e
:4 0 ee :4 0 51
:2 0 52 :3 0 420
7a1 7a3 :3 0 423
79e 7a5 :2 0 7bf
4c :3 0 5e :3 0
7a7 7a8 0 4e
:4 0 8c :4 0 51
:2 0 85 :3 0 426
7ac 7ae :3 0 51
:2 0 8d :4 0 429
7b0 7b2 :3 0 51
:2 0 74 :3 0 8e
:3 0 19 :2 0 8f
:2 0 42c 7b5 7b9
430 7b4 7bb :3 0
433 7a9 7bd :2 0
7bf 436 7c0 79b
7bf 0 7c1 439
0 7cf e9 :3 0
48 :3 0 ea :3 0
a :3 0 e8 :3 0
eb :3 0 bb :4 0
ef 1 :a 0 7cb
:2 0 7cf 7c3 7c9
:2 0 9 :3 0 48
:3 0 7cd :2 0 7cf
43b 7d2 :3 0 7d2
0 7d2 7d1 7cf
7d0 :6 0 7d4 1
:3 0 440 7d6 442
7d5 7d4 :2 0 7d7
444 :2 0 7d9 447
7d9 7d8 738 7d7
:6 0 7da :2 0 2
18 7d9 7dd :3 0
7dc 7da 7de :8 0

47f
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1c
1 1a 1 23
1 21 1 2a
1 28 1 2f
1 34 1 39
1 3e 1 43
1 48 1 4d
1 54 1 52
1 5b 1 59
1 60 1 66
1 6c 1 72
1 77 1 7c
1 82 1 88
1 8e 1 96
1 94 1 9d
1 9b 1 a4
1 a2 1 a9
1 af 1 b5
1 bb 1 c1
1 c7 1 cd
1 d3 1 d9
1 df 1 e5
1 eb 1 f1
1 f7 1 fd
1 103 1 109
1 10f 1 115
1 11b 1 121
1 127 1 12d
1 133 1 139
1 13f 1 145
1 14b 1 151
1 157 1 15d
1 16a 1 176
2 179 17b 2
17e 180 2 182
184 2 186 188
2 18a 18c 2
192 194 2 196
198 2 19a 19b
2 19d 19e 2
18e 1a0 2 1a2
1a4 2 1aa 1ac
2 1ae 1b0 2
1b2 1b3 2 1b5
1b6 2 1a6 1b8
2 1ba 1bc 2
1be 1c0 2 1c2
1c4 2 1c6 1c8
2 1ca 1cc 4
172 178 17d 1ce
1 1d0 1 1d2
2 1dc 1de 3
1da 1db 1e0 2
1e9 1eb 2 1e8
1ed 1 1ef 1
1f1 2 242 247
1 24e 1 249
2 261 263 3
25f 260 265 2
26e 270 2 272
274 2 276 278
2 27a 27c 2
27e 280 3 285
286 287 2 282
289 2 26d 28b
1 28d 1 28f
2 258 290 1
294 1 253 2
251 298 1 2a3
2 29f 2a3 2
2af 2b1 3 2ad
2ae 2b3 2 2bc
2be 2 2c0 2c2
2 2c4 2c6 1
2ce 2 2d0 2d1
2 2c8 2d3 2
2d5 2d7 2 2d9
2db 2 2dd 2df
2 2e1 2e3 2
2bb 2e5 1 2e7
1 2e9 2 2f3
2f5 3 2f1 2f2
2f7 2 300 302
2 2ff 304 1
306 1 308 3
30f 310 311 3
2ea 309 313 1
315 1 317 1
31c 3 32c 32d
32e 1 332 2
330 332 3 339
33a 33b 1 33f
2 33d 33f 2
34d 34f 3 34b
34c 351 2 35a
35c 2 35e 360
2 362 364 1
36c 2 36e 36f
2 366 371 2
373 375 2 377
379 2 37b 37d
2 37f 381 2
359 383 1 385
1 387 2 391
393 3 38f 390
395 2 39e 3a0
2 39d 3a2 1
3a4 1 3a6 3
3ad 3ae 3af 3
388 3a7 3b1 1
3b3 2 3be 3c3
1 3ca 1 3c5
2 3dd 3df 3
3db 3dc 3e1 2
3ea 3ec 2 3ee
3f0 2 3f2 3f4
2 3f6 3f8 2
3fa 3fc 3 401
402 403 2 3fe
405 2 3e9 407
1 409 1 40b
2 3d4 40c 1
410 1 3cf 2
3cd 414 3 41c
41d 41e 1 422
2 420 422 2
427 42a 2 434
436 3 432 433
438 2 441 443
2 445 447 2
449 44b 1 453
2 455 456 2
44d 458 2 440
45a 1 45c 1
45e 2 468 46a
3 466 467 46c
2 475 477 2
474 479 1 47b
1 47d 2 484
485 3 45f 47e
487 2 489 48a
5 325 328 3b4
417 48b 1 48d
2 490 491 1
495 2 493 495
1 499 8 4a3
4a4 4a5 4a6 4a7
4a8 4a9 4aa 1
4ad 1 4af 1
4b1 3 4b8 4b9
4ba 1 4bd 3
4c0 4c1 4c2 1
4c6 2 4c4 4c6
3 4cb 4cc 4cd
1 4d0 3 4d4
4d5 4d6 1 4d9
2 4db 4dc 1
4dd 2 4df 4e0
1 4e2 2 4f1
4f6 1 4fd 1
4f8 2 510 512
3 50e 50f 514
2 51d 51f 2
521 523 2 525
527 2 529 52b
2 52d 52f 3
534 535 536 2
531 538 2 51c
53a 1 53c 1
53e 2 507 53f
1 543 1 502
2 500 547 2
54e 54f 2 554
555 2 551 557
2 54a 55a 1
55c 2 56a 56b
2 56f 570 8
563 564 565 566
567 568 56d 572
2 577 578 1
57c 2 57a 57c
2 587 589 3
585 586 58b 2
594 596 2 598
59a 2 59c 59e
1 5a6 2 5a8
5a9 2 5a0 5ab
2 5ad 5af 2
5b1 5b3 2 5b5
5b7 2 5b9 5bb
2 593 5bd 1
5bf 1 5c1 2
5cb 5cd 3 5c9
5ca 5cf 2 5d8
5da 2 5d7 5dc
1 5de 1 5e0
3 5e7 5e8 5e9
3 5c2 5e1 5eb
1 60b 2 60a
60b 1 613 1
619 2 61b 61c
2 608 61d 1
624 1 61f 2
637 639 3 635
636 63b 2 644
646 2 648 64a
2 64c 64e 2
650 652 2 654
656 3 65b 65c
65d 2 658 65f
2 643 661 1
663 1 665 2
62e 666 1 66a
1 629 2 627
66e 2 5f1 671
2 674 675 1
679 2 685 687
3 683 684 689
2 692 694 2
696 698 2 69a
69c 1 6a2 2
6a4 6a5 2 69e
6a7 2 6a9 6ab
2 6ad 6af 2
6b1 6b3 2 6b5
6b7 2 691 6b9
1 6bb 1 6bd
2 6c7 6c9 3
6c5 6c6 6cb 2
6d4 6d6 2 6d3
6d8 1 6da 1
6dc 2 6e2 6e3
3 6e5 6e6 6e7
2 6f2 6f4 3
6f0 6f1 6f6 2
6ff 701 2 703
705 2 707 709
1 711 2 713
714 2 70b 716
2 718 71a 2
71c 71e 2 720
722 2 724 726
2 6fe 728 1
72a 1 72c 3
733 734 735 13
1d3 1f2 1f5 1f8
29b 316 48e 4b0
4e1 55d 560 575
676 67c 6be 6dd
6e9 72d 737 2
744 746 3 742
743 748 2 751
753 2 750 755
2 75c 760 2
762 764 2 766
76a 2 75b 76c
2 757 76e 1
770 3 771 77c
780 1 73b 2
793 795 3 791
792 797 2 7a0
7a2 2 79f 7a4
2 7ab 7ad 2
7af 7b1 3 7b6
7b7 7b8 2 7b3
7ba 2 7aa 7bc
2 7a6 7be 1
7c0 4 78a 7c1
7ca 7ce 1 7d2
1 785 2 783
7d6 37 1f 26
2d 32 37 3c
41 46 4b 50
57 5e 64 6a
70 75 7a 80
86 8c 92 99
a0 a7 ad b3
b9 bf c5 cb
d1 d7 dd e3
e9 ef f5 fb
101 107 10d 113
119 11f 125 12b
131 137 13d 143
149 14f 155 15b
162 
1
4
0 
7dd
0
1
14
a
3c
0 1 2 1 4 1 6 1
8 1 0 0 0 0 0 0
0 0 0 0 
11b 1 0
157 1 0
43 1 0
b5 1 0
127 1 0
d9 1 0
b 1 0
109 1 0
39 1 0
1a 1 0
6c 1 0
cd 1 0
df 1 0
f 1 0
59 1 0
3e 1 0
133 1 0
82 1 0
139 1 0
7c 1 0
72 1 0
121 1 0
e5 1 0
bb 1 0
f7 1 0
115 1 0
77 1 0
a9 1 0
c1 1 0
34 1 0
145 1 0
8e 1 0
60 1 0
103 1 0
4d 1 0
151 1 0
3 1 0
66 1 0
94 1 0
2f 1 0
c7 1 0
10f 1 0
d3 1 0
f1 1 0
52 1 0
13f 1 0
88 1 0
9b 1 0
28 1 0
eb 1 0
7 1 0
21 1 0
2 0 1
12d 1 0
48 1 0
fd 1 0
a2 1 0
af 1 0
14b 1 0
15d 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_DATES;
ALTER FUNCTION SP_U_WP_DATES COMPILE DEBUG;
/**************************************************************************/
Prompt == FUNCTION FC_U_WP_ACTUAL ==
CREATE OR REPLACE FUNCTION FC_U_WP_ACTUAL wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
16b
2 :e:
1FUNCTION:
1FC_U_WP_ACTUAL:
1H_ASSIGN_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1SH_H_NEW_WORK_PERCENT:
1PLS_INTEGER:
1SH_H_ACTUAL:
1SH_H_UNITS:
1H_REC_USER:
1H_ERROR_ID:
1RETURN:
1H_NEW_WORK_PERCENT:
1H_ACTUAL:
1H_UNITS:
1H_ID:
132:
1H_PRJ_ASSIGN_ID:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RES_ID:
1H_SD:
1DATE:
1H_FD:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_LAST_SUBMITTED:
1H_WEEK_OF:
1H_DAYOFYEAR:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_REC_STATUS:
1H_LAST_MINUTES:
10:
1H_COUNT:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_EFFORT:
1H_WORK_PERCENT:
1H_PERCENT_UNITS:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_LAST_DAY:
1H_PER_DAY:
1H_TASK_TYPE:
1H_TPH_DELETE:
1H_TEMP_VAR:
1H_MINUTES:
1H_DURATION:
1H_CONTOUR:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_WORK:
1H_SCHED_EFFORT:
1H_WORK_TYPE:
1H_ETC:
1H_CLOSE_TASK:
1H_REMAINING:
1H_ROLLUP_BITS:
1H_BITID:
1RAW:
136:
1PMO_CNST:
1SC_ZERO_BIT:
1H_BITID1:
1H_ASSIGN_STRING:
18192:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1DEBUG_PERFTIMING:
1T_TOTAL:
1S_TIME_1:
1S_TIME_2:
1S_TIME_3:
1S_TIME_4:
1H_CONF_FLAG:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_WP_ACTUAL(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
186:
1+:
1FPUT:
1               ENTER:: FC_U_WP_ACTUAL(87) :: cplan.sql(16954) :: :
1PROJECT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1BIT_FLAG:
1LAST_SUBMITTED:
1WORK_TODATE:
1SCHED_WORK:
1ETC:
1LAST_SCHED_MIN:
1PROJECT_ASSIGNMENT_ID:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1ASSIGN_UNITS:
1UNITS_MSP:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1TO_DATE:
1SUBSTR:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1ROLLUP_BITS:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, RESOURCE_ID, RESOURCE_TYPE, BIT_FLAG, LAST_SUBMITTED, WORK+
1_TODATE, SCHED_WORK-WORK_TODATE, ETC,:n      SCHED_WORK, LAST_SCHED_MIN, PROJ+
1ECT_ASSIGNMENT_ID, C_CONTOUR, C_EFFORT, T_UNIT, C_UNIT, CASE WHEN ASSIGN_UNIT+
1S > UNITS_MSP THEN ASSIGN_UNITS ELSE UNITS_MSP END,:n      UNRESOLVED_START, +
1UNRESOLVED_FINISH, TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(SubStr(U+
1NRESOLVED_FINISH, 1, 10)), BILLABLE, CAPITAL_EXPENSE,:n      REGULAR_COST, SP+
1ECIAL_COST, REGULAR_RATE, SPECIAL_RATE,:n      B_REGULAR_COST, B_SPECIAL_COST+
1, B_REGULAR_RATE, B_SPECIAL_RATE,:n      MILESTONE_PERCENT, TASK_ID, ROLLUP_B+
1ITS:n      INTO h_project_id, h_res_id, h_res_type, h_bit_flag, h_last_submit+
1ted, h_work_todate, h_remaining, h_etc,:n      h_effort, h_last_day, h_prj_as+
1sign_id, h_contour, h_work, h_eunit, h_unit, h_percent_units,:n      h_start_+
1date, h_finish_date, h_SD, h_FD, h_billable, h_capital_expense,:n      h_reg_+
1cost, h_spec_cost, h_reg_sale, h_spec_sale,:n      h_b_reg_cost, h_b_spec_cos+
1t, h_b_reg_sale, h_b_spec_sale,:n      h_work_percent, h_task_id, h_rollup_bi+
1ts:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID = h_id:
1PMO_DB2M:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1114:
1           EXCEPTION:: FC_U_WP_ACTUAL(115) :: cplan.sql(16982) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1TASK_TYPE:
1SCHED_EFFORT:
1SCHED_DURATION:
1MINUTE_PER_DAY:
1REC_STATUS:
1CONFIG_FLAG:
1TMT_WBS:
1ELEMENT_ID:
1SELECT PROJECT_ID, TASK_TYPE, SCHED_EFFORT, WORK_TODATE, MILESTONE_PERCENT, S+
1CHED_DURATION, MINUTE_PER_DAY, REC_STATUS, CONFIG_FLAG:n         INTO h_proje+
1ct_id, h_task_type, h_effort, h_work_todate, h_work_percent, h_duration, h_pe+
1r_day, h_rec_status, h_conf_flag:n         FROM TMT_WBS:n         WHERE ELEME+
1NT_ID = h_id:
1133:
1           EXCEPTION:: FC_U_WP_ACTUAL(134) :: cplan.sql(17001) :: :
1141:
1                EXIT:: FC_U_WP_ACTUAL(142) :: cplan.sql(17009) :: :
1RECORD_NOT_FOUND:
1T:
1148:
1                EXIT:: FC_U_WP_ACTUAL(149) :: cplan.sql(17016) :: :
1CANNOT_UPDATE_LOCKED_RECORD:
1BITAND:
1SC_WBS_ENFORCE_TC_TS:
1156:
1                EXIT:: FC_U_WP_ACTUAL(157) :: cplan.sql(17024) :: :
1SC_TIMESHEET_STEP_EXISTS:
1LEVEL_LOCK:
1PROJECT_DETAILS:
1SELECT LEVEL_LOCK:n         INTO h_temp_var:n         FROM PROJECT_DETAILS:n +
1        WHERE PROJECT_ID = h_project_id:
1175:
1           EXCEPTION:: FC_U_WP_ACTUAL(176) :: cplan.sql(17043) :: :
1>:
1SELECT REC_STATUS:n            INTO h_rec_status:n            FROM TMT_WBS:n +
1           WHERE ELEMENT_ID = h_project_id:
1194:
1           EXCEPTION:: FC_U_WP_ACTUAL(195) :: cplan.sql(17062) :: :
1PMO_ORASTD:
1STRCMP:
1L:
1202:
1                EXIT:: FC_U_WP_ACTUAL(203) :: cplan.sql(17070) :: :
1LEV_LOCKED_BY_COPY:
1COUNT:
1DUAL:
1A:
1TA:
1ACTIVITIES:
1TYPE_ID:
1SC_TIMESHEET_ACTIVITY:
1SELECT COUNT('X'):n         INTO h_temp_var:n         FROM DUAL:n         WHE+
1RE EXISTS(:n         SELECT A.ELEMENT_ID:n         FROM TASK_ASSIGNMENTS TA, +
1ACTIVITIES A:n         WHERE TA.PROJECT_ID = h_project_id:n         AND TA.TA+
1SK_ID = h_id:n         AND TA.TSK_ASSIGNMENT_ID = A.TSK_ASSIGNMENT_ID:n      +
1   AND A.TSK_ASSIGNMENT_ID <> A.ELEMENT_ID:n         AND A.TYPE_ID = pmo_cnst+
1.SC_TIMESHEET_ACTIVITY):
1230:
1           EXCEPTION:: FC_U_WP_ACTUAL(231) :: cplan.sql(17098) :: :
1238:
1                EXIT:: FC_U_WP_ACTUAL(239) :: cplan.sql(17106) :: :
18:
1245:
1      RETURN_INVALID:: FC_U_WP_ACTUAL(246) :: cplan.sql(17113) :: :
1STATE:: :
1INVALID_PARAMS:
1248:
1                EXIT:: FC_U_WP_ACTUAL(249) :: cplan.sql(17116) :: :
1PMODEFINES:
1PMO_RETURN_INVALID:
1FALSE:
1ELSIF:
1!=:
1256:
1                EXIT:: FC_U_WP_ACTUAL(257) :: cplan.sql(17124) :: :
1SC_TASK_ACTUAL_GRATER_THAN_SCH:
1FC_U_TASK_PERCENT:
1268:
1      RETURN_INVALID:: FC_U_WP_ACTUAL(269) :: cplan.sql(17136) :: :
1271:
1                EXIT:: FC_U_WP_ACTUAL(272) :: cplan.sql(17139) :: :
1279:
1                EXIT:: FC_U_WP_ACTUAL(280) :: cplan.sql(17147) :: :
1298:
1           EXCEPTION:: FC_U_WP_ACTUAL(299) :: cplan.sql(17166) :: :
1317:
1           EXCEPTION:: FC_U_WP_ACTUAL(318) :: cplan.sql(17185) :: :
1325:
1                EXIT:: FC_U_WP_ACTUAL(326) :: cplan.sql(17193) :: :
1SELECT MINUTE_PER_DAY, TASK_TYPE, REC_STATUS, CONFIG_FLAG:n         INTO h_pe+
1r_day, h_task_type, h_rec_status, h_conf_flag:n         FROM TMT_WBS:n       +
1  WHERE PROJECT_ID = h_project_id :n         AND ELEMENT_ID = h_task_id:
1345:
1           EXCEPTION:: FC_U_WP_ACTUAL(346) :: cplan.sql(17213) :: :
1353:
1                EXIT:: FC_U_WP_ACTUAL(354) :: cplan.sql(17221) :: :
1361:
1                EXIT:: FC_U_WP_ACTUAL(362) :: cplan.sql(17229) :: :
1SELECT COUNT('X'):n         INTO h_temp_var:n         FROM DUAL:n         WHE+
1RE EXISTS(:n         SELECT ELEMENT_ID:n         FROM ACTIVITIES:n         WH+
1ERE TSK_ASSIGNMENT_ID = h_id:n         AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n +
1        AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY):
1386:
1           EXCEPTION:: FC_U_WP_ACTUAL(387) :: cplan.sql(17254) :: :
1394:
1                EXIT:: FC_U_WP_ACTUAL(395) :: cplan.sql(17262) :: :
1TRUNC:
1*:
110000:
1/:
1SC_FD_EFFORT_DRIVEN:
1SC_FIXED_DURATION:
1DAY_YEAR:
1MIN:
1TASK_DAY_OF_YEAR:
1ACTUAL_FLAG:
1SELECT COUNT(DAY_YEAR), MIN(DAY_YEAR) :n                  INTO h_count, h_day+
1ofyear :n                  FROM TASK_DAY_OF_YEAR:n                  WHERE PRO+
1JECT_ID = h_project_id:n                  AND TSK_ASSIGNMENT_ID = h_id:n     +
1             AND ACTUAL_FLAG = 0:
1426:
1           EXCEPTION:: FC_U_WP_ACTUAL(427) :: cplan.sql(17294) :: :
1IS NOT NULL:
1SCHED_MIN:
1ACTUAL_MIN:
1SELECT SCHED_MIN - ACTUAL_MIN INTO h_minutes:n                        FROM TA+
1SK_DAY_OF_YEAR :n                        WHERE PROJECT_ID = h_project_id AND +
1TSK_ASSIGNMENT_ID = h_id AND DAY_YEAR = TO_DATE(SubStr(h_last_submitted, 1, 1+
10)):
1449:
1           EXCEPTION:: FC_U_WP_ACTUAL(450) :: cplan.sql(17317) :: :
1-:
1TO_NUMBER:
10.49:
1FC_FD_U_TDY:
110000.00:
1PMO_FUNC:
1BIT_OR:
1SC_BIT_30:
1U_ASSIGN_STRING:
1FC_TPHASE_ASSIGN:
1<:
1CONSIDER:
1PMO_STPU:
1SC_SCHED_BIT:
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_new_actual,:n           +
1                WORK_TODATE = h_new_actual,:n                           ETC =+
1 h_etc,:n                           MILESTONE_PERCENT = 10000:n              +
1             WHERE TSK_ASSIGNMENT_ID = h_id:
1FOUND:
1TRUE:
1100:
1506:
1           EXCEPTION:: FC_U_WP_ACTUAL(507) :: cplan.sql(17374) :: :
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_new_actual,:n           +
1                WORK_TODATE = h_new_actual,:n                           ETC =+
1 0,:n                           MILESTONE_PERCENT = 10000:n                  +
1         WHERE TSK_ASSIGNMENT_ID = h_id:
1534:
1           EXCEPTION:: FC_U_WP_ACTUAL(535) :: cplan.sql(17402) :: :
1UPDATE TASK_ASSIGNMENTS:n                           SET CONSIDER = 7,:n      +
1                     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_SC+
1HED_BIT),:n                           SCHED_WORK = h_etc,:n                  +
1         WORK_TODATE = h_new_actual:n                           WHERE TSK_ASS+
1IGNMENT_ID = h_id:
1564:
1           EXCEPTION:: FC_U_WP_ACTUAL(565) :: cplan.sql(17432) :: :
1593:
1           EXCEPTION:: FC_U_WP_ACTUAL(594) :: cplan.sql(17461) :: :
1UPDATE TASK_ASSIGNMENTS:n                     SET CONSIDER = 7,:n            +
1         ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_SCHED_BIT),:n +
1                    SCHED_WORK = h_new_actual,:n                     WORK_TOD+
1ATE = h_new_actual,:n                     ETC = 0,:n                     MILE+
1STONE_PERCENT = 10000:n                     WHERE TSK_ASSIGNMENT_ID = h_id:
1624:
1           EXCEPTION:: FC_U_WP_ACTUAL(625) :: cplan.sql(17492) :: :
1MAX:
1WEEK_OF:
1TIMESHEET_APPROVAL_STATUS:
1SELECT MAX(WEEK_OF):n                     INTO h_week_of:n                   +
1  FROM TIMESHEET_APPROVAL_STATUS:n                     WHERE ELEMENT_ID = h_p+
1roject_id:n                     AND RESOURCE_ID = h_res_id:
1646:
1           EXCEPTION:: FC_U_WP_ACTUAL(647) :: cplan.sql(17514) :: :
1SELECT TO_DATE(SubStr(h_week_of, 1, 10)) + 7      INTO h_week_of FROM DUAL:
1662:
1           EXCEPTION:: FC_U_WP_ACTUAL(663) :: cplan.sql(17530) :: :
1STRNCMP:
110:
1DB2TIMESTAMP:
1TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)):n                        INTO h_start_date:n      +
1                  FROM DUAL:
1685:
1           EXCEPTION:: FC_U_WP_ACTUAL(686) :: cplan.sql(17553) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                        INTO h_start_dat+
1e:n                        FROM DUAL:
1702:
1           EXCEPTION:: FC_U_WP_ACTUAL(703) :: cplan.sql(17570) :: :
1FC_DEL_NOACTUAL:
12:
1FC_RESCHEDULE:
1726:
1                EXIT:: FC_U_WP_ACTUAL(727) :: cplan.sql(17594) :: :
1FC_U_ASSIGN_PERCENT:
1748:
1                EXIT:: FC_U_WP_ACTUAL(749) :: cplan.sql(17616) :: :
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS:n            SET MILESTONE_PERCENT = h_new_work_perce+
1nt,:n            ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PERCEN+
1T_COMPLETE_BIT):n            WHERE TSK_ASSIGNMENT_ID = h_id:
1802:
1           EXCEPTION:: FC_U_WP_ACTUAL(803) :: cplan.sql(17670) :: :
1UPDATE TMT_WBS:n            SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo+
1_cnst.SC_PERCENT_COMPLETE_BIT):n            WHERE PROJECT_ID = h_project_id:n+
1            AND ELEMENT_ID = h_task_id:
1829:
1           EXCEPTION:: FC_U_WP_ACTUAL(830) :: cplan.sql(17697) :: :
1103079040:
1842:
1                EXIT:: FC_U_WP_ACTUAL(843) :: cplan.sql(17710) :: :
1SELECT UNITS_MSP:n               INTO h_temp_var:n               FROM TASK_AS+
1SIGNMENTS:n               WHERE TSK_ASSIGNMENT_ID = h_prj_assign_id:
1864:
1           EXCEPTION:: FC_U_WP_ACTUAL(865) :: cplan.sql(17732) :: :
1SC_SQL_SUCCESS:
1874:
1                EXIT:: FC_U_WP_ACTUAL(875) :: cplan.sql(17742) :: :
1TASK_ASSIGNMENT_ERROR:
1FC_U_TDY_LAST_ACTUAL:
1SC_BIT_29:
1SELECT TO_DATE(SubStr(UNRESOLVED_START, 1, 10)), TO_DATE(SubStr(UNRESOLVED_FI+
1NISH, 1, 10)) INTO h_SD, h_FD:n               FROM TASK_ASSIGNMENTS WHERE TSK+
1_ASSIGNMENT_ID = h_id:
1906:
1           EXCEPTION:: FC_U_WP_ACTUAL(907) :: cplan.sql(17774) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                  INTO h_start_date:n   +
1               FROM DUAL:
1942:
1           EXCEPTION:: FC_U_WP_ACTUAL(943) :: cplan.sql(17810) :: :
1961:
1                EXIT:: FC_U_WP_ACTUAL(962) :: cplan.sql(17829) :: :
1CONTOUR_TYPE:
1SC_PLANNED_BIT:
1UPDATE TASK_ASSIGNMENTS:n                  SET CONSIDER = 7,:n               +
1   UNITS_MSP = h_percent_units,:n                  C_EFFORT = 0,:n           +
1       C_UNIT = 0,:n                  C_CONTOUR = 0,:n                  CONTO+
1UR_TYPE = 0,:n                  ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,(pm+
1o_cnst.SC_SCHED_BIT+pmo_cnst.SC_PLANNED_BIT)):n                  WHERE TSK_AS+
1SIGNMENT_ID = h_id:
1987:
1           EXCEPTION:: FC_U_WP_ACTUAL(988) :: cplan.sql(17855) :: :
1FC_ROLLUP:
11005:
1                EXIT:: FC_U_WP_ACTUAL(1006) :: cplan.sql(17873) :: :
0

0
0
16df
2
0 a0 8d 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 90 :3 a0 b0 3f 90
:3 a0 b0 3f b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c :2 a0 6b 81 b0 a3 a0 51
a5 1c :2 a0 6b 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 :2 a0
6b :2 a0 6b 6e a5 b a 10
:2 a0 6b 6e :2 a0 6b 6e a5 b
6e 7e a0 b4 2e 6e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 d :4d a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :15 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 19 3c
:2 a0 :2 51 a5 b 7e 6e b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c :3 a0 51 a5 b :2 a0
6b a5 b 5a a0 7e a0 6b
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c a0 51 d
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 6e
a5 b 7e 51 b4 2e :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c b7 19 3c a0 51 d :1b a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b :2 a0 6b
a0 a5 b 65 a0 b7 :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e a0 51 d :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 a0 b7 :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e a0
51 d b7 :2 19 3c :2 a0 d :8 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b a5 b d b7 19
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b :2 a0 6b a0 a5 b 65
b7 :2 19 3c b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c a0
51 d :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :5 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 6e a5 b 7e 51 b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c b7 19 3c :d a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 :2 51 a5 b 7e 6e b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c :3 a0 51 a5 b :2 a0
6b a5 b 5a a0 7e a0 6b
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c a0 51 d
:c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :4 a0 51 a5 b 7e 51 b4
2e 5a 7e :2 a0 51 a5 b b4
2e a5 b d b7 19 3c :3 a0
51 a5 b d :2 a0 51 a5 b
a0 7e a0 51 a5 b b4 2e
:2 a0 d :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 52 10 a0 4d d :c a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 7e b4 2e 5a :2 a0 d
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e :2 a0 51 a5 b 7e
51 b4 2e 5a a0 7e b4 2e
:2 5a a 10 :c a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
7e :2 a0 51 a5 b b4 2e d
a0 51 d b7 19 3c :5 a0 a5
b 51 a5 b 7e :3 a0 a5 b
51 a5 b b4 2e 5a 7e 51
b4 2e a5 b d :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
d :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e :3 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
7e :2 a0 51 a5 b b4 2e d
b7 :3 a0 51 a5 b d b7 :2 19
3c :9 a0 51 a5 b d :5 a0 a5
b 51 a5 b 7e :3 a0 a5 b
51 a5 b b4 2e 5a 7e 51
b4 2e a5 b d :3 a0 6b :2 a0
51 a5 b :2 a0 6b a5 b d
:7 a0 51 a5 b :2 a0 51 a5 b
51 a5 b d :5 a0 51 a5 b
d b7 19 3c b7 :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :2 a0 6b :2 a0 a5 b 7e 51
b4 2e :3 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e d a0 51
d :2 a0 51 a5 b 7e :2 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e 5a b4 2e :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e 5a
7e :2 a0 51 a5 b b4 2e d
:11 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 6b :2 a0 51 a5 b :2 a0 6b
a5 b d b7 :10 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c b7
:2 a0 51 a5 b 7e :2 a0 51 a5
b 7e :2 a0 51 a5 b b4 2e
5a b4 2e :3 a0 51 a5 b 7e
:2 a0 51 a5 b b4 2e d :5 a0
a5 b 51 a5 b 7e :3 a0 a5
b 51 a5 b b4 2e 5a 7e
51 b4 2e 5a 7e 51 b4 2e
a5 b d :e a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :3 a0 51 a5 b
7e :2 a0 51 a5 b b4 2e d
a0 51 d :10 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c b7 :2 19
3c b7 :3 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e d a0 51
d :10 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c a0 7e b4 2e
5a a0 4d d :8 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 7e
b4 2e 5a :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d b7 19 3c a0 b7 :2 a0 51
a5 b 7e 51 b4 2e :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
5a d :a a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 :a a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 19 3c a0 7e
b4 2e 5a :4 a0 51 a5 b d
b7 :2 a0 :2 51 a5 b 7e 6e b4
2e :4 a0 51 a5 b d b7 :4 a0
51 a5 b d b7 :2 19 3c b7
:2 19 3c a0 51 d :8 a0 51 :2 a0
51 a5 b a5 b d :2 a0 51
a5 b 7e 51 b4 2e :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 51 a5 b 65
b7 19 3c b7 :2 19 3c :2 a0 d
b7 :5 a0 a5 b 51 a5 b 7e
:3 a0 a5 b 51 a5 b b4 2e
5a 7e 51 b4 2e 5a 7e 51
b4 2e a5 b d b7 :2 19 3c
:1b a0 51 a5 b :2 a0 51 a5 b
a5 b d :2 a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 51 a5 b 65 a0 b7 :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :b a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :b a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 b7 19 :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
51 a5 b 7e 51 b4 2e 5a
52 10 :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :3 a0 51 a5
b d b7 :2 19 3c a0 7e b4
2e 5a :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e 5a a 10 :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c b7
19 3c :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 51 a5 b
a0 7e a0 6b b4 2e 52 10
:2 a0 51 a5 b 7e 51 b4 2e
5a a0 7e b4 2e :2 5a a 10
:9 a0 51 a5 b d b7 19 3c
:4 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e 5a 7e 51 b4 2e
5a 7e 51 b4 2e a5 b d
:9 a0 51 a5 b d :3 a0 6b :2 a0
51 a5 b :2 a0 6b a5 b d
:5 a0 :3 51 a5 b d :b a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :5 a0
51 a5 b d b7 :2 a0 51 a5
b 7e 51 b4 2e 5a a0 7e
b4 2e :2 5a a 10 :9 a0 51 a5
b d b7 19 3c a0 7e b4
2e 5a :4 a0 51 a5 b d b7
:2 a0 :2 51 a5 b 7e 6e b4 2e
:4 a0 51 a5 b d b7 :4 a0 51
a5 b d b7 :2 19 3c b7 :2 19
3c a0 7e b4 2e 5a :a a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e d b7 19 3c a0
51 d a0 51 d :8 a0 51 :2 a0
51 a5 b a5 b d :2 a0 51
a5 b 7e 51 b4 2e :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 :12 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :2 19 3c b7 :2 19 3c
b7 :2 19 3c :2 a0 6b :2 a0 a5 b
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 a4 b1 11
68 4f 1d 17 b5 
16df
2
0 3 7 2b 1f 23 27 1e
32 3f 3b 1b 47 50 4c 3a
58 65 61 37 6d 7e 72 76
7a 60 85 9a 8e 92 96 5d
a1 8d a6 aa ae b2 cf ba
be c6 ca 8a eb d6 da e2
e6 b9 10b f6 fa 102 106 b6
127 112 116 119 11a 122 f5 144
132 f2 136 137 13f 131 161 14f
12e 153 154 15c 14e 17e 16c 14b
170 171 179 16b 19b 189 168 18d
18e 196 188 1b7 1a6 1aa 1b2 185
1cf 1be 1c2 1ca 1a5 1eb 1da 1de
1e6 1a2 203 1f2 1f6 1fe 1d9 21f
20e 212 21a 1d6 237 226 22a 232
20d 253 242 246 24e 20a 26f 25a
25e 261 262 26a 241 28c 27a 23e
27e 27f 287 279 2a9 297 276 29b
29c 2a4 296 2c5 2b4 2b8 293 2c0
2b3 2e1 2d0 2d4 2b0 2dc 2cf 2fd
2ec 2f0 2cc 2f8 2eb 319 308 30c
2e8 314 307 335 324 328 304 330
323 351 340 344 320 34c 33f 36d
35c 360 33c 368 35b 389 378 37c
358 384 377 3a5 394 398 374 3a0
393 3c1 3b0 3b4 390 3bc 3af 3dd
3cc 3d0 3ac 3d8 3cb 3f9 3e8 3ec
3c8 3f4 3e7 415 404 408 3e4 410
403 431 420 424 400 42c 41f 44d
43c 440 41c 448 43b 469 458 45c
438 464 457 485 474 478 454 480
473 4a1 490 494 470 49c 48f 4bd
4ac 4b0 48c 4b8 4ab 4d9 4c8 4cc
4a8 4d4 4c7 4f5 4e4 4e8 4c4 4f0
4e3 511 500 504 4e0 50c 4ff 52d
51c 520 4fc 528 51b 549 538 53c
518 544 537 565 554 558 534 560
553 581 570 574 550 57c 56f 59d
58c 590 56c 598 58b 5b9 5a8 5ac
588 5b4 5a7 5e1 5c4 5a4 5c8 5c9
5d1 5d5 5d9 5dc 5c3 609 5ec 5c0
5f0 5f1 5f9 5fd 601 604 5eb 626
614 5e8 618 619 621 613 642 631
635 610 63d 630 65e 64d 651 62d
659 64c 67a 669 66d 649 675 668
696 685 689 665 691 684 6b2 6a1
6a5 681 6ad 6a0 6ce 6bd 6c1 69d
6c9 6bc 6ea 6d9 6dd 6b9 6e5 6d8
706 6f5 6f9 6d5 701 6f4 722 711
715 6f1 71d 710 73e 72d 731 70d
739 72c 75a 749 74d 729 755 748
776 765 769 745 771 764 792 781
785 761 78d 780 7ae 79d 7a1 77d
7a9 79c 7ca 7b9 7bd 799 7c5 7b8
7d1 7d5 7b5 7d9 7dd 7e1 7e4 7e9
7ea 1 7ec 7f1 7f5 7f9 7fc 801
805 809 80c 811 812 814 819 81c
820 821 826 82b 82e 833 834 839
83c 840 841 846 849 84e 84f 854
857 85c 85d 862 865 869 86d 871
872 874 879 87a 87c 87d 882 885
88a 88b 890 893 897 89b 89f 8a0
8a2 8a7 8a8 8aa 8ab 8b0 8b3 8b8
8b9 8be 8c1 8c5 8c9 8cd 8ce 8d0
8d5 8d6 8d8 8d9 8de 8e1 8e6 8e7
8ec 8ef 8f4 8f5 8fa 8fd 901 902
907 90a 90f 910 915 918 91d 91e
923 926 92b 92c 931 934 938 939
93e 941 946 947 94c 94f 954 955
95a 95b 960 962 966 969 96d 971
974 978 97c 97f 982 987 98a 98d
990 991 996 997 1 999 99e 9a2
9a6 9a9 9ae 9b3 9b6 9ba 9bb 9c0
9c1 9c6 9c8 9cc 9cf 9d3 9d7 9db
9df 9e3 9e7 9eb 9ef 9f3 9f7 9fb
9ff a03 a07 a0b a0f a13 a17 a1b
a1f a23 a27 a2b a2f a33 a37 a3b
a3f a43 a47 a4b a4f a53 a57 a5b
a5f a63 a67 a6b a6f a73 a77 a7b
a7f a83 a87 a8b a8f a93 a97 a9b
a9f aa3 aa7 aab aaf ab3 ab7 abb
abf ac3 ac7 acb acf ad3 ad7 adb
adf ae3 ae7 aeb aef af3 af7 afb
aff b03 b07 b0b b0f b1b b1f b23
b26 b2a b2e b30 b34 b38 b3c b3f
b43 b47 b49 b4a b4f 1 b53 b57
b5b b5e b62 b66 b6a b6e b71 b75
b79 b7c b7f b84 b87 b8a b8d b8e
b93 b94 1 b96 b9b b9f ba3 ba6
bab bb0 bb3 bb7 bb8 bbd bc0 bc5
bc6 bcb bce bd3 bd4 bd9 bdc be0
be1 be6 be9 bee bef bf4 bf7 bfb
bff c02 c05 c06 c08 c09 c0e c0f
c14 c16 c1a c1d c1f c23 c25 c31
c33 c35 c36 c3b c3f c41 c4d c4f
c53 c57 c5a c5e c61 c65 c68 c69
c6e c71 c75 c79 c7d c81 c85 c89
c8d c91 c95 c99 c9d ca1 ca5 ca9
cad cb1 cb5 cb9 cbd cc1 cc5 cd1
cd5 cd9 cdc ce0 ce4 ce6 cea cee
cf2 cf5 cf9 cfd cff d00 d05 1
d09 d0d d11 d14 d18 d1c d20 d24
d27 d2b d2f d32 d35 d3a d3d d40
d43 d44 d49 d4a 1 d4c d51 d55
d59 d5c d61 d66 d69 d6d d6e d73
d76 d7b d7c d81 d84 d89 d8a d8f
d92 d96 d97 d9c d9f da4 da5 daa
dad db1 db5 db8 dbb dbc dbe dbf
dc4 dc5 dca dcc dd0 dd3 dd5 dd9
ddb de7 de9 deb dec df1 df5 df7
e03 e05 e09 e0d e10 e14 e17 e1b
e1e e1f e24 e27 e2b e2f e33 e37
e3b e3e e42 e46 e49 e4c e51 e54
e57 e5a e5b e60 e61 1 e63 e68
e6c e70 e73 e78 e7d e80 e84 e85
e8a e8b e90 e92 e96 e99 e9d ea1
ea5 ea8 eac eae eb2 eb5 eb9 ebd
ec0 ec3 ec4 ec6 ec9 ece ecf ed4
ed8 edc ee0 ee4 ee8 eeb eef ef3
ef6 ef9 efe f01 f04 f07 f08 f0d
f0e 1 f10 f15 f19 f1d f20 f25
f2a f2d f31 f32 f37 f38 f3d f3f
f43 f46 f4a f4e f52 f55 f59 f5b
f5f f62 f66 f6a f6e f71 f72 f74
f78 f7c f7f f80 f82 f85 f89 f8c
f90 f93 f94 f99 f9d fa1 fa5 fa9
fad fb0 fb4 fb8 fbb fbe fc3 fc6
fc9 fcc fcd fd2 fd3 1 fd5 fda
fde fe2 fe5 fea fef ff2 ff6 ff7
ffc ffd 1002 1004 1008 100b 100f 1013
1017 101a 101e 1020 1024 1027 102b 102e
1032 1036 103a 103e 1042 1046 1052 1056
105a 105d 1061 1065 1067 106b 106f 1073
1076 107a 107e 1080 1081 1086 1 108a
108e 1092 1095 1099 109d 10a1 10a5 10a8
10ac 10b0 10b3 10b6 10bb 10be 10c1 10c4
10c5 10ca 10cb 1 10cd 10d2 10d6 10da
10dd 10e2 10e7 10ea 10ee 10ef 10f4 10f7
10fc 10fd 1102 1105 110a 110b 1110 1113
1117 1118 111d 1120 1125 1126 112b 112e
1132 1136 1139 113c 113d 113f 1140 1145
1146 114b 114d 1151 1154 1156 115a 115c
1168 116a 116c 116d 1172 1176 1178 1184
1186 118a 118e 1191 1192 1194 1197 119a
119b 11a0 11a4 11a8 11ac 11b0 11b4 11c0
11c4 11c8 11cb 11cf 11d3 11d5 11d9 11dd
11e1 11e4 11e8 11ec 11ee 11ef 11f4 1
11f8 11fc 1200 1203 1207 120b 120f 1213
1216 121a 121e 1221 1224 1229 122c 122f
1232 1233 1238 1239 1 123b 1240 1244
1248 124b 1250 1255 1258 125c 125d 1262
1265 126a 126b 1270 1273 1278 1279 127e
1281 1285 1286 128b 128e 1293 1294 1299
129c 12a0 12a4 12a7 12aa 12ab 12ad 12ae
12b3 12b4 12b9 12bb 12bf 12c2 12c4 12c8
12ca 12d6 12d8 12da 12db 12e0 12e4 12e6
12f2 12f4 12f8 12fc 12ff 1303 1308 1309
130b 130e 1311 1312 1317 131b 131f 1323
1327 132b 132e 1332 1336 1339 133c 1341
1344 1347 134a 134b 1350 1351 1 1353
1358 135c 1360 1363 1368 136d 1370 1374
1375 137a 137b 1380 1382 1386 1389 138d
1391 1395 1398 139c 139e 13a2 13a5 13a7
13ab 13ae 13b2 13b5 13b9 13bd 13c1 13c5
13c9 13cd 13d1 13d5 13d9 13dd 13e1 13e5
13e9 13ed 13f1 13f5 13f9 13fd 1401 1405
1409 140d 1411 1415 1419 141d 1421 1425
1431 1435 1439 143c 1440 1444 1446 144a
144e 1452 1455 1459 145d 145f 1460 1465
1 1469 146d 1471 1474 1478 147c 1480
1484 1487 148b 148f 1492 1495 149a 149d
14a0 14a3 14a4 14a9 14aa 1 14ac 14b1
14b5 14b9 14bc 14c1 14c6 14c9 14cd 14ce
14d3 14d6 14db 14dc 14e1 14e4 14e9 14ea
14ef 14f2 14f6 14f7 14fc 14ff 1504 1505
150a 150d 1511 1515 1518 151b 151c 151e
151f 1524 1525 152a 152c 1530 1533 1535
1539 153b 1547 1549 154b 154c 1551 1555
1557 1563 1565 1569 156d 1570 1571 1573
1576 1579 157a 157f 1583 1587 158b 158f
1593 1596 159a 159e 15a1 15a4 15a9 15ac
15af 15b2 15b3 15b8 15b9 1 15bb 15c0
15c4 15c8 15cb 15d0 15d5 15d8 15dc 15dd
15e2 15e3 15e8 15ea 15ee 15f1 15f5 15f9
15fd 1600 1604 1606 160a 160d 1611 1615
1618 1619 161b 161e 1621 1622 1627 162b
162f 1632 1636 163a 163d 1640 1645 1648
164b 164e 164f 1654 1655 1 1657 165c
1660 1664 1667 166c 1671 1674 1678 1679
167e 1681 1686 1687 168c 168f 1694 1695
169a 169d 16a1 16a5 16a9 16ad 16b0 16b1
16b3 16b8 16b9 16bb 16bc 16c1 16c2 16c7
16c9 16cd 16d0 16d4 16d8 16db 16df 16e3
16e6 16e9 16ee 16f1 16f4 16f7 16f8 16fd
16fe 1 1700 1705 1709 170d 1710 1715
171a 171d 1721 1722 1727 1728 172d 172f
1733 1736 173a 173e 1742 1745 1749 174d
1750 1754 1755 1757 175b 175f 1761 1765
1769 176c 176d 176f 1773 1776 177a 177d
177e 1780 1781 1786 178a 178d 1791 1795
1799 179c 179d 179f 17a3 17a6 17aa 17ad
17ae 17b0 17b1 17b6 17ba 17be 17c2 17c6
17ca 17cd 17d1 17d5 17d8 17db 17e0 17e3
17e6 17e9 17ea 17ef 17f0 1 17f2 17f7
17fb 17ff 1802 1807 180c 180f 1813 1814
1819 181a 181f 1821 1825 1828 182c 1830
1834 1837 183b 183f 1841 1845 1849 184c
184d 184f 1853 1856 185a 185d 185e 1860
1861 1866 186a 186d 1871 1873 1877 187b
187e 1882 1886 188a 188e 1892 1896 189a
189e 18a2 18a6 18aa 18ad 18ae 18b0 18b4
18b8 18bb 18bc 18be 18c2 18c6 18c9 18ca
18cc 18cd 18cf 18d3 18d5 18d9 18dd 18e1
18e4 18e8 18ec 18ef 18f2 18f7 18fa 18fd
1900 1901 1906 1907 1 1909 190e 1912
1916 1919 191e 1923 1926 192a 192b 1930
1933 1938 1939 193e 1941 1946 1947 194c
194f 1953 1957 195b 195f 1962 1963 1965
196a 196b 196d 196e 1973 1974 1979 197b
197f 1982 1986 198a 198d 1991 1995 1998
199b 19a0 19a3 19a6 19a9 19aa 19af 19b0
1 19b2 19b7 19bb 19bf 19c2 19c7 19cc
19cf 19d3 19d4 19d9 19da 19df 19e1 19e5
19e8 19ec 19f0 19f4 19f7 19fb 19ff 1a02
1a06 1a07 1a09 1a0d 1a0f 1a13 1a17 1a1a
1a1c 1a20 1a24 1a27 1a28 1a2a 1a2d 1a30
1a31 1a36 1a3a 1a3e 1a42 1a46 1a4a 1a4d
1a51 1a55 1a58 1a5b 1a60 1a63 1a66 1a69
1a6a 1a6f 1a70 1 1a72 1a77 1a7b 1a7f
1a82 1a87 1a8c 1a8f 1a93 1a94 1a99 1a9a
1a9f 1aa1 1aa5 1aa8 1aac 1ab0 1ab4 1ab7
1abb 1abd 1ac1 1ac4 1ac8 1acb 1acf 1ad3
1ad7 1adb 1adf 1ae3 1aef 1af3 1af7 1afa
1afe 1b02 1b04 1b08 1b0c 1b10 1b13 1b17
1b1b 1b1d 1b1e 1b23 1 1b27 1b2b 1b2f
1b32 1b36 1b3a 1b3e 1b42 1b45 1b49 1b4d
1b50 1b53 1b58 1b5b 1b5e 1b61 1b62 1b67
1b68 1 1b6a 1b6f 1b73 1b77 1b7a 1b7f
1b84 1b87 1b8b 1b8c 1b91 1b94 1b99 1b9a
1b9f 1ba2 1ba7 1ba8 1bad 1bb0 1bb4 1bb5
1bba 1bbd 1bc2 1bc3 1bc8 1bcb 1bcf 1bd3
1bd6 1bd9 1bda 1bdc 1bdd 1be2 1be3 1be8
1bea 1bee 1bf1 1bf3 1bf7 1bf9 1c05 1c07
1c09 1c0a 1c0f 1c13 1c15 1c21 1c23 1c27
1c2b 1c2e 1c2f 1c31 1c34 1c37 1c38 1c3d
1c41 1c45 1c49 1c4d 1c51 1c5d 1c61 1c65
1c68 1c6c 1c70 1c72 1c76 1c7a 1c7e 1c81
1c85 1c89 1c8b 1c8c 1c91 1 1c95 1c99
1c9d 1ca0 1ca4 1ca8 1cac 1cb0 1cb3 1cb7
1cbb 1cbe 1cc1 1cc6 1cc9 1ccc 1ccf 1cd0
1cd5 1cd6 1 1cd8 1cdd 1ce1 1ce5 1ce8
1ced 1cf2 1cf5 1cf9 1cfa 1cff 1d02 1d07
1d08 1d0d 1d10 1d15 1d16 1d1b 1d1e 1d22
1d23 1d28 1d2b 1d30 1d31 1d36 1d39 1d3d
1d41 1d44 1d47 1d48 1d4a 1d4b 1d50 1d51
1d56 1d58 1d5c 1d5f 1d61 1d65 1d67 1d73
1d75 1d77 1d78 1d7d 1d81 1d83 1d8f 1d91
1d95 1d99 1d9c 1da0 1da5 1da6 1da8 1dab
1dae 1daf 1db4 1db8 1dbc 1dc0 1dc4 1dc8
1dcb 1dcf 1dd3 1dd6 1dd9 1dde 1de1 1de4
1de7 1de8 1ded 1dee 1 1df0 1df5 1df9
1dfd 1e00 1e05 1e0a 1e0d 1e11 1e12 1e17
1e18 1e1d 1e1f 1e23 1e26 1e2a 1e2e 1e32
1e35 1e39 1e3b 1e3f 1e42 1e44 1e48 1e4b
1e4f 1e53 1e57 1e5b 1e5f 1e63 1e67 1e6b
1e6f 1e73 1e77 1e7b 1e7f 1e8b 1e8f 1e93
1e96 1e9a 1e9e 1ea0 1ea4 1ea8 1eac 1eaf
1eb3 1eb7 1eb9 1eba 1ebf 1 1ec3 1ec7
1ecb 1ece 1ed2 1ed6 1eda 1ede 1ee1 1ee5
1ee9 1eec 1eef 1ef4 1ef7 1efa 1efd 1efe
1f03 1f04 1 1f06 1f0b 1f0f 1f13 1f16
1f1b 1f20 1f23 1f27 1f28 1f2d 1f30 1f35
1f36 1f3b 1f3e 1f43 1f44 1f49 1f4c 1f50
1f51 1f56 1f59 1f5e 1f5f 1f64 1f67 1f6b
1f6f 1f72 1f75 1f76 1f78 1f79 1f7e 1f7f
1f84 1f86 1f8a 1f8d 1f8f 1f93 1f95 1fa1
1fa3 1fa5 1fa6 1fab 1faf 1fb1 1fbd 1fbf
1fc3 1fc7 1fca 1fcd 1fce 1fd0 1fd3 1fd8
1fd9 1fde 1fe2 1fe6 1fea 1fee 1ff2 1ff5
1ff9 1ffd 2000 2003 2008 200b 200e 2011
2012 2017 2018 1 201a 201f 2023 2027
202a 202f 2034 2037 203b 203c 2041 2042
2047 2049 204d 2050 2054 2058 205c 205f
2063 2065 2069 206c 2070 2074 2078 207b
207c 207e 2082 2086 2089 208a 208c 208f
2093 2096 209a 209d 209e 20a3 20a7 20ab
20af 20b3 20b7 20ba 20be 20c2 20c5 20c8
20cd 20d0 20d3 20d6 20d7 20dc 20dd 1
20df 20e4 20e8 20ec 20ef 20f4 20f9 20fc
2100 2101 2106 2107 210c 210e 2112 2115
2119 211d 2121 2124 2128 212a 212e 2131
2135 2138 213c 2140 2144 2148 214c 2150
2154 2158 215c 2160 2164 2168 216c 2178
217c 2180 2183 2187 218b 218d 2191 2195
2199 219c 21a0 21a4 21a6 21a7 21ac 1
21b0 21b4 21b8 21bb 21bf 21c3 21c7 21cb
21ce 21d2 21d6 21d9 21dc 21e1 21e4 21e7
21ea 21eb 21f0 21f1 1 21f3 21f8 21fc
2200 2203 2208 220d 2210 2214 2215 221a
221d 2222 2223 2228 222b 2230 2231 2236
2239 223d 223e 2243 2246 224b 224c 2251
2254 2258 225c 225f 2262 2263 2265 2266
226b 226c 2271 2273 2277 227a 227c 2280
2282 228e 2290 2292 2293 2298 229c 229e
22aa 22ac 22b0 22b4 22b7 22b8 22ba 22bd
22c0 22c1 22c6 22ca 22ce 22d2 22d6 22da
22dd 22e1 22e5 22e8 22eb 22f0 22f3 22f6
22f9 22fa 22ff 2300 1 2302 2307 230b
230f 2312 2317 231c 231f 2323 2324 2329
232a 232f 2331 2335 2338 233c 2340 2344
2347 234b 234d 2351 2354 2358 235c 235f
2360 2362 2365 2368 2369 236e 2371 2375
2379 237c 237d 237f 2382 2385 2386 238b
1 238e 2393 2397 239b 239f 23a3 23a6
23a7 23a9 23ac 23af 23b0 23b5 23b8 23bb
23bf 23c3 23c6 23c7 23c9 23ca 23cf 23d0
23d2 23d6 23d8 23dc 23df 23e3 23e7 23eb
23ee 23ef 23f1 23f5 23f9 23fd 2400 2401
2403 2407 240a 240e 2411 2412 2414 2415
241a 241e 2422 2426 242a 242e 2431 2432
2434 2438 243b 243f 2442 2443 2445 2446
244b 244f 2453 2456 2457 2459 245d 2460
2464 2467 2468 246d 2471 2475 2478 2479
247b 247f 2482 2486 2489 248a 1 248f
2494 2498 2499 249d 24a1 24a5 24a9 24ad
24b1 24b5 24b9 24bd 24c1 24c5 24c9 24cd
24d9 24dd 24e1 24e4 24e8 24ec 24ee 24f2
24f6 24fa 24fd 2501 2505 2507 2508 250d
1 2511 2515 2519 251c 2520 2524 2528
252c 252f 2533 2537 253a 253d 2542 2545
2548 254b 254c 2551 2552 1 2554 2559
255d 2561 2564 2569 256e 2571 2575 2576
257b 257e 2583 2584 2589 258c 2591 2592
2597 259a 259e 259f 25a4 25a7 25ac 25ad
25b2 25b5 25b9 25bd 25c0 25c3 25c4 25c6
25c7 25cc 25cd 25d2 25d4 25d8 25db 25dd
25e1 25e3 25ef 25f1 25f3 25f4 25f9 25fd
25ff 260b 260d 2611 2614 2615 261a 261d
2621 2625 2629 262b 262f 2632 2636 263a
263d 263e 2640 2643 2646 2647 264c 2650
2654 2657 2658 265a 265d 2660 2661 2666
2669 266d 2670 2671 2676 2679 1 267c
2681 2685 2689 268d 2691 2695 2699 269d
26a1 26a5 26a9 26ad 26b1 26bd 26c1 26c5
26c8 26cc 26d0 26d2 26d6 26da 26de 26e1
26e5 26e9 26eb 26ec 26f1 1 26f5 26f9
26fd 2700 2704 2708 270c 2710 2713 2717
271b 271e 2721 2726 2729 272c 272f 2730
2735 2736 1 2738 273d 2741 2745 2748
274d 2752 2755 2759 275a 275f 2762 2767
2768 276d 2770 2775 2776 277b 277e 2782
2783 2788 278b 2790 2791 2796 2799 279d
27a1 27a4 27a7 27a8 27aa 27ab 27b0 27b1
27b6 27b8 27bc 27bf 27c1 27c5 27c7 27d3
27d5 27d7 27d8 27dd 27e1 27e3 27ef 27f1
27f5 27f9 27fd 2800 2801 2803 2806 280a
280e 2811 2812 2814 2815 281a 281d 2821
2825 2828 2829 282b 282c 2831 2835 2839
283c 2840 2842 2846 2849 284d 2851 2855
2859 285d 285e 2860 2863 2864 2866 2869
286d 2871 2875 2876 2878 287b 287c 287e
287f 2884 2887 288a 288d 288e 2893 2894
2896 289a 289e 28a2 28a6 28a9 28aa 28ac
28af 28b3 28b7 28ba 28bb 28bd 28be 28c3
28c7 28cb 28cf 28d2 28d3 28d5 28d9 28dc
28e0 28e3 28e4 28e6 28e7 28ec 28f0 28f4
28f8 28fb 28fc 28fe 2901 2905 2909 290c
290d 290f 2910 2915 2918 291c 2920 2923
2924 2926 2927 292c 2930 2932 2936 293a
293e 2941 2942 2944 2948 294a 294e 2952
2955 2959 295d 2961 2965 2969 296d 2971
2975 2979 297c 297d 297f 2983 2987 298b
298f 2993 2997 2998 299a 299d 299e 29a0
29a3 29a7 29ab 29af 29b0 29b2 29b5 29b6
29b8 29b9 29be 29c1 29c4 29c7 29c8 29cd
29ce 29d0 29d4 29d8 29dc 29e0 29e3 29e7
29eb 29ee 29ef 29f1 29f5 29f9 29fc 29fd
29ff 2a03 2a07 2a0b 2a0f 2a13 2a17 2a1b
2a1f 2a22 2a23 2a25 2a29 2a2d 2a30 2a31
2a33 2a36 2a37 2a39 2a3d 2a41 2a45 2a49
2a4d 2a51 2a54 2a55 2a57 2a5b 2a5d 2a61
2a64 2a66 2a6a 2a6e 2a71 2a72 2a74 2a78
2a7b 2a7f 2a82 2a83 2a85 2a86 2a8b 2a8f
2a93 2a96 2a9a 2a9e 2a9f 2aa1 2aa4 2aa7
2aa8 2aad 2ab1 2ab5 2ab9 2abc 2abd 2abf
2ac2 2ac6 2aca 2acd 2ace 2ad0 2ad1 2ad6
2ada 2ade 2ae1 2ae5 2ae9 2aed 2af0 2af1
2af3 2af6 2afa 2afe 2b01 2b02 2b04 2b07
2b0b 2b0f 2b12 2b13 2b15 2b16 2b1b 2b1e
2b1f 2b24 2b28 2b2c 2b30 2b33 2b34 2b36
2b39 2b3d 2b41 2b44 2b45 2b47 2b48 2b4d
2b50 2b53 2b57 2b5b 2b5e 2b5f 2b61 2b62
2b67 2b6b 2b6f 2b73 2b77 2b7b 2b7f 2b83
2b87 2b8b 2b8f 2b93 2b97 2b9b 2b9f 2ba3
2ba7 2bab 2baf 2bbb 2bbf 2bc4 2bc8 2bcb
2bcc 2bd1 2bd5 2bd9 2bdc 2bdf 2be3 2be5
2be9 2bed 2bf0 2bf3 2bf7 2bf9 2bfd 2c01
2c04 2c06 2c0a 2c0e 2c12 2c15 2c19 2c1d
2c1f 2c20 2c25 1 2c29 2c2d 2c31 2c34
2c38 2c3c 2c40 2c44 2c47 2c4b 2c4f 2c52
2c55 2c5a 2c5d 2c60 2c63 2c64 2c69 2c6a
1 2c6c 2c71 2c75 2c79 2c7c 2c81 2c86
2c89 2c8d 2c8e 2c93 2c96 2c9b 2c9c 2ca1
2ca4 2ca9 2caa 2caf 2cb2 2cb6 2cb7 2cbc
2cbf 2cc4 2cc5 2cca 2ccd 2cd1 2cd5 2cd8
2cdb 2cdc 2cde 2cdf 2ce4 2ce5 2cea 2cec
2cf0 2cf3 2cf5 2cf9 2cfb 2d07 2d09 2d0b
2d0c 2d11 2d15 2d17 2d23 2d25 2d29 2d2d
2d31 2d34 2d38 2d3c 2d3f 2d40 2d42 2d46
2d4a 2d4d 2d4e 2d50 2d54 2d56 2d5a 2d5e
2d62 2d66 2d6a 2d6e 2d72 2d76 2d7a 2d7e
2d82 2d86 2d8a 2d8e 2d92 2d96 2da2 2da6
2dab 2daf 2db2 2db3 2db8 2dbc 2dc0 2dc3
2dc6 2dca 2dcc 2dd0 2dd4 2dd7 2dda 2dde
2de0 2de4 2de8 2deb 2ded 2df1 2df5 2df9
2dfc 2e00 2e04 2e06 2e07 2e0c 1 2e10
2e14 2e18 2e1b 2e1f 2e23 2e27 2e2b 2e2e
2e32 2e36 2e39 2e3c 2e41 2e44 2e47 2e4a
2e4b 2e50 2e51 1 2e53 2e58 2e5c 2e60
2e63 2e68 2e6d 2e70 2e74 2e75 2e7a 2e7d
2e82 2e83 2e88 2e8b 2e90 2e91 2e96 2e99
2e9d 2e9e 2ea3 2ea6 2eab 2eac 2eb1 2eb4
2eb8 2ebc 2ebf 2ec2 2ec3 2ec5 2ec6 2ecb
2ecc 2ed1 2ed3 2ed7 2eda 2edc 2ee0 2ee2
2eee 2ef0 2ef2 2ef3 2ef8 2efc 2efe 2f0a
2f0c 2f0e 2f12 2f16 2f19 2f1b 2f1f 2f23
2f26 2f27 2f29 2f2c 2f30 2f34 2f37 2f38
2f3a 2f3d 2f41 2f45 2f48 2f49 2f4b 2f4c
2f51 2f54 2f55 2f5a 2f5e 2f62 2f66 2f69
2f6a 2f6c 2f6f 2f73 2f77 2f7a 2f7b 2f7d
2f7e 2f83 2f87 2f8b 2f8f 2f93 2f97 2f9b
2f9c 2f9e 2fa1 2fa2 2fa4 2fa7 2fab 2faf
2fb3 2fb4 2fb6 2fb9 2fba 2fbc 2fbd 2fc2
2fc5 2fc8 2fcb 2fcc 2fd1 2fd4 2fd7 2fda
2fdb 2fe0 2fe1 2fe3 2fe7 2feb 2fef 2ff3
2ff7 2ffb 2fff 3003 3007 300b 300f 3013
3017 301b 301f 302b 302f 3034 3038 303b
303c 3041 3045 3049 304c 304f 3053 3055
3059 305d 3060 3063 3067 3069 306d 3071
3074 3076 307a 307e 3082 3085 3089 308d
308f 3090 3095 1 3099 309d 30a1 30a4
30a8 30ac 30b0 30b4 30b7 30bb 30bf 30c2
30c5 30ca 30cd 30d0 30d3 30d4 30d9 30da
1 30dc 30e1 30e5 30e9 30ec 30f1 30f6
30f9 30fd 30fe 3103 3106 310b 310c 3111
3114 3119 311a 311f 3122 3126 3127 312c
312f 3134 3135 313a 313d 3141 3145 3148
314b 314c 314e 314f 3154 3155 315a 315c
3160 3163 3165 3169 316b 3177 3179 317b
317c 3181 3185 3187 3193 3195 3197 319b
319f 31a3 31a6 31a7 31a9 31ac 31b0 31b4
31b7 31b8 31ba 31bb 31c0 31c4 31c8 31cb
31cf 31d3 31d7 31db 31df 31e3 31e7 31eb
31ef 31f3 31f7 31fb 31ff 3203 3207 320b
320f 321b 321f 3224 3228 322b 322c 3231
3235 3239 323c 323f 3243 3245 3249 324d
3250 3253 3257 3259 325d 3261 3264 3266
326a 326e 3272 3275 3279 327d 327f 3280
3285 1 3289 328d 3291 3294 3298 329c
32a0 32a4 32a7 32ab 32af 32b2 32b5 32ba
32bd 32c0 32c3 32c4 32c9 32ca 1 32cc
32d1 32d5 32d9 32dc 32e1 32e6 32e9 32ed
32ee 32f3 32f6 32fb 32fc 3301 3304 3309
330a 330f 3312 3316 3317 331c 331f 3324
3325 332a 332d 3331 3335 3338 333b 333c
333e 333f 3344 3345 334a 334c 3350 3353
3355 3359 335b 3367 3369 336b 336c 3371
3375 3377 3383 3385 3387 338b 338f 3392
3394 3398 339c 339f 33a1 33a5 33a9 33ad
33b0 33b1 33b3 33b6 33ba 33be 33c1 33c2
33c4 33c5 33ca 33ce 33d2 33d5 33d9 33dd
33e1 33e5 33e9 33ed 33f1 33f5 33f9 33fd
3401 3405 3409 340d 3411 3415 3419 3425
3429 342e 3432 3435 3436 343b 343f 3443
3446 3449 344d 344f 3453 3457 345a 345d
3461 3463 3467 346b 346e 3470 3474 3478
347c 347f 3483 3487 3489 348a 348f 1
3493 3497 349b 349e 34a2 34a6 34aa 34ae
34b1 34b5 34b9 34bc 34bf 34c4 34c7 34ca
34cd 34ce 34d3 34d4 1 34d6 34db 34df
34e3 34e6 34eb 34f0 34f3 34f7 34f8 34fd
3500 3505 3506 350b 350e 3513 3514 3519
351c 3520 3521 3526 3529 352e 352f 3534
3537 353b 353f 3542 3545 3546 3548 3549
354e 354f 3554 3556 355a 355d 355f 3563
3565 3571 3573 3575 3576 357b 357f 3581
358d 358f 3591 3595 3599 359c 35a0 35a3
35a4 35a9 35ac 35b0 35b1 35b5 35b9 35bd
35c1 35c5 35c9 35cd 35d1 35d5 35e1 35e5
35e9 35ec 35f0 35f4 35f6 35fa 35fe 3602
3605 3609 360d 360f 3610 3615 1 3619
361d 3621 3624 3628 362c 3630 3634 3637
363b 363f 3642 3645 364a 364d 3650 3653
3654 3659 365a 1 365c 3661 3665 3669
366c 3671 3676 3679 367d 367e 3683 3686
368b 368c 3691 3694 3699 369a 369f 36a2
36a6 36a7 36ac 36af 36b4 36b5 36ba 36bd
36c1 36c5 36c8 36cb 36cc 36ce 36cf 36d4
36d5 36da 36dc 36e0 36e3 36e5 36e9 36eb
36f7 36f9 36fb 36fc 3701 3705 3707 3713
3715 3719 371c 371d 3722 3725 3729 372d
3731 3735 3739 3745 3749 374d 3750 3754
3758 375a 375e 3762 3766 3769 376d 3771
3773 3774 3779 1 377d 3781 3785 3788
378c 3790 3794 3798 379b 379f 37a3 37a6
37a9 37ae 37b1 37b4 37b7 37b8 37bd 37be
1 37c0 37c5 37c9 37cd 37d0 37d5 37da
37dd 37e1 37e2 37e7 37ea 37ef 37f0 37f5
37f8 37fd 37fe 3803 3806 380a 380b 3810
3813 3818 3819 381e 3821 3825 3829 382c
382f 3830 3832 3833 3838 3839 383e 3840
3844 3847 3849 384d 384f 385b 385d 385f
3860 3865 3869 386b 3877 3879 387d 3881
3884 3888 388c 388f 3890 3892 3895 3898
3899 389e 38a2 38a6 38aa 38ac 38b0 38b3
38b7 38b9 38bd 38c1 38c4 38c5 38c7 38ca
38cd 38ce 38d3 38d7 38db 38df 38e2 38e6
38ea 38ed 38ee 38f0 38f4 38f8 38fb 38fc
38fe 3901 3905 3909 390d 3911 3915 3919
391d 3921 3925 3929 392d 3939 393d 3941
3944 3948 394c 394e 3952 3956 395a 395d
3961 3965 3967 3968 396d 1 3971 3975
3979 397c 3980 3984 3988 398c 398f 3993
3997 399a 399d 39a2 39a5 39a8 39ab 39ac
39b1 39b2 1 39b4 39b9 39bd 39c1 39c4
39c9 39ce 39d1 39d5 39d6 39db 39de 39e3
39e4 39e9 39ec 39f1 39f2 39f7 39fa 39fe
39ff 3a04 3a07 3a0c 3a0d 3a12 3a15 3a19
3a1d 3a20 3a23 3a24 3a26 3a27 3a2c 3a2d
3a32 3a34 3a38 3a3b 3a3d 3a41 3a43 3a4f
3a51 3a53 3a54 3a59 3a5d 3a5f 3a6b 3a6d
3a6f 3a73 3a77 3a7b 3a7f 3a83 3a87 3a8b
3a8f 3a93 3a97 3a9b 3aa7 3aab 3aaf 3ab2
3ab6 3aba 3abc 3ac0 3ac4 3ac8 3acb 3acf
3ad3 3ad5 3ad6 3adb 1 3adf 3ae3 3ae7
3aea 3aee 3af2 3af6 3afa 3afd 3b01 3b05
3b08 3b0b 3b10 3b13 3b16 3b19 3b1a 3b1f
3b20 1 3b22 3b27 3b2b 3b2f 3b32 3b37
3b3c 3b3f 3b43 3b44 3b49 3b4c 3b51 3b52
3b57 3b5a 3b5f 3b60 3b65 3b68 3b6c 3b6d
3b72 3b75 3b7a 3b7b 3b80 3b83 3b87 3b8b
3b8e 3b91 3b92 3b94 3b95 3b9a 3b9b 3ba0
3ba2 3ba6 3ba9 3bab 3baf 3bb1 3bbd 3bbf
3bc1 3bc2 3bc7 3bcb 3bcd 3bd9 3bdb 3bdd
3be1 3be5 3be8 3bea 3bee 3bf1 3bf5 3bf8
3bf9 3bfe 3c01 3c05 3c09 3c0d 3c11 3c14
3c15 3c17 3c1b 3c1d 3c21 3c25 3c28 3c2b
3c2c 3c2e 3c31 3c36 3c37 3c3c 3c40 3c44
3c48 3c4c 3c4f 3c50 3c52 3c56 3c58 3c5c
3c60 3c64 3c68 3c6b 3c6c 3c6e 3c72 3c74
3c78 3c7c 3c7f 3c81 3c85 3c89 3c8c 3c90
3c93 3c97 3c9b 3c9f 3ca3 3ca7 3cab 3caf
3cb3 3cb7 3cba 3cbe 3cc2 3cc5 3cc6 3cc8
3cc9 3ccb 3ccf 3cd3 3cd7 3cda 3cdb 3cdd
3ce0 3ce3 3ce4 3ce9 3ced 3cf1 3cf5 3cf9
3cfd 3d00 3d04 3d08 3d0b 3d0e 3d13 3d16
3d19 3d1c 3d1d 3d22 3d23 1 3d25 3d2a
3d2e 3d32 3d35 3d3a 3d3f 3d42 3d46 3d47
3d4c 3d4d 3d52 3d54 3d58 3d5b 3d5f 3d63
3d67 3d6a 3d6b 3d6d 3d71 3d73 3d77 3d7a
3d7c 3d80 3d84 3d87 3d8b 3d8f 3d93 3d95
3d99 3d9d 3da1 3da5 3da9 3daa 3dac 3daf
3db0 3db2 3db5 3db9 3dbd 3dc1 3dc2 3dc4
3dc7 3dc8 3dca 3dcb 3dd0 3dd3 3dd6 3dd9
3dda 3ddf 3de2 3de5 3de8 3de9 3dee 3def
3df1 3df5 3df7 3dfb 3dff 3e02 3e06 3e0a
3e0e 3e12 3e16 3e1a 3e1e 3e22 3e26 3e2a
3e2e 3e32 3e36 3e3a 3e3e 3e42 3e46 3e4a
3e4e 3e52 3e56 3e5a 3e5e 3e62 3e66 3e6a
3e6e 3e71 3e72 3e74 3e78 3e7c 3e7f 3e80
3e82 3e83 3e85 3e89 3e8d 3e91 3e95 3e99
3e9d 3ea0 3ea4 3ea8 3eab 3eae 3eb3 3eb6
3eb9 3ebc 3ebd 3ec2 3ec3 1 3ec5 3eca
3ece 3ed2 3ed5 3eda 3edf 3ee2 3ee6 3ee7
3eec 3eed 3ef2 3ef4 3ef8 3efb 3eff 3f03
3f07 3f0a 3f0b 3f0d 3f11 3f15 3f17 3f1b
3f1f 3f22 3f23 3f25 3f29 3f2c 3f30 3f33
3f34 3f36 3f37 3f3c 3f40 3f44 3f48 3f4c
3f50 3f54 3f58 3f5c 3f60 3f64 3f68 3f74
3f78 3f7d 3f81 3f84 3f85 3f8a 3f8e 3f92
3f95 3f98 3f9c 3f9e 3fa2 3fa6 3fa9 3fac
3fb0 3fb2 3fb6 3fba 3fbd 3fbf 3fc3 3fc7
3fcb 3fce 3fd2 3fd6 3fd8 3fd9 3fde 1
3fe2 3fe6 3fea 3fed 3ff1 3ff5 3ff9 3ffd
4000 4004 4008 400b 400e 4013 4016 4019
401c 401d 4022 4023 1 4025 402a 402e
4032 4035 403a 403f 4042 4046 4047 404c
404f 4054 4055 405a 405d 4062 4063 4068
406b 406f 4070 4075 4078 407d 407e 4083
4086 408a 408e 4091 4094 4095 4097 4098
409d 409e 40a3 40a5 40a9 40ac 40ae 40b2
40b4 40c0 40c2 40c4 40c5 40ca 40ce 40d0
40dc 40de 40e2 40e6 40ea 40ee 40f2 40f6
40fa 40fe 4102 4106 410a 4116 411a 411f
4123 4126 4127 412c 4130 4134 4137 413a
413e 4140 4144 4148 414b 414e 4152 4154
4158 415c 415f 4161 4165 4169 416d 4170
4174 4178 417a 417b 4180 1 4184 4188
418c 418f 4193 4197 419b 419f 41a2 41a6
41aa 41ad 41b0 41b5 41b8 41bb 41be 41bf
41c4 41c5 1 41c7 41cc 41d0 41d4 41d7
41dc 41e1 41e4 41e8 41e9 41ee 41f1 41f6
41f7 41fc 41ff 4204 4205 420a 420d 4211
4212 4217 421a 421f 4220 4225 4228 422c
4230 4233 4236 4237 4239 423a 423f 4240
4245 4247 424b 424e 4250 4254 4256 4262
4264 4266 4267 426c 4270 4272 427e 4280
4284 4286 428a 428e 4292 4295 4296 4298
429c 429f 42a3 42a6 42a7 42a9 42aa 42af
42b3 42b7 42ba 42bb 42bd 42c0 42c3 42c4
42c9 42cd 42d0 42d4 42d6 42da 42de 42e1
42e2 42e4 42e7 42ea 42eb 42f0 42f3 42f7
42fb 42fe 42ff 4301 4304 4307 4308 430d
1 4310 4315 4319 431d 4321 4325 4329
432c 4330 4334 4337 433a 433f 4342 4345
4348 4349 434e 434f 1 4351 4356 435a
435e 4361 4366 436b 436e 4372 4373 4378
4379 437e 4380 4384 4387 438b 438f 4393
4396 439a 439c 43a0 43a3 43a7 43ab 43af
43b2 43b3 43b5 43b9 43bb 43bf 43c3 43c6
43ca 43cd 43ce 43d3 43d6 43da 43de 43e2
43e6 43ea 43f6 43fa 43fe 4401 4405 4409
440b 440f 4413 4417 441a 441e 4422 4424
4425 442a 1 442e 4432 4436 4439 443d
4441 4445 4449 444c 4450 4454 4457 445a
445f 4462 4465 4468 4469 446e 446f 1
4471 4476 447a 447e 4481 4486 448b 448e
4492 4493 4498 449b 44a0 44a1 44a6 44a9
44ae 44af 44b4 44b7 44bb 44bc 44c1 44c4
44c9 44ca 44cf 44d2 44d6 44da 44dd 44e0
44e1 44e3 44e4 44e9 44ea 44ef 44f1 44f5
44f8 44fa 44fe 4500 450c 450e 4510 4511
4516 451a 451c 4528 452a 452e 4532 4535
4539 453c 4540 4543 4544 4549 454c 4550
4554 4557 4558 455a 455e 4561 4565 4568
4569 456b 456c 4571 1 4574 4579 457d
4581 4585 4589 458d 4590 4594 4598 459b
459e 45a3 45a6 45a9 45ac 45ad 45b2 45b3
1 45b5 45ba 45be 45c2 45c5 45ca 45cf
45d2 45d6 45d7 45dc 45dd 45e2 45e4 45e8
45eb 45ef 45f3 45f7 45fa 45fe 4600 4604
4607 4609 460d 4610 4614 4618 461b 461c
461e 4622 4625 4629 462c 462d 4632 4636
463a 463d 463e 4640 4644 4647 464b 464e
464f 1 4654 4659 465d 4661 4664 4665
4667 466a 466d 466e 4673 4676 467a 467d
467e 4683 4686 1 4689 468e 4692 4696
469a 469e 46a2 46a6 46aa 46ae 46b2 46b5
46b6 46b8 46bc 46be 46c2 46c5 46c9 46cd
46d1 46d5 46d8 46d9 46db 46de 46e2 46e6
46e9 46ea 46ec 46ed 46f2 46f5 46f8 46fb
46fc 4701 4704 4707 470a 470b 4710 4711
4713 4717 471b 471f 4723 4727 472b 472f
4733 4737 473b 473e 473f 4741 4745 4749
474d 4751 4754 4758 475c 475f 4760 4762
4766 476a 476d 476e 4770 4774 4778 477c
4780 4784 4788 478b 478e 4791 4792 4794
4798 479c 47a0 47a4 47a8 47ac 47b0 47b4
47b8 47bc 47c0 47c4 47d0 47d4 47d8 47db
47df 47e3 47e5 47e9 47ed 47f1 47f4 47f8
47fc 47fe 47ff 4804 1 4808 480c 4810
4813 4817 481b 481f 4823 4826 482a 482e
4831 4834 4839 483c 483f 4842 4843 4848
4849 1 484b 4850 4854 4858 485b 4860
4865 4868 486c 486d 4872 4875 487a 487b
4880 4883 4888 4889 488e 4891 4895 4896
489b 489e 48a3 48a4 48a9 48ac 48b0 48b4
48b7 48ba 48bb 48bd 48be 48c3 48c4 48c9
48cb 48cf 48d2 48d4 48d8 48da 48e6 48e8
48ea 48eb 48f0 48f4 48f6 4902 4904 4908
490c 4910 4914 4918 491b 491c 491e 4922
4924 4928 492c 492f 4930 4932 4935 4938
4939 493e 4941 4945 4948 4949 494e 4951
1 4954 4959 495d 4961 4965 4969 496d
4971 4975 4979 497d 4980 4981 4983 4987
4989 498d 4990 4994 4997 4998 499d 49a0
49a4 49a8 49ac 49b0 49b3 49b4 49b6 49ba
49bc 49c0 49c4 49c7 49ca 49cb 49cd 49d0
49d5 49d6 49db 49df 49e3 49e7 49eb 49ee
49ef 49f1 49f5 49f7 49fb 49ff 4a03 4a07
4a0a 4a0b 4a0d 4a11 4a13 4a17 4a1b 4a1e
4a20 4a24 4a28 4a2b 4a2f 4a32 4a33 4a38
4a3b 4a3f 4a43 4a47 4a4b 4a4f 4a53 4a57
4a5b 4a5f 4a63 4a6f 4a73 4a77 4a7a 4a7e
4a82 4a84 4a88 4a8c 4a90 4a93 4a97 4a9b
4a9d 4a9e 4aa3 1 4aa7 4aab 4aaf 4ab2
4ab6 4aba 4abe 4ac2 4ac5 4ac9 4acd 4ad0
4ad3 4ad8 4adb 4ade 4ae1 4ae2 4ae7 4ae8
1 4aea 4aef 4af3 4af7 4afa 4aff 4b04
4b07 4b0b 4b0c 4b11 4b14 4b19 4b1a 4b1f
4b22 4b27 4b28 4b2d 4b30 4b34 4b35 4b3a
4b3d 4b42 4b43 4b48 4b4b 4b4f 4b53 4b56
4b59 4b5a 4b5c 4b5d 4b62 4b63 4b68 4b6a
4b6e 4b71 4b73 4b77 4b79 4b85 4b87 4b89
4b8a 4b8f 4b93 4b95 4ba1 4ba3 4ba7 4bab
4baf 4bb2 4bb3 4bb5 4bb8 4bbc 4bc0 4bc3
4bc4 4bc6 4bc7 4bcc 4bd0 4bd2 4bd6 4bd9
4bdd 4be0 4be4 4be8 4beb 4bef 4bf3 4bf7
4bfb 4bff 4c03 4c07 4c0b 4c0f 4c12 4c16
4c1a 4c1d 4c1e 4c20 4c21 4c23 4c27 4c2b
4c2f 4c32 4c33 4c35 4c38 4c3b 4c3c 4c41
4c45 4c49 4c4d 4c51 4c55 4c58 4c5c 4c60
4c63 4c66 4c6b 4c6e 4c71 4c74 4c75 4c7a
4c7b 1 4c7d 4c82 4c86 4c8a 4c8d 4c92
4c97 4c9a 4c9e 4c9f 4ca4 4ca5 4caa 4cac
4cb0 4cb3 4cb7 4cbb 4cbf 4cc2 4cc6 4cc8
4ccc 4cd0 4cd4 4cd8 4cdc 4ce0 4ce4 4ce8
4cec 4cf0 4cf4 4cf8 4cfc 4d00 4d04 4d08
4d0c 4d10 4d1c 4d20 4d25 4d29 4d2c 4d2d
4d32 4d36 4d3a 4d3d 4d40 4d44 4d46 4d4a
4d4e 4d51 4d54 4d58 4d5a 4d5e 4d62 4d65
4d67 4d6b 4d6f 4d73 4d76 4d7a 4d7e 4d80
4d81 4d86 1 4d8a 4d8e 4d92 4d95 4d99
4d9d 4da1 4da5 4da8 4dac 4db0 4db3 4db6
4dbb 4dbe 4dc1 4dc4 4dc5 4dca 4dcb 1
4dcd 4dd2 4dd6 4dda 4ddd 4de2 4de7 4dea
4dee 4def 4df4 4df7 4dfc 4dfd 4e02 4e05
4e0a 4e0b 4e10 4e13 4e17 4e18 4e1d 4e20
4e25 4e26 4e2b 4e2e 4e32 4e36 4e39 4e3c
4e3d 4e3f 4e40 4e45 4e46 4e4b 4e4d 4e51
4e54 4e56 4e5a 4e5c 4e68 4e6a 4e6c 4e6d
4e72 4e76 4e78 4e84 4e86 4e88 4e8c 4e90
4e93 4e95 4e99 4e9d 4ea0 4ea2 4ea6 4eaa
4ead 4eaf 4eb3 4eb7 4eba 4ebe 4ec2 4ec5
4ec9 4ecd 4ece 4ed0 4ed4 4ed8 4edc 4edf
4ee3 4ee7 4eea 4eed 4ef2 4ef5 4ef8 4efb
4efc 4f01 4f02 1 4f04 4f09 4f0d 4f11
4f14 4f19 4f1e 4f21 4f25 4f26 4f2b 4f2e
4f33 4f34 4f39 4f3c 4f41 4f42 4f47 4f4a
4f4e 4f52 4f55 4f56 4f5b 4f5c 4f61 4f63
4f67 4f6a 4f6e 4f72 4f76 4f79 4f7d 4f7f
4f83 4f85 4f91 4f95 4f97 4f98 4fa1 
16df
2
0 1 a 6 15 19 20 :3 6
1c :3 6 12 :3 6 11 :3 6 14 18
1f :3 6 14 18 1f :2 6 1 3
a :2 1 4 :2 17 26 17 :2 4 :2 d
1c d :2 4 :2 c 1b c :2 4 9
12 11 :2 9 :2 4 14 1d 1c :2 14
:2 4 11 1a 19 :2 11 :2 4 e 17
16 :2 e :2 4 d 16 15 :2 d :2 4
:3 9 :2 4 :3 9 :2 4 :3 11 :2 4 :3 12 :2 4
:3 15 :2 4 :3 e :2 4 :3 10 :2 4 f 18
17 :2 f :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 :2 13 22 13
:2 4 :2 c 1b c :2 4 :2 f 1e f
:2 4 :2 16 25 16 :2 4 :2 d 1c d
:2 4 :2 13 22 13 :2 4 :2 14 23 14
:2 4 :2 12 21 12 :2 4 :2 11 20 11
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 10 1f 10 :2 4 :2 11 20 11
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 f 1e f :2 4 :2 e 1d e
:2 4 :2 e 1d e :2 4 :2 f 1e f
:2 4 :2 c 1b c :2 4 :2 b 1a b
:2 4 :2 b 1a b :2 4 :2 13 22 13
:2 4 :2 10 1f 10 :2 4 :2 a 19 a
:2 4 :2 11 20 11 :2 4 :2 10 1f 10
:2 4 :2 12 21 12 :2 4 c 10 f
c 20 :2 29 c :2 4 d 11 10
d 21 :2 2a d :2 4 14 1d 1c
:2 14 :2 4 :2 f 19 f :2 4 :2 f 19
f :2 4 :2 10 1a 10 :2 4 :2 10 1a
10 :2 4 :2 11 1b 11 :2 4 :2 11 1b
11 :2 4 :2 12 1c 12 :2 4 :2 12 1c
12 :2 4 :2 15 24 15 :2 4 :2 c 16
c :2 4 :2 d 1c d :2 4 :2 d 1c
d :2 4 :2 d 1c d :2 4 :2 d 1c
d :2 4 :2 10 1f 10 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 56 5c 5f :2 56 6d
85 8 :2 6d d 10 :2 6d 1c 1f
:2 6d b e :2 6d 13 16 1f 27
:2 1f 3f :2 16 :2 6d b e :2 6d 13
16 1f 27 :2 1f 35 :2 16 :2 6d b
e :2 6d 13 16 1f 27 :2 1f 34
:2 16 :2 6d b e :2 6d 13 16 :2 6d
1b 1e :2 6d 29 2c :2 6d b e
:2 6d 13 16 :2 6d 1b 1e :2 6d 29
2c :2 6d 31 34 :2 6d :2 7 4c :2 4
7 :2 11 23 :2 2d 39 3c 4e 50
51 :2 4e :2 23 :3 7 :2 d 12 1e 5f
62 :2 1e :2 7 54 :3 4 c 4 e
1a 27 36 40 50 5d 68 75
7 13 23 3a 45 4f 57 69
78 87 99 7 19 2c 34 3b
56 5e 65 81 8b 7 15 23
31 7 17 27 37 7 1a 23
c 1a 24 30 3c 4e 5d 6a
7 11 1d 2e 39 41 4a 52
7 15 24 2a 30 3c 7 13
20 2c 7 15 24 32 7 17
22 c d 21 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 55 58 59 :2 55 :2 29
:3 d :2 13 18 24 66 69 :2 24 76
79 :2 24 7d 80 :2 24 8c 8f :2 24
97 9a :2 24 a6 a9 b0 b9 bc
:2 a9 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 11 1d 28 36 43 56 66
76 82 f 1d 2a 34 43 53
5f 6a 78 f 10 1d :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5b 5c
:2 58 :2 2c :3 10 :2 16 1b 27 69 6c
:2 27 79 7c :2 27 80 83 :2 27 8f
92 :2 27 9a 9d :2 27 a9 ac b3
bc bf :2 ac :2 27 :2 10 5f :2 d :2 a
:4 16 :2 a 7 :3 35 b :2 14 1f 1d
:2 28 :2 1d :2 a 18 a d :2 17 29
:2 33 3f 42 54 57 58 :2 54 :2 29
:3 d :2 13 18 24 66 69 :2 24 :2 d
5b :3 a 11 :2 1a a 38 :2 7 a
11 1f 22 :2 a 25 27 :2 25 a
18 a d :2 17 29 :2 33 3f 42
54 57 58 :2 54 :2 29 :3 d :2 13 18
24 66 69 :2 24 :2 d 5b :3 a 11
:2 1a a 2b :2 7 b 12 d 1a
:2 12 1e :2 27 :2 b a 40 3e :2 49
:2 3e a 18 a d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 :2 d 5b
:3 a 11 :2 1a a 5e :3 7 15 7
11 :2 f 10 1d :2 a :2 13 1f a
7 f d :2 16 22 d 1d :2 a
:2 f d :2 16 22 d 10 :2 1a 2c
:2 36 42 46 58 5b 5c :2 58 :2 2c
:3 10 :2 16 1b 27 69 6c :2 27 79
7c :2 27 80 83 :2 27 8f 92 :2 27
9a 9d :2 27 a9 ac b3 bc bf
:2 ac :2 27 :2 10 5f :2 d :2 a :4 16 :2 a
7 :3 35 a 13 1f :2 a 22 24
:2 22 14 :2 12 13 20 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5b 5e 5f :2 5b
:2 2f :3 13 :2 19 1e 2a 6c 6f :2 2a
7c 7f :2 2a 83 86 :2 2a 92 95
:2 2a 9d a0 :2 2a ac af b6 bf
c2 :2 af :2 2a :2 13 62 :2 10 :2 d :4 19
:2 d a :3 26 d :2 18 1f 2d :2 d
32 34 :2 32 d 1b d 10 :2 1a
2c :2 36 42 45 57 5a 5b :2 57
:2 2c :3 10 :2 16 1b 27 69 6c :2 27
:2 10 5e :3 d 14 :2 1d d 36 :2 a
26 :3 7 15 7 11 :2 f 11 13
f 20 24 2f 10 13 20 e
11 1b e 11 25 27 e 10
25 27 e 10 1a 23 :2 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 58 5b 5c
:2 58 :2 2c :3 10 :2 16 1b 27 69 6c
:2 27 79 7c :2 27 80 83 :2 27 8f
92 :2 27 9a 9d :2 27 a9 ac b3
bc bf :2 ac :2 27 :2 10 5f :2 d :2 a
:4 16 :2 a 7 :3 35 a 13 1f :2 a
22 24 :2 22 a 18 a d :2 17
29 :2 33 3f 42 54 57 58 :2 54
:2 29 :3 d :2 13 18 24 66 69 :2 24
:2 d 5b :3 a 11 :2 1a a 26 :2 7
a 13 1d :2 a 20 22 :2 20 d
:2 17 29 :2 33 3f 42 54 57 58
:2 54 :2 29 :3 d :2 13 18 24 66 69
:2 24 76 79 :2 24 7d 80 :2 24 8a
8d 96 9e :2 a7 :2 96 b8 :2 8d :2 24
:2 d 5b :2 a d :2 17 29 :2 33 3f
42 54 57 58 :2 54 :2 29 :3 d :2 13
18 24 66 69 :2 24 :2 d 5b :3 a
11 :2 1c 2f :2 38 48 :2 11 a 7
24 d 16 20 :2 d 26 23 2f
3e :2 26 :2 23 a 1a a d 16
20 :2 d 25 23 2e 38 :2 25 :2 23
d 1b d 10 :2 1a 2c :2 36 42
45 57 5a 5b :2 57 :2 2c :3 10 :2 16
1b 27 69 6c :2 27 :2 10 5e :3 d
14 :2 1d d a 3b 10 19 23
:2 10 28 26 31 3b :2 28 :2 26 d
1d d 3e 3b :3 a 1a :2 a 18
2a 38 3e 4c 58 21 2f :2 58
33 3c 47 :2 33 4b 54 61 :2 4b
:2 18 a 41 24 d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 76 79
:2 24 7d 80 :2 24 8a 8d 96 9e
:2 a7 :2 96 b8 :2 8d :2 24 :2 d 5b :2 a
d :2 17 29 :2 33 3f 42 54 57
58 :2 54 :2 29 :3 d :2 13 18 24 66
69 :2 24 :2 d 5b :3 a 11 :2 1c 2f
:2 38 48 :2 11 a :4 7 35 a 13
1d :2 a 20 22 :2 20 a 18 a
d :2 17 29 :2 33 3f 42 54 57
58 :2 54 :2 29 :3 d :2 13 18 24 66
69 :2 24 :2 d 5b :3 a 11 :2 1a a
24 :3 7 15 7 11 :2 f 10 1d
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 58
5b 5c :2 58 :2 2c :3 10 :2 16 1b 27
69 6c :2 27 79 7c :2 27 80 83
:2 27 8f 92 :2 27 9a 9d :2 27 a9
ac b3 bc bf :2 ac :2 27 :2 10 5f
:2 d :2 a :4 16 :2 a 7 :3 4 a 13
1f :2 a 22 24 :2 22 14 :2 12 13
20 :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5b 5e 5f :2 5b :2 2f :3 13 :2 19 1e
2a 6c 6f :2 2a 7c 7f :2 2a 83
86 :2 2a 92 95 :2 2a 9d a0 :2 2a
ac af b6 bf c2 :2 af :2 2a :2 13
62 :2 10 :2 d :4 19 :2 d a :3 26 d
:2 18 1f 2d :2 d 32 34 :2 32 d
1b d 10 :2 1a 2c :2 36 42 45
57 5a 5b :2 57 :2 2c :3 10 :2 16 1b
27 69 6c :2 27 :2 10 5e :3 d 14
:2 1d d 36 :2 a 26 :2 7 11 21
2c 38 f 1a 27 35 f 10
1d e 1b :2 a :2 13 1f a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 58 5b 5c :2 58 :2 2c :3 10
:2 16 1b 27 69 6c :2 27 79 7c
:2 27 80 83 :2 27 8f 92 :2 27 9a
9d :2 27 a9 ac b3 bc bf :2 ac
:2 27 :2 10 5f :2 d :2 a :4 16 :2 a 7
:3 4 a 11 1f 22 :2 a 25 27
:2 25 a 18 a d :2 17 29 :2 33
3f 42 54 57 58 :2 54 :2 29 :3 d
:2 13 18 24 66 69 :2 24 :2 d 5b
:3 a 11 :2 1a a 2b :2 7 b 12
d 1a :2 12 1e :2 27 :2 b a 40
3e :2 49 :2 3e a 18 a d :2 17
29 :2 33 3f 42 54 57 58 :2 54
:2 29 :3 d :2 13 18 24 66 69 :2 24
:2 d 5b :3 a 11 :2 1a a 5e :3 7
15 7 11 :2 f 11 f 10 24
e 23 e 18 21 :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 58 5b 5c :2 58
:2 2c :3 10 :2 16 1b 27 69 6c :2 27
79 7c :2 27 80 83 :2 27 8f 92
:2 27 9a 9d :2 27 a9 ac b3 bc
bf :2 ac :2 27 :2 10 5f :2 d :2 a :4 16
:2 a 7 :3 4 a 13 1f :2 a 22
24 :2 22 a 18 a d :2 17 29
:2 33 3f 42 54 57 58 :2 54 :2 29
:3 d :2 13 18 24 66 69 :2 24 :2 d
5b :3 a 11 :2 1a a 26 :2 7 b
14 1e :2 b 21 23 :2 21 a 2b
34 48 :2 2b 4b 4d :2 4b 2a :3 a
20 27 30 3a :2 27 3d 3f :2 27
26 46 48 51 5b :2 48 :2 26 :2 20
a 50 :3 7 19 22 2c :2 19 7
a 13 1d :2 a 23 20 2c 3b
:2 23 :2 20 a 1a a d 16 24
:2 d 29 27 32 3c :2 29 :2 27 10
19 26 :2 10 2b 29 :2 34 :2 29 4b
13 20 :2 4b 25 23 :2 2e :2 23 :3 10
1f 10 1a 20 2b 2f 18 21
18 19 26 17 2b 17 :2 13 :2 1c
28 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 64 65
:2 61 :2 35 :3 19 :2 1f 24 30 72 75
:2 30 82 85 :2 30 89 8c :2 30 98
9b :2 30 a3 a6 :2 30 b2 b5 bc
c5 c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13
:4 1f :2 13 10 :3 40 :4 14 :2 13 23 13
2d :2 10 13 1c 25 :2 13 28 2a
:2 28 17 20 2c :2 17 2f 31 :2 2f
16 :4 3a 39 38 :2 16 20 2c 3c
1e 1f 2c 3d 51 5a 65 6d
74 :2 19 :2 22 2e 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
67 6a 6b :2 67 :2 3b :3 1f :2 25 2a
36 78 7b :2 36 88 8b :2 36 8f
92 :2 36 9e a1 :2 36 a9 ac :2 36
b8 bb c2 cb ce :2 bb :2 36 :2 1f
6e :2 1c :2 19 :4 25 :2 19 16 :3 59 16
22 2b 39 :2 22 3c 3e 47 56
:2 3e :2 22 59 5b 64 6f :2 5b :2 22
:2 16 28 16 59 :3 13 20 27 30
3a :2 30 45 :2 27 48 4a 53 5d
:2 53 67 :2 4a :2 27 26 6b 6d :2 26
:2 20 :2 13 21 2a 35 :2 21 38 3a
43 4c :2 3a :2 21 13 16 1f 2b
:2 16 31 2e 3a 44 :2 31 :2 2e 16
28 31 3c :2 28 3f 41 4a 54
:2 41 :2 28 57 59 62 6e :2 59 :2 28
16 47 16 28 31 3c :2 28 16
:5 13 21 2d 3b 4c 52 60 1d
2d 38 :2 21 :2 13 26 2d 36 40
:2 36 4c :2 2d 4f 51 5a 64 :2 5a
70 :2 51 :2 2d 2c 24 26 :2 2c :2 26
:2 13 21 :2 2a 31 3a 4b :2 31 4f
:2 58 :2 21 :2 13 21 31 3f 45 51
5a 65 :2 51 69 1f 30 :2 69 34
:2 21 :2 13 21 32 40 4b 51 :2 21
13 2c :2 10 40 13 1c 29 :2 13
2f 2c 38 3f :2 2f :2 2c 16 :2 21
28 32 :2 16 3e 40 :2 3e 16 22
2b 39 :2 22 3c 3e 47 51 :2 3e
:2 22 :2 16 28 16 19 22 30 :2 19
33 36 3f 4e :2 36 51 53 5c
63 :2 53 :2 36 35 :2 33 19 23 2c
3b :2 23 3e 40 49 50 :2 40 :2 23
22 54 56 5f 6d :2 56 :2 22 19
23 20 1c 2a 33 3a 46 4f
1c 29 1c 2a 1c 22 1c 22
36 1c 23 1f 2b :3 29 1f :2 28
34 1f 30 1f :2 28 34 1f :4 1c
19 21 1f :2 28 34 1f 2f :2 1c
:2 21 1f :2 28 34 1f 22 :2 2c 3e
:2 48 54 58 6a 6d 6e :2 6a :2 3e
:3 22 :2 28 2d 39 7b 7e :2 39 8b
8e :2 39 92 95 :2 39 a1 a4 :2 39
ac af :2 39 bb be c5 ce d1
:2 be :2 39 :2 22 71 :2 1f :2 1c :4 28 :2 1c
19 :3 67 19 2b :2 34 3b 44 54
:2 3b 58 :2 61 :2 2b 19 67 23 20
1c 2a 33 3a 46 4f 1c 29
1c 2a :2 1c 22 36 1c 23 1f
2b :3 29 1f :2 28 34 1f 30 1f
:2 28 34 1f :4 1c 19 21 1f :2 28
34 1f 2f :2 1c :2 21 1f :2 28 34
1f 22 :2 2c 3e :2 48 54 58 6a
6d 6e :2 6a :2 3e :3 22 :2 28 2d 39
7b 7e :2 39 8b 8e :2 39 92 95
:2 39 a1 a4 :2 39 ac af :2 39 bb
be c5 ce d1 :2 be :2 39 :2 22 71
:2 1f :2 1c :4 28 :2 1c 19 :7 16 42 19
22 30 :2 19 33 36 3f 4e :2 36
51 53 5c 63 :2 53 :2 36 35 :2 33
19 25 2e 35 :2 25 38 3a 43
4d :2 3a :2 25 :2 19 2b 33 3c 46
:2 3c 55 :2 33 58 5a 63 6d :2 63
78 :2 5a :2 33 32 24 26 :2 32 31
30 32 :2 31 :2 2b 19 23 20 1c
2a 33 3a 46 4f 1c 29 1c
2a 22 36 1c 23 1f 2b :3 29
1f :2 28 34 1f 30 1f :2 28 34
1f :4 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 6a 6d 6e
:2 6a :2 3e :3 22 :2 28 2d 39 7b 7e
:2 39 8b 8e :2 39 92 95 :2 39 a1
a4 :2 39 ac af :2 39 bb be c5
ce d1 :2 be :2 39 :2 22 71 :2 1f :2 1c
:4 28 :2 1c 19 :4 67 19 25 2e 3c
:2 25 3f 41 4a 54 :2 41 :2 25 :2 19
2b 19 23 20 1c 2a 33 3a
46 4f 1c 29 1c 2a :2 1c 22
36 1c 23 1f 2b :3 29 1f :2 28
34 1f 30 1f :2 28 34 1f :4 1c
19 21 1f :2 28 34 1f 2f :2 1c
:2 21 1f :2 28 34 1f 22 :2 2c 3e
:2 48 54 58 6a 6d 6e :2 6a :2 3e
:3 22 :2 28 2d 39 7b 7e :2 39 8b
8e :2 39 92 95 :2 39 a1 a4 :2 39
ac af :2 39 bb be c5 ce d1
:2 be :2 39 :2 22 71 :2 1f :2 1c :4 28 :2 1c
19 :7 16 :4 13 42 13 1f 28 36
:2 1f 39 3b 44 53 :2 3b :2 1f :2 13
25 13 1d 1a 16 24 2d 34
40 49 16 23 16 24 :2 16 1c
30 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 67 68 :2 64 :2 38
:3 1c :2 22 27 33 75 78 :2 33 85
88 :2 33 8c 8f :2 33 9b 9e :2 33
a6 a9 :2 33 b5 b8 bf c8 cb
:2 b8 :2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16
13 :7 10 :4 14 :2 13 20 13 1d 21
:2 1b 1c 29 1a 28 :2 16 :2 1f 2b
16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 64 67 68 :2 64
:2 38 :3 1c :2 22 27 33 75 78 :2 33
85 88 :2 33 8c 8f :2 33 9b 9e
:2 33 a6 a9 :2 33 b5 b8 bf c8
cb :2 b8 :2 33 :2 1c 6b :2 19 :2 16 :4 22
:2 16 13 :3 32 :4 17 16 20 28 2f
50 5f :2 19 :2 22 2e 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 67 6a 6b :2 67 :2 3b :3 1f :2 25
2a 36 78 7b :2 36 88 8b :2 36
8f 92 :2 36 9e a1 :2 36 a9 ac
:2 36 b8 bb c2 cb ce :2 bb :2 36
:2 1f 6e :2 1c :2 19 :4 25 :2 19 16 :3 2e
19 :2 24 2c 3e 49 :2 19 4d 4f
:2 4d 19 29 19 51 :2 16 13 2e
19 22 2d :2 19 30 32 :2 30 16
24 :2 2d 34 3d 48 :2 34 4c :2 55
:2 24 23 16 20 2b 38 40 47
62 6d 72 :2 1e :2 19 :2 22 2e 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6a 6b :2 67 :2 3b
:3 1f :2 25 2a 36 78 7b :2 36 88
8b :2 36 8f 92 :2 36 9e a1 :2 36
a9 ac :2 36 b8 bb c2 cb ce
:2 bb :2 36 :2 1f 6e :2 1c :2 19 :4 25 :2 19
16 :4 34 2e 20 2b 38 40 47
62 6d 72 :2 1e :2 19 :2 22 2e 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 67 6a 6b :2 67 :2 3b
:3 1f :2 25 2a 36 78 7b :2 36 88
8b :2 36 8f 92 :2 36 9e a1 :2 36
a9 ac :2 36 b8 bb c2 cb ce
:2 bb :2 36 :2 1f 6e :2 1c :2 19 :4 25 :2 19
16 :7 13 32 :2 10 :4 14 :2 13 21 31
3f 45 :2 21 13 31 16 1d 29
2c :2 16 2f 31 :2 2f 16 24 34
42 48 :2 24 16 35 16 24 34
42 48 :2 24 16 :4 13 :5 10 1e :2 10
1e 2c 32 40 4a 56 61 6d
1f 28 39 :2 1f :2 1e 10 13 1c
28 :2 13 2b 2e :2 2b 13 21 13
16 :2 20 32 :2 3c 48 4b 5d 60
61 :2 5d :2 32 :3 16 :2 1c 21 2d 6f
72 :2 2d :2 16 64 :3 13 1a 23 2f
:2 1a 13 30 :2 10 :5 d 19 d 3f
d 1f 27 30 3a :2 30 49 :2 27
4c 4e 57 61 :2 57 6c :2 4e :2 27
26 24 :3 26 25 30 32 :2 25 :2 1f
d :5 a 18 2c 3a 45 4f 55
25 31 3b 49 25 34 44 50
25 31 3e 4c 25 33 42 55
25 31 3d 46 51 :2 3d 55 23
30 :2 55 :2 18 :2 a 18 a d :2 17
29 :2 33 3f 42 54 57 58 :2 54
:2 29 :3 d :2 13 18 24 66 69 :2 24
:2 d 5b :3 a 11 1a 26 :2 11 a
7 3e d 16 2a :2 d 30 2d
39 49 :2 30 :2 2d 14 11 25 d
1b 24 2b 37 40 13 27 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5e 5f :2 5b :2 2f :3 13 :2 19
1e 2a 6c 6f :2 2a 7c 7f :2 2a
83 86 :2 2a 92 95 :2 2a 9d a0
:2 2a ac af b6 bf c2 :2 af :2 2a
:2 13 62 :2 10 :2 d :4 19 :2 d a :3 4c
14 11 1f 28 2f 3b 44 13
20 11 1e d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5b 5e 5f
:2 5b :2 2f :3 13 :2 19 1e 2a 6c 6f
:2 2a 7c 7f :2 2a 83 86 :2 2a 92
95 :2 2a 9d a0 :2 2a ac af b6
bf c2 :2 af :2 2a :2 13 62 :2 10 :2 d
:4 19 :2 d a :3 4c 7 4c 3e d
16 1f :2 d 25 22 2e 3f :2 25
:2 22 d 16 1f :2 d 22 24 :2 22
d 20 d 26 11 1a 23 :2 11
26 28 :2 26 10 2f 38 41 :2 2f
44 46 :2 44 2e :3 10 1e 10 13
:2 1d 2f :2 39 45 48 5a 5d 5e
:2 5a :2 2f :3 13 :2 19 1e 2a 6c 6f
:2 2a :2 13 61 :3 10 17 :2 20 10 51
:3 d 20 29 32 :2 20 d :4 a :4 e
d 17 :2 15 16 2a :2 10 :2 19 25
10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 61 62 :2 5e
:2 32 :3 16 :2 1c 21 2d 6f 72 :2 2d
7f 82 :2 2d 86 89 :2 2d 95 98
:2 2d a0 a3 :2 2d af b2 b9 c2
c5 :2 b2 :2 2d :2 16 65 :2 13 :2 10 :4 1c
:2 10 d :3 2b 11 :2 1a 25 23 :2 2e
:2 23 10 43 4c 5d :2 43 62 60
13 1f :2 62 :2 60 42 :3 10 1e 10
13 :2 1d 2f :2 39 45 48 5a 5d
5e :2 5a :2 2f :3 13 :2 19 1e 2a 6c
6f :2 2a :2 13 61 :3 10 17 :2 20 10
23 :2 d 2b :2 a d 16 23 :2 d
28 26 :2 31 :2 26 46 10 1d :2 46
22 20 :2 2b :2 20 :2 d 11 1a 26
:2 11 29 2b :2 29 10 :4 34 33 32
:3 10 1e 33 41 4c 56 67 26
38 44 :2 1e 10 53 :3 d 1a 22
2b 3c :2 22 3f 41 4a 55 :2 41
:2 22 21 59 5b :2 21 20 65 67
:2 20 :2 1a :2 d 1b 27 35 46 4c
5a 1d 28 33 :2 1b :2 d 1b :2 24
2b 34 45 :2 2b 49 :2 52 :2 1b :2 d
1b 2b 39 3f 4b 4e 51 :2 1b
d 17 1f 26 41 49 50 70
76 15 2c 40 :2 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 5e 61 62 :2 5e :2 32
:3 16 :2 1c 21 2d 6f 72 :2 2d 7f
82 :2 2d 86 89 :2 2d 95 98 :2 2d
a0 a3 :2 2d af b2 b9 c2 c5
:2 b2 :2 2d :2 16 65 :2 13 :2 10 :4 1c :2 10
d :3 3f d 1b 2c 3a 45 4b
:2 1b d 3f 11 1a 26 :2 11 29
2b :2 29 10 :4 34 33 32 :3 10 1e
33 41 4c 56 67 26 38 44
:2 1e 10 53 :2 d :4 11 :2 10 1e 2e
3c 42 :2 1e 10 2e 13 1a 26
29 :2 13 2c 2e :2 2c 13 21 31
3f 45 :2 21 13 32 13 21 31
3f 45 :2 21 13 :4 10 :4 d :4 11 10
1a 25 32 3a 41 5c 67 6c
:2 18 :2 13 :2 1c 28 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
61 64 65 :2 61 :2 35 :3 19 :2 1f 24
30 72 75 :2 30 82 85 :2 30 89
8c :2 30 98 9b :2 30 a3 a6 :2 30
b2 b5 bc c5 c8 :2 b5 :2 30 :2 19
68 :2 16 :2 13 :4 1f :2 13 10 :3 2f 10
1c 25 2f :2 1c 32 34 3d 4c
:2 34 :2 1c 10 2f :3 d 1a :2 d 1b
:2 d 1b 29 2f 3d 47 53 5e
6a 1f 28 39 :2 1f :2 1b d 10
19 25 :2 10 28 2b :2 28 10 1e
10 13 :2 1d 2f :2 39 45 48 5a
5d 5e :2 5a :2 2f :3 13 :2 19 1e 2a
6c 6f :2 2a :2 13 61 :3 10 17 :2 20
10 2d 1a 17 13 1f :5 13 21
2a 31 3e 47 54 5d 19 2d
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 64 65 :2 61 :2 35 :3 19
:2 1f 24 30 72 75 :2 30 82 85
:2 30 89 8c :2 30 98 9b :2 30 a3
a6 :2 30 b2 b5 bc c5 c8 :2 b5
:2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13 10
:7 d :4 a 42 3e :2 7 :5 4 :2 d 19
23 :2 19 4 7 :2 11 23 :2 2d 39
3c 4e 52 53 :2 4e :2 23 :3 7 :2 d
12 1e 61 64 :2 1e 71 74 :2 1e
78 7b :2 1e 85 88 :2 91 :2 1e :2 7
56 :3 4 b :2 14 4 :9 1 
16df
4
0 :2 1 :6 3 :4 4
:4 5 :4 6 :6 7 :6 8
2 :2 9 :2 1 :6 b
:6 c :6 d :7 e :7 f
:7 10 :7 11 :7 12 :5 13
:5 14 :5 15 :5 16 :5 17
:5 18 :5 19 :7 1a :7 1b
:7 1c :6 1d :6 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :6 35 :6 36 :6 37
:6 38 :a 39 :a 3a :7 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :6 41 :6 42 :6 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :b 4c
:11 4d 4e :2 4d :2 4e
:2 4d :2 4e :2 4d :2 4f
:2 4d :9 4f :2 4d :2 50
:2 4d :9 50 :2 4d :2 51
:2 4d :9 51 :2 4d :2 52
:2 4d :2 52 :2 4d :2 52
:2 4d :2 52 :2 4d :2 53
:2 4d :2 53 :2 4d :2 53
:2 4d :2 53 :2 4d :2 53
:4 4d :3 4c :11 56 :b 57
:3 56 :3 5a :9 5d :b 5e
:a 5f :4 60 :4 61 :3 62
:8 63 :8 64 :6 65 :4 66
:4 67 :3 68 69 :2 6a
5d :5 6b 5c 6d
:5 6e :3 6d :2 6f :5 71
:11 72 :24 73 :3 72 :2 70
:6 6f 6c :3 4b :a 78
:9 7a :9 7b 7c :2 7d
7a :5 7e 79 80
:5 81 :3 80 :2 82 :5 84
:11 85 :24 86 :3 85 :2 83
:6 82 7f :3 78 :a 8b
:3 8c :11 8d :b 8e :3 8d
:5 90 :3 8b :a 92 :3 93
:11 94 :b 95 :3 94 :5 97
:3 92 :2 99 :2 9a :2 99
:3 9a :3 99 :6 9a :3 9b
:11 9c :b 9d :3 9c :5 9f
9a :2 99 :3 a2 a4
a5 a6 :2 a7 a4
:5 a8 a3 aa :5 ab
:3 aa :2 ac :5 ae :11 af
:24 b0 :3 af :2 ad :6 ac
a9 :3 78 :9 b5 b7
b8 b9 :2 ba b7
:5 bb b6 bd :5 be
:3 bd :2 bf :5 c1 :11 c2
:24 c3 :3 c2 :2 c0 :6 bf
bc :3 b5 :b c8 :3 c9
:11 ca :b cb :3 ca :5 cd
:3 c8 :3 b5 :3 d2 d4
d5 d6 :2 d8 :4 d9
:3 da :3 db :4 dc :4 dd
:4 de d4 :5 df d3
e1 :5 e2 :3 e1 :2 e3
:5 e5 :11 e6 :24 e7 :3 e6
:2 e4 :6 e3 e0 :3 78
:9 ec :3 ed :11 ee :b ef
:3 ee :5 f1 :3 ec :9 f4
:11 f5 :20 f6 :3 f5 :11 f8
:b f9 :3 f8 :b fb fc
f4 :d fc :3 fd :d fe
:3 ff :11 100 :b 101 :3 100
:5 103 104 fe :d 104
:3 105 104 :3 fe :3 108
:7 109 :2 10a :2 109 :a 10a
:3 109 fc f4 :11 10c
:20 10d :3 10c :11 10f :b 110
:3 10f :b 112 10b :3 f4
78 :9 115 :3 116 :11 117
:b 118 :3 117 :5 11a :3 115
:3 11d 11f 120 121
:2 122 11f :5 123 11e
125 :5 126 :3 125 :2 127
:5 129 :11 12a :24 12b :3 12a
:2 128 :6 127 124 :3 114
:9 130 132 133 134
:2 135 132 :5 136 131
138 :5 139 :3 138 :2 13a
:5 13c :11 13d :24 13e :3 13d
:2 13b :6 13a 137 :3 130
:b 143 :3 144 :11 145 :b 146
:3 145 :5 148 :3 143 :3 130
:4 14d :4 14e 14f :2 150
:2 151 14d :5 152 14c
154 :5 155 :3 154 :2 156
:5 158 :11 159 :24 15a :3 159
:2 157 :6 156 153 :3 114
:a 15f :3 160 :11 161 :b 162
:3 161 :5 164 :3 15f :2 166
:2 167 :2 166 :3 167 :3 166
:6 167 :3 168 :11 169 :b 16a
:3 169 :5 16c 167 :2 166
:3 170 172 173 174
176 177 :2 178 :2 179
:3 17a 172 :5 17b 171
17d :5 17e :3 17d :2 17f
:5 181 :11 182 :24 183 :3 182
:2 180 :6 17f 17c :3 114
:9 188 :3 189 :11 18a :b 18b
:3 18a :5 18d :3 188 :16 190
:17 191 :3 190 :7 194 :d 195
:3 196 :d 198 :c 199 :2 19a
:2 199 :6 19a :2 199 :3 19b
:4 19d :2 19e 19f :2 1a0
:2 1a1 1a2 19d :5 1a3
19c 1a5 :5 1a6 :3 1a5
:2 1a7 :5 1a9 :11 1aa :24 1ab
:3 1aa :2 1a8 :6 1a7 1a4
:3 19a :5 1b0 :3 1b1 :3 1b0
:9 1b4 :12 1b5 :3 1b7 1b8
:8 1b9 1b7 :5 1ba 1b6
1bc :5 1bd :3 1bc :2 1be
:5 1c0 :11 1c1 :24 1c2 :3 1c1
:2 1bf :6 1be 1bb :3 1b5
:17 1c7 :3 1c8 :3 1b5 :1d 1cb
:f 1cc :d 1cd :17 1ce 1cd
:7 1d0 1cf :3 1cd :7 1d3
:3 1d4 :3 1d3 :16 1d7 :2 1d8
:5 1d7 :f 1d9 :b 1da :2 1db
:2 1da 1db :3 1da :9 1dc
:3 1b4 19a :d 1df :b 1e0
:f 1e1 :3 1e2 :16 1e4 :18 1e5
1e7 1e8 :6 1e9 :2 1ea
:2 1eb :2 1ec 1ed :2 1ee
1e7 :6 1ef :5 1f0 1ef
:5 1f2 1f1 :3 1ef 1e6
1f5 :5 1f6 :3 1f5 :2 1f7
:5 1f9 :11 1fa :24 1fb :3 1fa
:2 1f8 :6 1f7 1f4 :3 1e4
:f 200 1e4 203 204
:6 205 :2 206 :2 207 208
209 :2 20a 203 :6 20b
:5 20c 20b :5 20e 20d
:3 20b 202 211 :5 212
:3 211 :2 213 :5 215 :11 216
:24 217 :3 216 :2 214 :6 213
210 :4 201 :3 1e4 1e0
:16 21d :f 21e :16 21f :2 220
:3 21f :2 220 :5 21f 223
224 :6 225 :2 226 :2 227
:2 228 223 :6 229 :5 22a
229 :5 22c 22b :3 229
222 22f :5 230 :3 22f
:2 231 :5 233 :11 234 :24 235
:3 234 :2 232 :6 231 22e
:4 21d :f 23a :3 23b 23e
23f :6 240 :2 241 :2 242
243 244 :2 245 23e
:6 246 :5 247 246 :5 249
248 :3 246 23d 24c
:5 24d :3 24c :2 24e :5 250
:11 251 :24 252 :3 251 :2 24f
:6 24e 24b :4 239 :3 21d
21c :3 1e0 1df :f 259
:3 25a 25d 25e :6 25f
:2 260 :2 261 262 263
:2 264 25d :6 265 :5 266
265 :5 268 267 :3 265
25c 26b :5 26c :3 26b
:2 26d :5 26f :11 270 :24 271
:3 270 :2 26e :6 26d 26a
:4 258 :3 1df :5 277 :3 278
:2 27a 27b 27c :2 27d
:2 27e 27a :5 27f 279
281 :5 282 :3 281 :2 283
:5 285 :11 286 :24 287 :3 286
:2 284 :6 283 280 :3 277
:5 28c :6 28e :5 28f 28d
291 :5 292 :3 291 :2 293
:5 295 :11 296 :24 297 :3 296
:2 294 :6 293 290 :3 28c
:c 29c :3 29d :3 29c 29f
28c :9 29f :10 2a0 :8 2a3
2a4 2a5 2a3 :5 2a6
2a2 2a8 :5 2a9 :3 2a8
:2 2aa :5 2ac :11 2ad :24 2ae
:3 2ad :2 2ab :6 2aa 2a7
:4 29f 28c :8 2b4 2b5
2b6 2b4 :5 2b7 2b3
2b9 :5 2ba :3 2b9 :2 2bb
:5 2bd :11 2be :24 2bf :3 2be
:2 2bc :6 2bb 2b8 :4 2b2
:3 28c :3 277 :5 2c6 :8 2c7
2c6 :a 2c9 :8 2ca 2c9
:8 2cc 2cb :3 2c9 2c8
:3 2c6 :3 2d0 :9 2d1 :5 2d2
:3 2d1 :9 2d4 :3 2d5 :11 2d6
:b 2d7 :3 2d6 :7 2d9 :3 2d4
1de :3 199 :3 2dd 198
:16 2df :2 2e0 :3 2df :2 2e0
:5 2df 2de :3 198 :7 2e3
:4 2e4 :4 2e5 :4 2e6 :4 2e7
:8 2e8 :2 2e9 :2 2e8 :3 2e3
:3 2eb :11 2ec :b 2ed :3 2ec
:7 2ef 2f0 195 :d 2f0
313 :2 314 :6 315 :2 316
313 :6 317 :5 318 317
:5 31a 319 :3 317 312
31d :5 31e :3 31d :2 31f
:5 321 :11 322 :24 323 :3 322
:2 320 :6 31f 31c :3 2f0
32e :6 32f :2 330 :2 331
32e :6 332 :5 333 332
:5 335 334 :3 332 32d
338 :5 339 :3 338 :2 33a
:5 33c :11 33d :24 33e :3 33d
:2 33b :6 33a 337 :3 2f0
344 2f0 195 :d 344
:9 345 :3 346 345 :16 348
:3 349 :11 34a :b 34b :3 34a
:5 34d :3 348 :7 350 347
:3 345 :5 353 355 356
357 :2 358 355 :5 359
354 35b :5 35c :3 35b
:2 35d :5 35f :11 360 :24 361
:3 360 :2 35e :6 35d 35a
:3 353 :11 367 :2 368 :7 367
:3 369 :11 36a :b 36b :3 36a
:5 36d 368 :2 367 :3 353
:c 371 :2 372 :2 371 :6 372
:2 371 :12 373 :7 374 :3 375
:3 374 :3 373 :1c 379 :7 37a
:3 37b :3 37a :f 37d :b 37e
:8 381 :3 382 381 :5 383
380 385 :5 386 :3 385
:2 387 :5 389 :11 38a :24 38b
:3 38a :2 388 :6 387 384
:3 372 :9 390 372 :12 392
:7 393 :3 394 :3 393 :3 392
:5 398 :8 399 398 :a 39b
:8 39c 39b :8 39e 39d
:3 39b 39a :3 398 :5 3a2
:8 3a4 3a5 3a6 3a4
:5 3a7 3a3 3a9 :5 3aa
:3 3a9 :2 3ab :5 3ad :11 3ae
:24 3af :3 3ae :2 3ac :6 3ab
3a8 :3 3a2 :f 3b4 :3 3a2
:3 3b9 :3 3ba :9 3bb :5 3bc
:3 3bb :9 3bf :3 3c0 :11 3c1
:b 3c2 :3 3c1 :5 3c4 3bf
3c7 3c8 :2 3c9 3ca
3cb 3cc 3cd :8 3ce
:2 3cf 3c7 :6 3d0 :5 3d1
3d0 :5 3d3 3d2 :3 3d0
3c6 3d6 :5 3d7 :3 3d6
:2 3d8 :5 3da :11 3db :24 3dc
:3 3db :2 3d9 :6 3d8 3d5
:4 3c5 :3 3bf 391 :3 371
344 :3 195 114 :3 78
:8 3e6 :11 3ed :19 3ee :3 3ed
:5 3f0 :2 4b :7 1 
4fa3
4
:3 0 1 :3 0 2
:a 0 16da 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 5d 0 7
8 :3 0 7 :7 0
b a :3 0 8
:3 0 9 :7 0 f
e :3 0 d 8a
0 b 8 :3 0
a :7 0 13 12
:3 0 4 :3 0 5
:3 0 6 :3 0 b
:5 0 1 19 18
:3 0 16 b6 0
f 4 :3 0 5
:3 0 6 :3 0 c
:5 0 1 1f 1e
:3 0 d :3 0 8
:3 0 21 23 0
16da 2 24 :2 0
1a f2 0 18
8 :3 0 27 :7 0
7 :3 0 2b 28
29 16d8 0 e
:6 0 8 :3 0 2d
:7 0 9 :3 0 31
2e 2f 16d8 0
f :6 0 12 :2 0
1e 8 :3 0 33
:7 0 a :3 0 37
34 35 16d8 0
10 :6 0 6 :3 0
12 :2 0 1c 39
3b :6 0 3e 3c
0 16d8 0 11
:6 0 12 :2 0 22
6 :3 0 20 40
42 :6 0 45 43
0 16d8 0 13
:6 0 12 :2 0 26
6 :3 0 24 47
49 :6 0 4c 4a
0 16d8 0 14
:6 0 12 :2 0 2a
6 :3 0 28 4e
50 :6 0 53 51
0 16d8 0 15
:6 0 30 1a2 0
2e 6 :3 0 2c
55 57 :6 0 5a
58 0 16d8 0
16 :6 0 34 1d6
0 32 18 :3 0
5c :7 0 5f 5d
0 16d8 0 17
:6 0 18 :3 0 61
:7 0 64 62 0
16d8 0 19 :6 0
38 20a 0 36
1b :3 0 66 :7 0
69 67 0 16d8
0 1a :6 0 1b
:3 0 6b :7 0 6e
6c 0 16d8 0
1c :6 0 3c 23e
0 3a 18 :3 0
70 :7 0 73 71
0 16d8 0 1d
:6 0 18 :3 0 75
:7 0 78 76 0
16d8 0 1e :6 0
21 :2 0 40 18
:3 0 7a :7 0 7d
7b 0 16d8 0
1f :6 0 6 :3 0
21 :2 0 3e 7f
81 :6 0 84 82
0 16d8 0 20
:6 0 21 :2 0 44
6 :3 0 42 86
88 :6 0 8b 89
0 16d8 0 22
:6 0 25 :2 0 48
6 :3 0 46 8d
8f :6 0 92 90
0 16d8 0 23
:6 0 25 :2 0 4a
8 :3 0 94 :7 0
98 95 96 16d8
0 24 :6 0 25
:2 0 4c 8 :3 0
9a :7 0 9e 9b
9c 16d8 0 26
:6 0 25 :2 0 4e
8 :3 0 a0 :7 0
a4 a1 a2 16d8
0 27 :6 0 25
:2 0 50 8 :3 0
a6 :7 0 aa a7
a8 16d8 0 28
:6 0 25 :2 0 52
8 :3 0 ac :7 0
b0 ad ae 16d8
0 29 :6 0 25
:2 0 54 8 :3 0
b2 :7 0 b6 b3
b4 16d8 0 2a
:6 0 25 :2 0 56
8 :3 0 b8 :7 0
bc b9 ba 16d8
0 2b :6 0 25
:2 0 58 8 :3 0
be :7 0 c2 bf
c0 16d8 0 2c
:6 0 25 :2 0 5a
8 :3 0 c4 :7 0
c8 c5 c6 16d8
0 2d :6 0 25
:2 0 5c 8 :3 0
ca :7 0 ce cb
cc 16d8 0 2e
:6 0 25 :2 0 5e
8 :3 0 d0 :7 0
d4 d1 d2 16d8
0 2f :6 0 25
:2 0 60 8 :3 0
d6 :7 0 da d7
d8 16d8 0 30
:6 0 25 :2 0 62
8 :3 0 dc :7 0
e0 dd de 16d8
0 31 :6 0 25
:2 0 64 8 :3 0
e2 :7 0 e6 e3
e4 16d8 0 32
:6 0 25 :2 0 66
8 :3 0 e8 :7 0
ec e9 ea 16d8
0 33 :6 0 25
:2 0 68 8 :3 0
ee :7 0 f2 ef
f0 16d8 0 34
:6 0 25 :2 0 6a
8 :3 0 f4 :7 0
f8 f5 f6 16d8
0 35 :6 0 25
:2 0 6c 8 :3 0
fa :7 0 fe fb
fc 16d8 0 36
:6 0 25 :2 0 6e
8 :3 0 100 :7 0
104 101 102 16d8
0 37 :6 0 25
:2 0 70 8 :3 0
106 :7 0 10a 107
108 16d8 0 38
:6 0 25 :2 0 72
8 :3 0 10c :7 0
110 10d 10e 16d8
0 39 :6 0 25
:2 0 74 8 :3 0
112 :7 0 116 113
114 16d8 0 3a
:6 0 25 :2 0 76
8 :3 0 118 :7 0
11c 119 11a 16d8
0 3b :6 0 25
:2 0 78 8 :3 0
11e :7 0 122 11f
120 16d8 0 3c
:6 0 25 :2 0 7a
8 :3 0 124 :7 0
128 125 126 16d8
0 3d :6 0 25
:2 0 7c 8 :3 0
12a :7 0 12e 12b
12c 16d8 0 3e
:6 0 25 :2 0 7e
8 :3 0 130 :7 0
134 131 132 16d8
0 3f :6 0 43
:2 0 80 8 :3 0
136 :7 0 13a 137
138 16d8 0 40
:6 0 43 :2 0 84
42 :3 0 82 13c
13e 2 :5 0 44
:3 0 45 :3 0 140
141 0 144 13f
142 16d8 0 41
:6 0 48 :2 0 88
42 :3 0 86 146
148 2 :5 0 44
:3 0 45 :3 0 14a
14b 0 14e 149
14c 16d8 0 46
:6 0 25 :2 0 8c
6 :3 0 8a 150
152 :6 0 155 153
0 16d8 0 47
:6 0 25 :2 0 8e
4a :3 0 157 :7 0
15b 158 159 16d8
0 49 :6 0 25
:2 0 90 4a :3 0
15d :7 0 161 15e
15f 16d8 0 4b
:6 0 25 :2 0 92
4a :3 0 163 :7 0
167 164 165 16d8
0 4c :6 0 25
:2 0 94 4a :3 0
169 :7 0 16d 16a
16b 16d8 0 4d
:6 0 25 :2 0 96
4a :3 0 16f :7 0
173 170 171 16d8
0 4e :6 0 25
:2 0 98 4a :3 0
175 :7 0 179 176
177 16d8 0 4f
:6 0 25 :2 0 9a
4a :3 0 17b :7 0
17f 17c 17d 16d8
0 50 :6 0 25
:2 0 9c 4a :3 0
181 :7 0 185 182
183 16d8 0 51
:6 0 25 :2 0 9e
8 :3 0 187 :7 0
18b 188 189 16d8
0 52 :6 0 25
:2 0 a0 4a :3 0
18d :7 0 191 18e
18f 16d8 0 53
:6 0 25 :2 0 a2
8 :3 0 193 :7 0
197 194 195 16d8
0 54 :6 0 25
:2 0 a4 8 :3 0
199 :7 0 19d 19a
19b 16d8 0 55
:6 0 25 :2 0 a6
8 :3 0 19f :7 0
1a3 1a0 1a1 16d8
0 56 :6 0 25
:2 0 a8 8 :3 0
1a5 :7 0 1a9 1a6
1a7 16d8 0 57
:6 0 1b0 1b1 0
aa 8 :3 0 1ab
:7 0 1af 1ac 1ad
16d8 0 58 :6 0
59 :3 0 5a :3 0
59 :3 0 5b :3 0
1b3 1b4 0 2
:4 0 ac 1b5 1b7
1b2 1b9 1b8 :2 0
5c :3 0 5d :3 0
1bb 1bc 0 5e
:4 0 59 :3 0 5f
:3 0 1bf 1c0 0
2 :4 0 ae 1c1
1c3 60 :4 0 61
:2 0 62 :3 0 b0
1c6 1c8 :3 0 63
:4 0 61 :2 0 64
:4 0 b3 1cb 1cd
:3 0 61 :2 0 3
:3 0 b6 1cf 1d1
:3 0 61 :2 0 64
:4 0 b9 1d3 1d5
:3 0 61 :2 0 65
:4 0 bc 1d7 1d9
:3 0 61 :2 0 66
:3 0 67 :3 0 7
:3 0 bf 1dd 1df
68 :4 0 c1 1dc
1e2 c4 1db 1e4
:3 0 61 :2 0 65
:4 0 c7 1e6 1e8
:3 0 61 :2 0 66
:3 0 67 :3 0 9
:3 0 ca 1ec 1ee
68 :4 0 cc 1eb
1f1 cf 1ea 1f3
:3 0 61 :2 0 65
:4 0 d2 1f5 1f7
:3 0 61 :2 0 66
:3 0 67 :3 0 a
:3 0 d5 1fb 1fd
68 :4 0 d7 1fa
200 da 1f9 202
:3 0 61 :2 0 65
:4 0 dd 204 206
:3 0 61 :2 0 64
:4 0 e0 208 20a
:3 0 61 :2 0 b
:3 0 e3 20c 20e
:3 0 61 :2 0 64
:4 0 e6 210 212
:3 0 61 :2 0 65
:4 0 e9 214 216
:3 0 61 :2 0 64
:4 0 ec 218 21a
:3 0 61 :2 0 c
:3 0 ef 21c 21e
:3 0 61 :2 0 64
:4 0 f2 220 222
:3 0 61 :2 0 69
:4 0 f5 224 226
:3 0 f8 1bd 228
:2 0 22a fd 22b
1ba 22a 0 22c
ff 0 16d6 59
:3 0 5a :3 0 22d
22e 0 59 :3 0
6a :3 0 230 231
0 21 :2 0 2
:4 0 6b :2 0 6c
:2 0 21 :2 0 101
236 238 :3 0 104
232 23a 22f 23c
23b :2 0 5c :3 0
6d :3 0 23e 23f
0 5e :4 0 6e
:4 0 61 :2 0 62
:3 0 108 243 245
:3 0 10b 240 247
:2 0 249 10e 24a
23d 249 0 24b
110 0 16d6 11
:3 0 3 :3 0 24c
24d 0 16d6 6f
:3 0 70 :3 0 71
:3 0 72 :3 0 73
:3 0 74 :3 0 75
:3 0 74 :3 0 76
:3 0 75 :3 0 77
:3 0 78 :3 0 79
:3 0 7a :3 0 7b
:3 0 7c :3 0 7d
:3 0 7e :3 0 7d
:3 0 7e :3 0 7f
:3 0 80 :3 0 81
:3 0 82 :3 0 7f
:3 0 81 :3 0 82
:3 0 80 :3 0 83
:3 0 84 :3 0 85
:3 0 86 :3 0 87
:3 0 88 :3 0 89
:3 0 8a :3 0 8b
:3 0 8c :3 0 8d
:3 0 8e :3 0 8f
:3 0 14 :3 0 16
:3 0 22 :3 0 20
:3 0 1d :3 0 2c
:3 0 3f :3 0 3d
:3 0 29 :3 0 2e
:3 0 13 :3 0 35
:3 0 3a :3 0 38
:3 0 39 :3 0 2b
:3 0 1a :3 0 1c
:3 0 17 :3 0 19
:3 0 27 :3 0 28
:3 0 49 :3 0 4c
:3 0 4b :3 0 4d
:3 0 4e :3 0 50
:3 0 4f :3 0 51
:3 0 2a :3 0 15
:3 0 40 :3 0 90
:3 0 91 :3 0 11
:4 0 92 1 :8 0
2a2 93 :3 0 94
:3 0 29d 29e 0
95 :3 0 29f 2a0
0 2a2 112 2f5
96 :3 0 93 :3 0
94 :3 0 2a4 2a5
0 95 :3 0 2a6
2a7 0 2a9 115
2ab 117 2aa 2a9
:2 0 2f3 97 :3 0
93 :3 0 94 :3 0
2ae 2af 0 95
:3 0 2b0 2b1 0
2eb 59 :3 0 5a
:3 0 2b3 2b4 0
59 :3 0 6a :3 0
2b6 2b7 0 98
:2 0 2 :4 0 99
:2 0 6c :2 0 21
:2 0 119 2bc 2be
:3 0 11c 2b8 2c0
2b5 2c2 2c1 :2 0
5c :3 0 6d :3 0
2c4 2c5 0 5e
:4 0 9a :4 0 61
:2 0 62 :3 0 120
2c9 2cb :3 0 61
:2 0 9b :4 0 123
2cd 2cf :3 0 61
:2 0 9c :4 0 126
2d1 2d3 :3 0 61
:2 0 95 :3 0 129
2d5 2d7 :3 0 61
:2 0 9d :4 0 12c
2d9 2db :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 12f 2de 2e2
133 2dd 2e4 :3 0
136 2c6 2e6 :2 0
2e8 139 2e9 2c3
2e8 0 2ea 13b
0 2eb 13d 2ee
:3 0 2ee 0 2ee
2ed 2eb 2ec :6 0
2f0 2 :3 0 140
2f2 142 2f1 2f0
:2 0 2f3 144 :2 0
2f5 0 2f5 2f4
2a2 2f3 :6 0 16d6
1 :3 0 93 :3 0
94 :3 0 2f7 2f8
0 93 :3 0 a0
:2 0 a1 :3 0 2fa
2fc 0 149 2fb
2fe :3 0 2ff :2 0
6f :3 0 a2 :3 0
a3 :3 0 74 :3 0
8d :3 0 a4 :3 0
a5 :3 0 a6 :3 0
a7 :3 0 14 :3 0
30 :3 0 29 :3 0
2c :3 0 2a :3 0
34 :3 0 2f :3 0
23 :3 0 58 :3 0
a8 :3 0 a9 :3 0
11 :4 0 aa 1
:8 0 31c 93 :3 0
94 :3 0 317 318
0 95 :3 0 319
31a 0 31c 14c
36f 96 :3 0 93
:3 0 94 :3 0 31e
31f 0 95 :3 0
320 321 0 323
14f 325 151 324
323 :2 0 36d 97
:3 0 93 :3 0 94
:3 0 328 329 0
95 :3 0 32a 32b
0 365 59 :3 0
5a :3 0 32d 32e
0 59 :3 0 6a
:3 0 330 331 0
98 :2 0 2 :4 0
ab :2 0 6c :2 0
21 :2 0 153 336
338 :3 0 156 332
33a 32f 33c 33b
:2 0 5c :3 0 6d
:3 0 33e 33f 0
5e :4 0 ac :4 0
61 :2 0 62 :3 0
15a 343 345 :3 0
61 :2 0 9b :4 0
15d 347 349 :3 0
61 :2 0 9c :4 0
160 34b 34d :3 0
61 :2 0 95 :3 0
163 34f 351 :3 0
61 :2 0 9d :4 0
166 353 355 :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 169 358
35c 16d 357 35e
:3 0 170 340 360
:2 0 362 173 363
33d 362 0 364
175 0 365 177
368 :3 0 368 0
368 367 365 366
:6 0 36a 4 :3 0
17a 36c 17c 36b
36a :2 0 36d 17e
:2 0 36f 0 36f
36e 31c 36d :6 0
707 1 :3 0 93
:3 0 94 :3 0 371
372 0 93 :3 0
a0 :2 0 a1 :3 0
374 376 0 183
375 378 :3 0 379
:2 0 c :3 0 11
:3 0 37b 37c 0
3a2 59 :3 0 5a
:3 0 37e 37f 0
59 :3 0 6a :3 0
381 382 0 21
:2 0 2 :4 0 ad
:2 0 6c :2 0 21
:2 0 186 387 389
:3 0 189 383 38b
380 38d 38c :2 0
5c :3 0 6d :3 0
38f 390 0 5e
:4 0 ae :4 0 61
:2 0 62 :3 0 18d
394 396 :3 0 190
391 398 :2 0 39a
193 39b 38e 39a
0 39c 195 0
3a2 d :3 0 44
:3 0 af :3 0 39e
39f 0 3a0 :2 0
3a2 197 3a3 37a
3a2 0 3a4 19b
0 707 82 :3 0
23 :3 0 21 :2 0
21 :2 0 19d 3a5
3a9 a0 :2 0 b0
:4 0 1a3 3ab 3ad
:3 0 c :3 0 11
:3 0 3af 3b0 0
3d6 59 :3 0 5a
:3 0 3b2 3b3 0
59 :3 0 6a :3 0
3b5 3b6 0 21
:2 0 2 :4 0 b1
:2 0 6c :2 0 21
:2 0 1a6 3bb 3bd
:3 0 1a9 3b7 3bf
3b4 3c1 3c0 :2 0
5c :3 0 6d :3 0
3c3 3c4 0 5e
:4 0 b2 :4 0 61
:2 0 62 :3 0 1ad
3c8 3ca :3 0 1b0
3c5 3cc :2 0 3ce
1b3 3cf 3c2 3ce
0 3d0 1b5 0
3d6 d :3 0 44
:3 0 b3 :3 0 3d2
3d3 0 3d4 :2 0
3d6 1b7 3d7 3ae
3d6 0 3d8 1bb
0 707 b4 :3 0
66 :3 0 58 :3 0
25 :2 0 1bd 3da
3dd 44 :3 0 b5
:3 0 3df 3e0 0
1c0 3d9 3e2 3e3
:2 0 44 :3 0 a0
:2 0 b5 :3 0 3e5
3e7 0 1c5 3e6
3e9 :3 0 c :3 0
15 :3 0 3eb 3ec
0 412 59 :3 0
5a :3 0 3ee 3ef
0 59 :3 0 6a
:3 0 3f1 3f2 0
21 :2 0 2 :4 0
b6 :2 0 6c :2 0
21 :2 0 1c8 3f7
3f9 :3 0 1cb 3f3
3fb 3f0 3fd 3fc
:2 0 5c :3 0 6d
:3 0 3ff 400 0
5e :4 0 b7 :4 0
61 :2 0 62 :3 0
1cf 404 406 :3 0
1d2 401 408 :2 0
40a 1d5 40b 3fe
40a 0 40c 1d7
0 412 d :3 0
44 :3 0 b8 :3 0
40e 40f 0 410
:2 0 412 1d9 413
3ea 412 0 414
1dd 0 707 32
:3 0 25 :2 0 415
416 0 707 b9
:3 0 32 :3 0 ba
:3 0 6f :3 0 14
:4 0 bb 1 :8 0
423 93 :3 0 94
:3 0 41e 41f 0
95 :3 0 420 421
0 423 1df 476
96 :3 0 93 :3 0
94 :3 0 425 426
0 95 :3 0 427
428 0 42a 1e2
42c 1e4 42b 42a
:2 0 474 97 :3 0
93 :3 0 94 :3 0
42f 430 0 95
:3 0 431 432 0
46c 59 :3 0 5a
:3 0 434 435 0
59 :3 0 6a :3 0
437 438 0 98
:2 0 2 :4 0 bc
:2 0 6c :2 0 21
:2 0 1e6 43d 43f
:3 0 1e9 439 441
436 443 442 :2 0
5c :3 0 6d :3 0
445 446 0 5e
:4 0 bd :4 0 61
:2 0 62 :3 0 1ed
44a 44c :3 0 61
:2 0 9b :4 0 1f0
44e 450 :3 0 61
:2 0 9c :4 0 1f3
452 454 :3 0 61
:2 0 95 :3 0 1f6
456 458 :3 0 61
:2 0 9d :4 0 1f9
45a 45c :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 1fc 45f 463
200 45e 465 :3 0
203 447 467 :2 0
469 206 46a 444
469 0 46b 208
0 46c 20a 46f
:3 0 46f 0 46f
46e 46c 46d :6 0
471 6 :3 0 20d
473 20f 472 471
:2 0 474 211 :2 0
476 0 476 475
423 474 :6 0 707
1 :3 0 66 :3 0
32 :3 0 25 :2 0
214 478 47b be
:2 0 25 :2 0 219
47d 47f :3 0 a6
:3 0 23 :3 0 a8
:3 0 a9 :3 0 14
:4 0 bf 1 :8 0
48c 93 :3 0 94
:3 0 487 488 0
95 :3 0 489 48a
0 48c 21c 4df
96 :3 0 93 :3 0
94 :3 0 48e 48f
0 95 :3 0 490
491 0 493 21f
495 221 494 493
:2 0 4dd 97 :3 0
93 :3 0 94 :3 0
498 499 0 95
:3 0 49a 49b 0
4d5 59 :3 0 5a
:3 0 49d 49e 0
59 :3 0 6a :3 0
4a0 4a1 0 98
:2 0 2 :4 0 c0
:2 0 6c :2 0 21
:2 0 223 4a6 4a8
:3 0 226 4a2 4aa
49f 4ac 4ab :2 0
5c :3 0 6d :3 0
4ae 4af 0 5e
:4 0 c1 :4 0 61
:2 0 62 :3 0 22a
4b3 4b5 :3 0 61
:2 0 9b :4 0 22d
4b7 4b9 :3 0 61
:2 0 9c :4 0 230
4bb 4bd :3 0 61
:2 0 95 :3 0 233
4bf 4c1 :3 0 61
:2 0 9d :4 0 236
4c3 4c5 :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 239 4c8 4cc
23d 4c7 4ce :3 0
240 4b0 4d0 :2 0
4d2 243 4d3 4ad
4d2 0 4d4 245
0 4d5 247 4d8
:3 0 4d8 0 4d8
4d7 4d5 4d6 :6 0
4da 8 :3 0 24a
4dc 24c 4db 4da
:2 0 4dd 24e :2 0
4df 0 4df 4de
48c 4dd :6 0 516
1 :3 0 c2 :3 0
c3 :3 0 4e1 4e2
0 23 :3 0 c4
:4 0 251 4e3 4e6
a0 :2 0 25 :2 0
256 4e8 4ea :3 0
c :3 0 14 :3 0
4ec 4ed 0 513
59 :3 0 5a :3 0
4ef 4f0 0 59
:3 0 6a :3 0 4f2
4f3 0 21 :2 0
2 :4 0 c5 :2 0
6c :2 0 21 :2 0
259 4f8 4fa :3 0
25c 4f4 4fc 4f1
4fe 4fd :2 0 5c
:3 0 6d :3 0 500
501 0 5e :4 0
c6 :4 0 61 :2 0
62 :3 0 260 505
507 :3 0 263 502
509 :2 0 50b 266
50c 4ff 50b 0
50d 268 0 513
d :3 0 44 :3 0
c7 :3 0 50f 510
0 511 :2 0 513
26a 514 4eb 513
0 515 26e 0
516 270 517 480
516 0 518 273
0 707 32 :3 0
25 :2 0 519 51a
0 707 c8 :3 0
32 :3 0 c9 :3 0
ca :3 0 a9 :3 0
90 :3 0 cb :3 0
cc :3 0 ca :3 0
cb :3 0 6f :3 0
14 :3 0 cb :3 0
8e :3 0 11 :3 0
cb :3 0 91 :3 0
ca :3 0 91 :3 0
ca :3 0 91 :3 0
ca :3 0 a9 :3 0
ca :3 0 cd :3 0
44 :3 0 ce :4 0
cf 1 :8 0 53d
93 :3 0 94 :3 0
538 539 0 95
:3 0 53a 53b 0
53d 275 590 96
:3 0 93 :3 0 94
:3 0 53f 540 0
95 :3 0 541 542
0 544 278 546
27a 545 544 :2 0
58e 97 :3 0 93
:3 0 94 :3 0 549
54a 0 95 :3 0
54b 54c 0 586
59 :3 0 5a :3 0
54e 54f 0 59
:3 0 6a :3 0 551
552 0 98 :2 0
2 :4 0 d0 :2 0
6c :2 0 21 :2 0
27c 557 559 :3 0
27f 553 55b 550
55d 55c :2 0 5c
:3 0 6d :3 0 55f
560 0 5e :4 0
d1 :4 0 61 :2 0
62 :3 0 283 564
566 :3 0 61 :2 0
9b :4 0 286 568
56a :3 0 61 :2 0
9c :4 0 289 56c
56e :3 0 61 :2 0
95 :3 0 28c 570
572 :3 0 61 :2 0
9d :4 0 28f 574
576 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
292 579 57d 296
578 57f :3 0 299
561 581 :2 0 583
29c 584 55e 583
0 585 29e 0
586 2a0 589 :3 0
589 0 589 588
586 587 :6 0 58b
a :3 0 2a3 58d
2a5 58c 58b :2 0
58e 2a7 :2 0 590
0 590 58f 53d
58e :6 0 707 1
:3 0 66 :3 0 32
:3 0 25 :2 0 2aa
592 595 be :2 0
25 :2 0 2af 597
599 :3 0 c :3 0
11 :3 0 59b 59c
0 5c2 59 :3 0
5a :3 0 59e 59f
0 59 :3 0 6a
:3 0 5a1 5a2 0
21 :2 0 2 :4 0
d2 :2 0 6c :2 0
21 :2 0 2b2 5a7
5a9 :3 0 2b5 5a3
5ab 5a0 5ad 5ac
:2 0 5c :3 0 6d
:3 0 5af 5b0 0
5e :4 0 d3 :4 0
61 :2 0 62 :3 0
2b9 5b4 5b6 :3 0
2bc 5b1 5b8 :2 0
5ba 2bf 5bb 5ae
5ba 0 5bc 2c1
0 5c2 d :3 0
44 :3 0 b8 :3 0
5be 5bf 0 5c0
:2 0 5c2 2c3 5c3
59a 5c2 0 5c4
2c7 0 707 66
:3 0 29 :3 0 25
:2 0 2c9 5c5 5c8
a0 :2 0 25 :2 0
2ce 5ca 5cc :3 0
59 :3 0 5a :3 0
5ce 5cf 0 59
:3 0 6a :3 0 5d1
5d2 0 d4 :2 0
2 :4 0 d5 :2 0
6c :2 0 21 :2 0
2d1 5d7 5d9 :3 0
2d4 5d3 5db 5d0
5dd 5dc :2 0 5c
:3 0 6d :3 0 5df
5e0 0 5e :4 0
d6 :4 0 61 :2 0
62 :3 0 2d8 5e4
5e6 :3 0 61 :2 0
9b :4 0 2db 5e8
5ea :3 0 61 :2 0
d7 :4 0 2de 5ec
5ee :3 0 61 :2 0
66 :3 0 67 :3 0
44 :3 0 d8 :3 0
5f3 5f4 0 2e1
5f2 5f6 68 :4 0
2e3 5f1 5f9 2e6
5f0 5fb :3 0 2e9
5e1 5fd :2 0 5ff
2ec 600 5de 5ff
0 601 2ee 0
62d 59 :3 0 5a
:3 0 602 603 0
59 :3 0 6a :3 0
605 606 0 21
:2 0 2 :4 0 d9
:2 0 6c :2 0 21
:2 0 2f0 60b 60d
:3 0 2f3 607 60f
604 611 610 :2 0
5c :3 0 6d :3 0
613 614 0 5e
:4 0 da :4 0 61
:2 0 62 :3 0 2f7
618 61a :3 0 2fa
615 61c :2 0 61e
2fd 61f 612 61e
0 620 2ff 0
62d d :3 0 db
:3 0 dc :3 0 622
623 0 44 :3 0
d8 :3 0 625 626
0 dd :3 0 301
624 629 62a :2 0
62d de :3 0 304
704 66 :3 0 f
:3 0 25 :2 0 308
62e 631 66 :3 0
df :2 0 2c :3 0
25 :2 0 30b 633
637 310 634 639
:3 0 3e :3 0 25
:2 0 63b 63c 0
6a3 66 :3 0 f
:3 0 25 :2 0 313
63e 641 66 :3 0
be :2 0 29 :3 0
25 :2 0 316 643
647 31b 644 649
:3 0 c :3 0 11
:3 0 64b 64c 0
673 59 :3 0 5a
:3 0 64e 64f 0
59 :3 0 6a :3 0
651 652 0 21
:2 0 2 :4 0 e0
:2 0 6c :2 0 21
:2 0 31e 657 659
:3 0 321 653 65b
650 65d 65c :2 0
5c :3 0 6d :3 0
65f 660 0 5e
:4 0 e1 :4 0 61
:2 0 62 :3 0 325
664 666 :3 0 328
661 668 :2 0 66a
32b 66b 65e 66a
0 66c 32d 0
673 d :3 0 44
:3 0 e2 :3 0 66e
66f 0 670 :2 0
673 de :3 0 32f
686 66 :3 0 f
:3 0 25 :2 0 333
674 677 66 :3 0
a0 :2 0 29 :3 0
25 :2 0 336 679
67d 33b 67a 67f
:3 0 3e :3 0 21
:2 0 681 682 0
684 33e 685 680
684 0 687 64a
673 0 687 340
0 6a3 2d :3 0
f :3 0 688 689
0 6a3 32 :3 0
e3 :3 0 14 :3 0
11 :3 0 2d :3 0
b :3 0 66 :3 0
3e :3 0 25 :2 0
343 691 694 66
:3 0 2f :3 0 25
:2 0 346 696 699
66 :3 0 30 :3 0
25 :2 0 349 69b
69e 34c 68c 6a0
68b 6a1 0 6a3
354 6a4 63a 6a3
0 706 59 :3 0
5a :3 0 6a5 6a6
0 59 :3 0 6a
:3 0 6a8 6a9 0
d4 :2 0 2 :4 0
e4 :2 0 6c :2 0
21 :2 0 359 6ae
6b0 :3 0 35c 6aa
6b2 6a7 6b4 6b3
:2 0 5c :3 0 6d
:3 0 6b6 6b7 0
5e :4 0 e5 :4 0
61 :2 0 62 :3 0
360 6bb 6bd :3 0
61 :2 0 9b :4 0
363 6bf 6c1 :3 0
61 :2 0 d7 :4 0
366 6c3 6c5 :3 0
61 :2 0 66 :3 0
67 :3 0 44 :3 0
d8 :3 0 6ca 6cb
0 369 6c9 6cd
68 :4 0 36b 6c8
6d0 36e 6c7 6d2
:3 0 371 6b8 6d4
:2 0 6d6 374 6d7
6b5 6d6 0 6d8
376 0 703 59
:3 0 5a :3 0 6d9
6da 0 59 :3 0
6a :3 0 6dc 6dd
0 21 :2 0 2
:4 0 e6 :2 0 6c
:2 0 21 :2 0 378
6e2 6e4 :3 0 37b
6de 6e6 6db 6e8
6e7 :2 0 5c :3 0
6d :3 0 6ea 6eb
0 5e :4 0 e7
:4 0 61 :2 0 62
:3 0 37f 6ef 6f1
:3 0 382 6ec 6f3
:2 0 6f5 385 6f6
6e9 6f5 0 6f7
387 0 703 d
:3 0 db :3 0 dc
:3 0 6f9 6fa 0
44 :3 0 d8 :3 0
6fc 6fd 0 dd
:3 0 389 6fb 700
701 :2 0 703 38c
705 5cd 62d 0
706 0 703 0
706 390 0 707
394 1699 66 :3 0
29 :3 0 25 :2 0
3a0 708 70b a0
:2 0 25 :2 0 3a5
70d 70f :3 0 c
:3 0 11 :3 0 711
712 0 738 59
:3 0 5a :3 0 714
715 0 59 :3 0
6a :3 0 717 718
0 21 :2 0 2
:4 0 e8 :2 0 6c
:2 0 21 :2 0 3a8
71d 71f :3 0 3ab
719 721 716 723
722 :2 0 5c :3 0
6d :3 0 725 726
0 5e :4 0 e9
:4 0 61 :2 0 62
:3 0 3af 72a 72c
:3 0 3b2 727 72e
:2 0 730 3b5 731
724 730 0 732
3b7 0 738 d
:3 0 44 :3 0 d8
:3 0 734 735 0
736 :2 0 738 3b9
739 710 738 0
73a 3bd 0 1698
32 :3 0 25 :2 0
73b 73c 0 1698
b9 :3 0 32 :3 0
ba :3 0 6f :3 0
14 :4 0 bb 1
:8 0 749 93 :3 0
94 :3 0 744 745
0 95 :3 0 746
747 0 749 3bf
79c 96 :3 0 93
:3 0 94 :3 0 74b
74c 0 95 :3 0
74d 74e 0 750
3c2 752 3c4 751
750 :2 0 79a 97
:3 0 93 :3 0 94
:3 0 755 756 0
95 :3 0 757 758
0 792 59 :3 0
5a :3 0 75a 75b
0 59 :3 0 6a
:3 0 75d 75e 0
98 :2 0 2 :4 0
ea :2 0 6c :2 0
21 :2 0 3c6 763
765 :3 0 3c9 75f
767 75c 769 768
:2 0 5c :3 0 6d
:3 0 76b 76c 0
5e :4 0 eb :4 0
61 :2 0 62 :3 0
3cd 770 772 :3 0
61 :2 0 9b :4 0
3d0 774 776 :3 0
61 :2 0 9c :4 0
3d3 778 77a :3 0
61 :2 0 95 :3 0
3d6 77c 77e :3 0
61 :2 0 9d :4 0
3d9 780 782 :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 3dc 785
789 3e0 784 78b
:3 0 3e3 76d 78d
:2 0 78f 3e6 790
76a 78f 0 791
3e8 0 792 3ea
795 :3 0 795 0
795 794 792 793
:6 0 797 c :3 0
3ed 799 3ef 798
797 :2 0 79a 3f1
:2 0 79c 0 79c
79b 749 79a :6 0
1698 1 :3 0 66
:3 0 32 :3 0 25
:2 0 3f4 79e 7a1
be :2 0 25 :2 0
3f9 7a3 7a5 :3 0
a6 :3 0 23 :3 0
a8 :3 0 a9 :3 0
14 :4 0 bf 1
:8 0 7b2 93 :3 0
94 :3 0 7ad 7ae
0 95 :3 0 7af
7b0 0 7b2 3fc
805 96 :3 0 93
:3 0 94 :3 0 7b4
7b5 0 95 :3 0
7b6 7b7 0 7b9
3ff 7bb 401 7ba
7b9 :2 0 803 97
:3 0 93 :3 0 94
:3 0 7be 7bf 0
95 :3 0 7c0 7c1
0 7fb 59 :3 0
5a :3 0 7c3 7c4
0 59 :3 0 6a
:3 0 7c6 7c7 0
98 :2 0 2 :4 0
ec :2 0 6c :2 0
21 :2 0 403 7cc
7ce :3 0 406 7c8
7d0 7c5 7d2 7d1
:2 0 5c :3 0 6d
:3 0 7d4 7d5 0
5e :4 0 ed :4 0
61 :2 0 62 :3 0
40a 7d9 7db :3 0
61 :2 0 9b :4 0
40d 7dd 7df :3 0
61 :2 0 9c :4 0
410 7e1 7e3 :3 0
61 :2 0 95 :3 0
413 7e5 7e7 :3 0
61 :2 0 9d :4 0
416 7e9 7eb :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 419 7ee
7f2 41d 7ed 7f4
:3 0 420 7d6 7f6
:2 0 7f8 423 7f9
7d3 7f8 0 7fa
425 0 7fb 427
7fe :3 0 7fe 0
7fe 7fd 7fb 7fc
:6 0 800 e :3 0
42a 802 42c 801
800 :2 0 803 42e
:2 0 805 0 805
804 7b2 803 :6 0
83c 1 :3 0 c2
:3 0 c3 :3 0 807
808 0 23 :3 0
c4 :4 0 431 809
80c a0 :2 0 25
:2 0 436 80e 810
:3 0 c :3 0 14
:3 0 812 813 0
839 59 :3 0 5a
:3 0 815 816 0
59 :3 0 6a :3 0
818 819 0 21
:2 0 2 :4 0 ee
:2 0 6c :2 0 21
:2 0 439 81e 820
:3 0 43c 81a 822
817 824 823 :2 0
5c :3 0 6d :3 0
826 827 0 5e
:4 0 ef :4 0 61
:2 0 62 :3 0 440
82b 82d :3 0 443
828 82f :2 0 831
446 832 825 831
0 833 448 0
839 d :3 0 44
:3 0 c7 :3 0 835
836 0 837 :2 0
839 44a 83a 811
839 0 83b 44e
0 83c 450 83d
7a6 83c 0 83e
453 0 1698 a5
:3 0 a2 :3 0 a6
:3 0 a7 :3 0 2f
:3 0 30 :3 0 23
:3 0 58 :3 0 a8
:3 0 6f :3 0 14
:3 0 a9 :3 0 15
:4 0 f0 1 :8 0
852 93 :3 0 94
:3 0 84d 84e 0
95 :3 0 84f 850
0 852 455 8a5
96 :3 0 93 :3 0
94 :3 0 854 855
0 95 :3 0 856
857 0 859 458
85b 45a 85a 859
:2 0 8a3 97 :3 0
93 :3 0 94 :3 0
85e 85f 0 95
:3 0 860 861 0
89b 59 :3 0 5a
:3 0 863 864 0
59 :3 0 6a :3 0
866 867 0 98
:2 0 2 :4 0 f1
:2 0 6c :2 0 21
:2 0 45c 86c 86e
:3 0 45f 868 870
865 872 871 :2 0
5c :3 0 6d :3 0
874 875 0 5e
:4 0 f2 :4 0 61
:2 0 62 :3 0 463
879 87b :3 0 61
:2 0 9b :4 0 466
87d 87f :3 0 61
:2 0 9c :4 0 469
881 883 :3 0 61
:2 0 95 :3 0 46c
885 887 :3 0 61
:2 0 9d :4 0 46f
889 88b :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 472 88e 892
476 88d 894 :3 0
479 876 896 :2 0
898 47c 899 873
898 0 89a 47e
0 89b 480 89e
:3 0 89e 0 89e
89d 89b 89c :6 0
8a0 10 :3 0 483
8a2 485 8a1 8a0
:2 0 8a3 487 :2 0
8a5 0 8a5 8a4
852 8a3 :6 0 1698
1 :3 0 82 :3 0
23 :3 0 21 :2 0
21 :2 0 48a 8a7
8ab a0 :2 0 b0
:4 0 490 8ad 8af
:3 0 c :3 0 11
:3 0 8b1 8b2 0
8d8 59 :3 0 5a
:3 0 8b4 8b5 0
59 :3 0 6a :3 0
8b7 8b8 0 21
:2 0 2 :4 0 f3
:2 0 6c :2 0 21
:2 0 493 8bd 8bf
:3 0 496 8b9 8c1
8b6 8c3 8c2 :2 0
5c :3 0 6d :3 0
8c5 8c6 0 5e
:4 0 f4 :4 0 61
:2 0 62 :3 0 49a
8ca 8cc :3 0 49d
8c7 8ce :2 0 8d0
4a0 8d1 8c4 8d0
0 8d2 4a2 0
8d8 d :3 0 44
:3 0 b3 :3 0 8d4
8d5 0 8d6 :2 0
8d8 4a4 8d9 8b0
8d8 0 8da 4a8
0 1698 b4 :3 0
66 :3 0 58 :3 0
25 :2 0 4aa 8dc
8df 44 :3 0 b5
:3 0 8e1 8e2 0
4ad 8db 8e4 8e5
:2 0 44 :3 0 a0
:2 0 b5 :3 0 8e7
8e9 0 4b2 8e8
8eb :3 0 c :3 0
15 :3 0 8ed 8ee
0 914 59 :3 0
5a :3 0 8f0 8f1
0 59 :3 0 6a
:3 0 8f3 8f4 0
21 :2 0 2 :4 0
f5 :2 0 6c :2 0
21 :2 0 4b5 8f9
8fb :3 0 4b8 8f5
8fd 8f2 8ff 8fe
:2 0 5c :3 0 6d
:3 0 901 902 0
5e :4 0 f6 :4 0
61 :2 0 62 :3 0
4bc 906 908 :3 0
4bf 903 90a :2 0
90c 4c2 90d 900
90c 0 90e 4c4
0 914 d :3 0
44 :3 0 b8 :3 0
910 911 0 912
:2 0 914 4c6 915
8ec 914 0 916
4ca 0 1698 32
:3 0 25 :2 0 917
918 0 1698 c8
:3 0 32 :3 0 c9
:3 0 a9 :3 0 cc
:3 0 91 :3 0 11
:3 0 91 :3 0 a9
:3 0 cd :3 0 44
:3 0 ce :4 0 f7
1 :8 0 92c 93
:3 0 94 :3 0 927
928 0 95 :3 0
929 92a 0 92c
4cc 97f 96 :3 0
93 :3 0 94 :3 0
92e 92f 0 95
:3 0 930 931 0
933 4cf 935 4d1
934 933 :2 0 97d
97 :3 0 93 :3 0
94 :3 0 938 939
0 95 :3 0 93a
93b 0 975 59
:3 0 5a :3 0 93d
93e 0 59 :3 0
6a :3 0 940 941
0 98 :2 0 2
:4 0 f8 :2 0 6c
:2 0 21 :2 0 4d3
946 948 :3 0 4d6
942 94a 93f 94c
94b :2 0 5c :3 0
6d :3 0 94e 94f
0 5e :4 0 f9
:4 0 61 :2 0 62
:3 0 4da 953 955
:3 0 61 :2 0 9b
:4 0 4dd 957 959
:3 0 61 :2 0 9c
:4 0 4e0 95b 95d
:3 0 61 :2 0 95
:3 0 4e3 95f 961
:3 0 61 :2 0 9d
:4 0 4e6 963 965
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 4e9
968 96c 4ed 967
96e :3 0 4f0 950
970 :2 0 972 4f3
973 94d 972 0
974 4f5 0 975
4f7 978 :3 0 978
0 978 977 975
976 :6 0 97a 12
:3 0 4fa 97c 4fc
97b 97a :2 0 97d
4fe :2 0 97f 0
97f 97e 92c 97d
:6 0 1698 1 :3 0
66 :3 0 32 :3 0
25 :2 0 501 981
984 be :2 0 25
:2 0 506 986 988
:3 0 c :3 0 11
:3 0 98a 98b 0
9b1 59 :3 0 5a
:3 0 98d 98e 0
59 :3 0 6a :3 0
990 991 0 21
:2 0 2 :4 0 fa
:2 0 6c :2 0 21
:2 0 509 996 998
:3 0 50c 992 99a
98f 99c 99b :2 0
5c :3 0 6d :3 0
99e 99f 0 5e
:4 0 fb :4 0 61
:2 0 62 :3 0 510
9a3 9a5 :3 0 513
9a0 9a7 :2 0 9a9
516 9aa 99d 9a9
0 9ab 518 0
9b1 d :3 0 44
:3 0 b8 :3 0 9ad
9ae 0 9af :2 0
9b1 51a 9b2 989
9b1 0 9b3 51e
0 1698 66 :3 0
f :3 0 25 :2 0
520 9b4 9b7 be
:2 0 25 :2 0 525
9b9 9bb :3 0 9bc
:2 0 66 :3 0 e
:3 0 25 :2 0 528
9be 9c1 a0 :2 0
25 :2 0 52d 9c3
9c5 :3 0 9c6 :2 0
9bd 9c8 9c7 :2 0
e :3 0 fc :3 0
66 :3 0 f :3 0
25 :2 0 530 9cc
9cf fd :2 0 fe
:2 0 533 9d1 9d3
:3 0 9d4 :2 0 ff
:2 0 66 :3 0 29
:3 0 25 :2 0 536
9d7 9da 539 9d6
9dc :3 0 53c 9cb
9de 9ca 9df 0
9e1 53e 9e2 9c9
9e1 0 9e3 540
0 1698 3b :3 0
66 :3 0 29 :3 0
25 :2 0 542 9e5
9e8 9e4 9e9 0
1698 66 :3 0 f
:3 0 25 :2 0 545
9eb 9ee 66 :3 0
df :2 0 2c :3 0
25 :2 0 548 9f0
9f4 54d 9f1 9f6
:3 0 2d :3 0 f
:3 0 9f8 9f9 0
11fd 66 :3 0 2d
:3 0 25 :2 0 550
9fb 9fe 66 :3 0
be :2 0 29 :3 0
25 :2 0 553 a00
a04 558 a01 a06
:3 0 66 :3 0 30
:3 0 25 :2 0 55b
a08 a0b 44 :3 0
a0 :2 0 100 :3 0
a0d a0f 0 560
a0e a11 :3 0 66
:3 0 30 :3 0 25
:2 0 563 a13 a16
44 :3 0 a0 :2 0
101 :3 0 a18 a1a
0 568 a19 a1c
:3 0 a12 a1e a1d
:2 0 1f :4 0 a20
a21 0 be8 c8
:3 0 102 :3 0 103
:3 0 102 :3 0 26
:3 0 1f :3 0 104
:3 0 6f :3 0 14
:3 0 91 :3 0 11
:3 0 105 :4 0 106
1 :8 0 a35 93
:3 0 94 :3 0 a30
a31 0 95 :3 0
a32 a33 0 a35
56b a88 96 :3 0
93 :3 0 94 :3 0
a37 a38 0 95
:3 0 a39 a3a 0
a3c 56e a3e 570
a3d a3c :2 0 a86
97 :3 0 93 :3 0
94 :3 0 a41 a42
0 95 :3 0 a43
a44 0 a7e 59
:3 0 5a :3 0 a46
a47 0 59 :3 0
6a :3 0 a49 a4a
0 98 :2 0 2
:4 0 107 :2 0 6c
:2 0 21 :2 0 572
a4f a51 :3 0 575
a4b a53 a48 a55
a54 :2 0 5c :3 0
6d :3 0 a57 a58
0 5e :4 0 108
:4 0 61 :2 0 62
:3 0 579 a5c a5e
:3 0 61 :2 0 9b
:4 0 57c a60 a62
:3 0 61 :2 0 9c
:4 0 57f a64 a66
:3 0 61 :2 0 95
:3 0 582 a68 a6a
:3 0 61 :2 0 9d
:4 0 585 a6c a6e
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 588
a71 a75 58c a70
a77 :3 0 58f a59
a79 :2 0 a7b 592
a7c a56 a7b 0
a7d 594 0 a7e
596 a81 :3 0 a81
0 a81 a80 a7e
a7f :6 0 a83 14
:3 0 599 a85 59b
a84 a83 :2 0 a86
59d :2 0 a88 0
a88 a87 a35 a86
:6 0 be8 1 :3 0
1f :3 0 109 :2 0
5a0 a8b a8c :3 0
a8d :2 0 1a :3 0
1f :3 0 a8f a90
0 a92 5a2 a93
a8e a92 0 a94
5a4 0 be8 66
:3 0 26 :3 0 25
:2 0 5a6 a95 a98
be :2 0 25 :2 0
5ab a9a a9c :3 0
66 :3 0 2e :3 0
25 :2 0 5ae a9e
aa1 be :2 0 25
:2 0 5b3 aa3 aa5
:3 0 aa6 :2 0 1d
:3 0 109 :2 0 5b6
aa9 aaa :3 0 aab
:2 0 aac :2 0 aa7
aae aad :2 0 10a
:3 0 10b :3 0 33
:3 0 104 :3 0 6f
:3 0 14 :3 0 91
:3 0 11 :3 0 102
:3 0 81 :3 0 82
:3 0 1d :4 0 10c
1 :8 0 ac2 93
:3 0 94 :3 0 abd
abe 0 95 :3 0
abf ac0 0 ac2
5b8 b15 96 :3 0
93 :3 0 94 :3 0
ac4 ac5 0 95
:3 0 ac6 ac7 0
ac9 5bb acb 5bd
aca ac9 :2 0 b13
97 :3 0 93 :3 0
94 :3 0 ace acf
0 95 :3 0 ad0
ad1 0 b0b 59
:3 0 5a :3 0 ad3
ad4 0 59 :3 0
6a :3 0 ad6 ad7
0 98 :2 0 2
:4 0 10d :2 0 6c
:2 0 21 :2 0 5bf
adc ade :3 0 5c2
ad8 ae0 ad5 ae2
ae1 :2 0 5c :3 0
6d :3 0 ae4 ae5
0 5e :4 0 10e
:4 0 61 :2 0 62
:3 0 5c6 ae9 aeb
:3 0 61 :2 0 9b
:4 0 5c9 aed aef
:3 0 61 :2 0 9c
:4 0 5cc af1 af3
:3 0 61 :2 0 95
:3 0 5cf af5 af7
:3 0 61 :2 0 9d
:4 0 5d2 af9 afb
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 5d5
afe b02 5d9 afd
b04 :3 0 5dc ae6
b06 :2 0 b08 5df
b09 ae3 b08 0
b0a 5e1 0 b0b
5e3 b0e :3 0 b0e
0 b0e b0d b0b
b0c :6 0 b10 16
:3 0 5e6 b12 5e8
b11 b10 :2 0 b13
5ea :2 0 b15 0
b15 b14 ac2 b13
:6 0 b31 1 :3 0
29 :3 0 66 :3 0
2d :3 0 25 :2 0
5ed b18 b1b 10f
:2 0 66 :3 0 2c
:3 0 25 :2 0 5f0
b1e b21 5f3 b1d
b23 :3 0 10f :2 0
66 :3 0 33 :3 0
25 :2 0 5f6 b26
b29 5f9 b25 b2b
:3 0 b17 b2c 0
b31 2a :3 0 fe
:2 0 b2e b2f 0
b31 5fc b32 aaf
b31 0 b33 600
0 be5 33 :3 0
fc :3 0 66 :3 0
110 :3 0 29 :3 0
602 b37 b39 25
:2 0 604 b36 b3c
ff :2 0 66 :3 0
110 :3 0 26 :3 0
607 b40 b42 25
:2 0 609 b3f b45
60c b3e b47 :3 0
b48 :2 0 6c :2 0
111 :2 0 60f b4a
b4c :3 0 612 b35
b4e b34 b4f 0
be5 32 :3 0 66
:3 0 33 :3 0 25
:2 0 614 b52 b55
fd :2 0 66 :3 0
26 :3 0 25 :2 0
617 b58 b5b 61a
b57 b5d :3 0 b51
b5e 0 be5 66
:3 0 32 :3 0 25
:2 0 61d b60 b63
66 :3 0 df :2 0
29 :3 0 25 :2 0
620 b65 b69 625
b66 b6b :3 0 24
:3 0 66 :3 0 33
:3 0 25 :2 0 628
b6e b71 6c :2 0
66 :3 0 29 :3 0
25 :2 0 62b b74
b77 62e b73 b79
:3 0 10f :2 0 66
:3 0 32 :3 0 25
:2 0 631 b7c b7f
634 b7b b81 :3 0
b6d b82 0 b84
637 b8d 24 :3 0
66 :3 0 33 :3 0
25 :2 0 639 b86
b89 b85 b8a 0
b8c 63c b8e b6c
b84 0 b8f 0
b8c 0 b8f 63e
0 be5 32 :3 0
112 :3 0 14 :3 0
13 :3 0 11 :3 0
1a :3 0 1c :3 0
24 :3 0 33 :3 0
25 :2 0 641 b91
b9a b90 b9b 0
be5 2b :3 0 fc
:3 0 66 :3 0 110
:3 0 33 :3 0 64a
ba0 ba2 25 :2 0
64c b9f ba5 ff
:2 0 66 :3 0 110
:3 0 2f :3 0 64f
ba9 bab 25 :2 0
651 ba8 bae 654
ba7 bb0 :3 0 bb1
:2 0 fd :2 0 113
:2 0 657 bb3 bb5
:3 0 65a b9e bb7
b9d bb8 0 be5
32 :3 0 114 :3 0
115 :3 0 bbb bbc
0 66 :3 0 2b
:3 0 25 :2 0 65c
bbe bc1 44 :3 0
116 :3 0 bc3 bc4
0 65f bbd bc6
bba bc7 0 be5
32 :3 0 117 :3 0
14 :3 0 11 :3 0
32 :3 0 66 :3 0
2f :3 0 25 :2 0
662 bce bd1 66
:3 0 2b :3 0 25
:2 0 665 bd3 bd6
25 :2 0 668 bca
bd9 bc9 bda 0
be5 32 :3 0 118
:3 0 14 :3 0 15
:3 0 11 :3 0 25
:2 0 66f bdd be2
bdc be3 0 be5
674 be6 a9d be5
0 be7 67e 0
be8 680 1180 66
:3 0 3f :3 0 25
:2 0 685 be9 bec
66 :3 0 df :2 0
3d :3 0 25 :2 0
688 bee bf2 68d
bef bf4 :3 0 c2
:3 0 c3 :3 0 bf6
bf7 0 16 :3 0
b :3 0 690 bf8
bfb a0 :2 0 25
:2 0 695 bfd bff
:3 0 29 :3 0 66
:3 0 2d :3 0 25
:2 0 698 c02 c05
10f :2 0 66 :3 0
29 :3 0 25 :2 0
69b c08 c0b 69e
c07 c0d :3 0 c01
c0e 0 d4c 2a
:3 0 fe :2 0 c10
c11 0 d4c 66
:3 0 2d :3 0 25
:2 0 6a1 c13 c16
119 :2 0 66 :3 0
2c :3 0 25 :2 0
6a4 c19 c1c 6c
:2 0 66 :3 0 3d
:3 0 25 :2 0 6a7
c1f c22 6aa c1e
c24 :3 0 c25 :2 0
6af c18 c27 :3 0
3d :3 0 66 :3 0
2c :3 0 25 :2 0
6b2 c2a c2d 6c
:2 0 66 :3 0 3d
:3 0 25 :2 0 6b5
c30 c33 6b8 c2f
c35 :3 0 c36 :2 0
10f :2 0 66 :3 0
2d :3 0 25 :2 0
6bb c39 c3c 6be
c38 c3e :3 0 c29
c3f 0 ccc 90
:3 0 11a :3 0 8f
:3 0 11b :3 0 115
:3 0 8f :3 0 44
:3 0 11c :3 0 75
:3 0 2d :3 0 74
:3 0 2d :3 0 76
:3 0 3d :3 0 8d
:3 0 91 :3 0 11
:4 0 11d 1 :8 0
c68 11e :4 0 c53
:3 0 11f :3 0 a0
:2 0 6c3 c56 c57
:3 0 93 :3 0 94
:3 0 c59 c5a 0
25 :2 0 c5b c5c
0 c5e 6c6 c65
93 :3 0 94 :3 0
c5f c60 0 120
:2 0 c61 c62 0
c64 6c8 c66 c58
c5e 0 c67 0
c64 0 c67 6ca
0 c68 6cd cbb
96 :3 0 93 :3 0
94 :3 0 c6a c6b
0 95 :3 0 c6c
c6d 0 c6f 6d0
c71 6d2 c70 c6f
:2 0 cb9 97 :3 0
93 :3 0 94 :3 0
c74 c75 0 95
:3 0 c76 c77 0
cb1 59 :3 0 5a
:3 0 c79 c7a 0
59 :3 0 6a :3 0
c7c c7d 0 98
:2 0 2 :4 0 121
:2 0 6c :2 0 21
:2 0 6d4 c82 c84
:3 0 6d7 c7e c86
c7b c88 c87 :2 0
5c :3 0 6d :3 0
c8a c8b 0 5e
:4 0 122 :4 0 61
:2 0 62 :3 0 6db
c8f c91 :3 0 61
:2 0 9b :4 0 6de
c93 c95 :3 0 61
:2 0 9c :4 0 6e1
c97 c99 :3 0 61
:2 0 95 :3 0 6e4
c9b c9d :3 0 61
:2 0 9d :4 0 6e7
c9f ca1 :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 6ea ca4 ca8
6ee ca3 caa :3 0
6f1 c8c cac :2 0
cae 6f4 caf c89
cae 0 cb0 6f6
0 cb1 6f8 cb4
:3 0 cb4 0 cb4
cb3 cb1 cb2 :6 0
cb6 18 :3 0 6fb
cb8 6fd cb7 cb6
:2 0 cb9 6ff :2 0
cbb 0 cbb cba
c68 cb9 :6 0 ccc
1 :3 0 2a :3 0
114 :3 0 115 :3 0
cbe cbf 0 66
:3 0 2a :3 0 25
:2 0 702 cc1 cc4
44 :3 0 116 :3 0
cc6 cc7 0 705
cc0 cc9 cbd cca
0 ccc 708 d49
90 :3 0 11a :3 0
8f :3 0 11b :3 0
115 :3 0 8f :3 0
44 :3 0 11c :3 0
75 :3 0 2d :3 0
74 :3 0 2d :3 0
76 :3 0 8d :3 0
91 :3 0 11 :4 0
123 1 :8 0 cf3
11e :4 0 cde :3 0
11f :3 0 a0 :2 0
70e ce1 ce2 :3 0
93 :3 0 94 :3 0
ce4 ce5 0 25
:2 0 ce6 ce7 0
ce9 711 cf0 93
:3 0 94 :3 0 cea
ceb 0 120 :2 0
cec ced 0 cef
713 cf1 ce3 ce9
0 cf2 0 cef
0 cf2 715 0
cf3 718 d46 96
:3 0 93 :3 0 94
:3 0 cf5 cf6 0
95 :3 0 cf7 cf8
0 cfa 71b cfc
71d cfb cfa :2 0
d44 97 :3 0 93
:3 0 94 :3 0 cff
d00 0 95 :3 0
d01 d02 0 d3c
59 :3 0 5a :3 0
d04 d05 0 59
:3 0 6a :3 0 d07
d08 0 98 :2 0
2 :4 0 124 :2 0
6c :2 0 21 :2 0
71f d0d d0f :3 0
722 d09 d11 d06
d13 d12 :2 0 5c
:3 0 6d :3 0 d15
d16 0 5e :4 0
125 :4 0 61 :2 0
62 :3 0 726 d1a
d1c :3 0 61 :2 0
9b :4 0 729 d1e
d20 :3 0 61 :2 0
9c :4 0 72c d22
d24 :3 0 61 :2 0
95 :3 0 72f d26
d28 :3 0 61 :2 0
9d :4 0 732 d2a
d2c :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
735 d2f d33 739
d2e d35 :3 0 73c
d17 d37 :2 0 d39
73f d3a d14 d39
0 d3b 741 0
d3c 743 d3f :3 0
d3f 0 d3f d3e
d3c d3d :6 0 d41
1a :3 0 746 d43
748 d42 d41 :2 0
d44 74a :2 0 d46
0 d46 d45 cf3
d44 :6 0 d48 1
:3 0 74d d4a c28
ccc 0 d4b 0
d48 0 d4b 74f
0 d4c 752 ea0
66 :3 0 2d :3 0
25 :2 0 756 d4d
d50 119 :2 0 66
:3 0 2c :3 0 25
:2 0 759 d53 d56
6c :2 0 66 :3 0
3d :3 0 25 :2 0
75c d59 d5c 75f
d58 d5e :3 0 d5f
:2 0 764 d52 d61
:3 0 29 :3 0 66
:3 0 3d :3 0 25
:2 0 767 d64 d67
10f :2 0 66 :3 0
29 :3 0 25 :2 0
76a d6a d6d 76d
d69 d6f :3 0 d63
d70 0 e0d 2a
:3 0 fc :3 0 66
:3 0 110 :3 0 2d
:3 0 770 d75 d77
25 :2 0 772 d74
d7a ff :2 0 66
:3 0 110 :3 0 29
:3 0 775 d7e d80
25 :2 0 777 d7d
d83 77a d7c d85
:3 0 d86 :2 0 fd
:2 0 113 :2 0 77d
d88 d8a :3 0 d8b
:2 0 6c :2 0 111
:2 0 780 d8d d8f
:3 0 783 d73 d91
d72 d92 0 e0d
90 :3 0 11a :3 0
8f :3 0 11b :3 0
115 :3 0 8f :3 0
44 :3 0 11c :3 0
75 :3 0 3d :3 0
74 :3 0 2d :3 0
91 :3 0 11 :4 0
126 1 :8 0 db8
11e :4 0 da3 :3 0
11f :3 0 a0 :2 0
787 da6 da7 :3 0
93 :3 0 94 :3 0
da9 daa 0 25
:2 0 dab dac 0
dae 78a db5 93
:3 0 94 :3 0 daf
db0 0 120 :2 0
db1 db2 0 db4
78c db6 da8 dae
0 db7 0 db4
0 db7 78e 0
db8 791 e0b 96
:3 0 93 :3 0 94
:3 0 dba dbb 0
95 :3 0 dbc dbd
0 dbf 794 dc1
796 dc0 dbf :2 0
e09 97 :3 0 93
:3 0 94 :3 0 dc4
dc5 0 95 :3 0
dc6 dc7 0 e01
59 :3 0 5a :3 0
dc9 dca 0 59
:3 0 6a :3 0 dcc
dcd 0 98 :2 0
2 :4 0 127 :2 0
6c :2 0 21 :2 0
798 dd2 dd4 :3 0
79b dce dd6 dcb
dd8 dd7 :2 0 5c
:3 0 6d :3 0 dda
ddb 0 5e :4 0
128 :4 0 61 :2 0
62 :3 0 79f ddf
de1 :3 0 61 :2 0
9b :4 0 7a2 de3
de5 :3 0 61 :2 0
9c :4 0 7a5 de7
de9 :3 0 61 :2 0
95 :3 0 7a8 deb
ded :3 0 61 :2 0
9d :4 0 7ab def
df1 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
7ae df4 df8 7b2
df3 dfa :3 0 7b5
ddc dfc :2 0 dfe
7b8 dff dd9 dfe
0 e00 7ba 0
e01 7bc e04 :3 0
e04 0 e04 e03
e01 e02 :6 0 e06
1c :3 0 7bf e08
7c1 e07 e06 :2 0
e09 7c3 :2 0 e0b
0 e0b e0a db8
e09 :6 0 e0d 1
:3 0 7c6 e9c 29
:3 0 66 :3 0 2d
:3 0 25 :2 0 7ca
e0f e12 10f :2 0
66 :3 0 29 :3 0
25 :2 0 7cd e15
e18 7d0 e14 e1a
:3 0 e0e e1b 0
e9b 2a :3 0 fe
:2 0 e1d e1e 0
e9b 90 :3 0 11a
:3 0 8f :3 0 11b
:3 0 115 :3 0 8f
:3 0 44 :3 0 11c
:3 0 75 :3 0 2d
:3 0 74 :3 0 2d
:3 0 76 :3 0 8d
:3 0 91 :3 0 11
:4 0 123 1 :8 0
e46 11e :4 0 e31
:3 0 11f :3 0 a0
:2 0 7d5 e34 e35
:3 0 93 :3 0 94
:3 0 e37 e38 0
25 :2 0 e39 e3a
0 e3c 7d8 e43
93 :3 0 94 :3 0
e3d e3e 0 120
:2 0 e3f e40 0
e42 7da e44 e36
e3c 0 e45 0
e42 0 e45 7dc
0 e46 7df e99
96 :3 0 93 :3 0
94 :3 0 e48 e49
0 95 :3 0 e4a
e4b 0 e4d 7e2
e4f 7e4 e4e e4d
:2 0 e97 97 :3 0
93 :3 0 94 :3 0
e52 e53 0 95
:3 0 e54 e55 0
e8f 59 :3 0 5a
:3 0 e57 e58 0
59 :3 0 6a :3 0
e5a e5b 0 98
:2 0 2 :4 0 129
:2 0 6c :2 0 21
:2 0 7e6 e60 e62
:3 0 7e9 e5c e64
e59 e66 e65 :2 0
5c :3 0 6d :3 0
e68 e69 0 5e
:4 0 12a :4 0 61
:2 0 62 :3 0 7ed
e6d e6f :3 0 61
:2 0 9b :4 0 7f0
e71 e73 :3 0 61
:2 0 9c :4 0 7f3
e75 e77 :3 0 61
:2 0 95 :3 0 7f6
e79 e7b :3 0 61
:2 0 9d :4 0 7f9
e7d e7f :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 7fc e82 e86
800 e81 e88 :3 0
803 e6a e8a :2 0
e8c 806 e8d e67
e8c 0 e8e 808
0 e8f 80a e92
:3 0 e92 0 e92
e91 e8f e90 :6 0
e94 1e :3 0 80d
e96 80f e95 e94
:2 0 e97 811 :2 0
e99 0 e99 e98
e46 e97 :6 0 e9b
1 :3 0 814 e9d
d62 e0d 0 e9e
0 e9b 0 e9e
818 0 e9f 81b
ea1 c00 d4c 0
ea2 0 e9f 0
ea2 81d 0 ea3
820 f32 29 :3 0
66 :3 0 2d :3 0
25 :2 0 822 ea5
ea8 10f :2 0 66
:3 0 2c :3 0 25
:2 0 825 eab eae
828 eaa eb0 :3 0
ea4 eb1 0 f31
2a :3 0 fe :2 0
eb3 eb4 0 f31
90 :3 0 11a :3 0
8f :3 0 11b :3 0
115 :3 0 8f :3 0
44 :3 0 11c :3 0
75 :3 0 2d :3 0
74 :3 0 2d :3 0
76 :3 0 8d :3 0
91 :3 0 11 :4 0
12b 1 :8 0 edc
11e :4 0 ec7 :3 0
11f :3 0 a0 :2 0
82d eca ecb :3 0
93 :3 0 94 :3 0
ecd ece 0 25
:2 0 ecf ed0 0
ed2 830 ed9 93
:3 0 94 :3 0 ed3
ed4 0 120 :2 0
ed5 ed6 0 ed8
832 eda ecc ed2
0 edb 0 ed8
0 edb 834 0
edc 837 f2f 96
:3 0 93 :3 0 94
:3 0 ede edf 0
95 :3 0 ee0 ee1
0 ee3 83a ee5
83c ee4 ee3 :2 0
f2d 97 :3 0 93
:3 0 94 :3 0 ee8
ee9 0 95 :3 0
eea eeb 0 f25
59 :3 0 5a :3 0
eed eee 0 59
:3 0 6a :3 0 ef0
ef1 0 98 :2 0
2 :4 0 12c :2 0
6c :2 0 21 :2 0
83e ef6 ef8 :3 0
841 ef2 efa eef
efc efb :2 0 5c
:3 0 6d :3 0 efe
eff 0 5e :4 0
12d :4 0 61 :2 0
62 :3 0 845 f03
f05 :3 0 61 :2 0
9b :4 0 848 f07
f09 :3 0 61 :2 0
9c :4 0 84b f0b
f0d :3 0 61 :2 0
95 :3 0 84e f0f
f11 :3 0 61 :2 0
9d :4 0 851 f13
f15 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
854 f18 f1c 858
f17 f1e :3 0 85b
f00 f20 :2 0 f22
85e f23 efd f22
0 f24 860 0
f25 862 f28 :3 0
f28 0 f28 f27
f25 f26 :6 0 f2a
20 :3 0 865 f2c
867 f2b f2a :2 0
f2d 869 :2 0 f2f
0 f2f f2e edc
f2d :6 0 f31 1
:3 0 86c f33 bf5
ea3 0 f34 0
f31 0 f34 870
0 117f 1d :3 0
109 :2 0 873 f36
f37 :3 0 f38 :2 0
1e :4 0 f3a f3b
0 1102 12e :3 0
12f :3 0 1e :3 0
130 :3 0 a9 :3 0
14 :3 0 70 :3 0
16 :4 0 131 1
:8 0 f4b 93 :3 0
94 :3 0 f46 f47
0 95 :3 0 f48
f49 0 f4b 875
f9e 96 :3 0 93
:3 0 94 :3 0 f4d
f4e 0 95 :3 0
f4f f50 0 f52
878 f54 87a f53
f52 :2 0 f9c 97
:3 0 93 :3 0 94
:3 0 f57 f58 0
95 :3 0 f59 f5a
0 f94 59 :3 0
5a :3 0 f5c f5d
0 59 :3 0 6a
:3 0 f5f f60 0
98 :2 0 2 :4 0
132 :2 0 6c :2 0
21 :2 0 87c f65
f67 :3 0 87f f61
f69 f5e f6b f6a
:2 0 5c :3 0 6d
:3 0 f6d f6e 0
5e :4 0 133 :4 0
61 :2 0 62 :3 0
883 f72 f74 :3 0
61 :2 0 9b :4 0
886 f76 f78 :3 0
61 :2 0 9c :4 0
889 f7a f7c :3 0
61 :2 0 95 :3 0
88c f7e f80 :3 0
61 :2 0 9d :4 0
88f f82 f84 :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 892 f87
f8b 896 f86 f8d
:3 0 899 f6f f8f
:2 0 f91 89c f92
f6c f91 0 f93
89e 0 f94 8a0
f97 :3 0 f97 0
f97 f96 f94 f95
:6 0 f99 22 :3 0
8a3 f9b 8a5 f9a
f99 :2 0 f9c 8a7
:2 0 f9e 0 f9e
f9d f4b f9c :6 0
1102 1 :3 0 1e
:3 0 109 :2 0 8aa
fa1 fa2 :3 0 fa3
:2 0 81 :3 0 82
:3 0 1e :3 0 1e
:3 0 c9 :4 0 134
1 :8 0 fb0 93
:3 0 94 :3 0 fab
fac 0 95 :3 0
fad fae 0 fb0
8ac 1003 96 :3 0
93 :3 0 94 :3 0
fb2 fb3 0 95
:3 0 fb4 fb5 0
fb7 8af fb9 8b1
fb8 fb7 :2 0 1001
97 :3 0 93 :3 0
94 :3 0 fbc fbd
0 95 :3 0 fbe
fbf 0 ff9 59
:3 0 5a :3 0 fc1
fc2 0 59 :3 0
6a :3 0 fc4 fc5
0 98 :2 0 2
:4 0 135 :2 0 6c
:2 0 21 :2 0 8b3
fca fcc :3 0 8b6
fc6 fce fc3 fd0
fcf :2 0 5c :3 0
6d :3 0 fd2 fd3
0 5e :4 0 136
:4 0 61 :2 0 62
:3 0 8ba fd7 fd9
:3 0 61 :2 0 9b
:4 0 8bd fdb fdd
:3 0 61 :2 0 9c
:4 0 8c0 fdf fe1
:3 0 61 :2 0 95
:3 0 8c3 fe3 fe5
:3 0 61 :2 0 9d
:4 0 8c6 fe7 fe9
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 8c9
fec ff0 8cd feb
ff2 :3 0 8d0 fd4
ff4 :2 0 ff6 8d3
ff7 fd1 ff6 0
ff8 8d5 0 ff9
8d7 ffc :3 0 ffc
0 ffc ffb ff9
ffa :6 0 ffe 24
:3 0 8da 1000 8dc
fff ffe :2 0 1001
8de :2 0 1003 0
1003 1002 fb0 1001
:6 0 1018 1 :3 0
c2 :3 0 137 :3 0
1005 1006 0 1d
:3 0 1e :3 0 138
:2 0 8e1 1007 100b
119 :2 0 25 :2 0
8e7 100d 100f :3 0
1a :3 0 1e :3 0
1011 1012 0 1014
8ea 1015 1010 1014
0 1016 8ec 0
1018 de :3 0 8ee
10ff 66 :3 0 35
:3 0 25 :2 0 8f1
1019 101c be :2 0
25 :2 0 8f6 101e
1020 :3 0 35 :3 0
114 :3 0 115 :3 0
1023 1024 0 66
:3 0 35 :3 0 25
:2 0 8f9 1026 1029
44 :3 0 116 :3 0
102b 102c 0 8fc
1025 102e 102f :2 0
1022 1030 0 1097
c2 :3 0 139 :3 0
81 :3 0 82 :3 0
1d :3 0 c2 :3 0
13a :3 0 1a :3 0
1a :3 0 c9 :4 0
13b 1 :8 0 1042
93 :3 0 94 :3 0
103d 103e 0 95
:3 0 103f 1040 0
1042 8ff 1095 96
:3 0 93 :3 0 94
:3 0 1044 1045 0
95 :3 0 1046 1047
0 1049 902 104b
904 104a 1049 :2 0
1093 97 :3 0 93
:3 0 94 :3 0 104e
104f 0 95 :3 0
1050 1051 0 108b
59 :3 0 5a :3 0
1053 1054 0 59
:3 0 6a :3 0 1056
1057 0 98 :2 0
2 :4 0 13c :2 0
6c :2 0 21 :2 0
906 105c 105e :3 0
909 1058 1060 1055
1062 1061 :2 0 5c
:3 0 6d :3 0 1064
1065 0 5e :4 0
13d :4 0 61 :2 0
62 :3 0 90d 1069
106b :3 0 61 :2 0
9b :4 0 910 106d
106f :3 0 61 :2 0
9c :4 0 913 1071
1073 :3 0 61 :2 0
95 :3 0 916 1075
1077 :3 0 61 :2 0
9d :4 0 919 1079
107b :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
91c 107e 1082 920
107d 1084 :3 0 923
1066 1086 :2 0 1088
926 1089 1063 1088
0 108a 928 0
108b 92a 108e :3 0
108e 0 108e 108d
108b 108c :6 0 1090
26 :3 0 92d 1092
92f 1091 1090 :2 0
1093 931 :2 0 1095
0 1095 1094 1042
1093 :6 0 1097 1
:3 0 934 1098 1021
1097 0 1101 c2
:3 0 139 :3 0 81
:3 0 82 :3 0 1d
:3 0 c2 :3 0 13a
:3 0 1a :3 0 1a
:3 0 c9 :4 0 13e
1 :8 0 10a9 93
:3 0 94 :3 0 10a4
10a5 0 95 :3 0
10a6 10a7 0 10a9
937 10fc 96 :3 0
93 :3 0 94 :3 0
10ab 10ac 0 95
:3 0 10ad 10ae 0
10b0 93a 10b2 93c
10b1 10b0 :2 0 10fa
97 :3 0 93 :3 0
94 :3 0 10b5 10b6
0 95 :3 0 10b7
10b8 0 10f2 59
:3 0 5a :3 0 10ba
10bb 0 59 :3 0
6a :3 0 10bd 10be
0 98 :2 0 2
:4 0 13f :2 0 6c
:2 0 21 :2 0 93e
10c3 10c5 :3 0 941
10bf 10c7 10bc 10c9
10c8 :2 0 5c :3 0
6d :3 0 10cb 10cc
0 5e :4 0 140
:4 0 61 :2 0 62
:3 0 945 10d0 10d2
:3 0 61 :2 0 9b
:4 0 948 10d4 10d6
:3 0 61 :2 0 9c
:4 0 94b 10d8 10da
:3 0 61 :2 0 95
:3 0 94e 10dc 10de
:3 0 61 :2 0 9d
:4 0 951 10e0 10e2
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 954
10e5 10e9 958 10e4
10eb :3 0 95b 10cd
10ed :2 0 10ef 95e
10f0 10ca 10ef 0
10f1 960 0 10f2
962 10f5 :3 0 10f5
0 10f5 10f4 10f2
10f3 :6 0 10f7 28
:3 0 965 10f9 967
10f8 10f7 :2 0 10fa
969 :2 0 10fc 0
10fc 10fb 10a9 10fa
:6 0 10fe 1 :3 0
96c 1100 fa4 1018
0 1101 0 10fe
0 1101 96e 0
1102 972 1103 f39
1102 0 1104 976
0 117f 13 :3 0
109 :2 0 978 1106
1107 :3 0 1108 :2 0
32 :3 0 141 :3 0
14 :3 0 11 :3 0
142 :2 0 97a 110b
110f 110a 1110 0
1112 97e 1133 82
:3 0 20 :3 0 21
:2 0 21 :2 0 980
1113 1117 a0 :2 0
142 :4 0 986 1119
111b :3 0 32 :3 0
141 :3 0 14 :3 0
11 :3 0 25 :2 0
989 111e 1122 111d
1123 0 1125 98d
112f 32 :3 0 141
:3 0 14 :3 0 11
:3 0 21 :2 0 98f
1127 112b 1126 112c
0 112e 993 1130
111c 1125 0 1131
0 112e 0 1131
995 0 1132 998
1134 1109 1112 0
1135 0 1132 0
1135 99a 0 117f
32 :3 0 142 :2 0
1136 1137 0 117f
32 :3 0 143 :3 0
11 :3 0 1a :3 0
29 :3 0 32 :3 0
35 :3 0 b :3 0
25 :2 0 66 :3 0
2b :3 0 25 :2 0
99d 1142 1145 9a0
113a 1147 1139 1148
0 117f 66 :3 0
32 :3 0 25 :2 0
9a9 114a 114d df
:2 0 25 :2 0 9ae
114f 1151 :3 0 c
:3 0 11 :3 0 1153
1154 0 117c 59
:3 0 5a :3 0 1156
1157 0 59 :3 0
6a :3 0 1159 115a
0 21 :2 0 2
:4 0 144 :2 0 6c
:2 0 21 :2 0 9b1
115f 1161 :3 0 9b4
115b 1163 1158 1165
1164 :2 0 5c :3 0
6d :3 0 1167 1168
0 5e :4 0 145
:4 0 61 :2 0 62
:3 0 9b8 116c 116e
:3 0 9bb 1169 1170
:2 0 1172 9be 1173
1166 1172 0 1174
9c0 0 117c d
:3 0 66 :3 0 32
:3 0 25 :2 0 9c2
1176 1179 117a :2 0
117c 9c5 117d 1152
117c 0 117e 9c9
0 117f 9cb 1181
a1f be8 0 1182
0 117f 0 1182
9d2 0 1186 29
:3 0 2d :3 0 1183
1184 0 1186 9d5
11aa 2a :3 0 fc
:3 0 66 :3 0 110
:3 0 2d :3 0 9d8
118a 118c 25 :2 0
9da 1189 118f ff
:2 0 66 :3 0 110
:3 0 29 :3 0 9dd
1193 1195 25 :2 0
9df 1192 1198 9e2
1191 119a :3 0 119b
:2 0 fd :2 0 113
:2 0 9e5 119d 119f
:3 0 11a0 :2 0 6c
:2 0 111 :2 0 9e8
11a2 11a4 :3 0 9eb
1188 11a6 1187 11a7
0 11a9 9ed 11ab
a07 1186 0 11ac
0 11a9 0 11ac
9ef 0 11fd 32
:3 0 146 :3 0 14
:3 0 15 :3 0 16
:3 0 11 :3 0 1d
:3 0 20 :3 0 29
:3 0 2d :3 0 3b
:3 0 2c :3 0 2a
:3 0 49 :3 0 4c
:3 0 4b :3 0 4d
:3 0 4e :3 0 50
:3 0 4f :3 0 51
:3 0 28 :3 0 27
:3 0 2e :3 0 b
:3 0 66 :3 0 2f
:3 0 25 :2 0 9f2
11c6 11c9 66 :3 0
30 :3 0 25 :2 0
9f5 11cb 11ce 9f8
11ae 11d0 11ad 11d1
0 11fd c :3 0
11 :3 0 11d3 11d4
0 11fd 59 :3 0
5a :3 0 11d6 11d7
0 59 :3 0 6a
:3 0 11d9 11da 0
21 :2 0 2 :4 0
147 :2 0 6c :2 0
21 :2 0 a12 11df
11e1 :3 0 a15 11db
11e3 11d8 11e5 11e4
:2 0 5c :3 0 6d
:3 0 11e7 11e8 0
5e :4 0 148 :4 0
61 :2 0 62 :3 0
a19 11ec 11ee :3 0
a1c 11e9 11f0 :2 0
11f2 a1f 11f3 11e6
11f2 0 11f4 a21
0 11fd d :3 0
66 :3 0 32 :3 0
25 :2 0 a23 11f6
11f9 11fa :2 0 11fd
de :3 0 a26 1696
66 :3 0 e :3 0
25 :2 0 a2d 11fe
1201 66 :3 0 df
:2 0 2a :3 0 25
:2 0 a30 1203 1207
a35 1204 1209 :3 0
90 :3 0 8d :3 0
e :3 0 8f :3 0
11b :3 0 115 :3 0
8f :3 0 44 :3 0
149 :3 0 91 :3 0
11 :4 0 14a 1
:8 0 122c 11e :4 0
1217 :3 0 11f :3 0
a0 :2 0 a3a 121a
121b :3 0 93 :3 0
94 :3 0 121d 121e
0 25 :2 0 121f
1220 0 1222 a3d
1229 93 :3 0 94
:3 0 1223 1224 0
120 :2 0 1225 1226
0 1228 a3f 122a
121c 1222 0 122b
0 1228 0 122b
a41 0 122c a44
127f 96 :3 0 93
:3 0 94 :3 0 122e
122f 0 95 :3 0
1230 1231 0 1233
a47 1235 a49 1234
1233 :2 0 127d 97
:3 0 93 :3 0 94
:3 0 1238 1239 0
95 :3 0 123a 123b
0 1275 59 :3 0
5a :3 0 123d 123e
0 59 :3 0 6a
:3 0 1240 1241 0
98 :2 0 2 :4 0
14b :2 0 6c :2 0
21 :2 0 a4b 1246
1248 :3 0 a4e 1242
124a 123f 124c 124b
:2 0 5c :3 0 6d
:3 0 124e 124f 0
5e :4 0 14c :4 0
61 :2 0 62 :3 0
a52 1253 1255 :3 0
61 :2 0 9b :4 0
a55 1257 1259 :3 0
61 :2 0 9c :4 0
a58 125b 125d :3 0
61 :2 0 95 :3 0
a5b 125f 1261 :3 0
61 :2 0 9d :4 0
a5e 1263 1265 :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 a61 1268
126c a65 1267 126e
:3 0 a68 1250 1270
:2 0 1272 a6b 1273
124d 1272 0 1274
a6d 0 1275 a6f
1278 :3 0 1278 0
1278 1277 1275 1276
:6 0 127a 2a :3 0
a72 127c a74 127b
127a :2 0 127d a76
:2 0 127f 0 127f
127e 122c 127d :6 0
12f8 1 :3 0 a8
:3 0 8f :3 0 11b
:3 0 115 :3 0 8f
:3 0 44 :3 0 149
:3 0 6f :3 0 14
:3 0 a9 :3 0 15
:4 0 14d 1 :8 0
12a2 11e :4 0 128d
:3 0 11f :3 0 a0
:2 0 a7b 1290 1291
:3 0 93 :3 0 94
:3 0 1293 1294 0
25 :2 0 1295 1296
0 1298 a7e 129f
93 :3 0 94 :3 0
1299 129a 0 120
:2 0 129b 129c 0
129e a80 12a0 1292
1298 0 12a1 0
129e 0 12a1 a82
0 12a2 a85 12f5
96 :3 0 93 :3 0
94 :3 0 12a4 12a5
0 95 :3 0 12a6
12a7 0 12a9 a88
12ab a8a 12aa 12a9
:2 0 12f3 97 :3 0
93 :3 0 94 :3 0
12ae 12af 0 95
:3 0 12b0 12b1 0
12eb 59 :3 0 5a
:3 0 12b3 12b4 0
59 :3 0 6a :3 0
12b6 12b7 0 98
:2 0 2 :4 0 14e
:2 0 6c :2 0 21
:2 0 a8c 12bc 12be
:3 0 a8f 12b8 12c0
12b5 12c2 12c1 :2 0
5c :3 0 6d :3 0
12c4 12c5 0 5e
:4 0 14f :4 0 61
:2 0 62 :3 0 a93
12c9 12cb :3 0 61
:2 0 9b :4 0 a96
12cd 12cf :3 0 61
:2 0 9c :4 0 a99
12d1 12d3 :3 0 61
:2 0 95 :3 0 a9c
12d5 12d7 :3 0 61
:2 0 9d :4 0 a9f
12d9 12db :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 aa2 12de 12e2
aa6 12dd 12e4 :3 0
aa9 12c6 12e6 :2 0
12e8 aac 12e9 12c3
12e8 0 12ea aae
0 12eb ab0 12ee
:3 0 12ee 0 12ee
12ed 12eb 12ec :6 0
12f0 2c :3 0 ab3
12f2 ab5 12f1 12f0
:2 0 12f3 ab7 :2 0
12f5 0 12f5 12f4
12a2 12f3 :6 0 12f8
1 :3 0 de :3 0
aba 12f9 120a 12f8
0 1697 66 :3 0
10 :3 0 25 :2 0
abd 12fa 12fd 66
:3 0 df :2 0 2b
:3 0 25 :2 0 ac0
12ff 1303 ac5 1300
1305 :3 0 66 :3 0
10 :3 0 25 :2 0
ac8 1307 130a a0
:2 0 25 :2 0 acd
130c 130e :3 0 2b
:3 0 120 :2 0 1310
1311 0 1313 ad0
135c 66 :3 0 10
:3 0 25 :2 0 ad2
1314 1317 119 :2 0
21 :2 0 ad7 1319
131b :3 0 131c :2 0
66 :3 0 10 :3 0
25 :2 0 ada 131e
1321 be :2 0 150
:2 0 adf 1323 1325
:3 0 1326 :2 0 131d
1328 1327 :2 0 c
:3 0 11 :3 0 132a
132b 0 1351 59
:3 0 5a :3 0 132d
132e 0 59 :3 0
6a :3 0 1330 1331
0 21 :2 0 2
:4 0 151 :2 0 6c
:2 0 21 :2 0 ae2
1336 1338 :3 0 ae5
1332 133a 132f 133c
133b :2 0 5c :3 0
6d :3 0 133e 133f
0 5e :4 0 152
:4 0 61 :2 0 62
:3 0 ae9 1343 1345
:3 0 aec 1340 1347
:2 0 1349 aef 134a
133d 1349 0 134b
af1 0 1351 d
:3 0 44 :3 0 d8
:3 0 134d 134e 0
134f :2 0 1351 af3
1352 1329 1351 0
1353 af7 0 135b
2b :3 0 66 :3 0
10 :3 0 25 :2 0
af9 1355 1358 1354
1359 0 135b afc
135d 130f 1313 0
135e 0 135b 0
135e aff 0 1694
13 :3 0 109 :2 0
b02 1360 1361 :3 0
1362 :2 0 7e :3 0
32 :3 0 90 :3 0
91 :3 0 13 :4 0
153 1 :8 0 136f
93 :3 0 94 :3 0
136a 136b 0 95
:3 0 136c 136d 0
136f b04 13c2 96
:3 0 93 :3 0 94
:3 0 1371 1372 0
95 :3 0 1373 1374
0 1376 b07 1378
b09 1377 1376 :2 0
13c0 97 :3 0 93
:3 0 94 :3 0 137b
137c 0 95 :3 0
137d 137e 0 13b8
59 :3 0 5a :3 0
1380 1381 0 59
:3 0 6a :3 0 1383
1384 0 98 :2 0
2 :4 0 154 :2 0
6c :2 0 21 :2 0
b0b 1389 138b :3 0
b0e 1385 138d 1382
138f 138e :2 0 5c
:3 0 6d :3 0 1391
1392 0 5e :4 0
155 :4 0 61 :2 0
62 :3 0 b12 1396
1398 :3 0 61 :2 0
9b :4 0 b15 139a
139c :3 0 61 :2 0
9c :4 0 b18 139e
13a0 :3 0 61 :2 0
95 :3 0 b1b 13a2
13a4 :3 0 61 :2 0
9d :4 0 b1e 13a6
13a8 :3 0 61 :2 0
82 :3 0 9e :3 0
21 :2 0 9f :2 0
b21 13ab 13af b25
13aa 13b1 :3 0 b28
1393 13b3 :2 0 13b5
b2b 13b6 1390 13b5
0 13b7 b2d 0
13b8 b2f 13bb :3 0
13bb 0 13bb 13ba
13b8 13b9 :6 0 13bd
2e :3 0 b32 13bf
b34 13be 13bd :2 0
13c0 b36 :2 0 13c2
0 13c2 13c1 136f
13c0 :6 0 1408 1
:3 0 93 :3 0 94
:3 0 13c4 13c5 0
93 :3 0 a0 :2 0
156 :3 0 13c7 13c9
0 b3b 13c8 13cb
:3 0 13cc :2 0 66
:3 0 2b :3 0 25
:2 0 b3e 13ce 13d1
66 :3 0 be :2 0
32 :3 0 25 :2 0
b41 13d3 13d7 b46
13d4 13d9 :3 0 13da
:2 0 13cd 13dc 13db
:2 0 c :3 0 13
:3 0 13de 13df 0
1405 59 :3 0 5a
:3 0 13e1 13e2 0
59 :3 0 6a :3 0
13e4 13e5 0 21
:2 0 2 :4 0 157
:2 0 6c :2 0 21
:2 0 b49 13ea 13ec
:3 0 b4c 13e6 13ee
13e3 13f0 13ef :2 0
5c :3 0 6d :3 0
13f2 13f3 0 5e
:4 0 158 :4 0 61
:2 0 62 :3 0 b50
13f7 13f9 :3 0 b53
13f4 13fb :2 0 13fd
b56 13fe 13f1 13fd
0 13ff b58 0
1405 d :3 0 44
:3 0 159 :3 0 1401
1402 0 1403 :2 0
1405 b5a 1406 13dd
1405 0 1407 b5e
0 1408 b60 1409
1363 1408 0 140a
b63 0 1694 66
:3 0 30 :3 0 25
:2 0 b65 140b 140e
44 :3 0 a0 :2 0
101 :3 0 1410 1412
0 b6a 1411 1414
:3 0 66 :3 0 30
:3 0 25 :2 0 b6d
1416 1419 44 :3 0
a0 :2 0 100 :3 0
141b 141d 0 b72
141c 141f :3 0 1415
1421 1420 :2 0 66
:3 0 2e :3 0 25
:2 0 b75 1423 1426
be :2 0 25 :2 0
b7a 1428 142a :3 0
142b :2 0 1d :3 0
109 :2 0 b7d 142e
142f :3 0 1430 :2 0
1431 :2 0 142c 1433
1432 :2 0 32 :3 0
15a :3 0 14 :3 0
15 :3 0 16 :3 0
13 :3 0 11 :3 0
1d :3 0 2e :3 0
25 :2 0 b7f 1436
143f 1435 1440 0
1442 b88 1443 1434
1442 0 1444 b8a
0 14f7 33 :3 0
fc :3 0 66 :3 0
2b :3 0 25 :2 0
b8c 1447 144a fd
:2 0 66 :3 0 2f
:3 0 25 :2 0 b8f
144d 1450 b92 144c
1452 :3 0 1453 :2 0
ff :2 0 113 :2 0
b95 1455 1457 :3 0
1458 :2 0 6c :2 0
111 :2 0 b98 145a
145c :3 0 b9b 1446
145e 1445 145f 0
14f7 32 :3 0 112
:3 0 14 :3 0 13
:3 0 11 :3 0 1a
:3 0 1c :3 0 33
:3 0 33 :3 0 25
:2 0 b9d 1462 146b
1461 146c 0 14f7
32 :3 0 114 :3 0
115 :3 0 146f 1470
0 66 :3 0 2b
:3 0 25 :2 0 ba6
1472 1475 44 :3 0
15b :3 0 1477 1478
0 ba9 1471 147a
146e 147b 0 14f7
32 :3 0 117 :3 0
14 :3 0 11 :3 0
32 :3 0 25 :2 0
25 :2 0 25 :2 0
bac 147e 1485 147d
1486 0 14f7 81
:3 0 82 :3 0 7f
:3 0 81 :3 0 82
:3 0 80 :3 0 17
:3 0 19 :3 0 90
:3 0 91 :3 0 11
:4 0 15c 1 :8 0
1499 93 :3 0 94
:3 0 1494 1495 0
95 :3 0 1496 1497
0 1499 bb3 14ec
96 :3 0 93 :3 0
94 :3 0 149b 149c
0 95 :3 0 149d
149e 0 14a0 bb6
14a2 bb8 14a1 14a0
:2 0 14ea 97 :3 0
93 :3 0 94 :3 0
14a5 14a6 0 95
:3 0 14a7 14a8 0
14e2 59 :3 0 5a
:3 0 14aa 14ab 0
59 :3 0 6a :3 0
14ad 14ae 0 98
:2 0 2 :4 0 15d
:2 0 6c :2 0 21
:2 0 bba 14b3 14b5
:3 0 bbd 14af 14b7
14ac 14b9 14b8 :2 0
5c :3 0 6d :3 0
14bb 14bc 0 5e
:4 0 15e :4 0 61
:2 0 62 :3 0 bc1
14c0 14c2 :3 0 61
:2 0 9b :4 0 bc4
14c4 14c6 :3 0 61
:2 0 9c :4 0 bc7
14c8 14ca :3 0 61
:2 0 95 :3 0 bca
14cc 14ce :3 0 61
:2 0 9d :4 0 bcd
14d0 14d2 :3 0 61
:2 0 82 :3 0 9e
:3 0 21 :2 0 9f
:2 0 bd0 14d5 14d9
bd4 14d4 14db :3 0
bd7 14bd 14dd :2 0
14df bda 14e0 14ba
14df 0 14e1 bdc
0 14e2 bde 14e5
:3 0 14e5 0 14e5
14e4 14e2 14e3 :6 0
14e7 30 :3 0 be1
14e9 be3 14e8 14e7
:2 0 14ea be5 :2 0
14ec 0 14ec 14eb
1499 14ea :6 0 14f7
1 :3 0 32 :3 0
118 :3 0 14 :3 0
15 :3 0 11 :3 0
25 :2 0 be8 14ef
14f4 14ee 14f5 0
14f7 bed 1691 66
:3 0 2e :3 0 25
:2 0 bf5 14f8 14fb
be :2 0 25 :2 0
bfa 14fd 14ff :3 0
1500 :2 0 1d :3 0
109 :2 0 bfd 1503
1504 :3 0 1505 :2 0
1506 :2 0 1501 1508
1507 :2 0 32 :3 0
15a :3 0 14 :3 0
15 :3 0 16 :3 0
13 :3 0 11 :3 0
1d :3 0 2e :3 0
25 :2 0 bff 150b
1514 150a 1515 0
1517 c08 1518 1509
1517 0 1519 c0a
0 1690 13 :3 0
109 :2 0 c0c 151b
151c :3 0 151d :2 0
32 :3 0 141 :3 0
14 :3 0 11 :3 0
142 :2 0 c0e 1520
1524 151f 1525 0
1527 c12 1548 82
:3 0 20 :3 0 21
:2 0 21 :2 0 c14
1528 152c a0 :2 0
142 :4 0 c1a 152e
1530 :3 0 32 :3 0
141 :3 0 14 :3 0
11 :3 0 25 :2 0
c1d 1533 1537 1532
1538 0 153a c21
1544 32 :3 0 141
:3 0 14 :3 0 11
:3 0 21 :2 0 c23
153c 1540 153b 1541
0 1543 c27 1545
1531 153a 0 1546
0 1543 0 1546
c29 0 1547 c2c
1549 151e 1527 0
154a 0 1547 0
154a c2e 0 1690
1d :3 0 109 :2 0
c31 154c 154d :3 0
154e :2 0 c2 :3 0
139 :3 0 81 :3 0
82 :3 0 1d :3 0
c2 :3 0 13a :3 0
1a :3 0 1a :3 0
c9 :4 0 15f 1
:8 0 1560 93 :3 0
94 :3 0 155b 155c
0 95 :3 0 155d
155e 0 1560 c33
15b3 96 :3 0 93
:3 0 94 :3 0 1562
1563 0 95 :3 0
1564 1565 0 1567
c36 1569 c38 1568
1567 :2 0 15b1 97
:3 0 93 :3 0 94
:3 0 156c 156d 0
95 :3 0 156e 156f
0 15a9 59 :3 0
5a :3 0 1571 1572
0 59 :3 0 6a
:3 0 1574 1575 0
98 :2 0 2 :4 0
160 :2 0 6c :2 0
21 :2 0 c3a 157a
157c :3 0 c3d 1576
157e 1573 1580 157f
:2 0 5c :3 0 6d
:3 0 1582 1583 0
5e :4 0 161 :4 0
61 :2 0 62 :3 0
c41 1587 1589 :3 0
61 :2 0 9b :4 0
c44 158b 158d :3 0
61 :2 0 9c :4 0
c47 158f 1591 :3 0
61 :2 0 95 :3 0
c4a 1593 1595 :3 0
61 :2 0 9d :4 0
c4d 1597 1599 :3 0
61 :2 0 82 :3 0
9e :3 0 21 :2 0
9f :2 0 c50 159c
15a0 c54 159b 15a2
:3 0 c57 1584 15a4
:2 0 15a6 c5a 15a7
1581 15a6 0 15a8
c5c 0 15a9 c5e
15ac :3 0 15ac 0
15ac 15ab 15a9 15aa
:6 0 15ae 32 :3 0
c61 15b0 c63 15af
15ae :2 0 15b1 c65
:2 0 15b3 0 15b3
15b2 1560 15b1 :6 0
15c4 1 :3 0 29
:3 0 66 :3 0 29
:3 0 25 :2 0 c68
15b6 15b9 10f :2 0
66 :3 0 2c :3 0
25 :2 0 c6b 15bc
15bf c6e 15bb 15c1
:3 0 15b5 15c2 0
15c4 c71 15c5 154f
15c4 0 15c6 c74
0 1690 35 :3 0
25 :2 0 15c7 15c8
0 1690 32 :3 0
142 :2 0 15ca 15cb
0 1690 32 :3 0
143 :3 0 11 :3 0
1a :3 0 29 :3 0
32 :3 0 35 :3 0
b :3 0 25 :2 0
66 :3 0 2b :3 0
25 :2 0 c76 15d6
15d9 c79 15ce 15db
15cd 15dc 0 1690
66 :3 0 32 :3 0
25 :2 0 c82 15de
15e1 df :2 0 25
:2 0 c87 15e3 15e5
:3 0 c :3 0 11
:3 0 15e7 15e8 0
160e 59 :3 0 5a
:3 0 15ea 15eb 0
59 :3 0 6a :3 0
15ed 15ee 0 21
:2 0 2 :4 0 162
:2 0 6c :2 0 21
:2 0 c8a 15f3 15f5
:3 0 c8d 15ef 15f7
15ec 15f9 15f8 :2 0
5c :3 0 6d :3 0
15fb 15fc 0 5e
:4 0 163 :4 0 61
:2 0 62 :3 0 c91
1600 1602 :3 0 c94
15fd 1604 :2 0 1606
c97 1607 15fa 1606
0 1608 c99 0
160e d :3 0 44
:3 0 159 :3 0 160a
160b 0 160c :2 0
160e c9b 168d 90
:3 0 11a :3 0 7e
:3 0 2b :3 0 7a
:3 0 7c :3 0 79
:3 0 164 :3 0 8f
:3 0 11b :3 0 115
:3 0 8f :3 0 44
:3 0 11c :3 0 44
:3 0 165 :3 0 91
:3 0 11 :4 0 166
1 :8 0 1637 11e
:4 0 1622 :3 0 11f
:3 0 a0 :2 0 ca1
1625 1626 :3 0 93
:3 0 94 :3 0 1628
1629 0 25 :2 0
162a 162b 0 162d
ca4 1634 93 :3 0
94 :3 0 162e 162f
0 120 :2 0 1630
1631 0 1633 ca6
1635 1627 162d 0
1636 0 1633 0
1636 ca8 0 1637
cab 168a 96 :3 0
93 :3 0 94 :3 0
1639 163a 0 95
:3 0 163b 163c 0
163e cae 1640 cb0
163f 163e :2 0 1688
97 :3 0 93 :3 0
94 :3 0 1643 1644
0 95 :3 0 1645
1646 0 1680 59
:3 0 5a :3 0 1648
1649 0 59 :3 0
6a :3 0 164b 164c
0 98 :2 0 2
:4 0 167 :2 0 6c
:2 0 21 :2 0 cb2
1651 1653 :3 0 cb5
164d 1655 164a 1657
1656 :2 0 5c :3 0
6d :3 0 1659 165a
0 5e :4 0 168
:4 0 61 :2 0 62
:3 0 cb9 165e 1660
:3 0 61 :2 0 9b
:4 0 cbc 1662 1664
:3 0 61 :2 0 9c
:4 0 cbf 1666 1668
:3 0 61 :2 0 95
:3 0 cc2 166a 166c
:3 0 61 :2 0 9d
:4 0 cc5 166e 1670
:3 0 61 :2 0 82
:3 0 9e :3 0 21
:2 0 9f :2 0 cc8
1673 1677 ccc 1672
1679 :3 0 ccf 165b
167b :2 0 167d cd2
167e 1658 167d 0
167f cd4 0 1680
cd6 1683 :3 0 1683
0 1683 1682 1680
1681 :6 0 1685 34
:3 0 cd9 1687 cdb
1686 1685 :2 0 1688
cdd :2 0 168a 0
168a 1689 1637 1688
:6 0 168c 1 :3 0
ce0 168e 15e6 160e
0 168f 0 168c
0 168f ce2 0
1690 ce5 1692 1422
14f7 0 1693 0
1690 0 1693 ced
0 1694 cf0 1695
1306 1694 0 1697
9f7 11fd 0 1697
cf4 0 1698 cf8
169a 300 707 0
169b 0 1698 0
169b d06 0 16d6
93 :3 0 94 :3 0
169c 169d 0 169
:3 0 14 :3 0 d09
169f 16a1 169e 16a2
0 16d6 59 :3 0
5a :3 0 16a4 16a5
0 59 :3 0 6a
:3 0 16a7 16a8 0
21 :2 0 2 :4 0
16a :2 0 6c :2 0
21 :2 0 d0b 16ad
16af :3 0 d0e 16a9
16b1 16a6 16b3 16b2
:2 0 5c :3 0 6d
:3 0 16b5 16b6 0
5e :4 0 16b :4 0
61 :2 0 62 :3 0
d12 16ba 16bc :3 0
61 :2 0 9b :4 0
d15 16be 16c0 :3 0
61 :2 0 d7 :4 0
d18 16c2 16c4 :3 0
61 :2 0 93 :3 0
94 :3 0 16c7 16c8
0 d1b 16c6 16ca
:3 0 d1e 16b7 16cc
:2 0 16ce d21 16cf
16b4 16ce 0 16d0
d23 0 16d6 d
:3 0 93 :3 0 94
:3 0 16d2 16d3 0
16d4 :2 0 16d6 d25
16d9 :3 0 16d9 d2e
16d9 16d8 16d6 16d7
:6 0 16da :2 0 2
24 16d9 16dd :3 0
16dc 16da 16de :8 0

d6f
4
:3 0 1 3 1
9 1 d 1
11 1 15 1
1b 6 8 c
10 14 1a 20
1 26 1 2c
1 32 1 3a
1 38 1 41
1 3f 1 48
1 46 1 4f
1 4d 1 56
1 54 1 5b
1 60 1 65
1 6a 1 6f
1 74 1 79
1 80 1 7e
1 87 1 85
1 8e 1 8c
1 93 1 99
1 9f 1 a5
1 ab 1 b1
1 b7 1 bd
1 c3 1 c9
1 cf 1 d5
1 db 1 e1
1 e7 1 ed
1 f3 1 f9
1 ff 1 105
1 10b 1 111
1 117 1 11d
1 123 1 129
1 12f 1 135
1 13d 1 13b
1 147 1 145
1 151 1 14f
1 156 1 15c
1 162 1 168
1 16e 1 174
1 17a 1 180
1 186 1 18c
1 192 1 198
1 19e 1 1a4
1 1aa 1 1b6
1 1c2 2 1c5
1c7 2 1ca 1cc
2 1ce 1d0 2
1d2 1d4 2 1d6
1d8 1 1de 2
1e0 1e1 2 1da
1e3 2 1e5 1e7
1 1ed 2 1ef
1f0 2 1e9 1f2
2 1f4 1f6 1
1fc 2 1fe 1ff
2 1f8 201 2
203 205 2 207
209 2 20b 20d
2 20f 211 2
213 215 2 217
219 2 21b 21d
2 21f 221 2
223 225 4 1be
1c4 1c9 227 1
229 1 22b 2
235 237 3 233
234 239 2 242
244 2 241 246
1 248 1 24a
2 29c 2a1 1
2a8 1 2a3 2
2bb 2bd 3 2b9
2ba 2bf 2 2c8
2ca 2 2cc 2ce
2 2d0 2d2 2
2d4 2d6 2 2d8
2da 3 2df 2e0
2e1 2 2dc 2e3
2 2c7 2e5 1
2e7 1 2e9 2
2b2 2ea 1 2ee
1 2ad 2 2ab
2f2 1 2fd 2
2f9 2fd 2 316
31b 1 322 1
31d 2 335 337
3 333 334 339
2 342 344 2
346 348 2 34a
34c 2 34e 350
2 352 354 3
359 35a 35b 2
356 35d 2 341
35f 1 361 1
363 2 32c 364
1 368 1 327
2 325 36c 1
377 2 373 377
2 386 388 3
384 385 38a 2
393 395 2 392
397 1 399 1
39b 3 37d 39c
3a1 1 3a3 3
3a6 3a7 3a8 1
3ac 2 3aa 3ac
2 3ba 3bc 3
3b8 3b9 3be 2
3c7 3c9 2 3c6
3cb 1 3cd 1
3cf 3 3b1 3d0
3d5 1 3d7 2
3db 3dc 2 3de
3e1 1 3e8 2
3e4 3e8 2 3f6
3f8 3 3f4 3f5
3fa 2 403 405
2 402 407 1
409 1 40b 3
3ed 40c 411 1
413 2 41d 422
1 429 1 424
2 43c 43e 3
43a 43b 440 2
449 44b 2 44d
44f 2 451 453
2 455 457 2
459 45b 3 460
461 462 2 45d
464 2 448 466
1 468 1 46a
2 433 46b 1
46f 1 42e 2
42c 473 2 479
47a 1 47e 2
47c 47e 2 486
48b 1 492 1
48d 2 4a5 4a7
3 4a3 4a4 4a9
2 4b2 4b4 2
4b6 4b8 2 4ba
4bc 2 4be 4c0
2 4c2 4c4 3
4c9 4ca 4cb 2
4c6 4cd 2 4b1
4cf 1 4d1 1
4d3 2 49c 4d4
1 4d8 1 497
2 495 4dc 2
4e4 4e5 1 4e9
2 4e7 4e9 2
4f7 4f9 3 4f5
4f6 4fb 2 504
506 2 503 508
1 50a 1 50c
3 4ee 50d 512
1 514 2 4df
515 1 517 2
537 53c 1 543
1 53e 2 556
558 3 554 555
55a 2 563 565
2 567 569 2
56b 56d 2 56f
571 2 573 575
3 57a 57b 57c
2 577 57e 2
562 580 1 582
1 584 2 54d
585 1 589 1
548 2 546 58d
2 593 594 1
598 2 596 598
2 5a6 5a8 3
5a4 5a5 5aa 2
5b3 5b5 2 5b2
5b7 1 5b9 1
5bb 3 59d 5bc
5c1 1 5c3 2
5c6 5c7 1 5cb
2 5c9 5cb 2
5d6 5d8 3 5d4
5d5 5da 2 5e3
5e5 2 5e7 5e9
2 5eb 5ed 1
5f5 2 5f7 5f8
2 5ef 5fa 2
5e2 5fc 1 5fe
1 600 2 60a
60c 3 608 609
60e 2 617 619
2 616 61b 1
61d 1 61f 2
627 628 3 601
620 62b 2 62f
630 2 635 636
1 638 2 632
638 2 63f 640
2 645 646 1
648 2 642 648
2 656 658 3
654 655 65a 2
663 665 2 662
667 1 669 1
66b 3 64d 66c
671 2 675 676
2 67b 67c 1
67e 2 678 67e
1 683 2 686
685 2 692 693
2 697 698 2
69c 69d 7 68d
68e 68f 690 695
69a 69f 4 63d
687 68a 6a2 2
6ad 6af 3 6ab
6ac 6b1 2 6ba
6bc 2 6be 6c0
2 6c2 6c4 1
6cc 2 6ce 6cf
2 6c6 6d1 2
6b9 6d3 1 6d5
1 6d7 2 6e1
6e3 3 6df 6e0
6e5 2 6ee 6f0
2 6ed 6f2 1
6f4 1 6f6 2
6fe 6ff 3 6d8
6f7 702 3 704
6a4 705 b 36f
3a4 3d8 414 417
476 518 51b 590
5c4 706 2 709
70a 1 70e 2
70c 70e 2 71c
71e 3 71a 71b
720 2 729 72b
2 728 72d 1
72f 1 731 3
713 732 737 1
739 2 743 748
1 74f 1 74a
2 762 764 3
760 761 766 2
76f 771 2 773
775 2 777 779
2 77b 77d 2
77f 781 3 786
787 788 2 783
78a 2 76e 78c
1 78e 1 790
2 759 791 1
795 1 754 2
752 799 2 79f
7a0 1 7a4 2
7a2 7a4 2 7ac
7b1 1 7b8 1
7b3 2 7cb 7cd
3 7c9 7ca 7cf
2 7d8 7da 2
7dc 7de 2 7e0
7e2 2 7e4 7e6
2 7e8 7ea 3
7ef 7f0 7f1 2
7ec 7f3 2 7d7
7f5 1 7f7 1
7f9 2 7c2 7fa
1 7fe 1 7bd
2 7bb 802 2
80a 80b 1 80f
2 80d 80f 2
81d 81f 3 81b
81c 821 2 82a
82c 2 829 82e
1 830 1 832
3 814 833 838
1 83a 2 805
83b 1 83d 2
84c 851 1 858
1 853 2 86b
86d 3 869 86a
86f 2 878 87a
2 87c 87e 2
880 882 2 884
886 2 888 88a
3 88f 890 891
2 88c 893 2
877 895 1 897
1 899 2 862
89a 1 89e 1
85d 2 85b 8a2
3 8a8 8a9 8aa
1 8ae 2 8ac
8ae 2 8bc 8be
3 8ba 8bb 8c0
2 8c9 8cb 2
8c8 8cd 1 8cf
1 8d1 3 8b3
8d2 8d7 1 8d9
2 8dd 8de 2
8e0 8e3 1 8ea
2 8e6 8ea 2
8f8 8fa 3 8f6
8f7 8fc 2 905
907 2 904 909
1 90b 1 90d
3 8ef 90e 913
1 915 2 926
92b 1 932 1
92d 2 945 947
3 943 944 949
2 952 954 2
956 958 2 95a
95c 2 95e 960
2 962 964 3
969 96a 96b 2
966 96d 2 951
96f 1 971 1
973 2 93c 974
1 978 1 937
2 935 97c 2
982 983 1 987
2 985 987 2
995 997 3 993
994 999 2 9a2
9a4 2 9a1 9a6
1 9a8 1 9aa
3 98c 9ab 9b0
1 9b2 2 9b5
9b6 1 9ba 2
9b8 9ba 2 9bf
9c0 1 9c4 2
9c2 9c4 2 9cd
9ce 2 9d0 9d2
2 9d8 9d9 2
9d5 9db 1 9dd
1 9e0 1 9e2
2 9e6 9e7 2
9ec 9ed 2 9f2
9f3 1 9f5 2
9ef 9f5 2 9fc
9fd 2 a02 a03
1 a05 2 9ff
a05 2 a09 a0a
1 a10 2 a0c
a10 2 a14 a15
1 a1b 2 a17
a1b 2 a2f a34
1 a3b 1 a36
2 a4e a50 3
a4c a4d a52 2
a5b a5d 2 a5f
a61 2 a63 a65
2 a67 a69 2
a6b a6d 3 a72
a73 a74 2 a6f
a76 2 a5a a78
1 a7a 1 a7c
2 a45 a7d 1
a81 1 a40 2
a3e a85 1 a8a
1 a91 1 a93
2 a96 a97 1
a9b 2 a99 a9b
2 a9f aa0 1
aa4 2 aa2 aa4
1 aa8 2 abc
ac1 1 ac8 1
ac3 2 adb add
3 ad9 ada adf
2 ae8 aea 2
aec aee 2 af0
af2 2 af4 af6
2 af8 afa 3
aff b00 b01 2
afc b03 2 ae7
b05 1 b07 1
b09 2 ad2 b0a
1 b0e 1 acd
2 acb b12 2
b19 b1a 2 b1f
b20 2 b1c b22
2 b27 b28 2
b24 b2a 3 b15
b2d b30 1 b32
1 b38 2 b3a
b3b 1 b41 2
b43 b44 2 b3d
b46 2 b49 b4b
1 b4d 2 b53
b54 2 b59 b5a
2 b56 b5c 2
b61 b62 2 b67
b68 1 b6a 2
b64 b6a 2 b6f
b70 2 b75 b76
2 b72 b78 2
b7d b7e 2 b7a
b80 1 b83 2
b87 b88 1 b8b
2 b8d b8e 8
b92 b93 b94 b95
b96 b97 b98 b99
1 ba1 2 ba3
ba4 1 baa 2
bac bad 2 ba6
baf 2 bb2 bb4
1 bb6 2 bbf
bc0 2 bc2 bc5
2 bcf bd0 2
bd4 bd5 6 bcb
bcc bcd bd2 bd7
bd8 4 bde bdf
be0 be1 9 b33
b50 b5f b8f b9c
bb9 bc8 bdb be4
1 be6 4 a22
a88 a94 be7 2
bea beb 2 bf0
bf1 1 bf3 2
bed bf3 2 bf9
bfa 1 bfe 2
bfc bfe 2 c03
c04 2 c09 c0a
2 c06 c0c 2
c14 c15 2 c1a
c1b 2 c20 c21
2 c1d c23 1
c26 2 c17 c26
2 c2b c2c 2
c31 c32 2 c2e
c34 2 c3a c3b
2 c37 c3d 1
c55 2 c54 c55
1 c5d 1 c63
2 c65 c66 2
c52 c67 1 c6e
1 c69 2 c81
c83 3 c7f c80
c85 2 c8e c90
2 c92 c94 2
c96 c98 2 c9a
c9c 2 c9e ca0
3 ca5 ca6 ca7
2 ca2 ca9 2
c8d cab 1 cad
1 caf 2 c78
cb0 1 cb4 1
c73 2 c71 cb8
2 cc2 cc3 2
cc5 cc8 3 c40
cbb ccb 1 ce0
2 cdf ce0 1
ce8 1 cee 2
cf0 cf1 2 cdd
cf2 1 cf9 1
cf4 2 d0c d0e
3 d0a d0b d10
2 d19 d1b 2
d1d d1f 2 d21
d23 2 d25 d27
2 d29 d2b 3
d30 d31 d32 2
d2d d34 2 d18
d36 1 d38 1
d3a 2 d03 d3b
1 d3f 1 cfe
2 cfc d43 1
d46 2 d49 d4a
3 c0f c12 d4b
2 d4e d4f 2
d54 d55 2 d5a
d5b 2 d57 d5d
1 d60 2 d51
d60 2 d65 d66
2 d6b d6c 2
d68 d6e 1 d76
2 d78 d79 1
d7f 2 d81 d82
2 d7b d84 2
d87 d89 2 d8c
d8e 1 d90 1
da5 2 da4 da5
1 dad 1 db3
2 db5 db6 2
da2 db7 1 dbe
1 db9 2 dd1
dd3 3 dcf dd0
dd5 2 dde de0
2 de2 de4 2
de6 de8 2 dea
dec 2 dee df0
3 df5 df6 df7
2 df2 df9 2
ddd dfb 1 dfd
1 dff 2 dc8
e00 1 e04 1
dc3 2 dc1 e08
3 d71 d93 e0b
2 e10 e11 2
e16 e17 2 e13
e19 1 e33 2
e32 e33 1 e3b
1 e41 2 e43
e44 2 e30 e45
1 e4c 1 e47
2 e5f e61 3
e5d e5e e63 2
e6c e6e 2 e70
e72 2 e74 e76
2 e78 e7a 2
e7c e7e 3 e83
e84 e85 2 e80
e87 2 e6b e89
1 e8b 1 e8d
2 e56 e8e 1
e92 1 e51 2
e4f e96 3 e1c
e1f e99 2 e9c
e9d 1 e9e 2
ea0 ea1 1 ea2
2 ea6 ea7 2
eac ead 2 ea9
eaf 1 ec9 2
ec8 ec9 1 ed1
1 ed7 2 ed9
eda 2 ec6 edb
1 ee2 1 edd
2 ef5 ef7 3
ef3 ef4 ef9 2
f02 f04 2 f06
f08 2 f0a f0c
2 f0e f10 2
f12 f14 3 f19
f1a f1b 2 f16
f1d 2 f01 f1f
1 f21 1 f23
2 eec f24 1
f28 1 ee7 2
ee5 f2c 3 eb2
eb5 f2f 2 f32
f33 1 f35 2
f45 f4a 1 f51
1 f4c 2 f64
f66 3 f62 f63
f68 2 f71 f73
2 f75 f77 2
f79 f7b 2 f7d
f7f 2 f81 f83
3 f88 f89 f8a
2 f85 f8c 2
f70 f8e 1 f90
1 f92 2 f5b
f93 1 f97 1
f56 2 f54 f9b
1 fa0 2 faa
faf 1 fb6 1
fb1 2 fc9 fcb
3 fc7 fc8 fcd
2 fd6 fd8 2
fda fdc 2 fde
fe0 2 fe2 fe4
2 fe6 fe8 3
fed fee fef 2
fea ff1 2 fd5
ff3 1 ff5 1
ff7 2 fc0 ff8
1 ffc 1 fbb
2 fb9 1000 3
1008 1009 100a 1
100e 2 100c 100e
1 1013 1 1015
2 1003 1016 2
101a 101b 1 101f
2 101d 101f 2
1027 1028 2 102a
102d 2 103c 1041
1 1048 1 1043
2 105b 105d 3
1059 105a 105f 2
1068 106a 2 106c
106e 2 1070 1072
2 1074 1076 2
1078 107a 3 107f
1080 1081 2 107c
1083 2 1067 1085
1 1087 1 1089
2 1052 108a 1
108e 1 104d 2
104b 1092 2 1031
1095 2 10a3 10a8
1 10af 1 10aa
2 10c2 10c4 3
10c0 10c1 10c6 2
10cf 10d1 2 10d3
10d5 2 10d7 10d9
2 10db 10dd 2
10df 10e1 3 10e6
10e7 10e8 2 10e3
10ea 2 10ce 10ec
1 10ee 1 10f0
2 10b9 10f1 1
10f5 1 10b4 2
10b2 10f9 1 10fc
3 10ff 1098 1100
3 f3c f9e 1101
1 1103 1 1105
3 110c 110d 110e
1 1111 3 1114
1115 1116 1 111a
2 1118 111a 3
111f 1120 1121 1
1124 3 1128 1129
112a 1 112d 2
112f 1130 1 1131
2 1133 1134 2
1143 1144 8 113b
113c 113d 113e 113f
1140 1141 1146 2
114b 114c 1 1150
2 114e 1150 2
115e 1160 3 115c
115d 1162 2 116b
116d 2 116a 116f
1 1171 1 1173
2 1177 1178 3
1155 1174 117b 1
117d 6 f34 1104
1135 1138 1149 117e
2 1180 1181 2
1182 1185 1 118b
2 118d 118e 1
1194 2 1196 1197
2 1190 1199 2
119c 119e 2 11a1
11a3 1 11a5 1
11a8 2 11aa 11ab
2 11c7 11c8 2
11cc 11cd 19 11af
11b0 11b1 11b2 11b3
11b4 11b5 11b6 11b7
11b8 11b9 11ba 11bb
11bc 11bd 11be 11bf
11c0 11c1 11c2 11c3
11c4 11c5 11ca 11cf
2 11de 11e0 3
11dc 11dd 11e2 2
11eb 11ed 2 11ea
11ef 1 11f1 1
11f3 2 11f7 11f8
6 9fa 11ac 11d2
11d5 11f4 11fb 2
11ff 1200 2 1205
1206 1 1208 2
1202 1208 1 1219
2 1218 1219 1
1221 1 1227 2
1229 122a 2 1216
122b 1 1232 1
122d 2 1245 1247
3 1243 1244 1249
2 1252 1254 2
1256 1258 2 125a
125c 2 125e 1260
2 1262 1264 3
1269 126a 126b 2
1266 126d 2 1251
126f 1 1271 1
1273 2 123c 1274
1 1278 1 1237
2 1235 127c 1
128f 2 128e 128f
1 1297 1 129d
2 129f 12a0 2
128c 12a1 1 12a8
1 12a3 2 12bb
12bd 3 12b9 12ba
12bf 2 12c8 12ca
2 12cc 12ce 2
12d0 12d2 2 12d4
12d6 2 12d8 12da
3 12df 12e0 12e1
2 12dc 12e3 2
12c7 12e5 1 12e7
1 12e9 2 12b2
12ea 1 12ee 1
12ad 2 12ab 12f2
2 127f 12f5 2
12fb 12fc 2 1301
1302 1 1304 2
12fe 1304 2 1308
1309 1 130d 2
130b 130d 1 1312
2 1315 1316 1
131a 2 1318 131a
2 131f 1320 1
1324 2 1322 1324
2 1335 1337 3
1333 1334 1339 2
1342 1344 2 1341
1346 1 1348 1
134a 3 132c 134b
1350 1 1352 2
1356 1357 2 1353
135a 2 135c 135d
1 135f 2 1369
136e 1 1375 1
1370 2 1388 138a
3 1386 1387 138c
2 1395 1397 2
1399 139b 2 139d
139f 2 13a1 13a3
2 13a5 13a7 3
13ac 13ad 13ae 2
13a9 13b0 2 1394
13b2 1 13b4 1
13b6 2 137f 13b7
1 13bb 1 137a
2 1378 13bf 1
13ca 2 13c6 13ca
2 13cf 13d0 2
13d5 13d6 1 13d8
2 13d2 13d8 2
13e9 13eb 3 13e7
13e8 13ed 2 13f6
13f8 2 13f5 13fa
1 13fc 1 13fe
3 13e0 13ff 1404
1 1406 2 13c2
1407 1 1409 2
140c 140d 1 1413
2 140f 1413 2
1417 1418 1 141e
2 141a 141e 2
1424 1425 1 1429
2 1427 1429 1
142d 8 1437 1438
1439 143a 143b 143c
143d 143e 1 1441
1 1443 2 1448
1449 2 144e 144f
2 144b 1451 2
1454 1456 2 1459
145b 1 145d 8
1463 1464 1465 1466
1467 1468 1469 146a
2 1473 1474 2
1476 1479 6 147f
1480 1481 1482 1483
1484 2 1493 1498
1 149f 1 149a
2 14b2 14b4 3
14b0 14b1 14b6 2
14bf 14c1 2 14c3
14c5 2 14c7 14c9
2 14cb 14cd 2
14cf 14d1 3 14d6
14d7 14d8 2 14d3
14da 2 14be 14dc
1 14de 1 14e0
2 14a9 14e1 1
14e5 1 14a4 2
14a2 14e9 4 14f0
14f1 14f2 14f3 7
1444 1460 146d 147c
1487 14ec 14f6 2
14f9 14fa 1 14fe
2 14fc 14fe 1
1502 8 150c 150d
150e 150f 1510 1511
1512 1513 1 1516
1 1518 1 151a
3 1521 1522 1523
1 1526 3 1529
152a 152b 1 152f
2 152d 152f 3
1534 1535 1536 1
1539 3 153d 153e
153f 1 1542 2
1544 1545 1 1546
2 1548 1549 1
154b 2 155a 155f
1 1566 1 1561
2 1579 157b 3
1577 1578 157d 2
1586 1588 2 158a
158c 2 158e 1590
2 1592 1594 2
1596 1598 3 159d
159e 159f 2 159a
15a1 2 1585 15a3
1 15a5 1 15a7
2 1570 15a8 1
15ac 1 156b 2
1569 15b0 2 15b7
15b8 2 15bd 15be
2 15ba 15c0 2
15b3 15c3 1 15c5
2 15d7 15d8 8
15cf 15d0 15d1 15d2
15d3 15d4 15d5 15da
2 15df 15e0 1
15e4 2 15e2 15e4
2 15f2 15f4 3
15f0 15f1 15f6 2
15ff 1601 2 15fe
1603 1 1605 1
1607 3 15e9 1608
160d 1 1624 2
1623 1624 1 162c
1 1632 2 1634
1635 2 1621 1636
1 163d 1 1638
2 1650 1652 3
164e 164f 1654 2
165d 165f 2 1661
1663 2 1665 1667
2 1669 166b 2
166d 166f 3 1674
1675 1676 2 1671
1678 2 165c 167a
1 167c 1 167e
2 1647 167f 1
1683 1 1642 2
1640 1687 1 168a
2 168d 168e 7
1519 154a 15c6 15c9
15cc 15dd 168f 2
1691 1692 3 135e
140a 1693 3 1696
12f9 1695 d 73a
73d 79c 83e 8a5
8da 916 919 97f
9b3 9e3 9ea 1697
2 1699 169a 1
16a0 2 16ac 16ae
3 16aa 16ab 16b0
2 16b9 16bb 2
16bd 16bf 2 16c1
16c3 2 16c5 16c9
2 16b8 16cb 1
16cd 1 16cf 8
22c 24b 24e 2f5
169b 16a3 16d0 16d5
40 2a 30 36
3d 44 4b 52
59 5e 63 68
6d 72 77 7c
83 8a 91 97
9d a3 a9 af
b5 bb c1 c7
cd d3 d9 df
e5 eb f1 f7
fd 103 109 10f
115 11b 121 127
12d 133 139 143
14d 154 15a 160
166 16c 172 178
17e 184 18a 190
196 19c 1a2 1a8
1ae 
1
4
0 
16dd
0
1
50
35
47
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

117 1 0
1b 1 0
180 1 0
12f 1 0
e1 1 0
ff 1 0
6a 1 0
129 1 0
db 1 0
c3 1 0
123 1 0
c9 1 0
145 1 0
85 1 0
186 1 0
99 1 0
15c 1 0
18c 1 0
3 1 0
26 1 0
162 1 0
13b 1 0
79 1 0
e7 1 0
d 1 0
b7 1 0
10b 1 0
6f 1 0
ab 1 0
1aa 1 0
8c 1 0
b1 1 0
65 1 0
16e 1 0
9f 1 0
9 1 0
f9 1 0
93 1 0
135 1 0
11 1 0
60 1 0
17a 1 0
2c 1 0
a5 1 0
4d 1 0
38 1 0
bd 1 0
105 1 0
2 0 1
111 1 0
32 1 0
11d 1 0
7e 1 0
74 1 0
168 1 0
d5 1 0
54 1 0
46 1 0
cf 1 0
3f 1 0
156 1 0
5b 1 0
192 1 0
198 1 0
ed 1 0
15 1 0
19e 1 0
1a4 1 0
14f 1 0
f3 1 0
174 1 0
0

/
SHOW ERRORS FUNCTION FC_U_WP_ACTUAL;
ALTER FUNCTION FC_U_WP_ACTUAL COMPILE DEBUG;
/******************************************************************************************************************
update Actual Work, %W, %C in Work Packages
assign_id:      TSK_ASSIGNMENT_ID or TASK_ID
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_WP_ACTUAL ==
CREATE OR REPLACE FUNCTION SP_U_WP_ACTUAL wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
67
2 :e:
1FUNCTION:
1SP_U_WP_ACTUAL:
1ASSIGN_ID:
1VARCHAR2:
1P_WORK_PERCENT:
1PLS_INTEGER:
1P_ACTUAL:
1P_UNITS:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ASSIGN_ID:
132:
1H_NEW_WORK_PERCENT:
10:
1H_ACTUAL:
1H_UNITS:
1H_REC_USER:
1H_ERROR_ID:
1H_ACC_REJ_BITFLAG:
1H_ETC:
1H_PREV_ACTUAL:
1H_TEMP_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_ACTUAL(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
1+:
1FPUT:
1               ENTER:: SP_U_WP_ACTUAL(33) :: cplan.sql(17919) :: :
1A:
1WORK_TODATE:
1TASK_ASSIGNMENTS:
1JOIN:
1TMT_WBS:
1W:
1ELEMENT_ID:
1TASK_ID:
1TSK_ASSIGNMENT_ID:
1TYPE_ID:
1PMO_CNST:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SELECT A.WORK_TODATE:n      INTO h_prev_actual:n      FROM TASK_ASSIGNMENTS A+
1:n      JOIN TMT_WBS W ON W.ELEMENT_ID = A.TASK_ID:n      WHERE TSK_ASSIGNMEN+
1T_ID = h_assign_id:n      AND W.TYPE_ID IN(pmo_cnst.SC_PERSONAL_TASK, pmo_cns+
1t.SC_ACTIVE_ADM_TASK, pmo_cnst.SC_INACTIVE_ADM_TASK):
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
158:
1           EXCEPTION:: SP_U_WP_ACTUAL(59) :: cplan.sql(17945) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1FC_U_WP_ACTUAL:
1=:
1<:
1>:
115:
1FC_U_ASSIGN_ETC:
14:
182:
1       RETURN_STATUS:: SP_U_WP_ACTUAL(83) :: cplan.sql(17969) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
189:
1           EXCEPTION:: SP_U_WP_ACTUAL(90) :: cplan.sql(17976) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1101:
1           EXCEPTION:: SP_U_WP_ACTUAL(102) :: cplan.sql(17988) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2b5
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c a0
4d d :2 a0 d :2 a0 d :2 a0 d
:2 a0 d :2 a0 d :16 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :3 a0 6b
d :2 a0 6b :7 a0 a5 b d a0
7e 51 b4 2e 5a :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e 5a a 10 a0 51 d :2 a0
51 a5 b 7e 51 b4 2e a0
51 d b7 a0 51 d b7 :2 19
3c :2 a0 6b :5 a0 a5 b d b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
2b5
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 56
7c 80 84 88 8b 8f ac 97
9b 9e 9f a7 96 c8 b7 bb
93 c3 b6 e4 d3 d7 b3 df
d2 100 ef f3 cf fb ee 11d
10b eb 10f 110 118 10a 13a 128
107 12c 12d 135 127 156 145 149
124 151 144 172 161 165 141 16d
160 18e 17d 181 15d 189 17c 1aa
199 19d 179 1a5 198 1ca 1b5 1b9
195 1bd 1c5 1b4 1d1 1d5 1b1 1d9
1dd 1e1 1e4 1e9 1ea 1 1ec 1f1
1f5 1f9 1fc 201 205 209 20c 211
212 214 219 21c 220 221 226 22b
22e 233 234 239 23c 240 241 246
249 24e 24f 254 257 25c 25d 262
265 269 26d 271 272 274 279 27a
27c 27d 282 285 28a 28b 290 293
297 29b 29f 2a0 2a2 2a7 2a8 2aa
2ab 2b0 2b3 2b8 2b9 2be 2c1 2c5
2c9 2cd 2ce 2d0 2d5 2d6 2d8 2d9
2de 2e1 2e6 2e7 2ec 2ef 2f4 2f5
2fa 2fd 301 302 307 30a 30f 310
315 318 31d 31e 323 324 329 32b
32f 332 336 33a 33d 341 345 348
34b 350 353 356 359 35a 35f 360
1 362 367 36b 36f 372 377 37c
37f 383 384 389 38a 38f 391 395
398 39c 39d 3a1 3a5 3a9 3ad 3b1
3b5 3b9 3bd 3c1 3c5 3c9 3cd 3d1
3d5 3d9 3dd 3e1 3e5 3e9 3ed 3f1
3f5 3f9 3fd 401 405 409 40d 411
415 419 41d 421 425 429 42d 431
435 441 445 449 44c 450 454 456
45a 45e 462 465 469 46d 46f 470
475 1 479 47d 481 484 488 48c
490 494 497 49b 49f 4a2 4a5 4aa
4ad 4b0 4b3 4b4 4b9 4ba 1 4bc
4c1 4c5 4c9 4cc 4d1 4d6 4d9 4dd
4de 4e3 4e6 4eb 4ec 4f1 4f4 4f9
4fa 4ff 502 506 507 50c 50f 514
515 51a 51d 521 525 528 52b 52c
52e 52f 534 535 53a 53c 540 543
545 549 54b 557 559 55b 55c 561
565 567 573 575 579 57d 581 584
588 58c 590 593 597 59b 59f 5a3
5a7 5ab 5af 5b0 5b2 5b6 5ba 5bd
5c0 5c1 5c6 5c9 5cd 5d1 5d4 5d5
5d7 5db 5de 5e2 5e5 5e6 5e8 5e9
5ee 1 5f1 5f6 5fa 5fd 601 605
609 60c 60d 60f 612 615 616 61b
61f 622 626 628 62c 62f 633 635
639 63d 640 644 648 64b 64f 653
657 65b 65f 660 662 666 668 66c
66f 673 677 67a 67e 682 685 688
68d 690 693 696 697 69c 69d 1
69f 6a4 6a8 6ac 6af 6b4 6b9 6bc
6c0 6c1 6c6 6c9 6ce 6cf 6d4 6d7
6dc 6dd 6e2 6e5 6e9 6ed 6f1 6f5
6f8 6f9 6fb 700 701 703 704 709
70c 711 712 717 71a 71f 720 725
728 72c 72d 732 735 73a 73b 740
741 746 748 74c 74f 753 757 75a
75e 762 765 769 76d 76e 773 775
779 77d 780 784 788 78b 78f 793
796 799 79e 7a1 7a4 7a7 7a8 7ad
7ae 1 7b0 7b5 7b9 7bd 7c0 7c5
7ca 7cd 7d1 7d2 7d7 7d8 7dd 7e1
7e5 7e8 7ed 7f2 7f5 7f9 7fd 800
801 806 809 80e 80f 814 817 81b
81f 822 823 828 829 82e 830 834
837 83b 83f 843 847 84b 84f 853
857 85b 867 86c 870 874 878 87c
87e 87f 884 1 888 88c 890 893
897 89b 89f 8a3 8a6 8aa 8ae 8b1
8b4 8b9 8bc 8bf 8c2 8c3 8c8 8c9
1 8cb 8d0 8d4 8d8 8db 8e0 8e5
8e8 8ec 8ed 8f2 8f3 8f8 8fc 900
903 908 90d 910 914 915 91a 91d
922 923 928 92b 92f 933 936 939
93a 93c 93d 942 943 948 94a 94e
951 955 959 95d 961 965 969 96d
979 97e 982 986 98a 98e 990 994
996 9a2 9a4 9a6 9a7 9ac 9b0 9b2
9be 9c2 9c4 9c5 9ce 
2b5
2
0 1 a 6 10 :3 6 15 :3 6
f :3 6 e :3 6 10 :2 6 1 3
a 13 a :2 1 4 10 19 18
:2 10 :2 4 :2 17 26 17 :2 4 :2 d 1c
d :2 4 :2 c 1b c :2 4 f 18
17 :2 f :2 4 f 18 17 :2 f :2 4
:2 16 25 16 :2 4 :2 a 19 a :2 4
:2 12 21 12 :2 4 :2 11 29 11 :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 56 5c 5f :2 56 6d 85 8
:2 6d d 10 :2 6d 1a 1d :2 6d b
e :2 6d 13 16 1f 27 :2 1f 38
:2 16 :2 6d b e :2 6d 13 16 1f
27 :2 1f 32 :2 16 :2 6d b e :2 6d
13 16 1f 27 :2 1f 31 :2 16 :2 6d
b e :2 6d 13 16 :2 6d 1b 1e
:2 6d 28 2b :2 6d 30 33 :2 6d :2 7
4c :2 4 7 :2 11 23 :2 2d 39 3c
4e 50 51 :2 4e :2 23 :3 7 :2 d 12
1e 5f 62 :2 1e :2 7 54 :3 4 12
:2 4 13 :2 4 1a :2 4 10 :2 4 f
:2 4 12 4 e 10 :2 c 1d 7
c 14 19 1b 28 2a d 21
b d 18 21 33 3c 50 59
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 55
57 58 :2 55 :2 29 :3 d :2 13 18 24
65 68 :2 24 75 78 :2 24 7c 7f
:2 24 8b 8e :2 24 96 99 :2 24 a5
a8 af b8 bb :2 a8 :2 24 :2 d 5b
:2 a :2 7 :4 13 :2 7 4 :3 1 4 14
:2 1d :2 4 :2 d 19 28 35 49 53
5c 27 :2 19 4 8 15 17 :2 15
7 1f 28 32 :2 1f 37 35 40
4f :2 37 :2 35 1e :3 7 1c 7 a
13 1d :2 a 20 22 :2 20 a 13
a 24 a 13 a :5 7 :2 10 1c
2c 39 40 53 :2 1c 7 53 :2 4
7 :2 11 23 :2 2d 39 3c 4e 50
51 :2 4e :2 23 :3 7 :2 d 12 1e 5f
62 :2 1e 6f 72 :2 1e 76 79 :2 1e
83 86 8f 97 :2 a0 :2 8f ab :2 86
:2 1e b3 b6 :2 1e be c1 :2 1e c6
c9 :2 1e d4 d7 :2 1e :2 7 54 :3 4
:2 f 21 :2 2a 34 40 :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
52 54 55 :2 52 :2 26 :3 a :2 10 15
21 62 65 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 58 :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
4f 52 53 :2 4f :2 23 :3 7 :2 d 12
1e 60 63 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 56 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
2b5
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 2
:4 8 :2 1 :7 a :6 b
:6 c :6 d :7 e :7 f
:6 10 :6 11 :6 12 :6 13
:7 15 :b 17 :11 18 19
:2 18 :2 19 :2 18 :2 19
:2 18 :2 1a :2 18 :9 1a
:2 18 :2 1b :2 18 :9 1b
:2 18 :2 1c :2 18 :9 1c
:2 18 :2 1d :2 18 :2 1d
:2 18 :2 1d :2 18 :2 1d
:2 18 :2 1d :4 18 :3 17
:11 20 :b 21 :3 20 :3 24
:3 26 :3 27 :3 28 :3 29
:3 2a :2 2d 2e :2 2f
:7 30 :2 31 :8 32 2d
:5 33 2c 35 :5 36
:3 35 :2 37 :5 39 :11 3a
:24 3b :3 3a :2 38 :6 37
34 :3 16 :5 40 :9 42
43 :3 42 :16 47 :3 48
:9 49 :3 4a 49 :3 4c
4b :3 49 :b 4f :3 47
:11 52 :30 53 :3 52 :a 55
16 :3 58 :11 59 :b 5a
:17 5b :3 59 :2 5d :3 5e
:3 5f 60 5e 5d
5e :3 61 :3 58 :2 62
:5 64 :11 65 :b 66 :18 67
:3 65 :2 69 6a :3 6b
6c 6a 69 6a
:3 6d :2 63 :6 62 57
:7 1 
9d0
4
:3 0 1 :3 0 2
:a 0 2b0 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d :2 0 b
6 :3 0 8 :7 0
11 10 :3 0 4
:3 0 9 :7 0 15
14 :3 0 a :3 0
b :3 0 c :2 0
4 19 1a 0
17 1b 0 2b0
2 1c :2 0 10
:2 0 15 4 :3 0
e :2 0 13 1f
21 :6 0 24 22
0 2ae 0 d
:6 0 10 :2 0 17
6 :3 0 26 :7 0
2a 27 28 2ae
0 f :6 0 10
:2 0 19 6 :3 0
2c :7 0 30 2d
2e 2ae 0 11
:6 0 e :2 0 1b
6 :3 0 32 :7 0
36 33 34 2ae
0 12 :6 0 e
:2 0 1f 4 :3 0
1d 38 3a :6 0
3d 3b 0 2ae
0 13 :6 0 10
:2 0 23 4 :3 0
21 3f 41 :6 0
44 42 0 2ae
0 14 :6 0 10
:2 0 25 6 :3 0
46 :7 0 4a 47
48 2ae 0 15
:6 0 10 :2 0 27
6 :3 0 4c :7 0
50 4d 4e 2ae
0 16 :6 0 10
:2 0 29 6 :3 0
52 :7 0 56 53
54 2ae 0 17
:6 0 5e 5f 0
2b 6 :3 0 58
0 2 :5 0 5c
59 5a 2ae 0
18 :6 0 64 65
0 2d b :3 0
c :2 0 4 60
:7 0 63 61 0
2ae 0 19 :6 0
1a :3 0 1b :3 0
1a :3 0 1c :3 0
67 68 0 2
:4 0 2f 69 6b
66 6d 6c :2 0
1d :3 0 1e :3 0
6f 70 0 1f
:4 0 1a :3 0 20
:3 0 73 74 0
2 :4 0 31 75
77 21 :4 0 22
:2 0 23 :3 0 33
7a 7c :3 0 24
:4 0 22 :2 0 25
:4 0 36 7f 81
:3 0 22 :2 0 3
:3 0 39 83 85
:3 0 22 :2 0 25
:4 0 3c 87 89
:3 0 22 :2 0 26
:4 0 3f 8b 8d
:3 0 22 :2 0 27
:3 0 28 :3 0 5
:3 0 42 91 93
29 :4 0 44 90
96 47 8f 98
:3 0 22 :2 0 26
:4 0 4a 9a 9c
:3 0 22 :2 0 27
:3 0 28 :3 0 7
:3 0 4d a0 a2
29 :4 0 4f 9f
a5 52 9e a7
:3 0 22 :2 0 26
:4 0 55 a9 ab
:3 0 22 :2 0 27
:3 0 28 :3 0 8
:3 0 58 af b1
29 :4 0 5a ae
b4 5d ad b6
:3 0 22 :2 0 26
:4 0 60 b8 ba
:3 0 22 :2 0 25
:4 0 63 bc be
:3 0 22 :2 0 9
:3 0 66 c0 c2
:3 0 22 :2 0 25
:4 0 69 c4 c6
:3 0 22 :2 0 2a
:4 0 6c c8 ca
:3 0 6f 71 cc
:2 0 ce 74 cf
6e ce 0 d0
76 0 20e 1a
:3 0 1b :3 0 d1
d2 0 1a :3 0
2b :3 0 d4 d5
0 2c :2 0 2
:4 0 e :2 0 2d
:2 0 2c :2 0 78
da dc :3 0 7b
d6 de d3 e0
df :2 0 1d :3 0
2e :3 0 e2 e3
0 1f :4 0 2f
:4 0 22 :2 0 23
:3 0 7f e7 e9
:3 0 82 e4 eb
:2 0 ed 85 ee
e1 ed 0 ef
87 0 20e 14
:4 0 f0 f1 0
20e d :3 0 3
:3 0 f3 f4 0
20e f :3 0 5
:3 0 f6 f7 0
20e 11 :3 0 7
:3 0 f9 fa 0
20e 12 :3 0 8
:3 0 fc fd 0
20e 13 :3 0 9
:3 0 ff 100 0
20e 30 :3 0 31
:3 0 17 :3 0 32
:3 0 30 :3 0 33
:3 0 34 :3 0 35
:3 0 35 :3 0 36
:3 0 30 :3 0 37
:3 0 38 :3 0 d
:3 0 35 :3 0 39
:3 0 3a :3 0 3b
:3 0 3a :3 0 3c
:3 0 3a :3 0 3d
:4 0 3e 1 :8 0
11e b :3 0 3f
:3 0 119 11a 0
40 :3 0 11b 11c
0 11e 89 171
41 :3 0 b :3 0
3f :3 0 120 121
0 40 :3 0 122
123 0 125 8c
127 8e 126 125
:2 0 16f 42 :3 0
b :3 0 3f :3 0
12a 12b 0 40
:3 0 12c 12d 0
167 1a :3 0 1b
:3 0 12f 130 0
1a :3 0 2b :3 0
132 133 0 43
:2 0 2 :4 0 44
:2 0 2d :2 0 2c
:2 0 90 138 13a
:3 0 93 134 13c
131 13e 13d :2 0
1d :3 0 2e :3 0
140 141 0 1f
:4 0 45 :4 0 22
:2 0 23 :3 0 97
145 147 :3 0 22
:2 0 46 :4 0 9a
149 14b :3 0 22
:2 0 47 :4 0 9d
14d 14f :3 0 22
:2 0 40 :3 0 a0
151 153 :3 0 22
:2 0 48 :4 0 a3
155 157 :3 0 22
:2 0 49 :3 0 4a
:3 0 2c :2 0 4b
:2 0 a6 15a 15e
aa 159 160 :3 0
ad 142 162 :2 0
164 b0 165 13f
164 0 166 b2
0 167 b4 16a
:3 0 16a 0 16a
169 167 168 :6 0
16c 2 :3 0 b7
16e b9 16d 16c
:2 0 16f bb :2 0
171 0 171 170
11e 16f :6 0 20e
1 :3 0 18 :3 0
b :3 0 3f :3 0
174 175 0 173
176 0 20e b
:3 0 3f :3 0 178
179 0 4c :3 0
d :3 0 f :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
be 17b 182 17a
183 0 20e 18
:3 0 4d :2 0 10
:2 0 c7 186 188
:3 0 189 :2 0 27
:3 0 11 :3 0 10
:2 0 ca 18b 18e
27 :3 0 4e :2 0
17 :3 0 10 :2 0
cd 190 194 d2
191 196 :3 0 197
:2 0 18a 199 198
:2 0 15 :3 0 2c
:2 0 19b 19c 0
1bd 27 :3 0 11
:3 0 10 :2 0 d5
19e 1a1 4f :2 0
10 :2 0 da 1a3
1a5 :3 0 16 :3 0
10 :2 0 1a7 1a8
0 1aa dd 1af
16 :3 0 50 :2 0
1ab 1ac 0 1ae
df 1b0 1a6 1aa
0 1b1 0 1ae
0 1b1 e1 0
1bd b :3 0 3f
:3 0 1b2 1b3 0
51 :3 0 d :3 0
16 :3 0 15 :3 0
13 :3 0 e4 1b5
1ba 1b4 1bb 0
1bd e9 1be 19a
1bd 0 1bf ed
0 20e 1a :3 0
1b :3 0 1c0 1c1
0 1a :3 0 2b
:3 0 1c3 1c4 0
52 :2 0 2 :4 0
53 :2 0 2d :2 0
2c :2 0 ef 1c9
1cb :3 0 f2 1c5
1cd 1c2 1cf 1ce
:2 0 1d :3 0 2e
:3 0 1d1 1d2 0
1f :4 0 54 :4 0
22 :2 0 23 :3 0
f6 1d6 1d8 :3 0
22 :2 0 46 :4 0
f9 1da 1dc :3 0
22 :2 0 55 :4 0
fc 1de 1e0 :3 0
22 :2 0 27 :3 0
28 :3 0 b :3 0
3f :3 0 1e5 1e6
0 ff 1e4 1e8
29 :4 0 101 1e3
1eb 104 1e2 1ed
:3 0 22 :2 0 56
:4 0 107 1ef 1f1
:3 0 22 :2 0 25
:4 0 10a 1f3 1f5
:3 0 22 :2 0 14
:3 0 10d 1f7 1f9
:3 0 22 :2 0 25
:4 0 110 1fb 1fd
:3 0 113 1d3 1ff
:2 0 201 116 202
1d0 201 0 203
118 0 20e 57
:3 0 58 :3 0 204
205 0 b :3 0
3f :3 0 207 208
0 14 :3 0 59
:3 0 11a 206 20c
:2 0 20e 11e 2af
b :3 0 5a :2 0
4 20f 210 0
1a :3 0 1b :3 0
212 213 0 1a
:3 0 2b :3 0 215
216 0 43 :2 0
2 :4 0 5b :2 0
2d :2 0 2c :2 0
12d 21b 21d :3 0
130 217 21f 214
221 220 :2 0 1d
:3 0 2e :3 0 223
224 0 1f :4 0
5c :4 0 22 :2 0
23 :3 0 134 228
22a :3 0 137 225
22c :2 0 245 1d
:3 0 2e :3 0 22e
22f 0 1f :4 0
5d :4 0 22 :2 0
b :3 0 5e :3 0
234 235 0 13a
233 237 :3 0 22
:2 0 56 :4 0 13d
239 23b :3 0 22
:2 0 b :3 0 5f
:3 0 23e 23f 0
140 23d 241 :3 0
143 230 243 :2 0
245 146 246 222
245 0 247 149
0 257 60 :3 0
19 :3 0 b :3 0
5e :3 0 61 :3 0
b :3 0 5f :3 0
62 :3 0 63 :4 0
64 1 :a 0 253
:2 0 257 249 251
:2 0 a :3 0 19
:3 0 255 :2 0 257
14b 259 14f 258
257 :2 0 2ad 42
:3 0 b :3 0 3f
:3 0 25c 25d 0
40 :3 0 25e 25f
0 2a5 1a :3 0
1b :3 0 261 262
0 1a :3 0 2b
:3 0 264 265 0
43 :2 0 2 :4 0
65 :2 0 2d :2 0
2c :2 0 151 26a
26c :3 0 154 266
26e 263 270 26f
:2 0 1d :3 0 2e
:3 0 272 273 0
1f :4 0 66 :4 0
22 :2 0 23 :3 0
158 277 279 :3 0
15b 274 27b :2 0
295 1d :3 0 2e
:3 0 27d 27e 0
1f :4 0 47 :4 0
22 :2 0 40 :3 0
15e 282 284 :3 0
22 :2 0 48 :4 0
161 286 288 :3 0
22 :2 0 49 :3 0
4a :3 0 2c :2 0
4b :2 0 164 28b
28f 168 28a 291
:3 0 16b 27f 293
:2 0 295 16e 296
271 295 0 297
171 0 2a5 60
:3 0 19 :3 0 61
:3 0 b :3 0 5f
:3 0 62 :3 0 63
:4 0 67 1 :a 0
2a1 :2 0 2a5 299
29f :2 0 a :3 0
19 :3 0 2a3 :2 0
2a5 173 2a8 :3 0
2a8 0 2a8 2a7
2a5 2a6 :6 0 2aa
1 :3 0 178 2ac
17a 2ab 2aa :2 0
2ad 17c :2 0 2af
17f 2af 2ae 20e
2ad :6 0 2b0 :2 0
2 1c 2af 2b3
:3 0 2b2 2b0 2b4
:8 0 
18b
4
:3 0 1 3 1
7 1 b 1
f 1 13 5
6 a e 12
16 1 20 1
1e 1 25 1
2b 1 31 1
39 1 37 1
40 1 3e 1
45 1 4b 1
51 1 57 1
5d 1 6a 1
76 2 79 7b
2 7e 80 2
82 84 2 86
88 2 8a 8c
1 92 2 94
95 2 8e 97
2 99 9b 1
a1 2 a3 a4
2 9d a6 2
a8 aa 1 b0
2 b2 b3 2
ac b5 2 b7
b9 2 bb bd
2 bf c1 2
c3 c5 2 c7
c9 4 72 78
7d cb 1 cd
1 cf 2 d9
db 3 d7 d8
dd 2 e6 e8
2 e5 ea 1
ec 1 ee 2
118 11d 1 124
1 11f 2 137
139 3 135 136
13b 2 144 146
2 148 14a 2
14c 14e 2 150
152 2 154 156
3 15b 15c 15d
2 158 15f 2
143 161 1 163
1 165 2 12e
166 1 16a 1
129 2 127 16e
6 17c 17d 17e
17f 180 181 1
187 2 185 187
2 18c 18d 2
192 193 1 195
2 18f 195 2
19f 1a0 1 1a4
2 1a2 1a4 1
1a9 1 1ad 2
1af 1b0 4 1b6
1b7 1b8 1b9 3
19d 1b1 1bc 1
1be 2 1c8 1ca
3 1c6 1c7 1cc
2 1d5 1d7 2
1d9 1db 2 1dd
1df 1 1e7 2
1e9 1ea 2 1e1
1ec 2 1ee 1f0
2 1f2 1f4 2
1f6 1f8 2 1fa
1fc 2 1d4 1fe
1 200 1 202
3 209 20a 20b
e d0 ef f2
f5 f8 fb fe
101 171 177 184
1bf 203 20d 2
21a 21c 3 218
219 21e 2 227
229 2 226 22b
2 232 236 2
238 23a 2 23c
240 2 231 242
2 22d 244 1
246 3 247 252
256 1 211 2
269 26b 3 267
268 26d 2 276
278 2 275 27a
2 281 283 2
285 287 3 28c
28d 28e 2 289
290 2 280 292
2 27c 294 1
296 4 260 297
2a0 2a4 1 2a8
1 25b 2 259
2ac b 23 29
2f 35 3c 43
49 4f 55 5b
62 
1
4
0 
2b3
0
1
14
4
11
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
3e 1 0
2 0 1
57 1 0
4b 1 0
13 1 0
1e 1 0
25 1 0
45 1 0
2b 1 0
3 1 0
31 1 0
f 1 0
7 1 0
b 1 0
37 1 0
5d 1 0
51 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_ACTUAL;
ALTER FUNCTION SP_U_WP_ACTUAL COMPILE DEBUG;
Prompt == FUNCTION FC_U_FD_SD ==
CREATE OR REPLACE FUNCTION FC_U_FD_SD wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
94
2 :e:
1FUNCTION:
1FC_U_FD_SD:
1H_SCHED_START:
1OUT:
1NOCOPY:
1TIMESTAMP:
1H_START_DATE:
1H_FINISH_DATE:
1H_PRJ_ASSIGN_ID:
1VARCHAR2:
1H_PROJECT_ID:
1H_TASK_ID:
1A_TEMP_ID:
1H_SD:
1DATE:
1H_FD:
1H_BIT_FLAG:
1H_RES_ID:
1H_RES_TYPE:
1SH_H_PER_DAY:
1PLS_INTEGER:
1SH_H_PERCENT_UNITS:
1SH_H_REG_COST:
1NUMBER:
1SH_H_REG_SALE:
1SH_H_CAPITAL_EXPENSE:
1SH_H_BILLABLE:
1H_REC_USER:
1SH_H_EFFORT:
1SH_H_WORK_TODATE:
1RETURN:
1H_PER_DAY:
1H_PERCENT_UNITS:
1H_REG_COST:
1H_REG_SALE:
1H_CAPITAL_EXPENSE:
1H_BILLABLE:
1H_EFFORT:
1COALESCE:
10:
1H_WORK_TODATE:
1H_ID:
132:
1H_TPH_DELETE:
1H_COUNT:
1H_WORK_TYPE:
1H_REMAINING:
1H_TEMP_VAR:
1I_BITFLAG:
1I_SAME_FINISH_DATE:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_FD_SD(:
1NULLIF:
1':
1'':
1NULL:
1, :
1TO_CHAR:
1);:
1CHECK_TRACE:
11:
168:
1+:
1FPUT:
1               ENTER:: FC_U_FD_SD(69) :: cplan.sql(18073) :: :
1PMO_CNST:
1>=:
1SC_BIT_30:
1BITAND:
1SC_BIT_NOT_30:
1PMO_ORASTD:
1STRNCMP:
110:
1>:
1IS NOT NULL:
1COUNT:
1DAY_YEAR:
1TASK_DAY_OF_YEAR:
1TSK_ASSIGNMENT_ID:
1ACTUAL_FLAG:
1TO_DATE:
1SUBSTR:
1SELECT COUNT(DAY_YEAR) INTO h_count :n         FROM TASK_DAY_OF_YEAR:n       +
1  WHERE TSK_ASSIGNMENT_ID = a_temp_id AND ACTUAL_FLAG = 0 :n         AND DAY_+
1YEAR >= TO_DATE(SubStr(h_start_date, 1, 10)) AND DAY_YEAR < TO_DATE(SubStr(h_+
1sched_start, 1, 10)):
1PMO_DB2M:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
194:
1           EXCEPTION:: FC_U_FD_SD(95) :: cplan.sql(18099) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1SELECT COUNT(DAY_YEAR) INTO h_temp_var FROM TASK_DAY_OF_YEAR:n         WHERE +
1TSK_ASSIGNMENT_ID = h_prj_assign_id AND ACTUAL_FLAG = 0 :n         AND DAY_YE+
1AR > TO_DATE(SubStr(h_finish_date, 1, 10)):
1110:
1           EXCEPTION:: FC_U_FD_SD(111) :: cplan.sql(18115) :: :
1<:
1118:
1                EXIT:: FC_U_FD_SD(119) :: cplan.sql(18123) :: :
1TASK_ASSIGNMENT_ERROR:
1DB2TIMESTAMP:
1TIME:
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_start, 1, 10)), PMO_ORA+
1STD.TIME(h_start_date)):n      INTO h_sched_start:n      FROM DUAL:
1135:
1           EXCEPTION:: FC_U_FD_SD(136) :: cplan.sql(18140) :: :
1=:
12:
1-:
1!=:
1STRCMP:
1PMO_FUNC:
1BIT_OR:
1FC_FD_TA_TDY:
1NOT:
1TASK_ASSIGNMENTS:
1PLANNED_FINISH:
1UPDATE TASK_ASSIGNMENTS SET:n            PLANNED_FINISH      = h_finish_date+
1:n            WHERE TSK_ASSIGNMENT_ID = a_temp_id:
1FOUND:
1TRUE:
1100:
1182:
1           EXCEPTION:: FC_U_FD_SD(183) :: cplan.sql(18187) :: :
1SCHED_FINISH:
1UPDATE TASK_ASSIGNMENTS SET:n            SCHED_FINISH      = h_finish_date:n +
1           WHERE TSK_ASSIGNMENT_ID = a_temp_id:
1203:
1           EXCEPTION:: FC_U_FD_SD(204) :: cplan.sql(18208) :: :
1SELECT TO_DATE(SubStr(h_sched_start, 1, 10)), TO_DATE(SubStr(h_finish_date, 1+
1, 10)) :n      INTO h_SD, h_FD :n      FROM DUAL:
1221:
1           EXCEPTION:: FC_U_FD_SD(222) :: cplan.sql(18226) :: :
1FC_TPHASE_ASSIGN:
1229:
1                EXIT:: FC_U_FD_SD(230) :: cplan.sql(18234) :: :
1234:
1                EXIT:: FC_U_FD_SD(235) :: cplan.sql(18239) :: :
1STATE:: :
0

0
0
65e
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 b0 3d b4
:2 a0 2c 6a a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 1c :2 a0 51 a5 b 81 b0
a3 a0 1c :2 a0 51 a5 b 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e :2 a0 6e 7e a0 b4 2e
7e 6e b4 2e 6e a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :2 a0 6e 7e a0 b4 2e 7e
6e b4 2e 6e a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 6e a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :2 a0
6e 7e a0 b4 2e 7e 6e b4
2e 6e a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :2 a0 6e
7e a0 b4 2e 7e 6e b4 2e
6e a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :3 a0
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e :3 a0 a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :2 a0 7e a0 6b
b4 2e a0 51 d :5 a0 6b a5
b 5a d b7 19 3c :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a a0 7e b4 2e 5a a 10
a0 51 d a0 51 d :f a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:b a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c b7 19 3c :a a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 :2 51
a5 b 7e 6e b4 2e a0 51
d b7 a0 51 d b7 :2 19 3c
:2 a0 7e a0 b4 2e d a0 7e
51 b4 2e :3 a0 6b :2 a0 a5 b
d a0 51 d :3 a0 6b :2 a0 51
a5 b :2 a0 6b a5 b d b7
:3 a0 6b :2 a0 a5 b d a0 51
d b7 :2 19 3c :11 a0 51 a5 b
:2 a0 51 a5 b a0 51 a5 b
d a0 7e 51 b4 2e :2 a0 51
a5 b 7e 51 b4 2e 7e b4
2e :5 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :5 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 19 3c b7 19 3c
:9 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :5 a0 51 a5 b d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 a4 b1 11 68 4f 1d 17
b5 
65e
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 7b 6f 73
77 37 82 93 87 8b 8f 6e
9a af a3 a7 ab 6b b6 c7
bb bf c3 a2 ce e3 d7 db
df 9f ea fb ef f3 f7 d6
102 117 10b 10f 113 d3 11e 12f
123 127 12b 10a 136 14b 13f 143
147 107 152 15b 157 13e 163 170
16c 13b 178 181 17d 16b 189 196
192 168 19e 1a7 1a3 191 1af 1bc
1b8 18e 1c4 1d5 1c9 1cd 1d1 1b7
1dc 1e9 1e5 1b4 1f1 1fa 1f6 1e4
202 1e1 207 20b 20f 213 230 21b
21f 227 22b 21a 250 23b 23f 247
24b 217 26c 257 25b 263 267 23a
28c 277 27b 283 287 237 2a8 293
297 29f 2a3 276 2c8 2b3 2b7 2bf
2c3 273 2ee 2cf 2d3 2db 2df 2e3
2e6 2e7 2e9 2b2 315 2f9 2fd 305
309 2af 30d 30e 310 2f8 332 320
2f5 324 325 32d 31f 34e 33d 341
31c 349 33c 36a 359 35d 339 365
358 386 375 379 355 381 374 3a2
391 395 371 39d 390 3be 3ad 3b1
38d 3b9 3ac 3da 3c9 3cd 3a9 3d5
3c8 3f6 3e5 3e9 3c5 3f1 3e4 3fd
401 3e1 405 409 40d 410 415 416
1 418 41d 421 425 428 42d 431
435 438 43d 43e 440 445 448 44c
44d 452 457 45a 45e 462 467 46a
46e 46f 474 477 47c 47d 482 487
488 48a 48f 490 492 493 498 49b
4a0 4a1 4a6 4a9 4ad 4b1 4b6 4b9
4bd 4be 4c3 4c6 4cb 4cc 4d1 4d6
4d7 4d9 4de 4df 4e1 4e2 4e7 4ea
4ef 4f0 4f5 4f8 4fc 500 505 508
50c 50d 512 515 51a 51b 520 525
526 528 52d 52e 530 531 536 539
53e 53f 544 547 54c 54d 552 555
559 55a 55f 562 567 568 56d 570
575 576 57b 57e 583 584 589 58c
590 591 596 599 59e 59f 5a4 5a7
5ac 5ad 5b2 5b5 5ba 5bb 5c0 5c3
5c7 5c8 5cd 5d0 5d5 5d6 5db 5de
5e3 5e4 5e9 5ec 5f1 5f2 5f7 5fa
5fe 5ff 604 607 60c 60d 612 615
61a 61b 620 623 627 62b 630 633
637 638 63d 640 645 646 64b 650
651 653 658 659 65b 65c 661 664
669 66a 66f 672 676 67a 67f 682
686 687 68c 68f 694 695 69a 69f
6a0 6a2 6a7 6a8 6aa 6ab 6b0 6b3
6b8 6b9 6be 6c1 6c6 6c7 6cc 6cf
6d3 6d4 6d9 6dc 6e1 6e2 6e7 6ea
6ef 6f0 6f5 6f8 6fd 6fe 703 706
70a 70b 710 713 718 719 71e 721
726 727 72c 72f 734 735 73a 73d
741 742 747 74a 74f 750 755 758
75d 75e 763 766 76a 76e 772 773
775 77a 77b 77d 77e 783 786 78b
78c 791 794 798 79c 7a0 7a1 7a3
7a8 7a9 7ab 7ac 7b1 7b4 7b9 7ba
7bf 7c2 7c6 7ca 7ce 7cf 7d1 7d6
7d7 7d9 7da 7df 7e2 7e7 7e8 7ed
7f0 7f4 7f8 7fc 7fd 7ff 804 805
807 808 80d 810 815 816 81b 81e
822 826 82a 82b 82d 832 833 835
836 83b 83e 843 844 849 84c 850
854 858 859 85b 860 861 863 864
869 86c 871 872 877 87a 87f 880
885 888 88c 88d 892 895 89a 89b
8a0 8a3 8a8 8a9 8ae 8b1 8b5 8b9
8bd 8be 8c0 8c5 8c6 8c8 8c9 8ce
8d1 8d6 8d7 8dc 8df 8e3 8e7 8eb
8ec 8ee 8f3 8f4 8f6 8f7 8fc 8ff
904 905 90a 90b 910 912 916 919
91d 921 924 928 92c 92f 932 937
93a 93d 940 941 946 947 1 949
94e 952 956 959 95e 963 966 96a
96b 970 971 976 978 97c 97f 983
987 98a 98e 991 992 997 99b 99e
9a2 9a6 9aa 9ae 9b2 9b6 9b9 9ba
9bc 9bf 9c3 9c5 9c9 9cc 9d0 9d4
9d7 9db 9df 9e2 9e3 9e5 9e8 9eb
9ec 9f1 9f4 9f8 9fb 9fc a01 1
a04 a09 a0d a10 a14 a18 a1b a1f
a23 a27 a2b a2f a33 a37 a3b a3f
a43 a47 a4b a4f a53 a57 a5b a67
a6b a6f a72 a76 a7a a7c a80 a84
a88 a8b a8f a93 a95 a96 a9b 1
a9f aa3 aa7 aaa aae ab2 ab6 aba
abd ac1 ac5 ac8 acb ad0 ad3 ad6
ad9 ada adf ae0 1 ae2 ae7 aeb
aef af2 af7 afc aff b03 b04 b09
b0c b11 b12 b17 b1a b1f b20 b25
b28 b2c b2d b32 b35 b3a b3b b40
b43 b47 b4b b4e b51 b52 b54 b55
b5a b5b b60 b62 b66 b69 b6b b6f
b71 b7d b7f b81 b82 b87 b8b b8d
b99 b9b b9f ba3 ba7 bab baf bb3
bb7 bbb bbf bc3 bc7 bd3 bd7 bdb
bde be2 be6 be8 bec bf0 bf4 bf7
bfb bff c01 c02 c07 1 c0b c0f
c13 c16 c1a c1e c22 c26 c29 c2d
c31 c34 c37 c3c c3f c42 c45 c46
c4b c4c 1 c4e c53 c57 c5b c5e
c63 c68 c6b c6f c70 c75 c78 c7d
c7e c83 c86 c8b c8c c91 c94 c98
c99 c9e ca1 ca6 ca7 cac caf cb3
cb7 cba cbd cbe cc0 cc1 cc6 cc7
ccc cce cd2 cd5 cd7 cdb cdd ce9
ceb ced cee cf3 cf7 cf9 d05 d07
d0b d0f d12 d13 d15 d19 d1c d20
d23 d24 d26 d27 d2c d30 d34 d38
d3c d40 d43 d47 d4b d4e d51 d56
d59 d5c d5f d60 d65 d66 1 d68
d6d d71 d75 d78 d7d d82 d85 d89
d8a d8f d90 d95 d97 d9b d9e da2
da6 daa dad db1 db3 db7 dba dbc
dc0 dc3 dc7 dcb dcf dd3 dd7 ddb
ddf de3 de7 deb df7 dfb dff e02
e06 e0a e0c e10 e14 e18 e1b e1f
e23 e25 e26 e2b 1 e2f e33 e37
e3a e3e e42 e46 e4a e4d e51 e55
e58 e5b e60 e63 e66 e69 e6a e6f
e70 1 e72 e77 e7b e7f e82 e87
e8c e8f e93 e94 e99 e9c ea1 ea2
ea7 eaa eaf eb0 eb5 eb8 ebc ebd
ec2 ec5 eca ecb ed0 ed3 ed7 edb
ede ee1 ee2 ee4 ee5 eea eeb ef0
ef2 ef6 ef9 efb eff f01 f0d f0f
f11 f12 f17 f1b f1d f29 f2b f2f
f33 f36 f39 f3a f3c f3f f44 f45
f4a f4e f51 f55 f57 f5b f5e f62
f64 f68 f6c f6f f73 f77 f7a f7e
f7f f84 f88 f8c f8f f92 f93 f98
f9c fa0 fa4 fa7 fab faf fb0 fb2
fb6 fba fbd fc1 fc5 fc9 fcd fd0
fd4 fd8 fdb fdc fde fe2 fe6 fe9
fea fec ff0 ff2 ff6 ffa ffe 1001
1005 1009 100a 100c 1010 1014 1017 101b
101d 1021 1025 1028 102c 1030 1034 1038
103c 1040 1044 1048 104c 1050 1054 1058
105c 1060 1064 1068 106c 106f 1070 1072
1076 107a 107d 107e 1080 1084 1087 1088
108a 108e 1092 1095 1098 1099 109e 10a2
10a6 10a9 10aa 10ac 10af 10b2 10b3 10b8
10bb 10bc 10c1 10c5 10c9 10cd 10d1 10d5
10e1 10e5 10ea 10ee 10f1 10f2 10f7 10fb
10ff 1102 1105 1109 110b 110f 1113 1116
1119 111d 111f 1123 1127 112a 112c 1130
1134 1138 113b 113f 1143 1145 1146 114b
1 114f 1153 1157 115a 115e 1162 1166
116a 116d 1171 1175 1178 117b 1180 1183
1186 1189 118a 118f 1190 1 1192 1197
119b 119f 11a2 11a7 11ac 11af 11b3 11b4
11b9 11bc 11c1 11c2 11c7 11ca 11cf 11d0
11d5 11d8 11dc 11dd 11e2 11e5 11ea 11eb
11f0 11f3 11f7 11fb 11fe 1201 1202 1204
1205 120a 120b 1210 1212 1216 1219 121b
121f 1221 122d 122f 1231 1232 1237 123b
123d 1249 124b 124d 1251 1255 1259 125d
1261 126d 1271 1276 127a 127d 127e 1283
1287 128b 128e 1291 1295 1297 129b 129f
12a2 12a5 12a9 12ab 12af 12b3 12b6 12b8
12bc 12c0 12c4 12c7 12cb 12cf 12d1 12d2
12d7 1 12db 12df 12e3 12e6 12ea 12ee
12f2 12f6 12f9 12fd 1301 1304 1307 130c
130f 1312 1315 1316 131b 131c 1 131e
1323 1327 132b 132e 1333 1338 133b 133f
1340 1345 1348 134d 134e 1353 1356 135b
135c 1361 1364 1368 1369 136e 1371 1376
1377 137c 137f 1383 1387 138a 138d 138e
1390 1391 1396 1397 139c 139e 13a2 13a5
13a7 13ab 13ad 13b9 13bb 13bd 13be 13c3
13c7 13c9 13d5 13d7 13d9 13dd 13e1 13e4
13e6 13ea 13ed 13f1 13f5 13f9 13fd 1401
1405 1409 140d 1411 141d 1421 1425 1428
142c 1430 1432 1436 143a 143e 1441 1445
1449 144b 144c 1451 1 1455 1459 145d
1460 1464 1468 146c 1470 1473 1477 147b
147e 1481 1486 1489 148c 148f 1490 1495
1496 1 1498 149d 14a1 14a5 14a8 14ad
14b2 14b5 14b9 14ba 14bf 14c2 14c7 14c8
14cd 14d0 14d5 14d6 14db 14de 14e2 14e3
14e8 14eb 14f0 14f1 14f6 14f9 14fd 1501
1504 1507 1508 150a 150b 1510 1511 1516
1518 151c 151f 1521 1525 1527 1533 1535
1537 1538 153d 1541 1543 154f 1551 1555
1559 155d 1561 1565 1568 1569 156b 156f
1573 1577 157a 157e 1582 1585 1588 158d
1590 1593 1596 1597 159c 159d 1 159f
15a4 15a8 15ac 15af 15b4 15b9 15bc 15c0
15c1 15c6 15c7 15cc 15ce 15d2 15d5 15d9
15dd 15e1 15e4 15e8 15ec 15f0 15f3 15f7
15fb 15fe 1601 1606 1609 160c 160f 1610
1615 1616 1 1618 161d 1621 1625 1628
162d 1632 1635 1639 163a 163f 1642 1647
1648 164d 1650 1655 1656 165b 165e 1662
1666 1669 166a 166f 1670 1675 1677 167b
167e 1682 1686 168a 168d 1691 1693 1697
1699 16a5 16a9 16ab 16ac 16b5 
65e
2
0 1 a 6 17 1b 22 :3 6
16 1a 21 :3 6 17 1b 22 :3 6
19 1d 24 :3 6 16 1a 21 :3 6
13 17 1e :3 6 13 17 1e :3 6
e 12 19 :3 6 e 12 19 :3 6
14 18 1f :3 6 12 16 1d :3 6
14 18 1f :3 6 13 :3 6 19 :3 6
14 :3 6 14 :3 6 1b :3 6 14 :3 6
14 18 1f :3 6 12 :3 6 17 :2 6
1 3 a :2 1 4 :2 e 1d e
:2 4 :2 14 23 14 :2 4 :2 f 19 f
:2 4 :2 f 19 f :2 4 :2 16 25 16
:2 4 :2 f 1e f :2 4 :2 d 1c 25
32 :2 1c d :2 4 :2 12 21 2a 3c
:2 21 12 :2 4 9 12 11 :2 9 :2 4
:2 11 20 11 :2 4 :2 c 1b c :2 4
:2 10 1f 10 :2 4 :2 10 1f 10 :2 4
:2 f 1e f :2 4 :2 e 26 e :2 4
:2 17 2f 17 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 52 58 5b :2 52 69 7d 8
11 18 1d 20 :2 18 2e 31 :2 18
36 :2 11 3f :2 8 :2 69 b e :2 69
13 16 1f 26 2b 2e :2 26 3b
3e :2 26 43 :2 1f 4c :2 16 :2 69 b
e :2 69 13 16 1f 26 2b 2e
:2 26 3c 3f :2 26 44 :2 1f 4d :2 16
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 2e 31 :2 69 b e :2 69
13 16 :2 69 1b 1e :2 69 2b 2e
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 28 2b :2 69 b e :2 69
13 16 :2 69 1b 1e :2 69 28 2b
:2 69 b e :2 69 13 16 1f 26
2b 2e :2 26 33 36 :2 26 3b :2 1f
44 :2 16 :2 69 b e :2 69 13 16
1f 26 2b 2e :2 26 33 36 :2 26
3b :2 1f 44 :2 16 :2 69 b e :2 69
13 16 :2 69 1b 1e :2 69 29 2c
:2 69 b e :2 69 13 16 :2 69 1b
1e :2 69 27 2a :2 69 b e :2 69
13 16 :2 69 1b 1e :2 69 29 2c
:2 69 b e :2 69 13 16 1f 27
:2 1f 36 :2 16 :2 69 b e :2 69 13
16 1f 27 :2 1f 3c :2 16 :2 69 b
e :2 69 13 16 1f 27 :2 1f 37
:2 16 :2 69 b e :2 69 13 16 1f
27 :2 1f 37 :2 16 :2 69 b e :2 69
13 16 1f 27 :2 1f 3e :2 16 :2 69
b e :2 69 13 16 1f 27 :2 1f
37 :2 16 :2 69 b e :2 69 13 16
:2 69 1b 1e :2 69 29 2c :2 69 b
e :2 69 13 16 1f 27 :2 1f 35
:2 16 :2 69 b e :2 69 13 16 1f
27 :2 1f 3a :2 16 :2 69 42 45 :2 69
:2 7 48 :2 4 7 :2 11 23 :2 2d 39
3c 4a 4c 4d :2 4a :2 23 :3 7 :2 d
12 1e 5b 5e :2 1e :2 7 50 :2 4
7 13 10 :2 1c :2 10 7 1d :2 7
14 1b 25 :2 2e :2 14 13 7 26
:2 4 8 :2 13 1b 2a 38 :2 8 3c
3e :2 3c 7 :4 46 45 :3 7 15 :2 7
12 7 11 17 26 f 10 24
32 e 1a 22 29 43 4e 56
5d :2 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
54 56 57 :2 54 :2 2c :3 10 :2 16 1b
27 64 67 :2 27 74 77 :2 27 7b
7e :2 27 8a 8d :2 27 95 98 :2 27
a4 a7 ae b7 ba :2 a7 :2 27 :2 10
5a :2 d :2 a :4 16 :2 a 7 :3 63 11
17 26 36 10 24 38 e 19
21 28 :2 a :2 13 1f a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 54 57 58 :2 54 :2 2c :3 10 :2 16
1b 27 65 68 :2 27 75 78 :2 27
7c 7f :2 27 8b 8e :2 27 96 99
:2 27 a5 a8 af b8 bb :2 a8 :2 27
:2 10 5b :2 d :2 a :4 16 :2 a 7 :3 63
a 13 1f :2 a 24 22 2d 36
:2 24 :2 22 a 12 a d :2 17 29
:2 33 3f 42 50 53 54 :2 50 :2 29
:3 d :2 13 18 24 62 65 :2 24 :2 d
57 :3 a 11 :2 1a a 39 :2 7 63
:2 4 e 19 26 2e 35 4d 58
5d :2 c :2 7 :2 10 1c 7 4 c
a :2 13 1f a 1a :2 7 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 51 54 55 :2 51 :2 29 :3 d :2 13
18 24 62 65 :2 24 72 75 :2 24
79 7c :2 24 88 8b :2 24 93 96
:2 24 a2 a5 ac b5 b8 :2 a5 :2 24
:2 d 58 :2 a :2 7 :4 13 :2 7 4 :3 1
7 e 1a 1d :2 7 20 22 :2 20
7 16 7 26 7 16 7 :5 4
13 1c 1e :2 13 4 7 1a 1d
:2 1a 7 14 :2 1f 26 35 :2 14 :2 7
15 :2 7 16 :2 1f 26 2f 3c :2 26
40 :2 49 :2 16 7 1f 7 14 :2 1f
26 35 :2 14 :2 7 15 7 :5 4 12
1f 2d 38 43 4d 59 5f 1e
2d 3c 49 54 1e 2a 33 40
:2 2a 44 4d 59 :2 44 1e 29 :2 12
4 7 1a 1d :2 1a e 17 24
:2 e 27 2a :2 27 :3 a 14 d 23
13 27 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 57 5a 5b :2 57
:2 2f :3 13 :2 19 1e 2a 68 6b :2 2a
78 7b :2 2a 7f 82 :2 2a 8e 91
:2 2a 99 9c :2 2a a8 ab b2 bb
be :2 ab :2 2a :2 13 5e :2 10 :2 d :4 19
:2 d a :4 2c 14 d 21 13 27
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 57 5a 5b :2 57 :2 2f :3 13
:2 19 1e 2a 68 6b :2 2a 78 7b
:2 2a 7f 82 :2 2a 8e 91 :2 2a 99
9c :2 2a a8 ab b2 bb be :2 ab
:2 2a :2 13 5e :2 10 :2 d :4 19 :2 d a
:7 7 1f :2 4 e 16 1d 35 3d
44 c 12 c :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 51 54 55 :2 51 :2 29
:3 d :2 13 18 24 62 65 :2 24 72
75 :2 24 79 7c :2 24 88 8b :2 24
93 96 :2 24 a2 a5 ac b5 b8
:2 a5 :2 24 :2 d 58 :2 a :2 7 :4 13 :2 7
4 :3 1 4 12 23 31 3c 47
:2 12 4 7 :2 11 23 :2 2d 39 3c
4a 4d 4e :2 4a :2 23 :3 7 :2 d 12
1e 5c 5f :2 1e :2 7 51 :3 4 b
:2 14 4 7 :2 11 23 :2 2d 39 3c
4a 4d 4e :2 4a :2 23 :3 7 :2 d 12
1e 5c 5f :2 1e 6c 6f :2 1e 73
76 :2 1e 80 83 :2 8c :2 1e :2 7 51
:3 4 b :2 14 4 :9 1 
65e
4
0 :2 1 :6 3 :6 4
:6 5 :6 6 :6 7 :6 8
:6 9 :6 a :6 b :6 c
:6 d :6 e :4 f :4 10
:4 11 :4 12 :4 13 :4 14
:6 15 :4 16 :4 17 2
:2 18 :2 1 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:a 20 :a 21 :7 22 :6 23
:6 24 :6 25 :6 26 :6 27
:6 28 :6 29 :b 2b :11 2c
:11 2d :2 2c :2 2e :2 2c
:12 2e :2 2c :2 2f :2 2c
:12 2f :2 2c :2 30 :2 2c
:2 30 :2 2c :2 30 :2 2c
:2 30 :2 2c :2 31 :2 2c
:2 31 :2 2c :2 31 :2 2c
:2 31 :2 2c :2 32 :2 2c
:2 32 :2 2c :2 32 :2 2c
:2 32 :2 2c :2 33 :2 2c
:2 33 :2 2c :2 33 :2 2c
:2 33 :2 2c :2 34 :2 2c
:12 34 :2 2c :2 35 :2 2c
:12 35 :2 2c :2 36 :2 2c
:2 36 :2 2c :2 36 :2 2c
:2 36 :2 2c :2 37 :2 2c
:2 37 :2 2c :2 37 :2 2c
:2 37 :2 2c :2 38 :2 2c
:2 38 :2 2c :2 38 :2 2c
:2 38 :2 2c :2 39 :2 2c
:9 39 :2 2c :2 3a :2 2c
:9 3a :2 2c :2 3b :2 2c
:9 3b :2 2c :2 3c :2 2c
:9 3c :2 2c :2 3d :2 2c
:9 3d :2 2c :2 3e :2 2c
:9 3e :2 2c :2 3f :2 2c
:2 3f :2 2c :2 3f :2 2c
:2 3f :2 2c :2 40 :2 2c
:9 40 :2 2c :2 41 :2 2c
:9 41 :2 2c :2 41 :4 2c
:3 2b :11 44 :b 45 :3 44
:7 4a :3 4b :a 4d :3 4a
:14 4f :3 50 :3 51 :3 53
54 :3 55 :8 56 53
:5 57 52 59 :5 5a
:3 59 :2 5b :5 5d :11 5e
:24 5f :3 5e :2 5c :6 5b
58 :3 4f :4 64 :3 65
:4 66 64 :5 67 63
69 :5 6a :3 69 :2 6b
:5 6d :11 6e :24 6f :3 6e
:2 6c :6 6b 68 :3 4f
:d 74 :3 75 :11 76 :b 77
:3 76 :5 79 :3 74 :3 4f
:8 7d 7e 7f 7d
:5 80 7c 82 :5 83
:3 82 :2 84 :5 86 :11 87
:24 88 :3 87 :2 85 :6 84
81 :3 2a :a 8d :3 8e
8d :3 90 8f :3 8d
:7 93 :5 95 :9 96 :3 98
:f 99 95 :9 9b :3 9d
9a :3 95 :9 a0 :5 a1
:b a2 :2 a3 :3 a0 :5 a5
:c a6 a8 :2 a9 :2 aa
a8 :6 ab :5 ac ab
:5 ae ad :3 ab a7
b1 :5 b2 :3 b1 :2 b3
:5 b5 :11 b6 :24 b7 :3 b6
:2 b4 :6 b3 b0 :4 a6
bd :2 be :2 bf bd
:6 c0 :5 c1 c0 :5 c3
c2 :3 c0 bc c6
:5 c7 :3 c6 :2 c8 :5 ca
:11 cb :24 cc :3 cb :2 c9
:6 c8 c5 :4 bb :3 a6
:3 a5 :6 d3 :2 d4 d5
d3 :5 d6 d2 d8
:5 d9 :3 d8 :2 da :5 dc
:11 dd :24 de :3 dd :2 db
:6 da d7 :3 2a :9 e3
:11 e5 :b e6 :3 e5 :5 e8
:11 ea :19 eb :3 ea :5 ed
:2 2a :7 1 
16b7
4
:3 0 1 :3 0 2
:a 0 659 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
6 :3 0 8 :5 0
1 13 12 :3 0
d 9f 0 b
4 :3 0 5 :3 0
a :3 0 9 :5 0
1 19 18 :3 0
4 :3 0 5 :3 0
a :3 0 b :5 0
1 1f 1e :3 0
11 d3 0 f
4 :3 0 5 :3 0
a :3 0 c :5 0
1 25 24 :3 0
4 :3 0 5 :3 0
a :3 0 d :5 0
1 2b 2a :3 0
15 107 0 13
4 :3 0 5 :3 0
f :3 0 e :5 0
1 31 30 :3 0
4 :3 0 5 :3 0
f :3 0 10 :5 0
1 37 36 :3 0
19 13b 0 17
4 :3 0 5 :3 0
a :3 0 11 :5 0
1 3d 3c :3 0
4 :3 0 5 :3 0
a :3 0 12 :5 0
1 43 42 :3 0
1d 168 0 1b
4 :3 0 5 :3 0
a :3 0 13 :5 0
1 49 48 :3 0
15 :3 0 14 :7 0
4d 4c :3 0 21
18e 0 1f 15
:3 0 16 :7 0 51
50 :3 0 18 :3 0
17 :7 0 55 54
:3 0 25 1b4 0
23 18 :3 0 19
:7 0 59 58 :3 0
15 :3 0 1a :7 0
5d 5c :3 0 29
1e1 0 27 15
:3 0 1b :7 0 61
60 :3 0 4 :3 0
5 :3 0 a :3 0
1c :5 0 1 67
66 :3 0 2d :2 0
2b 15 :3 0 1d
:7 0 6b 6a :3 0
15 :3 0 1e :7 0
6f 6e :3 0 1f
:3 0 15 :3 0 71
73 0 659 2
74 :2 0 45 237
0 43 15 :3 0
77 :7 0 14 :3 0
7b 78 79 657
0 20 :6 0 49
273 0 47 15
:3 0 7d :7 0 16
:3 0 81 7e 7f
657 0 21 :6 0
18 :3 0 83 :7 0
17 :3 0 87 84
85 657 0 22
:6 0 4d 2af 0
4b 18 :3 0 89
:7 0 19 :3 0 8d
8a 8b 657 0
23 :6 0 15 :3 0
8f :7 0 1a :3 0
93 90 91 657
0 24 :6 0 28
:2 0 52 15 :3 0
95 :7 0 1b :3 0
99 96 97 657
0 25 :6 0 15
:3 0 9b :7 0 27
:3 0 1d :3 0 28
:2 0 4f 9d a0
a3 9c a1 657
0 26 :6 0 2b
:2 0 57 15 :3 0
a5 :7 0 27 :3 0
1e :3 0 54 a7
aa ad a6 ab
657 0 29 :6 0
28 :2 0 5b a
:3 0 59 af b1
:6 0 b4 b2 0
657 0 2a :6 0
28 :2 0 5d 15
:3 0 b6 :7 0 ba
b7 b8 657 0
2c :6 0 28 :2 0
5f 15 :3 0 bc
:7 0 c0 bd be
657 0 2d :6 0
28 :2 0 61 15
:3 0 c2 :7 0 c6
c3 c4 657 0
2e :6 0 28 :2 0
63 15 :3 0 c8
:7 0 cc c9 ca
657 0 2f :6 0
28 :2 0 65 15
:3 0 ce :7 0 d2
cf d0 657 0
30 :6 0 28 :2 0
67 15 :3 0 d4
0 2 :5 0 d8
d5 d6 657 0
31 :6 0 df e0
0 69 15 :3 0
da 0 2 :5 0
de db dc 657
0 32 :6 0 33
:3 0 34 :3 0 33
:3 0 35 :3 0 e2
e3 0 2 :4 0
6b e4 e6 e1
e8 e7 :2 0 36
:3 0 37 :3 0 ea
eb 0 38 :4 0
33 :3 0 39 :3 0
ee ef 0 2
:4 0 6d f0 f2
3a :4 0 3b :2 0
3c :3 0 6f f5
f7 :3 0 3d :4 0
3b :2 0 27 :3 0
3e :3 0 3f :4 0
3b :2 0 3 :3 0
72 fe 100 :3 0
3b :2 0 3f :4 0
75 102 104 :3 0
40 :4 0 78 fc
107 41 :4 0 7b
fb 10a 7e fa
10c :3 0 3b :2 0
42 :4 0 81 10e
110 :3 0 3b :2 0
27 :3 0 3e :3 0
3f :4 0 3b :2 0
7 :3 0 84 116
118 :3 0 3b :2 0
3f :4 0 87 11a
11c :3 0 40 :4 0
8a 114 11f 41
:4 0 8d 113 122
90 112 124 :3 0
3b :2 0 42 :4 0
93 126 128 :3 0
3b :2 0 27 :3 0
3e :3 0 3f :4 0
3b :2 0 8 :3 0
96 12e 130 :3 0
3b :2 0 3f :4 0
99 132 134 :3 0
40 :4 0 9c 12c
137 41 :4 0 9f
12b 13a a2 12a
13c :3 0 3b :2 0
42 :4 0 a5 13e
140 :3 0 3b :2 0
3f :4 0 a8 142
144 :3 0 3b :2 0
9 :3 0 ab 146
148 :3 0 3b :2 0
3f :4 0 ae 14a
14c :3 0 3b :2 0
42 :4 0 b1 14e
150 :3 0 3b :2 0
3f :4 0 b4 152
154 :3 0 3b :2 0
b :3 0 b7 156
158 :3 0 3b :2 0
3f :4 0 ba 15a
15c :3 0 3b :2 0
42 :4 0 bd 15e
160 :3 0 3b :2 0
3f :4 0 c0 162
164 :3 0 3b :2 0
c :3 0 c3 166
168 :3 0 3b :2 0
3f :4 0 c6 16a
16c :3 0 3b :2 0
42 :4 0 c9 16e
170 :3 0 3b :2 0
3f :4 0 cc 172
174 :3 0 3b :2 0
d :3 0 cf 176
178 :3 0 3b :2 0
3f :4 0 d2 17a
17c :3 0 3b :2 0
42 :4 0 d5 17e
180 :3 0 3b :2 0
27 :3 0 3e :3 0
3f :4 0 3b :2 0
e :3 0 d8 186
188 :3 0 3b :2 0
3f :4 0 db 18a
18c :3 0 40 :4 0
de 184 18f 41
:4 0 e1 183 192
e4 182 194 :3 0
3b :2 0 42 :4 0
e7 196 198 :3 0
3b :2 0 27 :3 0
3e :3 0 3f :4 0
3b :2 0 10 :3 0
ea 19e 1a0 :3 0
3b :2 0 3f :4 0
ed 1a2 1a4 :3 0
40 :4 0 f0 19c
1a7 41 :4 0 f3
19b 1aa f6 19a
1ac :3 0 3b :2 0
42 :4 0 f9 1ae
1b0 :3 0 3b :2 0
3f :4 0 fc 1b2
1b4 :3 0 3b :2 0
11 :3 0 ff 1b6
1b8 :3 0 3b :2 0
3f :4 0 102 1ba
1bc :3 0 3b :2 0
42 :4 0 105 1be
1c0 :3 0 3b :2 0
3f :4 0 108 1c2
1c4 :3 0 3b :2 0
12 :3 0 10b 1c6
1c8 :3 0 3b :2 0
3f :4 0 10e 1ca
1cc :3 0 3b :2 0
42 :4 0 111 1ce
1d0 :3 0 3b :2 0
3f :4 0 114 1d2
1d4 :3 0 3b :2 0
13 :3 0 117 1d6
1d8 :3 0 3b :2 0
3f :4 0 11a 1da
1dc :3 0 3b :2 0
42 :4 0 11d 1de
1e0 :3 0 3b :2 0
27 :3 0 43 :3 0
14 :3 0 120 1e4
1e6 41 :4 0 122
1e3 1e9 125 1e2
1eb :3 0 3b :2 0
42 :4 0 128 1ed
1ef :3 0 3b :2 0
27 :3 0 43 :3 0
16 :3 0 12b 1f3
1f5 41 :4 0 12d
1f2 1f8 130 1f1
1fa :3 0 3b :2 0
42 :4 0 133 1fc
1fe :3 0 3b :2 0
27 :3 0 43 :3 0
17 :3 0 136 202
204 41 :4 0 138
201 207 13b 200
209 :3 0 3b :2 0
42 :4 0 13e 20b
20d :3 0 3b :2 0
27 :3 0 43 :3 0
19 :3 0 141 211
213 41 :4 0 143
210 216 146 20f
218 :3 0 3b :2 0
42 :4 0 149 21a
21c :3 0 3b :2 0
27 :3 0 43 :3 0
1a :3 0 14c 220
222 41 :4 0 14e
21f 225 151 21e
227 :3 0 3b :2 0
42 :4 0 154 229
22b :3 0 3b :2 0
27 :3 0 43 :3 0
1b :3 0 157 22f
231 41 :4 0 159
22e 234 15c 22d
236 :3 0 3b :2 0
42 :4 0 15f 238
23a :3 0 3b :2 0
3f :4 0 162 23c
23e :3 0 3b :2 0
1c :3 0 165 240
242 :3 0 3b :2 0
3f :4 0 168 244
246 :3 0 3b :2 0
42 :4 0 16b 248
24a :3 0 3b :2 0
27 :3 0 43 :3 0
1d :3 0 16e 24e
250 41 :4 0 170
24d 253 173 24c
255 :3 0 3b :2 0
42 :4 0 176 257
259 :3 0 3b :2 0
27 :3 0 43 :3 0
1e :3 0 179 25d
25f 41 :4 0 17b
25c 262 17e 25b
264 :3 0 3b :2 0
44 :4 0 181 266
268 :3 0 184 ec
26a :2 0 26c 189
26d e9 26c 0
26e 18b 0 655
33 :3 0 34 :3 0
26f 270 0 33
:3 0 45 :3 0 272
273 0 46 :2 0
2 :4 0 47 :2 0
48 :2 0 46 :2 0
18d 278 27a :3 0
190 274 27c 271
27e 27d :2 0 36
:3 0 49 :3 0 280
281 0 38 :4 0
4a :4 0 3b :2 0
3c :3 0 194 285
287 :3 0 197 282
289 :2 0 28b 19a
28c 27f 28b 0
28d 19c 0 655
26 :3 0 4b :3 0
4c :2 0 4d :3 0
28f 291 0 1a0
290 293 :3 0 32
:3 0 46 :2 0 295
296 0 2a2 26
:3 0 4e :3 0 26
:3 0 4b :3 0 4f
:3 0 29b 29c 0
1a3 299 29e 29f
:2 0 298 2a0 0
2a2 1a6 2a3 294
2a2 0 2a4 1a9
0 655 50 :3 0
51 :3 0 2a5 2a6
0 3 :3 0 7
:3 0 52 :2 0 1ab
2a7 2ab 53 :2 0
28 :2 0 1b1 2ad
2af :3 0 2b0 :2 0
9 :3 0 54 :2 0
1b4 2b3 2b4 :3 0
2b5 :2 0 2b1 2b7
2b6 :2 0 30 :3 0
28 :2 0 2b9 2ba
0 3c6 2d :3 0
28 :2 0 2bc 2bd
0 3c6 55 :3 0
56 :3 0 2d :3 0
57 :3 0 58 :3 0
d :3 0 59 :3 0
56 :3 0 5a :3 0
5b :3 0 7 :3 0
56 :3 0 5a :3 0
5b :3 0 3 :4 0
5c 1 :8 0 2d4
5d :3 0 5e :3 0
2cf 2d0 0 5f
:3 0 2d1 2d2 0
2d4 1b6 327 60
:3 0 5d :3 0 5e
:3 0 2d6 2d7 0
5f :3 0 2d8 2d9
0 2db 1b9 2dd
1bb 2dc 2db :2 0
325 61 :3 0 5d
:3 0 5e :3 0 2e0
2e1 0 5f :3 0
2e2 2e3 0 31d
33 :3 0 34 :3 0
2e5 2e6 0 33
:3 0 45 :3 0 2e8
2e9 0 62 :2 0
2 :4 0 63 :2 0
48 :2 0 46 :2 0
1bd 2ee 2f0 :3 0
1c0 2ea 2f2 2e7
2f4 2f3 :2 0 36
:3 0 49 :3 0 2f6
2f7 0 38 :4 0
64 :4 0 3b :2 0
3c :3 0 1c4 2fb
2fd :3 0 3b :2 0
65 :4 0 1c7 2ff
301 :3 0 3b :2 0
66 :4 0 1ca 303
305 :3 0 3b :2 0
5f :3 0 1cd 307
309 :3 0 3b :2 0
67 :4 0 1d0 30b
30d :3 0 3b :2 0
5b :3 0 68 :3 0
46 :2 0 69 :2 0
1d3 310 314 1d7
30f 316 :3 0 1da
2f8 318 :2 0 31a
1dd 31b 2f5 31a
0 31c 1df 0
31d 1e1 320 :3 0
320 0 320 31f
31d 31e :6 0 322
2 :3 0 1e4 324
1e6 323 322 :2 0
325 1e8 :2 0 327
0 327 326 2d4
325 :6 0 3c6 1
:3 0 55 :3 0 56
:3 0 30 :3 0 57
:3 0 58 :3 0 9
:3 0 59 :3 0 56
:3 0 5a :3 0 5b
:3 0 8 :4 0 6a
1 :8 0 33a 5d
:3 0 5e :3 0 335
336 0 5f :3 0
337 338 0 33a
1eb 38d 60 :3 0
5d :3 0 5e :3 0
33c 33d 0 5f
:3 0 33e 33f 0
341 1ee 343 1f0
342 341 :2 0 38b
61 :3 0 5d :3 0
5e :3 0 346 347
0 5f :3 0 348
349 0 383 33
:3 0 34 :3 0 34b
34c 0 33 :3 0
45 :3 0 34e 34f
0 62 :2 0 2
:4 0 6b :2 0 48
:2 0 46 :2 0 1f2
354 356 :3 0 1f5
350 358 34d 35a
359 :2 0 36 :3 0
49 :3 0 35c 35d
0 38 :4 0 6c
:4 0 3b :2 0 3c
:3 0 1f9 361 363
:3 0 3b :2 0 65
:4 0 1fc 365 367
:3 0 3b :2 0 66
:4 0 1ff 369 36b
:3 0 3b :2 0 5f
:3 0 202 36d 36f
:3 0 3b :2 0 67
:4 0 205 371 373
:3 0 3b :2 0 5b
:3 0 68 :3 0 46
:2 0 69 :2 0 208
376 37a 20c 375
37c :3 0 20f 35e
37e :2 0 380 212
381 35b 380 0
382 214 0 383
216 386 :3 0 386
0 386 385 383
384 :6 0 388 4
:3 0 219 38a 21b
389 388 :2 0 38b
21d :2 0 38d 0
38d 38c 33a 38b
:6 0 3c6 1 :3 0
27 :3 0 30 :3 0
28 :2 0 220 38f
392 27 :3 0 6d
:2 0 2d :3 0 28
:2 0 223 394 398
228 395 39a :3 0
2a :3 0 9 :3 0
39c 39d 0 3c3
33 :3 0 34 :3 0
39f 3a0 0 33
:3 0 45 :3 0 3a2
3a3 0 46 :2 0
2 :4 0 6e :2 0
48 :2 0 46 :2 0
22b 3a8 3aa :3 0
22e 3a4 3ac 3a1
3ae 3ad :2 0 36
:3 0 49 :3 0 3b0
3b1 0 38 :4 0
6f :4 0 3b :2 0
3c :3 0 232 3b5
3b7 :3 0 235 3b2
3b9 :2 0 3bb 238
3bc 3af 3bb 0
3bd 23a 0 3c3
1f :3 0 4b :3 0
70 :3 0 3bf 3c0
0 3c1 :2 0 3c3
23c 3c4 39b 3c3
0 3c5 240 0
3c6 242 3c7 2b8
3c6 0 3c8 248
0 655 50 :3 0
71 :3 0 5a :3 0
5b :3 0 3 :3 0
50 :3 0 72 :3 0
7 :3 0 3 :3 0
73 :4 0 74 1
:8 0 3d9 5d :3 0
5e :3 0 3d4 3d5
0 5f :3 0 3d6
3d7 0 3d9 24a
42c 60 :3 0 5d
:3 0 5e :3 0 3db
3dc 0 5f :3 0
3dd 3de 0 3e0
24d 3e2 24f 3e1
3e0 :2 0 42a 61
:3 0 5d :3 0 5e
:3 0 3e5 3e6 0
5f :3 0 3e7 3e8
0 422 33 :3 0
34 :3 0 3ea 3eb
0 33 :3 0 45
:3 0 3ed 3ee 0
62 :2 0 2 :4 0
75 :2 0 48 :2 0
46 :2 0 251 3f3
3f5 :3 0 254 3ef
3f7 3ec 3f9 3f8
:2 0 36 :3 0 49
:3 0 3fb 3fc 0
38 :4 0 76 :4 0
3b :2 0 3c :3 0
258 400 402 :3 0
3b :2 0 65 :4 0
25b 404 406 :3 0
3b :2 0 66 :4 0
25e 408 40a :3 0
3b :2 0 5f :3 0
261 40c 40e :3 0
3b :2 0 67 :4 0
264 410 412 :3 0
3b :2 0 5b :3 0
68 :3 0 46 :2 0
69 :2 0 267 415
419 26b 414 41b
:3 0 26e 3fd 41d
:2 0 41f 271 420
3fa 41f 0 421
273 0 422 275
425 :3 0 425 0
425 424 422 423
:6 0 427 6 :3 0
278 429 27a 428
427 :2 0 42a 27c
:2 0 42c 0 42c
42b 3d9 42a :6 0
655 1 :3 0 5b
:3 0 11 :3 0 46
:2 0 46 :2 0 27f
42e 432 77 :2 0
78 :4 0 285 434
436 :3 0 2e :3 0
78 :2 0 438 439
0 43b 288 440
2e :3 0 28 :2 0
43c 43d 0 43f
28a 441 437 43b
0 442 0 43f
0 442 28c 0
655 2f :3 0 26
:3 0 79 :2 0 29
:3 0 28f 445 447
:3 0 443 448 0
655 32 :3 0 7a
:2 0 28 :2 0 294
44b 44d :3 0 31
:3 0 50 :3 0 7b
:3 0 450 451 0
8 :3 0 10 :3 0
297 452 455 44f
456 0 46a 30
:3 0 78 :2 0 458
459 0 46a 2f
:3 0 7c :3 0 7d
:3 0 45c 45d 0
27 :3 0 2f :3 0
28 :2 0 29a 45f
462 4b :3 0 4d
:3 0 464 465 0
29d 45e 467 45b
468 0 46a 2a0
478 31 :3 0 50
:3 0 7b :3 0 46c
46d 0 3 :3 0
7 :3 0 2a4 46e
471 46b 472 0
477 30 :3 0 46
:2 0 474 475 0
477 2a7 479 44e
46a 0 47a 0
477 0 47a 2aa
0 655 30 :3 0
7e :3 0 b :3 0
c :3 0 d :3 0
12 :3 0 13 :3 0
e :3 0 10 :3 0
3 :3 0 8 :3 0
2e :3 0 20 :3 0
21 :3 0 1c :3 0
27 :3 0 2f :3 0
28 :2 0 2ad 48a
48d 27 :3 0 30
:3 0 28 :2 0 2b0
48f 492 31 :3 0
28 :2 0 2b3 47c
496 47b 497 0
655 32 :3 0 7a
:2 0 28 :2 0 2c7
49a 49c :3 0 27
:3 0 2e :3 0 28
:2 0 2ca 49e 4a1
7a :2 0 28 :2 0
2cf 4a3 4a5 :3 0
7f :2 0 2d2 4a7
4a8 :3 0 80 :3 0
81 :3 0 8 :3 0
58 :3 0 d :4 0
82 1 :8 0 4c5
83 :4 0 4b0 :3 0
84 :3 0 77 :2 0
2d6 4b3 4b4 :3 0
5d :3 0 5e :3 0
4b6 4b7 0 28
:2 0 4b8 4b9 0
4bb 2d9 4c2 5d
:3 0 5e :3 0 4bc
4bd 0 85 :2 0
4be 4bf 0 4c1
2db 4c3 4b5 4bb
0 4c4 0 4c1
0 4c4 2dd 0
4c5 2e0 518 60
:3 0 5d :3 0 5e
:3 0 4c7 4c8 0
5f :3 0 4c9 4ca
0 4cc 2e3 4ce
2e5 4cd 4cc :2 0
516 61 :3 0 5d
:3 0 5e :3 0 4d1
4d2 0 5f :3 0
4d3 4d4 0 50e
33 :3 0 34 :3 0
4d6 4d7 0 33
:3 0 45 :3 0 4d9
4da 0 62 :2 0
2 :4 0 86 :2 0
48 :2 0 46 :2 0
2e7 4df 4e1 :3 0
2ea 4db 4e3 4d8
4e5 4e4 :2 0 36
:3 0 49 :3 0 4e7
4e8 0 38 :4 0
87 :4 0 3b :2 0
3c :3 0 2ee 4ec
4ee :3 0 3b :2 0
65 :4 0 2f1 4f0
4f2 :3 0 3b :2 0
66 :4 0 2f4 4f4
4f6 :3 0 3b :2 0
5f :3 0 2f7 4f8
4fa :3 0 3b :2 0
67 :4 0 2fa 4fc
4fe :3 0 3b :2 0
5b :3 0 68 :3 0
46 :2 0 69 :2 0
2fd 501 505 301
500 507 :3 0 304
4e9 509 :2 0 50b
307 50c 4e6 50b
0 50d 309 0
50e 30b 511 :3 0
511 0 511 510
50e 50f :6 0 513
8 :3 0 30e 515
310 514 513 :2 0
516 312 :2 0 518
0 518 517 4c5
516 :6 0 51a 1
:3 0 315 58c 80
:3 0 88 :3 0 8
:3 0 58 :3 0 d
:4 0 89 1 :8 0
536 83 :4 0 521
:3 0 84 :3 0 77
:2 0 319 524 525
:3 0 5d :3 0 5e
:3 0 527 528 0
28 :2 0 529 52a
0 52c 31c 533
5d :3 0 5e :3 0
52d 52e 0 85
:2 0 52f 530 0
532 31e 534 526
52c 0 535 0
532 0 535 320
0 536 323 589
60 :3 0 5d :3 0
5e :3 0 538 539
0 5f :3 0 53a
53b 0 53d 326
53f 328 53e 53d
:2 0 587 61 :3 0
5d :3 0 5e :3 0
542 543 0 5f
:3 0 544 545 0
57f 33 :3 0 34
:3 0 547 548 0
33 :3 0 45 :3 0
54a 54b 0 62
:2 0 2 :4 0 8a
:2 0 48 :2 0 46
:2 0 32a 550 552
:3 0 32d 54c 554
549 556 555 :2 0
36 :3 0 49 :3 0
558 559 0 38
:4 0 8b :4 0 3b
:2 0 3c :3 0 331
55d 55f :3 0 3b
:2 0 65 :4 0 334
561 563 :3 0 3b
:2 0 66 :4 0 337
565 567 :3 0 3b
:2 0 5f :3 0 33a
569 56b :3 0 3b
:2 0 67 :4 0 33d
56d 56f :3 0 3b
:2 0 5b :3 0 68
:3 0 46 :2 0 69
:2 0 340 572 576
344 571 578 :3 0
347 55a 57a :2 0
57c 34a 57d 557
57c 0 57e 34c
0 57f 34e 582
:3 0 582 0 582
581 57f 580 :6 0
584 a :3 0 351
586 353 585 584
:2 0 587 355 :2 0
589 0 589 588
536 587 :6 0 58b
1 :3 0 358 58d
4a9 51a 0 58e
0 58b 0 58e
35a 0 58f 35d
590 49d 58f 0
591 35f 0 655
5a :3 0 5b :3 0
3 :3 0 5a :3 0
5b :3 0 8 :3 0
e :3 0 10 :3 0
73 :4 0 8c 1
:8 0 5a1 5d :3 0
5e :3 0 59c 59d
0 5f :3 0 59e
59f 0 5a1 361
5f4 60 :3 0 5d
:3 0 5e :3 0 5a3
5a4 0 5f :3 0
5a5 5a6 0 5a8
364 5aa 366 5a9
5a8 :2 0 5f2 61
:3 0 5d :3 0 5e
:3 0 5ad 5ae 0
5f :3 0 5af 5b0
0 5ea 33 :3 0
34 :3 0 5b2 5b3
0 33 :3 0 45
:3 0 5b5 5b6 0
62 :2 0 2 :4 0
8d :2 0 48 :2 0
46 :2 0 368 5bb
5bd :3 0 36b 5b7
5bf 5b4 5c1 5c0
:2 0 36 :3 0 49
:3 0 5c3 5c4 0
38 :4 0 8e :4 0
3b :2 0 3c :3 0
36f 5c8 5ca :3 0
3b :2 0 65 :4 0
372 5cc 5ce :3 0
3b :2 0 66 :4 0
375 5d0 5d2 :3 0
3b :2 0 5f :3 0
378 5d4 5d6 :3 0
3b :2 0 67 :4 0
37b 5d8 5da :3 0
3b :2 0 5b :3 0
68 :3 0 46 :2 0
69 :2 0 37e 5dd
5e1 382 5dc 5e3
:3 0 385 5c5 5e5
:2 0 5e7 388 5e8
5c2 5e7 0 5e9
38a 0 5ea 38c
5ed :3 0 5ed 0
5ed 5ec 5ea 5eb
:6 0 5ef c :3 0
38f 5f1 391 5f0
5ef :2 0 5f2 393
:2 0 5f4 0 5f4
5f3 5a1 5f2 :6 0
655 1 :3 0 30
:3 0 8f :3 0 b
:3 0 c :3 0 d
:3 0 28 :2 0 396
5f7 5fc 5f6 5fd
0 655 33 :3 0
34 :3 0 5ff 600
0 33 :3 0 45
:3 0 602 603 0
46 :2 0 2 :4 0
90 :2 0 48 :2 0
46 :2 0 39b 608
60a :3 0 39e 604
60c 601 60e 60d
:2 0 36 :3 0 49
:3 0 610 611 0
38 :4 0 91 :4 0
3b :2 0 3c :3 0
3a2 615 617 :3 0
3a5 612 619 :2 0
61b 3a8 61c 60f
61b 0 61d 3aa
0 655 1f :3 0
5d :3 0 5e :3 0
61f 620 0 621
:2 0 655 33 :3 0
34 :3 0 623 624
0 33 :3 0 45
:3 0 626 627 0
46 :2 0 2 :4 0
92 :2 0 48 :2 0
46 :2 0 3ac 62c
62e :3 0 3af 628
630 625 632 631
:2 0 36 :3 0 49
:3 0 634 635 0
38 :4 0 93 :4 0
3b :2 0 3c :3 0
3b3 639 63b :3 0
3b :2 0 65 :4 0
3b6 63d 63f :3 0
3b :2 0 94 :4 0
3b9 641 643 :3 0
3b :2 0 5d :3 0
5e :3 0 646 647
0 3bc 645 649
:3 0 3bf 636 64b
:2 0 64d 3c2 64e
633 64d 0 64f
3c4 0 655 1f
:3 0 5d :3 0 5e
:3 0 651 652 0
653 :2 0 655 3c6
658 :3 0 658 3d7
658 657 655 656
:6 0 659 :2 0 2
74 658 65c :3 0
65b 659 65d :8 0

3e8
4
:3 0 1 3 1
9 1 f 1
15 1 1b 1
21 1 27 1
2d 1 33 1
39 1 3f 1
45 1 4b 1
4f 1 53 1
57 1 5b 1
5f 1 63 1
69 1 6d 15
8 e 14 1a
20 26 2c 32
38 3e 44 4a
4e 52 56 5a
5e 62 68 6c
70 1 76 1
7c 1 82 1
88 1 8e 1
94 2 9e 9f
1 9a 2 a8
a9 1 a4 1
b0 1 ae 1
b5 1 bb 1
c1 1 c7 1
cd 1 d3 1
d9 1 e5 1
f1 2 f4 f6
2 fd ff 2
101 103 2 105
106 2 108 109
2 f9 10b 2
10d 10f 2 115
117 2 119 11b
2 11d 11e 2
120 121 2 111
123 2 125 127
2 12d 12f 2
131 133 2 135
136 2 138 139
2 129 13b 2
13d 13f 2 141
143 2 145 147
2 149 14b 2
14d 14f 2 151
153 2 155 157
2 159 15b 2
15d 15f 2 161
163 2 165 167
2 169 16b 2
16d 16f 2 171
173 2 175 177
2 179 17b 2
17d 17f 2 185
187 2 189 18b
2 18d 18e 2
190 191 2 181
193 2 195 197
2 19d 19f 2
1a1 1a3 2 1a5
1a6 2 1a8 1a9
2 199 1ab 2
1ad 1af 2 1b1
1b3 2 1b5 1b7
2 1b9 1bb 2
1bd 1bf 2 1c1
1c3 2 1c5 1c7
2 1c9 1cb 2
1cd 1cf 2 1d1
1d3 2 1d5 1d7
2 1d9 1db 2
1dd 1df 1 1e5
2 1e7 1e8 2
1e1 1ea 2 1ec
1ee 1 1f4 2
1f6 1f7 2 1f0
1f9 2 1fb 1fd
1 203 2 205
206 2 1ff 208
2 20a 20c 1
212 2 214 215
2 20e 217 2
219 21b 1 221
2 223 224 2
21d 226 2 228
22a 1 230 2
232 233 2 22c
235 2 237 239
2 23b 23d 2
23f 241 2 243
245 2 247 249
1 24f 2 251
252 2 24b 254
2 256 258 1
25e 2 260 261
2 25a 263 2
265 267 4 ed
f3 f8 269 1
26b 1 26d 2
277 279 3 275
276 27b 2 284
286 2 283 288
1 28a 1 28c
1 292 2 28e
292 2 29a 29d
2 297 2a1 1
2a3 3 2a8 2a9
2aa 1 2ae 2
2ac 2ae 1 2b2
2 2ce 2d3 1
2da 1 2d5 2
2ed 2ef 3 2eb
2ec 2f1 2 2fa
2fc 2 2fe 300
2 302 304 2
306 308 2 30a
30c 3 311 312
313 2 30e 315
2 2f9 317 1
319 1 31b 2
2e4 31c 1 320
1 2df 2 2dd
324 2 334 339
1 340 1 33b
2 353 355 3
351 352 357 2
360 362 2 364
366 2 368 36a
2 36c 36e 2
370 372 3 377
378 379 2 374
37b 2 35f 37d
1 37f 1 381
2 34a 382 1
386 1 345 2
343 38a 2 390
391 2 396 397
1 399 2 393
399 2 3a7 3a9
3 3a5 3a6 3ab
2 3b4 3b6 2
3b3 3b8 1 3ba
1 3bc 3 39e
3bd 3c2 1 3c4
5 2bb 2be 327
38d 3c5 1 3c7
2 3d3 3d8 1
3df 1 3da 2
3f2 3f4 3 3f0
3f1 3f6 2 3ff
401 2 403 405
2 407 409 2
40b 40d 2 40f
411 3 416 417
418 2 413 41a
2 3fe 41c 1
41e 1 420 2
3e9 421 1 425
1 3e4 2 3e2
429 3 42f 430
431 1 435 2
433 435 1 43a
1 43e 2 440
441 2 444 446
1 44c 2 44a
44c 2 453 454
2 460 461 2
463 466 3 457
45a 469 2 46f
470 2 473 476
2 478 479 2
48b 48c 2 490
491 11 47d 47e
47f 480 481 482
483 484 485 486
487 488 489 48e
493 494 495 1
49b 2 499 49b
2 49f 4a0 1
4a4 2 4a2 4a4
1 4a6 1 4b2
2 4b1 4b2 1
4ba 1 4c0 2
4c2 4c3 2 4af
4c4 1 4cb 1
4c6 2 4de 4e0
3 4dc 4dd 4e2
2 4eb 4ed 2
4ef 4f1 2 4f3
4f5 2 4f7 4f9
2 4fb 4fd 3
502 503 504 2
4ff 506 2 4ea
508 1 50a 1
50c 2 4d5 50d
1 511 1 4d0
2 4ce 515 1
518 1 523 2
522 523 1 52b
1 531 2 533
534 2 520 535
1 53c 1 537
2 54f 551 3
54d 54e 553 2
55c 55e 2 560
562 2 564 566
2 568 56a 2
56c 56e 3 573
574 575 2 570
577 2 55b 579
1 57b 1 57d
2 546 57e 1
582 1 541 2
53f 586 1 589
2 58c 58d 1
58e 1 590 2
59b 5a0 1 5a7
1 5a2 2 5ba
5bc 3 5b8 5b9
5be 2 5c7 5c9
2 5cb 5cd 2
5cf 5d1 2 5d3
5d5 2 5d7 5d9
3 5de 5df 5e0
2 5db 5e2 2
5c6 5e4 1 5e6
1 5e8 2 5b1
5e9 1 5ed 1
5ac 2 5aa 5f1
4 5f8 5f9 5fa
5fb 2 607 609
3 605 606 60b
2 614 616 2
613 618 1 61a
1 61c 2 62b
62d 3 629 62a
62f 2 638 63a
2 63c 63e 2
640 642 2 644
648 2 637 64a
1 64c 1 64e
10 26e 28d 2a4
3c8 42c 442 449
47a 498 591 5f4
5fe 61d 622 64f
654 10 7a 80
86 8c 92 98
a2 ac b3 b9
bf c5 cb d1
d7 dd 
1
4
0 
65c
0
1
14
d
26
0 1 2 1 4 1 6 1
8 1 a 1 c 0 0 0
0 0 0 0 
6d 1 0
2 0 1
c7 1 0
cd 1 0
d3 1 0
f 1 0
b5 1 0
69 1 0
45 1 0
bb 1 0
3 1 0
88 1 0
4b 1 0
57 1 0
7c 1 0
9a 1 0
27 1 0
9 1 0
94 1 0
5f 1 0
33 1 0
8e 1 0
ae 1 0
21 1 0
4f 1 0
a4 1 0
c1 1 0
39 1 0
5b 1 0
3f 1 0
1b 1 0
76 1 0
15 1 0
82 1 0
2d 1 0
63 1 0
d9 1 0
53 1 0
0

/
SHOW ERRORS FUNCTION FC_U_FD_SD;
ALTER FUNCTION FC_U_FD_SD COMPILE DEBUG;
Prompt == FUNCTION FC_U_PARTICIPANT ==
CREATE OR REPLACE FUNCTION FC_U_PARTICIPANT wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
245
2 :e:
1FUNCTION:
1FC_U_PARTICIPANT:
1H_P_ASSIGN_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1H_P_SECURITY_ID:
1H_P_PLANNED_START:
1TIMESTAMP:
1H_P_PLANNED_FINISH:
1SH_H_P_DELAY:
1PLS_INTEGER:
1SH_H_P_UNITS:
1SH_H_P_WORK_PERCENT:
1SH_H_P_ACTUAL:
1H_P_RES_ID:
1H_ID:
1RETURN:
1H_P_DELAY:
1H_P_UNITS:
1H_P_WORK_PERCENT:
1H_P_ACTUAL:
1H_TSK_ASSIGNMENT_ID:
132:
1H_SECURITY_ID:
1A_ELEMENT_ID:
1A_PARTICIPANT_ID:
1255:
1A_PARTICIPANT_NAME:
1A_SECURITY_NAME:
1H_FULL_NAME:
1A_RES_ASSIGNMENT_ID:
1A_SECURITY_ID:
1A_TEMP_ID:
1H_PRJ_ASSIGN_ID:
1H_CREATED_BY:
1H_PROJECT_ID:
1H_CRI_SECURITY_ID:
1H_ACTUAL_START:
1H_START_DATE:
1H_FINISH_DATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_START_DT:
1H_TA_START_DT:
1H_TA_FINISH_DT:
1H_TASK_START_DT:
1H_TASK_FINISH_DT:
1H_SD:
1DATE:
1H_FD:
1H_WEEK_OF:
1H_BIT_FLAG:
11:
1H_RES_TYPE:
1H_BASELINE_FLAG:
1H_TASK_ACTUAL:
10:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_DAYOFYEAR:
1H_LAST_SUBMITTED:
1A_ASSIGNMENT_COUNT:
1A_ELEMENT_TYPE:
1H_RESPONSIBLE:
1A_PARTICIPANT:
1A_RESOURCE_TYPE:
1A_SECURITY_VALUE:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_TRANSFED_CRI:
1H_TASK_ID:
1H_RES_ID:
1H_REC_USER:
1H_EFFORT:
1H_CONTOUR:
1H_DELAY:
1H_PERCENT_UNITS:
1H_WORK_PERCENT:
1H_WORK_TODATE:
1H_NEW_ACTUAL:
1H_WORK:
1H_LAST_DAY:
1H_MINUTES:
1H_LAST_MINUTES:
1H_TASK_TYPE:
1H_PER_DAY:
1H_WORK_TYPE:
1H_ASSIGN_COUNT:
1H_DURATION:
1H_BITFLAG:
1H_CONSIDER:
1H_EUNIT:
1H_UNIT:
1H_SCHED_EFFORT:
1H_ETC:
1H_ROLLUP_BITS:
1H_CLOSE_TASK:
1H_DAY_MIN:
1H_COUNT:
1H_REMAINING:
1H_PRIORITY:
1H_PA_UNITS:
1H_CONF_FLAG:
1H_ASSIGN_STRING:
18192:
1H_TEMP_RES_TYPE:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_REG_COST:
1NUMBER:
1H_REG_SALE:
1H_SPEC_COST:
1H_SPEC_SALE:
1H_B_REG_COST:
1H_B_REG_SALE:
1H_B_SPEC_COST:
1H_B_SPEC_SALE:
1STMT:
18000:
1I_GET_DATE:
1I_RESCHED:
1I_BITFLAG:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
1CURSOR:
1CFDSDT:
1PMO_ORASTD:
1DB2TIMESTAMP:
1DAY_YEAR:
1TIME:
1PMO_STPU:
1FIRST_AVAIL_TIME:
1BIT_SCHED:
1CALENDAR_DAY_OF_YEAR:
1ELEMENT_ID:
1TO_DATE:
1SUBSTR:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.FIRST_AVAIL+
1_TIME(BIT_SCHED))) :n         FROM CALENDAR_DAY_OF_YEAR:n         WHERE ELEME+
1NT_ID = h_project_id:n         AND DAY_YEAR >= TO_DATE(SubStr(h_sched_start, +
11, 10)):n         ORDER BY DAY_YEAR ASC:
1CFDFDT:
1LAST_AVAIL_TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.LAST_AVAIL_+
1TIME(BIT_SCHED))) :n         FROM CALENDAR_DAY_OF_YEAR:n         WHERE ELEMEN+
1T_ID = h_project_id:n         AND DAY_YEAR <= TO_DATE(SubStr(h_sched_finish, +
11, 10)):n         ORDER BY DAY_YEAR DESC:
1C_P_DELAY:
1PMO_DB2M:
1REF_CURSOR:
1C_R_DELAY:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_U_PARTICIPANT(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
1155:
1+:
1FPUT:
1               ENTER:: FC_U_PARTICIPANT(156) :: cplan.sql(18405) :: :
1:
1RA:
1RES_ASSIGNMENT_ID:
1PARTICIPANT:
1ELEMENT_TYPE:
1RESOURCE_TYPE:
1CRI_SECURITY_ID:
1RESOURCE_ID:
1PROJECT_ID:
1TABLE_TYPE:
1RESOURCE_ASSIGNMENTS:
1SELECT ra.RES_ASSIGNMENT_ID, ra.PARTICIPANT, ra.ELEMENT_ID, ra.ELEMENT_TYPE,+
1:n      CASE WHEN ra.RESOURCE_TYPE = '0' THEN 0 ELSE 1 END,:n      CASE WHEN +
1ra.CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END,:n      ra.RESOURCE_ID,:n      r+
1a.PROJECT_ID, ra.TABLE_TYPE:n      INTO a_res_assignment_id, a_participant, a+
1_element_id, a_element_type,:n      a_resource_type,:n      h_transfed_cri,:n+
1      a_participant_id,:n      h_project_id, h_table_type:n      FROM RESOURC+
1E_ASSIGNMENTS ra:n      WHERE ra.RES_ASSIGNMENT_ID = a_temp_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1189:
1           EXCEPTION:: FC_U_PARTICIPANT(190) :: cplan.sql(18439) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1PROJECT_ASSIGNMENT_ID:
1BIT_FLAG:
1LAST_SUBMITTED:
1C_CONTOUR:
1C_EFFORT:
1T_UNIT:
1C_UNIT:
1CONTOUR_TYPE:
1ASSIGN_UNITS:
1UNITS_MSP:
1ACTUAL_START:
1WORK_TODATE:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1PLANNED_WORK:
1SCHED_WORK:
1ASSIGNMENT_DELAY:
1LAST_SCHED_MIN:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1B_REGULAR_COST:
1B_SPECIAL_COST:
1B_REGULAR_RATE:
1B_SPECIAL_RATE:
1MILESTONE_PERCENT:
1TASK_ID:
1ROLLUP_BITS:
1BASELINE3_START:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT RES_ASSIGNMENT_ID, PROJECT_ASSIGNMENT_ID, PROJECT_ID, RESOURCE_ID, RES+
1OURCE_TYPE, BIT_FLAG, :n         LAST_SUBMITTED, C_CONTOUR, C_EFFORT, T_UNIT,+
1 C_UNIT, CONTOUR_TYPE, :n         CASE WHEN ASSIGN_UNITS > UNITS_MSP THEN ASS+
1IGN_UNITS ELSE UNITS_MSP END, ACTUAL_START, WORK_TODATE, UNRESOLVED_START, UN+
1RESOLVED_FINISH,:n         CASE WHEN BIT_FLAG = '0' THEN PLANNED_WORK ELSE SC+
1HED_WORK END, ASSIGNMENT_DELAY,LAST_SCHED_MIN,:n         TO_DATE(SubStr(UNRES+
1OLVED_START, 1, 10)), TO_DATE(SubStr(UNRESOLVED_FINISH, 1, 10)), BILLABLE, CA+
1PITAL_EXPENSE,:n         REGULAR_COST, SPECIAL_COST, REGULAR_RATE, SPECIAL_RA+
1TE,:n         B_REGULAR_COST, B_SPECIAL_COST, B_REGULAR_RATE, B_SPECIAL_RATE,+
1:n         MILESTONE_PERCENT, TASK_ID, ROLLUP_BITS, CASE WHEN RESOURCE_TYPE =+
1 '1' AND BASELINE3_START IS NOT NuLL THEN '1' ELSE '0' END:n         INTO a_r+
1es_assignment_id, h_prj_assign_id, h_project_id, h_res_id,h_res_type, h_bit_f+
1lag, :n         h_last_submitted, h_contour, h_work, h_eunit, h_unit, h_bitfl+
1ag,:n         h_percent_units, h_actual_start, h_work_todate, h_start_date, h+
1_finish_date,:n         h_effort, h_delay, h_last_day,:n         h_SD, h_FD, +
1h_billable, h_capital_expense,:n         h_reg_cost, h_spec_cost, h_reg_sale,+
1 h_spec_sale,:n         h_b_reg_cost, h_b_spec_cost, h_b_reg_sale, h_b_spec_s+
1ale,:n         h_work_percent, h_task_id, h_rollup_bits, h_baseline_flag:n   +
1      FROM TASK_ASSIGNMENTS:n         WHERE TSK_ASSIGNMENT_ID = a_temp_id:
1222:
1           EXCEPTION:: FC_U_PARTICIPANT(223) :: cplan.sql(18472) :: :
1TASK_TYPE:
1MINUTE_PER_DAY:
1START_DT:
1FINISH_DT:
1UNRESOLVED_DURATION:
1PRIORITY:
1CONFIG_FLAG:
1ASSIGN_COUNT:
1SD:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1WORK_PERCENT:
1ETC:
1FORECAST_START:
1FORECAST_FINISH:
1TMT_WBS:
1SELECT PROJECT_ID, TASK_TYPE, MINUTE_PER_DAY, START_DT, FINISH_DT, UNRESOLVED+
1_DURATION, PRIORITY, CONFIG_FLAG, :n            ASSIGN_COUNT, SD, WORK_TODATE+
1, PLANNED_EFFORT + SCHED_EFFORT, WORK_PERCENT, ETC, COALESCE(FORECAST_START,F+
1ORECAST_FINISH):n            INTO h_project_id, h_task_type, h_per_day, h_sta+
1rt_date, h_finish_date, h_duration, h_priority, h_conf_flag,:n            h_a+
1ssign_count, h_work_type, h_work_todate, h_effort, h_work_percent, h_etc, h_s+
1tart_DT:n            FROM TMT_WBS WHERE ELEMENT_ID = a_temp_id:
1242:
1           EXCEPTION:: FC_U_PARTICIPANT(243) :: cplan.sql(18492) :: :
1250:
1                EXIT:: FC_U_PARTICIPANT(251) :: cplan.sql(18500) :: :
1PMO_CNST:
1RECORD_NOT_FOUND:
1BITAND:
1SC_WBS_ENFORCE_TC_TS:
1258:
1                EXIT:: FC_U_PARTICIPANT(259) :: cplan.sql(18508) :: :
1SC_TIMESHEET_STEP_EXISTS:
1STRNCMP:
110:
1>:
1!=:
1269:
1                EXIT:: FC_U_PARTICIPANT(270) :: cplan.sql(18519) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1IS NOT NULL:
1-:
1278:
1                EXIT:: FC_U_PARTICIPANT(279) :: cplan.sql(18528) :: :
1CANNOT_UPDATE_ASSIGN_ACCEPT_RE:
1287:
1                EXIT:: FC_U_PARTICIPANT(288) :: cplan.sql(18537) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.FIRST_AVAIL+
1_TIME(BIT_SCHED))) INTO h_sched_start:n                     FROM CALENDAR_DAY+
1_OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n             +
1        AND DAY_YEAR = TO_DATE(SubStr(h_sched_start, 1, 10)):
1306:
1           EXCEPTION:: FC_U_PARTICIPANT(307) :: cplan.sql(18556) :: :
1DUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_start, 1, 10)), PMO_ORA+
1STD.TIME('08::00')) INTO h_sched_start:n                        FROM DUAL:
1323:
1           EXCEPTION:: FC_U_PARTICIPANT(324) :: cplan.sql(18573) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.LAST_AVAIL_+
1TIME(BIT_SCHED))) INTO h_sched_finish:n                     FROM CALENDAR_DAY+
1_OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n             +
1        AND DAY_YEAR = TO_DATE(SubStr(h_sched_finish, 1, 10)):
1346:
1           EXCEPTION:: FC_U_PARTICIPANT(347) :: cplan.sql(18596) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_finish, 1, 10)), PMO_OR+
1ASTD.TIME('17::00')) INTO h_sched_finish:n                        FROM DUAL:
1363:
1           EXCEPTION:: FC_U_PARTICIPANT(364) :: cplan.sql(18613) :: :
1SC_SS:
1SCHED_START:
1SCHED_FINISH:
1SCHED_DURATION:
1UPDATE TMT_WBS SET SCHED_START = h_sched_start, SCHED_FINISH = h_sched_finish+
1, SCHED_DURATION = h_duration:n                     WHERE ELEMENT_ID = a_temp+
1_id:
1FOUND:
1TRUE:
1100:
1388:
1           EXCEPTION:: FC_U_PARTICIPANT(389) :: cplan.sql(18638) :: :
1PLANNED_START:
1PLANNED_FINISH:
1PLANNED_DURATION:
1UPDATE TMT_WBS SET PLANNED_START = h_sched_start, PLANNED_FINISH = h_sched_fi+
1nish, PLANNED_DURATION = h_duration:n                     WHERE ELEMENT_ID = +
1a_temp_id:
1408:
1           EXCEPTION:: FC_U_PARTICIPANT(409) :: cplan.sql(18658) :: :
1OPEN:
1446:
1           EXCEPTION:: FC_U_PARTICIPANT(447) :: cplan.sql(18696) :: :
1CLOSE:
1463:
1           EXCEPTION:: FC_U_PARTICIPANT(464) :: cplan.sql(18713) :: :
1SC_FIXED_DURATION:
1SC_FD_EFFORT_DRIVEN:
1PMO_FUNC:
1BIT_OR:
1SC_BIT_30:
1COUNT:
1TASK_DAY_OF_YEAR:
1ACTUAL_FLAG:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n                 +
1       SELECT 'X' FROM TASK_DAY_OF_YEAR:n                        WHERE PROJEC+
1T_ID = h_project_id AND TASK_ID = a_temp_id :n                        AND ACT+
1UAL_FLAG = 1 AND DAY_YEAR > TO_DATE(SubStr(h_sched_finish, 1, 10))):
1490:
1           EXCEPTION:: FC_U_PARTICIPANT(491) :: cplan.sql(18740) :: :
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n                 +
1          SELECT 'X' FROM TASK_ASSIGNMENTS:n                           WHERE +
1PROJECT_ID = h_project_id AND TASK_ID = a_temp_id :n                         +
1  AND TO_DATE(SubStr(START_DT, 1, 10)) > TO_DATE(SubStr(h_sched_finish, 1, 10+
1))):
1509:
1           EXCEPTION:: FC_U_PARTICIPANT(510) :: cplan.sql(18759) :: :
1518:
1                EXIT:: FC_U_PARTICIPANT(519) :: cplan.sql(18768) :: :
1CANNOT_UPDATE_HAS_ACTUAL:
1553:
1           EXCEPTION:: FC_U_PARTICIPANT(554) :: cplan.sql(18803) :: :
1569:
1           EXCEPTION:: FC_U_PARTICIPANT(570) :: cplan.sql(18819) :: :
1TRUNC:
1/:
1*:
1<:
1FC_START_FINISH_DT:
1TA:
1PA:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n                 +
1 SELECT 'X' FROM TASK_ASSIGNMENTS ta:n                  WHERE ta.PROJECT_ID =+
1 h_project_id AND ta.TASK_ID = a_temp_id:n                  AND ta.PROJECT_AS+
1SIGNMENT_ID IS NOT NuLL AND EXISTS (:n                  SELECT 'X' FROM TASK_+
1ASSIGNMENTS pa:n                  WHERE pa.PROJECT_ID = h_project_id AND pa.T+
1SK_ASSIGNMENT_ID = ta.PROJECT_ASSIGNMENT_ID :n                  AND (TO_DATE(+
1SubStr(h_sched_start, 1, 10)) < TO_DATE(SubStr(pa.START_DT, 1, 10)) OR TO_DAT+
1E(SubStr(h_sched_finish, 1, 10)) > TO_DATE(SubStr(pa.FINISH_DT, 1, 10))))):
1612:
1           EXCEPTION:: FC_U_PARTICIPANT(613) :: cplan.sql(18862) :: :
1620:
1                EXIT:: FC_U_PARTICIPANT(621) :: cplan.sql(18870) :: :
1TASK_ASSIGNMENT_ERROR:
1FC_CHANGE_TA_DATES:
1631:
1                EXIT:: FC_U_PARTICIPANT(632) :: cplan.sql(18881) :: :
1ELSIF:
1641:
1                EXIT:: FC_U_PARTICIPANT(642) :: cplan.sql(18891) :: :
1SC_TASK_ACTUAL_GRATER_THAN_SCH:
1A:
1ACTIVITIES:
1TYPE_ID:
1SC_TIMESHEET_ACTIVITY:
1SELECT COUNT('X') INTO h_temp_var:n               FROM DUAL:n               W+
1HERE EXISTS(SELECT A.ELEMENT_ID FROM TASK_ASSIGNMENTS TA, ACTIVITIES A:n     +
1          WHERE TA.TASK_ID = a_temp_id:n               AND TA.TSK_ASSIGNMENT_+
1ID = A.TSK_ASSIGNMENT_ID:n               AND A.TSK_ASSIGNMENT_ID <> A.ELEMENT+
1_ID:n               AND A.TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY):
1667:
1           EXCEPTION:: FC_U_PARTICIPANT(668) :: cplan.sql(18917) :: :
1675:
1                EXIT:: FC_U_PARTICIPANT(676) :: cplan.sql(18925) :: :
1JOIN:
1TIMESHEET_APPROVAL_STATUS:
1APV:
1WEEK_OF:
1SELECT COUNT('X') INTO h_temp_var FROM DUAL WHERE EXISTS (:n               SE+
1LECT 'X' FROM TASK_ASSIGNMENTS ta JOIN TIMESHEET_APPROVAL_STATUS apv:n       +
1        ON apv.ELEMENT_ID = ta.PROJECT_ID AND apv.RESOURCE_ID = ta.RESOURCE_I+
1D:n               WHERE ta.PROJECT_ID = h_project_id AND ta.TASK_ID = a_temp_+
1id AND:n               (TO_DATE(SubStr(ta.ACTUAL_START, 1, 10)) - 7     ) <= +
1apv.WEEK_OF):
1696:
1           EXCEPTION:: FC_U_PARTICIPANT(697) :: cplan.sql(18946) :: :
1704:
1                EXIT:: FC_U_PARTICIPANT(705) :: cplan.sql(18954) :: :
1TS_APPROVAL_ERROR:
1FC_U_TASK_PERCENT:
1FC_ROLLUP:
1721:
1                EXIT:: FC_U_PARTICIPANT(722) :: cplan.sql(18971) :: :
1732:
1                EXIT:: FC_U_PARTICIPANT(733) :: cplan.sql(18982) :: :
1NOT:
1SELECT UNRESOLVED_START, UNRESOLVED_FINISH, UNITS_MSP INTO h_ta_start_DT, h_t+
1a_finish_DT, h_pa_units:n               FROM TASK_ASSIGNMENTS:n              +
1 WHERE TSK_ASSIGNMENT_ID = h_prj_assign_id:
1749:
1           EXCEPTION:: FC_U_PARTICIPANT(750) :: cplan.sql(18999) :: :
1SC_SQL_SUCCESS:
1757:
1                EXIT:: FC_U_PARTICIPANT(758) :: cplan.sql(19007) :: :
1766:
1                EXIT:: FC_U_PARTICIPANT(767) :: cplan.sql(19016) :: :
1773:
1                EXIT:: FC_U_PARTICIPANT(774) :: cplan.sql(19023) :: :
1DURATION:
1SELECT MINUTE_PER_DAY, TASK_TYPE, WORK_TODATE, START_DT, FINISH_DT, CONFIG_FL+
1AG, DURATION:n            INTO h_per_day, h_task_type, h_task_actual, h_task_+
1start_DT, h_task_finish_DT, h_conf_flag, h_duration:n            FROM TMT_WBS+
1:n            WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1792:
1           EXCEPTION:: FC_U_PARTICIPANT(793) :: cplan.sql(19042) :: :
1801:
1                EXIT:: FC_U_PARTICIPANT(802) :: cplan.sql(19051) :: :
1822:
1                EXIT:: FC_U_PARTICIPANT(823) :: cplan.sql(19072) :: :
1SELECT COUNT(DAY_YEAR) INTO h_count :n                     FROM CALENDAR_DAY_+
1OF_YEAR:n                     WHERE ELEMENT_ID = h_project_id:n              +
1       AND DAY_YEAR BETWEEN TO_DATE(SubStr(h_task_start_DT, 1, 10)) AND TO_DA+
1TE(SubStr(h_task_finish_DT, 1, 10)):
1843:
1           EXCEPTION:: FC_U_PARTICIPANT(844) :: cplan.sql(19093) :: :
1FC_U_FD_SD:
1864:
1                EXIT:: FC_U_PARTICIPANT(865) :: cplan.sql(19114) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_sched_finish, 1, 10)), PMO_OR+
1ASTD.TIME(h_finish_date)):n                  INTO h_sched_finish:n           +
1       FROM DUAL:
1885:
1           EXCEPTION:: FC_U_PARTICIPANT(886) :: cplan.sql(19135) :: :
1STRCMP:
1FC_U_TDY_LAST_ACTUAL:
12:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                        INTO h_start_dat+
1e:n                        FROM DUAL:
1912:
1           EXCEPTION:: FC_U_PARTICIPANT(913) :: cplan.sql(19162) :: :
1FC_FD_TA_TDY:
1FD:
1SC_UHF:
1ACTUAL_FINISH:
1UPDATE TASK_ASSIGNMENTS SET FD = pmo_cnst.SC_UHF, ACTUAL_FINISH = h_sched_fin+
1ish, ETC = 0, :n                        MILESTONE_PERCENT = 10000, SCHED_WORK+
1 = WORK_TODATE, SCHED_FINISH = h_sched_finish :n                        WHERE+
1 TSK_ASSIGNMENT_ID = a_temp_id:
1946:
1           EXCEPTION:: FC_U_PARTICIPANT(947) :: cplan.sql(19196) :: :
1SC_SF:
1UPDATE TASK_ASSIGNMENTS SET FD = pmo_cnst.SC_SF, ACTUAL_FINISH = NULL, MILEST+
1ONE_PERCENT = (WORK_TODATE * 10000)/SCHED_WORK :n                        WHER+
1E TSK_ASSIGNMENT_ID = a_temp_id:
1967:
1           EXCEPTION:: FC_U_PARTICIPANT(968) :: cplan.sql(19217) :: :
1FC_TPHASE_ASSIGN:
1981:
1                EXIT:: FC_U_PARTICIPANT(982) :: cplan.sql(19231) :: :
1FC_DELAY:
1FC_FD_LOADCALENDAR:
1GET_FD_DURATION:
1IS NULL:
11014:
1                EXIT:: FC_U_PARTICIPANT(1015) :: cplan.sql(19264) :: :
1CANNOT_ASSIGN_RESOURCE_CALENDA:
11028:
1                EXIT:: FC_U_PARTICIPANT(1029) :: cplan.sql(19278) :: :
1SELECT START_DT INTO h_start_date:n                  FROM TMT_WBS:n          +
1        WHERE ELEMENT_ID = h_task_id:
11050:
1           EXCEPTION:: FC_U_PARTICIPANT(1051) :: cplan.sql(19300) :: :
1SELECT * FROM (SELECT DAY_YEAR FROM CALENDAR_DAY_OF_YEAR :
1WHERE ELEMENT_ID = ':
1' AND DAY_YEAR < TO_DATE(SubStr(':
1', 1, 10)) :
1ORDER BY DAY_YEAR DESC) WHERE ROWNUM<=:
1LOOP:
1EXIT:
11108:
1           EXCEPTION:: FC_U_PARTICIPANT(1109) :: cplan.sql(19358) :: :
11123:
1           EXCEPTION:: FC_U_PARTICIPANT(1124) :: cplan.sql(19373) :: :
11133:
1                EXIT:: FC_U_PARTICIPANT(1134) :: cplan.sql(19383) :: :
11139:
1                EXIT:: FC_U_PARTICIPANT(1140) :: cplan.sql(19389) :: :
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_dayofyear, 1, 10)), PMO_ORAST+
1D.TIME(h_start_date)):n                  INTO h_start_date:n                 +
1 FROM DUAL:
11157:
1           EXCEPTION:: FC_U_PARTICIPANT(1158) :: cplan.sql(19407) :: :
11168:
1                EXIT:: FC_U_PARTICIPANT(1169) :: cplan.sql(19418) :: :
11176:
1                EXIT:: FC_U_PARTICIPANT(1177) :: cplan.sql(19426) :: :
1103079040:
11187:
1                EXIT:: FC_U_PARTICIPANT(1188) :: cplan.sql(19437) :: :
1INVALID_PARAMS:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)) + 1     :n                     INTO h_start_date:n+
1                     FROM DUAL:
11219:
1           EXCEPTION:: FC_U_PARTICIPANT(1220) :: cplan.sql(19469) :: :
110000.00:
10.49:
1FC_FD_U_TDY:
1SC_BIT_29:
1U_ASSIGN_STRING:
11237:
1                EXIT:: FC_U_PARTICIPANT(1238) :: cplan.sql(19487) :: :
10.5:
1SELECT COUNT(*) INTO h_temp_var:n                     FROM TASK_DAY_OF_YEAR:n+
1                     WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = +
1a_temp_id:
11256:
1           EXCEPTION:: FC_U_PARTICIPANT(1257) :: cplan.sql(19506) :: :
11271:
1                EXIT:: FC_U_PARTICIPANT(1272) :: cplan.sql(19521) :: :
190:
1SC_SCHED_BIT:
1SC_PLANNED_BIT:
1SC_PERCENT_UNITS_BIT:
1CONSIDER:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, UNITS_MSP = h_percent_units,:n     +
1             C_EFFORT = 0, C_UNIT = 0, C_CONTOUR = 0, CONTOUR_TYPE = 1,:n    +
1              ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,h_rollup_bits):n     +
1             WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11303:
1           EXCEPTION:: FC_U_PARTICIPANT(1304) :: cplan.sql(19553) :: :
1FC_DEL_NOACTUAL:
1SELECT PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_last_submitted, 1, 10)), PMO_+
1ORASTD.TIME(h_start_date)):n                     INTO h_start_date:n         +
1            FROM DUAL:
11346:
1           EXCEPTION:: FC_U_PARTICIPANT(1347) :: cplan.sql(19596) :: :
11363:
1           EXCEPTION:: FC_U_PARTICIPANT(1364) :: cplan.sql(19613) :: :
1FC_RESCHEDULE:
11379:
1                EXIT:: FC_U_PARTICIPANT(1380) :: cplan.sql(19629) :: :
1BAK_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n                          BAK_ASSIGN_STRING = NU+
1LL:n                     WHERE TSK_ASSIGNMENT_ID = A_TEMP_ID:
1BAK_START_DT:
1BAK_FINISH_DT:
1ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,(pmo_cnst.SC_SCHED_BIT+pmo_cnst.SC_PLANNED_BIT)),:n                   +
1  BAK_START_DT = COALESCE(SCHED_START,PLANNED_START), BAK_FINISH_DT = COALESC+
1E(SCHED_FINISH,PLANNED_FINISH),:n                     BAK_ASSIGN_STRING = ASS+
1IGN_STRING :n                     WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11405:
1           EXCEPTION:: FC_U_PARTICIPANT(1406) :: cplan.sql(19655) :: :
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,(pmo_cnst.SC_SCHED_BIT+pmo_cnst.SC_PLANNED_BIT)) :n                   +
1  WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11425:
1           EXCEPTION:: FC_U_PARTICIPANT(1426) :: cplan.sql(19675) :: :
1PROFILE_ID:
1SELECT ta.TSK_ASSIGNMENT_ID INTO h_tsk_assignment_id :n                     F+
1ROM RESOURCE_ASSIGNMENTS ra, TASK_ASSIGNMENTS ta :n                     WHERE+
1 ra.RES_ASSIGNMENT_ID = a_res_assignment_id AND ra.PROFILE_ID IS NOT NuLL :n +
1                    AND ta.PROJECT_ID = h_project_id AND ta.TASK_ID = h_task_+
1id :n                     AND ta.RESOURCE_ID = ra.PROFILE_ID AND ta.RESOURCE_+
1TYPE = '1' AND ta.PLANNED_WORK = 0:
11447:
1           EXCEPTION:: FC_U_PARTICIPANT(1448) :: cplan.sql(19697) :: :
1SELECT COALESCE(PLANNED_START,SCHED_START) INTO h_start_date :n              +
1          FROM TASK_ASSIGNMENTS :n                        WHERE TSK_ASSIGNMEN+
1T_ID = a_temp_id:
11465:
1           EXCEPTION:: FC_U_PARTICIPANT(1466) :: cplan.sql(19715) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                        START_DT	= h_start_date,+
1 :n                        FINISH_DT	= h_start_date :n                       +
1 WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
11486:
1           EXCEPTION:: FC_U_PARTICIPANT(1487) :: cplan.sql(19736) :: :
11497:
1                EXIT:: FC_U_PARTICIPANT(1498) :: cplan.sql(19747) :: :
1SELECT COUNT('X') INTO h_temp_var:n               FROM DUAL:n               W+
1HERE EXISTS(SELECT ELEMENT_ID FROM ACTIVITIES:n               WHERE TSK_ASSIG+
1NMENT_ID = a_temp_id:n               AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n   +
1            AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY):
11520:
1           EXCEPTION:: FC_U_PARTICIPANT(1521) :: cplan.sql(19770) :: :
11528:
1                EXIT:: FC_U_PARTICIPANT(1529) :: cplan.sql(19778) :: :
1MIN:
1SELECT COUNT(DAY_YEAR), MIN(DAY_YEAR) :n                     INTO h_count, h_+
1dayofyear :n                     FROM TASK_DAY_OF_YEAR:n                     +
1WHERE PROJECT_ID = h_project_id:n                     AND TSK_ASSIGNMENT_ID =+
1 a_temp_id:n                     AND ACTUAL_FLAG = 0:
11555:
1           EXCEPTION:: FC_U_PARTICIPANT(1556) :: cplan.sql(19805) :: :
1SCHED_MIN:
1ACTUAL_MIN:
1SELECT SCHED_MIN - ACTUAL_MIN INTO h_minutes:n                           FROM+
1 TASK_DAY_OF_YEAR :n                           WHERE PROJECT_ID = h_project_i+
1d AND TSK_ASSIGNMENT_ID = a_temp_id AND DAY_YEAR = TO_DATE(SubStr(h_last_subm+
1itted, 1, 10)):
11578:
1           EXCEPTION:: FC_U_PARTICIPANT(1579) :: cplan.sql(19828) :: :
110000:
1TO_NUMBER:
1FC_U_ASSIGN_PERCENT:
1SELECT  ( TO_DATE(SubStr(h_finish_date, 1, 10)) )  INTO  h_last_submitted FRO+
1M DUAL:
11635:
1           EXCEPTION:: FC_U_PARTICIPANT(1636) :: cplan.sql(19885) :: :
1SELECT  ( PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(h_finish_date, 1, 10)), PMO_+
1ORASTD.TIME('00::00')) + 1      )  INTO  h_start_date FROM DUAL:
11649:
1           EXCEPTION:: FC_U_PARTICIPANT(1650) :: cplan.sql(19899) :: :
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET CONSIDER = 7, ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLU+
1P_BITS,pmo_cnst.SC_SCHED_BIT),:n                     SCHED_WORK = h_new_actua+
1l, WORK_TODATE = h_new_actual, ETC = 0, MILESTONE_PERCENT = 10000,:n         +
1            FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION +
1= 0:n                     WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11671:
1           EXCEPTION:: FC_U_PARTICIPANT(1672) :: cplan.sql(19921) :: :
11684:
1                EXIT:: FC_U_PARTICIPANT(1685) :: cplan.sql(19934) :: :
11710:
1                EXIT:: FC_U_PARTICIPANT(1711) :: cplan.sql(19960) :: :
11717:
1                EXIT:: FC_U_PARTICIPANT(1718) :: cplan.sql(19967) :: :
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS SET MILESTONE_PERCENT = h_p_work_percent,:n          +
1     ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PERCENT_COMPLETE_B+
1IT):n               WHERE TSK_ASSIGNMENT_ID = a_temp_id:
11738:
1           EXCEPTION:: FC_U_PARTICIPANT(1739) :: cplan.sql(19988) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PERC+
1ENT_COMPLETE_BIT):n               WHERE PROJECT_ID = h_project_id AND ELEMENT+
1_ID = h_task_id:
11757:
1           EXCEPTION:: FC_U_PARTICIPANT(1758) :: cplan.sql(20007) :: :
11766:
1                EXIT:: FC_U_PARTICIPANT(1767) :: cplan.sql(20016) :: :
1SECURITY_ID:
1SELECT ra.SECURITY_ID, ra.PARTICIPANT, ra.ELEMENT_ID, ra.ELEMENT_TYPE,:n     +
1       CASE WHEN ra.RESOURCE_TYPE = '0' THEN 0 ELSE 1 END,:n            CASE +
1WHEN ra.CRI_SECURITY_ID IS NuLL THEN 0 ELSE 1 END,:n            ra.RESOURCE_I+
1D,:n            ra.PROJECT_ID, ra.TABLE_TYPE:n            INTO h_security_id,+
1 a_participant, a_element_id, a_element_type,:n            a_resource_type,:n+
1            h_transfed_cri,:n            a_participant_id,:n            h_pro+
1ject_id, h_table_type:n            FROM RESOURCE_ASSIGNMENTS ra WHERE ra.RES_+
1ASSIGNMENT_ID = a_res_assignment_id:
11790:
1           EXCEPTION:: FC_U_PARTICIPANT(1791) :: cplan.sql(20040) :: :
11799:
1                EXIT:: FC_U_PARTICIPANT(1800) :: cplan.sql(20049) :: :
11808:
1                EXIT:: FC_U_PARTICIPANT(1809) :: cplan.sql(20058) :: :
1SC_TABLE_WBS:
1FC_U_ASSIGNED_SECURITY:
11824:
1                EXIT:: FC_U_PARTICIPANT(1825) :: cplan.sql(20074) :: :
11829:
1                EXIT:: FC_U_PARTICIPANT(1830) :: cplan.sql(20079) :: :
1STATE:: :
0

0
0
2b45
2
0 a0 8d 90 :3 a0 b0 3f 90
:3 a0 b0 3f 90 :3 a0 b0 3f 90
:3 a0 b0 3f 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 90 :3 a0 b0 3f 90
:3 a0 b0 3f b4 :2 a0 2c 6a a3
a0 1c a0 81 b0 a3 a0 1c
a0 81 b0 a3 a0 1c a0 81
b0 a3 a0 1c a0 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :10 a0 12a bd b7 11 a4 b1
a0 f4 b4 bf c8 :10 a0 12a bd
b7 11 a4 b1 a3 :2 a0 6b 1c
81 b0 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 6e a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :2 a0
6e 7e a0 b4 2e 7e 6e b4
2e 6e a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c a0 51 d a0 6e d :2 a0
d :2 a0 d :2 a0 d :20 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:55 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :24 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c :3 a0 51 a5 b :2 a0 6b a5
b 5a a0 7e a0 6b b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c :2 a0 d :2 a0 d :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
19 3c a0 7e b4 2e :2 5a :2 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e 5a a0 7e a0 51 a5
b b4 2e 5a 52 10 :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 51 65 b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e :10 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a :9 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 19 3c :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e a0 4d
d b7 19 3c b7 :10 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
:9 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c a0 51 d
b7 :2 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c b7 a0 51 d a0 51 d
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e :2 a0 e9 dd b3 :2 a0 e9
d3 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
:9 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :2 a0 51 a5 b a0 7e
a0 6b b4 2e 52 10 a0 6e
d :3 a0 6b :2 a0 51 a5 b :2 a0
6b a5 b d a0 51 d b7
19 3c b7 :2 a0 51 a5 b 7e
51 b4 2e a0 51 d :d a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:e a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 19 3c
b7 19 3c :2 a0 e9 dd b3 :2 a0
e9 d3 :2 a0 f :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :2 a0 51 a5 b a0 7e a0
6b b4 2e :2 a0 51 a5 b a0
7e a0 6b b4 2e 52 10 5a
a 10 :2 a0 51 a5 b a0 7e
a0 6b b4 2e :2 a0 51 a5 b
a0 7e a0 6b b4 2e 52 10
:4 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e a5 b d :2 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e 5a a0 7e a0 51 a5 b
b4 2e :3 a0 51 a5 b 7e 51
b4 2e d b7 19 3c b7 19
3c a0 6e d a0 51 d b7
19 3c b7 :2 19 3c :2 a0 51 a5
b 7e 51 b4 2e a0 7e 51
b4 2e a 10 5a :2 a0 51 a5
b a0 7e a0 6b b4 2e :2 a0
51 a5 b a0 7e a0 6b b4
2e 52 10 5a a 10 :7 a0 a5
b d b7 19 3c a0 51 d
:24 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :e a0 51 a5
b 51 a5 b d :2 a0 51 a5
b 7e 51 b4 2e :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 51 a5 b 65 b7
19 3c b7 :2 19 3c a0 b7 :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 a0
51 d :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 a0 b7
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e a0 51 d b7
:2 19 3c a0 51 d :18 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
19 3c a0 51 d :1c a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
19 3c :3 a0 51 a5 b d :8 a0
51 a5 b :2 a0 51 a5 b :2 a0
51 a5 b a5 b d b7 :2 19
3c :2 a0 51 a5 b 7e 51 b4
2e :3 a0 a5 b d b7 19 3c
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 51 a5
b 65 a0 b7 a0 7e b4 2e
5a a0 7e b4 2e 5a a 10
:2 a0 d :2 a0 d :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c a0
7e b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 7e b4 2e a
10 :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b 65 b7 19 3c :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e 5a 52 10 :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 a0
b7 :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 :2 19 3c b7 19 3c :13 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :3 a0 51 a5 b :2 a0 6b a5
b 5a a0 7e a0 6b b4 2e
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c :2 a0 :2 51 a5 b 7e
6e b4 2e a0 51 d b7 a0
51 d b7 :2 19 3c a0 51 d
a0 51 d :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a 52 10 :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e 5a
52 10 :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e a 10
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 19 3c :2 a0 51 a5 b a0
7e a0 6b b4 2e :2 a0 51 a5
b a0 7e a0 6b b4 2e 52
10 a0 51 d :d a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 5a 52 10 a0 6e
d :7 a0 a5 b d b7 19 3c
:17 a0 51 a5 b :2 a0 51 a5 b
a5 b d :3 a0 a5 b d :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 51 a5 b
65 b7 :2 a0 d a0 51 d a0
51 d b7 :2 19 3c a0 b7 :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e :a a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 6b :2 a0 a5 b
d :2 a0 51 a5 b 7e 51 b4
2e 5a a0 7e b4 2e :2 5a a
10 :9 a0 51 a5 b d b7 19
3c :2 a0 :2 51 a5 b 7e 6e b4
2e a0 51 d a0 7e b4 2e
5a :a a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 :2 51 a5 b d
b7 19 3c b7 a0 51 d b7
:2 19 3c :3 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e d :11 a0 51
a5 b 51 a0 51 a5 b d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e :e a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 51
a5 b 7e 51 b4 2e a 10
:a a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 19 3c :5 a0 51
a5 b d :3 a0 a5 b d :2 a0
6b 51 d :2 a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b 65 a0 b7 19 :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :3 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e d :2 a0 51
a5 b a0 7e a0 6b b4 2e
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 52 10 :2 a0 :2 51 a5 b
7e 6e b4 2e 5a :2 a0 d b7
:2 a0 d b7 :2 19 3c :6 a0 a5 b
d :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e 7e b4 2e :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
7e b4 2e a 10 a0 6e d
:3 a0 6b d :5 a0 a5 b d :2 a0
6b a0 d :3 a0 6b d :6 a0 a5
b d :2 a0 6b a0 d :3 a0 6b
:2 a0 51 a5 b :2 a0 6b a5 b
d b7 :2 a0 d b7 :2 19 3c a0
7e b4 2e 5a :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :17 a0 51 a5
b :2 a0 51 a5 b a5 b d
:3 a0 a5 b d :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 51 a5 b 65 b7 a0
51 d b7 :2 19 3c a0 b7 19
:2 a0 51 a5 b 7e 51 b4 2e
a0 51 d a0 51 d :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 b7 19 :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d a0 4d d a0 6e
d :2 a0 51 a5 b 7e 51 b4
2e a0 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e d :3 a0 11c 11d
b7 a0 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 51 a5 b
a5 b b4 2e d :3 a0 11c 11d
b7 :2 19 3c :3 a0 51 a5 b 7e
51 b4 2e :2 a0 e9 d3 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :2 a0 e9 d3
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a a0 2b b7 19 3c b7
a0 47 :2 a0 51 a5 b 7e 51
b4 2e :2 a0 e9 c1 :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c a0 7e b4 2e
5a :2 a0 51 a5 b 7e 51 b4
2e :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 :2 19 3c b7 19 3c
:a a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f a0 51 d a0 51 d
b7 :2 19 3c a0 b7 :2 a0 51 a5
b a0 7e a0 51 a5 b b4
2e :2 a0 51 a5 b 7e 51 b4
2e :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e a 10 :2 a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
19 3c :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e a0 51 d b7 :2 a0 51 a5
b 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a 52
10 :2 a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
65 b7 19 3c :3 a0 51 a5 b
d b7 :2 19 3c :2 a0 51 a5 b
a0 7e a0 6b b4 2e :2 a0 51
a5 b a0 7e a0 6b b4 2e
52 10 :2 a0 51 a5 b 7e 51
b4 2e 5a a0 7e b4 2e :2 5a
a 10 :a a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c :4 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e 5a 7e 51 b4 2e 5a
7e 51 b4 2e a5 b d :9 a0
51 a5 b d :3 a0 6b :2 a0 51
a5 b :2 a0 6b a5 b d :5 a0
:3 51 a5 b d :5 a0 51 a5 b
d :3 a0 a5 b d :2 a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :3 a0 51 a5 b 65 b7
:4 a0 51 a5 b 7e :2 a0 51 a5
b b4 2e 5a 7e 51 b4 2e
5a 7e 51 b4 2e a5 b d
:2 a0 51 a5 b a0 7e a0 51
a5 b b4 2e a0 51 d :7 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 51 65 b7
19 3c b7 19 3c a0 51 d
a0 51 d :2 a0 51 a5 b 7e
51 b4 2e a0 51 d b7 19
3c :3 a0 6b :2 a0 6b :2 a0 6b :2 a0
6b a5 b :2 a0 6b a5 b d
:f a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
a0 51 d b7 19 3c b7 :2 19
3c b7 :2 19 3c a0 7e 51 b4
2e :2 a0 51 a5 b 7e 51 b4
2e 5a a0 7e b4 2e :2 5a a
10 :9 a0 51 a5 b d b7 19
3c a0 7e b4 2e 5a :4 a0 51
a5 b d b7 :2 a0 :2 51 a5 b
7e 6e b4 2e :4 a0 51 a5 b
d b7 :4 a0 51 a5 b d b7
:2 19 3c b7 :2 19 3c a0 7e b4
2e 5a :2 a0 51 a5 b 7e 51
b4 2e :3 a0 6b :2 a0 51 a5 b
:2 a0 6b a5 b 5a d :a a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :a a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d b7 19 3c a0 51 d
:a a0 51 a5 b :2 a0 51 a5 b
a5 b d :2 a0 51 a5 b 7e
51 b4 2e :2 a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:3 a0 6b 65 a0 b7 a0 7e 51
b4 2e :2 a0 :2 51 a5 b 7e 6e
b4 2e :4 a0 12a :16 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :c a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
7e b4 2e a0 4d d :1a a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 7e b4 2e 5a :7 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :7 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
19 3c b7 19 3c b7 :2 19 3c
:3 a0 a5 b d :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 51 a5 b 65 b7 19
3c :2 a0 51 a5 b a0 7e a0
51 a5 b b4 2e a0 51 d
:c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :3 a0 51 a5
b d :3 a0 51 a5 b d :2 a0
51 a5 b a0 7e a0 51 a5
b b4 2e :2 a0 51 a5 b a0
7e a0 6b b4 2e :2 a0 51 a5
b a0 7e a0 6b b4 2e 52
10 a0 4d d :c a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 7e
b4 2e 5a :2 a0 d b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
5a a0 7e b4 2e :2 5a a 10
:c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 51 a5 b 7e :2 a0
51 a5 b b4 2e 7e :2 a0 51
a5 b b4 2e d b7 :3 a0 51
a5 b 7e :2 a0 51 a5 b b4
2e d b7 :2 19 3c a0 51 d
:5 a0 a5 b 51 a5 b 7e :3 a0
a5 b 51 a5 b b4 2e 5a
7e 51 b4 2e a5 b d :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d :2 a0 51 a5 b a0
7e a0 51 a5 b b4 2e :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e 7e :2 a0 51 a5 b b4
2e d b7 :3 a0 51 a5 b d
b7 :2 19 3c :9 a0 51 a5 b d
:5 a0 a5 b 51 a5 b 7e :3 a0
a5 b 51 a5 b b4 2e 5a
7e 51 b4 2e a5 b d :3 a0
6b :2 a0 51 a5 b :2 a0 6b a5
b d :7 a0 51 a5 b :2 a0 51
a5 b 51 a5 b d :5 a0 51
a5 b d b7 19 3c b7 a0
51 d :3 a0 51 a5 b d :1b a0
51 a5 b :2 a0 51 a5 b a5
b d :3 a0 51 a5 b d :3 a0
51 a5 b 7e :2 a0 51 a5 b
b4 2e d :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :9 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :13 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 51 d :8 a0 51 :2 a0 51 a5
b a5 b d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 51 a5 b 65 b7 19
3c b7 19 3c b7 :2 19 3c :3 a0
51 a5 b d a0 51 d b7
:5 a0 a5 b 51 a5 b 7e :3 a0
a5 b 51 a5 b b4 2e 5a
7e 51 b4 2e 5a 7e 51 b4
2e a5 b d b7 :2 19 3c :1b a0
51 a5 b :2 a0 51 a5 b a5
b d :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
51 a5 b 65 a0 b7 :2 a0 51
a5 b a0 7e a0 51 a5 b
b4 2e :2 a0 51 a5 b 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :2 a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :3 a0 6b 65 b7 19
3c :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :b a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :3 a0 a5 b d
:2 a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 51 a5
b 65 b7 19 :20 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 6b
a0 7e a0 6b b4 2e 5a 7e
b4 2e :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c :2 a0 6b :2 a0
a5 b 7e 51 b4 2e :2 a0 6b
51 d :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 b7 19 3c b7 :2 19 3c
b7 19 3c :2 a0 d :2 a0 d :2 a0
d :3 a0 6b d :2 a0 6b :5 a0 a5
b d :2 a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :3 a0
6b 65 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :3 a0 6b 65 b7 a4 b1
11 68 4f 1d 17 b5 
2b45
2
0 3 7 2b 1f 23 27 1e
32 47 3b 3f 43 1b 4e 5f
53 57 5b 3a 66 7b 6f 73
77 37 82 8b 87 6e 93 a0
9c 6b a8 b1 ad 9b b9 c6
c2 98 ce df d3 d7 db c1
e6 fb ef f3 f7 be 102 ee
107 10b 10f 113 130 11b 11f 127
12b eb 14c 137 13b 143 147 11a
16c 157 15b 163 167 117 188 173
177 17f 183 156 1a5 193 153 197
198 1a0 192 1c2 1b0 18f 1b4 1b5
1bd 1af 1df 1cd 1ac 1d1 1d2 1da
1cc 1fc 1ea 1c9 1ee 1ef 1f7 1e9
219 207 1e6 20b 20c 214 206 236
224 203 228 229 231 223 253 241
220 245 246 24e 240 270 25e 23d
262 263 26b 25d 28d 27b 25a 27f
280 288 27a 2aa 298 277 29c 29d
2a5 297 2c7 2b5 294 2b9 2ba 2c2
2b4 2e4 2d2 2b1 2d6 2d7 2df 2d1
301 2ef 2ce 2f3 2f4 2fc 2ee 31e
30c 2eb 310 311 319 30b 33a 329
32d 335 308 352 341 345 34d 328
36e 35d 361 369 325 386 375 379
381 35c 3a2 391 395 39d 359 3ba
3a9 3ad 3b5 390 3d6 3c5 3c9 3d1
38d 3ee 3dd 3e1 3e9 3c4 40a 3f9
3fd 405 3c1 422 411 415 41d 3f8
43e 42d 431 439 3f5 456 445 449
451 42c 472 461 465 46d 429 48e
479 47d 480 481 489 460 4ab 499
45d 49d 49e 4a6 498 4c8 4b6 495
4ba 4bb 4c3 4b5 4e4 4d3 4d7 4b2
4df 4d2 500 4ef 4f3 4cf 4fb 4ee
51c 50b 50f 4eb 517 50a 538 527
52b 507 533 526 554 543 547 54f
523 56c 55b 55f 567 542 588 577
57b 53f 583 576 5a4 593 597 573
59f 592 5c0 5af 5b3 58f 5bb 5ae
5dc 5cb 5cf 5ab 5d7 5ca 5f8 5e7
5eb 5c7 5f3 5e6 614 603 607 5e3
60f 602 630 61f 623 5ff 62b 61e
64c 63b 63f 61b 647 63a 668 657
65b 637 663 656 684 673 677 653
67f 672 6a1 68f 66f 693 694 69c
68e 6be 6ac 68b 6b0 6b1 6b9 6ab
6db 6c9 6a8 6cd 6ce 6d6 6c8 6f7
6e6 6ea 6c5 6f2 6e5 713 702 706
6e2 70e 701 72f 71e 722 6fe 72a
71d 74b 73a 73e 71a 746 739 767
756 75a 736 762 755 783 772 776
752 77e 771 79f 78e 792 76e 79a
78d 7bb 7aa 7ae 78a 7b6 7a9 7d7
7c6 7ca 7a6 7d2 7c5 7f3 7e2 7e6
7c2 7ee 7e1 80f 7fe 802 7de 80a
7fd 82b 81a 81e 7fa 826 819 847
836 83a 816 842 835 863 852 856
832 85e 851 87f 86e 872 84e 87a
86d 89b 88a 88e 86a 896 889 8b7
8a6 8aa 886 8b2 8a5 8d3 8c2 8c6
8a2 8ce 8c1 8ef 8de 8e2 8be 8ea
8dd 90b 8fa 8fe 8da 906 8f9 927
916 91a 8f6 922 915 943 932 936
912 93e 931 95f 94e 952 92e 95a
94d 97b 96a 96e 94a 976 969 997
986 98a 966 992 985 9b3 9a2 9a6
982 9ae 9a1 9cf 9be 9c2 99e 9ca
9bd 9eb 9da 9de 9ba 9e6 9d9 a07
9f6 9fa 9d6 a02 9f5 a23 a12 a16
9f2 a1e a11 a40 a2e a0e a32 a33
a3b a2d a5d a4b a2a a4f a50 a58
a4a a79 a68 a6c a47 a74 a67 a96
a84 a64 a88 a89 a91 a83 ab2 aa1
aa5 a80 aad aa0 ace abd ac1 a9d
ac9 abc aea ad9 add ab9 ae5 ad8
b06 af5 af9 ad5 b01 af4 b22 b11
b15 af1 b1d b10 b3e b2d b31 b0d
b39 b2c b5a b49 b4d b29 b55 b48
b76 b65 b69 b45 b71 b64 b92 b81
b85 b61 b8d b80 bae b9d ba1 b7d
ba9 b9c bca bb9 bbd b99 bc5 bb8
be7 bd5 bb5 bd9 bda be2 bd4 c03
bf2 bf6 bfe bd1 c1b c0a c0e c16
bf1 c37 c26 c2a c32 bee c4f c3e
c42 c4a c25 c6b c5a c5e c22 c66
c59 c72 c76 c56 c87 c8a c8e c92
c96 c9a c9e ca2 ca6 caa cae cb2
cb6 cba cbe cc2 cc6 cca cce cda
cdf ce1 ced cf1 cf3 cf7 d08 d09
d0c d10 d14 d18 d1c d20 d24 d28
d2c d30 d34 d38 d3c d40 d44 d48
d4c d50 d5c d61 d63 d6f d73 d91
d79 d7d d81 d84 d8c d78 db1 d9c
da0 d75 da4 dac d9b db8 dbc d98
dc0 dc4 dc8 dcb dd0 dd1 1 dd3
dd8 ddc de0 de3 de8 dec df0 df3
df8 df9 dfb e00 e03 e07 e08 e0d
e12 e15 e1a e1b e20 e23 e27 e28
e2d e30 e35 e36 e3b e3e e43 e44
e49 e4c e51 e52 e57 e5a e5e e5f
e64 e67 e6c e6d e72 e75 e7a e7b
e80 e83 e87 e8b e90 e93 e97 e98
e9d ea0 ea5 ea6 eab eb0 eb1 eb3
eb8 eb9 ebb ebc ec1 ec4 ec9 eca
ecf ed2 ed6 eda edf ee2 ee6 ee7
eec eef ef4 ef5 efa eff f00 f02
f07 f08 f0a f0b f10 f13 f18 f19
f1e f21 f25 f29 f2d f2e f30 f35
f36 f38 f39 f3e f41 f46 f47 f4c
f4f f53 f57 f5b f5c f5e f63 f64
f66 f67 f6c f6f f74 f75 f7a f7d
f81 f85 f89 f8a f8c f91 f92 f94
f95 f9a f9d fa2 fa3 fa8 fab faf
fb3 fb7 fb8 fba fbf fc0 fc2 fc3
fc8 fcb fd0 fd1 fd6 fd9 fde fdf
fe4 fe7 feb fec ff1 ff4 ff9 ffa
fff 1002 1007 1008 100d 1010 1015 1016
101b 101e 1022 1023 1028 102b 1030 1031
1036 1039 103e 103f 1044 1045 104a 104c
1050 1053 1057 105b 105e 1062 1066 1069
106c 1071 1074 1077 107a 107b 1080 1081
1 1083 1088 108c 1090 1093 1098 109d
10a0 10a4 10a5 10aa 10ab 10b0 10b2 10b6
10b9 10bd 10c0 10c4 10c8 10cd 10d1 10d5
10d9 10dd 10e1 10e5 10e9 10ed 10f1 10f5
10f9 10fd 1101 1105 1109 110d 1111 1115
1119 111d 1121 1125 1129 112d 1131 1135
1139 113d 1141 1145 1149 114d 1151 1155
1159 115d 1161 1165 1169 116d 1171 1175
1181 1185 1189 118c 1190 1194 1196 119a
119e 11a2 11a5 11a9 11ad 11af 11b0 11b5
1 11b9 11bd 11c1 11c4 11c8 11cc 11d0
11d4 11d7 11db 11df 11e2 11e5 11ea 11ed
11f0 11f3 11f4 11f9 11fa 1 11fc 1201
1205 1209 120c 1211 1216 1219 121d 121e
1223 1226 122b 122c 1231 1234 1239 123a
123f 1242 1246 1247 124c 124f 1254 1255
125a 125d 1261 1265 1268 126b 126c 126e
126f 1274 1275 127a 127c 1280 1283 1285
1289 128b 1297 1299 129b 129c 12a1 12a5
12a7 12b3 12b5 12b9 12bd 12c0 12c4 12c7
12cb 12ce 12cf 12d4 12d7 12db 12df 12e3
12e7 12eb 12ef 12f3 12f7 12fb 12ff 1303
1307 130b 130f 1313 1317 131b 131f 1323
1327 132b 132f 1333 1337 133b 133f 1343
1347 134b 134f 1353 1357 135b 135f 1363
1367 136b 136f 1373 1377 137b 137f 1383
1387 138b 138f 1393 1397 139b 139f 13a3
13a7 13ab 13af 13b3 13b7 13bb 13bf 13c3
13c7 13cb 13cf 13d3 13d7 13db 13df 13e3
13e7 13eb 13ef 13f3 13f7 13fb 13ff 1403
1407 140b 140f 1413 1417 141b 141f 1423
1427 142b 1437 143b 143f 1442 1446 144a
144c 1450 1454 1458 145b 145f 1463 1465
1466 146b 1 146f 1473 1477 147a 147e
1482 1486 148a 148d 1491 1495 1498 149b
14a0 14a3 14a6 14a9 14aa 14af 14b0 1
14b2 14b7 14bb 14bf 14c2 14c7 14cc 14cf
14d3 14d4 14d9 14dc 14e1 14e2 14e7 14ea
14ef 14f0 14f5 14f8 14fc 14fd 1502 1505
150a 150b 1510 1513 1517 151b 151e 1521
1522 1524 1525 152a 152b 1530 1532 1536
1539 153b 153f 1541 154d 154f 1551 1552
1557 155b 155d 1569 156b 156f 1573 1576
157a 157d 1581 1584 1585 158a 158d 1591
1595 1599 159d 15a1 15a5 15a9 15ad 15b1
15b5 15b9 15bd 15c1 15c5 15c9 15cd 15d1
15d5 15d9 15dd 15e1 15e5 15e9 15ed 15f1
15f5 15f9 15fd 1601 1605 1609 160d 1611
1615 1619 161d 1629 162d 1631 1634 1638
163c 163e 1642 1646 164a 164d 1651 1655
1657 1658 165d 1 1661 1665 1669 166c
1670 1674 1678 167c 167f 1683 1687 168a
168d 1692 1695 1698 169b 169c 16a1 16a2
1 16a4 16a9 16ad 16b1 16b4 16b9 16be
16c1 16c5 16c6 16cb 16ce 16d3 16d4 16d9
16dc 16e1 16e2 16e7 16ea 16ee 16ef 16f4
16f7 16fc 16fd 1702 1705 1709 170d 1710
1713 1714 1716 1717 171c 171d 1722 1724
1728 172b 172d 1731 1733 173f 1741 1743
1744 1749 174d 174f 175b 175d 1761 1765
1768 176c 176f 1773 1776 1777 177c 177f
1783 1787 178b 178f 1793 1796 179a 179e
17a1 17a4 17a9 17ac 17af 17b2 17b3 17b8
17b9 1 17bb 17c0 17c4 17c8 17cb 17d0
17d5 17d8 17dc 17dd 17e2 17e3 17e8 17ea
17ee 17f1 17f5 17f9 17fd 1800 1804 1806
180a 180d 1811 1815 1819 181c 181d 181f
1823 1827 182a 182b 182d 1830 1834 1837
183b 183e 183f 1844 1848 184c 1850 1854
1858 185b 185f 1863 1866 1869 186e 1871
1874 1877 1878 187d 187e 1 1880 1885
1889 188d 1890 1895 189a 189d 18a1 18a2
18a7 18a8 18ad 18af 18b3 18b6 18ba 18be
18c2 18c5 18c9 18cb 18cf 18d2 18d6 18da
18de 18e2 18e6 18ea 18ee 18f2 18f5 18f9
18fd 1900 1901 1903 1906 1909 190a 190f
1912 1916 191a 191d 1921 1925 1928 1929
192b 192e 1931 1932 1937 1 193a 193f
1943 1947 194b 194f 1953 1956 195a 195e
1961 1964 1969 196c 196f 1972 1973 1978
1979 1 197b 1980 1984 1988 198b 1990
1995 1998 199c 199d 19a2 19a3 19a8 19aa
19ae 19b1 19b5 19b9 19bd 19c0 19c4 19c6
19ca 19cd 19d1 19d4 19d5 19da 19dd 19e0
19e4 19e8 19eb 19ec 19ee 19f1 19f5 19f9
19fc 19fd 19ff 1a00 1a05 1a08 1a0c 1a0f
1a13 1a16 1a17 1a19 1a1a 1a1f 1 1a22
1a27 1a2b 1a2f 1a33 1a37 1a3b 1a3e 1a42
1a46 1a49 1a4c 1a51 1a54 1a57 1a5a 1a5b
1a60 1a61 1 1a63 1a68 1a6c 1a70 1a73
1a78 1a7d 1a80 1a84 1a85 1a8a 1a8b 1a90
1a92 1a96 1a99 1a9d 1aa1 1aa5 1aa8 1aac
1aae 1ab2 1ab5 1ab9 1abd 1ac0 1ac4 1ac8
1acb 1acc 1ace 1ad1 1ad4 1ad5 1ada 1add
1ae1 1ae5 1ae8 1aec 1af0 1af3 1af4 1af6
1af9 1afc 1afd 1b02 1 1b05 1b0a 1b0e
1b12 1b15 1b16 1b18 1b1b 1b1e 1b1f 1b24
1b28 1b2c 1b2f 1b33 1b37 1b3a 1b3d 1b42
1b45 1b48 1b4b 1b4c 1b51 1b52 1 1b54
1b59 1b5d 1b61 1b64 1b69 1b6e 1b71 1b75
1b76 1b7b 1b7c 1b81 1b83 1b87 1b8a 1b8e
1b91 1b95 1b97 1b9b 1b9e 1ba2 1ba6 1ba9
1baa 1bac 1baf 1bb2 1bb3 1bb8 1bbc 1bc0
1bc3 1bc7 1bcb 1bce 1bcf 1bd1 1bd4 1bd7
1bd8 1bdd 1be1 1be5 1be9 1bed 1bf1 1bf5
1bf9 1bfd 1c01 1c05 1c09 1c0d 1c11 1c15
1c19 1c1d 1c29 1c2d 1c31 1c34 1c38 1c3c
1c3e 1c42 1c46 1c4a 1c4d 1c51 1c55 1c57
1c58 1c5d 1 1c61 1c65 1c69 1c6c 1c70
1c74 1c78 1c7c 1c7f 1c83 1c87 1c8a 1c8d
1c92 1c95 1c98 1c9b 1c9c 1ca1 1ca2 1
1ca4 1ca9 1cad 1cb1 1cb4 1cb9 1cbe 1cc1
1cc5 1cc6 1ccb 1cce 1cd3 1cd4 1cd9 1cdc
1ce1 1ce2 1ce7 1cea 1cee 1cef 1cf4 1cf7
1cfc 1cfd 1d02 1d05 1d09 1d0d 1d10 1d13
1d14 1d16 1d17 1d1c 1d1d 1d22 1d24 1d28
1d2b 1d2d 1d31 1d33 1d3f 1d41 1d43 1d44
1d49 1d4d 1d4f 1d5b 1d5d 1d61 1d65 1d68
1d6c 1d6f 1d73 1d76 1d77 1d7c 1d7f 1d83
1d87 1d8b 1d8f 1d93 1d97 1d9b 1d9f 1da3
1daf 1db3 1db7 1dba 1dbe 1dc2 1dc4 1dc8
1dcc 1dd0 1dd3 1dd7 1ddb 1ddd 1dde 1de3
1 1de7 1deb 1def 1df2 1df6 1dfa 1dfe
1e02 1e05 1e09 1e0d 1e10 1e13 1e18 1e1b
1e1e 1e21 1e22 1e27 1e28 1 1e2a 1e2f
1e33 1e37 1e3a 1e3f 1e44 1e47 1e4b 1e4c
1e51 1e54 1e59 1e5a 1e5f 1e62 1e67 1e68
1e6d 1e70 1e74 1e75 1e7a 1e7d 1e82 1e83
1e88 1e8b 1e8f 1e93 1e96 1e99 1e9a 1e9c
1e9d 1ea2 1ea3 1ea8 1eaa 1eae 1eb1 1eb3
1eb7 1eb9 1ec5 1ec7 1ec9 1eca 1ecf 1ed3
1ed5 1ee1 1ee3 1ee5 1ee9 1eec 1ef0 1ef4
1ef7 1efb 1eff 1f02 1f03 1f05 1f08 1f0b
1f0c 1f11 1f15 1f16 1f1a 1f1c 1f20 1f23
1f25 1f29 1f2d 1f31 1f35 1f39 1f3d 1f41
1f45 1f49 1f4d 1f51 1f55 1f59 1f5d 1f61
1f65 1f71 1f75 1f79 1f7c 1f80 1f84 1f86
1f8a 1f8e 1f92 1f95 1f99 1f9d 1f9f 1fa0
1fa5 1 1fa9 1fad 1fb1 1fb4 1fb8 1fbc
1fc0 1fc4 1fc7 1fcb 1fcf 1fd2 1fd5 1fda
1fdd 1fe0 1fe3 1fe4 1fe9 1fea 1 1fec
1ff1 1ff5 1ff9 1ffc 2001 2006 2009 200d
200e 2013 2016 201b 201c 2021 2024 2029
202a 202f 2032 2036 2037 203c 203f 2044
2045 204a 204d 2051 2055 2058 205b 205c
205e 205f 2064 2065 206a 206c 2070 2073
2075 2079 207b 2087 2089 208b 208c 2091
2095 2097 20a3 20a5 20a9 20ad 20b0 20b4
20b7 20bb 20be 20bf 20c4 20c7 20cb 20cf
20d3 20d7 20db 20df 20e3 20e7 20eb 20f7
20fb 20ff 2102 2106 210a 210c 2110 2114
2118 211b 211f 2123 2125 2126 212b 1
212f 2133 2137 213a 213e 2142 2146 214a
214d 2151 2155 2158 215b 2160 2163 2166
2169 216a 216f 2170 1 2172 2177 217b
217f 2182 2187 218c 218f 2193 2194 2199
219c 21a1 21a2 21a7 21aa 21af 21b0 21b5
21b8 21bc 21bd 21c2 21c5 21ca 21cb 21d0
21d3 21d7 21db 21de 21e1 21e2 21e4 21e5
21ea 21eb 21f0 21f2 21f6 21f9 21fb 21ff
2201 220d 220f 2211 2212 2217 221b 221d
2229 222b 222d 2231 2234 2238 223b 223f
2241 2245 2249 224c 2250 2254 2257 2258
225a 225e 2261 2265 2268 2269 226e 2272
2276 227a 227e 2282 2286 228a 228e 2292
229e 22a2 22a7 22ab 22ae 22af 22b4 22b8
22bc 22bf 22c2 22c6 22c8 22cc 22d0 22d3
22d6 22da 22dc 22e0 22e4 22e7 22e9 22ed
22f1 22f5 22f8 22fc 2300 2302 2303 2308
1 230c 2310 2314 2317 231b 231f 2323
2327 232a 232e 2332 2335 2338 233d 2340
2343 2346 2347 234c 234d 1 234f 2354
2358 235c 235f 2364 2369 236c 2370 2371
2376 2379 237e 237f 2384 2387 238c 238d
2392 2395 2399 239a 239f 23a2 23a7 23a8
23ad 23b0 23b4 23b8 23bb 23be 23bf 23c1
23c2 23c7 23c8 23cd 23cf 23d3 23d6 23d8
23dc 23de 23ea 23ec 23ee 23ef 23f4 23f8
23fa 2406 2408 240a 240e 2412 2416 241a
241e 2422 2426 242a 242e 243a 243e 2443
2447 244a 244b 2450 2454 2458 245b 245e
2462 2464 2468 246c 246f 2472 2476 2478
247c 2480 2483 2485 2489 248d 2491 2494
2498 249c 249e 249f 24a4 1 24a8 24ac
24b0 24b3 24b7 24bb 24bf 24c3 24c6 24ca
24ce 24d1 24d4 24d9 24dc 24df 24e2 24e3
24e8 24e9 1 24eb 24f0 24f4 24f8 24fb
2500 2505 2508 250c 250d 2512 2515 251a
251b 2520 2523 2528 2529 252e 2531 2535
2536 253b 253e 2543 2544 2549 254c 2550
2554 2557 255a 255b 255d 255e 2563 2564
2569 256b 256f 2572 2574 2578 257a 2586
2588 258a 258b 2590 2594 2596 25a2 25a4
25a6 25aa 25ae 25b1 25b3 25b7 25ba 25be
25c2 25c5 25c9 25cd 25d1 25d4 25d8 25dc
25df 25e0 25e2 25e5 25e8 25e9 25ee 25f2
25f6 25fb 25ff 2600 2604 2608 260d 2612
2616 261a 261f 2623 2627 262a 262d 2631
2633 2637 263b 263e 2641 2645 2647 264b
264f 2652 2656 265a 265d 2661 2664 2668
266b 266c 2671 2674 2678 267c 2680 2684
2688 268c 2690 2694 2698 26a4 26a8 26ac
26af 26b3 26b7 26b9 26bd 26c1 26c5 26c8
26cc 26d0 26d2 26d3 26d8 1 26dc 26e0
26e4 26e7 26eb 26ef 26f3 26f7 26fa 26fe
2702 2705 2708 270d 2710 2713 2716 2717
271c 271d 1 271f 2724 2728 272c 272f
2734 2739 273c 2740 2741 2746 2749 274e
274f 2754 2757 275c 275d 2762 2765 2769
276a 276f 2772 2777 2778 277d 2780 2784
2788 278b 278e 278f 2791 2792 2797 2798
279d 279f 27a3 27a6 27a8 27ac 27ae 27ba
27bc 27be 27bf 27c4 27c8 27ca 27d6 27d8
27da 27de 27e1 27e5 27e9 27ee 27f0 27f4
27f8 27fb 27ff 2803 2805 2809 280d 2811
2814 2818 281c 281e 281f 2824 1 2828
282c 2830 2833 2837 283b 283f 2843 2846
284a 284e 2851 2854 2859 285c 285f 2862
2863 2868 2869 1 286b 2870 2874 2878
287b 2880 2885 2888 288c 288d 2892 2895
289a 289b 28a0 28a3 28a8 28a9 28ae 28b1
28b5 28b6 28bb 28be 28c3 28c4 28c9 28cc
28d0 28d4 28d7 28da 28db 28dd 28de 28e3
28e4 28e9 28eb 28ef 28f2 28f4 28f8 28fa
2906 2908 290a 290b 2910 2914 2916 2922
2924 2928 292c 292f 2930 2932 2936 2939
293d 2940 2941 2946 294a 294e 2951 2952
2954 2958 295b 295f 2962 2963 1 2968
296d 2971 2976 297a 297e 2982 2986 2989
298d 2991 2994 2995 2997 299b 299f 29a2
29a3 29a5 29a9 29ad 29b0 29b4 29b6 29ba
29bd 29bf 29c3 29c7 29ca 29cb 29cd 29d0
29d3 29d4 29d9 29dd 29e0 29e4 29e8 29ec
29f0 29f4 29f8 29fc 2a00 2a04 2a08 2a0c
2a10 2a14 2a18 2a24 2a28 2a2c 2a2f 2a33
2a37 2a39 2a3d 2a41 2a45 2a48 2a4c 2a50
2a52 2a53 2a58 1 2a5c 2a60 2a64 2a67
2a6b 2a6f 2a73 2a77 2a7a 2a7e 2a82 2a85
2a88 2a8d 2a90 2a93 2a96 2a97 2a9c 2a9d
1 2a9f 2aa4 2aa8 2aac 2aaf 2ab4 2ab9
2abc 2ac0 2ac1 2ac6 2ac9 2ace 2acf 2ad4
2ad7 2adc 2add 2ae2 2ae5 2ae9 2aea 2aef
2af2 2af7 2af8 2afd 2b00 2b04 2b08 2b0b
2b0e 2b0f 2b11 2b12 2b17 2b18 2b1d 2b1f
2b23 2b26 2b28 2b2c 2b2e 2b3a 2b3c 2b3e
2b3f 2b44 2b48 2b4a 2b56 2b58 2b5c 2b60
2b63 2b64 2b66 2b69 2b6c 2b6d 2b72 2b76
2b7a 2b7e 2b82 2b86 2b8a 2b8e 2b92 2b96
2b9a 2b9e 2ba2 2ba6 2baa 2bb6 2bba 2bbe
2bc1 2bc5 2bc9 2bcb 2bcf 2bd3 2bd7 2bda
2bde 2be2 2be4 2be5 2bea 1 2bee 2bf2
2bf6 2bf9 2bfd 2c01 2c05 2c09 2c0c 2c10
2c14 2c17 2c1a 2c1f 2c22 2c25 2c28 2c29
2c2e 2c2f 1 2c31 2c36 2c3a 2c3e 2c41
2c46 2c4b 2c4e 2c52 2c53 2c58 2c5b 2c60
2c61 2c66 2c69 2c6e 2c6f 2c74 2c77 2c7b
2c7c 2c81 2c84 2c89 2c8a 2c8f 2c92 2c96
2c9a 2c9d 2ca0 2ca1 2ca3 2ca4 2ca9 2caa
2caf 2cb1 2cb5 2cb8 2cba 2cbe 2cc0 2ccc
2cce 2cd0 2cd1 2cd6 2cda 2cdc 2ce8 2cea
2cec 2cf0 2cf3 2cf7 2cfb 2cfe 2cff 2d01
2d04 2d07 2d08 2d0d 2d11 2d15 2d19 2d1d
2d21 2d24 2d28 2d2c 2d2f 2d32 2d37 2d3a
2d3d 2d40 2d41 2d46 2d47 1 2d49 2d4e
2d52 2d56 2d59 2d5e 2d63 2d66 2d6a 2d6b
2d70 2d71 2d76 2d78 2d7c 2d7f 2d83 2d87
2d8b 2d8e 2d92 2d94 2d98 2d9b 2d9d 2da1
2da4 2da8 2dac 2db1 2db5 2db6 2dba 2dbe
2dc3 2dc8 2dcc 2dd0 2dd5 2dd9 2ddd 2de0
2de3 2de7 2de9 2ded 2df1 2df4 2df7 2dfb
2dfd 2e01 2e05 2e08 2e0c 2e10 2e13 2e17
2e1a 2e1e 2e21 2e22 2e27 2e2a 2e2e 2e32
2e36 2e3a 2e3e 2e42 2e46 2e4a 2e4e 2e5a
2e5e 2e62 2e65 2e69 2e6d 2e6f 2e73 2e77
2e7b 2e7e 2e82 2e86 2e88 2e89 2e8e 1
2e92 2e96 2e9a 2e9d 2ea1 2ea5 2ea9 2ead
2eb0 2eb4 2eb8 2ebb 2ebe 2ec3 2ec6 2ec9
2ecc 2ecd 2ed2 2ed3 1 2ed5 2eda 2ede
2ee2 2ee5 2eea 2eef 2ef2 2ef6 2ef7 2efc
2eff 2f04 2f05 2f0a 2f0d 2f12 2f13 2f18
2f1b 2f1f 2f20 2f25 2f28 2f2d 2f2e 2f33
2f36 2f3a 2f3e 2f41 2f44 2f45 2f47 2f48
2f4d 2f4e 2f53 2f55 2f59 2f5c 2f5e 2f62
2f64 2f70 2f72 2f74 2f75 2f7a 2f7e 2f80
2f8c 2f8e 2f90 2f94 2f97 2f9b 2f9f 2fa4
2fa6 2faa 2fae 2fb1 2fb5 2fb9 2fbb 2fbf
2fc3 2fc7 2fca 2fce 2fd2 2fd4 2fd5 2fda
1 2fde 2fe2 2fe6 2fe9 2fed 2ff1 2ff5
2ff9 2ffc 3000 3004 3007 300a 300f 3012
3015 3018 3019 301e 301f 1 3021 3026
302a 302e 3031 3036 303b 303e 3042 3043
3048 304b 3050 3051 3056 3059 305e 305f
3064 3067 306b 306c 3071 3074 3079 307a
307f 3082 3086 308a 308d 3090 3091 3093
3094 3099 309a 309f 30a1 30a5 30a8 30aa
30ae 30b0 30bc 30be 30c0 30c1 30c6 30ca
30cc 30d8 30da 30de 30e2 30e5 30e6 30e8
30eb 30ee 30ef 30f4 30f8 30fc 30ff 3100
3102 3106 3109 310d 3110 3111 3116 311a
311e 3121 3122 3124 3128 312b 312f 3132
3133 1 3138 313d 1 3140 3145 3149
314d 3150 3151 3153 3157 315a 315e 3161
3162 3167 316b 316f 3172 3173 3175 3179
317c 3180 3183 3184 1 3189 318e 3192
3196 319a 319e 31a1 31a2 31a4 31a7 31ab
31af 31b2 31b3 31b5 31b6 31bb 31bc 31be
31c2 31c6 31ca 31cd 31ce 31d0 31d3 31d7
31db 31de 31df 31e1 31e2 31e7 31ea 31ee
31f1 31f5 31f8 31f9 31fb 31fc 3201 3205
3209 320d 3210 3211 3213 3216 3219 321a
321f 3223 3225 3229 322c 322e 3232 3235
3239 323e 3242 3246 3249 324d 324f 3253
3256 3258 325c 3260 3263 3267 326b 326e
326f 3271 3274 3277 3278 327d 3281 3284
3287 3288 1 328d 3292 3295 3299 329d
32a0 32a1 32a3 32a7 32aa 32ae 32b1 32b2
32b7 32bb 32bf 32c2 32c3 32c5 32c9 32cc
32d0 32d3 32d4 1 32d9 32de 1 32e1
32e6 32ea 32ee 32f2 32f6 32fa 32fe 3302
3303 3305 3309 330b 330f 3312 3316 3319
331d 3321 3325 3329 332d 3331 3335 3339
333d 3341 3345 3349 334d 3351 3355 3359
335d 3361 3365 3369 336d 3371 3375 3379
337d 3381 3385 3389 338d 3391 3395 3399
339d 33a1 33a5 33a9 33ad 33b9 33bd 33c1
33c4 33c8 33cc 33ce 33d2 33d6 33da 33dd
33e1 33e5 33e7 33e8 33ed 1 33f1 33f5
33f9 33fc 3400 3404 3408 340c 340f 3413
3417 341a 341d 3422 3425 3428 342b 342c
3431 3432 1 3434 3439 343d 3441 3444
3449 344e 3451 3455 3456 345b 345e 3463
3464 3469 346c 3471 3472 3477 347a 347e
347f 3484 3487 348c 348d 3492 3495 3499
349d 34a0 34a3 34a4 34a6 34a7 34ac 34ad
34b2 34b4 34b8 34bb 34bd 34c1 34c3 34cf
34d1 34d3 34d4 34d9 34dd 34df 34eb 34ed
34f1 34f5 34f8 34f9 34fb 34fe 3501 3502
3507 350b 350f 3513 3517 351b 351e 3522
3526 3529 352c 3531 3534 3537 353a 353b
3540 3541 1 3543 3548 354c 3550 3553
3558 355d 3560 3564 3565 356a 356b 3570
3572 3576 3579 357d 3581 3585 3588 358c
358e 3592 3595 3599 359d 35a1 35a5 35a9
35ad 35b1 35b5 35b9 35bd 35c1 35c5 35c9
35cd 35d0 35d1 35d3 35d6 35d7 35d9 35dd
35e1 35e5 35e8 35e9 35eb 35ee 35f1 35f2
35f7 35fb 35ff 3603 3607 360b 360e 3612
3616 3619 361c 3621 3624 3627 362a 362b
3630 3631 1 3633 3638 363c 3640 3643
3648 364d 3650 3654 3655 365a 365b 3660
3662 3666 3669 366d 3671 3675 3678 3679
367b 367f 3681 3685 3688 368a 368e 3692
3695 3699 369b 369f 36a3 36a6 36a7 36a9
36ad 36b0 36b4 36b7 36b8 36ba 36bb 36c0
36c3 36c7 36cb 36ce 36cf 36d1 36d4 36d7
36d8 36dd 1 36e0 36e5 36e9 36ec 36f0
36f4 36f8 36fb 36fc 36fe 3702 3705 3709
370c 370d 370f 3710 3715 3719 371d 3721
3725 3729 372c 3730 3734 3737 373a 373f
3742 3745 3748 3749 374e 374f 1 3751
3756 375a 375e 3761 3766 376b 376e 3772
3773 3778 3779 377e 3780 3784 3787 378b
378f 3793 3796 379a 379e 37a0 37a4 37a8
37ab 37ac 37ae 37b2 37b5 37b9 37bc 37bd
37bf 37c0 37c5 37c9 37cc 37d0 37d2 37d6
37da 37dd 37e1 37e4 37e8 37ec 37f0 37f4
37f8 37fc 3800 3804 3808 380c 3810 3814
3818 381c 3820 3824 3828 382c 3830 3834
3838 383c 3840 3844 3848 3854 3858 385c
385f 3863 3867 3869 386d 3871 3875 3878
387c 3880 3882 3883 3888 1 388c 3890
3894 3897 389b 389f 38a3 38a7 38aa 38ae
38b2 38b5 38b8 38bd 38c0 38c3 38c6 38c7
38cc 38cd 1 38cf 38d4 38d8 38dc 38df
38e4 38e9 38ec 38f0 38f1 38f6 38f9 38fe
38ff 3904 3907 390c 390d 3912 3915 3919
391a 391f 3922 3927 3928 392d 3930 3934
3938 393b 393e 393f 3941 3942 3947 3948
394d 394f 3953 3956 3958 395c 395e 396a
396c 396e 396f 3974 3978 397a 3986 3988
398c 3990 3993 3994 3996 3999 399c 399d
39a2 39a6 39aa 39ae 39b2 39b6 39b9 39bd
39c1 39c4 39c7 39cc 39cf 39d2 39d5 39d6
39db 39dc 1 39de 39e3 39e7 39eb 39ee
39f3 39f8 39fb 39ff 3a00 3a05 3a06 3a0b
3a0d 3a11 3a14 3a18 3a1c 3a20 3a23 3a27
3a29 3a2d 3a30 3a34 3a37 3a3b 3a3f 3a43
3a47 3a4b 3a4f 3a53 3a57 3a5b 3a5f 3a63
3a67 3a6b 3a6f 3a73 3a77 3a7b 3a7f 3a83
3a87 3a8b 3a8f 3a93 3a97 3a9b 3a9f 3aa3
3aa7 3aab 3ab7 3abb 3abf 3ac2 3ac6 3aca
3acc 3ad0 3ad4 3ad8 3adb 3adf 3ae3 3ae5
3ae6 3aeb 1 3aef 3af3 3af7 3afa 3afe
3b02 3b06 3b0a 3b0d 3b11 3b15 3b18 3b1b
3b20 3b23 3b26 3b29 3b2a 3b2f 3b30 1
3b32 3b37 3b3b 3b3f 3b42 3b47 3b4c 3b4f
3b53 3b54 3b59 3b5c 3b61 3b62 3b67 3b6a
3b6f 3b70 3b75 3b78 3b7c 3b7d 3b82 3b85
3b8a 3b8b 3b90 3b93 3b97 3b9b 3b9e 3ba1
3ba2 3ba4 3ba5 3baa 3bab 3bb0 3bb2 3bb6
3bb9 3bbb 3bbf 3bc1 3bcd 3bcf 3bd1 3bd2
3bd7 3bdb 3bdd 3be9 3beb 3bef 3bf3 3bf6
3bf7 3bf9 3bfc 3bff 3c00 3c05 3c09 3c0d
3c11 3c15 3c19 3c1c 3c20 3c24 3c27 3c2a
3c2f 3c32 3c35 3c38 3c39 3c3e 3c3f 1
3c41 3c46 3c4a 3c4e 3c51 3c56 3c5b 3c5e
3c62 3c63 3c68 3c69 3c6e 3c70 3c74 3c77
3c7b 3c7f 3c83 3c86 3c8a 3c8c 3c90 3c93
3c97 3c9b 3c9f 3ca2 3ca3 3ca5 3ca9 3cad
3cb1 3cb5 3cb9 3cbd 3cc1 3cc5 3cc9 3ccc
3ccd 3ccf 3cd3 3cd7 3cda 3cdb 3cdd 3ce1
3ce5 3ce8 3ce9 3ceb 3cec 3cee 3cf2 3cf4
3cf8 3cfc 3cff 3d03 3d07 3d0a 3d0b 3d0d
3d10 3d13 3d14 3d19 3d1d 3d21 3d25 3d26
3d28 3d2c 3d2e 3d32 3d35 3d39 3d3d 3d41
3d45 3d49 3d4c 3d50 3d54 3d57 3d5a 3d5f
3d62 3d65 3d68 3d69 3d6e 3d6f 1 3d71
3d76 3d7a 3d7e 3d81 3d86 3d8b 3d8e 3d92
3d93 3d98 3d99 3d9e 3da0 3da4 3da7 3dab
3daf 3db3 3db6 3db7 3db9 3dbd 3dc1 3dc3
3dc7 3dca 3dcb 3dd0 3dd3 3dd7 3dda 3ddb
3de0 1 3de3 3de8 3dec 3df0 3df4 3df8
3dfc 3e00 3e04 3e08 3e0b 3e0f 3e13 3e16
3e17 3e19 3e1c 3e1f 3e20 3e25 3e28 3e2c
3e30 3e33 3e37 3e3b 3e3e 3e3f 3e41 3e44
3e47 3e48 3e4d 1 3e50 3e55 3e59 3e5d
3e61 3e65 3e69 3e6c 3e70 3e74 3e77 3e7a
3e7f 3e82 3e85 3e88 3e89 3e8e 3e8f 1
3e91 3e96 3e9a 3e9e 3ea1 3ea6 3eab 3eae
3eb2 3eb3 3eb8 3eb9 3ebe 3ec0 3ec4 3ec7
3ecb 3ecf 3ed3 3ed6 3eda 3edc 3ee0 3ee3
3ee7 3eea 3eeb 3ef0 3ef3 3ef7 3efb 3efe
3eff 3f01 3f04 3f07 3f08 3f0d 3f10 3f11
1 3f16 3f1b 3f1f 3f23 3f27 3f2b 3f2f
3f33 3f37 3f3b 3f3f 3f4b 3f4f 3f53 3f56
3f5a 3f5e 3f60 3f64 3f68 3f6c 3f6f 3f73
3f77 3f79 3f7a 3f7f 1 3f83 3f87 3f8b
3f8e 3f92 3f96 3f9a 3f9e 3fa1 3fa5 3fa9
3fac 3faf 3fb4 3fb7 3fba 3fbd 3fbe 3fc3
3fc4 1 3fc6 3fcb 3fcf 3fd3 3fd6 3fdb
3fe0 3fe3 3fe7 3fe8 3fed 3ff0 3ff5 3ff6
3ffb 3ffe 4003 4004 4009 400c 4010 4011
4016 4019 401e 401f 4024 4027 402b 402f
4032 4035 4036 4038 4039 403e 403f 4044
4046 404a 404d 404f 4053 4055 4061 4063
4065 4066 406b 406f 4071 407d 407f 4083
4087 408a 408e 4091 4095 4098 4099 409e
40a1 40a5 40a9 40ad 40b1 40b5 40b8 40bc
40c0 40c3 40c6 40cb 40ce 40d1 40d4 40d5
40da 40db 1 40dd 40e2 40e6 40ea 40ed
40f2 40f7 40fa 40fe 40ff 4104 4105 410a
410c 4110 4113 4117 411b 411f 4122 4126
4128 412c 412f 4133 4137 413a 413e 4142
4145 4146 4148 414b 414e 414f 4154 4157
415b 415f 4162 4166 416a 416d 416e 4170
4173 4176 4177 417c 1 417f 4184 4188
418c 4190 4194 4198 419b 419f 41a3 41a6
41a9 41ae 41b1 41b4 41b7 41b8 41bd 41be
1 41c0 41c5 41c9 41cd 41d0 41d5 41da
41dd 41e1 41e2 41e7 41e8 41ed 41ef 41f3
41f6 41fa 41fe 4202 4205 4209 420d 420f
4213 4217 421a 421e 4222 4225 4226 4228
422b 422e 422f 4234 4237 423b 423f 4242
4246 424a 424d 424e 4250 4253 4256 4257
425c 1 425f 4264 4268 426c 4270 4274
4278 427b 427f 4283 4286 4289 428e 4291
4294 4297 4298 429d 429e 1 42a0 42a5
42a9 42ad 42b0 42b5 42ba 42bd 42c1 42c2
42c7 42c8 42cd 42cf 42d3 42d6 42da 42de
42e2 42e5 42e9 42eb 42ef 42f3 42f6 42f8
42fc 42ff 4303 4307 430b 430f 4313 4317
431b 431f 4323 4327 432b 432f 4333 4337
433b 433f 4343 4347 434b 4357 435b 435f
4362 4366 436a 436c 4370 4374 4378 437b
437f 4383 4385 4386 438b 1 438f 4393
4397 439a 439e 43a2 43a6 43aa 43ad 43b1
43b5 43b8 43bb 43c0 43c3 43c6 43c9 43ca
43cf 43d0 1 43d2 43d7 43db 43df 43e2
43e7 43ec 43ef 43f3 43f4 43f9 43fc 4401
4402 4407 440a 440f 4410 4415 4418 441c
441d 4422 4425 442a 442b 4430 4433 4437
443b 443e 4441 4442 4444 4445 444a 444b
4450 4452 4456 4459 445b 445f 4461 446d
446f 4471 4472 4477 447b 447d 4489 448b
448f 4493 4497 449a 449b 449d 44a1 44a5
44a8 44a9 44ab 44ae 44b2 44b5 44b9 44bc
44bd 44c2 44c6 44ca 44ce 44d2 44d6 44d9
44dd 44e1 44e4 44e7 44ec 44ef 44f2 44f5
44f6 44fb 44fc 1 44fe 4503 4507 450b
450e 4513 4518 451b 451f 4520 4525 4526
452b 452d 4531 4534 4538 453c 4540 4543
4547 4549 454d 4550 4554 4558 455b 455e
455f 4561 4564 4569 456a 456f 4573 4576
457a 457c 4580 4583 4587 4589 458d 4591
4594 4598 459b 459f 45a3 45a6 45aa 45ae
45b2 45b5 45b9 45bd 45c0 45c1 45c3 45c6
45c9 45ca 45cf 45d2 45d6 45da 45dd 45e1
45e5 45e8 45e9 45eb 45ee 45f1 45f2 45f7
1 45fa 45ff 4603 4607 460a 460b 460d
4611 4614 4618 461b 461c 461e 461f 4624
1 4627 462c 4630 4634 4637 463b 463f
4642 4643 4645 4648 464b 464c 4651 4655
4659 465c 465d 465f 4662 4665 4666 466b
466f 4673 4676 467a 467e 4681 4682 4684
4687 468a 468b 1 4690 4695 4699 469d
46a1 46a5 46a9 46ac 46b0 46b4 46b7 46ba
46bf 46c2 46c5 46c8 46c9 46ce 46cf 1
46d1 46d6 46da 46de 46e1 46e6 46eb 46ee
46f2 46f3 46f8 46f9 46fe 4700 4704 4707
470b 470f 4713 4716 471a 471c 4720 4723
4727 472b 472e 472f 4731 4735 4738 473c
473f 4740 4745 4749 474d 4750 4751 4753
4757 475a 475e 4761 4762 1 4767 476c
4770 4773 4777 477b 477f 4783 4787 478b
478f 4793 4797 479b 479f 47a3 47a7 47ab
47b7 47bb 47bf 47c2 47c6 47ca 47cc 47d0
47d4 47d8 47db 47df 47e3 47e5 47e6 47eb
1 47ef 47f3 47f7 47fa 47fe 4802 4806
480a 480d 4811 4815 4818 481b 4820 4823
4826 4829 482a 482f 4830 1 4832 4837
483b 483f 4842 4847 484c 484f 4853 4854
4859 485c 4861 4862 4867 486a 486f 4870
4875 4878 487c 487d 4882 4885 488a 488b
4890 4893 4897 489b 489e 48a1 48a2 48a4
48a5 48aa 48ab 48b0 48b2 48b6 48b9 48bb
48bf 48c1 48cd 48cf 48d1 48d2 48d7 48db
48dd 48e9 48eb 48ef 48f3 48f6 48fa 48fe
4901 4902 4904 4907 490a 490b 4910 4913
4917 491b 491e 4922 4926 4929 492a 492c
492f 4932 4933 4938 1 493b 4940 4944
4949 494d 4951 4955 4959 495d 4961 4965
4969 496a 496c 4970 4972 4976 4979 497d
4981 4985 4989 498d 4991 4995 4999 499d
49a1 49a5 49a9 49ad 49b1 49b5 49b9 49bd
49c1 49c5 49c9 49cd 49d1 49d5 49d8 49d9
49db 49df 49e3 49e6 49e7 49e9 49ea 49ec
49f0 49f4 49f8 49fc 49fd 49ff 4a03 4a07
4a0b 4a0f 4a13 4a17 4a1a 4a1e 4a22 4a25
4a28 4a2d 4a30 4a33 4a36 4a37 4a3c 4a3d
1 4a3f 4a44 4a48 4a4c 4a4f 4a54 4a59
4a5c 4a60 4a61 4a66 4a67 4a6c 4a6e 4a72
4a75 4a79 4a7d 4a81 4a84 4a85 4a87 4a8b
4a8d 4a91 4a95 4a99 4a9d 4aa0 4aa4 4aa8
4aab 4aaf 4ab1 4ab5 4ab9 4abc 4ac0 4ac2
4ac6 4aca 4acd 4ad1 4ad5 4ad8 4ad9 4adb
4ade 4ae1 4ae2 4ae7 4aeb 4aef 4af3 4af7
4afb 4aff 4b03 4b07 4b0b 4b0f 4b1b 4b1f
4b23 4b26 4b2a 4b2e 4b30 4b34 4b38 4b3c
4b3f 4b43 4b47 4b49 4b4a 4b4f 1 4b53
4b57 4b5b 4b5e 4b62 4b66 4b6a 4b6e 4b71
4b75 4b79 4b7c 4b7f 4b84 4b87 4b8a 4b8d
4b8e 4b93 4b94 1 4b96 4b9b 4b9f 4ba3
4ba6 4bab 4bb0 4bb3 4bb7 4bb8 4bbd 4bc0
4bc5 4bc6 4bcb 4bce 4bd3 4bd4 4bd9 4bdc
4be0 4be1 4be6 4be9 4bee 4bef 4bf4 4bf7
4bfb 4bff 4c02 4c05 4c06 4c08 4c09 4c0e
4c0f 4c14 4c16 4c1a 4c1d 4c1f 4c23 4c25
4c31 4c33 4c35 4c36 4c3b 4c3f 4c41 4c4d
4c4f 4c53 4c57 4c5b 4c5e 4c62 4c66 4c67
4c69 4c6d 4c71 4c75 4c78 4c79 4c7b 4c7e
4c81 4c82 4c87 4c8a 4c8e 4c91 4c92 4c97
4c9a 1 4c9d 4ca2 4ca6 4caa 4cae 4cb2
4cb6 4cba 4cbe 4cc2 4cc6 4cc9 4cca 4ccc
4cd0 4cd2 4cd6 4cd9 4cdd 4ce1 4ce4 4ce7
4ce8 4cea 4ced 4cf2 4cf3 4cf8 4cfc 4cff
4d03 4d07 4d0a 4d0b 4d10 4d13 4d17 4d1b
4d1f 4d23 4d27 4d2b 4d2f 4d33 4d37 4d3b
4d47 4d4b 4d4f 4d52 4d56 4d5a 4d5c 4d60
4d64 4d68 4d6b 4d6f 4d73 4d75 4d76 4d7b
1 4d7f 4d83 4d87 4d8a 4d8e 4d92 4d96
4d9a 4d9d 4da1 4da5 4da8 4dab 4db0 4db3
4db6 4db9 4dba 4dbf 4dc0 1 4dc2 4dc7
4dcb 4dcf 4dd2 4dd7 4ddc 4ddf 4de3 4de4
4de9 4dec 4df1 4df2 4df7 4dfa 4dff 4e00
4e05 4e08 4e0c 4e0d 4e12 4e15 4e1a 4e1b
4e20 4e23 4e27 4e2b 4e2e 4e31 4e32 4e34
4e35 4e3a 4e3b 4e40 4e42 4e46 4e49 4e4b
4e4f 4e51 4e5d 4e5f 4e61 4e62 4e67 4e6b
4e6d 4e79 4e7b 4e7f 4e83 4e87 4e8a 4e8d
4e8e 4e90 4e94 4e96 4e9a 4e9d 4e9f 4ea3
4ea6 4eaa 4eac 4eb0 4eb4 4eb7 4ebb 4ebf
4ec3 4ec6 4ec7 4ec9 4ecc 4ed0 4ed4 4ed7
4ed8 4eda 4edb 4ee0 4ee4 4ee8 4eec 4ef0
4ef4 4ef8 4efc 4f00 4f04 4f08 4f0c 4f10
4f14 4f18 4f1c 4f20 4f24 4f28 4f2b 4f2c
4f2e 4f31 4f35 4f38 4f39 4f3b 4f3f 4f43
4f47 4f4a 4f4b 4f4d 4f50 4f53 4f54 4f59
4f5d 4f61 4f64 4f68 4f6c 4f6f 4f70 4f72
4f75 4f78 4f79 4f7e 4f82 4f86 4f8a 4f8e
4f92 4f96 4f9a 4f9e 4fa2 4fa6 4faa 4fae
4fb2 4fb6 4fc2 4fc6 4fcb 4fcf 4fd2 4fd3
4fd8 4fdc 4fe0 4fe3 4fe6 4fea 4fec 4ff0
4ff4 4ff7 4ffa 4ffe 5000 5004 5008 500b
500d 5011 5015 5019 501c 5020 5024 5026
5027 502c 1 5030 5034 5038 503b 503f
5043 5047 504b 504e 5052 5056 5059 505c
5061 5064 5067 506a 506b 5070 5071 1
5073 5078 507c 5080 5083 5088 508d 5090
5094 5095 509a 509d 50a2 50a3 50a8 50ab
50b0 50b1 50b6 50b9 50bd 50be 50c3 50c6
50cb 50cc 50d1 50d4 50d8 50dc 50df 50e2
50e3 50e5 50e6 50eb 50ec 50f1 50f3 50f7
50fa 50fc 5100 5102 510e 5110 5112 5113
5118 511c 511e 512a 512c 5130 5132 5136
513a 513d 513e 5140 5143 5146 5147 514c
5150 5154 5157 515b 515f 5162 5163 5165
5168 516b 516c 1 5171 5176 517a 517e
5182 5186 518a 518e 5192 5196 519a 519e
51aa 51ae 51b3 51b7 51ba 51bb 51c0 51c4
51c8 51cb 51ce 51d2 51d4 51d8 51dc 51df
51e2 51e6 51e8 51ec 51f0 51f3 51f5 51f9
51fd 5201 5204 5208 520c 520e 520f 5214
1 5218 521c 5220 5223 5227 522b 522f
5233 5236 523a 523e 5241 5244 5249 524c
524f 5252 5253 5258 5259 1 525b 5260
5264 5268 526b 5270 5275 5278 527c 527d
5282 5285 528a 528b 5290 5293 5298 5299
529e 52a1 52a5 52a6 52ab 52ae 52b3 52b4
52b9 52bc 52c0 52c4 52c7 52ca 52cb 52cd
52ce 52d3 52d4 52d9 52db 52df 52e2 52e4
52e8 52ea 52f6 52f8 52fa 52fb 5300 5304
5306 5312 5314 5316 531a 531e 5321 5323
5327 532a 532e 5332 5336 533a 533e 5341
5342 5344 5348 534c 5350 5354 5355 5357
535b 535f 5363 5366 5369 536d 5371 5375
5379 537d 5381 5384 5388 538c 538f 5392
5397 539a 539d 53a0 53a1 53a6 53a7 1
53a9 53ae 53b2 53b6 53b9 53be 53c3 53c6
53ca 53cb 53d0 53d1 53d6 53d8 53dc 53df
53e3 53e7 53eb 53ee 53f2 53f6 53f8 53fc
5400 5404 5407 5408 540a 540e 5411 5415
5418 5419 541b 541c 5421 5425 5429 542d
5430 5431 5433 5436 543a 543e 5441 5442
5444 5445 544a 544e 5452 5456 5459 545a
545c 5460 5463 5467 546a 546b 5470 5474
5478 547b 547c 547e 5482 5485 5489 548c
548d 1 5492 5497 549b 549f 54a2 54a5
54a6 54a8 54ab 54b0 54b1 54b6 54b9 54bd
54c1 54c5 54c7 54cb 54cf 54d3 54d5 54d9
54dd 54e0 54e4 54e8 54ec 54f0 54f4 54f8
54f9 54fb 54ff 5503 5507 550a 550e 5512
5515 5516 5518 551b 551e 551f 5524 5527
5528 552d 5531 5535 5538 553c 5540 5543
5544 5546 5549 554c 554d 5552 5555 5556
1 555b 5560 5564 5569 556d 5571 5575
5579 557c 5580 5584 5588 558c 5590 5594
5595 5597 559b 559f 55a3 55a6 55aa 55ae
55b2 55b6 55ba 55bd 55c1 55c5 55c9 55cd
55d1 55d5 55d9 55da 55dc 55e0 55e4 55e8
55eb 55ef 55f3 55f7 55fb 55ff 5602 5606
560a 560d 560e 5610 5614 5618 561b 561c
561e 5622 5624 5628 562c 5630 5632 5636
563a 563d 5641 5644 5645 564a 564d 5651
5655 5658 565c 5660 5663 5666 566b 566e
5671 5674 5675 567a 567b 1 567d 5682
5686 568a 568d 5692 5697 569a 569e 569f
56a4 56a5 56aa 56ac 56b0 56b3 56b7 56bb
56bf 56c2 56c6 56c8 56cc 56cf 56d3 56d7
56db 56df 56e3 56e7 56eb 56ef 56f3 56f7
56fb 56ff 5703 5707 570b 570f 5713 5717
571b 571f 5723 5727 572b 572e 572f 5731
5735 5739 573c 573d 573f 5740 5742 5746
574a 574e 5752 5753 5755 5759 575d 5761
5765 5769 576d 5770 5774 5778 577b 577e
5783 5786 5789 578c 578d 5792 5793 1
5795 579a 579e 57a2 57a5 57aa 57af 57b2
57b6 57b7 57bc 57bd 57c2 57c4 57c8 57cb
57cf 57d3 57d7 57da 57db 57dd 57e1 57e3
57e7 57ea 57ee 57f0 57f4 57f8 57fb 57ff
5801 5805 5809 580d 5810 5811 5813 5816
5819 581a 581f 5823 5826 582a 582e 5831
5835 5839 583d 5841 5845 5849 5855 5859
585d 5860 5864 5868 586a 586e 5872 5876
5879 587d 5881 5883 5884 5889 1 588d
5891 5895 5898 589c 58a0 58a4 58a8 58ab
58af 58b3 58b6 58b9 58be 58c1 58c4 58c7
58c8 58cd 58ce 1 58d0 58d5 58d9 58dd
58e0 58e5 58ea 58ed 58f1 58f2 58f7 58fa
58ff 5900 5905 5908 590d 590e 5913 5916
591a 591b 5920 5923 5928 5929 592e 5931
5935 5939 593c 593f 5940 5942 5943 5948
5949 594e 5950 5954 5957 5959 595d 595f
596b 596d 596f 5970 5975 5979 597b 5987
5989 598d 598f 5993 5997 599b 599e 599f
59a1 59a5 59a8 59ac 59af 59b0 59b2 59b3
59b8 59bc 59c0 59c4 59c7 59c8 59ca 59cd
59d1 59d5 59d8 59d9 59db 59dc 59e1 59e5
59e9 59ea 59ee 59f2 59f7 59fb 59ff 5a03
5a06 5a07 5a09 5a0c 5a0f 5a10 5a15 5a19
5a1e 5a21 5a26 5a27 5a2c 5a2f 5a33 5a34
5a39 5a3c 5a41 5a42 5a47 5a4a 5a4e 5a4f
5a54 5a57 5a5c 5a5d 5a62 5a65 5a6a 5a6b
5a70 5a73 5a77 5a7b 5a7f 5a82 5a83 5a85
5a86 5a88 5a89 5a8e 5a92 5a96 5a9a 5a9e
5aa1 5aa5 5aa7 5aab 5ab0 5ab3 5ab8 5ab9
5abe 5ac1 5ac5 5ac6 5acb 5ace 5ad3 5ad4
5ad9 5adc 5ae0 5ae1 5ae6 5ae9 5aee 5aef
5af4 5af7 5afc 5afd 5b02 5b05 5b09 5b0d
5b11 5b14 5b15 5b17 5b18 5b1a 5b1b 5b20
5b24 5b28 5b2c 5b30 5b33 5b37 5b39 5b3d
5b41 5b44 5b48 5b4c 5b50 5b53 5b54 5b56
5b59 5b5c 5b5d 5b62 5b66 5b6a 5b6f 5b74
5b78 5b7c 5b81 5b85 5b89 5b8c 5b8f 5b93
5b95 5b99 5b9d 5ba0 5ba3 5ba7 5ba9 5bad
5bb1 5bb4 5bb6 5bba 5bbe 5bc3 5bc8 5bcc
5bd0 5bd5 5bd9 5bdd 5be0 5be3 5be7 5be9
5bed 5bf1 5bf4 5bf7 5bfb 5bfd 5c01 5c05
5c08 5c0a 5c0e 5c12 5c15 5c19 5c1d 5c20
5c24 5c27 5c2b 5c2e 5c2f 5c34 5c37 5c3b
5c41 5c43 5c47 5c4a 5c4c 5c50 5c57 5c5b
5c5f 5c62 5c63 5c65 5c68 5c6b 5c6c 5c71
5c75 5c79 5c7e 5c80 5c84 5c88 5c8b 5c8f
5c93 5c95 5c99 5c9d 5ca1 5ca4 5ca8 5cac
5cae 5caf 5cb4 1 5cb8 5cbc 5cc0 5cc3
5cc7 5ccb 5ccf 5cd3 5cd6 5cda 5cde 5ce1
5ce4 5ce9 5cec 5cef 5cf2 5cf3 5cf8 5cf9
1 5cfb 5d00 5d04 5d08 5d0b 5d10 5d15
5d18 5d1c 5d1d 5d22 5d25 5d2a 5d2b 5d30
5d33 5d38 5d39 5d3e 5d41 5d45 5d46 5d4b
5d4e 5d53 5d54 5d59 5d5c 5d60 5d64 5d67
5d6a 5d6b 5d6d 5d6e 5d73 5d74 5d79 5d7b
5d7f 5d82 5d84 5d88 5d8a 5d96 5d98 5d9a
5d9b 5da0 5da4 5da6 5db2 5db4 5db6 5dba
5dbe 5dc3 5dc5 5dc9 5dcd 5dd0 5dd4 5dd8
5dda 5dde 5de2 5de6 5de9 5ded 5df1 5df3
5df4 5df9 1 5dfd 5e01 5e05 5e08 5e0c
5e10 5e14 5e18 5e1b 5e1f 5e23 5e26 5e29
5e2e 5e31 5e34 5e37 5e38 5e3d 5e3e 1
5e40 5e45 5e49 5e4d 5e50 5e55 5e5a 5e5d
5e61 5e62 5e67 5e6a 5e6f 5e70 5e75 5e78
5e7d 5e7e 5e83 5e86 5e8a 5e8b 5e90 5e93
5e98 5e99 5e9e 5ea1 5ea5 5ea9 5eac 5eaf
5eb0 5eb2 5eb3 5eb8 5eb9 5ebe 5ec0 5ec4
5ec7 5ec9 5ecd 5ecf 5edb 5edd 5edf 5ee0
5ee5 5ee9 5eeb 5ef7 5ef9 5efb 5eff 5f03
5f06 5f0a 5f0d 5f0e 5f13 5f16 5f1a 5f1e
5f21 5f22 5f24 5f27 5f2a 5f2b 5f30 5f34
5f38 5f3c 5f40 5f44 5f47 5f4b 5f4f 5f52
5f55 5f5a 5f5d 5f60 5f63 5f64 5f69 5f6a
1 5f6c 5f71 5f75 5f79 5f7c 5f81 5f86
5f89 5f8d 5f8e 5f93 5f94 5f99 5f9b 5f9f
5fa2 5fa6 5faa 5fae 5fb1 5fb5 5fb7 5fbb
5fbf 5fc3 5fc7 5fcb 5fce 5fd2 5fd6 5fd9
5fdc 5fe1 5fe4 5fe7 5fea 5feb 5ff0 5ff1
1 5ff3 5ff8 5ffc 6000 6003 6008 600d
6010 6014 6015 601a 601b 6020 6022 6026
6029 602d 6031 6035 6038 603c 603e 6042
6046 6049 604b 604f 6052 6056 605a 605e
6062 6066 606a 606e 6072 6076 607a 6086
608a 608e 6091 6095 6099 609b 609f 60a3
60a7 60aa 60ae 60b2 60b4 60b5 60ba 1
60be 60c2 60c6 60c9 60cd 60d1 60d5 60d9
60dc 60e0 60e4 60e7 60ea 60ef 60f2 60f5
60f8 60f9 60fe 60ff 1 6101 6106 610a
610e 6111 6116 611b 611e 6122 6123 6128
612b 6130 6131 6136 6139 613e 613f 6144
6147 614b 614c 6151 6154 6159 615a 615f
6162 6166 616a 616d 6170 6171 6173 6174
6179 617a 617f 6181 6185 6188 618a 618e
6190 619c 619e 61a0 61a1 61a6 61aa 61ac
61b8 61ba 61be 61c1 61c5 61c9 61cc 61d0
61d2 61d6 61da 61dd 61e1 61e3 61e7 61eb
61ee 61ef 61f1 61f5 61f8 61fc 61ff 6200
6202 6203 6208 620c 6210 6213 6214 6216
6219 621c 621d 6222 6226 622a 622d 622e
6230 6234 6237 623b 623e 623f 6241 6242
1 6247 624c 6250 6254 6258 625c 6260
6263 6267 626b 626e 6271 6276 6279 627c
627f 6280 6285 6286 1 6288 628d 6291
6295 6298 629d 62a2 62a5 62a9 62aa 62af
62b0 62b5 62b7 62bb 62be 62c2 62c6 62ca
62cd 62d1 62d3 62d7 62da 62de 62e2 62e5
62e6 62e8 62ec 62ef 62f3 62f6 62f7 62f9
62fa 62ff 6303 6307 630b 630f 6313 6316
631a 631e 6321 6324 6329 632c 632f 6332
6333 6338 6339 1 633b 6340 6344 6348
634b 6350 6355 6358 635c 635d 6362 6363
6368 636a 636e 6371 6375 6379 637d 6380
6384 6386 638a 638d 6391 6395 6398 6399
639b 639e 63a1 63a2 63a7 63ab 63ae 63b2
63b4 63b8 63bc 63bf 63c0 63c2 63c5 63c8
63c9 63ce 63d1 63d5 63d9 63dc 63dd 63df
63e2 63e5 63e6 63eb 1 63ee 63f3 63f7
63fb 63ff 6403 6407 640a 640e 6412 6415
6418 641d 6420 6423 6426 6427 642c 642d
1 642f 6434 6438 643c 643f 6444 6449
644c 6450 6451 6456 6457 645c 645e 6462
6465 6469 646d 6471 6474 6478 647a 647e
6481 6485 6489 648d 6490 6491 6493 6497
6499 649d 64a1 64a4 64a8 64ac 64af 64b0
64b2 64b6 64b9 64bd 64c0 64c1 64c6 64ca
64ce 64d1 64d2 64d4 64d8 64db 64df 64e2
64e3 1 64e8 64ed 64f1 64f5 64f8 64f9
64fb 64fe 6501 6502 6507 650a 650e 6511
6512 6517 651a 1 651d 6522 6526 652a
652e 6532 6536 653a 653e 6542 6546 654a
6556 655a 655e 6561 6565 6569 656b 656f
6573 6577 657a 657e 6582 6584 6585 658a
1 658e 6592 6596 6599 659d 65a1 65a5
65a9 65ac 65b0 65b4 65b7 65ba 65bf 65c2
65c5 65c8 65c9 65ce 65cf 1 65d1 65d6
65da 65de 65e1 65e6 65eb 65ee 65f2 65f3
65f8 65fb 6600 6601 6606 6609 660e 660f
6614 6617 661b 661c 6621 6624 6629 662a
662f 6632 6636 663a 663d 6640 6641 6643
6644 6649 664a 664f 6651 6655 6658 665a
665e 6660 666c 666e 6670 6671 6676 667a
667c 6688 668a 668c 6690 6693 6697 669b
669f 66a3 66a6 66a7 66a9 66ac 66b0 66b4
66b7 66b8 66ba 66bb 66c0 66c3 66c6 66c9
66ca 66cf 66d2 66d5 66d8 66d9 66de 66df
66e1 66e5 66e9 66ed 66f1 66f5 66f9 66fd
6701 6705 6709 670c 670d 670f 6713 6717
671b 671f 6722 6726 672a 672d 672e 6730
6734 6738 673b 673c 673e 6742 6746 674a
674e 6752 6756 6759 675c 675f 6760 6762
6766 676a 676e 6772 6776 677a 677d 677e
6780 6784 6788 678c 6790 6791 6793 6797
679b 679f 67a3 67a7 67ab 67ae 67b2 67b6
67b9 67bc 67c1 67c4 67c7 67ca 67cb 67d0
67d1 1 67d3 67d8 67dc 67e0 67e3 67e8
67ed 67f0 67f4 67f5 67fa 67fb 6800 6802
6806 6809 680d 6811 6815 6818 6819 681b
681f 6821 6825 6829 682d 6831 6834 6835
6837 683a 683e 6842 6845 6846 6848 6849
684e 6851 6854 6857 6858 685d 6860 6863
6866 6867 686c 686d 686f 6873 6877 687b
687e 687f 6881 6885 6888 688c 688f 6890
6892 6893 6898 689c 689f 68a3 68a7 68ab
68af 68b3 68b7 68bb 68bf 68cb 68cf 68d3
68d6 68da 68de 68e0 68e4 68e8 68ec 68ef
68f3 68f7 68f9 68fa 68ff 1 6903 6907
690b 690e 6912 6916 691a 691e 6921 6925
6929 692c 692f 6934 6937 693a 693d 693e
6943 6944 1 6946 694b 694f 6953 6956
695b 6960 6963 6967 6968 696d 6970 6975
6976 697b 697e 6983 6984 6989 698c 6990
6991 6996 6999 699e 699f 69a4 69a7 69ab
69af 69b2 69b5 69b6 69b8 69b9 69be 69bf
69c4 69c6 69ca 69cd 69cf 69d3 69d5 69e1
69e3 69e5 69e6 69eb 69ef 69f1 69fd 69ff
6a03 6a07 6a0a 6a0b 6a0d 6a10 6a13 6a14
6a19 6a1d 6a21 6a24 6a28 6a2c 6a2f 6a32
6a37 6a3a 6a3d 6a40 6a41 6a46 6a47 1
6a49 6a4e 6a52 6a56 6a59 6a5e 6a63 6a66
6a6a 6a6b 6a70 6a71 6a76 6a78 6a7c 6a7f
6a83 6a86 6a8a 6a8c 6a90 6a93 6a95 6a99
6a9c 6aa0 6aa3 6aa7 6aab 6aae 6ab2 6ab6
6aba 6abd 6abe 6ac0 6ac3 6ac6 6ac7 6acc
6ad0 6ad3 6ad7 6ad9 6add 6ae0 6ae4 6ae8
6aec 6aef 6af3 6af7 6afa 6afe 6b02 6b05
6b09 6b0d 6b10 6b11 6b13 6b17 6b1b 6b1e
6b1f 6b21 6b25 6b29 6b2d 6b31 6b35 6b39
6b3d 6b41 6b45 6b49 6b4d 6b51 6b55 6b59
6b5d 6b61 6b6d 6b71 6b76 6b7a 6b7d 6b7e
6b83 6b87 6b8b 6b8e 6b91 6b95 6b97 6b9b
6b9f 6ba2 6ba5 6ba9 6bab 6baf 6bb3 6bb6
6bb8 6bbc 6bc0 6bc4 6bc7 6bcb 6bcf 6bd1
6bd2 6bd7 1 6bdb 6bdf 6be3 6be6 6bea
6bee 6bf2 6bf6 6bf9 6bfd 6c01 6c04 6c07
6c0c 6c0f 6c12 6c15 6c16 6c1b 6c1c 1
6c1e 6c23 6c27 6c2b 6c2e 6c33 6c38 6c3b
6c3f 6c40 6c45 6c48 6c4d 6c4e 6c53 6c56
6c5b 6c5c 6c61 6c64 6c68 6c69 6c6e 6c71
6c76 6c77 6c7c 6c7f 6c83 6c87 6c8a 6c8d
6c8e 6c90 6c91 6c96 6c97 6c9c 6c9e 6ca2
6ca5 6ca7 6cab 6cad 6cb9 6cbb 6cbd 6cbe
6cc3 6cc7 6cc9 6cd5 6cd7 6cdb 6cdf 6ce2
6ce3 6ce5 6ce8 6ceb 6cec 6cf1 6cf5 6cf8
6cfc 6cfe 6d02 6d05 6d07 6d0b 6d0f 6d12
6d14 6d18 6d1c 6d1f 6d23 6d26 6d29 6d2a
6d2f 6d33 6d37 6d3a 6d3b 6d3d 6d40 6d43
6d44 6d49 6d4c 6d50 6d53 6d54 6d59 6d5c
1 6d5f 6d64 6d68 6d6c 6d70 6d74 6d78
6d7c 6d80 6d84 6d88 6d8b 6d8c 6d8e 6d92
6d94 6d98 6d9b 6d9f 6da2 6da3 6da8 6dab
6daf 6db3 6db7 6dbb 6dbe 6dbf 6dc1 6dc5
6dc7 6dcb 6dcf 6dd2 6dd5 6dd6 6dd8 6ddb
6de0 6de1 6de6 6dea 6dee 6df2 6df6 6df9
6dfa 6dfc 6e00 6e02 6e06 6e0a 6e0e 6e12
6e15 6e16 6e18 6e1c 6e1e 6e22 6e26 6e29
6e2b 6e2f 6e33 6e36 6e3a 6e3d 6e3e 6e43
6e46 6e4a 6e4e 6e51 6e52 6e54 6e57 6e5a
6e5b 6e60 6e64 6e68 6e6c 6e6f 6e73 6e77
6e7a 6e7b 6e7d 6e81 6e85 6e88 6e89 6e8b
6e8e 6e92 6e96 6e9a 6e9e 6ea2 6ea6 6eaa
6eae 6eb2 6eb6 6eba 6ec6 6eca 6ece 6ed1
6ed5 6ed9 6edb 6edf 6ee3 6ee7 6eea 6eee
6ef2 6ef4 6ef5 6efa 1 6efe 6f02 6f06
6f09 6f0d 6f11 6f15 6f19 6f1c 6f20 6f24
6f27 6f2a 6f2f 6f32 6f35 6f38 6f39 6f3e
6f3f 1 6f41 6f46 6f4a 6f4e 6f51 6f56
6f5b 6f5e 6f62 6f63 6f68 6f6b 6f70 6f71
6f76 6f79 6f7e 6f7f 6f84 6f87 6f8b 6f8c
6f91 6f94 6f99 6f9a 6f9f 6fa2 6fa6 6faa
6fad 6fb0 6fb1 6fb3 6fb4 6fb9 6fba 6fbf
6fc1 6fc5 6fc8 6fca 6fce 6fd0 6fdc 6fde
6fe0 6fe1 6fe6 6fea 6fec 6ff8 6ffa 6ffc
7000 7004 7008 700c 7010 7014 7018 701c
7020 7024 7030 7034 7038 703b 703f 7043
7045 7049 704d 7051 7054 7058 705c 705e
705f 7064 1 7068 706c 7070 7073 7077
707b 707f 7083 7086 708a 708e 7091 7094
7099 709c 709f 70a2 70a3 70a8 70a9 1
70ab 70b0 70b4 70b8 70bb 70c0 70c5 70c8
70cc 70cd 70d2 70d5 70da 70db 70e0 70e3
70e8 70e9 70ee 70f1 70f5 70f6 70fb 70fe
7103 7104 7109 710c 7110 7114 7117 711a
711b 711d 711e 7123 7124 7129 712b 712f
7132 7134 7138 713a 7146 7148 714a 714b
7150 7154 7156 7162 7164 7166 716a 716e
7171 7175 7179 717d 7180 7181 7183 7186
718a 718e 7191 7192 7194 7195 719a 719e
71a0 71a4 71a7 71ab 71ae 71b2 71b6 71ba
71be 71c2 71c6 71ca 71ce 71d2 71d6 71da
71dd 71de 71e0 71e4 71e8 71eb 71ec 71ee
71ef 71f1 71f5 71f9 71fd 7200 7201 7203
7206 7209 720a 720f 7213 7217 721b 721f
7223 7226 722a 722e 7231 7234 7239 723c
723f 7242 7243 7248 7249 1 724b 7250
7254 7258 725b 7260 7265 7268 726c 726d
7272 7273 7278 727a 727e 7281 7285 7289
728d 7290 7294 7298 729a 729e 72a1 72a4
72a5 72aa 72ae 72b2 72b5 72b8 72b9 72bb
72be 72c3 72c4 72c9 72cd 72d1 72d5 72d9
72e5 72e9 72ed 72f1 72f5 72f9 72fd 7301
7305 7309 730d 7311 7315 7319 731d 7321
7325 7329 732d 7331 7335 7339 733d 7349
734d 7352 7356 7359 735a 735f 7363 7367
736a 736d 7371 7373 7377 737b 737e 7381
7385 7387 738b 738f 7392 7394 7398 739c
73a0 73a3 73a7 73ab 73ad 73ae 73b3 1
73b7 73bb 73bf 73c2 73c6 73ca 73ce 73d2
73d5 73d9 73dd 73e0 73e3 73e8 73eb 73ee
73f1 73f2 73f7 73f8 1 73fa 73ff 7403
7407 740a 740f 7414 7417 741b 741c 7421
7424 7429 742a 742f 7432 7437 7438 743d
7440 7444 7445 744a 744d 7452 7453 7458
745b 745f 7463 7466 7469 746a 746c 746d
7472 7473 7478 747a 747e 7481 7483 7487
7489 7495 7497 7499 749a 749f 74a3 74a5
74b1 74b3 74b5 74b9 74bd 74c1 74c5 74c9
74cd 74d1 74d5 74d9 74dd 74e1 74e5 74f1
74f5 74fa 74fe 7501 7502 7507 750b 750f
7512 7515 7519 751b 751f 7523 7526 7529
752d 752f 7533 7537 753a 753c 7540 7544
7548 754b 754f 7553 7555 7556 755b 1
755f 7563 7567 756a 756e 7572 7576 757a
757d 7581 7585 7588 758b 7590 7593 7596
7599 759a 759f 75a0 1 75a2 75a7 75ab
75af 75b2 75b7 75bc 75bf 75c3 75c4 75c9
75cc 75d1 75d2 75d7 75da 75df 75e0 75e5
75e8 75ec 75ed 75f2 75f5 75fa 75fb 7600
7603 7607 760b 760e 7611 7612 7614 7615
761a 761b 7620 7622 7626 7629 762b 762f
7631 763d 763f 7641 7642 7647 764b 764d
7659 765b 765d 7661 7665 7668 766c 7670
7673 7674 7676 7679 767c 767d 7682 7685
7686 768b 768f 7690 7694 7698 769c 76a0
76a4 76a8 76ac 76b0 76b4 76b8 76bc 76c0
76c4 76c8 76cc 76d0 76d4 76d8 76dc 76e0
76e4 76e8 76ec 76f0 76f4 76f8 76fc 7708
770c 7710 7713 7717 771b 771d 7721 7725
7729 772c 7730 7734 7736 7737 773c 1
7740 7744 7748 774b 774f 7753 7757 775b
775e 7762 7766 7769 776c 7771 7774 7777
777a 777b 7780 7781 1 7783 7788 778c
7790 7793 7798 779d 77a0 77a4 77a5 77aa
77ad 77b2 77b3 77b8 77bb 77c0 77c1 77c6
77c9 77cd 77ce 77d3 77d6 77db 77dc 77e1
77e4 77e8 77ec 77ef 77f2 77f3 77f5 77f6
77fb 77fc 7801 7803 7807 780a 780c 7810
7812 781e 7820 7822 7823 7828 782c 782e
783a 783c 7840 7843 7844 7849 784c 7850
7854 7858 785c 7860 7864 7868 7874 7878
787c 787f 7883 7887 7889 788d 7891 7895
7898 789c 78a0 78a2 78a3 78a8 1 78ac
78b0 78b4 78b7 78bb 78bf 78c3 78c7 78ca
78ce 78d2 78d5 78d8 78dd 78e0 78e3 78e6
78e7 78ec 78ed 1 78ef 78f4 78f8 78fc
78ff 7904 7909 790c 7910 7911 7916 7919
791e 791f 7924 7927 792c 792d 7932 7935
7939 793a 793f 7942 7947 7948 794d 7950
7954 7958 795b 795e 795f 7961 7962 7967
7968 796d 796f 7973 7976 7978 797c 797e
798a 798c 798e 798f 7994 7998 799a 79a6
79a8 79ac 79b0 79b4 79b8 79bc 79c0 79c4
79d0 79d4 79d9 79dd 79e0 79e1 79e6 79ea
79ee 79f1 79f4 79f8 79fa 79fe 7a02 7a05
7a08 7a0c 7a0e 7a12 7a16 7a19 7a1b 7a1f
7a23 7a27 7a2a 7a2e 7a32 7a34 7a35 7a3a
1 7a3e 7a42 7a46 7a49 7a4d 7a51 7a55
7a59 7a5c 7a60 7a64 7a67 7a6a 7a6f 7a72
7a75 7a78 7a79 7a7e 7a7f 1 7a81 7a86
7a8a 7a8e 7a91 7a96 7a9b 7a9e 7aa2 7aa3
7aa8 7aab 7ab0 7ab1 7ab6 7ab9 7abe 7abf
7ac4 7ac7 7acb 7acc 7ad1 7ad4 7ad9 7ada
7adf 7ae2 7ae6 7aea 7aed 7af0 7af1 7af3
7af4 7af9 7afa 7aff 7b01 7b05 7b08 7b0a
7b0e 7b10 7b1c 7b1e 7b20 7b21 7b26 7b2a
7b2c 7b38 7b3a 7b3c 7b40 7b43 7b45 7b49
7b4c 7b4e 7b52 7b56 7b59 7b5d 7b61 7b65
7b66 7b68 7b6c 7b70 7b74 7b78 7b7c 7b80
7b83 7b87 7b8b 7b8e 7b91 7b96 7b99 7b9c
7b9f 7ba0 7ba5 7ba6 1 7ba8 7bad 7bb1
7bb5 7bb8 7bbd 7bc2 7bc5 7bc9 7bca 7bcf
7bd0 7bd5 7bd7 7bdb 7bde 7be2 7be6 7bea
7bed 7bee 7bf0 7bf4 7bf6 7bfa 7bfd 7c01
7c05 7c08 7c09 7c0b 7c0f 7c12 7c16 7c19
7c1a 7c1c 7c1d 7c22 7c26 7c29 7c2d 7c31
7c35 7c39 7c3d 7c41 7c45 7c49 7c4d 7c51
7c55 7c59 7c5d 7c69 7c6d 7c71 7c74 7c78
7c7c 7c7e 7c82 7c86 7c8a 7c8d 7c91 7c95
7c97 7c98 7c9d 1 7ca1 7ca5 7ca9 7cac
7cb0 7cb4 7cb8 7cbc 7cbf 7cc3 7cc7 7cca
7ccd 7cd2 7cd5 7cd8 7cdb 7cdc 7ce1 7ce2
1 7ce4 7ce9 7ced 7cf1 7cf4 7cf9 7cfe
7d01 7d05 7d06 7d0b 7d0e 7d13 7d14 7d19
7d1c 7d21 7d22 7d27 7d2a 7d2e 7d2f 7d34
7d37 7d3c 7d3d 7d42 7d45 7d49 7d4d 7d50
7d53 7d54 7d56 7d57 7d5c 7d5d 7d62 7d64
7d68 7d6b 7d6d 7d71 7d73 7d7f 7d81 7d83
7d84 7d89 7d8d 7d8f 7d9b 7d9d 7da1 7da5
7da8 7da9 7dab 7dae 7db1 7db2 7db7 7dbb
7dbf 7dc3 7dc7 7dcb 7dce 7dd2 7dd6 7dd9
7ddc 7de1 7de4 7de7 7dea 7deb 7df0 7df1
1 7df3 7df8 7dfc 7e00 7e03 7e08 7e0d
7e10 7e14 7e15 7e1a 7e1b 7e20 7e22 7e26
7e29 7e2d 7e31 7e35 7e38 7e3c 7e3e 7e42
7e45 7e49 7e4d 7e51 7e54 7e55 7e57 7e5b
7e5f 7e63 7e67 7e6a 7e6b 7e6d 7e71 7e75
7e79 7e7c 7e7d 7e7f 7e83 7e86 7e8a 7e8d
7e8e 7e90 7e91 7e96 7e9a 7e9e 7ea1 7ea2
7ea4 7ea8 7eab 7eaf 7eb2 7eb3 7eb8 7ebc
7ec0 7ec3 7ec4 7ec6 7eca 7ecd 7ed1 7ed4
7ed5 1 7eda 7edf 7ee3 7ee4 7ee8 7eec
7ef0 7ef4 7ef8 7efc 7f00 7f04 7f08 7f0c
7f10 7f14 7f18 7f24 7f28 7f2c 7f2f 7f33
7f37 7f39 7f3d 7f41 7f45 7f48 7f4c 7f50
7f52 7f53 7f58 1 7f5c 7f60 7f64 7f67
7f6b 7f6f 7f73 7f77 7f7a 7f7e 7f82 7f85
7f88 7f8d 7f90 7f93 7f96 7f97 7f9c 7f9d
1 7f9f 7fa4 7fa8 7fac 7faf 7fb4 7fb9
7fbc 7fc0 7fc1 7fc6 7fc9 7fce 7fcf 7fd4
7fd7 7fdc 7fdd 7fe2 7fe5 7fe9 7fea 7fef
7ff2 7ff7 7ff8 7ffd 8000 8004 8008 800b
800e 800f 8011 8012 8017 8018 801d 801f
8023 8026 8028 802c 802e 803a 803c 803e
803f 8044 8048 804a 8056 8058 805c 805f
8060 8065 8068 806c 8070 8074 8076 807a
807d 8081 8085 8088 8089 808b 808e 8091
8092 8097 809b 809f 80a2 80a3 80a5 80a8
80ab 80ac 80b1 80b4 80b8 80bb 80bc 80c1
80c4 1 80c7 80cc 80d0 80d4 80d8 80dc
80e0 80e4 80e8 80ec 80f0 80f4 80f8 80fc
8108 810c 8110 8113 8117 811b 811d 8121
8125 8129 812c 8130 8134 8136 8137 813c
1 8140 8144 8148 814b 814f 8153 8157
815b 815e 8162 8166 8169 816c 8171 8174
8177 817a 817b 8180 8181 1 8183 8188
818c 8190 8193 8198 819d 81a0 81a4 81a5
81aa 81ad 81b2 81b3 81b8 81bb 81c0 81c1
81c6 81c9 81cd 81ce 81d3 81d6 81db 81dc
81e1 81e4 81e8 81ec 81ef 81f2 81f3 81f5
81f6 81fb 81fc 8201 8203 8207 820a 820c
8210 8212 821e 8220 8222 8223 8228 822c
822e 823a 823c 8240 8244 8248 824b 824c
824e 8251 8255 8259 825c 825d 825f 8260
8265 8268 826c 8270 8273 8274 8276 8277
827c 8280 8282 8286 828a 828e 8291 8292
8294 8297 829b 829f 82a2 82a3 82a5 82a6
82ab 82af 82b1 82b5 82b9 82bc 82c0 82c3
82c7 82cb 82cf 82d3 82d7 82db 82dc 82de
82e1 82e2 82e4 82e7 82eb 82ef 82f3 82f4
82f6 82f9 82fa 82fc 82fd 8302 8305 8308
830b 830c 8311 8312 8314 8318 831c 8320
8324 8327 8328 832a 832d 8331 8335 8338
8339 833b 833c 8341 8345 8349 834d 8350
8351 8353 8357 835a 835e 8361 8362 8364
8365 836a 836e 8372 8376 8379 837a 837c
837f 8383 8387 838a 838b 838d 838e 8393
8396 839a 839e 83a1 83a2 83a4 83a5 83aa
83ae 83b0 83b4 83b8 83bc 83bf 83c0 83c2
83c6 83c8 83cc 83d0 83d3 83d7 83db 83df
83e3 83e7 83eb 83ef 83f3 83f7 83fa 83fb
83fd 8401 8405 8409 840d 8411 8415 8416
8418 841b 841c 841e 8421 8425 8429 842d
842e 8430 8433 8434 8436 8437 843c 843f
8442 8445 8446 844b 844c 844e 8452 8456
845a 845e 8461 8465 8469 846c 846d 846f
8473 8477 847a 847b 847d 8481 8485 8489
848d 8491 8495 8499 849d 84a0 84a1 84a3
84a7 84ab 84ae 84af 84b1 84b4 84b5 84b7
84bb 84bf 84c3 84c7 84cb 84cf 84d2 84d3
84d5 84d9 84db 84df 84e2 84e4 84e8 84eb
84ef 84f3 84f7 84fb 84fe 84ff 8501 8505
8509 850d 8511 8515 8519 851d 8521 8525
8529 852d 8531 8535 8539 853d 8541 8545
8549 854d 8551 8555 8559 855d 8561 8565
8569 856d 8571 8574 8575 8577 857b 857f
8582 8583 8585 8586 8588 858c 8590 8594
8598 859b 859c 859e 85a2 85a6 85aa 85ae
85b1 85b2 85b4 85b7 85bb 85bf 85c2 85c3
85c5 85c6 85cb 85cf 85d3 85d7 85db 85df
85e3 85ef 85f3 85f7 85fa 85fe 8602 8604
8608 860c 8610 8613 8617 861b 861d 861e
8623 1 8627 862b 862f 8632 8636 863a
863e 8642 8645 8649 864d 8650 8653 8658
865b 865e 8661 8662 8667 8668 1 866a
866f 8673 8677 867a 867f 8684 8687 868b
868c 8691 8694 8699 869a 869f 86a2 86a7
86a8 86ad 86b0 86b4 86b5 86ba 86bd 86c2
86c3 86c8 86cb 86cf 86d3 86d6 86d9 86da
86dc 86dd 86e2 86e3 86e8 86ea 86ee 86f1
86f3 86f7 86f9 8705 8707 8709 870a 870f
8713 8715 8721 8723 8727 872b 872f 8733
8737 873b 873f 8743 8747 8753 8757 875b
875e 8762 8766 8768 876c 8770 8774 8777
877b 877f 8781 8782 8787 1 878b 878f
8793 8796 879a 879e 87a2 87a6 87a9 87ad
87b1 87b4 87b7 87bc 87bf 87c2 87c5 87c6
87cb 87cc 1 87ce 87d3 87d7 87db 87de
87e3 87e8 87eb 87ef 87f0 87f5 87f8 87fd
87fe 8803 8806 880b 880c 8811 8814 8818
8819 881e 8821 8826 8827 882c 882f 8833
8837 883a 883d 883e 8840 8841 8846 8847
884c 884e 8852 8855 8857 885b 885d 8869
886b 886d 886e 8873 8877 8879 8885 8887
888b 888f 8893 8897 889b 889f 88a3 88a7
88ab 88af 88b3 88b7 88bb 88bf 88c3 88c7
88cb 88cf 88d3 88df 88e3 88e8 88ec 88ef
88f0 88f5 88f9 88fd 8900 8903 8907 8909
890d 8911 8914 8917 891b 891d 8921 8925
8928 892a 892e 8932 8936 8939 893d 8941
8943 8944 8949 1 894d 8951 8955 8958
895c 8960 8964 8968 896b 896f 8973 8976
8979 897e 8981 8984 8987 8988 898d 898e
1 8990 8995 8999 899d 89a0 89a5 89aa
89ad 89b1 89b2 89b7 89ba 89bf 89c0 89c5
89c8 89cd 89ce 89d3 89d6 89da 89db 89e0
89e3 89e8 89e9 89ee 89f1 89f5 89f9 89fc
89ff 8a00 8a02 8a03 8a08 8a09 8a0e 8a10
8a14 8a17 8a19 8a1d 8a1f 8a2b 8a2d 8a2f
8a30 8a35 8a39 8a3b 8a47 8a49 8a4d 8a51
8a54 8a58 8a5b 8a5f 8a62 8a63 8a68 8a6b
8a6f 8a72 8a76 8a7a 8a7e 8a82 8a86 8a8a
8a8e 8a92 8a96 8a99 8a9d 8aa1 8aa4 8aa5
8aa7 8aa8 8aaa 8aae 8ab2 8ab6 8ab9 8aba
8abc 8abf 8ac2 8ac3 8ac8 8acc 8ad0 8ad4
8ad8 8adc 8adf 8ae3 8ae7 8aea 8aed 8af2
8af5 8af8 8afb 8afc 8b01 8b02 1 8b04
8b09 8b0d 8b11 8b14 8b19 8b1e 8b21 8b25
8b26 8b2b 8b2c 8b31 8b33 8b37 8b3a 8b3e
8b42 8b46 8b49 8b4a 8b4c 8b50 8b52 8b56
8b59 8b5b 8b5f 8b62 8b64 8b68 8b6c 8b6f
8b73 8b77 8b7b 8b7e 8b7f 8b81 8b85 8b89
8b8c 8b90 8b92 8b96 8b9a 8b9e 8ba2 8ba6
8ba7 8ba9 8bac 8bad 8baf 8bb2 8bb6 8bba
8bbe 8bbf 8bc1 8bc4 8bc5 8bc7 8bc8 8bcd
8bd0 8bd3 8bd6 8bd7 8bdc 8bdf 8be2 8be5
8be6 8beb 8bec 8bee 8bf2 8bf4 8bf8 8bfc
8bff 8c03 8c07 8c0b 8c0f 8c13 8c17 8c1b
8c1f 8c23 8c27 8c2b 8c2f 8c33 8c37 8c3b
8c3f 8c43 8c47 8c4b 8c4f 8c53 8c57 8c5b
8c5f 8c63 8c67 8c6b 8c6e 8c6f 8c71 8c75
8c79 8c7c 8c7d 8c7f 8c80 8c82 8c86 8c8a
8c8e 8c92 8c96 8c9a 8c9d 8ca1 8ca5 8ca8
8cab 8cb0 8cb3 8cb6 8cb9 8cba 8cbf 8cc0
1 8cc2 8cc7 8ccb 8ccf 8cd2 8cd7 8cdc
8cdf 8ce3 8ce4 8ce9 8cea 8cef 8cf1 8cf5
8cf8 8cfc 8d00 8d04 8d07 8d08 8d0a 8d0e
8d12 8d14 8d18 8d1c 8d1f 8d20 8d22 8d26
8d29 8d2d 8d30 8d31 8d33 8d34 8d39 8d3d
8d41 8d44 8d45 8d47 8d4a 8d4d 8d4e 8d53
8d56 8d5a 8d5e 8d61 8d62 8d64 8d67 8d6a
8d6b 8d70 1 8d73 8d78 8d7c 8d80 8d84
8d88 8d8c 8d8f 8d93 8d97 8d9a 8d9d 8da2
8da5 8da8 8dab 8dac 8db1 8db2 1 8db4
8db9 8dbd 8dc1 8dc4 8dc9 8dce 8dd1 8dd5
8dd6 8ddb 8ddc 8de1 8de3 8de7 8dea 8dee
8df2 8df6 8df9 8dfd 8dff 8e03 8e06 8e0a
8e0e 8e12 8e16 8e1a 8e1e 8e22 8e26 8e2a
8e2e 8e32 8e3e 8e42 8e47 8e4b 8e4e 8e4f
8e54 8e58 8e5c 8e5f 8e62 8e66 8e68 8e6c
8e70 8e73 8e76 8e7a 8e7c 8e80 8e84 8e87
8e89 8e8d 8e91 8e95 8e98 8e9c 8ea0 8ea2
8ea3 8ea8 1 8eac 8eb0 8eb4 8eb7 8ebb
8ebf 8ec3 8ec7 8eca 8ece 8ed2 8ed5 8ed8
8edd 8ee0 8ee3 8ee6 8ee7 8eec 8eed 1
8eef 8ef4 8ef8 8efc 8eff 8f04 8f09 8f0c
8f10 8f11 8f16 8f19 8f1e 8f1f 8f24 8f27
8f2c 8f2d 8f32 8f35 8f39 8f3a 8f3f 8f42
8f47 8f48 8f4d 8f50 8f54 8f58 8f5b 8f5e
8f5f 8f61 8f62 8f67 8f68 8f6d 8f6f 8f73
8f76 8f78 8f7c 8f7e 8f8a 8f8c 8f8e 8f8f
8f94 8f98 8f9a 8fa6 8fa8 8fac 8fb0 8fb4
8fb8 8fbc 8fc0 8fc4 8fc8 8fcc 8fd0 8fd4
8fe0 8fe4 8fe9 8fed 8ff0 8ff1 8ff6 8ffa
8ffe 9001 9004 9008 900a 900e 9012 9015
9018 901c 901e 9022 9026 9029 902b 902f
9033 9037 903a 903e 9042 9044 9045 904a
1 904e 9052 9056 9059 905d 9061 9065
9069 906c 9070 9074 9077 907a 907f 9082
9085 9088 9089 908e 908f 1 9091 9096
909a 909e 90a1 90a6 90ab 90ae 90b2 90b3
90b8 90bb 90c0 90c1 90c6 90c9 90ce 90cf
90d4 90d7 90db 90dc 90e1 90e4 90e9 90ea
90ef 90f2 90f6 90fa 90fd 9100 9101 9103
9104 9109 910a 910f 9111 9115 9118 911a
911e 9120 912c 912e 9130 9131 9136 913a
913c 9148 914a 914c 9150 9154 9157 915b
915f 9163 9164 9166 916a 916e 9172 9176
917a 917e 9181 9185 9189 918c 918f 9194
9197 919a 919d 919e 91a3 91a4 1 91a6
91ab 91af 91b3 91b6 91bb 91c0 91c3 91c7
91c8 91cd 91ce 91d3 91d5 91d9 91dc 91e0
91e4 91e8 91eb 91ec 91ee 91f2 91f4 91f8
91fc 9200 9204 9208 920c 9210 9214 9218
921c 9220 9224 9228 922c 9230 9234 9238
923c 9240 9244 9248 924c 9250 9254 9258
925c 9260 9264 9268 926c 9270 9274 9278
9284 9288 928c 928f 9293 9297 9299 929d
92a1 92a5 92a8 92ac 92b0 92b2 92b3 92b8
1 92bc 92c0 92c4 92c7 92cb 92cf 92d3
92d7 92da 92de 92e2 92e5 92e8 92ed 92f0
92f3 92f6 92f7 92fc 92fd 1 92ff 9304
9308 930c 930f 9314 9319 931c 9320 9321
9326 9329 932e 932f 9334 9337 933c 933d
9342 9345 9349 934a 934f 9352 9357 9358
935d 9360 9364 9368 936b 936e 936f 9371
9372 9377 9378 937d 937f 9383 9386 9388
938c 938e 939a 939c 939e 939f 93a4 93a8
93aa 93b6 93b8 93bc 93c0 93c3 93c7 93ca
93ce 93d1 93d2 93d7 93da 93dd 93de 93e3
93e7 93eb 93ef 93f3 93f7 93fa 93fe 9402
9405 9408 940d 9410 9413 9416 9417 941c
941d 1 941f 9424 9428 942c 942f 9434
9439 943c 9440 9441 9446 9447 944c 944e
9452 9455 9459 945d 9461 9464 9468 946a
946e 9471 9475 9479 947c 9480 9484 9485
9487 948a 948d 948e 9493 9497 949b 949e
94a1 94a5 94a9 94ad 94b1 94b5 94b9 94bc
94c0 94c4 94c7 94ca 94cf 94d2 94d5 94d8
94d9 94de 94df 1 94e1 94e6 94ea 94ee
94f1 94f6 94fb 94fe 9502 9503 9508 9509
950e 9510 9514 9517 951b 951f 9523 9526
952a 952c 9530 9533 9535 9539 953d 9540
9542 9546 9549 954d 9551 9555 9559 955d
9561 9565 9569 956d 9571 9575 9579 957c
9580 9584 9588 958b 958f 9593 9597 959b
959f 95a0 95a2 95a6 95aa 95ae 95b2 95b6
95ba 95bd 95c1 95c5 95c8 95cb 95d0 95d3
95d6 95d9 95da 95df 95e0 1 95e2 95e7
95eb 95ef 95f2 95f7 95fc 95ff 9603 9604
9609 960a 960f 9611 9615 9618 961c 9620
9624 9627 962b 962f 9633 9636 963a 963e
9641 9644 9649 964c 964f 9652 9653 9658
9659 1 965b 9660 9664 9668 966b 9670
9675 9678 967c 967d 9682 9685 968a 968b
9690 9693 9698 9699 969e 96a1 96a5 96a9
96ac 96ad 96b2 96b3 96b8 96ba 96be 96c1
96c5 96c9 96cd 96d0 96d4 96d6 96da 96dc
96e8 96ec 96ee 96ef 96f8 
2b45
2
0 1 a 6 17 1b 22 :3 6
19 1d 24 :3 6 1b 1f 26 :3 6
1c 20 27 :3 6 13 :3 6 13 :3 6
1a :3 6 14 :3 6 14 18 1f :3 6
e 12 19 :2 6 1 3 a :2 1
4 :2 e 1d e :2 4 :2 e 1d e
:2 4 :2 15 24 15 :2 4 :2 f 1e f
:2 4 18 21 20 :2 18 :2 4 12 1b
1a :2 12 :2 4 11 1a 19 :2 11 :2 4
15 1e 1d :2 15 :2 4 17 20 1f
:2 17 :2 4 14 1d 1c :2 14 :2 4 10
19 18 :2 10 :2 4 18 21 20 :2 18
:2 4 12 1b 1a :2 12 :2 4 e 17
16 :2 e :2 4 14 1d 1c :2 14 :2 4
11 1a 19 :2 11 :2 4 11 1a 19
:2 11 :2 4 16 1f 1e :2 16 :2 4 :3 13
:2 4 :3 11 :2 4 :3 12 :2 4 :3 12 :2 4 :3 13
:2 4 :3 f :2 4 :3 12 :2 4 :3 13 :2 4 :3 14
:2 4 :3 15 :2 4 :3 9 :2 4 :3 9 :2 4 :3 e
:2 4 f 18 17 :2 f :2 4 f 18
17 :2 f :2 4 14 1d 1c :2 14 :2 4
:2 12 21 12 :2 4 :2 f 1e f :2 4
:2 16 25 16 :2 4 :2 11 20 11 :2 4
:3 10 :2 4 :3 15 :2 4 :2 17 26 17 :2 4
:2 13 22 13 :2 4 :2 12 21 12 :2 4
:2 12 21 12 :2 4 :2 14 23 14 :2 4
:2 15 24 15 :2 4 :2 12 21 12 :2 4
:2 d 1c d :2 4 :2 11 20 11 :2 4
:2 13 22 13 :2 4 e 17 16 :2 e
:2 4 d 16 15 :2 d :2 4 f 18
17 :2 f :2 4 :2 d 1c d :2 4 :2 e
1d e :2 4 :2 c 1b c :2 4 :2 14
23 14 :2 4 :2 13 22 13 :2 4 :2 12
21 12 :2 4 :2 11 20 11 :2 4 :2 b
1a b :2 4 :2 f 1e f :2 4 :2 e
1d e :2 4 :2 13 22 13 :2 4 :2 10
1f 10 :2 4 :2 e 1d e :2 4 :2 10
1f 10 :2 4 :2 13 22 13 :2 4 :2 f
1e f :2 4 :2 e 1d e :2 4 :2 f
1e f :2 4 :2 c 1b c :2 4 :2 b
1a b :2 4 :2 13 22 13 :2 4 :2 a
19 a :2 4 :2 12 21 12 :2 4 :2 11
20 11 :2 4 :2 e 1d e :2 4 :2 c
1b c :2 4 :2 10 1f 10 :2 4 :2 f
1e f :2 4 :2 f 1e f :2 4 :2 10
1f 10 :2 4 14 1d 1c :2 14 :2 4
14 1d 1c :2 14 :2 4 :2 17 26 17
:2 4 17 20 1f :2 17 :2 4 :2 13 22
13 :2 4 :2 14 23 14 :2 4 :2 f 1e
f :2 4 :2 f 19 f :2 4 :2 f 19
f :2 4 :2 10 1a 10 :2 4 :2 10 1a
10 :2 4 :2 11 1b 11 :2 4 :2 11 1b
11 :2 4 :2 12 1c 12 :2 4 :2 12 1c
12 :2 4 9 12 11 :2 9 :2 4 :3 f
:2 4 :3 e :2 4 :3 e :2 4 :3 10 :2 4 :2 16
2e 16 4 7 e 0 :2 7 11
1c 29 33 3e 43 4c 5d f
10 1d e 1a 22 29 13 a
:6 7 e 0 :2 7 11 1c 29 33
3e 43 4c 5c f 10 1d e
1a 22 29 13 a :6 7 11 1a
:3 11 :2 7 11 1a :3 11 :2 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 58 5e 61 :2 58 6f 89
8 :2 6f d 10 :2 6f 1e 21 :2 6f
b e :2 6f 13 16 :2 6f 1b 1e
:2 6f 2e 31 :2 6f b e :2 6f 13
16 1f 26 2b 2e :2 26 40 43
:2 26 48 :2 1f 51 :2 16 :2 6f b e
:2 6f 13 16 1f 26 2b 2e :2 26
41 44 :2 26 49 :2 1f 52 :2 16 :2 6f
b e :2 6f 13 16 1f 27 :2 1f
36 :2 16 :2 6f b e :2 6f 13 16
1f 27 :2 1f 36 :2 16 :2 6f b e
:2 6f 13 16 1f 27 :2 1f 3d :2 16
:2 6f b e :2 6f 13 16 1f 27
:2 1f 37 :2 16 :2 6f b e :2 6f 13
16 :2 6f 1b 1e :2 6f 29 2c :2 6f
b e :2 6f 13 16 :2 6f 1b 1e
:2 6f 23 26 :2 6f 2b 2e :2 6f :2 7
4e :2 4 7 :2 11 23 :2 2d 39 3c
50 53 54 :2 50 :2 23 :3 7 :2 d 12
1e 62 65 :2 1e :2 7 57 :3 4 13
:2 4 14 :2 4 12 :2 4 15 :2 4 11
4 e 11 24 27 34 37 43
46 11 14 11 14 7 a 7
a 16 19 c 21 30 3e :4 7
15 c 21 d 10 24 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 57 5a 5b
:2 57 :2 29 :3 d :2 13 18 24 68 6b
:2 24 78 7b :2 24 7f 82 :2 24 8e
91 :2 24 99 9c :2 24 a8 ab b2
bb be :2 ab :2 24 :2 d 5e :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a 7 11 24 3b 47 54
63 a 1a 25 2f 37 3f 14
23 32 44 53 61 6e 80 14
28 3a 4a 5b a 12 19 34
3c 43 5f 69 a 18 26 34
a 1a 2a 3a a 1d 26 3d
55 f 24 35 43 4c 58 a
1c 27 2f 38 40 a 1b 2b
3a 48 a 14 1d a 10 16
22 a 16 23 2f a 18 27
35 a 1a 25 34 f 10 24
:2 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 5a
5d 5e :2 5a :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 7b 7e :2 27 82 85
:2 27 91 94 :2 27 9c 9f :2 27 ab
ae b5 be c1 :2 ae :2 27 :2 10 61
:2 d :2 a :4 16 :2 a 7 :3 35 b :2 14
1f 1d :2 28 :2 1d a 14 20 2b
3b 45 50 65 6f d 1b 1f
2c 3d 4b 59 5e 67 76 12
20 2d 38 46 55 61 6d d
1d 2a 39 43 53 5a 12 20
2d :2 d :2 16 22 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5d 60 61 :2 5d :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 94 97 :2 2a 9f a2 :2 2a
ae b1 b8 c1 c4 :2 b1 :2 2a :2 13
64 :2 10 :2 d :4 19 :2 d a :3 38 e
:2 17 22 20 :2 2b :2 20 :2 d 15 d
10 :2 1a 2c :2 36 42 45 59 5c
5d :2 59 :2 2c :3 10 :2 16 1b 27 6b
6e :2 27 :2 10 60 :3 d 14 :2 1d d
3b :2 a e 15 10 1d :2 15 21
:2 2a :2 e d 43 41 :2 4c :2 41 d
15 d 10 :2 1a 2c :2 36 42 45
59 5c 5d :2 59 :2 2c :3 10 :2 16 1b
27 6b 6e :2 27 :2 10 60 :3 d 14
:2 1d d 61 :3 a 1b :2 a 1c a
e :2 19 21 30 40 :2 e 44 46
:2 44 d 4e :2 59 10 20 2f :2 4e
33 36 :2 33 4d :3 d 15 d 10
:2 1a 2c :2 36 42 45 59 5c 5d
:2 59 :2 2c :3 10 :2 16 1b 27 6b 6e
:2 27 :2 10 60 :3 d 14 :2 1d d 39
:2 a :4 f e d 2d 36 40 :2 2d
43 45 4e 5d :2 45 :2 2d 2c 64
61 10 17 :2 64 :2 61 2b :3 d 15
d 10 :2 1a 2c :2 36 42 45 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 :2 10 60 :3 d 14 :2 1d
d 1b :2 a e :2 19 21 30 3e
:2 e 42 45 :2 42 d 4c :2 57 5f
12 21 :2 4c 25 28 :2 25 4b :2 d
10 19 28 :2 10 2b 2d :2 2b 13
:2 1d 2f :2 39 45 48 5c 5f 60
:2 5c :2 2f :3 13 :2 19 1e 2a 6e 71
:2 2a :2 13 63 :3 10 17 10 2f :2 d
10 19 29 :2 10 2c 2e :2 2c 13
:2 1e 26 35 43 :2 13 47 4a :2 47
1d 28 35 3f 4a 4f 58 69
7b 1b 1c 29 1a 25 2d 34
:2 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :3 4c 17 :2 20
2b 29 :2 34 :2 29 16 20 2b 38
40 47 5f 6a 7e 1e :2 19 :2 22
2e 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 69 6c 6d
:2 69 :2 3b :3 1f :2 25 2a 36 7a 7d
:2 36 8a 8d :2 36 91 94 :2 36 a0
a3 :2 36 ab ae :2 36 ba bd c4
cd d0 :2 bd :2 36 :2 1f 70 :2 1c :2 19
:4 25 :2 19 16 :4 44 :2 13 16 :2 21 29
38 48 :2 16 4c 4e :2 4c 16 28
16 50 :2 13 4c 1d 28 35 3f
4a 4f 58 68 7a 1b 1c 29
1a 25 2d 34 :2 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 69 6a :2 66 :2 38
:3 1c :2 22 27 33 77 7a :2 33 87
8a :2 33 8e 91 :2 33 9d a0 :2 33
a8 ab :2 33 b7 ba c1 ca cd
:2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16
13 :3 10 17 :2 20 2b 29 :2 34 :2 29
16 20 2b 38 40 47 60 6b
7f 1e :2 19 :2 22 2e 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 69 6c 6d :2 69 :2 3b :3 1f :2 25
2a 36 7a 7d :2 36 8a 8d :2 36
91 94 :2 36 a0 a3 :2 36 ab ae
:2 36 ba bd c4 cd d0 :2 bd :2 36
:2 1f 70 :2 1c :2 19 :4 25 :2 19 16 :4 44
:3 13 21 13 :4 10 13 1c 29 :2 13
2e 2c :2 37 :2 2c 1d 29 37 46
55 65 76 1c 29 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :4 3d 1d 29
39 48 59 69 7c 1c 29 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 69 6a :2 66 :2 38 :3 1c :2 22
27 33 77 7a :2 33 87 8a :2 33
8e 91 :2 33 9d a0 :2 33 a8 ab
:2 33 b7 ba c1 ca cd :2 ba :2 33
:2 1c 6d :2 19 :2 16 :4 22 :2 16 13 :7 10
30 10 1e :2 10 1b 10 13 :2 1e
26 35 43 :2 13 47 4a :2 47 13
18 :3 13 19 25 :2 13 16 1d :2 16
:2 1f 2b 16 23 16 :2 1f 2b 16
:4 13 17 :2 20 2b 29 :2 34 :2 29 16
20 2b 38 40 47 5f 6a 7e
1e :2 19 :2 22 2e 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
69 6c 6d :2 69 :2 3b :3 1f :2 25 2a
36 7a 7d :2 36 8a 8d :2 36 91
94 :2 36 a0 a3 :2 36 ab ae :2 36
ba bd c4 cd d0 :2 bd :2 36 :2 1f
70 :2 1c :2 19 :4 25 :2 19 16 :4 44 :2 13
16 1c :3 16 :2 1f 2b 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 69 6a :2 66 :2 38 :3 1c :2 22
27 33 77 7a :2 33 87 8a :2 33
8e 91 :2 33 9d a0 :2 33 a8 ab
:2 33 b7 ba c1 ca cd :2 ba :2 33
:2 1c 6d :2 19 :2 16 :4 22 :2 16 13 :3 4c
16 1f 2c :2 16 31 2f :2 3a :2 2f
4f 19 26 :2 4f 2b 29 :2 34 :2 29
:3 16 28 :2 16 21 :2 2a 31 3a 46
:2 31 4a :2 53 :2 21 :2 16 24 16 48
:2 13 4c 16 1f 2e :2 16 31 33
:2 31 16 24 16 20 30 40 29
1f 2c 3d 47 1d 31 3c 44
4b :2 19 :2 22 2e 19 16 1e 1c
:2 25 31 1c 2c :2 19 :2 1e 1c :2 25
31 1c 1f :2 29 3b :2 45 51 55
69 6c 6d :2 69 :2 3b :3 1f :2 25 2a
36 7a 7d :2 36 8a 8d :2 36 91
94 :2 36 a0 a3 :2 36 ab ae :2 36
ba bd c4 cd d0 :2 bd :2 36 :2 1f
70 :2 1c :2 19 :4 25 :2 19 16 :3 35 19
22 2e :2 19 31 33 :2 31 23 33
43 2c 22 2f 40 4a 20 28
2f 43 4b 52 :2 1c :2 25 31 1c
19 21 1f :2 28 34 1f 2f :2 1c
:2 21 1f :2 28 34 1f 22 :2 2c 3e
:2 48 54 58 6c 6f 70 :2 6c :2 3e
:3 22 :2 28 2d 39 7d 80 :2 39 8d
90 :2 39 94 97 :2 39 a3 a6 :2 39
ae b1 :2 39 bd c0 c7 d0 d3
:2 c0 :2 39 :2 22 73 :2 1f :2 1c :4 28 :2 1c
19 :4 35 :2 16 19 22 2e :2 19 31
33 :2 31 19 21 19 1c :2 26 38
:2 42 4e 51 65 68 69 :2 65 :2 38
:3 1c :2 22 27 33 77 7a :2 33 :2 1c
6c :3 19 20 :2 29 19 35 :2 16 35
:3 13 18 :3 13 19 25 :2 13 16 1d
:2 16 :2 1f 2b 16 23 16 :2 1f 2b
16 :4 13 17 :2 20 2b 29 :2 34 :2 29
16 20 2b 38 40 47 60 6b
7f 1e :2 19 :2 22 2e 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 69 6c 6d :2 69 :2 3b :3 1f :2 25
2a 36 7a 7d :2 36 8a 8d :2 36
91 94 :2 36 a0 a3 :2 36 ab ae
:2 36 ba bd c4 cd d0 :2 bd :2 36
:2 1f 70 :2 1c :2 19 :4 25 :2 19 16 :4 44
:2 13 16 1c :3 16 :2 1f 2b 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 69 6a :2 66 :2 38 :3 1c
:2 22 27 33 77 7a :2 33 87 8a
:2 33 8e 91 :2 33 9d a0 :2 33 a8
ab :2 33 b7 ba c1 ca cd :2 ba
:2 33 :2 1c 6d :2 19 :2 16 :4 22 :2 16 13
:3 10 16 1f 2e :2 16 31 33 :2 31
3a 43 50 :2 3a 55 53 :2 5e :2 53
1c 25 32 :2 1c 37 35 :2 40 :2 35
:2 3a 39 :2 16 19 22 2f :2 19 34
32 :2 3d :2 32 52 1c 29 :2 52 2e
2c :2 37 :2 2c :3 19 24 2a 33 3f
:2 2a 42 44 4d 58 :2 44 :2 2a :2 24
19 1d 26 2f :2 1d 32 34 3d
48 :2 34 :2 1d 1c 4e 4c 57 63
:2 4e :2 4c 1c 27 30 39 :2 27 3c
3e :2 27 1c 66 :2 19 4b :3 16 27
:2 16 24 16 55 :2 13 :4 10 14 1d
26 :2 14 29 2b :2 29 31 3c 3e
:2 3c :2 14 13 46 16 23 :2 46 28
26 :2 31 :2 26 46 16 23 :2 46 28
26 :2 31 :2 26 :2 46 45 :3 13 21 34
42 51 5a 6a :2 21 13 46 :3 10
1e 10 1a 2a 3a 23 34 19
1c 29 3a 3d 47 17 1a 23
34 19 1c 29 3a 3d 51 54
18 20 27 40 48 4f 52 67
6f 76 90 98 9f a2 :2 13 :2 1c
28 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 63 66 67
:2 63 :2 35 :3 19 :2 1f 24 30 74 77
:2 30 84 87 :2 30 8b 8e :2 30 9a
9d :2 30 a5 a8 :2 30 b4 b7 be
c7 ca :2 b7 :2 30 :2 19 6a :2 16 :2 13
:4 1f :2 13 10 :3 d 13 1c 28 :2 13
2b 2d :2 2b 13 1b 13 16 :2 20
32 :2 3c 48 4b 5f 62 63 :2 5f
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
:2 16 66 :3 13 1a :2 23 13 2f :3 10
1e 31 3f 4a 58 67 24 34
3f 4b 57 24 2d 3a :2 24 3e
:2 1e 10 13 1c 28 :2 13 2b 2e
:2 2b 13 1b 13 16 :2 20 32 :2 3c
48 4b 5f 62 63 :2 5f :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d :2 16 66
:3 13 1a 23 2f :2 1a 13 30 :2 10
:4 d a 2b 11 1a 26 :2 11 2c
29 35 44 :2 2c :2 29 10 4d 56
60 :2 4d 63 65 :2 63 4c :2 10 d
1d d 10 19 25 :2 10 2a 28
33 3d :2 2a :2 28 10 18 10 13
:2 1d 2f :2 39 45 48 5c 5f 60
:2 5c :2 2f :3 13 :2 19 1e 2a 6e 71
:2 2a :2 13 63 :3 10 17 :2 20 10 d
40 13 1c 28 :2 13 2d 2b 36
40 :2 2d :2 2b 10 20 10 43 40
:3 d 1b d 17 27 15 24 26
36 47 4b 56 16 19 23 14
17 2b 2d 14 16 2b 2d 14
16 20 29 :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 60 63 64 :2 60 :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d 81 84
:2 2d 88 8b :2 2d 97 9a :2 2d a2
a5 :2 2d b1 b4 bb c4 c7 :2 b4
:2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10 d
:3 68 10 19 25 :2 10 28 2a :2 28
10 18 10 13 :2 1d 2f :2 39 45
48 5c 5f 60 :2 5c :2 2f :3 13 :2 19
1e 2a 6e 71 :2 2a :2 13 63 :3 10
17 :2 20 10 2c :3 d 1b d 17
27 37 20 31 34 39 53 13
17 24 27 36 3a 48 4b 16
19 26 37 3a 44 11 19 20
23 46 4a :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 60 63 64 :2 60 :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d 81 84
:2 2d 88 8b :2 2d 97 9a :2 2d a2
a5 :2 2d b1 b4 bb c4 c7 :2 b4
:2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10 d
:3 68 10 19 25 :2 10 28 2a :2 28
10 18 10 13 :2 1d 2f :2 39 45
48 5c 5f 60 :2 5c :2 2f :3 13 :2 19
1e 2a 6e 71 :2 2a :2 13 63 :3 10
17 :2 20 10 2c :3 d 1d 26 32
:2 1d :2 d 1b 2d 3b 46 54 60
21 2f :2 60 33 3c 47 :2 33 4b
54 61 :2 4b :2 1b d 68 2b :2 a
d 16 22 :2 d 25 27 :2 25 d
1b 25 :2 1b d 29 :3 a 12 a
d :2 17 29 :2 33 3f 42 56 59
5a :2 56 :2 29 :3 d :2 13 18 24 68
6b :2 24 :2 d 5d :3 a 11 1a 26
:2 11 a 7 38 :4 e d :4 32 31
:2 d a 1b :2 a 1c a e :2 19
21 30 40 :2 e 44 46 :2 44 d
4e :2 59 10 20 2f :2 4e 33 36
:2 33 4d :3 d 15 d 10 :2 1a 2c
:2 36 42 45 59 5c 5d :2 59 :2 2c
:3 10 :2 16 1b 27 6b 6e :2 27 :2 10
60 :3 d 14 :2 1d d 39 :2 a :4 e
d 33 3c 4b :2 33 4e 51 :2 4e
:3 2f :2 d 17 29 3c 4b 5a 6a
15 16 2a :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 60 63 64 :2 60 :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d 81 84
:2 2d 88 8b :2 2d 97 9a :2 2d a2
a5 :2 2d b1 b4 bb c4 c7 :2 b4
:2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10 d
:3 53 11 :2 1a 26 23 :2 2f :2 23 :2 10
18 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 17
:2 20 10 3f :2 d 11 :2 1c 24 33
42 :2 11 46 48 :2 46 10 4f :2 5a
62 15 25 :2 4f 29 2b :2 29 4e
:3 10 18 10 13 :2 1d 2f :2 39 45
48 5c 5f 60 :2 5c :2 2f :3 13 :2 19
1e 2a 6e 71 :2 2a :2 13 63 :3 10
17 :2 20 10 d 2e 14 :2 1f 27
37 46 :2 14 4a 4c :2 4a 13 53
:2 5e 13 23 33 :2 53 37 39 :2 37
52 :2 13 10 18 10 13 :2 1d 2f
:2 39 45 48 5c 5f 60 :2 5c :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a :2 13
63 :3 10 17 :2 20 10 3c 2e :2 d
53 :2 a 14 24 2f 3c 46 51
5e 12 1d 2a 39 4a 5c 69
12 13 20 31 3e :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5d 60 61 :2 5d
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 94 97
:2 2a 9f a2 :2 2a ae b1 b8 c1
c4 :2 b1 :2 2a :2 13 64 :2 10 :2 d :4 19
:2 d a :3 52 e 15 10 1d :2 15
21 :2 2a :2 e d 43 41 :2 4c :2 41
d 15 d 10 :2 1a 2c :2 36 42
45 59 5c 5d :2 59 :2 2c :3 10 :2 16
1b 27 6b 6e :2 27 :2 10 60 :3 d
14 :2 1d d 61 :2 a d 14 20
23 :2 d 26 28 :2 26 d 20 d
2c d 20 d :5 a 17 :2 a 17
a e :2 19 21 30 3e :2 e 42
45 :2 42 d 4c :2 57 5f 12 21
:2 4c 25 28 :2 25 4b :2 d 2f 38
43 :2 2f 49 46 52 5b :2 49 :2 46
2e :2 d 10 :2 1b 23 32 40 :2 10
44 47 :2 44 13 1c 2b :2 13 2e
30 :2 2e 36 :2 41 49 58 18 :2 36
1c 1e :2 1c :3 13 1b 13 16 :2 20
32 :2 3c 48 4b 5f 62 63 :2 5f
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
:2 16 66 :3 13 1a :2 23 13 20 :2 10
13 1c 29 :2 13 2e 2c :2 37 :2 2c
4c 16 23 :2 4c 28 26 :2 31 :2 26
:3 13 1e 13 1d 23 32 1b 1c
29 1a 2b 33 3a 57 5f 66
:2 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :3 45 17 :2 22
2a 39 4a :2 17 4e 50 :2 4e 16
57 :2 62 6a 1b 2d :2 57 31 33
:2 31 56 :3 16 27 :2 16 24 37 45
54 5d 6c :2 24 16 36 :3 13 26
31 40 4e 5d 21 2f 3a 45
4b 51 5d 21 2d 38 49 55
21 34 40 4c 55 5f :2 4c 21
2a 39 :2 21 :2 26 :2 13 21 2b :2 21
:2 13 1b 13 16 :2 20 32 :2 3c 48
4b 5f 62 63 :2 5f :2 32 :3 16 :2 1c
21 2d 71 74 :2 2d :2 16 66 :3 13
1a 23 2f :2 1a 13 45 13 23
:2 13 1e :2 13 20 13 :4 10 d 49
13 :2 1e 26 36 45 :2 13 49 4c
:2 49 1a 25 32 3a 41 5a 65
6a :2 18 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 63 66 67 :2 63 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 84 87 :2 30
8b 8e :2 30 9a 9d :2 30 a5 a8
:2 30 b4 b7 be c7 ca :2 b7 :2 30
:2 19 6a :2 16 :2 13 :4 1f :2 13 10 :3 4e
10 1d :2 28 2f 3f :2 1d 10 14
1d 29 :2 14 2c 2e :2 2c 13 :4 37
36 35 :3 13 21 36 44 4f 59
6a 26 38 44 :2 21 13 56 :2 10
13 1a 26 29 :2 13 2c 2e :2 2c
13 22 13 :4 17 16 20 2b 38
40 47 62 6d 72 :2 1e :2 19 :2 22
2e 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 69 6c 6d
:2 69 :2 3b :3 1f :2 25 2a 36 7a 7d
:2 36 8a 8d :2 36 91 94 :2 36 a0
a3 :2 36 ab ae :2 36 ba bd c4
cd d0 :2 bd :2 36 :2 1f 70 :2 1c :2 19
:4 25 :2 19 16 :3 35 16 1e 25 33
36 :2 1e 16 35 :2 13 32 13 22
13 :5 10 1f 28 32 :2 1f 35 37
40 4f :2 37 :2 1f :2 10 1e 2b 39
44 4f 59 65 6b 1e 2c 3c
49 54 1e 2a 33 40 :2 2a 44
47 52 :2 1e 10 13 1c 28 :2 13
2b 2d :2 2b 16 :2 21 29 3b 4b
:2 16 4f 51 :2 4f 20 35 3a 43
4b 5b 6b 19 34 41 4e 5d
1f 33 19 20 1c 28 :3 26 1c
:2 25 31 1c 2d 1c :2 25 31 1c
:4 19 16 1e 1c :2 25 31 1c 2c
:2 19 :2 1e 1c :2 25 31 1c 1f :2 29
3b :2 45 51 55 69 6c 6d :2 69
:2 3b :3 1f :2 25 2a 36 7a 7d :2 36
8a 8d :2 36 91 94 :2 36 a0 a3
:2 36 ab ae :2 36 ba bd c4 cd
d0 :2 bd :2 36 :2 1f 70 :2 1c :2 19 :4 25
:2 19 16 :3 53 13 53 19 22 2f
:2 19 32 34 :2 32 3a :2 45 4d 5f
1b :2 3a 1f 21 :2 1f :2 19 20 35
3a 43 4a 60 75 8a 1f 33
19 20 1c 28 :3 26 1c :2 25 31
1c 2d 1c :2 25 31 1c :4 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 69 6c 6d :2 69 :2 3b :3 1f
:2 25 2a 36 7a 7d :2 36 8a 8d
:2 36 91 94 :2 36 a0 a3 :2 36 ab
ae :2 36 ba bd c4 cd d0 :2 bd
:2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19 16
:4 23 53 :2 13 2f :3 10 1e 2f 3d
48 53 :2 1e :2 10 1e 28 :2 1e :2 10
:2 19 25 :2 10 18 10 13 :2 1d 2f
:2 39 45 48 5c 5f 60 :2 5c :2 2f
:3 13 :2 19 1e 2a 6e 71 :2 2a :2 13
63 :3 10 17 :2 20 10 d 4e 49
13 1c 25 :2 13 2a 28 33 3e
:2 2a :2 28 10 1b 24 2f :2 1b 32
34 3d 46 :2 34 :2 1b 10 13 1c
29 :2 13 2e 2c :2 37 :2 2c 4c 16
23 :2 4c 28 26 :2 31 :2 26 :2 13 17
1e 2a 2d :2 17 30 32 :2 30 :2 16
1e 16 37 16 1e 16 :5 13 21
2a 30 3f 48 :2 21 13 1a :2 25
2d 33 44 :2 1a 48 4b :2 48 :3 16
55 :2 60 68 1b 2d :2 55 31 34
:2 31 :3 51 :3 16 28 :2 16 2b :2 34 :2 16
25 38 46 51 :2 25 :2 16 :2 1f 2b
:2 16 2b :2 34 :2 16 25 35 43 52
62 :2 25 :2 16 :2 1f 2b :2 16 22 :2 2b
32 3b 45 :2 32 49 :2 52 :2 22 16
36 16 28 16 :4 13 :4 17 16 19
:2 23 35 :2 3f 4b 4e 62 66 67
:2 62 :2 35 :3 19 :2 1f 24 30 75 78
:2 30 :2 19 6a :3 16 1d :2 26 16 2f
:3 13 26 31 40 4e 5e 21 2f
3a 45 4b 51 5d 21 2d 38
49 55 21 34 40 4c 55 5f
:2 4c 21 2a 39 :2 21 :2 26 :2 13 21
2b :2 21 :2 13 1b 13 16 :2 20 32
:2 3c 48 4b 5f 63 64 :2 5f :2 32
:3 16 :2 1c 21 2d 72 75 :2 2d :2 16
67 :3 13 1a 23 2f :2 1a 13 45
13 20 13 :4 10 d 41 49 13
1c 27 :2 13 2a 2c :2 2a 10 1b
:2 10 1d 10 1a 28 18 19 26
:2 13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 63
67 68 :2 63 :2 35 :3 19 :2 1f 24 30
75 78 :2 30 85 88 :2 30 8c 8f
:2 30 9b 9e :2 30 a6 a9 :2 30 b5
b8 bf c8 cb :2 b8 :2 30 :2 19 6b
:2 16 :2 13 :4 1f :2 13 10 :3 2e d 2e
49 13 1c 25 :2 13 2a 28 33
3e :2 2a :2 28 10 1b 24 2d :2 1b
30 32 3b 46 :2 32 :2 1b :2 10 1f
:2 10 18 10 13 1c 2d :2 13 30
32 :2 30 13 1b 1a 1d :2 1b 35
38 :2 1b 45 48 :2 1b 1f 22 :2 1b
2f 32 :2 1b 1a 1d :2 1b 46 49
51 5a 63 :2 51 :2 49 :2 1b :2 13 18
:2 26 13 34 13 1b 1a 1d :2 1b
35 38 :2 1b 41 44 :2 1b 6a 6d
:2 1b 1f 22 :2 1b 1a 1d :2 1b 46
49 51 5a 63 :2 51 :2 49 :2 1b :2 13
18 :2 26 13 :5 10 16 1f 30 :2 16
33 35 :2 33 1c 2b :2 16 19 23
:2 19 :2 22 2e 19 29 19 :2 22 2e
19 :4 16 37 1c 2b :2 16 19 23
:2 19 :2 22 2e 19 29 19 :2 22 2e
19 :4 16 :4 13 17 :2 20 2c 29 :2 35
:2 29 :3 16 45 :2 13 10 14 41 13
1c 2d :2 13 30 32 :2 30 16 1c
:3 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
6a 6b :2 66 :2 38 :3 1c :2 22 27 33
78 7b :2 33 88 8b :2 33 8f 92
:2 33 9e a1 :2 33 a9 ac :2 33 b8
bb c2 cb ce :2 bb :2 33 :2 1c 6e
:2 19 :2 16 :4 22 :2 16 13 :4 34 16 1c
:3 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
6a 6b :2 66 :2 38 :3 1c :2 22 27 33
78 7b :2 33 88 8b :2 33 8f 92
:2 33 9e a1 :2 33 a9 ac :2 33 b8
bb c2 cb ce :2 bb :2 33 :2 1c 6e
:2 19 :2 16 :4 22 :2 16 13 :7 10 :4 14 13
16 1f 30 :2 16 33 35 :2 33 16
1e 16 19 :2 23 35 :2 3f 4b 4e
62 66 67 :2 62 :2 35 :3 19 :2 1f 24
30 75 78 :2 30 :2 19 6a :3 16 1d
:2 26 16 37 16 1e 16 19 :2 23
35 :2 3f 4b 4e 62 66 67 :2 62
:2 35 :3 19 :2 1f 24 30 75 78 :2 30
:2 19 6a :3 16 1d :2 26 16 :4 13 29
:2 10 1a 25 32 3a 41 57 62
67 :2 18 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 63 67 68 :2 63 :2 35 :3 19 :2 1f
24 30 75 78 :2 30 85 88 :2 30
8c 8f :2 30 9b 9e :2 30 a6 a9
:2 30 b5 b8 bf c8 cb :2 b8 :2 30
:2 19 6b :2 16 :2 13 :4 1f :2 13 10 :3 41
10 1b :2 10 1d 10 41 49 :2 d
a 5f 10 19 24 :2 10 2a 27
33 44 :2 2a :2 27 10 19 25 :2 10
28 2a :2 28 30 39 44 :2 30 49
47 52 5e :2 49 :2 47 :3 10 18 10
13 :2 1d 2f :2 39 45 48 5c 60
61 :2 5c :2 2f :3 13 :2 19 1e 2a 6f
72 :2 2a :2 13 64 :3 10 17 :2 20 10
61 :2 d 10 19 28 :2 10 2d 2b
36 40 :2 2d :2 2b 10 18 10 13
:2 1d 2f :2 39 45 48 5c 60 61
:2 5c :2 2f :3 13 :2 19 1e 2a 6f 72
:2 2a :2 13 64 :3 10 17 :2 20 10 43
:2 d 10 19 24 :2 10 27 29 :2 27
10 23 10 2b 14 1d 28 :2 14
2b 2d :2 2b 13 34 3d 48 :2 34
4b 4d :2 4b 33 :3 13 1b 13 16
:2 20 32 :2 3c 48 4b 5f 63 64
:2 5f :2 32 :3 16 :2 1c 21 2d 72 75
:2 2d :2 16 67 :3 13 1a :2 23 13 58
:3 10 23 2c 37 :2 23 10 :4 d 10
19 26 :2 10 2b 29 :2 34 :2 29 49
13 20 :2 49 25 23 :2 2e :2 23 :2 10
14 1d 29 :2 14 2c 2e :2 2c 13
:4 37 36 35 :2 13 1d 28 35 3d
44 5f 6a 6f :2 1b :2 16 :2 1f 2b
16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 6a 6b :2 66
:2 38 :3 1c :2 22 27 33 78 7b :2 33
88 8b :2 33 8f 92 :2 33 9e a1
:2 33 a9 ac :2 33 b8 bb c2 cb
ce :2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22
:2 16 13 :4 56 :3 10 1d 25 2e 3f
:2 25 42 44 4d 58 :2 44 :2 25 24
5c 5e :2 24 23 68 6a :2 23 :2 1d
:2 10 1e 2a 38 49 54 62 1d
28 33 :2 1e :2 10 1e :2 27 2e 37
48 :2 2e 4c :2 55 :2 1e :2 10 1e 2e
3c 47 53 56 59 :2 1e :2 10 1e
2f 3d 48 53 :2 1e :2 10 1e 28
:2 1e :2 10 18 10 13 :2 1d 2f :2 39
45 48 5c 60 61 :2 5c :2 2f :3 13
:2 19 1e 2a 6f 72 :2 2a :2 13 64
:3 10 17 20 2c :2 17 10 42 10
1d 25 2e 39 :2 25 3c 3e 47
58 :2 3e :2 25 24 5c 5e :2 24 23
68 6a :2 23 :2 1d 10 13 1c 27
:2 13 2c 2a 35 3f :2 2c :2 2a 13
21 13 1d 2b 1b 1c 29 3a
4e :2 16 :2 1f 2b 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 6a 6b :2 66 :2 38 :3 1c :2 22 27
33 78 7b :2 33 88 8b :2 33 8f
92 :2 33 9e a1 :2 33 a9 ac :2 33
b8 bb c2 cb ce :2 bb :2 33 :2 1c
6e :2 19 :2 16 :4 22 :2 16 13 :3 42 16
1f 2b :2 16 2e 30 :2 2e 19 :2 23
35 :2 3f 4b 4e 62 66 67 :2 62
:2 35 :3 19 :2 1f 24 30 75 78 :2 30
:2 19 6a :3 16 1d 16 32 :2 13 42
:3 10 1b :2 10 1d 10 13 1c 27
:2 13 2a 2c :2 2a 13 20 13 2f
:3 10 21 :2 2a 31 :2 3a 41 :2 4a 58
:2 61 :2 31 72 :2 7b :2 21 10 1a 2f
3d 49 13 21 2d 3c 13 21
2a 31 3d 19 2d 13 1a 16
22 :3 20 16 :2 1f 2b 16 27 16
:2 1f 2b 16 :4 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 63
67 68 :2 63 :2 35 :3 19 :2 1f 24 30
75 78 :2 30 85 88 :2 30 8c 8f
:2 30 9b 9e :2 30 a6 a9 :2 30 b5
b8 bf c8 cb :2 b8 :2 30 :2 19 6b
:2 16 :2 13 :4 1f :2 13 10 :3 d 13 1c
27 :2 13 2a 2d :2 2a 13 20 13
2f :2 10 :4 d 47 5f :2 a d 17
19 :2 17 11 1a 26 :2 11 29 2b
:2 29 10 :4 34 33 32 :3 10 1e 33
41 4c 56 67 26 38 44 :2 1e
10 53 :2 d :4 11 :2 10 23 33 41
4c :2 23 10 2e 13 1a 26 29
:2 13 2c 2e :2 2c 13 26 36 44
4f :2 26 13 32 13 26 36 44
4f :2 26 13 :4 10 :4 d :4 11 10 13
1c 27 :2 13 2a 2c :2 2a 13 21
:2 2a 31 3a 45 :2 31 49 :2 52 :2 21
20 13 1d 28 35 3d 44 5f
6a 6f :2 1b :2 16 :2 1f 2b 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 6a 6b :2 66 :2 38 :3 1c
:2 22 27 33 78 7b :2 33 88 8b
:2 33 8f 92 :2 33 9e a1 :2 33 a9
ac :2 33 b8 bb c2 cb ce :2 bb
:2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16 13
:4 2e 1d 28 35 3d 44 5f 6a
6f :2 1b :2 16 :2 1f 2b 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 6a 6b :2 66 :2 38 :3 1c :2 22
27 33 78 7b :2 33 88 8b :2 33
8f 92 :2 33 9e a1 :2 33 a9 ac
:2 33 b8 bb c2 cb ce :2 bb :2 33
:2 1c 6e :2 19 :2 16 :4 22 :2 16 13 :8 10
1c 25 2f :2 1c 32 34 3d 4c
:2 34 :2 1c 10 2f :3 d 1f :2 d 20
2e 39 47 51 61 24 30 39
42 :2 30 46 4f 60 :2 46 :2 20 d
10 19 2a :2 10 2d 30 :2 2d 10
18 10 13 :2 1d 2f :2 39 45 48
5c 60 61 :2 5c :2 2f :3 13 :2 19 1e
2a 6f 72 :2 2a :2 13 64 :3 10 17
:2 20 10 d 32 13 1d 1f :2 1d
13 1a 2b 2e :2 13 31 33 :2 31
1a 1b 1c 30 13 1d 32 40
4e 57 5e 6b 74 81 8a 16
25 2e 3a 4a 5a 63 70 16
2a 1c 30 16 1d 19 25 :3 23
19 :2 22 2e 19 2a 19 :2 22 2e
19 :4 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 6a 6b
:2 66 :2 38 :3 1c :2 22 27 33 78 7b
:2 33 88 8b :2 33 8f 92 :2 33 9e
a1 :2 33 a9 ac :2 33 b8 bb c2
cb ce :2 bb :2 33 :2 1c 6e :2 19 :2 16
:4 22 :2 16 13 :4 37 1d 32 40 4e
57 5e 6b 74 81 8a 1c 30
16 1d 19 25 :3 23 19 :2 22 2e
19 2a 19 :2 22 2e 19 :4 16 13
1b 19 :2 22 2e 19 29 :2 16 :2 1b
19 :2 22 2e 19 1c :2 26 38 :2 42
4e 52 66 6a 6b :2 66 :2 38 :3 1c
:2 22 27 33 78 7b :2 33 88 8b
:2 33 8f 92 :2 33 9e a1 :2 33 a9
ac :2 33 b8 bb c2 cb ce :2 bb
:2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16 13
:7 10 17 20 31 :2 17 34 37 :2 34
:4 13 2a 13 1d 20 37 1b 30
34 45 1c 1f 33 4b 4e 1a
1d 2a 3b 3e 48 1a 1d 2b
2e 3d 40 58 5b :2 16 :2 1f 2b
16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 6a 6b :2 66
:2 38 :3 1c :2 22 27 33 78 7b :2 33
88 8b :2 33 8f 92 :2 33 9e a1
:2 33 a9 ac :2 33 b8 bb c2 cb
ce :2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22
:2 16 13 :3 39 :4 17 16 20 29 37
49 1e 1f 33 :2 19 :2 22 2e 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 69 6d 6e :2 69 :2 3b
:3 1f :2 25 2a 36 7b 7e :2 36 8b
8e :2 36 92 95 :2 36 a1 a4 :2 36
ac af :2 36 bb be c5 ce d1
:2 be :2 36 :2 1f 71 :2 1c :2 19 :4 25 :2 19
16 :3 38 20 19 24 19 25 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 69 6d 6e :2 69 :2 3b
:3 1f :2 25 2a 36 7b 7e :2 36 8b
8e :2 36 92 95 :2 36 a1 a4 :2 36
ac af :2 36 bb be c5 ce d1
:2 be :2 36 :2 1f 71 :2 1c :2 19 :4 25 :2 19
16 :4 38 :2 13 39 :2 10 21 32 :3 d
1b 25 :2 1b :2 d 15 d 10 :2 1a
2c :2 36 42 45 59 5d 5e :2 59
:2 2c :3 10 :2 16 1b 27 6c 6f :2 27
:2 10 61 :3 d 14 1d 29 :2 14 d
1b :2 a d 16 22 :2 d 28 25
31 40 :2 28 :2 25 d 1b d 17
27 15 24 34 16 2a 14 29
14 1e 27 :2 10 :2 19 25 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 60 64 65 :2 60 :2 32 :3 16
:2 1c 21 2d 72 75 :2 2d 82 85
:2 2d 89 8c :2 2d 98 9b :2 2d a3
a6 :2 2d b2 b5 bc c5 c8 :2 b5
:2 2d :2 16 68 :2 13 :2 10 :4 1c :2 10 d
:3 43 10 19 25 :2 10 28 2a :2 28
10 18 10 13 :2 1d 2f :2 39 45
48 5c 60 61 :2 5c :2 2f :3 13 :2 19
1e 2a 6f 72 :2 2a :2 13 64 :3 10
17 :2 20 10 2c :3 d 1d 26 32
:2 1d :2 d 1f 28 32 :2 1f d 10
19 27 :2 10 2c 2a 35 3f :2 2c
:2 2a 13 1c 29 :2 13 2e 2c :2 37
:2 2c 4e 16 23 :2 4e 28 26 :2 31
:2 26 :3 13 22 13 1d 23 2e 32
1b 24 1b 1c 29 1a 2e 1a
:2 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
6a 6b :2 66 :2 38 :3 1c :2 22 27 33
78 7b :2 33 88 8b :2 33 8f 92
:2 33 9e a1 :2 33 a9 ac :2 33 b8
bb c2 cb ce :2 bb :2 33 :2 1c 6e
:2 19 :2 16 :4 22 :2 16 13 :3 43 :4 17 :2 16
26 16 30 :2 13 16 1f 28 :2 16
2b 2d :2 2b 1a 23 2f :2 1a 32
34 :2 32 19 :4 3d 3c 3b :2 19 23
2f 3f 21 22 2f 40 54 62
6d 75 7c :2 1c :2 25 31 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6c 70 71 :2 6c :2 3e :3 22
:2 28 2d 39 7e 81 :2 39 8e 91
:2 39 95 98 :2 39 a4 a7 :2 39 af
b2 :2 39 be c1 c8 d1 d4 :2 c1
:2 39 :2 22 74 :2 1f :2 1c :4 28 :2 1c 19
:3 5c 19 25 2e 3c :2 25 3f 41
4a 59 :2 41 :2 25 5c 5e 67 72
:2 5e :2 25 19 5c 19 25 2e 3c
:2 25 3f 41 4a 59 :2 41 :2 25 19
:5 16 28 :2 16 23 2a 33 3d :2 33
48 :2 2a 4b 4d 56 60 :2 56 6a
:2 4d :2 2a 29 6e 70 :2 29 :2 23 :2 16
24 2d 38 :2 24 3b 3d 46 4f
:2 3d :2 24 16 19 22 2e :2 19 34
31 3d 47 :2 34 :2 31 19 2b 34
3f :2 2b 42 44 4d 57 :2 44 :2 2b
5a 5c 65 71 :2 5c :2 2b 19 4a
19 2b 34 3f :2 2b 19 :5 16 24
30 3e 4f 5a 68 1e 2e 39
:2 24 :2 16 29 30 39 43 :2 39 4f
:2 30 52 54 5d 67 :2 5d 73 :2 54
:2 30 2f 24 26 :2 2f :2 29 :2 16 24
:2 2d 34 3d 4e :2 34 52 :2 5b :2 24
:2 16 24 34 42 4d 59 62 6d
:2 59 71 1f 30 :2 71 34 :2 24 :2 16
24 35 43 4e 59 :2 24 16 2f
:2 13 43 13 25 :2 13 21 2a 34
:2 21 :2 13 26 3a 48 53 5d 2a
3c 48 52 2a 3a 49 59 2a
37 43 50 2a 39 47 2a 3d
49 55 2a 33 3e :2 2a 42 4b
58 :2 42 :2 26 :2 13 24 2d 37 :2 24
:2 13 1f 28 36 :2 1f 39 3b 44
53 :2 3b :2 1f 13 20 28 2f 4f
65 :2 16 :2 1f 2b 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 6a 6b :2 66 :2 38 :3 1c :2 22 27
33 78 7b :2 33 88 8b :2 33 8f
92 :2 33 9e a1 :2 33 a9 ac :2 33
b8 bb c2 cb ce :2 bb :2 33 :2 1c
6e :2 19 :2 16 :4 22 :2 16 13 :3 10 20
2b 38 40 47 5f 6a 8b 9d
:2 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
6a 6b :2 66 :2 38 :3 1c :2 22 27 33
78 7b :2 33 88 8b :2 33 8f 92
:2 33 9e a1 :2 33 a9 ac :2 33 b8
bb c2 cb ce :2 bb :2 33 :2 1c 6e
:2 19 :2 16 :4 22 :2 16 13 :3 10 1d 32
40 4e 57 5e 6a 73 16 23
31 3f 4d 56 16 2d 45 1c
30 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 6a 6b :2 66 :2 38
:3 1c :2 22 27 33 78 7b :2 33 88
8b :2 33 8f 92 :2 33 9e a1 :2 33
a9 ac :2 33 b8 bb c2 cb ce
:2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16
13 :3 10 17 :2 20 2b 29 :2 34 :2 29
:2 16 28 :2 16 24 32 3d 4b 55
65 70 1f 22 2b 3c :2 22 :2 24
16 19 22 2e :2 19 31 34 :2 31
19 21 19 1c :2 26 38 :2 42 4e
51 65 69 6a :2 65 :2 38 :3 1c :2 22
27 33 78 7b :2 33 :2 1c 6d :3 19
20 29 35 :2 20 19 36 :2 16 44
:2 13 :5 10 1c 25 33 :2 1c :2 10 1e
10 42 10 22 2a 33 3d :2 33
4c :2 2a 4f 51 5a 64 :2 5a 6f
:2 51 :2 2a 29 24 26 :2 29 28 30
32 :2 28 :2 22 10 :5 d 1b 2f 3d
48 52 5d 25 31 3b 49 25
34 44 50 25 31 3e 4c 25
33 42 55 25 31 3d 46 51
:2 3d 55 23 30 :2 55 :2 1b :2 d 15
d 10 :2 1a 2c :2 36 42 45 59
5d 5e :2 59 :2 2c :3 10 :2 16 1b 27
6c 6f :2 27 :2 10 61 :3 d 14 1d
29 :2 14 d a 43 10 19 2b
:2 10 31 2e 3a 4a :2 31 :2 2e 11
1a 29 :2 11 2c 2e :2 2c 10 36
3f 51 :2 36 54 56 :2 54 35 :3 10
18 10 13 :2 1d 2f :2 39 45 48
5c 60 61 :2 5c :2 2f :3 13 :2 19 1e
2a 6f 72 :2 2a :2 13 64 :3 10 17
:2 20 10 59 :2 d 17 2c 40 10
1e 27 2e 3a 43 16 2a 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 60 64 65 :2 60 :2 32 :3 16 :2 1c
21 2d 72 75 :2 2d 82 85 :2 2d
89 8c :2 2d 98 9b :2 2d a3 a6
:2 2d b2 b5 bc c5 c8 :2 b5 :2 2d
:2 16 68 :2 13 :2 10 :4 1c :2 10 d :3 4d
17 23 31 3a 41 4d 56 16
23 34 41 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 60 64 65
:2 60 :2 32 :3 16 :2 1c 21 2d 72 75
:2 2d 82 85 :2 2d 89 8c :2 2d 98
9b :2 2d a3 a6 :2 2d b2 b5 bc
c5 c8 :2 b5 :2 2d :2 16 68 :2 13 :2 10
:4 1c :2 10 d :4 4d 43 :3 a 18 22
:2 18 :2 a 12 a d :2 17 29 :2 33
3f 42 56 5a 5b :2 56 :2 29 :3 d
:2 13 18 24 69 6c :2 24 :2 d 5e
:3 a 11 1a 26 :2 11 a 52 38
14 17 24 27 34 37 43 46
17 1a 17 1a d 10 d 10
1c 1f 12 21 30 3e :4 d 1b
12 27 30 33 47 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5d 61 62 :2 5d
:2 2f :3 13 :2 19 1e 2a 6f 72 :2 2a
7f 82 :2 2a 86 89 :2 2a 95 98
:2 2a a0 a3 :2 2a af b2 b9 c2
c5 :2 b2 :2 2a :2 13 65 :2 10 :2 d :4 19
:2 d a :3 7 12 :2 1b 26 24 :2 2f
:2 24 11 :4 d 15 d 10 :2 1a 2c
:2 36 42 45 59 5d 5e :2 59 :2 2c
:3 10 :2 16 1b 27 6c 6f :2 27 :2 10
61 :3 d 14 :2 1d d 3f :2 a d
:2 18 1f 2e :2 d 3d 3f :2 3d d
:2 16 22 :2 d 15 d 10 :2 1a 2c
:2 36 42 45 59 5d 5e :2 59 :2 2c
:3 10 :2 16 1b 27 6c 6f :2 27 :2 10
61 :3 d 14 :2 1d d 41 :2 a :4 7
35 :3 4 11 :2 4 15 :2 4 12 :2 4
14 :2 1d :2 4 :2 d 19 30 3e 49
58 :2 19 :2 4 c 4 7 :2 11 23
:2 2d 39 3c 50 54 55 :2 50 :2 23
:3 7 :2 d 12 1e 63 66 :2 1e :2 7
58 :3 4 b :2 14 4 7 :2 11 23
:2 2d 39 3c 50 54 55 :2 50 :2 23
:3 7 :2 d 12 1e 63 66 :2 1e 73
76 :2 1e 7a 7d :2 1e 87 8a :2 93
:2 1e :2 7 58 :3 4 b :2 14 4 :9 1

2b45
4
0 :2 1 :6 3 :6 4
:6 5 :6 6 :4 7 :4 8
:4 9 :4 a :6 b :6 c
2 :2 d :2 1 :6 f
:6 10 :6 11 :6 12 :7 13
:7 14 :7 15 :7 16 :7 17
:7 18 :7 19 :7 1a :7 1b
:7 1c :7 1d :7 1e :7 1f
:7 20 :5 21 :5 22 :5 23
:5 24 :5 25 :5 26 :5 27
:5 28 :5 29 :5 2a :5 2b
:5 2c :5 2d :7 2e :7 2f
:7 30 :6 31 :6 32 :6 33
:6 34 :5 35 :5 36 :6 37
:6 38 :6 39 :6 3a :6 3b
:6 3c :6 3d :6 3e :6 3f
:6 40 :7 41 :7 42 :7 43
:6 44 :6 45 :6 46 :6 47
:6 48 :6 49 :6 4a :6 4b
:6 4c :6 4d :6 4e :6 4f
:6 50 :6 51 :6 52 :6 53
:6 54 :6 55 :6 56 :6 57
:6 58 :6 59 :6 5a :6 5b
:6 5c :6 5d :6 5e :6 5f
:6 60 :6 61 :7 62 :7 63
:6 64 :7 65 :6 66 :6 67
:6 68 :6 69 :6 6a :6 6b
:6 6c :6 6d :6 6e :6 6f
:6 70 :7 71 :5 72 :5 73
:5 74 :5 75 :6 76 :2 78
0 :2 78 :8 79 7a
:2 7b :4 7c 7d 79
:5 78 :2 7f 0 :2 7f
:8 80 81 :2 82 :4 83
84 80 :5 7f :7 87
:7 8a :b 8d :11 8e 8f
:2 8e :2 8f :2 8e :2 8f
:2 8e :2 90 :2 8e :2 90
:2 8e :2 90 :2 8e :2 90
:2 8e :2 91 :2 8e :12 91
:2 8e :2 92 :2 8e :12 92
:2 8e :2 93 :2 8e :9 93
:2 8e :2 94 :2 8e :9 94
:2 8e :2 95 :2 8e :9 95
:2 8e :2 96 :2 8e :9 96
:2 8e :2 97 :2 8e :2 97
:2 8e :2 97 :2 8e :2 97
:2 8e :2 98 :2 8e :2 98
:2 8e :2 98 :2 8e :2 98
:2 8e :2 98 :4 8e :3 8d
:11 9b :b 9c :3 9b :3 a1
:3 a2 :3 a3 :3 a4 :3 a7
:8 aa :2 ab :2 ac :2 ad
:4 ae :4 af b0 b1
b2 :2 b3 :2 b4 :3 b5
aa :5 b6 a9 b8
:5 b9 :3 b8 :2 ba :5 bc
:11 bd :24 be :3 bd :2 bb
:6 ba b7 :3 8c :a c3
:6 c5 :6 c6 :8 c7 :5 c8
:8 c9 :4 ca :4 cb :5 cc
:6 cd :6 ce :5 cf :3 d0
:4 d1 :4 d2 :4 d3 :4 d4
d5 :2 d6 c5 :5 d7
c4 d9 :5 da :3 d9
:2 db :5 dd :11 de :24 df
:3 de :2 dc :6 db d8
:3 c3 :a e4 :8 e6 :a e7
:8 e8 :7 e9 :3 ea e6
:5 eb e5 ed :5 ee
:3 ed :2 ef :5 f1 :11 f2
:24 f3 :3 f2 :2 f0 :6 ef
ec :3 e4 :a f8 :3 f9
:11 fa :b fb :3 fa :5 fd
:3 f8 :2 ff :2 100 :2 ff
:3 100 :3 ff :6 100 :3 101
:11 102 :b 103 :3 102 :5 105
100 :2 ff :3 108 :3 109
:10 10a :3 10b :2 10a :4 10b
:3 10a :3 10c :11 10d :b 10e
:3 10d :5 110 10b :2 10a
:16 113 :2 114 :7 113 :3 115
:11 116 :b 117 :3 116 :5 119
114 :2 113 :11 11c :2 11d
:2 11c :4 11d :3 11c :9 11e
:11 11f :b 120 :3 11f :3 122
:3 11e :9 124 :c 125 :9 127
128 :2 129 :4 12a 127
:5 12b 126 12d :5 12e
:3 12d :2 12f :5 131 :11 132
:24 133 :3 132 :2 130 :6 12f
12c :3 125 :a 138 :8 13a
13b 13a :5 13c 139
13e :5 13f :3 13e :2 140
:5 142 :11 143 :24 144 :3 143
:2 141 :6 140 13d :6 138
:c 14a :3 14b :3 14a 125
:9 14f 150 :2 151 :4 152
14f :5 153 14e 155
:5 156 :3 155 :2 157 :5 159
:11 15a :24 15b :3 15a :2 158
:6 157 154 :3 14d :a 160
:8 162 163 162 :5 164
161 166 :5 167 :3 166
:2 168 :5 16a :11 16b :24 16c
:3 16b :2 169 :6 168 165
:6 160 :3 172 14d :3 125
:b 175 :7 177 :2 178 177
:6 179 :5 17a 179 :5 17c
17b :3 179 176 17f
:5 180 :3 17f :2 181 :5 183
:11 184 :24 185 :3 184 :2 182
:6 181 17e :4 175 :7 18b
:2 18c 18b :6 18d :5 18e
18d :5 190 18f :3 18d
18a 193 :5 194 :3 193
:2 195 :5 197 :11 198 :24 199
:3 198 :2 196 :6 195 192
:4 189 :3 175 124 :3 1a0
:3 1a1 :c 1a2 :5 1ab :4 1ad
:3 1ae :5 1af 1ae :5 1b1
1b0 :3 1ae :a 1b3 :8 1b5
1b6 1b5 :5 1b7 1b4
1b9 :5 1ba :3 1b9 :2 1bb
:5 1bd :11 1be :24 1bf :3 1be
:2 1bc :6 1bb 1b8 :6 1b3
:4 1c7 :5 1c8 1c6 1ca
:5 1cb :3 1ca :2 1cc :5 1ce
:11 1cf :24 1d0 :3 1cf :2 1cd
:6 1cc 1c9 :3 1a2 :c 1d5
:2 1d6 :2 1d5 :6 1d6 :2 1d5
:3 1d7 :f 1d8 :3 1d9 1d6
:2 1d5 1a2 :9 1dc :3 1dd
:3 1df 1e0 :4 1e1 :5 1e2
1df :5 1e3 1de 1e5
:5 1e6 :3 1e5 :2 1e7 :5 1e9
:11 1ea :24 1eb :3 1ea :2 1e8
:6 1e7 1e4 :3 1dc :9 1f0
:3 1f2 1f3 :4 1f4 :6 1f5
1f2 :5 1f6 1f1 1f8
:5 1f9 :3 1f8 :2 1fa :5 1fc
:11 1fd :24 1fe :3 1fd :2 1fb
:6 1fa 1f7 :6 1f0 :9 204
:3 205 :11 206 :b 207 :3 206
:5 209 :3 204 :3 1dc :5 215
:4 217 :3 218 :5 219 218
:5 21b 21a :3 218 :a 21e
:8 220 221 220 :5 222
21f 224 :5 225 :3 224
:2 226 :5 228 :11 229 :24 22a
:3 229 :2 227 :6 226 223
:6 21e :4 231 :5 232 230
234 :5 235 :3 234 :2 236
:5 238 :11 239 :24 23a :3 239
:2 237 :6 236 233 :3 1db
:14 23f :b 240 :5 23f :c 241
:2 242 :2 241 :6 242 :2 241
:12 243 :16 244 :b 245 :3 244
242 :2 241 :3 248 :3 249
240 :2 23f 1db :3 1a2
:12 24e :2 24f :2 24e :7 24f
:2 250 :2 24f :6 250 :5 24e
:a 251 250 :2 24e :3 254
:3 256 :2 257 :6 258 :2 259
:2 25a :7 25b :e 25c 256
:5 25d 255 25f :5 260
:3 25f :2 261 :5 263 :11 264
:24 265 :3 264 :2 262 :6 261
25e :3 19f :9 26a :3 26b
:11 26c :b 26d :3 26c :5 26f
:3 26a :7 272 :5 273 :6 274
:3 272 :9 275 :3 276 :11 277
:b 278 :3 277 :7 27a :3 275
19f :3 124 27d 11d
:1a 27d :3 27e :d 27f :3 280
:11 281 :b 282 :3 281 :5 284
286 27f :d 286 :3 287
286 :3 27f :3 28b :2 28d
28e :6 28f :3 290 :4 291
:4 292 :4 293 28d :5 294
28c 296 :5 297 :3 296
:2 298 :5 29a :11 29b :24 29c
:3 29b :2 299 :6 298 295
:3 27d :9 2a1 :3 2a2 :11 2a3
:b 2a4 :3 2a3 :5 2a6 :3 2a1
:3 2aa :3 2ac :5 2ad :8 2ae
:6 2af :6 2b0 2ac :5 2b1
2ab 2b3 :5 2b4 :3 2b3
:2 2b5 :5 2b7 :11 2b8 :24 2b9
:3 2b8 :2 2b6 :6 2b5 2b2
:3 27d :9 2be :3 2bf :11 2c0
:b 2c1 :3 2c0 :5 2c3 :3 2be
:7 2c6 :7 2c8 :2 2c9 :2 2c8
:a 2c9 :3 2c8 27d 11d
:2 11c :9 2cc :6 2cd :3 2cc
:3 2d0 :11 2d1 :b 2d2 :3 2d1
:7 2d4 2d5 e4 :c 2d5
:3 2d6 :3 2d7 :10 2d9 :3 2da
:2 2d9 :4 2da :3 2d9 :3 2db
:11 2dc :b 2dd :3 2dc :5 2df
2da :2 2d9 :13 2e1 :6 2e3
2e4 :2 2e5 2e3 :5 2e6
2e2 2e8 :5 2e9 :3 2e8
:2 2ea :5 2ec :11 2ed :24 2ee
:3 2ed :2 2eb :6 2ea 2e7
:3 2e1 :a 2f3 :3 2f4 :11 2f5
:b 2f6 :3 2f5 :5 2f8 :3 2f3
:11 2fb :2 2fc :2 2fb :4 2fc
:3 2fb :3 2fd :11 2fe :b 2ff
:3 2fe :5 301 302 2fc
:10 302 :3 303 :2 302 :4 303
:3 302 :3 304 :11 305 :b 306
:3 305 :5 308 303 2fc
:2 2fb :3 2e1 :7 30d :7 30e
30f :4 310 30d :5 311
30c 313 :5 314 :3 313
:2 315 :5 317 :11 318 :24 319
:3 318 :2 316 :6 315 312
:3 2d5 :2 31e :2 31f :2 31e
:3 31f :3 31e :6 31f :3 320
:11 321 :b 322 :3 321 :5 324
31f :2 31e :a 327 :3 328
327 :3 32a 329 :3 327
:3 32d :3 32e :11 330 :2 331
:2 330 :4 331 :3 330 :e 331
:2 330 :c 332 :e 333 334
:2 333 :4 334 :2 333 :3 335
:11 336 :b 337 :3 336 :5 339
334 :2 333 :c 33c :2 33d
:2 33c :6 33d :2 33c :3 33e
:3 340 341 :2 342 :7 343
340 :5 344 33f 346
:5 347 :3 346 :2 348 :5 34a
:11 34b :24 34c :3 34b :2 349
:6 348 345 :3 33d :11 351
:2 352 :2 351 :4 352 :3 351
:3 354 :a 355 352 :2 351
:6 358 :7 359 :5 35a :8 35b
:5 35c :3 358 :6 35e :3 35f
:11 360 :b 361 :3 360 :7 363
33d :3 365 :3 366 :3 367
364 :3 33c 369 332
:c 369 :8 36b 36c 36d
36b :5 36e 36a 370
:5 371 :3 370 :2 372 :5 374
:11 375 :24 376 :3 375 :2 373
:6 372 36f :3 369 :9 37b
:12 37d :7 37e :3 37f :3 37e
:3 37d :a 382 :3 383 :5 384
:8 386 387 388 386
:5 389 385 38b :5 38c
:3 38b :2 38d :5 38f :11 390
:24 391 :3 390 :2 38e :6 38d
38a :3 384 :8 395 :3 384
382 :3 398 397 :3 382
:f 39b :9 39d :5 39e :9 39f
:3 39d :9 3a1 :c 3a2 :7 3a4
:5 3a5 :2 3a6 3a4 :6 3a7
:5 3a8 3a7 :5 3aa 3a9
:3 3a7 3a3 3ad :5 3ae
:3 3ad :2 3af :5 3b1 :11 3b2
:24 3b3 :3 3b2 :2 3b0 :6 3af
3ac :3 3a2 3b7 3a2
:e 3b7 3b8 :2 3b7 :4 3b8
:2 3b7 :8 3ba :2 3bb 3ba
:6 3bc :5 3bd 3bc :5 3bf
3be :3 3bc 3b9 3c2
:5 3c3 :3 3c2 :2 3c4 :5 3c6
:11 3c7 :24 3c8 :3 3c7 :2 3c5
:6 3c4 3c1 :4 3b8 :3 3a2
:3 3a1 :9 3cf :6 3d1 :5 3d3
:3 3d4 :11 3d5 :b 3d6 :3 3d5
:5 3d8 3da 369 332
:d 3da :f 3db :c 3dc :2 3dd
:2 3dc :6 3dd :2 3dc :b 3de
:3 3df 3de :3 3e1 3e0
:3 3de :9 3e4 :13 3e6 :2 3e7
:2 3e6 :4 3e7 :5 3e6 :3 3e8
:5 3e9 :8 3ea :5 3eb :5 3ec
:9 3ed :5 3ee :f 3f0 3e7
:3 3f2 3f1 :3 3e6 :5 3f5
:11 3f6 :b 3f7 :3 3f6 :5 3f9
:3 3f5 :6 3fc :7 3fd :5 3fe
:8 3ff :5 400 :3 3fc :6 402
:3 403 :11 404 :b 405 :3 404
:7 407 3dd :3 409 408
:3 3dc 40b 3da 332
:9 40b :3 40c :3 40d :2 410
411 :2 412 410 :5 413
40f 415 :5 416 :3 415
:2 417 :5 419 :11 41a :24 41b
:3 41a :2 418 :6 417 414
:3 40b 41f 40b 332
:d 41f :f 420 :3 421 :3 422
:9 424 :2 425 :2 426 :2 425
:2 426 :2 425 :2 426 :2 425
:2 427 :2 425 :2 427 :2 425
:2 428 :2 425 :9 428 :3 425
:5 42a 424 :2 42c :2 42d
:2 42c :2 42d :2 42c :2 42d
:2 42c :2 42d :2 42c :2 42e
:2 42c :2 42f :2 42c :9 42f
:3 42c :5 431 42b :3 424
434 :9 435 :4 436 :3 437
:5 438 437 :5 43a 439
:3 437 435 :4 43d :3 43e
:5 43f 43e :5 441 440
:3 43e 43c :3 435 :a 445
:2 446 :3 445 434 448
41f :9 44a :4 44c :5 44d
44b 44f :5 450 :3 44f
:2 451 :5 453 :11 454 :24 455
:3 454 :2 452 :6 451 44e
:4 44a :4 45b :5 45c 45a
45e :5 45f :3 45e :2 460
:5 462 :11 463 :24 464 :3 463
:2 461 :6 460 45d :4 459
:3 44a :5 46a :9 46b :3 46c
:11 46d :b 46e :3 46d :5 470
46b :3 472 :11 473 :b 474
:3 473 :5 476 471 :3 46b
:3 46a :8 47b 47c 47d
47b :5 47e 47a 480
:5 481 :3 480 :2 482 :5 484
:11 485 :24 486 :3 485 :2 483
:6 482 47f :3 41f :3 48a
:3 48b 41f :3 332 48d
331 :d 48d :18 48e :3 48f
:11 490 :b 491 :3 490 :5 493
:3 48e :d 496 :3 497 :11 498
:b 499 :3 498 :5 49b :3 496
:9 49e :3 49f 49e :16 4a1
:3 4a2 :11 4a3 :b 4a4 :3 4a3
:5 4a6 :3 4a1 :7 4aa 4a0
:3 49e :c 4ad :2 4ae :2 4ad
:6 4ae :2 4ad :12 4af :8 4b9
4ba 4bb 4b9 :5 4bc
4b8 4be :5 4bf :3 4be
:2 4c0 :5 4c2 :11 4c3 :24 4c4
:3 4c3 :2 4c1 :6 4c0 4bd
:6 4af :1c 4ca :7 4cb :3 4cc
:3 4cb :f 4ce :b 4cf :9 4d1
:6 4d3 :3 4d4 :11 4d5 :b 4d6
:3 4d5 :7 4d8 4ae :1c 4da
:d 4db :3 4dc :2 4de 4df
:4 4e0 4de :5 4e1 4dd
4e3 :5 4e4 :3 4e3 :2 4e5
:5 4e7 :11 4e8 :24 4e9 :3 4e8
:2 4e6 :6 4e5 4e2 :3 4db
:9 4ee :11 4f7 :b 4f8 :3 4f7
:3 4fa :3 4ee :3 4db :3 4fe
:3 4ff :9 500 :3 501 :3 500
:15 506 :4 508 :4 509 :5 50a
:2 50b 508 :6 50c :5 50d
50c :5 50f 50e :3 50c
507 512 :5 513 :3 512
:2 514 :5 516 :11 517 :24 518
:3 517 :2 515 :6 514 511
:3 4d9 :9 51d :3 51e :3 51d
4d9 :3 4ad 48d 331
:2 330 :5 523 :12 524 :7 525
:3 526 :3 525 :3 524 :5 529
:8 52a 529 :a 52c :8 52d
52c :8 52f 52e :3 52c
52b :3 529 :5 533 :9 534
:10 535 :8 538 539 53a
538 :5 53b 537 53d
:5 53e :3 53d :2 53f :5 541
:11 542 :24 543 :3 542 :2 540
:6 53f 53c :4 534 :8 549
54a 54b 549 :5 54c
548 54e :5 54f :3 54e
:2 550 :5 552 :11 553 :24 554
:3 553 :2 551 :6 550 54d
:4 547 :3 534 :f 55a :3 533
:3 55d :7 55e :b 55f :3 55e
:9 561 :3 562 :11 563 :b 564
:3 563 :5 566 567 561
:5 567 :a 568 569 56a
:2 56b 569 :a 56e :8 56f
:2 570 :2 571 56e :6 572
:5 573 572 :5 575 574
:3 572 56d 578 :5 579
:3 578 :2 57a :5 57c :11 57d
:24 57e :3 57d :2 57b :6 57a
577 :4 568 :a 584 :2 585
584 :6 586 :5 587 586
:5 589 588 :3 586 583
58c :5 58d :3 58c :2 58e
:5 590 :11 591 :24 592 :3 591
:2 58f :6 58e 58b :4 582
:3 568 :c 598 :3 599 :3 59b
:4 59c :5 59d :6 59e :8 59f
59b :5 5a0 59a 5a2
:5 5a3 :3 5a2 :2 5a4 :5 5a6
:11 5a7 :24 5a8 :3 5a7 :2 5a5
:6 5a4 5a1 :3 598 :5 5ad
:4 5af 5b0 :2 5b1 5af
:5 5b2 5ae 5b4 :5 5b5
:3 5b4 :2 5b6 :5 5b8 :11 5b9
:24 5ba :3 5b9 :2 5b7 :6 5b6
5b3 :3 5ad 5bf :2 5c0
:2 5c1 :2 5c2 5bf :6 5c3
:5 5c4 5c3 :5 5c6 5c5
:3 5c3 5be 5c9 :5 5ca
:3 5c9 :2 5cb :5 5cd :11 5ce
:24 5cf :3 5ce :2 5cc :6 5cb
5c8 :6 5ad :3 598 567
:3 561 :6 5d7 :3 5d8 :11 5d9
:b 5da :3 5d9 :7 5dc :3 523
:d 5df :3 5e1 :2 5e3 5e4
:2 5e5 :2 5e6 :2 5e7 :3 5e8
5e3 :5 5e9 5e2 5eb
:5 5ec :3 5eb :2 5ed :5 5ef
:11 5f0 :24 5f1 :3 5f0 :2 5ee
:6 5ed 5ea :3 5df :9 5f6
:3 5f7 :11 5f8 :b 5f9 :3 5f8
:5 5fb :3 5f6 :7 5fe :7 600
:d 601 :c 602 :2 603 :2 602
:6 603 :2 602 :3 604 :4 606
:2 607 608 :2 609 :2 60a
60b 606 :5 60c 605
60e :5 60f :3 60e :2 610
:5 612 :11 613 :24 614 :3 613
:2 611 :6 610 60d :3 603
:5 619 :3 61a :3 619 :9 61d
:12 61e :3 620 621 :8 622
620 :5 623 61f 625
:5 626 :3 625 :2 627 :5 629
:11 62a :24 62b :3 62a :2 628
:6 627 624 :3 61e :17 630
61e :f 632 631 :3 61e
:3 634 :1d 636 :f 637 :d 638
:17 639 638 :7 63c 63b
:3 638 :7 63f :3 640 :3 63f
:16 643 :2 644 :5 643 :f 645
:b 646 :2 647 :2 646 647
:3 646 :9 649 :3 61d 603
:3 64c :7 64d :6 650 :4 651
:4 652 :4 653 :3 654 :4 655
:a 656 :3 650 :7 658 :f 659
:6 65b :5 65c 65a 65e
:5 65f :3 65e :2 660 :5 662
:11 663 :24 664 :3 663 :2 661
:6 660 65d :3 64b :a 669
:5 66a 668 66c :5 66d
:3 66c :2 66e :5 670 :11 671
:24 672 :3 671 :2 66f :6 66e
66b :3 64b :8 678 :6 679
:3 67a :2 67b 678 :6 67c
:5 67d 67c :5 67f 67e
:3 67c 677 682 :5 683
:3 682 :2 684 :5 686 :11 687
:24 688 :3 687 :2 685 :6 684
681 :3 64b :a 68d :3 68e
:8 68f :6 690 :3 68f :9 692
:3 693 :11 694 :b 695 :3 694
:7 697 :3 692 :3 68d 64b
:3 602 :7 69c :3 69d 601
:16 69f :2 6a0 :3 69f :2 6a0
:5 69f 69e :3 601 :7 6a5
:4 6a6 :4 6a7 :4 6a8 :4 6a9
:8 6aa :2 6ab :2 6aa :3 6a5
:3 6ad :11 6ae :b 6af :3 6ae
:7 6b1 6b2 5df :d 6b2
:16 6b3 :3 6b4 :11 6b5 :b 6b6
:3 6b5 :5 6b8 :3 6b3 :3 6bc
:6 6bd :2 6be 6bc :6 6bf
:5 6c0 6bf :5 6c2 6c1
:3 6bf 6bb 6c5 :5 6c6
:3 6c5 :2 6c7 :5 6c9 :11 6ca
:24 6cb :3 6ca :2 6c8 :6 6c7
6c4 :3 6b2 :7 6d0 :4 6d1
6d0 :6 6d2 :5 6d3 6d2
:5 6d5 6d4 :3 6d2 6cf
6d8 :5 6d9 :3 6d8 :2 6da
:5 6dc :11 6dd :24 6de :3 6dd
:2 6db :6 6da 6d7 :4 6b2
:3 5df :6 6e4 :3 6e5 :11 6e6
:b 6e7 :3 6e6 :7 6e9 2d5
e4 :8 6ec :2 6ed :2 6ee
:2 6ef :4 6f0 :4 6f1 6f2
6f3 6f4 :2 6f5 :5 6f6
6ec :5 6f7 6eb 6f9
:5 6fa :3 6f9 :2 6fb :5 6fd
:11 6fe :24 6ff :3 6fe :2 6fc
:6 6fb 6f8 :3 6ea :d 705
:3 706 :11 707 :b 708 :3 707
:5 70a :3 705 :b 70d :5 70e
:3 70f :11 710 :b 711 :3 710
:5 713 :3 70d 6ea :3 e4
:3 c3 :3 718 :3 719 :3 71a
:5 71c :b 71d :3 71f :11 720
:b 721 :3 720 :5 723 :11 725
:19 726 :3 725 :5 728 :2 8c
:7 1 
96fa
4
:3 0 1 :3 0 2
:a 0 2b40 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 6b 0 7
4 :3 0 5 :3 0
6 :3 0 7 :5 0
1 d c :3 0
4 :3 0 5 :3 0
9 :3 0 8 :5 0
1 13 12 :3 0
d 98 0 b
4 :3 0 5 :3 0
9 :3 0 a :5 0
1 19 18 :3 0
c :3 0 b :7 0
1d 1c :3 0 11
be 0 f c
:3 0 d :7 0 21
20 :3 0 c :3 0
e :7 0 25 24
:3 0 15 eb 0
13 c :3 0 f
:7 0 29 28 :3 0
4 :3 0 5 :3 0
6 :3 0 10 :5 0
1 2f 2e :3 0
22 117 0 17
4 :3 0 5 :3 0
6 :3 0 11 :5 0
1 35 34 :3 0
12 :3 0 c :3 0
37 39 0 2b40
2 3a :2 0 26
153 0 24 c
:3 0 3d :7 0 b
:3 0 41 3e 3f
2b3e 0 13 :6 0
c :3 0 43 :7 0
d :3 0 47 44
45 2b3e 0 14
:6 0 18 :2 0 28
c :3 0 49 :7 0
e :3 0 4d 4a
4b 2b3e 0 15
:6 0 c :3 0 4f
:7 0 f :3 0 53
50 51 2b3e 0
16 :6 0 18 :2 0
2c 6 :3 0 2a
55 57 :6 0 5a
58 0 2b3e 0
17 :6 0 18 :2 0
30 6 :3 0 2e
5c 5e :6 0 61
5f 0 2b3e 0
19 :6 0 1c :2 0
34 6 :3 0 32
63 65 :6 0 68
66 0 2b3e 0
1a :6 0 1c :2 0
38 6 :3 0 36
6a 6c :6 0 6f
6d 0 2b3e 0
1b :6 0 18 :2 0
3c 6 :3 0 3a
71 73 :6 0 76
74 0 2b3e 0
1d :6 0 1c :2 0
40 6 :3 0 3e
78 7a :6 0 7d
7b 0 2b3e 0
1e :6 0 18 :2 0
44 6 :3 0 42
7f 81 :6 0 84
82 0 2b3e 0
1f :6 0 18 :2 0
48 6 :3 0 46
86 88 :6 0 8b
89 0 2b3e 0
20 :6 0 18 :2 0
4c 6 :3 0 4a
8d 8f :6 0 92
90 0 2b3e 0
21 :6 0 18 :2 0
50 6 :3 0 4e
94 96 :6 0 99
97 0 2b3e 0
22 :6 0 18 :2 0
54 6 :3 0 52
9b 9d :6 0 a0
9e 0 2b3e 0
23 :6 0 18 :2 0
58 6 :3 0 56
a2 a4 :6 0 a7
a5 0 2b3e 0
24 :6 0 18 :2 0
5c 6 :3 0 5a
a9 ab :6 0 ae
ac 0 2b3e 0
25 :6 0 62 325
0 60 6 :3 0
5e b0 b2 :6 0
b5 b3 0 2b3e
0 26 :6 0 66
359 0 64 9
:3 0 b7 :7 0 ba
b8 0 2b3e 0
27 :6 0 9 :3 0
bc :7 0 bf bd
0 2b3e 0 28
:6 0 6a 38d 0
68 9 :3 0 c1
:7 0 c4 c2 0
2b3e 0 29 :6 0
9 :3 0 c6 :7 0
c9 c7 0 2b3e
0 2a :6 0 6e
3c1 0 6c 9
:3 0 cb :7 0 ce
cc 0 2b3e 0
2b :6 0 9 :3 0
d0 :7 0 d3 d1
0 2b3e 0 2c
:6 0 72 3f5 0
70 9 :3 0 d5
:7 0 d8 d6 0
2b3e 0 2d :6 0
9 :3 0 da :7 0
dd db 0 2b3e
0 2e :6 0 76
429 0 74 9
:3 0 df :7 0 e2
e0 0 2b3e 0
2f :6 0 9 :3 0
e4 :7 0 e7 e5
0 2b3e 0 30
:6 0 7a 45d 0
78 32 :3 0 e9
:7 0 ec ea 0
2b3e 0 31 :6 0
32 :3 0 ee :7 0
f1 ef 0 2b3e
0 33 :6 0 36
:2 0 7e 32 :3 0
f3 :7 0 f6 f4
0 2b3e 0 34
:6 0 6 :3 0 36
:2 0 7c f8 fa
:6 0 fd fb 0
2b3e 0 35 :6 0
36 :2 0 82 6
:3 0 80 ff 101
:6 0 104 102 0
2b3e 0 37 :6 0
3a :2 0 86 6
:3 0 84 106 108
:6 0 10b 109 0
2b3e 0 38 :6 0
3a :2 0 88 c
:3 0 10d :7 0 111
10e 10f 2b3e 0
39 :6 0 3a :2 0
8a c :3 0 113
:7 0 117 114 115
2b3e 0 3b :6 0
3a :2 0 8c c
:3 0 119 :7 0 11d
11a 11b 2b3e 0
3c :6 0 90 53f
0 8e c :3 0
11f :7 0 123 120
121 2b3e 0 3d
:6 0 3a :2 0 92
32 :3 0 125 :7 0
128 126 0 2b3e
0 3e :6 0 32
:3 0 12a :7 0 12d
12b 0 2b3e 0
3f :6 0 3a :2 0
94 c :3 0 12f
:7 0 133 130 131
2b3e 0 40 :6 0
3a :2 0 96 c
:3 0 135 :7 0 139
136 137 2b3e 0
41 :6 0 3a :2 0
98 c :3 0 13b
:7 0 13f 13c 13d
2b3e 0 42 :6 0
3a :2 0 9a c
:3 0 141 :7 0 145
142 143 2b3e 0
43 :6 0 3a :2 0
9c c :3 0 147
:7 0 14b 148 149
2b3e 0 44 :6 0
3a :2 0 9e c
:3 0 14d :7 0 151
14e 14f 2b3e 0
45 :6 0 3a :2 0
a0 c :3 0 153
:7 0 157 154 155
2b3e 0 46 :6 0
3a :2 0 a2 c
:3 0 159 :7 0 15d
15a 15b 2b3e 0
47 :6 0 3a :2 0
a4 c :3 0 15f
:7 0 163 160 161
2b3e 0 48 :6 0
18 :2 0 a6 c
:3 0 165 :7 0 169
166 167 2b3e 0
49 :6 0 18 :2 0
aa 6 :3 0 a8
16b 16d :6 0 170
16e 0 2b3e 0
4a :6 0 18 :2 0
ae 6 :3 0 ac
172 174 :6 0 177
175 0 2b3e 0
4b :6 0 3a :2 0
b2 6 :3 0 b0
179 17b :6 0 17e
17c 0 2b3e 0
4c :6 0 3a :2 0
b4 c :3 0 180
:7 0 184 181 182
2b3e 0 4d :6 0
3a :2 0 b6 c
:3 0 186 :7 0 18a
187 188 2b3e 0
4e :6 0 3a :2 0
b8 c :3 0 18c
:7 0 190 18d 18e
2b3e 0 4f :6 0
3a :2 0 ba c
:3 0 192 :7 0 196
193 194 2b3e 0
50 :6 0 3a :2 0
bc c :3 0 198
:7 0 19c 199 19a
2b3e 0 51 :6 0
3a :2 0 be c
:3 0 19e :7 0 1a2
19f 1a0 2b3e 0
52 :6 0 3a :2 0
c0 c :3 0 1a4
:7 0 1a8 1a5 1a6
2b3e 0 53 :6 0
3a :2 0 c2 c
:3 0 1aa :7 0 1ae
1ab 1ac 2b3e 0
54 :6 0 3a :2 0
c4 c :3 0 1b0
:7 0 1b4 1b1 1b2
2b3e 0 55 :6 0
3a :2 0 c6 c
:3 0 1b6 :7 0 1ba
1b7 1b8 2b3e 0
56 :6 0 3a :2 0
c8 c :3 0 1bc
:7 0 1c0 1bd 1be
2b3e 0 57 :6 0
3a :2 0 ca c
:3 0 1c2 :7 0 1c6
1c3 1c4 2b3e 0
58 :6 0 3a :2 0
cc c :3 0 1c8
:7 0 1cc 1c9 1ca
2b3e 0 59 :6 0
3a :2 0 ce c
:3 0 1ce :7 0 1d2
1cf 1d0 2b3e 0
5a :6 0 3a :2 0
d0 c :3 0 1d4
:7 0 1d8 1d5 1d6
2b3e 0 5b :6 0
3a :2 0 d2 c
:3 0 1da :7 0 1de
1db 1dc 2b3e 0
5c :6 0 3a :2 0
d4 c :3 0 1e0
:7 0 1e4 1e1 1e2
2b3e 0 5d :6 0
3a :2 0 d6 c
:3 0 1e6 :7 0 1ea
1e7 1e8 2b3e 0
5e :6 0 3a :2 0
d8 c :3 0 1ec
:7 0 1f0 1ed 1ee
2b3e 0 5f :6 0
3a :2 0 da c
:3 0 1f2 :7 0 1f6
1f3 1f4 2b3e 0
60 :6 0 3a :2 0
dc c :3 0 1f8
:7 0 1fc 1f9 1fa
2b3e 0 61 :6 0
3a :2 0 de c
:3 0 1fe :7 0 202
1ff 200 2b3e 0
62 :6 0 3a :2 0
e0 c :3 0 204
:7 0 208 205 206
2b3e 0 63 :6 0
3a :2 0 e2 c
:3 0 20a :7 0 20e
20b 20c 2b3e 0
64 :6 0 3a :2 0
e4 c :3 0 210
:7 0 214 211 212
2b3e 0 65 :6 0
3a :2 0 e6 c
:3 0 216 :7 0 21a
217 218 2b3e 0
66 :6 0 3a :2 0
e8 c :3 0 21c
:7 0 220 21d 21e
2b3e 0 67 :6 0
3a :2 0 ea c
:3 0 222 :7 0 226
223 224 2b3e 0
68 :6 0 3a :2 0
ec c :3 0 228
:7 0 22c 229 22a
2b3e 0 69 :6 0
6c :2 0 ee c
:3 0 22e :7 0 232
22f 230 2b3e 0
6a :6 0 36 :2 0
f2 6 :3 0 f0
234 236 :6 0 239
237 0 2b3e 0
6b :6 0 3a :2 0
f6 6 :3 0 f4
23b 23d :6 0 240
23e 0 2b3e 0
6d :6 0 18 :2 0
f8 c :3 0 242
:7 0 246 243 244
2b3e 0 6e :6 0
3a :2 0 fc 6
:3 0 fa 248 24a
:6 0 24d 24b 0
2b3e 0 6f :6 0
3a :2 0 fe c
:3 0 24f :7 0 253
250 251 2b3e 0
70 :6 0 3a :2 0
100 c :3 0 255
:7 0 259 256 257
2b3e 0 71 :6 0
3a :2 0 102 c
:3 0 25b :7 0 25f
25c 25d 2b3e 0
72 :6 0 3a :2 0
104 74 :3 0 261
:7 0 265 262 263
2b3e 0 73 :6 0
3a :2 0 106 74
:3 0 267 :7 0 26b
268 269 2b3e 0
75 :6 0 3a :2 0
108 74 :3 0 26d
:7 0 271 26e 26f
2b3e 0 76 :6 0
3a :2 0 10a 74
:3 0 273 :7 0 277
274 275 2b3e 0
77 :6 0 3a :2 0
10c 74 :3 0 279
:7 0 27d 27a 27b
2b3e 0 78 :6 0
3a :2 0 10e 74
:3 0 27f :7 0 283
280 281 2b3e 0
79 :6 0 3a :2 0
110 74 :3 0 285
:7 0 289 286 287
2b3e 0 7a :6 0
7d :2 0 112 74
:3 0 28b :7 0 28f
28c 28d 2b3e 0
7b :6 0 118 bee
0 116 6 :3 0
114 291 293 :6 0
296 294 0 2b3e
0 7c :6 0 11c
c22 0 11a c
:3 0 298 :7 0 29b
299 0 2b3e 0
7e :6 0 c :3 0
29d :7 0 2a0 29e
0 2b3e 0 7f
:6 0 3a :2 0 11e
c :3 0 2a2 :7 0
2a5 2a3 0 2b3e
0 80 :6 0 82
:3 0 2a7 :7 0 2aa
2a8 0 2b3e 0
81 :9 0 120 c
:3 0 2ac 0 2
:5 0 2b0 2ad 2ae
2b3e 0 83 :6 0
84 :3 0 85 :a 0
2 2c7 :4 0 2b2
2b5 0 2b3 :3 0
86 :3 0 87 :3 0
88 :3 0 86 :3 0
89 :3 0 8a :3 0
8b :3 0 8c :3 0
8d :3 0 8e :3 0
25 :3 0 88 :3 0
8f :3 0 90 :3 0
2a :3 0 88 :4 0
91 1 :8 0 2c8
2b2 2b5 2c9 0
2b3e 122 2c9 2cb
2c8 2ca :6 0 2c7
:7 0 2c9 84 :3 0
92 :a 0 3 2e2
:5 0 2cd 2d0 0
2ce :3 0 86 :3 0
87 :3 0 88 :3 0
86 :3 0 89 :3 0
8a :3 0 93 :3 0
8c :3 0 8d :3 0
8e :3 0 25 :3 0
88 :3 0 8f :3 0
90 :3 0 2b :3 0
88 :4 0 94 1
:8 0 2e3 2cd 2d0
2e4 0 2b3e 124
2e4 2e6 2e3 2e5
:6 0 2e2 :7 0 2e4
2ef 2f0 0 126
96 :3 0 97 :2 0
4 2e8 2e9 0
2ea :7 0 2ed 2eb
0 2b3e 0 95
:6 0 2f5 2f6 0
128 96 :3 0 97
:2 0 4 2f1 :7 0
2f4 2f2 0 2b3e
0 98 :6 0 99
:3 0 9a :3 0 99
:3 0 9b :3 0 2f8
2f9 0 2 :4 0
12a 2fa 2fc 2f7
2fe 2fd :2 0 9c
:3 0 9d :3 0 300
301 0 9e :4 0
99 :3 0 9f :3 0
304 305 0 2
:4 0 12c 306 308
a0 :4 0 a1 :2 0
a2 :3 0 12e 30b
30d :3 0 a3 :4 0
a1 :2 0 a4 :4 0
131 310 312 :3 0
a1 :2 0 3 :3 0
134 314 316 :3 0
a1 :2 0 a4 :4 0
137 318 31a :3 0
a1 :2 0 a5 :4 0
13a 31c 31e :3 0
a1 :2 0 a4 :4 0
13d 320 322 :3 0
a1 :2 0 7 :3 0
140 324 326 :3 0
a1 :2 0 a4 :4 0
143 328 32a :3 0
a1 :2 0 a5 :4 0
146 32c 32e :3 0
a1 :2 0 a6 :3 0
a7 :3 0 a4 :4 0
a1 :2 0 8 :3 0
149 334 336 :3 0
a1 :2 0 a4 :4 0
14c 338 33a :3 0
a8 :4 0 14f 332
33d a9 :4 0 152
331 340 155 330
342 :3 0 a1 :2 0
a5 :4 0 158 344
346 :3 0 a1 :2 0
a6 :3 0 a7 :3 0
a4 :4 0 a1 :2 0
a :3 0 15b 34c
34e :3 0 a1 :2 0
a4 :4 0 15e 350
352 :3 0 a8 :4 0
161 34a 355 a9
:4 0 164 349 358
167 348 35a :3 0
a1 :2 0 a5 :4 0
16a 35c 35e :3 0
a1 :2 0 a6 :3 0
aa :3 0 b :3 0
16d 362 364 a9
:4 0 16f 361 367
172 360 369 :3 0
a1 :2 0 a5 :4 0
175 36b 36d :3 0
a1 :2 0 a6 :3 0
aa :3 0 d :3 0
178 371 373 a9
:4 0 17a 370 376
17d 36f 378 :3 0
a1 :2 0 a5 :4 0
180 37a 37c :3 0
a1 :2 0 a6 :3 0
aa :3 0 e :3 0
183 380 382 a9
:4 0 185 37f 385
188 37e 387 :3 0
a1 :2 0 a5 :4 0
18b 389 38b :3 0
a1 :2 0 a6 :3 0
aa :3 0 f :3 0
18e 38f 391 a9
:4 0 190 38e 394
193 38d 396 :3 0
a1 :2 0 a5 :4 0
196 398 39a :3 0
a1 :2 0 a4 :4 0
199 39c 39e :3 0
a1 :2 0 10 :3 0
19c 3a0 3a2 :3 0
a1 :2 0 a4 :4 0
19f 3a4 3a6 :3 0
a1 :2 0 a5 :4 0
1a2 3a8 3aa :3 0
a1 :2 0 a4 :4 0
1a5 3ac 3ae :3 0
a1 :2 0 11 :3 0
1a8 3b0 3b2 :3 0
a1 :2 0 a4 :4 0
1ab 3b4 3b6 :3 0
a1 :2 0 ab :4 0
1ae 3b8 3ba :3 0
1b1 302 3bc :2 0
3be 1b6 3bf 2ff
3be 0 3c0 1b8
0 2b3c 99 :3 0
9a :3 0 3c1 3c2
0 99 :3 0 ac
:3 0 3c4 3c5 0
36 :2 0 2 :4 0
ad :2 0 ae :2 0
36 :2 0 1ba 3ca
3cc :3 0 1bd 3c6
3ce 3c3 3d0 3cf
:2 0 9c :3 0 af
:3 0 3d2 3d3 0
9e :4 0 b0 :4 0
a1 :2 0 a2 :3 0
1c1 3d7 3d9 :3 0
1c4 3d4 3db :2 0
3dd 1c7 3de 3d1
3dd 0 3df 1c9
0 2b3c 58 :3 0
3a :2 0 3e0 3e1
0 2b3c 24 :3 0
b1 :4 0 3e3 3e4
0 2b3c 4c :3 0
10 :3 0 3e6 3e7
0 2b3c 21 :3 0
7 :3 0 3e9 3ea
0 2b3c 22 :3 0
3 :3 0 3ec 3ed
0 2b3c b2 :3 0
b3 :3 0 b2 :3 0
b4 :3 0 b2 :3 0
8e :3 0 b2 :3 0
b5 :3 0 b2 :3 0
b6 :3 0 b2 :3 0
b7 :3 0 b2 :3 0
b8 :3 0 b2 :3 0
b9 :3 0 b2 :3 0
ba :3 0 20 :3 0
43 :3 0 1a :3 0
41 :3 0 44 :3 0
49 :3 0 1b :3 0
25 :3 0 48 :3 0
bb :3 0 b2 :3 0
b2 :3 0 b3 :3 0
22 :4 0 bc 1
:8 0 415 96 :3 0
bd :3 0 410 411
0 be :3 0 412
413 0 415 1cb
468 bf :3 0 96
:3 0 bd :3 0 417
418 0 be :3 0
419 41a 0 41c
1ce 41e 1d0 41d
41c :2 0 466 c0
:3 0 96 :3 0 bd
:3 0 421 422 0
be :3 0 423 424
0 45e 99 :3 0
9a :3 0 426 427
0 99 :3 0 ac
:3 0 429 42a 0
c1 :2 0 2 :4 0
c2 :2 0 ae :2 0
36 :2 0 1d2 42f
431 :3 0 1d5 42b
433 428 435 434
:2 0 9c :3 0 af
:3 0 437 438 0
9e :4 0 c3 :4 0
a1 :2 0 a2 :3 0
1d9 43c 43e :3 0
a1 :2 0 c4 :4 0
1dc 440 442 :3 0
a1 :2 0 c5 :4 0
1df 444 446 :3 0
a1 :2 0 be :3 0
1e2 448 44a :3 0
a1 :2 0 c6 :4 0
1e5 44c 44e :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 1e8 451
455 1ec 450 457
:3 0 1ef 439 459
:2 0 45b 1f2 45c
436 45b 0 45d
1f4 0 45e 1f6
461 :3 0 461 0
461 460 45e 45f
:6 0 463 4 :3 0
1f9 465 1fb 464
463 :2 0 466 1fd
:2 0 468 0 468
467 415 466 :6 0
2b3c 1 :3 0 96
:3 0 bd :3 0 46a
46b 0 96 :3 0
c9 :2 0 ca :3 0
46d 46f 0 202
46e 471 :3 0 472
:2 0 b3 :3 0 cb
:3 0 b9 :3 0 b8
:3 0 b6 :3 0 cc
:3 0 cd :3 0 ce
:3 0 cf :3 0 d0
:3 0 d1 :3 0 d2
:3 0 d3 :3 0 d4
:3 0 d3 :3 0 d4
:3 0 d5 :3 0 d6
:3 0 d7 :3 0 d8
:3 0 cc :3 0 d9
:3 0 da :3 0 db
:3 0 dc :3 0 8f
:3 0 90 :3 0 d7
:3 0 8f :3 0 90
:3 0 d8 :3 0 dd
:3 0 de :3 0 df
:3 0 e0 :3 0 e1
:3 0 e2 :3 0 e3
:3 0 e4 :3 0 e5
:3 0 e6 :3 0 e7
:3 0 e8 :3 0 e9
:3 0 b6 :3 0 ea
:3 0 20 :3 0 23
:3 0 25 :3 0 4b
:3 0 37 :3 0 35
:3 0 3f :3 0 4e
:3 0 54 :3 0 5f
:3 0 60 :3 0 5d
:3 0 50 :3 0 27
:3 0 52 :3 0 28
:3 0 29 :3 0 4d
:3 0 4f :3 0 55
:3 0 31 :3 0 33
:3 0 3b :3 0 3c
:3 0 73 :3 0 76
:3 0 75 :3 0 77
:3 0 78 :3 0 7a
:3 0 79 :3 0 7b
:3 0 51 :3 0 4a
:3 0 63 :3 0 38
:3 0 eb :3 0 ec
:3 0 22 :4 0 ed
1 :8 0 4cf 96
:3 0 bd :3 0 4ca
4cb 0 be :3 0
4cc 4cd 0 4cf
205 522 bf :3 0
96 :3 0 bd :3 0
4d1 4d2 0 be
:3 0 4d3 4d4 0
4d6 208 4d8 20a
4d7 4d6 :2 0 520
c0 :3 0 96 :3 0
bd :3 0 4db 4dc
0 be :3 0 4dd
4de 0 518 99
:3 0 9a :3 0 4e0
4e1 0 99 :3 0
ac :3 0 4e3 4e4
0 c1 :2 0 2
:4 0 ee :2 0 ae
:2 0 36 :2 0 20c
4e9 4eb :3 0 20f
4e5 4ed 4e2 4ef
4ee :2 0 9c :3 0
af :3 0 4f1 4f2
0 9e :4 0 ef
:4 0 a1 :2 0 a2
:3 0 213 4f6 4f8
:3 0 a1 :2 0 c4
:4 0 216 4fa 4fc
:3 0 a1 :2 0 c5
:4 0 219 4fe 500
:3 0 a1 :2 0 be
:3 0 21c 502 504
:3 0 a1 :2 0 c6
:4 0 21f 506 508
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 222
50b 50f 226 50a
511 :3 0 229 4f3
513 :2 0 515 22c
516 4f0 515 0
517 22e 0 518
230 51b :3 0 51b
0 51b 51a 518
519 :6 0 51d 6
:3 0 233 51f 235
51e 51d :2 0 520
237 :2 0 522 0
522 521 4cf 520
:6 0 2ac7 1 :3 0
96 :3 0 bd :3 0
524 525 0 96
:3 0 c9 :2 0 ca
:3 0 527 529 0
23c 528 52b :3 0
52c :2 0 b9 :3 0
f0 :3 0 f1 :3 0
f2 :3 0 f3 :3 0
f4 :3 0 f5 :3 0
f6 :3 0 f7 :3 0
f8 :3 0 d6 :3 0
f9 :3 0 fa :3 0
fb :3 0 fc :3 0
a6 :3 0 fd :3 0
fe :3 0 25 :3 0
58 :3 0 59 :3 0
28 :3 0 29 :3 0
5c :3 0 68 :3 0
6a :3 0 5b :3 0
5a :3 0 52 :3 0
4d :3 0 51 :3 0
62 :3 0 2c :3 0
ff :3 0 8e :3 0
22 :4 0 100 1
:8 0 558 96 :3 0
bd :3 0 553 554
0 be :3 0 555
556 0 558 23f
5ab bf :3 0 96
:3 0 bd :3 0 55a
55b 0 be :3 0
55c 55d 0 55f
242 561 244 560
55f :2 0 5a9 c0
:3 0 96 :3 0 bd
:3 0 564 565 0
be :3 0 566 567
0 5a1 99 :3 0
9a :3 0 569 56a
0 99 :3 0 ac
:3 0 56c 56d 0
c1 :2 0 2 :4 0
101 :2 0 ae :2 0
36 :2 0 246 572
574 :3 0 249 56e
576 56b 578 577
:2 0 9c :3 0 af
:3 0 57a 57b 0
9e :4 0 102 :4 0
a1 :2 0 a2 :3 0
24d 57f 581 :3 0
a1 :2 0 c4 :4 0
250 583 585 :3 0
a1 :2 0 c5 :4 0
253 587 589 :3 0
a1 :2 0 be :3 0
256 58b 58d :3 0
a1 :2 0 c6 :4 0
259 58f 591 :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 25c 594
598 260 593 59a
:3 0 263 57c 59c
:2 0 59e 266 59f
579 59e 0 5a0
268 0 5a1 26a
5a4 :3 0 5a4 0
5a4 5a3 5a1 5a2
:6 0 5a6 8 :3 0
26d 5a8 26f 5a7
5a6 :2 0 5a9 271
:2 0 5ab 0 5ab
5aa 558 5a9 :6 0
10ee 1 :3 0 96
:3 0 bd :3 0 5ad
5ae 0 96 :3 0
c9 :2 0 ca :3 0
5b0 5b2 0 276
5b1 5b4 :3 0 5b5
:2 0 11 :3 0 22
:3 0 5b7 5b8 0
5de 99 :3 0 9a
:3 0 5ba 5bb 0
99 :3 0 ac :3 0
5bd 5be 0 36
:2 0 2 :4 0 103
:2 0 ae :2 0 36
:2 0 279 5c3 5c5
:3 0 27c 5bf 5c7
5bc 5c9 5c8 :2 0
9c :3 0 af :3 0
5cb 5cc 0 9e
:4 0 104 :4 0 a1
:2 0 a2 :3 0 280
5d0 5d2 :3 0 283
5cd 5d4 :2 0 5d6
286 5d7 5ca 5d6
0 5d8 288 0
5de 12 :3 0 105
:3 0 106 :3 0 5da
5db 0 5dc :2 0
5de 28a 5df 5b6
5de 0 5e0 28e
0 10ee 107 :3 0
a6 :3 0 6a :3 0
3a :2 0 290 5e2
5e5 105 :3 0 108
:3 0 5e7 5e8 0
293 5e1 5ea 5eb
:2 0 105 :3 0 c9
:2 0 108 :3 0 5ed
5ef 0 298 5ee
5f1 :3 0 11 :3 0
22 :3 0 5f3 5f4
0 61a 99 :3 0
9a :3 0 5f6 5f7
0 99 :3 0 ac
:3 0 5f9 5fa 0
36 :2 0 2 :4 0
109 :2 0 ae :2 0
36 :2 0 29b 5ff
601 :3 0 29e 5fb
603 5f8 605 604
:2 0 9c :3 0 af
:3 0 607 608 0
9e :4 0 10a :4 0
a1 :2 0 a2 :3 0
2a2 60c 60e :3 0
2a5 609 610 :2 0
612 2a8 613 606
612 0 614 2aa
0 61a 12 :3 0
105 :3 0 10b :3 0
616 617 0 618
:2 0 61a 2ac 61b
5f2 61a 0 61c
2b0 0 10ee 2a
:3 0 8 :3 0 61d
61e 0 10ee 2b
:3 0 a :3 0 620
621 0 10ee 86
:3 0 10c :3 0 623
624 0 2a :3 0
2b :3 0 10d :2 0
2b2 625 629 10e
:2 0 3a :2 0 2b8
62b 62d :3 0 62e
:2 0 86 :3 0 10c
:3 0 630 631 0
2b :3 0 29 :3 0
10d :2 0 2bb 632
636 10f :2 0 3a
:2 0 2c1 638 63a
:3 0 63b :2 0 62f
63d 63c :2 0 11
:3 0 22 :3 0 63f
640 0 666 99
:3 0 9a :3 0 642
643 0 99 :3 0
ac :3 0 645 646
0 36 :2 0 2
:4 0 110 :2 0 ae
:2 0 36 :2 0 2c4
64b 64d :3 0 2c7
647 64f 644 651
650 :2 0 9c :3 0
af :3 0 653 654
0 9e :4 0 111
:4 0 a1 :2 0 a2
:3 0 2cb 658 65a
:3 0 2ce 655 65c
:2 0 65e 2d1 65f
652 65e 0 660
2d3 0 666 12
:3 0 105 :3 0 112
:3 0 662 663 0
664 :2 0 666 2d5
667 63e 666 0
668 2d9 0 10ee
2c :3 0 113 :2 0
2db 66a 66b :3 0
66c :2 0 66d :2 0
a6 :3 0 4d :3 0
3a :2 0 2dd 66f
672 114 :2 0 a6
:3 0 52 :3 0 3a
:2 0 2e0 675 678
2e3 674 67a :3 0
67b :2 0 a6 :3 0
10f :2 0 62 :3 0
3a :2 0 2e6 67d
681 2eb 67e 683
:3 0 684 :2 0 66e
686 685 :2 0 11
:3 0 22 :3 0 688
689 0 6af 99
:3 0 9a :3 0 68b
68c 0 99 :3 0
ac :3 0 68e 68f
0 36 :2 0 2
:4 0 115 :2 0 ae
:2 0 36 :2 0 2ee
694 696 :3 0 2f1
690 698 68d 69a
699 :2 0 9c :3 0
af :3 0 69c 69d
0 9e :4 0 116
:4 0 a1 :2 0 a2
:3 0 2f5 6a1 6a3
:3 0 2f8 69e 6a5
:2 0 6a7 2fb 6a8
69b 6a7 0 6a9
2fd 0 6af 12
:3 0 105 :3 0 117
:3 0 6ab 6ac 0
6ad :2 0 6af 2ff
6b0 687 6af 0
6b1 303 0 10ee
86 :3 0 10c :3 0
6b2 6b3 0 2a
:3 0 28 :3 0 10d
:2 0 305 6b4 6b8
10f :2 0 3a :2 0
30b 6ba 6bc :3 0
6bd :2 0 86 :3 0
10c :3 0 6bf 6c0
0 2b :3 0 29
:3 0 10d :2 0 30e
6c1 6c5 10f :2 0
3a :2 0 314 6c7
6c9 :3 0 6ca :2 0
6be 6cc 6cb :2 0
a6 :3 0 52 :3 0
3a :2 0 317 6ce
6d1 10e :2 0 3a
:2 0 31c 6d3 6d5
:3 0 99 :3 0 9a
:3 0 6d7 6d8 0
99 :3 0 ac :3 0
6da 6db 0 36
:2 0 2 :4 0 118
:2 0 ae :2 0 36
:2 0 31f 6e0 6e2
:3 0 322 6dc 6e4
6d9 6e6 6e5 :2 0
9c :3 0 af :3 0
6e8 6e9 0 9e
:4 0 119 :4 0 a1
:2 0 a2 :3 0 326
6ed 6ef :3 0 329
6ea 6f1 :2 0 6f3
32c 6f4 6e7 6f3
0 6f5 32e 0
6f9 12 :3 0 3a
:2 0 6f7 :2 0 6f9
330 6fa 6d6 6f9
0 6fb 333 0
ed1 a6 :3 0 5b
:3 0 3a :2 0 335
6fc 6ff c9 :2 0
3a :2 0 33a 701
703 :3 0 86 :3 0
10c :3 0 705 706
0 2a :3 0 28
:3 0 10d :2 0 33d
707 70b 10f :2 0
3a :2 0 343 70d
70f :3 0 86 :3 0
87 :3 0 88 :3 0
86 :3 0 89 :3 0
8a :3 0 8b :3 0
8c :3 0 2a :3 0
8d :3 0 8e :3 0
25 :3 0 88 :3 0
8f :3 0 90 :3 0
2a :4 0 11a 1
:8 0 727 96 :3 0
bd :3 0 722 723
0 be :3 0 724
725 0 727 346
77a bf :3 0 96
:3 0 bd :3 0 729
72a 0 be :3 0
72b 72c 0 72e
349 730 34b 72f
72e :2 0 778 c0
:3 0 96 :3 0 bd
:3 0 733 734 0
be :3 0 735 736
0 770 99 :3 0
9a :3 0 738 739
0 99 :3 0 ac
:3 0 73b 73c 0
c1 :2 0 2 :4 0
11b :2 0 ae :2 0
36 :2 0 34d 741
743 :3 0 350 73d
745 73a 747 746
:2 0 9c :3 0 af
:3 0 749 74a 0
9e :4 0 11c :4 0
a1 :2 0 a2 :3 0
354 74e 750 :3 0
a1 :2 0 c4 :4 0
357 752 754 :3 0
a1 :2 0 c5 :4 0
35a 756 758 :3 0
a1 :2 0 be :3 0
35d 75a 75c :3 0
a1 :2 0 c6 :4 0
360 75e 760 :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 363 763
767 367 762 769
:3 0 36a 74b 76b
:2 0 76d 36d 76e
748 76d 0 76f
36f 0 770 371
773 :3 0 773 0
773 772 770 771
:6 0 775 a :3 0
374 777 376 776
775 :2 0 778 378
:2 0 77a 0 77a
779 727 778 :6 0
7ff 1 :3 0 96
:3 0 bd :3 0 77c
77d 0 96 :3 0
c9 :2 0 ca :3 0
77f 781 0 37d
780 783 :3 0 784
:2 0 86 :3 0 87
:3 0 8f :3 0 90
:3 0 2a :3 0 86
:3 0 89 :3 0 2a
:3 0 11d :4 0 11e
1 :8 0 795 96
:3 0 bd :3 0 790
791 0 be :3 0
792 793 0 795
380 7e8 bf :3 0
96 :3 0 bd :3 0
797 798 0 be
:3 0 799 79a 0
79c 383 79e 385
79d 79c :2 0 7e6
c0 :3 0 96 :3 0
bd :3 0 7a1 7a2
0 be :3 0 7a3
7a4 0 7de 99
:3 0 9a :3 0 7a6
7a7 0 99 :3 0
ac :3 0 7a9 7aa
0 c1 :2 0 2
:4 0 11f :2 0 ae
:2 0 36 :2 0 387
7af 7b1 :3 0 38a
7ab 7b3 7a8 7b5
7b4 :2 0 9c :3 0
af :3 0 7b7 7b8
0 9e :4 0 120
:4 0 a1 :2 0 a2
:3 0 38e 7bc 7be
:3 0 a1 :2 0 c4
:4 0 391 7c0 7c2
:3 0 a1 :2 0 c5
:4 0 394 7c4 7c6
:3 0 a1 :2 0 be
:3 0 397 7c8 7ca
:3 0 a1 :2 0 c6
:4 0 39a 7cc 7ce
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 39d
7d1 7d5 3a1 7d0
7d7 :3 0 3a4 7b9
7d9 :2 0 7db 3a7
7dc 7b6 7db 0
7dd 3a9 0 7de
3ab 7e1 :3 0 7e1
0 7e1 7e0 7de
7df :6 0 7e3 c
:3 0 3ae 7e5 3b0
7e4 7e3 :2 0 7e6
3b2 :2 0 7e8 0
7e8 7e7 795 7e6
:6 0 7ea 1 :3 0
3b5 7eb 785 7ea
0 7ec 3b7 0
7ff 86 :3 0 10c
:3 0 7ed 7ee 0
2a :3 0 2b :3 0
10d :2 0 3b9 7ef
7f3 10e :2 0 3a
:2 0 3bf 7f5 7f7
:3 0 2b :4 0 7f9
7fa 0 7fc 3c2
7fd 7f8 7fc 0
7fe 3c4 0 7ff
3c6 8e0 86 :3 0
87 :3 0 88 :3 0
86 :3 0 89 :3 0
8a :3 0 93 :3 0
8c :3 0 2b :3 0
8d :3 0 8e :3 0
25 :3 0 88 :3 0
8f :3 0 90 :3 0
2b :4 0 121 1
:8 0 816 96 :3 0
bd :3 0 811 812
0 be :3 0 813
814 0 816 3ca
869 bf :3 0 96
:3 0 bd :3 0 818
819 0 be :3 0
81a 81b 0 81d
3cd 81f 3cf 81e
81d :2 0 867 c0
:3 0 96 :3 0 bd
:3 0 822 823 0
be :3 0 824 825
0 85f 99 :3 0
9a :3 0 827 828
0 99 :3 0 ac
:3 0 82a 82b 0
c1 :2 0 2 :4 0
122 :2 0 ae :2 0
36 :2 0 3d1 830
832 :3 0 3d4 82c
834 829 836 835
:2 0 9c :3 0 af
:3 0 838 839 0
9e :4 0 123 :4 0
a1 :2 0 a2 :3 0
3d8 83d 83f :3 0
a1 :2 0 c4 :4 0
3db 841 843 :3 0
a1 :2 0 c5 :4 0
3de 845 847 :3 0
a1 :2 0 be :3 0
3e1 849 84b :3 0
a1 :2 0 c6 :4 0
3e4 84d 84f :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 3e7 852
856 3eb 851 858
:3 0 3ee 83a 85a
:2 0 85c 3f1 85d
837 85c 0 85e
3f3 0 85f 3f5
862 :3 0 862 0
862 861 85f 860
:6 0 864 e :3 0
3f8 866 3fa 865
864 :2 0 867 3fc
:2 0 869 0 869
868 816 867 :6 0
8df 1 :3 0 96
:3 0 bd :3 0 86b
86c 0 96 :3 0
c9 :2 0 ca :3 0
86e 870 0 401
86f 872 :3 0 873
:2 0 86 :3 0 87
:3 0 8f :3 0 90
:3 0 2b :3 0 86
:3 0 89 :3 0 2b
:3 0 11d :4 0 124
1 :8 0 884 96
:3 0 bd :3 0 87f
880 0 be :3 0
881 882 0 884
404 8d7 bf :3 0
96 :3 0 bd :3 0
886 887 0 be
:3 0 888 889 0
88b 407 88d 409
88c 88b :2 0 8d5
c0 :3 0 96 :3 0
bd :3 0 890 891
0 be :3 0 892
893 0 8cd 99
:3 0 9a :3 0 895
896 0 99 :3 0
ac :3 0 898 899
0 c1 :2 0 2
:4 0 125 :2 0 ae
:2 0 36 :2 0 40b
89e 8a0 :3 0 40e
89a 8a2 897 8a4
8a3 :2 0 9c :3 0
af :3 0 8a6 8a7
0 9e :4 0 126
:4 0 a1 :2 0 a2
:3 0 412 8ab 8ad
:3 0 a1 :2 0 c4
:4 0 415 8af 8b1
:3 0 a1 :2 0 c5
:4 0 418 8b3 8b5
:3 0 a1 :2 0 be
:3 0 41b 8b7 8b9
:3 0 a1 :2 0 c6
:4 0 41e 8bb 8bd
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 421
8c0 8c4 425 8bf
8c6 :3 0 428 8a8
8c8 :2 0 8ca 42b
8cb 8a5 8ca 0
8cc 42d 0 8cd
42f 8d0 :3 0 8d0
0 8d0 8cf 8cd
8ce :6 0 8d2 10
:3 0 432 8d4 434
8d3 8d2 :2 0 8d5
436 :2 0 8d7 0
8d7 8d6 884 8d5
:6 0 8d9 1 :3 0
439 8da 874 8d9
0 8db 43b 0
8df 5c :3 0 3a
:2 0 8dc 8dd 0
8df 43d 8e1 710
7ff 0 8e2 0
8df 0 8e2 441
0 9db a6 :3 0
5a :3 0 3a :2 0
444 8e3 8e6 105
:3 0 c9 :2 0 127
:3 0 8e8 8ea 0
449 8e9 8ec :3 0
ff :3 0 128 :3 0
2a :3 0 129 :3 0
2b :3 0 12a :3 0
5c :3 0 8e :3 0
22 :4 0 12b 1
:8 0 90d 12c :4 0
8f8 :3 0 12d :3 0
c9 :2 0 44e 8fb
8fc :3 0 96 :3 0
bd :3 0 8fe 8ff
0 3a :2 0 900
901 0 903 451
90a 96 :3 0 bd
:3 0 904 905 0
12e :2 0 906 907
0 909 453 90b
8fd 903 0 90c
0 909 0 90c
455 0 90d 458
960 bf :3 0 96
:3 0 bd :3 0 90f
910 0 be :3 0
911 912 0 914
45b 916 45d 915
914 :2 0 95e c0
:3 0 96 :3 0 bd
:3 0 919 91a 0
be :3 0 91b 91c
0 956 99 :3 0
9a :3 0 91e 91f
0 99 :3 0 ac
:3 0 921 922 0
c1 :2 0 2 :4 0
12f :2 0 ae :2 0
36 :2 0 45f 927
929 :3 0 462 923
92b 920 92d 92c
:2 0 9c :3 0 af
:3 0 92f 930 0
9e :4 0 130 :4 0
a1 :2 0 a2 :3 0
466 934 936 :3 0
a1 :2 0 c4 :4 0
469 938 93a :3 0
a1 :2 0 c5 :4 0
46c 93c 93e :3 0
a1 :2 0 be :3 0
46f 940 942 :3 0
a1 :2 0 c6 :4 0
472 944 946 :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 475 949
94d 479 948 94f
:3 0 47c 931 951
:2 0 953 47f 954
92e 953 0 955
481 0 956 483
959 :3 0 959 0
959 958 956 957
:6 0 95b 12 :3 0
486 95d 488 95c
95b :2 0 95e 48a
:2 0 960 0 960
95f 90d 95e :6 0
962 1 :3 0 48d
9d8 ff :3 0 131
:3 0 2a :3 0 132
:3 0 2b :3 0 133
:3 0 5c :3 0 8e
:3 0 22 :4 0 134
1 :8 0 982 12c
:4 0 96d :3 0 12d
:3 0 c9 :2 0 491
970 971 :3 0 96
:3 0 bd :3 0 973
974 0 3a :2 0
975 976 0 978
494 97f 96 :3 0
bd :3 0 979 97a
0 12e :2 0 97b
97c 0 97e 496
980 972 978 0
981 0 97e 0
981 498 0 982
49b 9d5 bf :3 0
96 :3 0 bd :3 0
984 985 0 be
:3 0 986 987 0
989 49e 98b 4a0
98a 989 :2 0 9d3
c0 :3 0 96 :3 0
bd :3 0 98e 98f
0 be :3 0 990
991 0 9cb 99
:3 0 9a :3 0 993
994 0 99 :3 0
ac :3 0 996 997
0 c1 :2 0 2
:4 0 135 :2 0 ae
:2 0 36 :2 0 4a2
99c 99e :3 0 4a5
998 9a0 995 9a2
9a1 :2 0 9c :3 0
af :3 0 9a4 9a5
0 9e :4 0 136
:4 0 a1 :2 0 a2
:3 0 4a9 9a9 9ab
:3 0 a1 :2 0 c4
:4 0 4ac 9ad 9af
:3 0 a1 :2 0 c5
:4 0 4af 9b1 9b3
:3 0 a1 :2 0 be
:3 0 4b2 9b5 9b7
:3 0 a1 :2 0 c6
:4 0 4b5 9b9 9bb
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 4b8
9be 9c2 4bc 9bd
9c4 :3 0 4bf 9a6
9c6 :2 0 9c8 4c2
9c9 9a3 9c8 0
9ca 4c4 0 9cb
4c6 9ce :3 0 9ce
0 9ce 9cd 9cb
9cc :6 0 9d0 14
:3 0 4c9 9d2 4cb
9d1 9d0 :2 0 9d3
4cd :2 0 9d5 0
9d5 9d4 982 9d3
:6 0 9d7 1 :3 0
4d0 9d9 8ed 962
0 9da 0 9d7
0 9da 4d2 0
9db 4d5 ecd 7e
:3 0 3a :2 0 9dc
9dd 0 ecc 66
:3 0 3a :2 0 9df
9e0 0 ecc 86
:3 0 10c :3 0 9e2
9e3 0 2a :3 0
28 :3 0 10d :2 0
4d8 9e4 9e8 10f
:2 0 3a :2 0 4de
9ea 9ec :3 0 137
:3 0 85 :4 0 9f1
:2 0 b08 9ef 9f2
:3 0 85 :3 0 2a
:4 0 9f6 :2 0 b08
9f3 9f4 :3 0 85
:3 0 12c :3 0 9f7
9f8 :3 0 96 :3 0
bd :3 0 9fa 9fb
0 3a :2 0 9fc
9fd 0 9ff 4e1
a06 96 :3 0 bd
:3 0 a00 a01 0
12e :2 0 a02 a03
0 a05 4e3 a07
9f9 9ff 0 a08
0 a05 0 a08
4e5 0 b08 96
:3 0 bd :3 0 a09
a0a 0 96 :3 0
c9 :2 0 ca :3 0
a0c a0e 0 4ea
a0d a10 :3 0 a11
:2 0 86 :3 0 87
:3 0 8f :3 0 90
:3 0 2a :3 0 86
:3 0 89 :3 0 2a
:3 0 11d :4 0 11e
1 :8 0 a22 96
:3 0 bd :3 0 a1d
a1e 0 be :3 0
a1f a20 0 a22
4ed a75 bf :3 0
96 :3 0 bd :3 0
a24 a25 0 be
:3 0 a26 a27 0
a29 4f0 a2b 4f2
a2a a29 :2 0 a73
c0 :3 0 96 :3 0
bd :3 0 a2e a2f
0 be :3 0 a30
a31 0 a6b 99
:3 0 9a :3 0 a33
a34 0 99 :3 0
ac :3 0 a36 a37
0 c1 :2 0 2
:4 0 138 :2 0 ae
:2 0 36 :2 0 4f4
a3c a3e :3 0 4f7
a38 a40 a35 a42
a41 :2 0 9c :3 0
af :3 0 a44 a45
0 9e :4 0 139
:4 0 a1 :2 0 a2
:3 0 4fb a49 a4b
:3 0 a1 :2 0 c4
:4 0 4fe a4d a4f
:3 0 a1 :2 0 c5
:4 0 501 a51 a53
:3 0 a1 :2 0 be
:3 0 504 a55 a57
:3 0 a1 :2 0 c6
:4 0 507 a59 a5b
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 50a
a5e a62 50e a5d
a64 :3 0 511 a46
a66 :2 0 a68 514
a69 a43 a68 0
a6a 516 0 a6b
518 a6e :3 0 a6e
0 a6e a6d a6b
a6c :6 0 a70 16
:3 0 51b a72 51d
a71 a70 :2 0 a73
51f :2 0 a75 0
a75 a74 a22 a73
:6 0 a77 1 :3 0
522 a78 a12 a77
0 a79 524 0
b08 13a :3 0 85
:4 0 a7d :2 0 a83
a7b 0 96 :3 0
bd :3 0 a7e a7f
0 be :3 0 a80
a81 0 a83 526
ad6 bf :3 0 96
:3 0 bd :3 0 a85
a86 0 be :3 0
a87 a88 0 a8a
529 a8c 52b a8b
a8a :2 0 ad4 c0
:3 0 96 :3 0 bd
:3 0 a8f a90 0
be :3 0 a91 a92
0 acc 99 :3 0
9a :3 0 a94 a95
0 99 :3 0 ac
:3 0 a97 a98 0
c1 :2 0 2 :4 0
13b :2 0 ae :2 0
36 :2 0 52d a9d
a9f :3 0 530 a99
aa1 a96 aa3 aa2
:2 0 9c :3 0 af
:3 0 aa5 aa6 0
9e :4 0 13c :4 0
a1 :2 0 a2 :3 0
534 aaa aac :3 0
a1 :2 0 c4 :4 0
537 aae ab0 :3 0
a1 :2 0 c5 :4 0
53a ab2 ab4 :3 0
a1 :2 0 be :3 0
53d ab6 ab8 :3 0
a1 :2 0 c6 :4 0
540 aba abc :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 543 abf
ac3 547 abe ac5
:3 0 54a aa7 ac7
:2 0 ac9 54d aca
aa4 ac9 0 acb
54f 0 acc 551
acf :3 0 acf 0
acf ace acc acd
:6 0 ad1 18 :3 0
554 ad3 556 ad2
ad1 :2 0 ad4 558
:2 0 ad6 0 ad6
ad5 a83 ad4 :6 0
b08 1 :3 0 a6
:3 0 58 :3 0 3a
:2 0 55b ad8 adb
105 :3 0 c9 :2 0
13d :3 0 add adf
0 560 ade ae1
:3 0 a6 :3 0 58
:3 0 3a :2 0 563
ae3 ae6 105 :3 0
c9 :2 0 13e :3 0
ae8 aea 0 568
ae9 aec :3 0 ae2
aee aed :2 0 2b
:3 0 b1 :4 0 af0
af1 0 b05 66
:3 0 13f :3 0 140
:3 0 af4 af5 0
a6 :3 0 5c :3 0
3a :2 0 56b af7
afa 105 :3 0 141
:3 0 afc afd 0
56e af6 aff af3
b00 0 b05 7e
:3 0 36 :2 0 b02
b03 0 b05 571
b06 aef b05 0
b07 575 0 b08
577 d91 a6 :3 0
52 :3 0 3a :2 0
57e b09 b0c 10e
:2 0 3a :2 0 583
b0e b10 :3 0 72
:3 0 3a :2 0 b12
b13 0 c25 142
:3 0 72 :3 0 11d
:3 0 143 :3 0 b9
:3 0 25 :3 0 e8
:3 0 22 :3 0 144
:3 0 88 :3 0 8f
:3 0 90 :3 0 2b
:4 0 145 1 :8 0
b28 96 :3 0 bd
:3 0 b23 b24 0
be :3 0 b25 b26
0 b28 586 b7b
bf :3 0 96 :3 0
bd :3 0 b2a b2b
0 be :3 0 b2c
b2d 0 b2f 589
b31 58b b30 b2f
:2 0 b79 c0 :3 0
96 :3 0 bd :3 0
b34 b35 0 be
:3 0 b36 b37 0
b71 99 :3 0 9a
:3 0 b39 b3a 0
99 :3 0 ac :3 0
b3c b3d 0 c1
:2 0 2 :4 0 146
:2 0 ae :2 0 36
:2 0 58d b42 b44
:3 0 590 b3e b46
b3b b48 b47 :2 0
9c :3 0 af :3 0
b4a b4b 0 9e
:4 0 147 :4 0 a1
:2 0 a2 :3 0 594
b4f b51 :3 0 a1
:2 0 c4 :4 0 597
b53 b55 :3 0 a1
:2 0 c5 :4 0 59a
b57 b59 :3 0 a1
:2 0 be :3 0 59d
b5b b5d :3 0 a1
:2 0 c6 :4 0 5a0
b5f b61 :3 0 a1
:2 0 90 :3 0 c7
:3 0 36 :2 0 c8
:2 0 5a3 b64 b68
5a7 b63 b6a :3 0
5aa b4c b6c :2 0
b6e 5ad b6f b49
b6e 0 b70 5af
0 b71 5b1 b74
:3 0 b74 0 b74
b73 b71 b72 :6 0
b76 1a :3 0 5b4
b78 5b6 b77 b76
:2 0 b79 5b8 :2 0
b7b 0 b7b b7a
b28 b79 :6 0 c25
1 :3 0 a6 :3 0
72 :3 0 3a :2 0
5bb b7d b80 c9
:2 0 3a :2 0 5c0
b82 b84 :3 0 142
:3 0 72 :3 0 11d
:3 0 eb :3 0 b9
:3 0 25 :3 0 e8
:3 0 22 :3 0 8f
:3 0 90 :3 0 f2
:3 0 8f :3 0 90
:3 0 2b :4 0 148
1 :8 0 b9a 96
:3 0 bd :3 0 b95
b96 0 be :3 0
b97 b98 0 b9a
5c3 bed bf :3 0
96 :3 0 bd :3 0
b9c b9d 0 be
:3 0 b9e b9f 0
ba1 5c6 ba3 5c8
ba2 ba1 :2 0 beb
c0 :3 0 96 :3 0
bd :3 0 ba6 ba7
0 be :3 0 ba8
ba9 0 be3 99
:3 0 9a :3 0 bab
bac 0 99 :3 0
ac :3 0 bae baf
0 c1 :2 0 2
:4 0 149 :2 0 ae
:2 0 36 :2 0 5ca
bb4 bb6 :3 0 5cd
bb0 bb8 bad bba
bb9 :2 0 9c :3 0
af :3 0 bbc bbd
0 9e :4 0 14a
:4 0 a1 :2 0 a2
:3 0 5d1 bc1 bc3
:3 0 a1 :2 0 c4
:4 0 5d4 bc5 bc7
:3 0 a1 :2 0 c5
:4 0 5d7 bc9 bcb
:3 0 a1 :2 0 be
:3 0 5da bcd bcf
:3 0 a1 :2 0 c6
:4 0 5dd bd1 bd3
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 5e0
bd6 bda 5e4 bd5
bdc :3 0 5e7 bbe
bde :2 0 be0 5ea
be1 bbb be0 0
be2 5ec 0 be3
5ee be6 :3 0 be6
0 be6 be5 be3
be4 :6 0 be8 1c
:3 0 5f1 bea 5f3
be9 be8 :2 0 beb
5f5 :2 0 bed 0
bed bec b9a beb
:6 0 bef 1 :3 0
5f8 bf0 b85 bef
0 bf1 5fa 0
c25 a6 :3 0 72
:3 0 3a :2 0 5fc
bf2 bf5 10e :2 0
3a :2 0 601 bf7
bf9 :3 0 11 :3 0
22 :3 0 bfb bfc
0 c22 99 :3 0
9a :3 0 bfe bff
0 99 :3 0 ac
:3 0 c01 c02 0
36 :2 0 2 :4 0
14b :2 0 ae :2 0
36 :2 0 604 c07
c09 :3 0 607 c03
c0b c00 c0d c0c
:2 0 9c :3 0 af
:3 0 c0f c10 0
9e :4 0 14c :4 0
a1 :2 0 a2 :3 0
60b c14 c16 :3 0
60e c11 c18 :2 0
c1a 611 c1b c0e
c1a 0 c1c 613
0 c22 12 :3 0
105 :3 0 14d :3 0
c1e c1f 0 c20
:2 0 c22 615 c23
bfa c22 0 c24
619 0 c25 61b
c26 b11 c25 0
c27 620 0 d90
137 :3 0 92 :4 0
c2b :2 0 d90 c29
c2c :3 0 92 :3 0
2b :4 0 c30 :2 0
d90 c2d c2e :3 0
92 :3 0 12c :3 0
c31 c32 :3 0 96
:3 0 bd :3 0 c34
c35 0 3a :2 0
c36 c37 0 c39
622 c40 96 :3 0
bd :3 0 c3a c3b
0 12e :2 0 c3c
c3d 0 c3f 624
c41 c33 c39 0
c42 0 c3f 0
c42 626 0 d90
96 :3 0 bd :3 0
c43 c44 0 96
:3 0 c9 :2 0 ca
:3 0 c46 c48 0
62b c47 c4a :3 0
c4b :2 0 86 :3 0
87 :3 0 8f :3 0
90 :3 0 2b :3 0
86 :3 0 89 :3 0
2b :3 0 11d :4 0
124 1 :8 0 c5c
96 :3 0 bd :3 0
c57 c58 0 be
:3 0 c59 c5a 0
c5c 62e caf bf
:3 0 96 :3 0 bd
:3 0 c5e c5f 0
be :3 0 c60 c61
0 c63 631 c65
633 c64 c63 :2 0
cad c0 :3 0 96
:3 0 bd :3 0 c68
c69 0 be :3 0
c6a c6b 0 ca5
99 :3 0 9a :3 0
c6d c6e 0 99
:3 0 ac :3 0 c70
c71 0 c1 :2 0
2 :4 0 14e :2 0
ae :2 0 36 :2 0
635 c76 c78 :3 0
638 c72 c7a c6f
c7c c7b :2 0 9c
:3 0 af :3 0 c7e
c7f 0 9e :4 0
14f :4 0 a1 :2 0
a2 :3 0 63c c83
c85 :3 0 a1 :2 0
c4 :4 0 63f c87
c89 :3 0 a1 :2 0
c5 :4 0 642 c8b
c8d :3 0 a1 :2 0
be :3 0 645 c8f
c91 :3 0 a1 :2 0
c6 :4 0 648 c93
c95 :3 0 a1 :2 0
90 :3 0 c7 :3 0
36 :2 0 c8 :2 0
64b c98 c9c 64f
c97 c9e :3 0 652
c80 ca0 :2 0 ca2
655 ca3 c7d ca2
0 ca4 657 0
ca5 659 ca8 :3 0
ca8 0 ca8 ca7
ca5 ca6 :6 0 caa
1e :3 0 65c cac
65e cab caa :2 0
cad 660 :2 0 caf
0 caf cae c5c
cad :6 0 cb1 1
:3 0 663 cb2 c4c
cb1 0 cb3 665
0 d90 13a :3 0
92 :4 0 cb7 :2 0
cbd cb5 0 96
:3 0 bd :3 0 cb8
cb9 0 be :3 0
cba cbb 0 cbd
667 d10 bf :3 0
96 :3 0 bd :3 0
cbf cc0 0 be
:3 0 cc1 cc2 0
cc4 66a cc6 66c
cc5 cc4 :2 0 d0e
c0 :3 0 96 :3 0
bd :3 0 cc9 cca
0 be :3 0 ccb
ccc 0 d06 99
:3 0 9a :3 0 cce
ccf 0 99 :3 0
ac :3 0 cd1 cd2
0 c1 :2 0 2
:4 0 150 :2 0 ae
:2 0 36 :2 0 66e
cd7 cd9 :3 0 671
cd3 cdb cd0 cdd
cdc :2 0 9c :3 0
af :3 0 cdf ce0
0 9e :4 0 151
:4 0 a1 :2 0 a2
:3 0 675 ce4 ce6
:3 0 a1 :2 0 c4
:4 0 678 ce8 cea
:3 0 a1 :2 0 c5
:4 0 67b cec cee
:3 0 a1 :2 0 be
:3 0 67e cf0 cf2
:3 0 a1 :2 0 c6
:4 0 681 cf4 cf6
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 684
cf9 cfd 688 cf8
cff :3 0 68b ce1
d01 :2 0 d03 68e
d04 cde d03 0
d05 690 0 d06
692 d09 :3 0 d09
0 d09 d08 d06
d07 :6 0 d0b 20
:3 0 695 d0d 697
d0c d0b :2 0 d0e
699 :2 0 d10 0
d10 d0f cbd d0e
:6 0 d90 1 :3 0
a6 :3 0 52 :3 0
3a :2 0 69c d12
d15 c9 :2 0 3a
:2 0 6a1 d17 d19
:3 0 a6 :3 0 58
:3 0 3a :2 0 6a4
d1b d1e 105 :3 0
c9 :2 0 13d :3 0
d20 d22 0 6a9
d21 d24 :3 0 a6
:3 0 58 :3 0 3a
:2 0 6ac d26 d29
105 :3 0 c9 :2 0
13e :3 0 d2b d2d
0 6b1 d2c d2f
:3 0 d25 d31 d30
:2 0 d32 :2 0 d1a
d34 d33 :2 0 a6
:3 0 58 :3 0 3a
:2 0 6b4 d36 d39
105 :3 0 c9 :2 0
13d :3 0 d3b d3d
0 6b9 d3c d3f
:3 0 a6 :3 0 58
:3 0 3a :2 0 6bc
d41 d44 105 :3 0
c9 :2 0 13e :3 0
d46 d48 0 6c1
d47 d4a :3 0 d40
d4c d4b :2 0 66
:3 0 152 :3 0 a6
:3 0 5c :3 0 3a
:2 0 6c4 d50 d53
153 :2 0 a6 :3 0
59 :3 0 3a :2 0
6c7 d56 d59 6ca
d55 d5b :3 0 6cd
d4f d5d d4e d5e
0 d84 a6 :3 0
66 :3 0 3a :2 0
6cf d60 d63 154
:2 0 a6 :3 0 59
:3 0 3a :2 0 6d2
d66 d69 6d5 d65
d6b :3 0 d6c :2 0
a6 :3 0 155 :2 0
5c :3 0 3a :2 0
6d8 d6e d72 6dd
d6f d74 :3 0 66
:3 0 a6 :3 0 66
:3 0 3a :2 0 6e0
d77 d7a ae :2 0
36 :2 0 6e3 d7c
d7e :3 0 d76 d7f
0 d81 6e6 d82
d75 d81 0 d83
6e8 0 d84 6ea
d85 d4d d84 0
d86 6ed 0 d8d
2a :3 0 b1 :4 0
d87 d88 0 d8d
7e :3 0 36 :2 0
d8a d8b 0 d8d
6ef d8e d35 d8d
0 d8f 6f3 0
d90 6f5 d92 9ed
b08 0 d93 0
d90 0 d93 6fd
0 ecc a6 :3 0
66 :3 0 3a :2 0
700 d94 d97 10e
:2 0 3a :2 0 705
d99 d9b :3 0 7e
:3 0 c9 :2 0 36
:2 0 70a d9e da0
:3 0 d9c da2 da1
:2 0 da3 :2 0 a6
:3 0 58 :3 0 3a
:2 0 70d da5 da8
105 :3 0 c9 :2 0
13d :3 0 daa dac
0 712 dab dae
:3 0 a6 :3 0 58
:3 0 3a :2 0 715
db0 db3 105 :3 0
c9 :2 0 13e :3 0
db5 db7 0 71a
db6 db9 :3 0 daf
dbb dba :2 0 dbc
:2 0 da4 dbe dbd
:2 0 72 :3 0 156
:3 0 25 :3 0 2a
:3 0 66 :3 0 2b
:3 0 59 :3 0 71d
dc1 dc7 dc0 dc8
0 dca 723 dcb
dbf dca 0 dcc
725 0 ecc 72
:3 0 3a :2 0 dcd
dce 0 ecc 142
:3 0 72 :3 0 11d
:3 0 eb :3 0 157
:3 0 157 :3 0 b9
:3 0 25 :3 0 157
:3 0 e8 :3 0 22
:3 0 157 :3 0 cb
:3 0 eb :3 0 158
:3 0 158 :3 0 b9
:3 0 25 :3 0 158
:3 0 ec :3 0 157
:3 0 cb :3 0 8f
:3 0 90 :3 0 2a
:3 0 8f :3 0 90
:3 0 158 :3 0 f2
:3 0 8f :3 0 90
:3 0 2b :3 0 8f
:3 0 90 :3 0 158
:3 0 f3 :4 0 159
1 :8 0 dfa 96
:3 0 bd :3 0 df5
df6 0 be :3 0
df7 df8 0 dfa
727 e4d bf :3 0
96 :3 0 bd :3 0
dfc dfd 0 be
:3 0 dfe dff 0
e01 72a e03 72c
e02 e01 :2 0 e4b
c0 :3 0 96 :3 0
bd :3 0 e06 e07
0 be :3 0 e08
e09 0 e43 99
:3 0 9a :3 0 e0b
e0c 0 99 :3 0
ac :3 0 e0e e0f
0 c1 :2 0 2
:4 0 15a :2 0 ae
:2 0 36 :2 0 72e
e14 e16 :3 0 731
e10 e18 e0d e1a
e19 :2 0 9c :3 0
af :3 0 e1c e1d
0 9e :4 0 15b
:4 0 a1 :2 0 a2
:3 0 735 e21 e23
:3 0 a1 :2 0 c4
:4 0 738 e25 e27
:3 0 a1 :2 0 c5
:4 0 73b e29 e2b
:3 0 a1 :2 0 be
:3 0 73e e2d e2f
:3 0 a1 :2 0 c6
:4 0 741 e31 e33
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 744
e36 e3a 748 e35
e3c :3 0 74b e1e
e3e :2 0 e40 74e
e41 e1b e40 0
e42 750 0 e43
752 e46 :3 0 e46
0 e46 e45 e43
e44 :6 0 e48 22
:3 0 755 e4a 757
e49 e48 :2 0 e4b
759 :2 0 e4d 0
e4d e4c dfa e4b
:6 0 ecc 1 :3 0
a6 :3 0 72 :3 0
3a :2 0 75c e4f
e52 10e :2 0 3a
:2 0 761 e54 e56
:3 0 11 :3 0 22
:3 0 e58 e59 0
e7f 99 :3 0 9a
:3 0 e5b e5c 0
99 :3 0 ac :3 0
e5e e5f 0 36
:2 0 2 :4 0 15c
:2 0 ae :2 0 36
:2 0 764 e64 e66
:3 0 767 e60 e68
e5d e6a e69 :2 0
9c :3 0 af :3 0
e6c e6d 0 9e
:4 0 15d :4 0 a1
:2 0 a2 :3 0 76b
e71 e73 :3 0 76e
e6e e75 :2 0 e77
771 e78 e6b e77
0 e79 773 0
e7f 12 :3 0 105
:3 0 15e :3 0 e7b
e7c 0 e7d :2 0
e7f 775 e80 e57
e7f 0 e81 779
0 ecc 72 :3 0
15f :3 0 25 :3 0
22 :3 0 28 :3 0
29 :3 0 2a :3 0
2b :3 0 59 :3 0
68 :3 0 72 :3 0
4c :3 0 a6 :3 0
58 :3 0 3a :2 0
77b e8e e91 3a
:2 0 77e e83 e94
e82 e95 0 ecc
a6 :3 0 72 :3 0
3a :2 0 78b e97
e9a 10f :2 0 3a
:2 0 790 e9c e9e
:3 0 11 :3 0 22
:3 0 ea0 ea1 0
ec9 99 :3 0 9a
:3 0 ea3 ea4 0
99 :3 0 ac :3 0
ea6 ea7 0 36
:2 0 2 :4 0 160
:2 0 ae :2 0 36
:2 0 793 eac eae
:3 0 796 ea8 eb0
ea5 eb2 eb1 :2 0
9c :3 0 af :3 0
eb4 eb5 0 9e
:4 0 161 :4 0 a1
:2 0 a2 :3 0 79a
eb9 ebb :3 0 79d
eb6 ebd :2 0 ebf
7a0 ec0 eb3 ebf
0 ec1 7a2 0
ec9 12 :3 0 a6
:3 0 72 :3 0 3a
:2 0 7a4 ec3 ec6
ec7 :2 0 ec9 7a7
eca e9f ec9 0
ecb 7ab 0 ecc
7ad ece 704 9db
0 ecf 0 ecc
0 ecf 7b7 0
ed1 162 :3 0 7ba
10b0 a6 :3 0 16
:3 0 3a :2 0 7bd
ed2 ed5 a6 :3 0
10f :2 0 52 :3 0
3a :2 0 7c0 ed7
edb 7c5 ed8 edd
:3 0 ede :2 0 a6
:3 0 4d :3 0 3a
:2 0 7c8 ee0 ee3
10e :2 0 3a :2 0
7cd ee5 ee7 :3 0
ee8 :2 0 edf eea
ee9 :2 0 64 :3 0
3a :2 0 eec eed
0 10ae a6 :3 0
16 :3 0 3a :2 0
7d0 eef ef2 a6
:3 0 10e :2 0 4d
:3 0 3a :2 0 7d3
ef4 ef8 7d8 ef5
efa :3 0 11 :3 0
22 :3 0 efc efd
0 f24 99 :3 0
9a :3 0 eff f00
0 99 :3 0 ac
:3 0 f02 f03 0
36 :2 0 2 :4 0
163 :2 0 ae :2 0
36 :2 0 7db f08
f0a :3 0 7de f04
f0c f01 f0e f0d
:2 0 9c :3 0 af
:3 0 f10 f11 0
9e :4 0 164 :4 0
a1 :2 0 a2 :3 0
7e2 f15 f17 :3 0
7e5 f12 f19 :2 0
f1b 7e8 f1c f0f
f1b 0 f1d 7ea
0 f24 12 :3 0
105 :3 0 165 :3 0
f1f f20 0 f21
:2 0 f24 162 :3 0
7ec f37 a6 :3 0
16 :3 0 3a :2 0
7f0 f25 f28 a6
:3 0 c9 :2 0 4d
:3 0 3a :2 0 7f3
f2a f2e 7f8 f2b
f30 :3 0 64 :3 0
36 :2 0 f32 f33
0 f35 7fb f36
f31 f35 0 f38
efb f24 0 f38
7fd 0 10ae 72
:3 0 3a :2 0 f39
f3a 0 10ae 142
:3 0 72 :3 0 11d
:3 0 166 :3 0 8e
:3 0 eb :3 0 157
:3 0 167 :3 0 166
:3 0 157 :3 0 e8
:3 0 22 :3 0 157
:3 0 ec :3 0 166
:3 0 ec :3 0 166
:3 0 ec :3 0 166
:3 0 8e :3 0 166
:3 0 168 :3 0 105
:3 0 169 :4 0 16a
1 :8 0 f5a 96
:3 0 bd :3 0 f55
f56 0 be :3 0
f57 f58 0 f5a
800 fad bf :3 0
96 :3 0 bd :3 0
f5c f5d 0 be
:3 0 f5e f5f 0
f61 803 f63 805
f62 f61 :2 0 fab
c0 :3 0 96 :3 0
bd :3 0 f66 f67
0 be :3 0 f68
f69 0 fa3 99
:3 0 9a :3 0 f6b
f6c 0 99 :3 0
ac :3 0 f6e f6f
0 c1 :2 0 2
:4 0 16b :2 0 ae
:2 0 36 :2 0 807
f74 f76 :3 0 80a
f70 f78 f6d f7a
f79 :2 0 9c :3 0
af :3 0 f7c f7d
0 9e :4 0 16c
:4 0 a1 :2 0 a2
:3 0 80e f81 f83
:3 0 a1 :2 0 c4
:4 0 811 f85 f87
:3 0 a1 :2 0 c5
:4 0 814 f89 f8b
:3 0 a1 :2 0 be
:3 0 817 f8d f8f
:3 0 a1 :2 0 c6
:4 0 81a f91 f93
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 81d
f96 f9a 821 f95
f9c :3 0 824 f7e
f9e :2 0 fa0 827
fa1 f7b fa0 0
fa2 829 0 fa3
82b fa6 :3 0 fa6
0 fa6 fa5 fa3
fa4 :6 0 fa8 24
:3 0 82e faa 830
fa9 fa8 :2 0 fab
832 :2 0 fad 0
fad fac f5a fab
:6 0 10ae 1 :3 0
a6 :3 0 72 :3 0
3a :2 0 835 faf
fb2 10e :2 0 3a
:2 0 83a fb4 fb6
:3 0 11 :3 0 22
:3 0 fb8 fb9 0
fdf 99 :3 0 9a
:3 0 fbb fbc 0
99 :3 0 ac :3 0
fbe fbf 0 36
:2 0 2 :4 0 16d
:2 0 ae :2 0 36
:2 0 83d fc4 fc6
:3 0 840 fc0 fc8
fbd fca fc9 :2 0
9c :3 0 af :3 0
fcc fcd 0 9e
:4 0 16e :4 0 a1
:2 0 a2 :3 0 844
fd1 fd3 :3 0 847
fce fd5 :2 0 fd7
84a fd8 fcb fd7
0 fd9 84c 0
fdf 12 :3 0 105
:3 0 10b :3 0 fdb
fdc 0 fdd :2 0
fdf 84e fe0 fb7
fdf 0 fe1 852
0 10ae 72 :3 0
3a :2 0 fe2 fe3
0 10ae 142 :3 0
72 :3 0 11d :3 0
eb :3 0 157 :3 0
16f :3 0 170 :3 0
171 :3 0 171 :3 0
8e :3 0 157 :3 0
b9 :3 0 171 :3 0
b8 :3 0 157 :3 0
b8 :3 0 157 :3 0
b9 :3 0 25 :3 0
157 :3 0 e8 :3 0
22 :3 0 8f :3 0
90 :3 0 157 :3 0
d5 :3 0 171 :3 0
172 :4 0 173 1
:8 0 1007 96 :3 0
bd :3 0 1002 1003
0 be :3 0 1004
1005 0 1007 854
105a bf :3 0 96
:3 0 bd :3 0 1009
100a 0 be :3 0
100b 100c 0 100e
857 1010 859 100f
100e :2 0 1058 c0
:3 0 96 :3 0 bd
:3 0 1013 1014 0
be :3 0 1015 1016
0 1050 99 :3 0
9a :3 0 1018 1019
0 99 :3 0 ac
:3 0 101b 101c 0
c1 :2 0 2 :4 0
174 :2 0 ae :2 0
36 :2 0 85b 1021
1023 :3 0 85e 101d
1025 101a 1027 1026
:2 0 9c :3 0 af
:3 0 1029 102a 0
9e :4 0 175 :4 0
a1 :2 0 a2 :3 0
862 102e 1030 :3 0
a1 :2 0 c4 :4 0
865 1032 1034 :3 0
a1 :2 0 c5 :4 0
868 1036 1038 :3 0
a1 :2 0 be :3 0
86b 103a 103c :3 0
a1 :2 0 c6 :4 0
86e 103e 1040 :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 871 1043
1047 875 1042 1049
:3 0 878 102b 104b
:2 0 104d 87b 104e
1028 104d 0 104f
87d 0 1050 87f
1053 :3 0 1053 0
1053 1052 1050 1051
:6 0 1055 26 :3 0
882 1057 884 1056
1055 :2 0 1058 886
:2 0 105a 0 105a
1059 1007 1058 :6 0
10ae 1 :3 0 a6
:3 0 72 :3 0 3a
:2 0 889 105c 105f
10e :2 0 3a :2 0
88e 1061 1063 :3 0
11 :3 0 22 :3 0
1065 1066 0 108c
99 :3 0 9a :3 0
1068 1069 0 99
:3 0 ac :3 0 106b
106c 0 36 :2 0
2 :4 0 176 :2 0
ae :2 0 36 :2 0
891 1071 1073 :3 0
894 106d 1075 106a
1077 1076 :2 0 9c
:3 0 af :3 0 1079
107a 0 9e :4 0
177 :4 0 a1 :2 0
a2 :3 0 898 107e
1080 :3 0 89b 107b
1082 :2 0 1084 89e
1085 1078 1084 0
1086 8a0 0 108c
12 :3 0 105 :3 0
178 :3 0 1088 1089
0 108a :2 0 108c
8a2 108d 1064 108c
0 108e 8a6 0
10ae 53 :3 0 a6
:3 0 16 :3 0 3a
:2 0 8a8 1090 1093
108f 1094 0 10ae
72 :3 0 179 :3 0
25 :3 0 22 :3 0
53 :3 0 4c :3 0
a6 :3 0 64 :3 0
3a :2 0 8ab 109c
109f a6 :3 0 59
:3 0 3a :2 0 8ae
10a1 10a4 a6 :3 0
58 :3 0 3a :2 0
8b1 10a6 10a9 8b4
1097 10ab 1096 10ac
0 10ae 8bc 10af
eeb 10ae 0 10b1
6cd ed1 0 10b1
8c7 0 10ee a6
:3 0 72 :3 0 3a
:2 0 8ca 10b2 10b5
c9 :2 0 3a :2 0
8cf 10b7 10b9 :3 0
72 :3 0 17a :3 0
25 :3 0 8d2 10bc
10be 10bb 10bf 0
10c1 8d4 10c2 10ba
10c1 0 10c3 8d6
0 10ee 11 :3 0
22 :3 0 10c4 10c5
0 10ee 99 :3 0
9a :3 0 10c7 10c8
0 99 :3 0 ac
:3 0 10ca 10cb 0
36 :2 0 2 :4 0
17b :2 0 ae :2 0
36 :2 0 8d8 10d0
10d2 :3 0 8db 10cc
10d4 10c9 10d6 10d5
:2 0 9c :3 0 af
:3 0 10d8 10d9 0
9e :4 0 17c :4 0
a1 :2 0 a2 :3 0
8df 10dd 10df :3 0
8e2 10da 10e1 :2 0
10e3 8e5 10e4 10d7
10e3 0 10e5 8e7
0 10ee 12 :3 0
a6 :3 0 72 :3 0
3a :2 0 8e9 10e7
10ea 10eb :2 0 10ee
162 :3 0 8ec 2ac4
8 :3 0 113 :2 0
8f9 10f0 10f1 :3 0
10f2 :2 0 a :3 0
113 :2 0 8fb 10f5
10f6 :3 0 10f7 :2 0
10f3 10f9 10f8 :2 0
2a :3 0 8 :3 0
10fb 10fc 0 29d5
2b :3 0 a :3 0
10fe 10ff 0 29d5
86 :3 0 10c :3 0
1101 1102 0 2a
:3 0 2b :3 0 10d
:2 0 8fd 1103 1107
10e :2 0 3a :2 0
903 1109 110b :3 0
110c :2 0 86 :3 0
10c :3 0 110e 110f
0 2b :3 0 29
:3 0 10d :2 0 906
1110 1114 10f :2 0
3a :2 0 90c 1116
1118 :3 0 1119 :2 0
110d 111b 111a :2 0
11 :3 0 22 :3 0
111d 111e 0 1144
99 :3 0 9a :3 0
1120 1121 0 99
:3 0 ac :3 0 1123
1124 0 36 :2 0
2 :4 0 17d :2 0
ae :2 0 36 :2 0
90f 1129 112b :3 0
912 1125 112d 1122
112f 112e :2 0 9c
:3 0 af :3 0 1131
1132 0 9e :4 0
17e :4 0 a1 :2 0
a2 :3 0 916 1136
1138 :3 0 919 1133
113a :2 0 113c 91c
113d 1130 113c 0
113e 91e 0 1144
12 :3 0 105 :3 0
112 :3 0 1140 1141
0 1142 :2 0 1144
920 1145 111c 1144
0 1146 924 0
29d5 23 :3 0 113
:2 0 926 1148 1149
:3 0 114a :2 0 a6
:3 0 52 :3 0 3a
:2 0 928 114c 114f
10f :2 0 3a :2 0
92d 1151 1153 :3 0
17f :2 0 930 1155
1156 :3 0 114b 1158
1157 :2 0 d7 :3 0
d8 :3 0 d4 :3 0
2d :3 0 2e :3 0
69 :3 0 eb :3 0
ec :3 0 23 :4 0
180 1 :8 0 1169
96 :3 0 bd :3 0
1164 1165 0 be
:3 0 1166 1167 0
1169 932 11bc bf
:3 0 96 :3 0 bd
:3 0 116b 116c 0
be :3 0 116d 116e
0 1170 935 1172
937 1171 1170 :2 0
11ba c0 :3 0 96
:3 0 bd :3 0 1175
1176 0 be :3 0
1177 1178 0 11b2
99 :3 0 9a :3 0
117a 117b 0 99
:3 0 ac :3 0 117d
117e 0 c1 :2 0
2 :4 0 181 :2 0
ae :2 0 36 :2 0
939 1183 1185 :3 0
93c 117f 1187 117c
1189 1188 :2 0 9c
:3 0 af :3 0 118b
118c 0 9e :4 0
182 :4 0 a1 :2 0
a2 :3 0 940 1190
1192 :3 0 a1 :2 0
c4 :4 0 943 1194
1196 :3 0 a1 :2 0
c5 :4 0 946 1198
119a :3 0 a1 :2 0
be :3 0 949 119c
119e :3 0 a1 :2 0
c6 :4 0 94c 11a0
11a2 :3 0 a1 :2 0
90 :3 0 c7 :3 0
36 :2 0 c8 :2 0
94f 11a5 11a9 953
11a4 11ab :3 0 956
118d 11ad :2 0 11af
959 11b0 118a 11af
0 11b1 95b 0
11b2 95d 11b5 :3 0
11b5 0 11b5 11b4
11b2 11b3 :6 0 11b7
28 :3 0 960 11b9
962 11b8 11b7 :2 0
11ba 964 :2 0 11bc
0 11bc 11bb 1169
11ba :6 0 127e 1
:3 0 96 :3 0 bd
:3 0 11be 11bf 0
96 :3 0 10f :2 0
183 :3 0 11c1 11c3
0 969 11c2 11c5
:3 0 11c6 :2 0 11
:3 0 23 :3 0 11c8
11c9 0 11ef 99
:3 0 9a :3 0 11cb
11cc 0 99 :3 0
ac :3 0 11ce 11cf
0 36 :2 0 2
:4 0 184 :2 0 ae
:2 0 36 :2 0 96c
11d4 11d6 :3 0 96f
11d0 11d8 11cd 11da
11d9 :2 0 9c :3 0
af :3 0 11dc 11dd
0 9e :4 0 185
:4 0 a1 :2 0 a2
:3 0 973 11e1 11e3
:3 0 976 11de 11e5
:2 0 11e7 979 11e8
11db 11e7 0 11e9
97b 0 11ef 12
:3 0 105 :3 0 15e
:3 0 11eb 11ec 0
11ed :2 0 11ef 97d
11f0 11c7 11ef 0
11f1 981 0 127e
86 :3 0 10c :3 0
11f2 11f3 0 2a
:3 0 2d :3 0 10d
:2 0 983 11f4 11f8
155 :2 0 3a :2 0
989 11fa 11fc :3 0
11fd :2 0 86 :3 0
10c :3 0 11ff 1200
0 2a :3 0 2e
:3 0 10d :2 0 98c
1201 1205 10e :2 0
3a :2 0 992 1207
1209 :3 0 120a :2 0
11fe 120c 120b :2 0
11 :3 0 23 :3 0
120e 120f 0 1236
99 :3 0 9a :3 0
1211 1212 0 99
:3 0 ac :3 0 1214
1215 0 36 :2 0
2 :4 0 186 :2 0
ae :2 0 36 :2 0
995 121a 121c :3 0
998 1216 121e 1213
1220 121f :2 0 9c
:3 0 af :3 0 1222
1223 0 9e :4 0
187 :4 0 a1 :2 0
a2 :3 0 99c 1227
1229 :3 0 99f 1224
122b :2 0 122d 9a2
122e 1221 122d 0
122f 9a4 0 1236
12 :3 0 105 :3 0
15e :3 0 1231 1232
0 1233 :2 0 1236
162 :3 0 9a6 127c
86 :3 0 10c :3 0
1237 1238 0 2b
:3 0 2d :3 0 10d
:2 0 9aa 1239 123d
155 :2 0 3a :2 0
9b0 123f 1241 :3 0
1242 :2 0 86 :3 0
10c :3 0 1244 1245
0 2b :3 0 2e
:3 0 10d :2 0 9b3
1246 124a 10e :2 0
3a :2 0 9b9 124c
124e :3 0 124f :2 0
1243 1251 1250 :2 0
11 :3 0 23 :3 0
1253 1254 0 127a
99 :3 0 9a :3 0
1256 1257 0 99
:3 0 ac :3 0 1259
125a 0 36 :2 0
2 :4 0 188 :2 0
ae :2 0 36 :2 0
9bc 125f 1261 :3 0
9bf 125b 1263 1258
1265 1264 :2 0 9c
:3 0 af :3 0 1267
1268 0 9e :4 0
189 :4 0 a1 :2 0
a2 :3 0 9c3 126c
126e :3 0 9c6 1269
1270 :2 0 1272 9c9
1273 1266 1272 0
1274 9cb 0 127a
12 :3 0 105 :3 0
15e :3 0 1276 1277
0 1278 :2 0 127a
9cd 127b 1252 127a
0 127d 120d 1236
0 127d 9d1 0
127e 9d4 127f 1159
127e 0 1280 9d8
0 29d5 f1 :3 0
f0 :3 0 d6 :3 0
f2 :3 0 f3 :3 0
f6 :3 0 18a :3 0
59 :3 0 58 :3 0
39 :3 0 2f :3 0
30 :3 0 6a :3 0
5c :3 0 ff :3 0
b9 :3 0 25 :3 0
8e :3 0 4a :4 0
18b 1 :8 0 129a
96 :3 0 bd :3 0
1295 1296 0 be
:3 0 1297 1298 0
129a 9da 12ed bf
:3 0 96 :3 0 bd
:3 0 129c 129d 0
be :3 0 129e 129f
0 12a1 9dd 12a3
9df 12a2 12a1 :2 0
12eb c0 :3 0 96
:3 0 bd :3 0 12a6
12a7 0 be :3 0
12a8 12a9 0 12e3
99 :3 0 9a :3 0
12ab 12ac 0 99
:3 0 ac :3 0 12ae
12af 0 c1 :2 0
2 :4 0 18c :2 0
ae :2 0 36 :2 0
9e1 12b4 12b6 :3 0
9e4 12b0 12b8 12ad
12ba 12b9 :2 0 9c
:3 0 af :3 0 12bc
12bd 0 9e :4 0
18d :4 0 a1 :2 0
a2 :3 0 9e8 12c1
12c3 :3 0 a1 :2 0
c4 :4 0 9eb 12c5
12c7 :3 0 a1 :2 0
c5 :4 0 9ee 12c9
12cb :3 0 a1 :2 0
be :3 0 9f1 12cd
12cf :3 0 a1 :2 0
c6 :4 0 9f4 12d1
12d3 :3 0 a1 :2 0
90 :3 0 c7 :3 0
36 :2 0 c8 :2 0
9f7 12d6 12da 9fb
12d5 12dc :3 0 9fe
12be 12de :2 0 12e0
a01 12e1 12bb 12e0
0 12e2 a03 0
12e3 a05 12e6 :3 0
12e6 0 12e6 12e5
12e3 12e4 :6 0 12e8
2a :3 0 a08 12ea
a0a 12e9 12e8 :2 0
12eb a0c :2 0 12ed
0 12ed 12ec 129a
12eb :6 0 29d5 1
:3 0 107 :3 0 a6
:3 0 6a :3 0 3a
:2 0 a0f 12f0 12f3
105 :3 0 108 :3 0
12f5 12f6 0 a12
12ef 12f8 12f9 :2 0
105 :3 0 c9 :2 0
108 :3 0 12fb 12fd
0 a17 12fc 12ff
:3 0 11 :3 0 4a
:3 0 1301 1302 0
1328 99 :3 0 9a
:3 0 1304 1305 0
99 :3 0 ac :3 0
1307 1308 0 36
:2 0 2 :4 0 18e
:2 0 ae :2 0 36
:2 0 a1a 130d 130f
:3 0 a1d 1309 1311
1306 1313 1312 :2 0
9c :3 0 af :3 0
1315 1316 0 9e
:4 0 18f :4 0 a1
:2 0 a2 :3 0 a21
131a 131c :3 0 a24
1317 131e :2 0 1320
a27 1321 1314 1320
0 1322 a29 0
1328 12 :3 0 105
:3 0 10b :3 0 1324
1325 0 1326 :2 0
1328 a2b 1329 1300
1328 0 132a a2f
0 29d5 90 :3 0
37 :3 0 36 :2 0
36 :2 0 a31 132b
132f c9 :2 0 36
:4 0 a37 1331 1333
:3 0 44 :3 0 36
:2 0 1335 1336 0
1338 a3a 133d 44
:3 0 3a :2 0 1339
133a 0 133c a3c
133e 1334 1338 0
133f 0 133c 0
133f a3e 0 29d5
7f :3 0 3a :2 0
1340 1341 0 29d5
80 :3 0 3a :2 0
1343 1344 0 29d5
86 :3 0 10c :3 0
1346 1347 0 2a
:3 0 28 :3 0 10d
:2 0 a41 1348 134c
10f :2 0 3a :2 0
a47 134e 1350 :3 0
1351 :2 0 86 :3 0
10c :3 0 1353 1354
0 2b :3 0 29
:3 0 10d :2 0 a4a
1355 1359 10f :2 0
3a :2 0 a50 135b
135d :3 0 135e :2 0
1352 1360 135f :2 0
a6 :3 0 13 :3 0
3a :2 0 a53 1362
1365 a6 :3 0 10f
:2 0 4f :3 0 3a
:2 0 a56 1367 136b
a5b 1368 136d :3 0
136e :2 0 1361 1370
136f :2 0 86 :3 0
10c :3 0 1372 1373
0 2a :3 0 28
:3 0 10d :2 0 a5e
1374 1378 10f :2 0
3a :2 0 a64 137a
137c :3 0 a6 :3 0
39 :3 0 3a :2 0
a67 137e 1381 10e
:2 0 3a :2 0 a6c
1383 1385 :3 0 86
:3 0 10c :3 0 1387
1388 0 2a :3 0
2f :3 0 10d :2 0
a6f 1389 138d 155
:2 0 3a :2 0 a75
138f 1391 :3 0 1386
1393 1392 :2 0 11
:3 0 22 :3 0 1395
1396 0 13bc 99
:3 0 9a :3 0 1398
1399 0 99 :3 0
ac :3 0 139b 139c
0 36 :2 0 2
:4 0 190 :2 0 ae
:2 0 36 :2 0 a78
13a1 13a3 :3 0 a7b
139d 13a5 139a 13a7
13a6 :2 0 9c :3 0
af :3 0 13a9 13aa
0 9e :4 0 191
:4 0 a1 :2 0 a2
:3 0 a7f 13ae 13b0
:3 0 a82 13ab 13b2
:2 0 13b4 a85 13b5
13a8 13b4 0 13b6
a87 0 13bc 12
:3 0 105 :3 0 14d
:3 0 13b8 13b9 0
13ba :2 0 13bc a89
13bd 1394 13bc 0
13be a8d 0 14ce
a6 :3 0 58 :3 0
3a :2 0 a8f 13bf
13c2 105 :3 0 c9
:2 0 13d :3 0 13c4
13c6 0 a94 13c5
13c8 :3 0 a6 :3 0
58 :3 0 3a :2 0
a97 13ca 13cd 105
:3 0 c9 :2 0 13e
:3 0 13cf 13d1 0
a9c 13d0 13d3 :3 0
13c9 13d5 13d4 :2 0
66 :3 0 3a :2 0
13d7 13d8 0 14bf
142 :3 0 88 :3 0
66 :3 0 8d :3 0
8e :3 0 25 :3 0
88 :3 0 8f :3 0
90 :3 0 2f :3 0
8f :3 0 90 :3 0
30 :4 0 192 1
:8 0 13ed 96 :3 0
bd :3 0 13e8 13e9
0 be :3 0 13ea
13eb 0 13ed a9f
1440 bf :3 0 96
:3 0 bd :3 0 13ef
13f0 0 be :3 0
13f1 13f2 0 13f4
aa2 13f6 aa4 13f5
13f4 :2 0 143e c0
:3 0 96 :3 0 bd
:3 0 13f9 13fa 0
be :3 0 13fb 13fc
0 1436 99 :3 0
9a :3 0 13fe 13ff
0 99 :3 0 ac
:3 0 1401 1402 0
c1 :2 0 2 :4 0
193 :2 0 ae :2 0
36 :2 0 aa6 1407
1409 :3 0 aa9 1403
140b 1400 140d 140c
:2 0 9c :3 0 af
:3 0 140f 1410 0
9e :4 0 194 :4 0
a1 :2 0 a2 :3 0
aad 1414 1416 :3 0
a1 :2 0 c4 :4 0
ab0 1418 141a :3 0
a1 :2 0 c5 :4 0
ab3 141c 141e :3 0
a1 :2 0 be :3 0
ab6 1420 1422 :3 0
a1 :2 0 c6 :4 0
ab9 1424 1426 :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 abc 1429
142d ac0 1428 142f
:3 0 ac3 1411 1431
:2 0 1433 ac6 1434
140e 1433 0 1435
ac8 0 1436 aca
1439 :3 0 1439 0
1439 1438 1436 1437
:6 0 143b 2c :3 0
acd 143d acf 143c
143b :2 0 143e ad1
:2 0 1440 0 1440
143f 13ed 143e :6 0
14bf 1 :3 0 86
:3 0 10c :3 0 1442
1443 0 2a :3 0
2f :3 0 10d :2 0
ad4 1444 1448 155
:2 0 3a :2 0 ada
144a 144c :3 0 144d
:2 0 86 :3 0 10c
:3 0 144f 1450 0
2a :3 0 30 :3 0
10d :2 0 add 1451
1455 10e :2 0 3a
:2 0 ae3 1457 1459
:3 0 145a :2 0 144e
145c 145b :2 0 29
:3 0 b1 :4 0 145e
145f 0 146b 72
:3 0 156 :3 0 25
:3 0 2a :3 0 66
:3 0 29 :3 0 59
:3 0 ae6 1462 1468
1461 1469 0 146b
aec 146c 145d 146b
0 146d aef 0
14bf 71 :3 0 195
:3 0 2a :3 0 28
:3 0 29 :3 0 23
:3 0 25 :3 0 4a
:3 0 22 :3 0 31
:3 0 33 :3 0 35
:3 0 4b :3 0 37
:3 0 59 :3 0 50
:3 0 73 :3 0 75
:3 0 3c :3 0 3b
:3 0 4c :3 0 a6
:3 0 4d :3 0 3a
:2 0 af1 1483 1486
a6 :3 0 52 :3 0
3a :2 0 af4 1488
148b af7 146f 148d
146e 148e 0 14bf
72 :3 0 17a :3 0
25 :3 0 b0d 1491
1493 1490 1494 0
14bf 11 :3 0 20
:3 0 1496 1497 0
14bf 99 :3 0 9a
:3 0 1499 149a 0
99 :3 0 ac :3 0
149c 149d 0 36
:2 0 2 :4 0 196
:2 0 ae :2 0 36
:2 0 b0f 14a2 14a4
:3 0 b12 149e 14a6
149b 14a8 14a7 :2 0
9c :3 0 af :3 0
14aa 14ab 0 9e
:4 0 197 :4 0 a1
:2 0 a2 :3 0 b16
14af 14b1 :3 0 b19
14ac 14b3 :2 0 14b5
b1c 14b6 14a9 14b5
0 14b7 b1e 0
14bf 12 :3 0 a6
:3 0 72 :3 0 3a
:2 0 b20 14b9 14bc
14bd :2 0 14bf b23
14ca 28 :3 0 2a
:3 0 14c0 14c1 0
14c9 4f :3 0 3a
:2 0 14c3 14c4 0
14c9 7f :3 0 36
:2 0 14c6 14c7 0
14c9 b2c 14cb 13d6
14bf 0 14cc 0
14c9 0 14cc b30
0 14ce 162 :3 0
b33 1b99 86 :3 0
10c :3 0 14cf 14d0
0 2b :3 0 29
:3 0 10d :2 0 b36
14d1 14d5 10f :2 0
3a :2 0 b3c 14d7
14d9 :3 0 86 :3 0
87 :3 0 8f :3 0
90 :3 0 2b :3 0
86 :3 0 89 :3 0
29 :3 0 2b :3 0
11d :4 0 198 1
:8 0 14eb 96 :3 0
bd :3 0 14e6 14e7
0 be :3 0 14e8
14e9 0 14eb b3f
153e bf :3 0 96
:3 0 bd :3 0 14ed
14ee 0 be :3 0
14ef 14f0 0 14f2
b42 14f4 b44 14f3
14f2 :2 0 153c c0
:3 0 96 :3 0 bd
:3 0 14f7 14f8 0
be :3 0 14f9 14fa
0 1534 99 :3 0
9a :3 0 14fc 14fd
0 99 :3 0 ac
:3 0 14ff 1500 0
c1 :2 0 2 :4 0
199 :2 0 ae :2 0
36 :2 0 b46 1505
1507 :3 0 b49 1501
1509 14fe 150b 150a
:2 0 9c :3 0 af
:3 0 150d 150e 0
9e :4 0 19a :4 0
a1 :2 0 a2 :3 0
b4d 1512 1514 :3 0
a1 :2 0 c4 :4 0
b50 1516 1518 :3 0
a1 :2 0 c5 :4 0
b53 151a 151c :3 0
a1 :2 0 be :3 0
b56 151e 1520 :3 0
a1 :2 0 c6 :4 0
b59 1522 1524 :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 b5c 1527
152b b60 1526 152d
:3 0 b63 150f 152f
:2 0 1531 b66 1532
150c 1531 0 1533
b68 0 1534 b6a
1537 :3 0 1537 0
1537 1536 1534 1535
:6 0 1539 2e :3 0
b6d 153b b6f 153a
1539 :2 0 153c b71
:2 0 153e 0 153e
153d 14eb 153c :6 0
177d 1 :3 0 80
:3 0 86 :3 0 19b
:3 0 1541 1542 0
2b :3 0 29 :3 0
b74 1543 1546 1540
1547 0 177d a6
:3 0 55 :3 0 3a
:2 0 b77 1549 154c
10e :2 0 3a :2 0
b7c 154e 1550 :3 0
1551 :2 0 3f :3 0
113 :2 0 b7f 1554
1555 :3 0 1556 :2 0
1557 :2 0 1552 1559
1558 :2 0 72 :3 0
19c :3 0 25 :3 0
4a :3 0 4b :3 0
23 :3 0 22 :3 0
3f :3 0 55 :3 0
3a :2 0 b81 155c
1565 155b 1566 0
1568 b8a 1569 155a
1568 0 156a b8c
0 177d 90 :3 0
35 :3 0 36 :2 0
36 :2 0 b8e 156b
156f c9 :2 0 19d
:4 0 b94 1571 1573
:3 0 5a :3 0 19d
:2 0 1575 1576 0
15ed 3f :3 0 113
:2 0 b97 1579 157a
:3 0 157b :2 0 86
:3 0 87 :3 0 8f
:3 0 90 :3 0 3f
:3 0 86 :3 0 89
:3 0 28 :3 0 28
:3 0 11d :4 0 19e
1 :8 0 158d 96
:3 0 bd :3 0 1588
1589 0 be :3 0
158a 158b 0 158d
b99 15e0 bf :3 0
96 :3 0 bd :3 0
158f 1590 0 be
:3 0 1591 1592 0
1594 b9c 1596 b9e
1595 1594 :2 0 15de
c0 :3 0 96 :3 0
bd :3 0 1599 159a
0 be :3 0 159b
159c 0 15d6 99
:3 0 9a :3 0 159e
159f 0 99 :3 0
ac :3 0 15a1 15a2
0 c1 :2 0 2
:4 0 19f :2 0 ae
:2 0 36 :2 0 ba0
15a7 15a9 :3 0 ba3
15a3 15ab 15a0 15ad
15ac :2 0 9c :3 0
af :3 0 15af 15b0
0 9e :4 0 1a0
:4 0 a1 :2 0 a2
:3 0 ba7 15b4 15b6
:3 0 a1 :2 0 c4
:4 0 baa 15b8 15ba
:3 0 a1 :2 0 c5
:4 0 bad 15bc 15be
:3 0 a1 :2 0 be
:3 0 bb0 15c0 15c2
:3 0 a1 :2 0 c6
:4 0 bb3 15c4 15c6
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 bb6
15c9 15cd bba 15c8
15cf :3 0 bbd 15b1
15d1 :2 0 15d3 bc0
15d4 15ae 15d3 0
15d5 bc2 0 15d6
bc4 15d9 :3 0 15d9
0 15d9 15d8 15d6
15d7 :6 0 15db 30
:3 0 bc7 15dd bc9
15dc 15db :2 0 15de
bcb :2 0 15e0 0
15e0 15df 158d 15de
:6 0 15ea 1 :3 0
31 :3 0 90 :3 0
28 :3 0 36 :2 0
10d :2 0 bce 15e3
15e7 15e2 15e8 0
15ea bd2 15eb 157c
15ea 0 15ec bd5
0 15ed bd7 15f2
5a :3 0 3a :2 0
15ee 15ef 0 15f1
bda 15f3 1574 15ed
0 15f4 0 15f1
0 15f4 bdc 0
177d 67 :3 0 a6
:3 0 4d :3 0 3a
:2 0 bdf 15f6 15f9
114 :2 0 a6 :3 0
52 :3 0 3a :2 0
be2 15fc 15ff be5
15fb 1601 :3 0 15f5
1602 0 177d 72
:3 0 1a1 :3 0 25
:3 0 4a :3 0 22
:3 0 4b :3 0 37
:3 0 31 :3 0 33
:3 0 28 :3 0 2b
:3 0 5a :3 0 59
:3 0 50 :3 0 4c
:3 0 a6 :3 0 67
:3 0 3a :2 0 be8
1613 1616 19d :2 0
80 :3 0 3a :2 0
beb 1605 161b 1604
161c 0 177d a6
:3 0 72 :3 0 3a
:2 0 bfd 161e 1621
c9 :2 0 3a :2 0
c02 1623 1625 :3 0
86 :3 0 10c :3 0
1627 1628 0 3f
:3 0 2b :3 0 10d
:2 0 c05 1629 162d
c9 :2 0 3a :2 0
c0b 162f 1631 :3 0
eb :3 0 1a2 :3 0
105 :3 0 1a3 :3 0
1a4 :3 0 2b :3 0
fc :3 0 e7 :3 0
da :3 0 d6 :3 0
129 :3 0 2b :3 0
ec :3 0 22 :4 0
1a5 1 :8 0 1657
12c :4 0 1642 :3 0
12d :3 0 c9 :2 0
c10 1645 1646 :3 0
96 :3 0 bd :3 0
1648 1649 0 3a
:2 0 164a 164b 0
164d c13 1654 96
:3 0 bd :3 0 164e
164f 0 12e :2 0
1650 1651 0 1653
c15 1655 1647 164d
0 1656 0 1653
0 1656 c17 0
1657 c1a 16aa bf
:3 0 96 :3 0 bd
:3 0 1659 165a 0
be :3 0 165b 165c
0 165e c1d 1660
c1f 165f 165e :2 0
16a8 c0 :3 0 96
:3 0 bd :3 0 1663
1664 0 be :3 0
1665 1666 0 16a0
99 :3 0 9a :3 0
1668 1669 0 99
:3 0 ac :3 0 166b
166c 0 c1 :2 0
2 :4 0 1a6 :2 0
ae :2 0 36 :2 0
c21 1671 1673 :3 0
c24 166d 1675 166a
1677 1676 :2 0 9c
:3 0 af :3 0 1679
167a 0 9e :4 0
1a7 :4 0 a1 :2 0
a2 :3 0 c28 167e
1680 :3 0 a1 :2 0
c4 :4 0 c2b 1682
1684 :3 0 a1 :2 0
c5 :4 0 c2e 1686
1688 :3 0 a1 :2 0
be :3 0 c31 168a
168c :3 0 a1 :2 0
c6 :4 0 c34 168e
1690 :3 0 a1 :2 0
90 :3 0 c7 :3 0
36 :2 0 c8 :2 0
c37 1693 1697 c3b
1692 1699 :3 0 c3e
167b 169b :2 0 169d
c41 169e 1678 169d
0 169f c43 0
16a0 c45 16a3 :3 0
16a3 0 16a3 16a2
16a0 16a1 :6 0 16a5
32 :3 0 c48 16a7
c4a 16a6 16a5 :2 0
16a8 c4c :2 0 16aa
0 16aa 16a9 1657
16a8 :6 0 16ad 1
:3 0 162 :3 0 c4f
173c a6 :3 0 67
:3 0 3a :2 0 c51
16ae 16b1 c9 :2 0
3a :2 0 c56 16b3
16b5 :3 0 86 :3 0
10c :3 0 16b7 16b8
0 3f :3 0 2b
:3 0 10d :2 0 c59
16b9 16bd 155 :2 0
3a :2 0 c5f 16bf
16c1 :3 0 16b6 16c3
16c2 :2 0 eb :3 0
1a2 :3 0 105 :3 0
1a8 :3 0 1a4 :3 0
e7 :3 0 d6 :3 0
da :3 0 ec :3 0
22 :4 0 1a9 1
:8 0 16e5 12c :4 0
16d0 :3 0 12d :3 0
c9 :2 0 c64 16d3
16d4 :3 0 96 :3 0
bd :3 0 16d6 16d7
0 3a :2 0 16d8
16d9 0 16db c67
16e2 96 :3 0 bd
:3 0 16dc 16dd 0
12e :2 0 16de 16df
0 16e1 c69 16e3
16d5 16db 0 16e4
0 16e1 0 16e4
c6b 0 16e5 c6e
1738 bf :3 0 96
:3 0 bd :3 0 16e7
16e8 0 be :3 0
16e9 16ea 0 16ec
c71 16ee c73 16ed
16ec :2 0 1736 c0
:3 0 96 :3 0 bd
:3 0 16f1 16f2 0
be :3 0 16f3 16f4
0 172e 99 :3 0
9a :3 0 16f6 16f7
0 99 :3 0 ac
:3 0 16f9 16fa 0
c1 :2 0 2 :4 0
1aa :2 0 ae :2 0
36 :2 0 c75 16ff
1701 :3 0 c78 16fb
1703 16f8 1705 1704
:2 0 9c :3 0 af
:3 0 1707 1708 0
9e :4 0 1ab :4 0
a1 :2 0 a2 :3 0
c7c 170c 170e :3 0
a1 :2 0 c4 :4 0
c7f 1710 1712 :3 0
a1 :2 0 c5 :4 0
c82 1714 1716 :3 0
a1 :2 0 be :3 0
c85 1718 171a :3 0
a1 :2 0 c6 :4 0
c88 171c 171e :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 c8b 1721
1725 c8f 1720 1727
:3 0 c92 1709 1729
:2 0 172b c95 172c
1706 172b 0 172d
c97 0 172e c99
1731 :3 0 1731 0
1731 1730 172e 172f
:6 0 1733 34 :3 0
c9c 1735 c9e 1734
1733 :2 0 1736 ca0
:2 0 1738 0 1738
1737 16e5 1736 :6 0
173a 1 :3 0 ca3
173b 16c4 173a 0
173d 1632 16ad 0
173d ca5 0 173e
ca8 173f 1626 173e
0 1740 caa 0
177d 72 :3 0 1ac
:3 0 25 :3 0 4a
:3 0 22 :3 0 3a
:2 0 cac 1742 1747
1741 1748 0 177d
72 :3 0 17a :3 0
25 :3 0 cb1 174b
174d 174a 174e 0
177d 96 :3 0 bd
:3 0 1750 1751 0
3a :2 0 1752 1753
0 177d 11 :3 0
20 :3 0 1755 1756
0 177d 99 :3 0
9a :3 0 1758 1759
0 99 :3 0 ac
:3 0 175b 175c 0
36 :2 0 2 :4 0
1ad :2 0 ae :2 0
36 :2 0 cb3 1761
1763 :3 0 cb6 175d
1765 175a 1767 1766
:2 0 9c :3 0 af
:3 0 1769 176a 0
9e :4 0 1ae :4 0
a1 :2 0 a2 :3 0
cba 176e 1770 :3 0
cbd 176b 1772 :2 0
1774 cc0 1775 1768
1774 0 1776 cc2
0 177d 12 :3 0
96 :3 0 bd :3 0
1778 1779 0 177a
:2 0 177d 162 :3 0
cc4 177e 14da 177d
0 1b9a a6 :3 0
4f :3 0 3a :2 0
cd2 177f 1782 a6
:3 0 155 :2 0 13
:3 0 3a :2 0 cd5
1784 1788 cda 1785
178a :3 0 4f :3 0
a6 :3 0 13 :3 0
3a :2 0 cdd 178d
1790 114 :2 0 a6
:3 0 4f :3 0 3a
:2 0 ce0 1793 1796
ce3 1792 1798 :3 0
178c 1799 0 18b7
a6 :3 0 58 :3 0
3a :2 0 ce6 179b
179e 105 :3 0 c9
:2 0 13d :3 0 17a0
17a2 0 ceb 17a1
17a4 :3 0 a6 :3 0
58 :3 0 3a :2 0
cee 17a6 17a9 105
:3 0 c9 :2 0 13e
:3 0 17ab 17ad 0
cf3 17ac 17af :3 0
17a5 17b1 17b0 :2 0
90 :3 0 37 :3 0
36 :2 0 36 :2 0
cf6 17b3 17b7 c9
:2 0 3a :4 0 cfc
17b9 17bb :3 0 17bc
:2 0 11 :3 0 4b
:3 0 17be 17bf 0
17c1 cff 17c6 11
:3 0 25 :3 0 17c2
17c3 0 17c5 d01
17c7 17bd 17c1 0
17c8 0 17c5 0
17c8 d03 0 18ae
72 :3 0 1af :3 0
11 :3 0 2a :3 0
4f :3 0 2d :3 0
d06 17ca 17cf 17c9
17d0 0 18ae 86
:3 0 10c :3 0 17d2
17d3 0 31 :3 0
2f :3 0 10d :2 0
d0b 17d4 17d8 10f
:2 0 3a :2 0 d11
17da 17dc :3 0 17f
:2 0 d14 17de 17df
:3 0 86 :3 0 10c
:3 0 17e1 17e2 0
33 :3 0 30 :3 0
10d :2 0 d16 17e3
17e7 10f :2 0 3a
:2 0 d1c 17e9 17eb
:3 0 17f :2 0 d1f
17ed 17ee :3 0 17e0
17f0 17ef :2 0 2e
:3 0 b1 :4 0 17f2
17f3 0 1829 83
:3 0 96 :3 0 bd
:3 0 17f6 17f7 0
17f5 17f8 0 1829
81 :3 0 1b0 :3 0
25 :3 0 59 :3 0
2d :3 0 d21 17fb
17ff 17fa 1800 0
1829 96 :3 0 bd
:3 0 1802 1803 0
83 :3 0 1804 1805
0 1829 83 :3 0
96 :3 0 bd :3 0
1808 1809 0 1807
180a 0 1829 81
:3 0 1b1 :3 0 25
:3 0 2d :3 0 2e
:3 0 5c :3 0 d25
180d 1812 180c 1813
0 1829 96 :3 0
bd :3 0 1815 1816
0 83 :3 0 1817
1818 0 1829 4d
:3 0 13f :3 0 140
:3 0 181b 181c 0
a6 :3 0 4d :3 0
3a :2 0 d2a 181e
1821 105 :3 0 141
:3 0 1823 1824 0
d2d 181d 1826 181a
1827 0 1829 d30
182e 2e :3 0 30
:3 0 182a 182b 0
182d d39 182f 17f1
1829 0 1830 0
182d 0 1830 d3b
0 18ae 2e :3 0
1b2 :2 0 d3e 1832
1833 :3 0 1834 :2 0
99 :3 0 9a :3 0
1836 1837 0 99
:3 0 ac :3 0 1839
183a 0 36 :2 0
2 :4 0 1b3 :2 0
ae :2 0 36 :2 0
d40 183f 1841 :3 0
d43 183b 1843 1838
1845 1844 :2 0 9c
:3 0 af :3 0 1847
1848 0 9e :4 0
1b4 :4 0 a1 :2 0
a2 :3 0 d47 184c
184e :3 0 d4a 1849
1850 :2 0 1852 d4d
1853 1846 1852 0
1854 d4f 0 185a
12 :3 0 105 :3 0
1b5 :3 0 1856 1857
0 1858 :2 0 185a
d51 185b 1835 185a
0 185c d54 0
18ae 71 :3 0 195
:3 0 2d :3 0 28
:3 0 2e :3 0 23
:3 0 25 :3 0 4a
:3 0 22 :3 0 31
:3 0 33 :3 0 35
:3 0 4b :3 0 37
:3 0 59 :3 0 50
:3 0 73 :3 0 75
:3 0 3c :3 0 3b
:3 0 4c :3 0 a6
:3 0 4d :3 0 3a
:2 0 d56 1872 1875
a6 :3 0 52 :3 0
3a :2 0 d59 1877
187a d5c 185e 187c
185d 187d 0 18ae
72 :3 0 17a :3 0
25 :3 0 d72 1880
1882 187f 1883 0
18ae 11 :3 0 20
:3 0 1885 1886 0
18ae 99 :3 0 9a
:3 0 1888 1889 0
99 :3 0 ac :3 0
188b 188c 0 36
:2 0 2 :4 0 1b6
:2 0 ae :2 0 36
:2 0 d74 1891 1893
:3 0 d77 188d 1895
188a 1897 1896 :2 0
9c :3 0 af :3 0
1899 189a 0 9e
:4 0 1b7 :4 0 a1
:2 0 a2 :3 0 d7b
189e 18a0 :3 0 d7e
189b 18a2 :2 0 18a4
d81 18a5 1898 18a4
0 18a6 d83 0
18ae 12 :3 0 a6
:3 0 72 :3 0 3a
:2 0 d85 18a8 18ab
18ac :2 0 18ae d88
18b3 7f :3 0 36
:2 0 18af 18b0 0
18b2 d92 18b4 17b2
18ae 0 18b5 0
18b2 0 18b5 d94
0 18b7 162 :3 0
d97 18b8 178b 18b7
0 1b9a a6 :3 0
13 :3 0 3a :2 0
d9a 18b9 18bc c9
:2 0 3a :2 0 d9f
18be 18c0 :3 0 4f
:3 0 3a :2 0 18c2
18c3 0 1929 7f
:3 0 36 :2 0 18c5
18c6 0 1929 f2
:3 0 28 :3 0 ff
:3 0 8e :3 0 4a
:4 0 1b8 1 :8 0
18d3 96 :3 0 bd
:3 0 18ce 18cf 0
be :3 0 18d0 18d1
0 18d3 da2 1926
bf :3 0 96 :3 0
bd :3 0 18d5 18d6
0 be :3 0 18d7
18d8 0 18da da5
18dc da7 18db 18da
:2 0 1924 c0 :3 0
96 :3 0 bd :3 0
18df 18e0 0 be
:3 0 18e1 18e2 0
191c 99 :3 0 9a
:3 0 18e4 18e5 0
99 :3 0 ac :3 0
18e7 18e8 0 c1
:2 0 2 :4 0 1b9
:2 0 ae :2 0 36
:2 0 da9 18ed 18ef
:3 0 dac 18e9 18f1
18e6 18f3 18f2 :2 0
9c :3 0 af :3 0
18f5 18f6 0 9e
:4 0 1ba :4 0 a1
:2 0 a2 :3 0 db0
18fa 18fc :3 0 a1
:2 0 c4 :4 0 db3
18fe 1900 :3 0 a1
:2 0 c5 :4 0 db6
1902 1904 :3 0 a1
:2 0 be :3 0 db9
1906 1908 :3 0 a1
:2 0 c6 :4 0 dbc
190a 190c :3 0 a1
:2 0 90 :3 0 c7
:3 0 36 :2 0 c8
:2 0 dbf 190f 1913
dc3 190e 1915 :3 0
dc6 18f7 1917 :2 0
1919 dc9 191a 18f4
1919 0 191b dcb
0 191c dcd 191f
:3 0 191f 0 191f
191e 191c 191d :6 0
1921 36 :3 0 dd0
1923 dd2 1922 1921
:2 0 1924 dd4 :2 0
1926 0 1926 1925
18d3 1924 :6 0 1929
1 :3 0 162 :3 0
dd7 192a 18c1 1929
0 1b9a a6 :3 0
4f :3 0 3a :2 0
ddb 192b 192e a6
:3 0 10e :2 0 13
:3 0 3a :2 0 dde
1930 1934 de3 1931
1936 :3 0 4f :3 0
a6 :3 0 4f :3 0
3a :2 0 de6 1939
193c 114 :2 0 a6
:3 0 13 :3 0 3a
:2 0 de9 193f 1942
dec 193e 1944 :3 0
1938 1945 0 1b97
3e :4 0 1947 1948
0 1b97 7c :3 0
b1 :4 0 194a 194b
0 1b97 a6 :3 0
44 :3 0 3a :2 0
def 194d 1950 c9
:2 0 36 :2 0 df4
1952 1954 :3 0 7c
:3 0 1bb :4 0 a1
:2 0 1bc :4 0 df7
1958 195a :3 0 a1
:2 0 25 :3 0 dfa
195c 195e :3 0 a1
:2 0 1bd :4 0 dfd
1960 1962 :3 0 a1
:2 0 28 :3 0 e00
1964 1966 :3 0 a1
:2 0 1be :4 0 e03
1968 196a :3 0 a1
:2 0 1bf :4 0 e06
196c 196e :3 0 a1
:2 0 aa :3 0 a6
:3 0 4f :3 0 3a
:2 0 e09 1972 1975
e0c 1971 1977 e0e
1970 1979 :3 0 1956
197a 0 1981 137
:3 0 95 :3 0 7c
:3 0 197d 197e 0
197f :2 0 1981 e11
19ae 7c :3 0 1bb
:4 0 a1 :2 0 1bc
:4 0 e14 1984 1986
:3 0 a1 :2 0 4b
:3 0 e17 1988 198a
:3 0 a1 :2 0 1bd
:4 0 e1a 198c 198e
:3 0 a1 :2 0 28
:3 0 e1d 1990 1992
:3 0 a1 :2 0 1be
:4 0 e20 1994 1996
:3 0 a1 :2 0 1bf
:4 0 e23 1998 199a
:3 0 a1 :2 0 aa
:3 0 a6 :3 0 4f
:3 0 3a :2 0 e26
199e 19a1 e29 199d
19a3 e2b 199c 19a5
:3 0 1982 19a6 0
19ad 137 :3 0 98
:3 0 7c :3 0 19a9
19aa 0 19ab :2 0
19ad e2e 19af 1955
1981 0 19b0 0
19ad 0 19b0 e31
0 1b97 1c0 :3 0
a6 :3 0 44 :3 0
3a :2 0 e34 19b2
19b5 c9 :2 0 36
:2 0 e39 19b7 19b9
:3 0 95 :3 0 3e
:4 0 19be :2 0 19d1
19bb 19bc :3 0 95
:3 0 12c :3 0 19bf
19c0 :3 0 96 :3 0
bd :3 0 19c2 19c3
0 3a :2 0 19c4
19c5 0 19c7 e3c
19ce 96 :3 0 bd
:3 0 19c8 19c9 0
12e :2 0 19ca 19cb
0 19cd e3e 19cf
19c1 19c7 0 19d0
0 19cd 0 19d0
e40 0 19d1 e43
19e9 98 :3 0 3e
:4 0 19d5 :2 0 19e8
19d2 19d3 :3 0 98
:3 0 12c :3 0 19d6
19d7 :3 0 96 :3 0
bd :3 0 19d9 19da
0 3a :2 0 19db
19dc 0 19de e46
19e5 96 :3 0 bd
:3 0 19df 19e0 0
12e :2 0 19e1 19e2
0 19e4 e48 19e6
19d8 19de 0 19e7
0 19e4 0 19e7
e4a 0 19e8 e4d
19ea 19ba 19d1 0
19eb 0 19e8 0
19eb e50 0 19fb
96 :3 0 bd :3 0
19ec 19ed 0 96
:3 0 10f :2 0 183
:3 0 19ef 19f1 0
e55 19f0 19f3 :3 0
19f4 :2 0 1c1 :8 0
19f8 e58 19f9 19f5
19f8 0 19fa e5a
0 19fb e5c 19fd
1c0 :4 0 19fb :4 0
1b97 a6 :3 0 44
:3 0 3a :2 0 e5f
19fe 1a01 c9 :2 0
36 :2 0 e64 1a03
1a05 :3 0 13a :3 0
95 :4 0 1a0a :2 0
1a10 1a08 0 96
:3 0 bd :3 0 1a0b
1a0c 0 be :3 0
1a0d 1a0e 0 1a10
e67 1a63 bf :3 0
96 :3 0 bd :3 0
1a12 1a13 0 be
:3 0 1a14 1a15 0
1a17 e6a 1a19 e6c
1a18 1a17 :2 0 1a61
c0 :3 0 96 :3 0
bd :3 0 1a1c 1a1d
0 be :3 0 1a1e
1a1f 0 1a59 99
:3 0 9a :3 0 1a21
1a22 0 99 :3 0
ac :3 0 1a24 1a25
0 c1 :2 0 2
:4 0 1c2 :2 0 ae
:2 0 36 :2 0 e6e
1a2a 1a2c :3 0 e71
1a26 1a2e 1a23 1a30
1a2f :2 0 9c :3 0
af :3 0 1a32 1a33
0 9e :4 0 1c3
:4 0 a1 :2 0 a2
:3 0 e75 1a37 1a39
:3 0 a1 :2 0 c4
:4 0 e78 1a3b 1a3d
:3 0 a1 :2 0 c5
:4 0 e7b 1a3f 1a41
:3 0 a1 :2 0 be
:3 0 e7e 1a43 1a45
:3 0 a1 :2 0 c6
:4 0 e81 1a47 1a49
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 e84
1a4c 1a50 e88 1a4b
1a52 :3 0 e8b 1a34
1a54 :2 0 1a56 e8e
1a57 1a31 1a56 0
1a58 e90 0 1a59
e92 1a5c :3 0 1a5c
0 1a5c 1a5b 1a59
1a5a :6 0 1a5e 39
:3 0 e95 1a60 e97
1a5f 1a5e :2 0 1a61
e99 :2 0 1a63 0
1a63 1a62 1a10 1a61
:6 0 1a65 1 :3 0
e9c 1ac5 13a :3 0
98 :4 0 1a69 :2 0
1a6f 1a67 0 96
:3 0 bd :3 0 1a6a
1a6b 0 be :3 0
1a6c 1a6d 0 1a6f
e9e 1ac2 bf :3 0
96 :3 0 bd :3 0
1a71 1a72 0 be
:3 0 1a73 1a74 0
1a76 ea1 1a78 ea3
1a77 1a76 :2 0 1ac0
c0 :3 0 96 :3 0
bd :3 0 1a7b 1a7c
0 be :3 0 1a7d
1a7e 0 1ab8 99
:3 0 9a :3 0 1a80
1a81 0 99 :3 0
ac :3 0 1a83 1a84
0 c1 :2 0 2
:4 0 1c4 :2 0 ae
:2 0 36 :2 0 ea5
1a89 1a8b :3 0 ea8
1a85 1a8d 1a82 1a8f
1a8e :2 0 9c :3 0
af :3 0 1a91 1a92
0 9e :4 0 1c5
:4 0 a1 :2 0 a2
:3 0 eac 1a96 1a98
:3 0 a1 :2 0 c4
:4 0 eaf 1a9a 1a9c
:3 0 a1 :2 0 c5
:4 0 eb2 1a9e 1aa0
:3 0 a1 :2 0 be
:3 0 eb5 1aa2 1aa4
:3 0 a1 :2 0 c6
:4 0 eb8 1aa6 1aa8
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 ebb
1aab 1aaf ebf 1aaa
1ab1 :3 0 ec2 1a93
1ab3 :2 0 1ab5 ec5
1ab6 1a90 1ab5 0
1ab7 ec7 0 1ab8
ec9 1abb :3 0 1abb
0 1abb 1aba 1ab8
1ab9 :6 0 1abd 3b
:3 0 ecc 1abf ece
1abe 1abd :2 0 1ac0
ed0 :2 0 1ac2 0
1ac2 1ac1 1a6f 1ac0
:6 0 1ac4 1 :3 0
ed3 1ac6 1a06 1a65
0 1ac7 0 1ac4
0 1ac7 ed5 0
1b97 3e :3 0 1b2
:2 0 ed8 1ac9 1aca
:3 0 1acb :2 0 a6
:3 0 44 :3 0 3a
:2 0 eda 1acd 1ad0
c9 :2 0 36 :2 0
edf 1ad2 1ad4 :3 0
11 :3 0 25 :3 0
1ad6 1ad7 0 1afd
99 :3 0 9a :3 0
1ad9 1ada 0 99
:3 0 ac :3 0 1adc
1add 0 36 :2 0
2 :4 0 1c6 :2 0
ae :2 0 36 :2 0
ee2 1ae2 1ae4 :3 0
ee5 1ade 1ae6 1adb
1ae8 1ae7 :2 0 9c
:3 0 af :3 0 1aea
1aeb 0 9e :4 0
1c7 :4 0 a1 :2 0
a2 :3 0 ee9 1aef
1af1 :3 0 eec 1aec
1af3 :2 0 1af5 eef
1af6 1ae9 1af5 0
1af7 ef1 0 1afd
12 :3 0 105 :3 0
106 :3 0 1af9 1afa
0 1afb :2 0 1afd
ef3 1b26 11 :3 0
4b :3 0 1afe 1aff
0 1b25 99 :3 0
9a :3 0 1b01 1b02
0 99 :3 0 ac
:3 0 1b04 1b05 0
36 :2 0 2 :4 0
1c8 :2 0 ae :2 0
36 :2 0 ef7 1b0a
1b0c :3 0 efa 1b06
1b0e 1b03 1b10 1b0f
:2 0 9c :3 0 af
:3 0 1b12 1b13 0
9e :4 0 1c9 :4 0
a1 :2 0 a2 :3 0
efe 1b17 1b19 :3 0
f01 1b14 1b1b :2 0
1b1d f04 1b1e 1b11
1b1d 0 1b1f f06
0 1b25 12 :3 0
105 :3 0 106 :3 0
1b21 1b22 0 1b23
:2 0 1b25 f08 1b27
1ad5 1afd 0 1b28
0 1b25 0 1b28
f0c 0 1b29 f0f
1b2a 1acc 1b29 0
1b2b f11 0 1b97
86 :3 0 87 :3 0
8f :3 0 90 :3 0
3e :3 0 86 :3 0
89 :3 0 28 :3 0
28 :3 0 11d :4 0
1ca 1 :8 0 1b3c
96 :3 0 bd :3 0
1b37 1b38 0 be
:3 0 1b39 1b3a 0
1b3c f13 1b8f bf
:3 0 96 :3 0 bd
:3 0 1b3e 1b3f 0
be :3 0 1b40 1b41
0 1b43 f16 1b45
f18 1b44 1b43 :2 0
1b8d c0 :3 0 96
:3 0 bd :3 0 1b48
1b49 0 be :3 0
1b4a 1b4b 0 1b85
99 :3 0 9a :3 0
1b4d 1b4e 0 99
:3 0 ac :3 0 1b50
1b51 0 c1 :2 0
2 :4 0 1cb :2 0
ae :2 0 36 :2 0
f1a 1b56 1b58 :3 0
f1d 1b52 1b5a 1b4f
1b5c 1b5b :2 0 9c
:3 0 af :3 0 1b5e
1b5f 0 9e :4 0
1cc :4 0 a1 :2 0
a2 :3 0 f21 1b63
1b65 :3 0 a1 :2 0
c4 :4 0 f24 1b67
1b69 :3 0 a1 :2 0
c5 :4 0 f27 1b6b
1b6d :3 0 a1 :2 0
be :3 0 f2a 1b6f
1b71 :3 0 a1 :2 0
c6 :4 0 f2d 1b73
1b75 :3 0 a1 :2 0
90 :3 0 c7 :3 0
36 :2 0 c8 :2 0
f30 1b78 1b7c f34
1b77 1b7e :3 0 f37
1b60 1b80 :2 0 1b82
f3a 1b83 1b5d 1b82
0 1b84 f3c 0
1b85 f3e 1b88 :3 0
1b88 0 1b88 1b87
1b85 1b86 :6 0 1b8a
3d :3 0 f41 1b8c
f43 1b8b 1b8a :2 0
1b8d f45 :2 0 1b8f
0 1b8f 1b8e 1b3c
1b8d :6 0 1b97 1
:3 0 4f :3 0 3a
:2 0 1b91 1b92 0
1b97 7f :3 0 36
:2 0 1b94 1b95 0
1b97 f48 1b98 1937
1b97 0 1b9a 137d
14ce 0 1b9a f53
0 1b9c 162 :3 0
f59 1f01 a6 :3 0
14 :3 0 3a :2 0
f5b 1b9d 1ba0 a6
:3 0 10f :2 0 50
:3 0 3a :2 0 f5e
1ba2 1ba6 f63 1ba3
1ba8 :3 0 a6 :3 0
69 :3 0 3a :2 0
f66 1baa 1bad 10e
:2 0 3a :2 0 f6b
1baf 1bb1 :3 0 a6
:3 0 14 :3 0 3a
:2 0 f6e 1bb3 1bb6
a6 :3 0 10e :2 0
69 :3 0 3a :2 0
f71 1bb8 1bbc f76
1bb9 1bbe :3 0 1bb2
1bc0 1bbf :2 0 11
:3 0 23 :3 0 1bc2
1bc3 0 1be9 99
:3 0 9a :3 0 1bc5
1bc6 0 99 :3 0
ac :3 0 1bc8 1bc9
0 36 :2 0 2
:4 0 1cd :2 0 ae
:2 0 36 :2 0 f79
1bce 1bd0 :3 0 f7c
1bca 1bd2 1bc7 1bd4
1bd3 :2 0 9c :3 0
af :3 0 1bd6 1bd7
0 9e :4 0 1ce
:4 0 a1 :2 0 a2
:3 0 f80 1bdb 1bdd
:3 0 f83 1bd8 1bdf
:2 0 1be1 f86 1be2
1bd5 1be1 0 1be3
f88 0 1be9 12
:3 0 105 :3 0 15e
:3 0 1be5 1be6 0
1be7 :2 0 1be9 f8a
1bea 1bc1 1be9 0
1beb f8e 0 1eff
a6 :3 0 52 :3 0
3a :2 0 f90 1bec
1bef a6 :3 0 c9
:2 0 4d :3 0 3a
:2 0 f93 1bf1 1bf5
f98 1bf2 1bf7 :3 0
11 :3 0 22 :3 0
1bf9 1bfa 0 1c20
99 :3 0 9a :3 0
1bfc 1bfd 0 99
:3 0 ac :3 0 1bff
1c00 0 36 :2 0
2 :4 0 1cf :2 0
ae :2 0 36 :2 0
f9b 1c05 1c07 :3 0
f9e 1c01 1c09 1bfe
1c0b 1c0a :2 0 9c
:3 0 af :3 0 1c0d
1c0e 0 9e :4 0
1d0 :4 0 a1 :2 0
a2 :3 0 fa2 1c12
1c14 :3 0 fa5 1c0f
1c16 :2 0 1c18 fa8
1c19 1c0c 1c18 0
1c1a faa 0 1c20
12 :3 0 96 :3 0
bd :3 0 1c1c 1c1d
0 1c1e :2 0 1c20
fac 1c21 1bf8 1c20
0 1c22 fb0 0
1eff a6 :3 0 14
:3 0 3a :2 0 fb2
1c23 1c26 c9 :2 0
3a :2 0 fb7 1c28
1c2a :3 0 50 :3 0
12e :2 0 1c2c 1c2d
0 1c2f fba 1c78
a6 :3 0 14 :3 0
3a :2 0 fbc 1c30
1c33 155 :2 0 36
:2 0 fc1 1c35 1c37
:3 0 1c38 :2 0 a6
:3 0 14 :3 0 3a
:2 0 fc4 1c3a 1c3d
10e :2 0 1d1 :2 0
fc9 1c3f 1c41 :3 0
1c42 :2 0 1c39 1c44
1c43 :2 0 11 :3 0
22 :3 0 1c46 1c47
0 1c6d 99 :3 0
9a :3 0 1c49 1c4a
0 99 :3 0 ac
:3 0 1c4c 1c4d 0
36 :2 0 2 :4 0
1d2 :2 0 ae :2 0
36 :2 0 fcc 1c52
1c54 :3 0 fcf 1c4e
1c56 1c4b 1c58 1c57
:2 0 9c :3 0 af
:3 0 1c5a 1c5b 0
9e :4 0 1d3 :4 0
a1 :2 0 a2 :3 0
fd3 1c5f 1c61 :3 0
fd6 1c5c 1c63 :2 0
1c65 fd9 1c66 1c59
1c65 0 1c67 fdb
0 1c6d 12 :3 0
105 :3 0 1d4 :3 0
1c69 1c6a 0 1c6b
:2 0 1c6d fdd 1c6e
1c45 1c6d 0 1c6f
fe1 0 1c77 50
:3 0 a6 :3 0 14
:3 0 3a :2 0 fe3
1c71 1c74 1c70 1c75
0 1c77 fe6 1c79
1c2b 1c2f 0 1c7a
0 1c77 0 1c7a
fe9 0 1eff a6
:3 0 58 :3 0 3a
:2 0 fec 1c7b 1c7e
105 :3 0 c9 :2 0
13d :3 0 1c80 1c82
0 ff1 1c81 1c84
:3 0 a6 :3 0 58
:3 0 3a :2 0 ff4
1c86 1c89 105 :3 0
c9 :2 0 13e :3 0
1c8b 1c8d 0 ff9
1c8c 1c8f :3 0 1c85
1c91 1c90 :2 0 a6
:3 0 55 :3 0 3a
:2 0 ffc 1c93 1c96
10e :2 0 3a :2 0
1001 1c98 1c9a :3 0
1c9b :2 0 3f :3 0
113 :2 0 1004 1c9e
1c9f :3 0 1ca0 :2 0
1ca1 :2 0 1c9c 1ca3
1ca2 :2 0 86 :3 0
87 :3 0 8f :3 0
90 :3 0 3f :3 0
86 :3 0 89 :3 0
28 :3 0 28 :3 0
11d :4 0 1d5 1
:8 0 1cb5 96 :3 0
bd :3 0 1cb0 1cb1
0 be :3 0 1cb2
1cb3 0 1cb5 1006
1d08 bf :3 0 96
:3 0 bd :3 0 1cb7
1cb8 0 be :3 0
1cb9 1cba 0 1cbc
1009 1cbe 100b 1cbd
1cbc :2 0 1d06 c0
:3 0 96 :3 0 bd
:3 0 1cc1 1cc2 0
be :3 0 1cc3 1cc4
0 1cfe 99 :3 0
9a :3 0 1cc6 1cc7
0 99 :3 0 ac
:3 0 1cc9 1cca 0
c1 :2 0 2 :4 0
1d6 :2 0 ae :2 0
36 :2 0 100d 1ccf
1cd1 :3 0 1010 1ccb
1cd3 1cc8 1cd5 1cd4
:2 0 9c :3 0 af
:3 0 1cd7 1cd8 0
9e :4 0 1d7 :4 0
a1 :2 0 a2 :3 0
1014 1cdc 1cde :3 0
a1 :2 0 c4 :4 0
1017 1ce0 1ce2 :3 0
a1 :2 0 c5 :4 0
101a 1ce4 1ce6 :3 0
a1 :2 0 be :3 0
101d 1ce8 1cea :3 0
a1 :2 0 c6 :4 0
1020 1cec 1cee :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 1023 1cf1
1cf5 1027 1cf0 1cf7
:3 0 102a 1cd9 1cf9
:2 0 1cfb 102d 1cfc
1cd6 1cfb 0 1cfd
102f 0 1cfe 1031
1d01 :3 0 1d01 0
1d01 1d00 1cfe 1cff
:6 0 1d03 3f :3 0
1034 1d05 1036 1d04
1d03 :2 0 1d06 1038
:2 0 1d08 0 1d08
1d07 1cb5 1d06 :6 0
1d0a 1 :3 0 103b
1d0b 1ca4 1d0a 0
1d0c 103d 0 1d88
56 :3 0 152 :3 0
a6 :3 0 50 :3 0
3a :2 0 103f 1d0f
1d12 154 :2 0 a6
:3 0 59 :3 0 3a
:2 0 1042 1d15 1d18
1045 1d14 1d1a :3 0
1d1b :2 0 153 :2 0
1d8 :2 0 1048 1d1d
1d1f :3 0 1d20 :2 0
ae :2 0 1d9 :2 0
104b 1d22 1d24 :3 0
104e 1d0e 1d26 1d0d
1d27 0 1d88 72
:3 0 1da :3 0 25
:3 0 23 :3 0 22
:3 0 28 :3 0 29
:3 0 56 :3 0 56
:3 0 3a :2 0 1050
1d2a 1d33 1d29 1d34
0 1d88 72 :3 0
13f :3 0 140 :3 0
1d37 1d38 0 a6
:3 0 50 :3 0 3a
:2 0 1059 1d3a 1d3d
105 :3 0 1db :3 0
1d3f 1d40 0 105c
1d39 1d42 1d36 1d43
0 1d88 72 :3 0
1dc :3 0 25 :3 0
22 :3 0 72 :3 0
3a :2 0 3a :2 0
3a :2 0 105f 1d46
1d4d 1d45 1d4e 0
1d88 72 :3 0 1ac
:3 0 25 :3 0 4a
:3 0 22 :3 0 3a
:2 0 1066 1d51 1d56
1d50 1d57 0 1d88
72 :3 0 17a :3 0
25 :3 0 106b 1d5a
1d5c 1d59 1d5d 0
1d88 11 :3 0 22
:3 0 1d5f 1d60 0
1d88 99 :3 0 9a
:3 0 1d62 1d63 0
99 :3 0 ac :3 0
1d65 1d66 0 36
:2 0 2 :4 0 1dd
:2 0 ae :2 0 36
:2 0 106d 1d6b 1d6d
:3 0 1070 1d67 1d6f
1d64 1d71 1d70 :2 0
9c :3 0 af :3 0
1d73 1d74 0 9e
:4 0 1de :4 0 a1
:2 0 a2 :3 0 1074
1d78 1d7a :3 0 1077
1d75 1d7c :2 0 1d7e
107a 1d7f 1d72 1d7e
0 1d80 107c 0
1d88 12 :3 0 a6
:3 0 72 :3 0 3a
:2 0 107e 1d82 1d85
1d86 :2 0 1d88 1081
1efc 65 :3 0 152
:3 0 a6 :3 0 59
:3 0 3a :2 0 108c
1d8b 1d8e 154 :2 0
a6 :3 0 50 :3 0
3a :2 0 108f 1d91
1d94 1092 1d90 1d96
:3 0 1d97 :2 0 153
:2 0 1d8 :2 0 1095
1d99 1d9b :3 0 1d9c
:2 0 ae :2 0 1df
:2 0 1098 1d9e 1da0
:3 0 109b 1d8a 1da2
1d89 1da3 0 1efb
a6 :3 0 65 :3 0
3a :2 0 109d 1da5
1da8 a6 :3 0 10e
:2 0 4d :3 0 3a
:2 0 10a0 1daa 1dae
10a5 1dab 1db0 :3 0
72 :3 0 3a :2 0
1db2 1db3 0 1e45
142 :3 0 72 :3 0
143 :3 0 b9 :3 0
25 :3 0 ec :3 0
22 :4 0 1e0 1
:8 0 1dc2 96 :3 0
bd :3 0 1dbd 1dbe
0 be :3 0 1dbf
1dc0 0 1dc2 10a8
1e15 bf :3 0 96
:3 0 bd :3 0 1dc4
1dc5 0 be :3 0
1dc6 1dc7 0 1dc9
10ab 1dcb 10ad 1dca
1dc9 :2 0 1e13 c0
:3 0 96 :3 0 bd
:3 0 1dce 1dcf 0
be :3 0 1dd0 1dd1
0 1e0b 99 :3 0
9a :3 0 1dd3 1dd4
0 99 :3 0 ac
:3 0 1dd6 1dd7 0
c1 :2 0 2 :4 0
1e1 :2 0 ae :2 0
36 :2 0 10af 1ddc
1dde :3 0 10b2 1dd8
1de0 1dd5 1de2 1de1
:2 0 9c :3 0 af
:3 0 1de4 1de5 0
9e :4 0 1e2 :4 0
a1 :2 0 a2 :3 0
10b6 1de9 1deb :3 0
a1 :2 0 c4 :4 0
10b9 1ded 1def :3 0
a1 :2 0 c5 :4 0
10bc 1df1 1df3 :3 0
a1 :2 0 be :3 0
10bf 1df5 1df7 :3 0
a1 :2 0 c6 :4 0
10c2 1df9 1dfb :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 10c5 1dfe
1e02 10c9 1dfd 1e04
:3 0 10cc 1de6 1e06
:2 0 1e08 10cf 1e09
1de3 1e08 0 1e0a
10d1 0 1e0b 10d3
1e0e :3 0 1e0e 0
1e0e 1e0d 1e0b 1e0c
:6 0 1e10 41 :3 0
10d6 1e12 10d8 1e11
1e10 :2 0 1e13 10da
:2 0 1e15 0 1e15
1e14 1dc2 1e13 :6 0
1e45 1 :3 0 a6
:3 0 72 :3 0 3a
:2 0 10dd 1e17 1e1a
c9 :2 0 36 :2 0
10e2 1e1c 1e1e :3 0
99 :3 0 9a :3 0
1e20 1e21 0 99
:3 0 ac :3 0 1e23
1e24 0 36 :2 0
2 :4 0 1e3 :2 0
ae :2 0 36 :2 0
10e5 1e29 1e2b :3 0
10e8 1e25 1e2d 1e22
1e2f 1e2e :2 0 9c
:3 0 af :3 0 1e31
1e32 0 9e :4 0
1e4 :4 0 a1 :2 0
a2 :3 0 10ec 1e36
1e38 :3 0 10ef 1e33
1e3a :2 0 1e3c 10f2
1e3d 1e30 1e3c 0
1e3e 10f4 0 1e42
12 :3 0 3a :2 0
1e40 :2 0 1e42 10f6
1e43 1e1f 1e42 0
1e44 10f9 0 1e45
10fb 1e46 1db1 1e45
0 1e47 10ff 0
1efb 4f :3 0 3a
:2 0 1e48 1e49 0
1efb 7f :3 0 19d
:2 0 1e4b 1e4c 0
1efb a6 :3 0 5d
:3 0 3a :2 0 1101
1e4e 1e51 155 :2 0
1e5 :2 0 1106 1e53
1e55 :3 0 5d :3 0
36 :2 0 1e57 1e58
0 1e5a 1109 1e5b
1e56 1e5a 0 1e5c
110b 0 1efb 63
:3 0 13f :3 0 140
:3 0 1e5e 1e5f 0
13f :3 0 140 :3 0
1e61 1e62 0 105
:3 0 1e6 :3 0 1e64
1e65 0 105 :3 0
1e7 :3 0 1e67 1e68
0 110d 1e63 1e6a
105 :3 0 1e8 :3 0
1e6c 1e6d 0 1110
1e60 1e6f 1e5d 1e70
0 1efb eb :3 0
1e9 :3 0 d4 :3 0
50 :3 0 cf :3 0
d1 :3 0 ce :3 0
d2 :3 0 e9 :3 0
8a :3 0 140 :3 0
e9 :3 0 63 :3 0
ec :3 0 22 :4 0
1ea 1 :8 0 1e97
12c :4 0 1e82 :3 0
12d :3 0 c9 :2 0
1115 1e85 1e86 :3 0
96 :3 0 bd :3 0
1e88 1e89 0 3a
:2 0 1e8a 1e8b 0
1e8d 1118 1e94 96
:3 0 bd :3 0 1e8e
1e8f 0 12e :2 0
1e90 1e91 0 1e93
111a 1e95 1e87 1e8d
0 1e96 0 1e93
0 1e96 111c 0
1e97 111f 1eea bf
:3 0 96 :3 0 bd
:3 0 1e99 1e9a 0
be :3 0 1e9b 1e9c
0 1e9e 1122 1ea0
1124 1e9f 1e9e :2 0
1ee8 c0 :3 0 96
:3 0 bd :3 0 1ea3
1ea4 0 be :3 0
1ea5 1ea6 0 1ee0
99 :3 0 9a :3 0
1ea8 1ea9 0 99
:3 0 ac :3 0 1eab
1eac 0 c1 :2 0
2 :4 0 1eb :2 0
ae :2 0 36 :2 0
1126 1eb1 1eb3 :3 0
1129 1ead 1eb5 1eaa
1eb7 1eb6 :2 0 9c
:3 0 af :3 0 1eb9
1eba 0 9e :4 0
1ec :4 0 a1 :2 0
a2 :3 0 112d 1ebe
1ec0 :3 0 a1 :2 0
c4 :4 0 1130 1ec2
1ec4 :3 0 a1 :2 0
c5 :4 0 1133 1ec6
1ec8 :3 0 a1 :2 0
be :3 0 1136 1eca
1ecc :3 0 a1 :2 0
c6 :4 0 1139 1ece
1ed0 :3 0 a1 :2 0
90 :3 0 c7 :3 0
36 :2 0 c8 :2 0
113c 1ed3 1ed7 1140
1ed2 1ed9 :3 0 1143
1ebb 1edb :2 0 1edd
1146 1ede 1eb8 1edd
0 1edf 1148 0
1ee0 114a 1ee3 :3 0
1ee3 0 1ee3 1ee2
1ee0 1ee1 :6 0 1ee5
43 :3 0 114d 1ee7
114f 1ee6 1ee5 :2 0
1ee8 1151 :2 0 1eea
0 1eea 1ee9 1e97
1ee8 :6 0 1efb 1
:3 0 a6 :3 0 4e
:3 0 3a :2 0 1154
1eec 1eef 10f :2 0
3a :2 0 1159 1ef1
1ef3 :3 0 4e :3 0
3a :2 0 1ef5 1ef6
0 1ef8 115c 1ef9
1ef4 1ef8 0 1efa
115e 0 1efb 1160
1efd 1c92 1d88 0
1efe 0 1efb 0
1efe 1169 0 1eff
116c 1f00 1ba9 1eff
0 1f02 1371 1b9c
0 1f02 1171 0
29d5 7f :3 0 10e
:2 0 3a :2 0 1176
1f04 1f06 :3 0 a6
:3 0 55 :3 0 3a
:2 0 1179 1f08 1f0b
10e :2 0 3a :2 0
117e 1f0d 1f0f :3 0
1f10 :2 0 3f :3 0
113 :2 0 1181 1f13
1f14 :3 0 1f15 :2 0
1f16 :2 0 1f11 1f18
1f17 :2 0 72 :3 0
19c :3 0 25 :3 0
4a :3 0 4b :3 0
23 :3 0 22 :3 0
3f :3 0 55 :3 0
3a :2 0 1183 1f1b
1f24 1f1a 1f25 0
1f27 118c 1f28 1f19
1f27 0 1f29 118e
0 234b 23 :3 0
113 :2 0 1190 1f2b
1f2c :3 0 1f2d :2 0
71 :3 0 1ed :3 0
25 :3 0 22 :3 0
19d :2 0 1192 1f30
1f34 1f2f 1f35 0
1f37 1196 1f58 90
:3 0 35 :3 0 36
:2 0 36 :2 0 1198
1f38 1f3c c9 :2 0
19d :4 0 119e 1f3e
1f40 :3 0 71 :3 0
1ed :3 0 25 :3 0
22 :3 0 3a :2 0
11a1 1f43 1f47 1f42
1f48 0 1f4a 11a5
1f54 71 :3 0 1ed
:3 0 25 :3 0 22
:3 0 36 :2 0 11a7
1f4c 1f50 1f4b 1f51
0 1f53 11ab 1f55
1f41 1f4a 0 1f56
0 1f53 0 1f56
11ad 0 1f57 11b0
1f59 1f2e 1f37 0
1f5a 0 1f57 0
1f5a 11b2 0 234b
3f :3 0 113 :2 0
11b5 1f5c 1f5d :3 0
1f5e :2 0 a6 :3 0
4e :3 0 3a :2 0
11b7 1f60 1f63 10e
:2 0 3a :2 0 11bc
1f65 1f67 :3 0 4e
:3 0 13f :3 0 140
:3 0 1f6a 1f6b 0
a6 :3 0 4e :3 0
3a :2 0 11bf 1f6d
1f70 105 :3 0 141
:3 0 1f72 1f73 0
11c2 1f6c 1f75 1f76
:2 0 1f69 1f77 0
1fde 86 :3 0 87
:3 0 8f :3 0 90
:3 0 3f :3 0 86
:3 0 89 :3 0 28
:3 0 28 :3 0 11d
:4 0 1ee 1 :8 0
1f89 96 :3 0 bd
:3 0 1f84 1f85 0
be :3 0 1f86 1f87
0 1f89 11c5 1fdc
bf :3 0 96 :3 0
bd :3 0 1f8b 1f8c
0 be :3 0 1f8d
1f8e 0 1f90 11c8
1f92 11ca 1f91 1f90
:2 0 1fda c0 :3 0
96 :3 0 bd :3 0
1f95 1f96 0 be
:3 0 1f97 1f98 0
1fd2 99 :3 0 9a
:3 0 1f9a 1f9b 0
99 :3 0 ac :3 0
1f9d 1f9e 0 c1
:2 0 2 :4 0 1ef
:2 0 ae :2 0 36
:2 0 11cc 1fa3 1fa5
:3 0 11cf 1f9f 1fa7
1f9c 1fa9 1fa8 :2 0
9c :3 0 af :3 0
1fab 1fac 0 9e
:4 0 1f0 :4 0 a1
:2 0 a2 :3 0 11d3
1fb0 1fb2 :3 0 a1
:2 0 c4 :4 0 11d6
1fb4 1fb6 :3 0 a1
:2 0 c5 :4 0 11d9
1fb8 1fba :3 0 a1
:2 0 be :3 0 11dc
1fbc 1fbe :3 0 a1
:2 0 c6 :4 0 11df
1fc0 1fc2 :3 0 a1
:2 0 90 :3 0 c7
:3 0 36 :2 0 c8
:2 0 11e2 1fc5 1fc9
11e6 1fc4 1fcb :3 0
11e9 1fad 1fcd :2 0
1fcf 11ec 1fd0 1faa
1fcf 0 1fd1 11ee
0 1fd2 11f0 1fd5
:3 0 1fd5 0 1fd5
1fd4 1fd2 1fd3 :6 0
1fd7 45 :3 0 11f3
1fd9 11f5 1fd8 1fd7
:2 0 1fda 11f7 :2 0
1fdc 0 1fdc 1fdb
1f89 1fda :6 0 1fde
1 :3 0 11fa 2045
86 :3 0 87 :3 0
8f :3 0 90 :3 0
3f :3 0 86 :3 0
89 :3 0 28 :3 0
28 :3 0 11d :4 0
1d5 1 :8 0 1fef
96 :3 0 bd :3 0
1fea 1feb 0 be
:3 0 1fec 1fed 0
1fef 11fd 2042 bf
:3 0 96 :3 0 bd
:3 0 1ff1 1ff2 0
be :3 0 1ff3 1ff4
0 1ff6 1200 1ff8
1202 1ff7 1ff6 :2 0
2040 c0 :3 0 96
:3 0 bd :3 0 1ffb
1ffc 0 be :3 0
1ffd 1ffe 0 2038
99 :3 0 9a :3 0
2000 2001 0 99
:3 0 ac :3 0 2003
2004 0 c1 :2 0
2 :4 0 1f1 :2 0
ae :2 0 36 :2 0
1204 2009 200b :3 0
1207 2005 200d 2002
200f 200e :2 0 9c
:3 0 af :3 0 2011
2012 0 9e :4 0
1f2 :4 0 a1 :2 0
a2 :3 0 120b 2016
2018 :3 0 a1 :2 0
c4 :4 0 120e 201a
201c :3 0 a1 :2 0
c5 :4 0 1211 201e
2020 :3 0 a1 :2 0
be :3 0 1214 2022
2024 :3 0 a1 :2 0
c6 :4 0 1217 2026
2028 :3 0 a1 :2 0
90 :3 0 c7 :3 0
36 :2 0 c8 :2 0
121a 202b 202f 121e
202a 2031 :3 0 1221
2013 2033 :2 0 2035
1224 2036 2010 2035
0 2037 1226 0
2038 1228 203b :3 0
203b 0 203b 203a
2038 2039 :6 0 203d
47 :3 0 122b 203f
122d 203e 203d :2 0
2040 122f :2 0 2042
0 2042 2041 1fef
2040 :6 0 2044 1
:3 0 1232 2046 1f68
1fde 0 2047 0
2044 0 2047 1234
0 2057 4d :3 0
a6 :3 0 4d :3 0
3a :2 0 1237 2049
204c 114 :2 0 a6
:3 0 52 :3 0 3a
:2 0 123a 204f 2052
123d 204e 2054 :3 0
2048 2055 0 2057
1240 2058 1f5f 2057
0 2059 1243 0
234b 70 :3 0 19d
:2 0 205a 205b 0
234b 71 :3 0 1f3
:3 0 22 :3 0 28
:3 0 4d :3 0 70
:3 0 4e :3 0 4c
:3 0 a6 :3 0 4f
:3 0 3a :2 0 1245
2065 2068 a6 :3 0
50 :3 0 3a :2 0
1248 206a 206d 124b
205e 206f 205d 2070
0 234b a6 :3 0
71 :3 0 3a :2 0
1254 2072 2075 10f
:2 0 3a :2 0 1259
2077 2079 :3 0 11
:3 0 22 :3 0 207b
207c 0 20a3 99
:3 0 9a :3 0 207e
207f 0 99 :3 0
ac :3 0 2081 2082
0 36 :2 0 2
:4 0 1f4 :2 0 ae
:2 0 36 :2 0 125c
2087 2089 :3 0 125f
2083 208b 2080 208d
208c :2 0 9c :3 0
af :3 0 208f 2090
0 9e :4 0 1f5
:4 0 a1 :2 0 a2
:3 0 1263 2094 2096
:3 0 1266 2091 2098
:2 0 209a 1269 209b
208e 209a 0 209c
126b 0 20a3 12
:3 0 105 :3 0 15e
:3 0 209e 209f 0
20a0 :2 0 20a3 162
:3 0 126d 231a 7f
:3 0 c9 :2 0 36
:2 0 1273 20a5 20a7
:3 0 90 :3 0 38
:3 0 36 :2 0 36
:2 0 1276 20a9 20ad
c9 :2 0 3a :4 0
127c 20af 20b1 :3 0
eb :3 0 1f6 :3 0
ec :3 0 22 :4 0
1f7 1 :8 0 2139
eb :3 0 1e9 :3 0
e9 :3 0 8a :3 0
140 :3 0 e9 :3 0
105 :3 0 1e6 :3 0
105 :3 0 1e7 :3 0
1f8 :3 0 a6 :3 0
128 :3 0 131 :3 0
1f9 :3 0 a6 :3 0
129 :3 0 132 :3 0
1f6 :3 0 1fa :3 0
ec :3 0 22 :4 0
1fb 1 :8 0 20e4
12c :4 0 20cf :3 0
12d :3 0 c9 :2 0
1281 20d2 20d3 :3 0
96 :3 0 bd :3 0
20d5 20d6 0 3a
:2 0 20d7 20d8 0
20da 1284 20e1 96
:3 0 bd :3 0 20db
20dc 0 12e :2 0
20dd 20de 0 20e0
1286 20e2 20d4 20da
0 20e3 0 20e0
0 20e3 1288 0
20e4 128b 2137 bf
:3 0 96 :3 0 bd
:3 0 20e6 20e7 0
be :3 0 20e8 20e9
0 20eb 128e 20ed
1290 20ec 20eb :2 0
2135 c0 :3 0 96
:3 0 bd :3 0 20f0
20f1 0 be :3 0
20f2 20f3 0 212d
99 :3 0 9a :3 0
20f5 20f6 0 99
:3 0 ac :3 0 20f8
20f9 0 c1 :2 0
2 :4 0 1fc :2 0
ae :2 0 36 :2 0
1292 20fe 2100 :3 0
1295 20fa 2102 20f7
2104 2103 :2 0 9c
:3 0 af :3 0 2106
2107 0 9e :4 0
1fd :4 0 a1 :2 0
a2 :3 0 1299 210b
210d :3 0 a1 :2 0
c4 :4 0 129c 210f
2111 :3 0 a1 :2 0
c5 :4 0 129f 2113
2115 :3 0 a1 :2 0
be :3 0 12a2 2117
2119 :3 0 a1 :2 0
c6 :4 0 12a5 211b
211d :3 0 a1 :2 0
90 :3 0 c7 :3 0
36 :2 0 c8 :2 0
12a8 2120 2124 12ac
211f 2126 :3 0 12af
2108 2128 :2 0 212a
12b2 212b 2105 212a
0 212c 12b4 0
212d 12b6 2130 :3 0
2130 0 2130 212f
212d 212e :6 0 2132
49 :3 0 12b9 2134
12bb 2133 2132 :2 0
2135 12bd :2 0 2137
0 2137 2136 20e4
2135 :6 0 2139 1
:3 0 12c0 21b2 eb
:3 0 1e9 :3 0 e9
:3 0 8a :3 0 140
:3 0 e9 :3 0 105
:3 0 1e6 :3 0 105
:3 0 1e7 :3 0 ec
:3 0 22 :4 0 1fe
1 :8 0 215c 12c
:4 0 2147 :3 0 12d
:3 0 c9 :2 0 12c5
214a 214b :3 0 96
:3 0 bd :3 0 214d
214e 0 3a :2 0
214f 2150 0 2152
12c8 2159 96 :3 0
bd :3 0 2153 2154
0 12e :2 0 2155
2156 0 2158 12ca
215a 214c 2152 0
215b 0 2158 0
215b 12cc 0 215c
12cf 21af bf :3 0
96 :3 0 bd :3 0
215e 215f 0 be
:3 0 2160 2161 0
2163 12d2 2165 12d4
2164 2163 :2 0 21ad
c0 :3 0 96 :3 0
bd :3 0 2168 2169
0 be :3 0 216a
216b 0 21a5 99
:3 0 9a :3 0 216d
216e 0 99 :3 0
ac :3 0 2170 2171
0 c1 :2 0 2
:4 0 1ff :2 0 ae
:2 0 36 :2 0 12d6
2176 2178 :3 0 12d9
2172 217a 216f 217c
217b :2 0 9c :3 0
af :3 0 217e 217f
0 9e :4 0 200
:4 0 a1 :2 0 a2
:3 0 12dd 2183 2185
:3 0 a1 :2 0 c4
:4 0 12e0 2187 2189
:3 0 a1 :2 0 c5
:4 0 12e3 218b 218d
:3 0 a1 :2 0 be
:3 0 12e6 218f 2191
:3 0 a1 :2 0 c6
:4 0 12e9 2193 2195
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 12ec
2198 219c 12f0 2197
219e :3 0 12f3 2180
21a0 :2 0 21a2 12f6
21a3 217d 21a2 0
21a4 12f8 0 21a5
12fa 21a8 :3 0 21a8
0 21a8 21a7 21a5
21a6 :6 0 21aa 4b
:3 0 12fd 21ac 12ff
21ab 21aa :2 0 21ad
1301 :2 0 21af 0
21af 21ae 215c 21ad
:6 0 21b1 1 :3 0
1304 21b3 20b2 2139
0 21b4 0 21b1
0 21b4 1306 0
2318 a6 :3 0 44
:3 0 3a :2 0 1309
21b5 21b8 10f :2 0
3a :2 0 130e 21ba
21bc :3 0 17f :2 0
1311 21be 21bf :3 0
17 :4 0 21c1 21c2
0 2315 157 :3 0
ec :3 0 17 :3 0
bb :3 0 b2 :3 0
eb :3 0 157 :3 0
b2 :3 0 b3 :3 0
20 :3 0 b2 :3 0
201 :3 0 157 :3 0
b9 :3 0 25 :3 0
157 :3 0 e8 :3 0
4a :3 0 157 :3 0
b8 :3 0 b2 :3 0
201 :3 0 157 :3 0
b6 :3 0 157 :3 0
d9 :4 0 202 1
:8 0 21e4 96 :3 0
bd :3 0 21df 21e0
0 be :3 0 21e1
21e2 0 21e4 1313
2237 bf :3 0 96
:3 0 bd :3 0 21e6
21e7 0 be :3 0
21e8 21e9 0 21eb
1316 21ed 1318 21ec
21eb :2 0 2235 c0
:3 0 96 :3 0 bd
:3 0 21f0 21f1 0
be :3 0 21f2 21f3
0 222d 99 :3 0
9a :3 0 21f5 21f6
0 99 :3 0 ac
:3 0 21f8 21f9 0
c1 :2 0 2 :4 0
203 :2 0 ae :2 0
36 :2 0 131a 21fe
2200 :3 0 131d 21fa
2202 21f7 2204 2203
:2 0 9c :3 0 af
:3 0 2206 2207 0
9e :4 0 204 :4 0
a1 :2 0 a2 :3 0
1321 220b 220d :3 0
a1 :2 0 c4 :4 0
1324 220f 2211 :3 0
a1 :2 0 c5 :4 0
1327 2213 2215 :3 0
a1 :2 0 be :3 0
132a 2217 2219 :3 0
a1 :2 0 c6 :4 0
132d 221b 221d :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 1330 2220
2224 1334 221f 2226
:3 0 1337 2208 2228
:2 0 222a 133a 222b
2205 222a 0 222c
133c 0 222d 133e
2230 :3 0 2230 0
2230 222f 222d 222e
:6 0 2232 4d :3 0
1341 2234 1343 2233
2232 :2 0 2235 1345
:2 0 2237 0 2237
2236 21e4 2235 :6 0
2315 1 :3 0 17
:3 0 113 :2 0 1348
223a 223b :3 0 223c
:2 0 a6 :3 0 131
:3 0 128 :3 0 28
:3 0 eb :3 0 ec
:3 0 22 :4 0 205
1 :8 0 224b 96
:3 0 bd :3 0 2246
2247 0 be :3 0
2248 2249 0 224b
134a 229e bf :3 0
96 :3 0 bd :3 0
224d 224e 0 be
:3 0 224f 2250 0
2252 134d 2254 134f
2253 2252 :2 0 229c
c0 :3 0 96 :3 0
bd :3 0 2257 2258
0 be :3 0 2259
225a 0 2294 99
:3 0 9a :3 0 225c
225d 0 99 :3 0
ac :3 0 225f 2260
0 c1 :2 0 2
:4 0 206 :2 0 ae
:2 0 36 :2 0 1351
2265 2267 :3 0 1354
2261 2269 225e 226b
226a :2 0 9c :3 0
af :3 0 226d 226e
0 9e :4 0 207
:4 0 a1 :2 0 a2
:3 0 1358 2272 2274
:3 0 a1 :2 0 c4
:4 0 135b 2276 2278
:3 0 a1 :2 0 c5
:4 0 135e 227a 227c
:3 0 a1 :2 0 be
:3 0 1361 227e 2280
:3 0 a1 :2 0 c6
:4 0 1364 2282 2284
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 1367
2287 228b 136b 2286
228d :3 0 136e 226f
228f :2 0 2291 1371
2292 226c 2291 0
2293 1373 0 2294
1375 2297 :3 0 2297
0 2297 2296 2294
2295 :6 0 2299 4f
:3 0 1378 229b 137a
229a 2299 :2 0 229c
137c :2 0 229e 0
229e 229d 224b 229c
:6 0 2312 1 :3 0
eb :3 0 f2 :3 0
28 :3 0 f3 :3 0
28 :3 0 ec :3 0
17 :4 0 208 1
:8 0 22bd 12c :4 0
22a8 :3 0 12d :3 0
c9 :2 0 1381 22ab
22ac :3 0 96 :3 0
bd :3 0 22ae 22af
0 3a :2 0 22b0
22b1 0 22b3 1384
22ba 96 :3 0 bd
:3 0 22b4 22b5 0
12e :2 0 22b6 22b7
0 22b9 1386 22bb
22ad 22b3 0 22bc
0 22b9 0 22bc
1388 0 22bd 138b
2310 bf :3 0 96
:3 0 bd :3 0 22bf
22c0 0 be :3 0
22c1 22c2 0 22c4
138e 22c6 1390 22c5
22c4 :2 0 230e c0
:3 0 96 :3 0 bd
:3 0 22c9 22ca 0
be :3 0 22cb 22cc
0 2306 99 :3 0
9a :3 0 22ce 22cf
0 99 :3 0 ac
:3 0 22d1 22d2 0
c1 :2 0 2 :4 0
209 :2 0 ae :2 0
36 :2 0 1392 22d7
22d9 :3 0 1395 22d3
22db 22d0 22dd 22dc
:2 0 9c :3 0 af
:3 0 22df 22e0 0
9e :4 0 20a :4 0
a1 :2 0 a2 :3 0
1399 22e4 22e6 :3 0
a1 :2 0 c4 :4 0
139c 22e8 22ea :3 0
a1 :2 0 c5 :4 0
139f 22ec 22ee :3 0
a1 :2 0 be :3 0
13a2 22f0 22f2 :3 0
a1 :2 0 c6 :4 0
13a5 22f4 22f6 :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 13a8 22f9
22fd 13ac 22f8 22ff
:3 0 13af 22e1 2301
:2 0 2303 13b2 2304
22de 2303 0 2305
13b4 0 2306 13b6
2309 :3 0 2309 0
2309 2308 2306 2307
:6 0 230b 51 :3 0
13b9 230d 13bb 230c
230b :2 0 230e 13bd
:2 0 2310 0 2310
230f 22bd 230e :6 0
2312 1 :3 0 13c0
2313 223d 2312 0
2314 13c3 0 2315
13c5 2316 21c0 2315
0 2317 13c9 0
2318 13cb 2319 20a8
2318 0 231b 207a
20a3 0 231b 13ce
0 234b 72 :3 0
17a :3 0 25 :3 0
13d1 231d 231f 231c
2320 0 234b 11
:3 0 22 :3 0 2322
2323 0 234b 99
:3 0 9a :3 0 2325
2326 0 99 :3 0
ac :3 0 2328 2329
0 36 :2 0 2
:4 0 20b :2 0 ae
:2 0 36 :2 0 13d3
232e 2330 :3 0 13d6
232a 2332 2327 2334
2333 :2 0 9c :3 0
af :3 0 2336 2337
0 9e :4 0 20c
:4 0 a1 :2 0 a2
:3 0 13da 233b 233d
:3 0 13dd 2338 233f
:2 0 2341 13e0 2342
2335 2341 0 2343
13e2 0 234b 12
:3 0 a6 :3 0 72
:3 0 3a :2 0 13e4
2345 2348 2349 :2 0
234b 13e7 234c 1f07
234b 0 234d 13f2
0 29d5 a6 :3 0
16 :3 0 3a :2 0
13f4 234e 2351 a6
:3 0 10f :2 0 52
:3 0 3a :2 0 13f7
2353 2357 13fc 2354
2359 :3 0 72 :3 0
3a :2 0 235b 235c
0 2868 142 :3 0
72 :3 0 11d :3 0
8e :3 0 167 :3 0
ec :3 0 22 :3 0
ec :3 0 8e :3 0
168 :3 0 105 :3 0
169 :4 0 20d 1
:8 0 2370 96 :3 0
bd :3 0 236b 236c
0 be :3 0 236d
236e 0 2370 13ff
23c3 bf :3 0 96
:3 0 bd :3 0 2372
2373 0 be :3 0
2374 2375 0 2377
1402 2379 1404 2378
2377 :2 0 23c1 c0
:3 0 96 :3 0 bd
:3 0 237c 237d 0
be :3 0 237e 237f
0 23b9 99 :3 0
9a :3 0 2381 2382
0 99 :3 0 ac
:3 0 2384 2385 0
c1 :2 0 2 :4 0
20e :2 0 ae :2 0
36 :2 0 1406 238a
238c :3 0 1409 2386
238e 2383 2390 238f
:2 0 9c :3 0 af
:3 0 2392 2393 0
9e :4 0 20f :4 0
a1 :2 0 a2 :3 0
140d 2397 2399 :3 0
a1 :2 0 c4 :4 0
1410 239b 239d :3 0
a1 :2 0 c5 :4 0
1413 239f 23a1 :3 0
a1 :2 0 be :3 0
1416 23a3 23a5 :3 0
a1 :2 0 c6 :4 0
1419 23a7 23a9 :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 141c 23ac
23b0 1420 23ab 23b2
:3 0 1423 2394 23b4
:2 0 23b6 1426 23b7
2391 23b6 0 23b8
1428 0 23b9 142a
23bc :3 0 23bc 0
23bc 23bb 23b9 23ba
:6 0 23be 53 :3 0
142d 23c0 142f 23bf
23be :2 0 23c1 1431
:2 0 23c3 0 23c3
23c2 2370 23c1 :6 0
2868 1 :3 0 a6
:3 0 72 :3 0 3a
:2 0 1434 23c5 23c8
10e :2 0 3a :2 0
1439 23ca 23cc :3 0
11 :3 0 22 :3 0
23ce 23cf 0 23f5
99 :3 0 9a :3 0
23d1 23d2 0 99
:3 0 ac :3 0 23d4
23d5 0 36 :2 0
2 :4 0 210 :2 0
ae :2 0 36 :2 0
143c 23da 23dc :3 0
143f 23d6 23de 23d3
23e0 23df :2 0 9c
:3 0 af :3 0 23e2
23e3 0 9e :4 0
211 :4 0 a1 :2 0
a2 :3 0 1443 23e7
23e9 :3 0 1446 23e4
23eb :2 0 23ed 1449
23ee 23e1 23ed 0
23ef 144b 0 23f5
12 :3 0 105 :3 0
10b :3 0 23f1 23f2
0 23f3 :2 0 23f5
144d 23f6 23cd 23f5
0 23f7 1451 0
2868 53 :3 0 a6
:3 0 16 :3 0 3a
:2 0 1453 23f9 23fc
23f8 23fd 0 2868
61 :3 0 a6 :3 0
4d :3 0 3a :2 0
1456 2400 2403 23ff
2404 0 2868 a6
:3 0 53 :3 0 3a
:2 0 1459 2406 2409
a6 :3 0 10e :2 0
4d :3 0 3a :2 0
145c 240b 240f 1461
240c 2411 :3 0 a6
:3 0 58 :3 0 3a
:2 0 1464 2413 2416
105 :3 0 c9 :2 0
13e :3 0 2418 241a
0 1469 2419 241c
:3 0 a6 :3 0 58
:3 0 3a :2 0 146c
241e 2421 105 :3 0
c9 :2 0 13d :3 0
2423 2425 0 1471
2424 2427 :3 0 241d
2429 2428 :2 0 3e
:4 0 242b 242c 0
2604 142 :3 0 88
:3 0 212 :3 0 88
:3 0 66 :3 0 3e
:3 0 143 :3 0 b9
:3 0 25 :3 0 ec
:3 0 22 :3 0 144
:4 0 213 1 :8 0
2440 96 :3 0 bd
:3 0 243b 243c 0
be :3 0 243d 243e
0 2440 1474 2493
bf :3 0 96 :3 0
bd :3 0 2442 2443
0 be :3 0 2444
2445 0 2447 1477
2449 1479 2448 2447
:2 0 2491 c0 :3 0
96 :3 0 bd :3 0
244c 244d 0 be
:3 0 244e 244f 0
2489 99 :3 0 9a
:3 0 2451 2452 0
99 :3 0 ac :3 0
2454 2455 0 c1
:2 0 2 :4 0 214
:2 0 ae :2 0 36
:2 0 147b 245a 245c
:3 0 147e 2456 245e
2453 2460 245f :2 0
9c :3 0 af :3 0
2462 2463 0 9e
:4 0 215 :4 0 a1
:2 0 a2 :3 0 1482
2467 2469 :3 0 a1
:2 0 c4 :4 0 1485
246b 246d :3 0 a1
:2 0 c5 :4 0 1488
246f 2471 :3 0 a1
:2 0 be :3 0 148b
2473 2475 :3 0 a1
:2 0 c6 :4 0 148e
2477 2479 :3 0 a1
:2 0 90 :3 0 c7
:3 0 36 :2 0 c8
:2 0 1491 247c 2480
1495 247b 2482 :3 0
1498 2464 2484 :2 0
2486 149b 2487 2461
2486 0 2488 149d
0 2489 149f 248c
:3 0 248c 0 248c
248b 2489 248a :6 0
248e 55 :3 0 14a2
2490 14a4 248f 248e
:2 0 2491 14a6 :2 0
2493 0 2493 2492
2440 2491 :6 0 2604
1 :3 0 3e :3 0
113 :2 0 14a9 2496
2497 :3 0 2498 :2 0
28 :3 0 3e :3 0
249a 249b 0 249d
14ab 249e 2499 249d
0 249f 14ad 0
2604 a6 :3 0 66
:3 0 3a :2 0 14af
24a0 24a3 10e :2 0
3a :2 0 14b4 24a5
24a7 :3 0 a6 :3 0
55 :3 0 3a :2 0
14b7 24a9 24ac 10e
:2 0 3a :2 0 14bc
24ae 24b0 :3 0 24b1
:2 0 3f :3 0 113
:2 0 14bf 24b4 24b5
:3 0 24b6 :2 0 24b7
:2 0 24b2 24b9 24b8
:2 0 216 :3 0 217
:3 0 56 :3 0 143
:3 0 b9 :3 0 25
:3 0 ec :3 0 22
:3 0 88 :3 0 8f
:3 0 90 :3 0 3f
:4 0 218 1 :8 0
24cd 96 :3 0 bd
:3 0 24c8 24c9 0
be :3 0 24ca 24cb
0 24cd 14c1 2520
bf :3 0 96 :3 0
bd :3 0 24cf 24d0
0 be :3 0 24d1
24d2 0 24d4 14c4
24d6 14c6 24d5 24d4
:2 0 251e c0 :3 0
96 :3 0 bd :3 0
24d9 24da 0 be
:3 0 24db 24dc 0
2516 99 :3 0 9a
:3 0 24de 24df 0
99 :3 0 ac :3 0
24e1 24e2 0 c1
:2 0 2 :4 0 219
:2 0 ae :2 0 36
:2 0 14c8 24e7 24e9
:3 0 14cb 24e3 24eb
24e0 24ed 24ec :2 0
9c :3 0 af :3 0
24ef 24f0 0 9e
:4 0 21a :4 0 a1
:2 0 a2 :3 0 14cf
24f4 24f6 :3 0 a1
:2 0 c4 :4 0 14d2
24f8 24fa :3 0 a1
:2 0 c5 :4 0 14d5
24fc 24fe :3 0 a1
:2 0 be :3 0 14d8
2500 2502 :3 0 a1
:2 0 c6 :4 0 14db
2504 2506 :3 0 a1
:2 0 90 :3 0 c7
:3 0 36 :2 0 c8
:2 0 14de 2509 250d
14e2 2508 250f :3 0
14e5 24f1 2511 :2 0
2513 14e8 2514 24ee
2513 0 2515 14ea
0 2516 14ec 2519
:3 0 2519 0 2519
2518 2516 2517 :6 0
251b 57 :3 0 14ef
251d 14f1 251c 251b
:2 0 251e 14f3 :2 0
2520 0 2520 251f
24cd 251e :6 0 2539
1 :3 0 4d :3 0
a6 :3 0 53 :3 0
3a :2 0 14f6 2523
2526 114 :2 0 a6
:3 0 52 :3 0 3a
:2 0 14f9 2529 252c
14fc 2528 252e :3 0
114 :2 0 a6 :3 0
56 :3 0 3a :2 0
14ff 2531 2534 1502
2530 2536 :3 0 2522
2537 0 2539 1505
254a 4d :3 0 a6
:3 0 53 :3 0 3a
:2 0 1508 253b 253e
114 :2 0 a6 :3 0
52 :3 0 3a :2 0
150b 2541 2544 150e
2540 2546 :3 0 253a
2547 0 2549 1511
254b 24ba 2539 0
254c 0 2549 0
254c 1513 0 2601
51 :3 0 21b :2 0
254d 254e 0 2601
56 :3 0 152 :3 0
a6 :3 0 21c :3 0
4d :3 0 1516 2553
2555 3a :2 0 1518
2552 2558 153 :2 0
a6 :3 0 21c :3 0
66 :3 0 151b 255c
255e 3a :2 0 151d
255b 2561 1520 255a
2563 :3 0 2564 :2 0
ae :2 0 1d9 :2 0
1523 2566 2568 :3 0
1526 2551 256a 2550
256b 0 2601 72
:3 0 a6 :3 0 56
:3 0 3a :2 0 1528
256e 2571 154 :2 0
a6 :3 0 66 :3 0
3a :2 0 152b 2574
2577 152e 2573 2579
:3 0 256d 257a 0
2601 a6 :3 0 72
:3 0 3a :2 0 1531
257c 257f a6 :3 0
10f :2 0 4d :3 0
3a :2 0 1534 2581
2585 1539 2582 2587
:3 0 57 :3 0 a6
:3 0 56 :3 0 3a
:2 0 153c 258a 258d
ae :2 0 a6 :3 0
4d :3 0 3a :2 0
153f 2590 2593 1542
258f 2595 :3 0 114
:2 0 a6 :3 0 72
:3 0 3a :2 0 1545
2598 259b 1548 2597
259d :3 0 2589 259e
0 25a0 154b 25a9
57 :3 0 a6 :3 0
56 :3 0 3a :2 0
154d 25a2 25a5 25a1
25a6 0 25a8 1550
25aa 2588 25a0 0
25ab 0 25a8 0
25ab 1552 0 2601
72 :3 0 1da :3 0
25 :3 0 23 :3 0
22 :3 0 28 :3 0
29 :3 0 57 :3 0
56 :3 0 3a :2 0
1555 25ad 25b6 25ac
25b7 0 2601 50
:3 0 152 :3 0 a6
:3 0 21c :3 0 56
:3 0 155e 25bc 25be
3a :2 0 1560 25bb
25c1 153 :2 0 a6
:3 0 21c :3 0 59
:3 0 1563 25c5 25c7
3a :2 0 1565 25c4
25ca 1568 25c3 25cc
:3 0 25cd :2 0 154
:2 0 1d8 :2 0 156b
25cf 25d1 :3 0 156e
25ba 25d3 25b9 25d4
0 2601 72 :3 0
13f :3 0 140 :3 0
25d7 25d8 0 a6
:3 0 50 :3 0 3a
:2 0 1570 25da 25dd
105 :3 0 141 :3 0
25df 25e0 0 1573
25d9 25e2 25d6 25e3
0 2601 72 :3 0
1dc :3 0 25 :3 0
22 :3 0 72 :3 0
a6 :3 0 59 :3 0
3a :2 0 1576 25ea
25ed a6 :3 0 50
:3 0 3a :2 0 1579
25ef 25f2 3a :2 0
157c 25e6 25f5 25e5
25f6 0 2601 72
:3 0 1ac :3 0 25
:3 0 4a :3 0 22
:3 0 3a :2 0 1583
25f9 25fe 25f8 25ff
0 2601 1588 2602
24a8 2601 0 2603
1593 0 2604 1595
27e4 51 :3 0 21b
:2 0 2605 2606 0
27e3 72 :3 0 a6
:3 0 4d :3 0 3a
:2 0 159a 2609 260c
2608 260d 0 27e3
71 :3 0 21d :3 0
25 :3 0 4a :3 0
4b :3 0 22 :3 0
3f :3 0 35 :3 0
4d :3 0 72 :3 0
61 :3 0 52 :3 0
51 :3 0 73 :3 0
76 :3 0 75 :3 0
77 :3 0 78 :3 0
7a :3 0 79 :3 0
7b :3 0 3c :3 0
3b :3 0 55 :3 0
4c :3 0 a6 :3 0
59 :3 0 3a :2 0
159d 2628 262b a6
:3 0 58 :3 0 3a
:2 0 15a0 262d 2630
15a3 2610 2632 260f
2633 0 27e3 52
:3 0 a6 :3 0 4d
:3 0 3a :2 0 15bd
2636 2639 2635 263a
0 27e3 4d :3 0
a6 :3 0 53 :3 0
3a :2 0 15c0 263d
2640 114 :2 0 a6
:3 0 52 :3 0 3a
:2 0 15c3 2643 2646
15c6 2642 2648 :3 0
263c 2649 0 27e3
8f :3 0 90 :3 0
29 :3 0 3f :3 0
11d :4 0 21e 1
:8 0 2656 96 :3 0
bd :3 0 2651 2652
0 be :3 0 2653
2654 0 2656 15c9
26a9 bf :3 0 96
:3 0 bd :3 0 2658
2659 0 be :3 0
265a 265b 0 265d
15cc 265f 15ce 265e
265d :2 0 26a7 c0
:3 0 96 :3 0 bd
:3 0 2662 2663 0
be :3 0 2664 2665
0 269f 99 :3 0
9a :3 0 2667 2668
0 99 :3 0 ac
:3 0 266a 266b 0
c1 :2 0 2 :4 0
21f :2 0 ae :2 0
36 :2 0 15d0 2670
2672 :3 0 15d3 266c
2674 2669 2676 2675
:2 0 9c :3 0 af
:3 0 2678 2679 0
9e :4 0 220 :4 0
a1 :2 0 a2 :3 0
15d7 267d 267f :3 0
a1 :2 0 c4 :4 0
15da 2681 2683 :3 0
a1 :2 0 c5 :4 0
15dd 2685 2687 :3 0
a1 :2 0 be :3 0
15e0 2689 268b :3 0
a1 :2 0 c6 :4 0
15e3 268d 268f :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 15e6 2692
2696 15ea 2691 2698
:3 0 15ed 267a 269a
:2 0 269c 15f0 269d
2677 269c 0 269e
15f2 0 269f 15f4
26a2 :3 0 26a2 0
26a2 26a1 269f 26a0
:6 0 26a4 59 :3 0
15f7 26a6 15f9 26a5
26a4 :2 0 26a7 15fb
:2 0 26a9 0 26a9
26a8 2656 26a7 :6 0
27e3 1 :3 0 86
:3 0 87 :3 0 8f
:3 0 90 :3 0 29
:3 0 86 :3 0 89
:3 0 28 :3 0 11d
:4 0 221 1 :8 0
26ba 96 :3 0 bd
:3 0 26b5 26b6 0
be :3 0 26b7 26b8
0 26ba 15fe 270d
bf :3 0 96 :3 0
bd :3 0 26bc 26bd
0 be :3 0 26be
26bf 0 26c1 1601
26c3 1603 26c2 26c1
:2 0 270b c0 :3 0
96 :3 0 bd :3 0
26c6 26c7 0 be
:3 0 26c8 26c9 0
2703 99 :3 0 9a
:3 0 26cb 26cc 0
99 :3 0 ac :3 0
26ce 26cf 0 c1
:2 0 2 :4 0 222
:2 0 ae :2 0 36
:2 0 1605 26d4 26d6
:3 0 1608 26d0 26d8
26cd 26da 26d9 :2 0
9c :3 0 af :3 0
26dc 26dd 0 9e
:4 0 223 :4 0 a1
:2 0 a2 :3 0 160c
26e1 26e3 :3 0 a1
:2 0 c4 :4 0 160f
26e5 26e7 :3 0 a1
:2 0 c5 :4 0 1612
26e9 26eb :3 0 a1
:2 0 be :3 0 1615
26ed 26ef :3 0 a1
:2 0 c6 :4 0 1618
26f1 26f3 :3 0 a1
:2 0 90 :3 0 c7
:3 0 36 :2 0 c8
:2 0 161b 26f6 26fa
161f 26f5 26fc :3 0
1622 26de 26fe :2 0
2700 1625 2701 26db
2700 0 2702 1627
0 2703 1629 2706
:3 0 2706 0 2706
2705 2703 2704 :6 0
2708 5b :3 0 162c
270a 162e 2709 2708
:2 0 270b 1630 :2 0
270d 0 270d 270c
26ba 270b :6 0 27e3
1 :3 0 eb :3 0
1e9 :3 0 e9 :3 0
8a :3 0 140 :3 0
e9 :3 0 105 :3 0
1e6 :3 0 da :3 0
53 :3 0 d6 :3 0
53 :3 0 fc :3 0
e7 :3 0 fd :3 0
fe :3 0 224 :3 0
ec :3 0 22 :4 0
225 1 :8 0 2738
12c :4 0 2723 :3 0
12d :3 0 c9 :2 0
1635 2726 2727 :3 0
96 :3 0 bd :3 0
2729 272a 0 3a
:2 0 272b 272c 0
272e 1638 2735 96
:3 0 bd :3 0 272f
2730 0 12e :2 0
2731 2732 0 2734
163a 2736 2728 272e
0 2737 0 2734
0 2737 163c 0
2738 163f 278b bf
:3 0 96 :3 0 bd
:3 0 273a 273b 0
be :3 0 273c 273d
0 273f 1642 2741
1644 2740 273f :2 0
2789 c0 :3 0 96
:3 0 bd :3 0 2744
2745 0 be :3 0
2746 2747 0 2781
99 :3 0 9a :3 0
2749 274a 0 99
:3 0 ac :3 0 274c
274d 0 c1 :2 0
2 :4 0 226 :2 0
ae :2 0 36 :2 0
1646 2752 2754 :3 0
1649 274e 2756 274b
2758 2757 :2 0 9c
:3 0 af :3 0 275a
275b 0 9e :4 0
227 :4 0 a1 :2 0
a2 :3 0 164d 275f
2761 :3 0 a1 :2 0
c4 :4 0 1650 2763
2765 :3 0 a1 :2 0
c5 :4 0 1653 2767
2769 :3 0 a1 :2 0
be :3 0 1656 276b
276d :3 0 a1 :2 0
c6 :4 0 1659 276f
2771 :3 0 a1 :2 0
90 :3 0 c7 :3 0
36 :2 0 c8 :2 0
165c 2774 2778 1660
2773 277a :3 0 1663
275c 277c :2 0 277e
1666 277f 2759 277e
0 2780 1668 0
2781 166a 2784 :3 0
2784 0 2784 2783
2781 2782 :6 0 2786
5d :3 0 166d 2788
166f 2787 2786 :2 0
2789 1671 :2 0 278b
0 278b 278a 2738
2789 :6 0 27e3 1
:3 0 96 :3 0 bd
:3 0 278d 278e 0
96 :3 0 c9 :2 0
183 :3 0 2790 2792
0 1676 2791 2794
:3 0 2795 :2 0 70
:3 0 19d :2 0 2797
2798 0 27e0 72
:3 0 1f3 :3 0 22
:3 0 28 :3 0 4d
:3 0 70 :3 0 4e
:3 0 4c :3 0 3a
:2 0 a6 :3 0 50
:3 0 3a :2 0 1679
27a3 27a6 167c 279b
27a8 279a 27a9 0
27e0 a6 :3 0 72
:3 0 3a :2 0 1685
27ab 27ae 10f :2 0
3a :2 0 168a 27b0
27b2 :3 0 11 :3 0
22 :3 0 27b4 27b5
0 27dd 99 :3 0
9a :3 0 27b7 27b8
0 99 :3 0 ac
:3 0 27ba 27bb 0
36 :2 0 2 :4 0
228 :2 0 ae :2 0
36 :2 0 168d 27c0
27c2 :3 0 1690 27bc
27c4 27b9 27c6 27c5
:2 0 9c :3 0 af
:3 0 27c8 27c9 0
9e :4 0 229 :4 0
a1 :2 0 a2 :3 0
1694 27cd 27cf :3 0
1697 27ca 27d1 :2 0
27d3 169a 27d4 27c7
27d3 0 27d5 169c
0 27dd 12 :3 0
a6 :3 0 72 :3 0
3a :2 0 169e 27d7
27da 27db :2 0 27dd
16a1 27de 27b3 27dd
0 27df 16a5 0
27e0 16a7 27e1 2796
27e0 0 27e2 16ab
0 27e3 16ad 27e5
242a 2604 0 27e6
0 27e3 0 27e6
16b7 0 27f1 4d
:3 0 a6 :3 0 53
:3 0 3a :2 0 16ba
27e8 27eb 27e7 27ec
0 27f1 55 :3 0
3a :2 0 27ee 27ef
0 27f1 16bd 2815
51 :3 0 152 :3 0
a6 :3 0 21c :3 0
53 :3 0 16c1 27f5
27f7 3a :2 0 16c3
27f4 27fa 153 :2 0
a6 :3 0 21c :3 0
4d :3 0 16c6 27fe
2800 3a :2 0 16c8
27fd 2803 16cb 27fc
2805 :3 0 2806 :2 0
154 :2 0 1d8 :2 0
16ce 2808 280a :3 0
280b :2 0 ae :2 0
1d9 :2 0 16d1 280d
280f :3 0 16d4 27f3
2811 27f2 2812 0
2814 16d6 2816 2412
27f1 0 2817 0
2814 0 2817 16d8
0 2868 72 :3 0
21d :3 0 25 :3 0
4a :3 0 4b :3 0
22 :3 0 3f :3 0
35 :3 0 4d :3 0
53 :3 0 61 :3 0
52 :3 0 51 :3 0
73 :3 0 76 :3 0
75 :3 0 77 :3 0
78 :3 0 7a :3 0
79 :3 0 7b :3 0
3c :3 0 3b :3 0
55 :3 0 4c :3 0
a6 :3 0 59 :3 0
3a :2 0 16db 2831
2834 a6 :3 0 58
:3 0 3a :2 0 16de
2836 2839 16e1 2819
283b 2818 283c 0
2868 11 :3 0 22
:3 0 283e 283f 0
2868 99 :3 0 9a
:3 0 2841 2842 0
99 :3 0 ac :3 0
2844 2845 0 36
:2 0 2 :4 0 22a
:2 0 ae :2 0 36
:2 0 16fb 284a 284c
:3 0 16fe 2846 284e
2843 2850 284f :2 0
9c :3 0 af :3 0
2852 2853 0 9e
:4 0 22b :4 0 a1
:2 0 a2 :3 0 1702
2857 2859 :3 0 1705
2854 285b :2 0 285d
1708 285e 2851 285d
0 285f 170a 0
2868 12 :3 0 a6
:3 0 72 :3 0 3a
:2 0 170c 2861 2864
2865 :2 0 2868 162
:3 0 170f 29a4 a6
:3 0 15 :3 0 3a
:2 0 171a 2869 286c
a6 :3 0 10f :2 0
51 :3 0 3a :2 0
171d 286e 2872 1722
286f 2874 :3 0 a6
:3 0 52 :3 0 3a
:2 0 1725 2876 2879
10e :2 0 3a :2 0
172a 287b 287d :3 0
287e :2 0 a6 :3 0
15 :3 0 3a :2 0
172d 2880 2883 c9
:2 0 3a :2 0 1732
2885 2887 :3 0 2888
:2 0 287f 288a 2889
:2 0 11 :3 0 22
:3 0 288c 288d 0
28b3 99 :3 0 9a
:3 0 288f 2890 0
99 :3 0 ac :3 0
2892 2893 0 36
:2 0 2 :4 0 22c
:2 0 ae :2 0 36
:2 0 1735 2898 289a
:3 0 1738 2894 289c
2891 289e 289d :2 0
9c :3 0 af :3 0
28a0 28a1 0 9e
:4 0 22d :4 0 a1
:2 0 a2 :3 0 173c
28a5 28a7 :3 0 173f
28a2 28a9 :2 0 28ab
1742 28ac 289f 28ab
0 28ad 1744 0
28b3 12 :3 0 96
:3 0 bd :3 0 28af
28b0 0 28b1 :2 0
28b3 1746 28b4 288b
28b3 0 28b5 174a
0 29a2 eb :3 0
e7 :3 0 15 :3 0
e9 :3 0 8a :3 0
140 :3 0 e9 :3 0
105 :3 0 22e :3 0
ec :3 0 22 :4 0
22f 1 :8 0 28d7
12c :4 0 28c2 :3 0
12d :3 0 c9 :2 0
174e 28c5 28c6 :3 0
96 :3 0 bd :3 0
28c8 28c9 0 3a
:2 0 28ca 28cb 0
28cd 1751 28d4 96
:3 0 bd :3 0 28ce
28cf 0 12e :2 0
28d0 28d1 0 28d3
1753 28d5 28c7 28cd
0 28d6 0 28d3
0 28d6 1755 0
28d7 1758 292a bf
:3 0 96 :3 0 bd
:3 0 28d9 28da 0
be :3 0 28db 28dc
0 28de 175b 28e0
175d 28df 28de :2 0
2928 c0 :3 0 96
:3 0 bd :3 0 28e3
28e4 0 be :3 0
28e5 28e6 0 2920
99 :3 0 9a :3 0
28e8 28e9 0 99
:3 0 ac :3 0 28eb
28ec 0 c1 :2 0
2 :4 0 230 :2 0
ae :2 0 36 :2 0
175f 28f1 28f3 :3 0
1762 28ed 28f5 28ea
28f7 28f6 :2 0 9c
:3 0 af :3 0 28f9
28fa 0 9e :4 0
231 :4 0 a1 :2 0
a2 :3 0 1766 28fe
2900 :3 0 a1 :2 0
c4 :4 0 1769 2902
2904 :3 0 a1 :2 0
c5 :4 0 176c 2906
2908 :3 0 a1 :2 0
be :3 0 176f 290a
290c :3 0 a1 :2 0
c6 :4 0 1772 290e
2910 :3 0 a1 :2 0
90 :3 0 c7 :3 0
36 :2 0 c8 :2 0
1775 2913 2917 1779
2912 2919 :3 0 177c
28fb 291b :2 0 291d
177f 291e 28f8 291d
0 291f 1781 0
2920 1783 2923 :3 0
2923 0 2923 2922
2920 2921 :6 0 2925
5f :3 0 1786 2927
1788 2926 2925 :2 0
2928 178a :2 0 292a
0 292a 2929 28d7
2928 :6 0 29a2 1
:3 0 ff :3 0 e9
:3 0 8a :3 0 140
:3 0 e9 :3 0 105
:3 0 22e :3 0 b9
:3 0 25 :3 0 8e
:3 0 4a :4 0 232
1 :8 0 294d 12c
:4 0 2938 :3 0 12d
:3 0 c9 :2 0 178f
293b 293c :3 0 96
:3 0 bd :3 0 293e
293f 0 3a :2 0
2940 2941 0 2943
1792 294a 96 :3 0
bd :3 0 2944 2945
0 12e :2 0 2946
2947 0 2949 1794
294b 293d 2943 0
294c 0 2949 0
294c 1796 0 294d
1799 29a0 bf :3 0
96 :3 0 bd :3 0
294f 2950 0 be
:3 0 2951 2952 0
2954 179c 2956 179e
2955 2954 :2 0 299e
c0 :3 0 96 :3 0
bd :3 0 2959 295a
0 be :3 0 295b
295c 0 2996 99
:3 0 9a :3 0 295e
295f 0 99 :3 0
ac :3 0 2961 2962
0 c1 :2 0 2
:4 0 233 :2 0 ae
:2 0 36 :2 0 17a0
2967 2969 :3 0 17a3
2963 296b 2960 296d
296c :2 0 9c :3 0
af :3 0 296f 2970
0 9e :4 0 234
:4 0 a1 :2 0 a2
:3 0 17a7 2974 2976
:3 0 a1 :2 0 c4
:4 0 17aa 2978 297a
:3 0 a1 :2 0 c5
:4 0 17ad 297c 297e
:3 0 a1 :2 0 be
:3 0 17b0 2980 2982
:3 0 a1 :2 0 c6
:4 0 17b3 2984 2986
:3 0 a1 :2 0 90
:3 0 c7 :3 0 36
:2 0 c8 :2 0 17b6
2989 298d 17ba 2988
298f :3 0 17bd 2971
2991 :2 0 2993 17c0
2994 296e 2993 0
2995 17c2 0 2996
17c4 2999 :3 0 2999
0 2999 2998 2996
2997 :6 0 299b 61
:3 0 17c7 299d 17c9
299c 299b :2 0 299e
17cb :2 0 29a0 0
29a0 299f 294d 299e
:6 0 29a2 1 :3 0
17ce 29a3 2875 29a2
0 29a5 235a 2868
0 29a5 17d2 0
29d5 72 :3 0 17a
:3 0 25 :3 0 17d5
29a7 29a9 29a6 29aa
0 29d5 11 :3 0
22 :3 0 29ac 29ad
0 29d5 99 :3 0
9a :3 0 29af 29b0
0 99 :3 0 ac
:3 0 29b2 29b3 0
36 :2 0 2 :4 0
235 :2 0 ae :2 0
36 :2 0 17d7 29b8
29ba :3 0 17da 29b4
29bc 29b1 29be 29bd
:2 0 9c :3 0 af
:3 0 29c0 29c1 0
9e :4 0 236 :4 0
a1 :2 0 a2 :3 0
17de 29c5 29c7 :3 0
17e1 29c2 29c9 :2 0
29cb 17e4 29cc 29bf
29cb 0 29cd 17e6
0 29d5 12 :3 0
a6 :3 0 72 :3 0
3a :2 0 17e8 29cf
29d2 29d3 :2 0 29d5
17eb 29d6 10fa 29d5
0 2ac6 b2 :3 0
237 :3 0 b2 :3 0
b4 :3 0 b2 :3 0
8e :3 0 b2 :3 0
b5 :3 0 b2 :3 0
b6 :3 0 b2 :3 0
b7 :3 0 b2 :3 0
b8 :3 0 b2 :3 0
b9 :3 0 b2 :3 0
ba :3 0 19 :3 0
43 :3 0 1a :3 0
41 :3 0 44 :3 0
49 :3 0 1b :3 0
25 :3 0 48 :3 0
bb :3 0 b2 :3 0
b2 :3 0 b3 :3 0
20 :4 0 238 1
:8 0 29fd 96 :3 0
bd :3 0 29f8 29f9
0 be :3 0 29fa
29fb 0 29fd 17fc
2a50 bf :3 0 96
:3 0 bd :3 0 29ff
2a00 0 be :3 0
2a01 2a02 0 2a04
17ff 2a06 1801 2a05
2a04 :2 0 2a4e c0
:3 0 96 :3 0 bd
:3 0 2a09 2a0a 0
be :3 0 2a0b 2a0c
0 2a46 99 :3 0
9a :3 0 2a0e 2a0f
0 99 :3 0 ac
:3 0 2a11 2a12 0
c1 :2 0 2 :4 0
239 :2 0 ae :2 0
36 :2 0 1803 2a17
2a19 :3 0 1806 2a13
2a1b 2a10 2a1d 2a1c
:2 0 9c :3 0 af
:3 0 2a1f 2a20 0
9e :4 0 23a :4 0
a1 :2 0 a2 :3 0
180a 2a24 2a26 :3 0
a1 :2 0 c4 :4 0
180d 2a28 2a2a :3 0
a1 :2 0 c5 :4 0
1810 2a2c 2a2e :3 0
a1 :2 0 be :3 0
1813 2a30 2a32 :3 0
a1 :2 0 c6 :4 0
1816 2a34 2a36 :3 0
a1 :2 0 90 :3 0
c7 :3 0 36 :2 0
c8 :2 0 1819 2a39
2a3d 181d 2a38 2a3f
:3 0 1820 2a21 2a41
:2 0 2a43 1823 2a44
2a1e 2a43 0 2a45
1825 0 2a46 1827
2a49 :3 0 2a49 0
2a49 2a48 2a46 2a47
:6 0 2a4b 63 :3 0
182a 2a4d 182c 2a4c
2a4b :2 0 2a4e 182e
:2 0 2a50 0 2a50
2a4f 29fd 2a4e :6 0
2ac3 1 :3 0 96
:3 0 bd :3 0 2a52
2a53 0 96 :3 0
c9 :2 0 183 :3 0
2a55 2a57 0 1833
2a56 2a59 :3 0 2a5a
:2 0 17f :2 0 1836
2a5c 2a5d :3 0 11
:3 0 20 :3 0 2a5f
2a60 0 2a86 99
:3 0 9a :3 0 2a62
2a63 0 99 :3 0
ac :3 0 2a65 2a66
0 36 :2 0 2
:4 0 23b :2 0 ae
:2 0 36 :2 0 1838
2a6b 2a6d :3 0 183b
2a67 2a6f 2a64 2a71
2a70 :2 0 9c :3 0
af :3 0 2a73 2a74
0 9e :4 0 23c
:4 0 a1 :2 0 a2
:3 0 183f 2a78 2a7a
:3 0 1842 2a75 2a7c
:2 0 2a7e 1845 2a7f
2a72 2a7e 0 2a80
1847 0 2a86 12
:3 0 105 :3 0 106
:3 0 2a82 2a83 0
2a84 :2 0 2a86 1849
2a87 2a5e 2a86 0
2a88 184d 0 2ac3
86 :3 0 19b :3 0
2a89 2a8a 0 21
:3 0 19 :3 0 184f
2a8b 2a8e c9 :2 0
3a :2 0 1854 2a90
2a92 :3 0 96 :3 0
bd :3 0 2a94 2a95
0 3a :2 0 2a96
2a97 0 2ac0 11
:3 0 20 :3 0 2a99
2a9a 0 2ac0 99
:3 0 9a :3 0 2a9c
2a9d 0 99 :3 0
ac :3 0 2a9f 2aa0
0 36 :2 0 2
:4 0 23d :2 0 ae
:2 0 36 :2 0 1857
2aa5 2aa7 :3 0 185a
2aa1 2aa9 2a9e 2aab
2aaa :2 0 9c :3 0
af :3 0 2aad 2aae
0 9e :4 0 23e
:4 0 a1 :2 0 a2
:3 0 185e 2ab2 2ab4
:3 0 1861 2aaf 2ab6
:2 0 2ab8 1864 2ab9
2aac 2ab8 0 2aba
1866 0 2ac0 12
:3 0 96 :3 0 bd
:3 0 2abc 2abd 0
2abe :2 0 2ac0 1868
2ac1 2a93 2ac0 0
2ac2 186d 0 2ac3
186f 2ac5 52d 10ee
0 2ac6 0 2ac3
0 2ac6 1873 0
2ac7 1877 2ac8 473
2ac7 0 2ac9 187a
0 2b3c 22 :3 0
3 :3 0 2aca 2acb
0 2b3c 21 :3 0
7 :3 0 2acd 2ace
0 2b3c 4c :3 0
10 :3 0 2ad0 2ad1
0 2b3c 48 :3 0
105 :3 0 23f :3 0
2ad4 2ad5 0 2ad3
2ad6 0 2b3c 96
:3 0 bd :3 0 2ad8
2ad9 0 240 :3 0
48 :3 0 22 :3 0
21 :3 0 4c :3 0
187c 2adb 2ae0 2ada
2ae1 0 2b3c 11
:3 0 22 :3 0 2ae3
2ae4 0 2b3c 99
:3 0 9a :3 0 2ae6
2ae7 0 99 :3 0
ac :3 0 2ae9 2aea
0 36 :2 0 2
:4 0 241 :2 0 ae
:2 0 36 :2 0 1881
2aef 2af1 :3 0 1884
2aeb 2af3 2ae8 2af5
2af4 :2 0 9c :3 0
af :3 0 2af7 2af8
0 9e :4 0 242
:4 0 a1 :2 0 a2
:3 0 1888 2afc 2afe
:3 0 188b 2af9 2b00
:2 0 2b02 188e 2b03
2af6 2b02 0 2b04
1890 0 2b3c 12
:3 0 96 :3 0 bd
:3 0 2b06 2b07 0
2b08 :2 0 2b3c 99
:3 0 9a :3 0 2b0a
2b0b 0 99 :3 0
ac :3 0 2b0d 2b0e
0 36 :2 0 2
:4 0 243 :2 0 ae
:2 0 36 :2 0 1892
2b13 2b15 :3 0 1895
2b0f 2b17 2b0c 2b19
2b18 :2 0 9c :3 0
af :3 0 2b1b 2b1c
0 9e :4 0 244
:4 0 a1 :2 0 a2
:3 0 1899 2b20 2b22
:3 0 a1 :2 0 c4
:4 0 189c 2b24 2b26
:3 0 a1 :2 0 245
:4 0 189f 2b28 2b2a
:3 0 a1 :2 0 96
:3 0 bd :3 0 2b2d
2b2e 0 18a2 2b2c
2b30 :3 0 18a5 2b1d
2b32 :2 0 2b34 18a8
2b35 2b1a 2b34 0
2b36 18aa 0 2b3c
12 :3 0 96 :3 0
bd :3 0 2b38 2b39
0 2b3a :2 0 2b3c
18ac 2b3f :3 0 2b3f
18c0 2b3f 2b3e 2b3c
2b3d :6 0 2b40 :2 0
2 3a 2b3f 2b43
:3 0 2b42 2b40 2b44
:8 0 
192d
4
:3 0 1 3 1
9 1 f 1
15 1 1b 1
1f 1 23 1
27 1 2b 1
31 a 8 e
14 1a 1e 22
26 2a 30 36
1 3c 1 42
1 48 1 4e
1 56 1 54
1 5d 1 5b
1 64 1 62
1 6b 1 69
1 72 1 70
1 79 1 77
1 80 1 7e
1 87 1 85
1 8e 1 8c
1 95 1 93
1 9c 1 9a
1 a3 1 a1
1 aa 1 a8
1 b1 1 af
1 b6 1 bb
1 c0 1 c5
1 ca 1 cf
1 d4 1 d9
1 de 1 e3
1 e8 1 ed
1 f2 1 f9
1 f7 1 100
1 fe 1 107
1 105 1 10c
1 112 1 118
1 11e 1 124
1 129 1 12e
1 134 1 13a
1 140 1 146
1 14c 1 152
1 158 1 15e
1 164 1 16c
1 16a 1 173
1 171 1 17a
1 178 1 17f
1 185 1 18b
1 191 1 197
1 19d 1 1a3
1 1a9 1 1af
1 1b5 1 1bb
1 1c1 1 1c7
1 1cd 1 1d3
1 1d9 1 1df
1 1e5 1 1eb
1 1f1 1 1f7
1 1fd 1 203
1 209 1 20f
1 215 1 21b
1 221 1 227
1 22d 1 235
1 233 1 23c
1 23a 1 241
1 249 1 247
1 24e 1 254
1 25a 1 260
1 266 1 26c
1 272 1 278
1 27e 1 284
1 28a 1 292
1 290 1 297
1 29c 1 2a1
1 2a6 1 2ab
1 2c6 1 2e1
1 2e7 1 2ee
1 2fb 1 307
2 30a 30c 2
30f 311 2 313
315 2 317 319
2 31b 31d 2
31f 321 2 323
325 2 327 329
2 32b 32d 2
333 335 2 337
339 2 33b 33c
2 33e 33f 2
32f 341 2 343
345 2 34b 34d
2 34f 351 2
353 354 2 356
357 2 347 359
2 35b 35d 1
363 2 365 366
2 35f 368 2
36a 36c 1 372
2 374 375 2
36e 377 2 379
37b 1 381 2
383 384 2 37d
386 2 388 38a
1 390 2 392
393 2 38c 395
2 397 399 2
39b 39d 2 39f
3a1 2 3a3 3a5
2 3a7 3a9 2
3ab 3ad 2 3af
3b1 2 3b3 3b5
2 3b7 3b9 4
303 309 30e 3bb
1 3bd 1 3bf
2 3c9 3cb 3
3c7 3c8 3cd 2
3d6 3d8 2 3d5
3da 1 3dc 1
3de 2 40f 414
1 41b 1 416
2 42e 430 3
42c 42d 432 2
43b 43d 2 43f
441 2 443 445
2 447 449 2
44b 44d 3 452
453 454 2 44f
456 2 43a 458
1 45a 1 45c
2 425 45d 1
461 1 420 2
41e 465 1 470
2 46c 470 2
4c9 4ce 1 4d5
1 4d0 2 4e8
4ea 3 4e6 4e7
4ec 2 4f5 4f7
2 4f9 4fb 2
4fd 4ff 2 501
503 2 505 507
3 50c 50d 50e
2 509 510 2
4f4 512 1 514
1 516 2 4df
517 1 51b 1
4da 2 4d8 51f
1 52a 2 526
52a 2 552 557
1 55e 1 559
2 571 573 3
56f 570 575 2
57e 580 2 582
584 2 586 588
2 58a 58c 2
58e 590 3 595
596 597 2 592
599 2 57d 59b
1 59d 1 59f
2 568 5a0 1
5a4 1 563 2
561 5a8 1 5b3
2 5af 5b3 2
5c2 5c4 3 5c0
5c1 5c6 2 5cf
5d1 2 5ce 5d3
1 5d5 1 5d7
3 5b9 5d8 5dd
1 5df 2 5e3
5e4 2 5e6 5e9
1 5f0 2 5ec
5f0 2 5fe 600
3 5fc 5fd 602
2 60b 60d 2
60a 60f 1 611
1 613 3 5f5
614 619 1 61b
3 626 627 628
1 62c 2 62a
62c 3 633 634
635 1 639 2
637 639 2 64a
64c 3 648 649
64e 2 657 659
2 656 65b 1
65d 1 65f 3
641 660 665 1
667 1 669 2
670 671 2 676
677 2 673 679
2 67f 680 1
682 2 67c 682
2 693 695 3
691 692 697 2
6a0 6a2 2 69f
6a4 1 6a6 1
6a8 3 68a 6a9
6ae 1 6b0 3
6b5 6b6 6b7 1
6bb 2 6b9 6bb
3 6c2 6c3 6c4
1 6c8 2 6c6
6c8 2 6cf 6d0
1 6d4 2 6d2
6d4 2 6df 6e1
3 6dd 6de 6e3
2 6ec 6ee 2
6eb 6f0 1 6f2
1 6f4 2 6f5
6f8 1 6fa 2
6fd 6fe 1 702
2 700 702 3
708 709 70a 1
70e 2 70c 70e
2 721 726 1
72d 1 728 2
740 742 3 73e
73f 744 2 74d
74f 2 751 753
2 755 757 2
759 75b 2 75d
75f 3 764 765
766 2 761 768
2 74c 76a 1
76c 1 76e 2
737 76f 1 773
1 732 2 730
777 1 782 2
77e 782 2 78f
794 1 79b 1
796 2 7ae 7b0
3 7ac 7ad 7b2
2 7bb 7bd 2
7bf 7c1 2 7c3
7c5 2 7c7 7c9
2 7cb 7cd 3
7d2 7d3 7d4 2
7cf 7d6 2 7ba
7d8 1 7da 1
7dc 2 7a5 7dd
1 7e1 1 7a0
2 79e 7e5 1
7e8 1 7eb 3
7f0 7f1 7f2 1
7f6 2 7f4 7f6
1 7fb 1 7fd
3 77a 7ec 7fe
2 810 815 1
81c 1 817 2
82f 831 3 82d
82e 833 2 83c
83e 2 840 842
2 844 846 2
848 84a 2 84c
84e 3 853 854
855 2 850 857
2 83b 859 1
85b 1 85d 2
826 85e 1 862
1 821 2 81f
866 1 871 2
86d 871 2 87e
883 1 88a 1
885 2 89d 89f
3 89b 89c 8a1
2 8aa 8ac 2
8ae 8b0 2 8b2
8b4 2 8b6 8b8
2 8ba 8bc 3
8c1 8c2 8c3 2
8be 8c5 2 8a9
8c7 1 8c9 1
8cb 2 894 8cc
1 8d0 1 88f
2 88d 8d4 1
8d7 1 8da 3
869 8db 8de 2
8e0 8e1 2 8e4
8e5 1 8eb 2
8e7 8eb 1 8fa
2 8f9 8fa 1
902 1 908 2
90a 90b 2 8f7
90c 1 913 1
90e 2 926 928
3 924 925 92a
2 933 935 2
937 939 2 93b
93d 2 93f 941
2 943 945 3
94a 94b 94c 2
947 94e 2 932
950 1 952 1
954 2 91d 955
1 959 1 918
2 916 95d 1
960 1 96f 2
96e 96f 1 977
1 97d 2 97f
980 2 96c 981
1 988 1 983
2 99b 99d 3
999 99a 99f 2
9a8 9aa 2 9ac
9ae 2 9b0 9b2
2 9b4 9b6 2
9b8 9ba 3 9bf
9c0 9c1 2 9bc
9c3 2 9a7 9c5
1 9c7 1 9c9
2 992 9ca 1
9ce 1 98d 2
98b 9d2 1 9d5
2 9d8 9d9 2
8e2 9da 3 9e5
9e6 9e7 1 9eb
2 9e9 9eb 1
9fe 1 a04 2
a06 a07 1 a0f
2 a0b a0f 2
a1c a21 1 a28
1 a23 2 a3b
a3d 3 a39 a3a
a3f 2 a48 a4a
2 a4c a4e 2
a50 a52 2 a54
a56 2 a58 a5a
3 a5f a60 a61
2 a5c a63 2
a47 a65 1 a67
1 a69 2 a32
a6a 1 a6e 1
a2d 2 a2b a72
1 a75 1 a78
2 a7c a82 1
a89 1 a84 2
a9c a9e 3 a9a
a9b aa0 2 aa9
aab 2 aad aaf
2 ab1 ab3 2
ab5 ab7 2 ab9
abb 3 ac0 ac1
ac2 2 abd ac4
2 aa8 ac6 1
ac8 1 aca 2
a93 acb 1 acf
1 a8e 2 a8c
ad3 2 ad9 ada
1 ae0 2 adc
ae0 2 ae4 ae5
1 aeb 2 ae7
aeb 2 af8 af9
2 afb afe 3
af2 b01 b04 1
b06 6 9f0 9f5
a08 a79 ad6 b07
2 b0a b0b 1
b0f 2 b0d b0f
2 b22 b27 1
b2e 1 b29 2
b41 b43 3 b3f
b40 b45 2 b4e
b50 2 b52 b54
2 b56 b58 2
b5a b5c 2 b5e
b60 3 b65 b66
b67 2 b62 b69
2 b4d b6b 1
b6d 1 b6f 2
b38 b70 1 b74
1 b33 2 b31
b78 2 b7e b7f
1 b83 2 b81
b83 2 b94 b99
1 ba0 1 b9b
2 bb3 bb5 3
bb1 bb2 bb7 2
bc0 bc2 2 bc4
bc6 2 bc8 bca
2 bcc bce 2
bd0 bd2 3 bd7
bd8 bd9 2 bd4
bdb 2 bbf bdd
1 bdf 1 be1
2 baa be2 1
be6 1 ba5 2
ba3 bea 1 bed
1 bf0 2 bf3
bf4 1 bf8 2
bf6 bf8 2 c06
c08 3 c04 c05
c0a 2 c13 c15
2 c12 c17 1
c19 1 c1b 3
bfd c1c c21 1
c23 4 b14 b7b
bf1 c24 1 c26
1 c38 1 c3e
2 c40 c41 1
c49 2 c45 c49
2 c56 c5b 1
c62 1 c5d 2
c75 c77 3 c73
c74 c79 2 c82
c84 2 c86 c88
2 c8a c8c 2
c8e c90 2 c92
c94 3 c99 c9a
c9b 2 c96 c9d
2 c81 c9f 1
ca1 1 ca3 2
c6c ca4 1 ca8
1 c67 2 c65
cac 1 caf 1
cb2 2 cb6 cbc
1 cc3 1 cbe
2 cd6 cd8 3
cd4 cd5 cda 2
ce3 ce5 2 ce7
ce9 2 ceb ced
2 cef cf1 2
cf3 cf5 3 cfa
cfb cfc 2 cf7
cfe 2 ce2 d00
1 d02 1 d04
2 ccd d05 1
d09 1 cc8 2
cc6 d0d 2 d13
d14 1 d18 2
d16 d18 2 d1c
d1d 1 d23 2
d1f d23 2 d27
d28 1 d2e 2
d2a d2e 2 d37
d38 1 d3e 2
d3a d3e 2 d42
d43 1 d49 2
d45 d49 2 d51
d52 2 d57 d58
2 d54 d5a 1
d5c 2 d61 d62
2 d67 d68 2
d64 d6a 2 d70
d71 1 d73 2
d6d d73 2 d78
d79 2 d7b d7d
1 d80 1 d82
2 d5f d83 1
d85 3 d86 d89
d8c 1 d8e 7
c27 c2a c2f c42
cb3 d10 d8f 2
d91 d92 2 d95
d96 1 d9a 2
d98 d9a 1 d9f
2 d9d d9f 2
da6 da7 1 dad
2 da9 dad 2
db1 db2 1 db8
2 db4 db8 5
dc2 dc3 dc4 dc5
dc6 1 dc9 1
dcb 2 df4 df9
1 e00 1 dfb
2 e13 e15 3
e11 e12 e17 2
e20 e22 2 e24
e26 2 e28 e2a
2 e2c e2e 2
e30 e32 3 e37
e38 e39 2 e34
e3b 2 e1f e3d
1 e3f 1 e41
2 e0a e42 1
e46 1 e05 2
e03 e4a 2 e50
e51 1 e55 2
e53 e55 2 e63
e65 3 e61 e62
e67 2 e70 e72
2 e6f e74 1
e76 1 e78 3
e5a e79 e7e 1
e80 2 e8f e90
c e84 e85 e86
e87 e88 e89 e8a
e8b e8c e8d e92
e93 2 e98 e99
1 e9d 2 e9b
e9d 2 eab ead
3 ea9 eaa eaf
2 eb8 eba 2
eb7 ebc 1 ebe
1 ec0 2 ec4
ec5 3 ea2 ec1
ec8 1 eca 9
9de 9e1 d93 dcc
dcf e4d e81 e96
ecb 2 ecd ece
2 6fb ecf 2
ed3 ed4 2 ed9
eda 1 edc 2
ed6 edc 2 ee1
ee2 1 ee6 2
ee4 ee6 2 ef0
ef1 2 ef6 ef7
1 ef9 2 ef3
ef9 2 f07 f09
3 f05 f06 f0b
2 f14 f16 2
f13 f18 1 f1a
1 f1c 3 efe
f1d f22 2 f26
f27 2 f2c f2d
1 f2f 2 f29
f2f 1 f34 2
f37 f36 2 f54
f59 1 f60 1
f5b 2 f73 f75
3 f71 f72 f77
2 f80 f82 2
f84 f86 2 f88
f8a 2 f8c f8e
2 f90 f92 3
f97 f98 f99 2
f94 f9b 2 f7f
f9d 1 f9f 1
fa1 2 f6a fa2
1 fa6 1 f65
2 f63 faa 2
fb0 fb1 1 fb5
2 fb3 fb5 2
fc3 fc5 3 fc1
fc2 fc7 2 fd0
fd2 2 fcf fd4
1 fd6 1 fd8
3 fba fd9 fde
1 fe0 2 1001
1006 1 100d 1
1008 2 1020 1022
3 101e 101f 1024
2 102d 102f 2
1031 1033 2 1035
1037 2 1039 103b
2 103d 103f 3
1044 1045 1046 2
1041 1048 2 102c
104a 1 104c 1
104e 2 1017 104f
1 1053 1 1012
2 1010 1057 2
105d 105e 1 1062
2 1060 1062 2
1070 1072 3 106e
106f 1074 2 107d
107f 2 107c 1081
1 1083 1 1085
3 1067 1086 108b
1 108d 2 1091
1092 2 109d 109e
2 10a2 10a3 2
10a7 10a8 7 1098
1099 109a 109b 10a0
10a5 10aa a eee
f38 f3b fad fe1
fe4 105a 108e 1095
10ad 2 10b0 10af
2 10b3 10b4 1
10b8 2 10b6 10b8
1 10bd 1 10c0
1 10c2 2 10cf
10d1 3 10cd 10ce
10d3 2 10dc 10de
2 10db 10e0 1
10e2 1 10e4 2
10e8 10e9 c 5ab
5e0 61c 61f 622
668 6b1 10b1 10c3
10c6 10e5 10ec 1
10ef 1 10f4 3
1104 1105 1106 1
110a 2 1108 110a
3 1111 1112 1113
1 1117 2 1115
1117 2 1128 112a
3 1126 1127 112c
2 1135 1137 2
1134 1139 1 113b
1 113d 3 111f
113e 1143 1 1145
1 1147 2 114d
114e 1 1152 2
1150 1152 1 1154
2 1163 1168 1
116f 1 116a 2
1182 1184 3 1180
1181 1186 2 118f
1191 2 1193 1195
2 1197 1199 2
119b 119d 2 119f
11a1 3 11a6 11a7
11a8 2 11a3 11aa
2 118e 11ac 1
11ae 1 11b0 2
1179 11b1 1 11b5
1 1174 2 1172
11b9 1 11c4 2
11c0 11c4 2 11d3
11d5 3 11d1 11d2
11d7 2 11e0 11e2
2 11df 11e4 1
11e6 1 11e8 3
11ca 11e9 11ee 1
11f0 3 11f5 11f6
11f7 1 11fb 2
11f9 11fb 3 1202
1203 1204 1 1208
2 1206 1208 2
1219 121b 3 1217
1218 121d 2 1226
1228 2 1225 122a
1 122c 1 122e
3 1210 122f 1234
3 123a 123b 123c
1 1240 2 123e
1240 3 1247 1248
1249 1 124d 2
124b 124d 2 125e
1260 3 125c 125d
1262 2 126b 126d
2 126a 126f 1
1271 1 1273 3
1255 1274 1279 2
127c 127b 3 11bc
11f1 127d 1 127f
2 1294 1299 1
12a0 1 129b 2
12b3 12b5 3 12b1
12b2 12b7 2 12c0
12c2 2 12c4 12c6
2 12c8 12ca 2
12cc 12ce 2 12d0
12d2 3 12d7 12d8
12d9 2 12d4 12db
2 12bf 12dd 1
12df 1 12e1 2
12aa 12e2 1 12e6
1 12a5 2 12a3
12ea 2 12f1 12f2
2 12f4 12f7 1
12fe 2 12fa 12fe
2 130c 130e 3
130a 130b 1310 2
1319 131b 2 1318
131d 1 131f 1
1321 3 1303 1322
1327 1 1329 3
132c 132d 132e 1
1332 2 1330 1332
1 1337 1 133b
2 133d 133e 3
1349 134a 134b 1
134f 2 134d 134f
3 1356 1357 1358
1 135c 2 135a
135c 2 1363 1364
2 1369 136a 1
136c 2 1366 136c
3 1375 1376 1377
1 137b 2 1379
137b 2 137f 1380
1 1384 2 1382
1384 3 138a 138b
138c 1 1390 2
138e 1390 2 13a0
13a2 3 139e 139f
13a4 2 13ad 13af
2 13ac 13b1 1
13b3 1 13b5 3
1397 13b6 13bb 1
13bd 2 13c0 13c1
1 13c7 2 13c3
13c7 2 13cb 13cc
1 13d2 2 13ce
13d2 2 13e7 13ec
1 13f3 1 13ee
2 1406 1408 3
1404 1405 140a 2
1413 1415 2 1417
1419 2 141b 141d
2 141f 1421 2
1423 1425 3 142a
142b 142c 2 1427
142e 2 1412 1430
1 1432 1 1434
2 13fd 1435 1
1439 1 13f8 2
13f6 143d 3 1445
1446 1447 1 144b
2 1449 144b 3
1452 1453 1454 1
1458 2 1456 1458
5 1463 1464 1465
1466 1467 2 1460
146a 1 146c 2
1484 1485 2 1489
148a 15 1470 1471
1472 1473 1474 1475
1476 1477 1478 1479
147a 147b 147c 147d
147e 147f 1480 1481
1482 1487 148c 1
1492 2 14a1 14a3
3 149f 14a0 14a5
2 14ae 14b0 2
14ad 14b2 1 14b4
1 14b6 2 14ba
14bb 8 13d9 1440
146d 148f 1495 1498
14b7 14be 3 14c2
14c5 14c8 2 14ca
14cb 2 13be 14cc
3 14d2 14d3 14d4
1 14d8 2 14d6
14d8 2 14e5 14ea
1 14f1 1 14ec
2 1504 1506 3
1502 1503 1508 2
1511 1513 2 1515
1517 2 1519 151b
2 151d 151f 2
1521 1523 3 1528
1529 152a 2 1525
152c 2 1510 152e
1 1530 1 1532
2 14fb 1533 1
1537 1 14f6 2
14f4 153b 2 1544
1545 2 154a 154b
1 154f 2 154d
154f 1 1553 8
155d 155e 155f 1560
1561 1562 1563 1564
1 1567 1 1569
3 156c 156d 156e
1 1572 2 1570
1572 1 1578 2
1587 158c 1 1593
1 158e 2 15a6
15a8 3 15a4 15a5
15aa 2 15b3 15b5
2 15b7 15b9 2
15bb 15bd 2 15bf
15c1 2 15c3 15c5
3 15ca 15cb 15cc
2 15c7 15ce 2
15b2 15d0 1 15d2
1 15d4 2 159d
15d5 1 15d9 1
1598 2 1596 15dd
3 15e4 15e5 15e6
2 15e0 15e9 1
15eb 2 1577 15ec
1 15f0 2 15f2
15f3 2 15f7 15f8
2 15fd 15fe 2
15fa 1600 2 1614
1615 11 1606 1607
1608 1609 160a 160b
160c 160d 160e 160f
1610 1611 1612 1617
1618 1619 161a 2
161f 1620 1 1624
2 1622 1624 3
162a 162b 162c 1
1630 2 162e 1630
1 1644 2 1643
1644 1 164c 1
1652 2 1654 1655
2 1641 1656 1
165d 1 1658 2
1670 1672 3 166e
166f 1674 2 167d
167f 2 1681 1683
2 1685 1687 2
1689 168b 2 168d
168f 3 1694 1695
1696 2 1691 1698
2 167c 169a 1
169c 1 169e 2
1667 169f 1 16a3
1 1662 2 1660
16a7 1 16aa 2
16af 16b0 1 16b4
2 16b2 16b4 3
16ba 16bb 16bc 1
16c0 2 16be 16c0
1 16d2 2 16d1
16d2 1 16da 1
16e0 2 16e2 16e3
2 16cf 16e4 1
16eb 1 16e6 2
16fe 1700 3 16fc
16fd 1702 2 170b
170d 2 170f 1711
2 1713 1715 2
1717 1719 2 171b
171d 3 1722 1723
1724 2 171f 1726
2 170a 1728 1
172a 1 172c 2
16f5 172d 1 1731
1 16f0 2 16ee
1735 1 1738 2
173c 173b 1 173d
1 173f 4 1743
1744 1745 1746 1
174c 2 1760 1762
3 175e 175f 1764
2 176d 176f 2
176c 1771 1 1773
1 1775 d 153e
1548 156a 15f4 1603
161d 1740 1749 174f
1754 1757 1776 177b
2 1780 1781 2
1786 1787 1 1789
2 1783 1789 2
178e 178f 2 1794
1795 2 1791 1797
2 179c 179d 1
17a3 2 179f 17a3
2 17a7 17a8 1
17ae 2 17aa 17ae
3 17b4 17b5 17b6
1 17ba 2 17b8
17ba 1 17c0 1
17c4 2 17c6 17c7
4 17cb 17cc 17cd
17ce 3 17d5 17d6
17d7 1 17db 2
17d9 17db 1 17dd
3 17e4 17e5 17e6
1 17ea 2 17e8
17ea 1 17ec 3
17fc 17fd 17fe 4
180e 180f 1810 1811
2 181f 1820 2
1822 1825 8 17f4
17f9 1801 1806 180b
1814 1819 1828 1
182c 2 182e 182f
1 1831 2 183e
1840 3 183c 183d
1842 2 184b 184d
2 184a 184f 1
1851 1 1853 2
1854 1859 1 185b
2 1873 1874 2
1878 1879 15 185f
1860 1861 1862 1863
1864 1865 1866 1867
1868 1869 186a 186b
186c 186d 186e 186f
1870 1871 1876 187b
1 1881 2 1890
1892 3 188e 188f
1894 2 189d 189f
2 189c 18a1 1
18a3 1 18a5 2
18a9 18aa 9 17c8
17d1 1830 185c 187e
1884 1887 18a6 18ad
1 18b1 2 18b3
18b4 2 179a 18b5
2 18ba 18bb 1
18bf 2 18bd 18bf
2 18cd 18d2 1
18d9 1 18d4 2
18ec 18ee 3 18ea
18eb 18f0 2 18f9
18fb 2 18fd 18ff
2 1901 1903 2
1905 1907 2 1909
190b 3 1910 1911
1912 2 190d 1914
2 18f8 1916 1
1918 1 191a 2
18e3 191b 1 191f
1 18de 2 18dc
1923 3 18c4 18c7
1926 2 192c 192d
2 1932 1933 1
1935 2 192f 1935
2 193a 193b 2
1940 1941 2 193d
1943 2 194e 194f
1 1953 2 1951
1953 2 1957 1959
2 195b 195d 2
195f 1961 2 1963
1965 2 1967 1969
2 196b 196d 2
1973 1974 1 1976
2 196f 1978 2
197b 1980 2 1983
1985 2 1987 1989
2 198b 198d 2
198f 1991 2 1993
1995 2 1997 1999
2 199f 19a0 1
19a2 2 199b 19a4
2 19a7 19ac 2
19ae 19af 2 19b3
19b4 1 19b8 2
19b6 19b8 1 19c6
1 19cc 2 19ce
19cf 2 19bd 19d0
1 19dd 1 19e3
2 19e5 19e6 2
19d4 19e7 2 19e9
19ea 1 19f2 2
19ee 19f2 1 19f7
1 19f9 2 19eb
19fa 2 19ff 1a00
1 1a04 2 1a02
1a04 2 1a09 1a0f
1 1a16 1 1a11
2 1a29 1a2b 3
1a27 1a28 1a2d 2
1a36 1a38 2 1a3a
1a3c 2 1a3e 1a40
2 1a42 1a44 2
1a46 1a48 3 1a4d
1a4e 1a4f 2 1a4a
1a51 2 1a35 1a53
1 1a55 1 1a57
2 1a20 1a58 1
1a5c 1 1a1b 2
1a19 1a60 1 1a63
2 1a68 1a6e 1
1a75 1 1a70 2
1a88 1a8a 3 1a86
1a87 1a8c 2 1a95
1a97 2 1a99 1a9b
2 1a9d 1a9f 2
1aa1 1aa3 2 1aa5
1aa7 3 1aac 1aad
1aae 2 1aa9 1ab0
2 1a94 1ab2 1
1ab4 1 1ab6 2
1a7f 1ab7 1 1abb
1 1a7a 2 1a78
1abf 1 1ac2 2
1ac5 1ac6 1 1ac8
2 1ace 1acf 1
1ad3 2 1ad1 1ad3
2 1ae1 1ae3 3
1adf 1ae0 1ae5 2
1aee 1af0 2 1aed
1af2 1 1af4 1
1af6 3 1ad8 1af7
1afc 2 1b09 1b0b
3 1b07 1b08 1b0d
2 1b16 1b18 2
1b15 1b1a 1 1b1c
1 1b1e 3 1b00
1b1f 1b24 2 1b26
1b27 1 1b28 1
1b2a 2 1b36 1b3b
1 1b42 1 1b3d
2 1b55 1b57 3
1b53 1b54 1b59 2
1b62 1b64 2 1b66
1b68 2 1b6a 1b6c
2 1b6e 1b70 2
1b72 1b74 3 1b79
1b7a 1b7b 2 1b76
1b7d 2 1b61 1b7f
1 1b81 1 1b83
2 1b4c 1b84 1
1b88 1 1b47 2
1b45 1b8c a 1946
1949 194c 19b0 19fd
1ac7 1b2b 1b8f 1b93
1b96 5 1b99 177e
18b8 192a 1b98 1
1b9a 2 1b9e 1b9f
2 1ba4 1ba5 1
1ba7 2 1ba1 1ba7
2 1bab 1bac 1
1bb0 2 1bae 1bb0
2 1bb4 1bb5 2
1bba 1bbb 1 1bbd
2 1bb7 1bbd 2
1bcd 1bcf 3 1bcb
1bcc 1bd1 2 1bda
1bdc 2 1bd9 1bde
1 1be0 1 1be2
3 1bc4 1be3 1be8
1 1bea 2 1bed
1bee 2 1bf3 1bf4
1 1bf6 2 1bf0
1bf6 2 1c04 1c06
3 1c02 1c03 1c08
2 1c11 1c13 2
1c10 1c15 1 1c17
1 1c19 3 1bfb
1c1a 1c1f 1 1c21
2 1c24 1c25 1
1c29 2 1c27 1c29
1 1c2e 2 1c31
1c32 1 1c36 2
1c34 1c36 2 1c3b
1c3c 1 1c40 2
1c3e 1c40 2 1c51
1c53 3 1c4f 1c50
1c55 2 1c5e 1c60
2 1c5d 1c62 1
1c64 1 1c66 3
1c48 1c67 1c6c 1
1c6e 2 1c72 1c73
2 1c6f 1c76 2
1c78 1c79 2 1c7c
1c7d 1 1c83 2
1c7f 1c83 2 1c87
1c88 1 1c8e 2
1c8a 1c8e 2 1c94
1c95 1 1c99 2
1c97 1c99 1 1c9d
2 1caf 1cb4 1
1cbb 1 1cb6 2
1cce 1cd0 3 1ccc
1ccd 1cd2 2 1cdb
1cdd 2 1cdf 1ce1
2 1ce3 1ce5 2
1ce7 1ce9 2 1ceb
1ced 3 1cf2 1cf3
1cf4 2 1cef 1cf6
2 1cda 1cf8 1
1cfa 1 1cfc 2
1cc5 1cfd 1 1d01
1 1cc0 2 1cbe
1d05 1 1d08 1
1d0b 2 1d10 1d11
2 1d16 1d17 2
1d13 1d19 2 1d1c
1d1e 2 1d21 1d23
1 1d25 8 1d2b
1d2c 1d2d 1d2e 1d2f
1d30 1d31 1d32 2
1d3b 1d3c 2 1d3e
1d41 6 1d47 1d48
1d49 1d4a 1d4b 1d4c
4 1d52 1d53 1d54
1d55 1 1d5b 2
1d6a 1d6c 3 1d68
1d69 1d6e 2 1d77
1d79 2 1d76 1d7b
1 1d7d 1 1d7f
2 1d83 1d84 a
1d0c 1d28 1d35 1d44
1d4f 1d58 1d5e 1d61
1d80 1d87 2 1d8c
1d8d 2 1d92 1d93
2 1d8f 1d95 2
1d98 1d9a 2 1d9d
1d9f 1 1da1 2
1da6 1da7 2 1dac
1dad 1 1daf 2
1da9 1daf 2 1dbc
1dc1 1 1dc8 1
1dc3 2 1ddb 1ddd
3 1dd9 1dda 1ddf
2 1de8 1dea 2
1dec 1dee 2 1df0
1df2 2 1df4 1df6
2 1df8 1dfa 3
1dff 1e00 1e01 2
1dfc 1e03 2 1de7
1e05 1 1e07 1
1e09 2 1dd2 1e0a
1 1e0e 1 1dcd
2 1dcb 1e12 2
1e18 1e19 1 1e1d
2 1e1b 1e1d 2
1e28 1e2a 3 1e26
1e27 1e2c 2 1e35
1e37 2 1e34 1e39
1 1e3b 1 1e3d
2 1e3e 1e41 1
1e43 3 1db4 1e15
1e44 1 1e46 2
1e4f 1e50 1 1e54
2 1e52 1e54 1
1e59 1 1e5b 2
1e66 1e69 2 1e6b
1e6e 1 1e84 2
1e83 1e84 1 1e8c
1 1e92 2 1e94
1e95 2 1e81 1e96
1 1e9d 1 1e98
2 1eb0 1eb2 3
1eae 1eaf 1eb4 2
1ebd 1ebf 2 1ec1
1ec3 2 1ec5 1ec7
2 1ec9 1ecb 2
1ecd 1ecf 3 1ed4
1ed5 1ed6 2 1ed1
1ed8 2 1ebc 1eda
1 1edc 1 1ede
2 1ea7 1edf 1
1ee3 1 1ea2 2
1ea0 1ee7 2 1eed
1eee 1 1ef2 2
1ef0 1ef2 1 1ef7
1 1ef9 8 1da4
1e47 1e4a 1e4d 1e5c
1e71 1eea 1efa 2
1efc 1efd 4 1beb
1c22 1c7a 1efe 2
1f01 1f00 1 1f05
2 1f03 1f05 2
1f09 1f0a 1 1f0e
2 1f0c 1f0e 1
1f12 8 1f1c 1f1d
1f1e 1f1f 1f20 1f21
1f22 1f23 1 1f26
1 1f28 1 1f2a
3 1f31 1f32 1f33
1 1f36 3 1f39
1f3a 1f3b 1 1f3f
2 1f3d 1f3f 3
1f44 1f45 1f46 1
1f49 3 1f4d 1f4e
1f4f 1 1f52 2
1f54 1f55 1 1f56
2 1f58 1f59 1
1f5b 2 1f61 1f62
1 1f66 2 1f64
1f66 2 1f6e 1f6f
2 1f71 1f74 2
1f83 1f88 1 1f8f
1 1f8a 2 1fa2
1fa4 3 1fa0 1fa1
1fa6 2 1faf 1fb1
2 1fb3 1fb5 2
1fb7 1fb9 2 1fbb
1fbd 2 1fbf 1fc1
3 1fc6 1fc7 1fc8
2 1fc3 1fca 2
1fae 1fcc 1 1fce
1 1fd0 2 1f99
1fd1 1 1fd5 1
1f94 2 1f92 1fd9
2 1f78 1fdc 2
1fe9 1fee 1 1ff5
1 1ff0 2 2008
200a 3 2006 2007
200c 2 2015 2017
2 2019 201b 2
201d 201f 2 2021
2023 2 2025 2027
3 202c 202d 202e
2 2029 2030 2
2014 2032 1 2034
1 2036 2 1fff
2037 1 203b 1
1ffa 2 1ff8 203f
1 2042 2 2045
2046 2 204a 204b
2 2050 2051 2
204d 2053 2 2047
2056 1 2058 2
2066 2067 2 206b
206c 8 205f 2060
2061 2062 2063 2064
2069 206e 2 2073
2074 1 2078 2
2076 2078 2 2086
2088 3 2084 2085
208a 2 2093 2095
2 2092 2097 1
2099 1 209b 3
207d 209c 20a1 1
20a6 2 20a4 20a6
3 20aa 20ab 20ac
1 20b0 2 20ae
20b0 1 20d1 2
20d0 20d1 1 20d9
1 20df 2 20e1
20e2 2 20ce 20e3
1 20ea 1 20e5
2 20fd 20ff 3
20fb 20fc 2101 2
210a 210c 2 210e
2110 2 2112 2114
2 2116 2118 2
211a 211c 3 2121
2122 2123 2 211e
2125 2 2109 2127
1 2129 1 212b
2 20f4 212c 1
2130 1 20ef 2
20ed 2134 2 20b7
2137 1 2149 2
2148 2149 1 2151
1 2157 2 2159
215a 2 2146 215b
1 2162 1 215d
2 2175 2177 3
2173 2174 2179 2
2182 2184 2 2186
2188 2 218a 218c
2 218e 2190 2
2192 2194 3 2199
219a 219b 2 2196
219d 2 2181 219f
1 21a1 1 21a3
2 216c 21a4 1
21a8 1 2167 2
2165 21ac 1 21af
2 21b2 21b3 2
21b6 21b7 1 21bb
2 21b9 21bb 1
21bd 2 21de 21e3
1 21ea 1 21e5
2 21fd 21ff 3
21fb 21fc 2201 2
220a 220c 2 220e
2210 2 2212 2214
2 2216 2218 2
221a 221c 3 2221
2222 2223 2 221e
2225 2 2209 2227
1 2229 1 222b
2 21f4 222c 1
2230 1 21ef 2
21ed 2234 1 2239
2 2245 224a 1
2251 1 224c 2
2264 2266 3 2262
2263 2268 2 2271
2273 2 2275 2277
2 2279 227b 2
227d 227f 2 2281
2283 3 2288 2289
228a 2 2285 228c
2 2270 228e 1
2290 1 2292 2
225b 2293 1 2297
1 2256 2 2254
229b 1 22aa 2
22a9 22aa 1 22b2
1 22b8 2 22ba
22bb 2 22a7 22bc
1 22c3 1 22be
2 22d6 22d8 3
22d4 22d5 22da 2
22e3 22e5 2 22e7
22e9 2 22eb 22ed
2 22ef 22f1 2
22f3 22f5 3 22fa
22fb 22fc 2 22f7
22fe 2 22e2 2300
1 2302 1 2304
2 22cd 2305 1
2309 1 22c8 2
22c6 230d 2 229e
2310 1 2313 3
21c3 2237 2314 1
2316 2 21b4 2317
2 231a 2319 1
231e 2 232d 232f
3 232b 232c 2331
2 233a 233c 2
2339 233e 1 2340
1 2342 2 2346
2347 a 1f29 1f5a
2059 205c 2071 231b
2321 2324 2343 234a
1 234c 2 234f
2350 2 2355 2356
1 2358 2 2352
2358 2 236a 236f
1 2376 1 2371
2 2389 238b 3
2387 2388 238d 2
2396 2398 2 239a
239c 2 239e 23a0
2 23a2 23a4 2
23a6 23a8 3 23ad
23ae 23af 2 23aa
23b1 2 2395 23b3
1 23b5 1 23b7
2 2380 23b8 1
23bc 1 237b 2
2379 23c0 2 23c6
23c7 1 23cb 2
23c9 23cb 2 23d9
23db 3 23d7 23d8
23dd 2 23e6 23e8
2 23e5 23ea 1
23ec 1 23ee 3
23d0 23ef 23f4 1
23f6 2 23fa 23fb
2 2401 2402 2
2407 2408 2 240d
240e 1 2410 2
240a 2410 2 2414
2415 1 241b 2
2417 241b 2 241f
2420 1 2426 2
2422 2426 2 243a
243f 1 2446 1
2441 2 2459 245b
3 2457 2458 245d
2 2466 2468 2
246a 246c 2 246e
2470 2 2472 2474
2 2476 2478 3
247d 247e 247f 2
247a 2481 2 2465
2483 1 2485 1
2487 2 2450 2488
1 248c 1 244b
2 2449 2490 1
2495 1 249c 1
249e 2 24a1 24a2
1 24a6 2 24a4
24a6 2 24aa 24ab
1 24af 2 24ad
24af 1 24b3 2
24c7 24cc 1 24d3
1 24ce 2 24e6
24e8 3 24e4 24e5
24ea 2 24f3 24f5
2 24f7 24f9 2
24fb 24fd 2 24ff
2501 2 2503 2505
3 250a 250b 250c
2 2507 250e 2
24f2 2510 1 2512
1 2514 2 24dd
2515 1 2519 1
24d8 2 24d6 251d
2 2524 2525 2
252a 252b 2 2527
252d 2 2532 2533
2 252f 2535 2
2520 2538 2 253c
253d 2 2542 2543
2 253f 2545 1
2548 2 254a 254b
1 2554 2 2556
2557 1 255d 2
255f 2560 2 2559
2562 2 2565 2567
1 2569 2 256f
2570 2 2575 2576
2 2572 2578 2
257d 257e 2 2583
2584 1 2586 2
2580 2586 2 258b
258c 2 2591 2592
2 258e 2594 2
2599 259a 2 2596
259c 1 259f 2
25a3 25a4 1 25a7
2 25a9 25aa 8
25ae 25af 25b0 25b1
25b2 25b3 25b4 25b5
1 25bd 2 25bf
25c0 1 25c6 2
25c8 25c9 2 25c2
25cb 2 25ce 25d0
1 25d2 2 25db
25dc 2 25de 25e1
2 25eb 25ec 2
25f0 25f1 6 25e7
25e8 25e9 25ee 25f3
25f4 4 25fa 25fb
25fc 25fd a 254c
254f 256c 257b 25ab
25b8 25d5 25e4 25f7
2600 1 2602 4
242d 2493 249f 2603
2 260a 260b 2
2629 262a 2 262e
262f 19 2611 2612
2613 2614 2615 2616
2617 2618 2619 261a
261b 261c 261d 261e
261f 2620 2621 2622
2623 2624 2625 2626
2627 262c 2631 2
2637 2638 2 263e
263f 2 2644 2645
2 2641 2647 2
2650 2655 1 265c
1 2657 2 266f
2671 3 266d 266e
2673 2 267c 267e
2 2680 2682 2
2684 2686 2 2688
268a 2 268c 268e
3 2693 2694 2695
2 2690 2697 2
267b 2699 1 269b
1 269d 2 2666
269e 1 26a2 1
2661 2 265f 26a6
2 26b4 26b9 1
26c0 1 26bb 2
26d3 26d5 3 26d1
26d2 26d7 2 26e0
26e2 2 26e4 26e6
2 26e8 26ea 2
26ec 26ee 2 26f0
26f2 3 26f7 26f8
26f9 2 26f4 26fb
2 26df 26fd 1
26ff 1 2701 2
26ca 2702 1 2706
1 26c5 2 26c3
270a 1 2725 2
2724 2725 1 272d
1 2733 2 2735
2736 2 2722 2737
1 273e 1 2739
2 2751 2753 3
274f 2750 2755 2
275e 2760 2 2762
2764 2 2766 2768
2 276a 276c 2
276e 2770 3 2775
2776 2777 2 2772
2779 2 275d 277b
1 277d 1 277f
2 2748 2780 1
2784 1 2743 2
2741 2788 1 2793
2 278f 2793 2
27a4 27a5 8 279c
279d 279e 279f 27a0
27a1 27a2 27a7 2
27ac 27ad 1 27b1
2 27af 27b1 2
27bf 27c1 3 27bd
27be 27c3 2 27cc
27ce 2 27cb 27d0
1 27d2 1 27d4
2 27d8 27d9 3
27b6 27d5 27dc 1
27de 3 2799 27aa
27df 1 27e1 9
2607 260e 2634 263b
264a 26a9 270d 278b
27e2 2 27e4 27e5
2 27e9 27ea 3
27e6 27ed 27f0 1
27f6 2 27f8 27f9
1 27ff 2 2801
2802 2 27fb 2804
2 2807 2809 2
280c 280e 1 2810
1 2813 2 2815
2816 2 2832 2833
2 2837 2838 19
281a 281b 281c 281d
281e 281f 2820 2821
2822 2823 2824 2825
2826 2827 2828 2829
282a 282b 282c 282d
282e 282f 2830 2835
283a 2 2849 284b
3 2847 2848 284d
2 2856 2858 2
2855 285a 1 285c
1 285e 2 2862
2863 a 235d 23c3
23f7 23fe 2405 2817
283d 2840 285f 2866
2 286a 286b 2
2870 2871 1 2873
2 286d 2873 2
2877 2878 1 287c
2 287a 287c 2
2881 2882 1 2886
2 2884 2886 2
2897 2899 3 2895
2896 289b 2 28a4
28a6 2 28a3 28a8
1 28aa 1 28ac
3 288e 28ad 28b2
1 28b4 1 28c4
2 28c3 28c4 1
28cc 1 28d2 2
28d4 28d5 2 28c1
28d6 1 28dd 1
28d8 2 28f0 28f2
3 28ee 28ef 28f4
2 28fd 28ff 2
2901 2903 2 2905
2907 2 2909 290b
2 290d 290f 3
2914 2915 2916 2
2911 2918 2 28fc
291a 1 291c 1
291e 2 28e7 291f
1 2923 1 28e2
2 28e0 2927 1
293a 2 2939 293a
1 2942 1 2948
2 294a 294b 2
2937 294c 1 2953
1 294e 2 2966
2968 3 2964 2965
296a 2 2973 2975
2 2977 2979 2
297b 297d 2 297f
2981 2 2983 2985
3 298a 298b 298c
2 2987 298e 2
2972 2990 1 2992
1 2994 2 295d
2995 1 2999 1
2958 2 2956 299d
3 28b5 292a 29a0
2 29a4 29a3 1
29a8 2 29b7 29b9
3 29b5 29b6 29bb
2 29c4 29c6 2
29c3 29c8 1 29ca
1 29cc 2 29d0
29d1 10 10fd 1100
1146 1280 12ed 132a
133f 1342 1345 1f02
234d 29a5 29ab 29ae
29cd 29d4 2 29f7
29fc 1 2a03 1
29fe 2 2a16 2a18
3 2a14 2a15 2a1a
2 2a23 2a25 2
2a27 2a29 2 2a2b
2a2d 2 2a2f 2a31
2 2a33 2a35 3
2a3a 2a3b 2a3c 2
2a37 2a3e 2 2a22
2a40 1 2a42 1
2a44 2 2a0d 2a45
1 2a49 1 2a08
2 2a06 2a4d 1
2a58 2 2a54 2a58
1 2a5b 2 2a6a
2a6c 3 2a68 2a69
2a6e 2 2a77 2a79
2 2a76 2a7b 1
2a7d 1 2a7f 3
2a61 2a80 2a85 1
2a87 2 2a8c 2a8d
1 2a91 2 2a8f
2a91 2 2aa4 2aa6
3 2aa2 2aa3 2aa8
2 2ab1 2ab3 2
2ab0 2ab5 1 2ab7
1 2ab9 4 2a98
2a9b 2aba 2abf 1
2ac1 3 2a50 2a88
2ac2 3 2ac4 29d6
2ac5 2 522 2ac6
1 2ac8 4 2adc
2add 2ade 2adf 2
2aee 2af0 3 2aec
2aed 2af2 2 2afb
2afd 2 2afa 2aff
1 2b01 1 2b03
2 2b12 2b14 3
2b10 2b11 2b16 2
2b1f 2b21 2 2b23
2b25 2 2b27 2b29
2 2b2b 2b2f 2
2b1e 2b31 1 2b33
1 2b35 13 3c0
3df 3e2 3e5 3e8
3eb 3ee 468 2ac9
2acc 2acf 2ad2 2ad7
2ae2 2ae5 2b04 2b09
2b36 2b3b 6c 40
46 4c 52 59
60 67 6e 75
7c 83 8a 91
98 9f a6 ad
b4 b9 be c3
c8 cd d2 d7
dc e1 e6 eb
f0 f5 fc 103
10a 110 116 11c
122 127 12c 132
138 13e 144 14a
150 156 15c 162
168 16f 176 17d
183 189 18f 195
19b 1a1 1a7 1ad
1b3 1b9 1bf 1c5
1cb 1d1 1d7 1dd
1e3 1e9 1ef 1f5
1fb 201 207 20d
213 219 21f 225
22b 231 238 23f
245 24c 252 258
25e 264 26a 270
276 27c 282 288
28e 295 29a 29f
2a4 2a9 2af 2c7
2e2 2ec 2f3 
1
4
0 
2b43
0
1
a0
64
77
0 1 1 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 1e 1
20 1 22 1 24 1 26 1
28 1 2a 1 2c 1 2e 1
30 1 32 1 34 1 36 1
1 39 1 3b 1 3d 1 3f
1 41 1 43 1 45 1 47
1 49 1 4b 1 4d 1 4f
1 51 1 53 1 55 1 57
1 59 1 5b 1 5d 1 5f
1 61 1 63 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

1f7 1 0
70 1 0
241 1 0
13a 1 0
2cd 1 3
28a 1 0
ca 1 0
21b 1 0
18b 1 0
25a 1 0
9 1 0
14c 1 0
3c 1 0
1e5 1 0
2 0 1
2a1 1 0
c0 1 0
54 1 0
15 1 0
23 1 0
209 1 0
11e 1 0
247 1 0
1a3 1 0
1fd 1 0
1af 1 0
fe 1 0
1f 1 0
215 1 0
c5 1 0
266 1 0
2e7 1 0
f 1 0
23a 1 0
158 1 0
2a6 1 0
290 1 0
26c 1 0
69 1 0
20f 1 0
152 1 0
124 1 0
254 1 0
1b5 1 0
191 1 0
1d3 1 0
1f1 1 0
129 1 0
17f 1 0
de 1 0
cf 1 0
297 1 0
22d 1 0
105 1 0
93 1 0
227 1 0
197 1 0
d4 1 0
146 1 0
bb 1 0
278 1 0
164 1 0
112 1 0
85 1 0
5b 1 0
2b2 1 2
1df 1 0
1bb 1 0
a1 1 0
29c 1 0
2ee 1 0
203 1 0
ed 1 0
e3 1 0
48 1 0
24e 1 0
134 1 0
284 1 0
10c 1 0
62 1 0
118 1 0
1b 1 0
140 1 0
16a 1 0
31 1 0
d9 1 0
b6 1 0
2ab 1 0
19d 1 0
1eb 1 0
4e 1 0
1a9 1 0
221 1 0
1cd 1 0
f7 1 0
af 1 0
27 1 0
42 1 0
f2 1 0
272 1 0
1c1 1 0
15e 1 0
171 1 0
a8 1 0
1c7 1 0
9a 1 0
8c 1 0
12e 1 0
260 1 0
e8 1 0
2b 1 0
7e 1 0
1d9 1 0
178 1 0
233 1 0
77 1 0
185 1 0
27e 1 0
3 1 0
0

/
SHOW ERRORS FUNCTION FC_U_PARTICIPANT;
ALTER FUNCTION FC_U_PARTICIPANT COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_PARTICIPANT ==
CREATE OR REPLACE FUNCTION SP_U_PARTICIPANT wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
58
2 :e:
1FUNCTION:
1SP_U_PARTICIPANT:
1ASSIGN_ID:
1VARCHAR2:
1SECURITY_ID001:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1P_DELAY:
1PLS_INTEGER:
1P_UNITS:
1P_WORK_PERCENT:
1P_ACTUAL:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_P_ASSIGN_ID:
132:
1H_P_SECURITY_ID:
1H_P_PLANNED_START:
1H_P_PLANNED_FINISH:
1H_P_DELAY:
10:
1H_P_UNITS:
1H_P_WORK_PERCENT:
1H_P_ACTUAL:
1H_P_RES_ID:
1H_ID:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_PARTICIPANT(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
11:
140:
1+:
1FPUT:
1               ENTER:: SP_U_PARTICIPANT(41) :: cplan.sql(20135) :: :
1SC_STATE:
1FC_U_PARTICIPANT:
14:
160:
1       RETURN_STATUS:: SP_U_PARTICIPANT(61) :: cplan.sql(20155) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
167:
1           EXCEPTION:: SP_U_PARTICIPANT(68) :: cplan.sql(20162) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
179:
1           EXCEPTION:: SP_U_PARTICIPANT(80) :: cplan.sql(20174) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
26f
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 :2 a0 6b 1c 81 b0
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:2 a0 6e 7e a0 b4 2e 7e 6e
b4 2e 6e a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e :2 a0
6e 7e a0 b4 2e 7e 6e b4
2e 6e a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
d :2 a0 d :2 a0 6b :b a0 a5 b
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 a0 6b
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e a5 57 b7 19 3c :9 a0 12a
e9 dd :2 a0 65 b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c :7 a0 12a e9 dd
:2 a0 65 b7 a4 b1 11 4f b7
a6 9 a4 b1 11 68 4f 1d
17 b5 
26f
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 a2
c8 cc d0 d4 d7 db f8 e3
e7 ea eb f3 e2 115 103 df
107 108 110 102 131 120 124 12c
ff 149 138 13c 144 11f 165 154
158 11c 160 153 181 170 174 150
17c 16f 19d 18c 190 16c 198 18b
1b9 1a8 1ac 188 1b4 1a7 1d6 1c4
1a4 1c8 1c9 1d1 1c3 1f3 1e1 1c0
1e5 1e6 1ee 1e0 213 1fe 202 1dd
206 20e 1fd 21a 21e 1fa 222 226
22a 22d 232 233 1 235 23a 23e
242 245 24a 24e 252 255 25a 25b
25d 262 265 269 26a 26f 274 277
27c 27d 282 285 289 28a 28f 292
297 298 29d 2a0 2a5 2a6 2ab 2ae
2b3 2b4 2b9 2bc 2c0 2c1 2c6 2c9
2ce 2cf 2d4 2d7 2dc 2dd 2e2 2e5
2e9 2ed 2f2 2f5 2f9 2fa 2ff 302
307 308 30d 312 313 315 31a 31b
31d 31e 323 326 32b 32c 331 334
338 33c 341 344 348 349 34e 351
356 357 35c 361 362 364 369 36a
36c 36d 372 375 37a 37b 380 383
387 38b 38f 390 392 397 398 39a
39b 3a0 3a3 3a8 3a9 3ae 3b1 3b5
3b9 3bd 3be 3c0 3c5 3c6 3c8 3c9
3ce 3d1 3d6 3d7 3dc 3df 3e3 3e7
3eb 3ec 3ee 3f3 3f4 3f6 3f7 3fc
3ff 404 405 40a 40d 411 415 419
41a 41c 421 422 424 425 42a 42d
432 433 438 43b 440 441 446 449
44d 44e 453 456 45b 45c 461 464
469 46a 46f 470 475 477 47b 47e
482 486 489 48d 491 494 497 49c
49f 4a2 4a5 4a6 4ab 4ac 1 4ae
4b3 4b7 4bb 4be 4c3 4c8 4cb 4cf
4d0 4d5 4d6 4db 4dd 4e1 4e4 4e8
4ec 4f0 4f4 4f8 4fc 500 504 508
50c 510 514 518 51c 520 524 528
52c 530 534 538 53c 540 544 548
54c 550 554 558 55b 55f 563 567
56b 56f 573 577 57b 57f 583 587
588 58a 58e 592 596 599 59d 5a1
5a4 5a7 5ac 5af 5b2 5b5 5b6 5bb
5bc 1 5be 5c3 5c7 5cb 5ce 5d3
5d8 5db 5df 5e0 5e5 5e8 5ed 5ee
5f3 5f6 5fb 5fc 601 604 608 60c
610 614 617 618 61a 61f 620 622
623 628 62b 630 631 636 639 63e
63f 644 647 64b 64c 651 654 659
65a 65f 660 665 667 66b 66e 672
676 679 67d 681 684 688 68c 68d
692 694 698 69c 69f 6a3 6a7 6aa
6ae 6b2 6b5 6b8 6bd 6c0 6c3 6c6
6c7 6cc 6cd 1 6cf 6d4 6d8 6dc
6df 6e4 6e9 6ec 6f0 6f1 6f6 6f7
6fc 700 704 707 70c 711 714 718
71c 71f 720 725 728 72d 72e 733
736 73a 73e 741 742 747 748 74d
74f 753 756 75a 75e 762 766 76a
76e 772 776 77a 786 78b 78f 793
797 79b 79d 79e 7a3 1 7a7 7ab
7af 7b2 7b6 7ba 7be 7c2 7c5 7c9
7cd 7d0 7d3 7d8 7db 7de 7e1 7e2
7e7 7e8 1 7ea 7ef 7f3 7f7 7fa
7ff 804 807 80b 80c 811 812 817
81b 81f 822 827 82c 82f 833 834
839 83c 841 842 847 84a 84e 852
855 858 859 85b 85c 861 862 867
869 86d 870 874 878 87c 880 884
888 88c 898 89d 8a1 8a5 8a9 8ad
8af 8b3 8b5 8c1 8c3 8c5 8c6 8cb
8cf 8d1 8dd 8e1 8e3 8e4 8ed 
26f
2
0 1 a 6 10 :3 6 15 :3 6
16 :3 6 17 :3 6 e :3 6 e :3 6
15 :3 6 f :3 6 10 :2 6 1 3
a 13 a :2 1 4 12 1b 1a
:2 12 :2 4 14 1d 1c :2 14 :2 4 :3 16
:2 4 :3 17 :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 15 24 15 :2 4 :2 f
1e f :2 4 f 18 17 :2 f :2 4
9 12 11 :2 9 :2 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 58 5e
61 :2 58 6f 89 8 :2 6f d 10
:2 6f 1a 1d :2 6f b e :2 6f 13
16 :2 6f 1b 1e :2 6f 2d 30 :2 6f
b e :2 6f 13 16 1f 26 2b
2e :2 26 3e 41 :2 26 46 :2 1f 4f
:2 16 :2 6f b e :2 6f 13 16 1f
26 2b 2e :2 26 3f 42 :2 26 47
:2 1f 50 :2 16 :2 6f b e :2 6f 13
16 1f 27 :2 1f 31 :2 16 :2 6f b
e :2 6f 13 16 1f 27 :2 1f 31
:2 16 :2 6f b e :2 6f 13 16 1f
27 :2 1f 38 :2 16 :2 6f b e :2 6f
13 16 1f 27 :2 1f 32 :2 16 :2 6f
b e :2 6f 13 16 :2 6f 1b 1e
:2 6f 28 2b :2 6f 30 33 :2 6f :2 7
4e :2 4 7 :2 11 23 :2 2d 39 3c
50 52 53 :2 50 :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :2 7 56 :3 4 15
:2 4 17 :2 4 19 :2 4 1a :2 4 11
:2 4 11 :2 4 18 :2 4 12 :2 4 12
:2 4 :2 d 19 2a 39 4a 29 3d
48 53 29 35 41 :2 19 4 7
:2 11 23 :2 2d 39 3c 50 52 53
:2 50 :2 23 :3 7 :2 d 12 1e 61 64
:2 1e 71 74 :2 1e 78 7b :2 1e 85
88 91 99 :2 a2 :2 91 ad :2 88 :2 1e
b5 b8 :2 1e c0 c3 :2 1e c8 cb
:2 1e d0 d3 :2 1e :2 7 56 :3 4 :2 f
21 :2 2a 34 3a :2 4 1 9 12
9 a :2 14 26 :2 30 3c 40 54
56 57 :2 54 :2 26 :3 a :2 10 15 21
64 67 :2 21 :3 a :2 10 15 39 5c
5f :2 68 :2 39 76 79 :2 39 81 84
:2 8d :2 39 :2 a 5a :3 7 c 15 1e
2c a 13 1e f e 7 e
7 e 7 29 :2 4 :2 9 7 :2 10
1c :2 7 :2 11 23 :2 2d 39 3d 51
53 54 :2 51 :2 23 :3 7 :2 d 12 1e
61 64 :2 1e :3 7 :2 d 12 36 42
45 :2 36 4d 50 :2 36 5c 5f 66
6f 72 :2 5f :2 36 :2 7 57 :2 4 7
c 1b a 13 1e f e 7
e 7 e 7 :2 4 :4 10 :2 4 :8 1

26f
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b 2
:4 c :2 1 :7 e :7 f
:5 10 :5 11 :6 12 :6 13
:6 14 :6 15 :7 16 :7 17
:7 19 :b 1b :11 1c 1d
:2 1c :2 1d :2 1c :2 1d
:2 1c :2 1e :2 1c :2 1e
:2 1c :2 1e :2 1c :2 1e
:2 1c :2 1f :2 1c :12 1f
:2 1c :2 20 :2 1c :12 20
:2 1c :2 21 :2 1c :9 21
:2 1c :2 22 :2 1c :9 22
:2 1c :2 23 :2 1c :9 23
:2 1c :2 24 :2 1c :9 24
:2 1c :2 25 :2 1c :2 25
:2 1c :2 25 :2 1c :2 25
:2 1c :2 25 :4 1c :3 1b
:11 28 :b 29 :3 28 :3 2e
:3 2f :3 30 :3 31 :3 32
:3 33 :3 34 :3 35 :3 36
:7 38 :4 39 :3 3a :3 38
:11 3c :30 3d :3 3c :a 3f
1a :3 42 :11 43 :b 44
:17 45 :3 43 :2 47 :3 48
:3 49 4a 48 47
48 :3 4b :3 42 :2 4c
:5 4e :11 4f :b 50 :18 51
:3 4f :2 53 54 :3 55
56 54 53 54
:3 57 :2 4d :6 4c 41
:7 1 
8ef
4
:3 0 1 :3 0 2
:a 0 26a 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 7 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 7 :3 0 8
:7 0 11 10 :3 0
a :3 0 9 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 b :7 0 19
18 :3 0 a :3 0
c :7 0 1d 1c
:3 0 15 :2 0 13
a :3 0 d :7 0
21 20 :3 0 4
:3 0 e :7 0 25
24 :3 0 f :3 0
10 :3 0 11 :2 0
4 29 2a 0
27 2b 0 26a
2 2c :2 0 13
:2 0 21 4 :3 0
13 :2 0 1f 2f
31 :6 0 34 32
0 268 0 12
:6 0 27 11c 0
25 4 :3 0 23
36 38 :6 0 3b
39 0 268 0
14 :6 0 18 :2 0
29 7 :3 0 3d
:7 0 40 3e 0
268 0 15 :6 0
7 :3 0 42 :7 0
45 43 0 268
0 16 :6 0 18
:2 0 2b a :3 0
47 :7 0 4b 48
49 268 0 17
:6 0 18 :2 0 2d
a :3 0 4d :7 0
51 4e 4f 268
0 19 :6 0 18
:2 0 2f a :3 0
53 :7 0 57 54
55 268 0 1a
:6 0 13 :2 0 31
a :3 0 59 :7 0
5d 5a 5b 268
0 1b :6 0 13
:2 0 35 4 :3 0
33 5f 61 :6 0
64 62 0 268
0 1c :6 0 6d
6e 0 39 4
:3 0 37 66 68
:6 0 6b 69 0
268 0 1d :6 0
73 74 0 3b
10 :3 0 11 :2 0
4 6f :7 0 72
70 0 268 0
1e :6 0 1f :3 0
20 :3 0 1f :3 0
21 :3 0 76 77
0 2 :4 0 3d
78 7a 75 7c
7b :2 0 22 :3 0
23 :3 0 7e 7f
0 24 :4 0 1f
:3 0 25 :3 0 82
83 0 2 :4 0
3f 84 86 26
:4 0 27 :2 0 28
:3 0 41 89 8b
:3 0 29 :4 0 27
:2 0 2a :4 0 44
8e 90 :3 0 27
:2 0 3 :3 0 47
92 94 :3 0 27
:2 0 2a :4 0 4a
96 98 :3 0 27
:2 0 2b :4 0 4d
9a 9c :3 0 27
:2 0 2a :4 0 50
9e a0 :3 0 27
:2 0 5 :3 0 53
a2 a4 :3 0 27
:2 0 2a :4 0 56
a6 a8 :3 0 27
:2 0 2b :4 0 59
aa ac :3 0 27
:2 0 2c :3 0 2d
:3 0 2a :4 0 27
:2 0 6 :3 0 5c
b2 b4 :3 0 27
:2 0 2a :4 0 5f
b6 b8 :3 0 2e
:4 0 62 b0 bb
2f :4 0 65 af
be 68 ae c0
:3 0 27 :2 0 2b
:4 0 6b c2 c4
:3 0 27 :2 0 2c
:3 0 2d :3 0 2a
:4 0 27 :2 0 8
:3 0 6e ca cc
:3 0 27 :2 0 2a
:4 0 71 ce d0
:3 0 2e :4 0 74
c8 d3 2f :4 0
77 c7 d6 7a
c6 d8 :3 0 27
:2 0 2b :4 0 7d
da dc :3 0 27
:2 0 2c :3 0 30
:3 0 9 :3 0 80
e0 e2 2f :4 0
82 df e5 85
de e7 :3 0 27
:2 0 2b :4 0 88
e9 eb :3 0 27
:2 0 2c :3 0 30
:3 0 b :3 0 8b
ef f1 2f :4 0
8d ee f4 90
ed f6 :3 0 27
:2 0 2b :4 0 93
f8 fa :3 0 27
:2 0 2c :3 0 30
:3 0 c :3 0 96
fe 100 2f :4 0
98 fd 103 9b
fc 105 :3 0 27
:2 0 2b :4 0 9e
107 109 :3 0 27
:2 0 2c :3 0 30
:3 0 d :3 0 a1
10d 10f 2f :4 0
a3 10c 112 a6
10b 114 :3 0 27
:2 0 2b :4 0 a9
116 118 :3 0 27
:2 0 2a :4 0 ac
11a 11c :3 0 27
:2 0 e :3 0 af
11e 120 :3 0 27
:2 0 2a :4 0 b2
122 124 :3 0 27
:2 0 31 :4 0 b5
126 128 :3 0 b8
80 12a :2 0 12c
bd 12d 7d 12c
0 12e bf 0
1c8 1f :3 0 20
:3 0 12f 130 0
1f :3 0 32 :3 0
132 133 0 33
:2 0 2 :4 0 34
:2 0 35 :2 0 33
:2 0 c1 138 13a
:3 0 c4 134 13c
131 13e 13d :2 0
22 :3 0 36 :3 0
140 141 0 24
:4 0 37 :4 0 27
:2 0 28 :3 0 c8
145 147 :3 0 cb
142 149 :2 0 14b
ce 14c 13f 14b
0 14d d0 0
1c8 12 :3 0 3
:3 0 14e 14f 0
1c8 14 :3 0 5
:3 0 151 152 0
1c8 15 :3 0 6
:3 0 154 155 0
1c8 16 :3 0 8
:3 0 157 158 0
1c8 17 :3 0 9
:3 0 15a 15b 0
1c8 19 :3 0 b
:3 0 15d 15e 0
1c8 1a :3 0 c
:3 0 160 161 0
1c8 1b :3 0 d
:3 0 163 164 0
1c8 1c :3 0 e
:3 0 166 167 0
1c8 10 :3 0 38
:3 0 169 16a 0
39 :3 0 12 :3 0
14 :3 0 15 :3 0
16 :3 0 17 :3 0
19 :3 0 1a :3 0
1b :3 0 1c :3 0
1d :3 0 d2 16c
177 16b 178 0
1c8 1f :3 0 20
:3 0 17a 17b 0
1f :3 0 32 :3 0
17d 17e 0 3a
:2 0 2 :4 0 3b
:2 0 35 :2 0 33
:2 0 dd 183 185
:3 0 e0 17f 187
17c 189 188 :2 0
22 :3 0 36 :3 0
18b 18c 0 24
:4 0 3c :4 0 27
:2 0 28 :3 0 e4
190 192 :3 0 27
:2 0 3d :4 0 e7
194 196 :3 0 27
:2 0 3e :4 0 ea
198 19a :3 0 27
:2 0 2c :3 0 30
:3 0 10 :3 0 38
:3 0 19f 1a0 0
ed 19e 1a2 2f
:4 0 ef 19d 1a5
f2 19c 1a7 :3 0
27 :2 0 3f :4 0
f5 1a9 1ab :3 0
27 :2 0 2a :4 0
f8 1ad 1af :3 0
27 :2 0 1d :3 0
fb 1b1 1b3 :3 0
27 :2 0 2a :4 0
fe 1b5 1b7 :3 0
101 18d 1b9 :2 0
1bb 104 1bc 18a
1bb 0 1bd 106
0 1c8 40 :3 0
41 :3 0 1be 1bf
0 10 :3 0 38
:3 0 1c1 1c2 0
1d :3 0 42 :3 0
108 1c0 1c6 :2 0
1c8 10c 269 10
:3 0 43 :2 0 4
1c9 1ca 0 1f
:3 0 20 :3 0 1cc
1cd 0 1f :3 0
32 :3 0 1cf 1d0
0 44 :2 0 2
:4 0 45 :2 0 35
:2 0 33 :2 0 11b
1d5 1d7 :3 0 11e
1d1 1d9 1ce 1db
1da :2 0 22 :3 0
36 :3 0 1dd 1de
0 24 :4 0 46
:4 0 27 :2 0 28
:3 0 122 1e2 1e4
:3 0 125 1df 1e6
:2 0 1ff 22 :3 0
36 :3 0 1e8 1e9
0 24 :4 0 47
:4 0 27 :2 0 10
:3 0 48 :3 0 1ee
1ef 0 128 1ed
1f1 :3 0 27 :2 0
3f :4 0 12b 1f3
1f5 :3 0 27 :2 0
10 :3 0 49 :3 0
1f8 1f9 0 12e
1f7 1fb :3 0 131
1ea 1fd :2 0 1ff
134 200 1dc 1ff
0 201 137 0
211 4a :3 0 1e
:3 0 10 :3 0 48
:3 0 4b :3 0 10
:3 0 49 :3 0 4c
:3 0 4d :4 0 4e
1 :a 0 20d :2 0
211 203 20b :2 0
f :3 0 1e :3 0
20f :2 0 211 139
213 13d 212 211
:2 0 267 4f :3 0
10 :3 0 38 :3 0
216 217 0 50
:3 0 218 219 0
25f 1f :3 0 20
:3 0 21b 21c 0
1f :3 0 32 :3 0
21e 21f 0 44
:2 0 2 :4 0 51
:2 0 35 :2 0 33
:2 0 13f 224 226
:3 0 142 220 228
21d 22a 229 :2 0
22 :3 0 36 :3 0
22c 22d 0 24
:4 0 52 :4 0 27
:2 0 28 :3 0 146
231 233 :3 0 149
22e 235 :2 0 24f
22 :3 0 36 :3 0
237 238 0 24
:4 0 53 :4 0 27
:2 0 50 :3 0 14c
23c 23e :3 0 27
:2 0 54 :4 0 14f
240 242 :3 0 27
:2 0 55 :3 0 56
:3 0 33 :2 0 57
:2 0 152 245 249
156 244 24b :3 0
159 239 24d :2 0
24f 15c 250 22b
24f 0 251 15f
0 25f 4a :3 0
1e :3 0 4b :3 0
10 :3 0 49 :3 0
4c :3 0 4d :4 0
58 1 :a 0 25b
:2 0 25f 253 259
:2 0 f :3 0 1e
:3 0 25d :2 0 25f
161 262 :3 0 262
0 262 261 25f
260 :6 0 264 1
:3 0 166 266 168
265 264 :2 0 267
16a :2 0 269 16d
269 268 1c8 267
:6 0 26a :2 0 2
2c 269 26d :3 0
26c 26a 26e :8 0

179
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 9
6 a e 12
16 1a 1e 22
26 1 30 1
2e 1 37 1
35 1 3c 1
41 1 46 1
4c 1 52 1
58 1 60 1
5e 1 67 1
65 1 6c 1
79 1 85 2
88 8a 2 8d
8f 2 91 93
2 95 97 2
99 9b 2 9d
9f 2 a1 a3
2 a5 a7 2
a9 ab 2 b1
b3 2 b5 b7
2 b9 ba 2
bc bd 2 ad
bf 2 c1 c3
2 c9 cb 2
cd cf 2 d1
d2 2 d4 d5
2 c5 d7 2
d9 db 1 e1
2 e3 e4 2
dd e6 2 e8
ea 1 f0 2
f2 f3 2 ec
f5 2 f7 f9
1 ff 2 101
102 2 fb 104
2 106 108 1
10e 2 110 111
2 10a 113 2
115 117 2 119
11b 2 11d 11f
2 121 123 2
125 127 4 81
87 8c 129 1
12b 1 12d 2
137 139 3 135
136 13b 2 144
146 2 143 148
1 14a 1 14c
a 16d 16e 16f
170 171 172 173
174 175 176 2
182 184 3 180
181 186 2 18f
191 2 193 195
2 197 199 1
1a1 2 1a3 1a4
2 19b 1a6 2
1a8 1aa 2 1ac
1ae 2 1b0 1b2
2 1b4 1b6 2
18e 1b8 1 1ba
1 1bc 3 1c3
1c4 1c5 e 12e
14d 150 153 156
159 15c 15f 162
165 168 179 1bd
1c7 2 1d4 1d6
3 1d2 1d3 1d8
2 1e1 1e3 2
1e0 1e5 2 1ec
1f0 2 1f2 1f4
2 1f6 1fa 2
1eb 1fc 2 1e7
1fe 1 200 3
201 20c 210 1
1cb 2 223 225
3 221 222 227
2 230 232 2
22f 234 2 23b
23d 2 23f 241
3 246 247 248
2 243 24a 2
23a 24c 2 236
24e 1 250 4
21a 251 25a 25e
1 262 1 215
2 213 266 b
33 3a 3f 44
4a 50 56 5c
63 6a 71 
1
4
0 
26d
0
1
14
2
15
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
35 1 0
f 1 0
46 1 0
41 1 0
13 1 0
23 1 0
7 1 0
3c 1 0
52 1 0
3 1 0
65 1 0
58 1 0
4c 1 0
b 1 0
17 1 0
1b 1 0
5e 1 0
1f 1 0
2 0 1
6c 1 0
2e 1 0
0

/
SHOW ERRORS FUNCTION SP_U_PARTICIPANT;
ALTER FUNCTION SP_U_PARTICIPANT COMPILE DEBUG;
/******************************************************************************************************************
update resource assignments SECURITY
assign_id:      RES_ASSIGNMENT_ID or TSK_ASSIGNMENT_ID
security_id:    SECURITY_ID in TMT_GLOBAL_SECURITY
*******************************************************************************************************************/
Prompt == FUNCTION SP_U_CRI_SECURITY ==
CREATE OR REPLACE FUNCTION SP_U_CRI_SECURITY wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
71
2 :e:
1FUNCTION:
1SP_U_CRI_SECURITY:
1ASSIGN_ID:
1VARCHAR2:
1SECURITY_ID001:
1P_PLANNED_START:
1TIMESTAMP:
1P_PLANNED_FINISH:
1P_DELAY:
1PLS_INTEGER:
1P_UNITS:
1P_WORK_PERCENT:
1P_ACTUAL:
1RES_ID001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1A_ELEMENT_ID:
132:
1A_PARTICIPANT_ID:
1255:
1A_PARTICIPANT_NAME:
1A_SECURITY_NAME:
1H_FULL_NAME:
1A_RES_ASSIGNMENT_ID:
1A_SECURITY_ID:
1A_TEMP_ID:
1H_CREATED_BY:
1H_PROJECT_ID:
1A_ASSIGNMENT_COUNT:
10:
1A_ELEMENT_TYPE:
1H_RESPONSIBLE:
1A_PARTICIPANT:
1A_RESOURCE_TYPE:
1A_SECURITY_VALUE:
1H_PARTICIPANT:
1H_UPDATE:
1H_TABLE_TYPE:
1H_ASSIGN_STRING:
18192:
1H_TEMP_RES_TYPE:
11:
1H_TEMP_PARTICIPANT:
1H_TEMP_SECURITY_ID:
1H_WBS_SECURITY_ID:
1H_TEMP_BITFLAG:
1H_TEMP_SC_STATE:
1H_TRANSFED_CRI:
1H_CRI_TABLE:
1H_CRI_ELEMENT_TYPE:
1H_REC_USER:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_CRI_SECURITY(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_U_CRI_SECURITY(61) :: cplan.sql(20256) :: :
1:
1PMO_CNST:
1SC_TABLE_CRI:
1SC_STATE:
1FC_U_ASSIGNED_SECURITY:
14:
176:
1       RETURN_STATUS:: SP_U_CRI_SECURITY(77) :: cplan.sql(20272) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
183:
1           EXCEPTION:: SP_U_CRI_SECURITY(84) :: cplan.sql(20279) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
195:
1           EXCEPTION:: SP_U_CRI_SECURITY(96) :: cplan.sql(20291) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
2e4
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :2 a0 6e 7e
a0 b4 2e 7e 6e b4 2e 6e
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e :2 a0 6e 7e a0
b4 2e 7e 6e b4 2e 6e a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e :3 a0 a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 6e
d :2 a0 d :2 a0 d :2 a0 d :3 a0
6b d :2 a0 6b :5 a0 a5 b d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
2e4
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 84
80 56 8c 95 91 7f 9d aa
a6 7c b2 bb b7 a5 c3 a2
c8 cc d0 d4 d7 db f8 e3
e7 ea eb f3 e2 115 103 df
107 108 110 102 132 120 ff 124
125 12d 11f 14f 13d 11c 141 142
14a 13c 16c 15a 139 15e 15f 167
159 189 177 156 17b 17c 184 176
1a6 194 173 198 199 1a1 193 1c3
1b1 190 1b5 1b6 1be 1b0 1e0 1ce
1ad 1d2 1d3 1db 1cd 1fd 1eb 1ca
1ef 1f0 1f8 1ea 219 208 20c 1e7
214 207 235 224 228 204 230 223
251 240 244 220 24c 23f 26d 25c
260 23c 268 25b 289 278 27c 258
284 277 2a5 294 298 274 2a0 293
2c1 2b0 2b4 290 2bc 2af 2dd 2cc
2d0 2ac 2d8 2cb 2f9 2e8 2ec 2c8
2f4 2e7 316 304 2e4 308 309 311
303 333 321 300 325 326 32e 320
34f 33e 342 31d 34a 33d 36c 35a
33a 35e 35f 367 359 389 377 356
37b 37c 384 376 3a5 394 398 373
3a0 393 3c1 3b0 3b4 390 3bc 3af
3dd 3cc 3d0 3ac 3d8 3cb 3f9 3e8
3ec 3c8 3f4 3e7 415 404 408 3e4
410 403 432 420 400 424 425 42d
41f 452 43d 441 41c 445 44d 43c
459 45d 439 461 465 469 46c 471
472 1 474 479 47d 481 484 489
48d 491 494 499 49a 49c 4a1 4a4
4a8 4a9 4ae 4b3 4b6 4bb 4bc 4c1
4c4 4c8 4c9 4ce 4d1 4d6 4d7 4dc
4df 4e4 4e5 4ea 4ed 4f2 4f3 4f8
4fb 4ff 500 505 508 50d 50e 513
516 51b 51c 521 524 528 52c 531
534 538 539 53e 541 546 547 54c
551 552 554 559 55a 55c 55d 562
565 56a 56b 570 573 577 57b 580
583 587 588 58d 590 595 596 59b
5a0 5a1 5a3 5a8 5a9 5ab 5ac 5b1
5b4 5b9 5ba 5bf 5c2 5c6 5ca 5ce
5cf 5d1 5d6 5d7 5d9 5da 5df 5e2
5e7 5e8 5ed 5f0 5f4 5f8 5fc 5fd
5ff 604 605 607 608 60d 610 615
616 61b 61e 622 626 62a 62b 62d
632 633 635 636 63b 63e 643 644
649 64c 650 654 658 659 65b 660
661 663 664 669 66c 671 672 677
67a 67f 680 685 688 68c 68d 692
695 69a 69b 6a0 6a3 6a8 6a9 6ae
6af 6b4 6b6 6ba 6bd 6c1 6c5 6c8
6cc 6d0 6d3 6d6 6db 6de 6e1 6e4
6e5 6ea 6eb 1 6ed 6f2 6f6 6fa
6fd 702 707 70a 70e 70f 714 715
71a 71c 720 723 727 72c 730 734
738 73c 740 744 748 74c 750 754
758 75c 760 763 767 76b 76f 772
776 77a 77e 782 786 787 789 78d
791 795 798 79c 7a0 7a3 7a6 7ab
7ae 7b1 7b4 7b5 7ba 7bb 1 7bd
7c2 7c6 7ca 7cd 7d2 7d7 7da 7de
7df 7e4 7e7 7ec 7ed 7f2 7f5 7fa
7fb 800 803 807 80b 80f 813 816
817 819 81e 81f 821 822 827 82a
82f 830 835 838 83d 83e 843 846
84a 84b 850 853 858 859 85e 85f
864 866 86a 86d 871 875 878 87c
880 883 887 88b 88c 891 893 897
89b 89e 8a2 8a6 8a9 8ad 8b1 8b4
8b7 8bc 8bf 8c2 8c5 8c6 8cb 8cc
1 8ce 8d3 8d7 8db 8de 8e3 8e8
8eb 8ef 8f0 8f5 8f6 8fb 8ff 903
906 90b 910 913 917 91b 91e 91f
924 927 92c 92d 932 935 939 93d
940 941 946 947 94c 94e 952 955
959 95d 961 965 969 96d 971 975
979 985 98a 98e 992 996 99a 99c
99d 9a2 1 9a6 9aa 9ae 9b1 9b5
9b9 9bd 9c1 9c4 9c8 9cc 9cf 9d2
9d7 9da 9dd 9e0 9e1 9e6 9e7 1
9e9 9ee 9f2 9f6 9f9 9fe a03 a06
a0a a0b a10 a11 a16 a1a a1e a21
a26 a2b a2e a32 a33 a38 a3b a40
a41 a46 a49 a4d a51 a54 a57 a58
a5a a5b a60 a61 a66 a68 a6c a6f
a73 a77 a7b a7f a83 a87 a8b a97
a9c aa0 aa4 aa8 aac aae ab2 ab4
ac0 ac2 ac4 ac5 aca ace ad0 adc
ae0 ae2 ae3 aec 
2e4
2
0 1 a 6 10 :3 6 15 :3 6
16 :3 6 17 :3 6 e :3 6 e :3 6
15 :3 6 f :3 6 10 :2 6 1 3
a 13 a :2 1 4 11 1a 19
:2 11 :2 4 15 1e 1d :2 15 :2 4 17
20 1f :2 17 :2 4 14 1d 1c :2 14
:2 4 10 19 18 :2 10 :2 4 18 21
20 :2 18 :2 4 12 1b 1a :2 12 :2 4
e 17 16 :2 e :2 4 11 1a 19
:2 11 :2 4 11 1a 19 :2 11 :2 4 :2 17
26 17 :2 4 :2 13 22 13 :2 4 :2 12
21 12 :2 4 :2 12 21 12 :2 4 :2 14
23 14 :2 4 :2 15 24 15 :2 4 :2 12
21 12 :2 4 :2 d 1c d :2 4 :2 11
20 11 :2 4 14 1d 1c :2 14 :2 4
14 1d 1c :2 14 :2 4 :2 17 26 17
:2 4 17 20 1f :2 17 :2 4 16 1f
1e :2 16 :2 4 :2 13 22 13 :2 4 :2 14
23 14 :2 4 :2 13 22 13 :2 4 :2 10
1f 10 :2 4 :2 17 26 17 :2 4 f
18 17 :2 f :2 4 e 17 :3 e 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 59 5f 62
:2 59 70 8b 8 :2 70 d 10 :2 70
1a 1d :2 70 b e :2 70 13 16
:2 70 1b 1e :2 70 2d 30 :2 70 b
e :2 70 13 16 1f 26 2b 2e
:2 26 3e 41 :2 26 46 :2 1f 4f :2 16
:2 70 b e :2 70 13 16 1f 26
2b 2e :2 26 3f 42 :2 26 47 :2 1f
50 :2 16 :2 70 b e :2 70 13 16
1f 27 :2 1f 31 :2 16 :2 70 b e
:2 70 13 16 1f 27 :2 1f 31 :2 16
:2 70 b e :2 70 13 16 1f 27
:2 1f 38 :2 16 :2 70 b e :2 70 13
16 1f 27 :2 1f 32 :2 16 :2 70 b
e :2 70 13 16 :2 70 1b 1e :2 70
28 2b :2 70 30 33 :2 70 :2 7 4f
:2 4 7 :2 11 23 :2 2d 39 3c 51
53 54 :2 51 :2 23 :3 7 :2 d 12 1e
62 65 :2 1e :2 7 57 :3 4 14 :2 4
11 :2 4 15 :2 4 12 :2 4 14 :2 1d
:2 4 :2 d 19 30 3e 49 58 :2 19
4 7 :2 11 23 :2 2d 39 3c 51
53 54 :2 51 :2 23 :3 7 :2 d 12 1e
62 65 :2 1e 72 75 :2 1e 79 7c
:2 1e 86 89 92 9a :2 a3 :2 92 ae
:2 89 :2 1e b6 b9 :2 1e c1 c4 :2 1e
c9 cc :2 1e d6 d9 :2 1e :2 7 57
:3 4 :2 f 21 :2 2a 34 3f :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 55 57 58 :2 55 :2 26 :3 a :2 10
15 21 65 68 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 5b :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 52 54 55 :2 52 :2 23 :3 7 :2 d
12 1e 62 65 :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 58
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
2e4
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 :4 8
:4 9 :4 a :4 b 2
:4 c :2 1 :7 e :7 f
:7 10 :7 11 :7 12 :7 13
:7 14 :7 15 :7 16 :7 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :7 21 :7 22 :6 23
:7 24 :7 25 :6 26 :6 27
:6 28 :6 29 :6 2a :7 2b
:7 2d :b 2f :11 30 31
:2 30 :2 31 :2 30 :2 31
:2 30 :2 32 :2 30 :2 32
:2 30 :2 32 :2 30 :2 32
:2 30 :2 33 :2 30 :12 33
:2 30 :2 34 :2 30 :12 34
:2 30 :2 35 :2 30 :9 35
:2 30 :2 36 :2 30 :9 36
:2 30 :2 37 :2 30 :9 37
:2 30 :2 38 :2 30 :9 38
:2 30 :2 39 :2 30 :2 39
:2 30 :2 39 :2 30 :2 39
:2 30 :2 39 :4 30 :3 2f
:11 3c :b 3d :3 3c :3 42
:3 45 :3 46 :3 47 :5 49
:b 4a :11 4c :30 4d :3 4c
:a 4f 2e :3 52 :11 53
:b 54 :17 55 :3 53 :2 57
:3 58 :3 59 5a 58
57 58 :3 5b :3 52
:2 5c :5 5e :11 5f :b 60
:18 61 :3 5f :2 63 64
:3 65 66 64 63
64 :3 67 :2 5d :6 5c
51 :7 1 
aee
4
:3 0 1 :3 0 2
:a 0 2df 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 7 :3 0
6 :7 0 d c
:3 0 d 7c 0
b 7 :3 0 8
:7 0 11 10 :3 0
a :3 0 9 :7 0
15 14 :3 0 11
a2 0 f a
:3 0 b :7 0 19
18 :3 0 a :3 0
c :7 0 1d 1c
:3 0 15 :2 0 13
a :3 0 d :7 0
21 20 :3 0 4
:3 0 e :7 0 25
24 :3 0 f :3 0
10 :3 0 11 :2 0
4 29 2a 0
27 2b 0 2df
2 2c :2 0 15
:2 0 21 4 :3 0
13 :2 0 1f 2f
31 :6 0 34 32
0 2dd 0 12
:6 0 15 :2 0 25
4 :3 0 23 36
38 :6 0 3b 39
0 2dd 0 14
:6 0 13 :2 0 29
4 :3 0 27 3d
3f :6 0 42 40
0 2dd 0 16
:6 0 15 :2 0 2d
4 :3 0 2b 44
46 :6 0 49 47
0 2dd 0 17
:6 0 13 :2 0 31
4 :3 0 2f 4b
4d :6 0 50 4e
0 2dd 0 18
:6 0 13 :2 0 35
4 :3 0 33 52
54 :6 0 57 55
0 2dd 0 19
:6 0 13 :2 0 39
4 :3 0 37 59
5b :6 0 5e 5c
0 2dd 0 1a
:6 0 13 :2 0 3d
4 :3 0 3b 60
62 :6 0 65 63
0 2dd 0 1b
:6 0 13 :2 0 41
4 :3 0 3f 67
69 :6 0 6c 6a
0 2dd 0 1c
:6 0 1f :2 0 45
4 :3 0 43 6e
70 :6 0 73 71
0 2dd 0 1d
:6 0 1f :2 0 47
a :3 0 75 :7 0
79 76 77 2dd
0 1e :6 0 1f
:2 0 49 a :3 0
7b :7 0 7f 7c
7d 2dd 0 20
:6 0 1f :2 0 4b
a :3 0 81 :7 0
85 82 83 2dd
0 21 :6 0 1f
:2 0 4d a :3 0
87 :7 0 8b 88
89 2dd 0 22
:6 0 1f :2 0 4f
a :3 0 8d :7 0
91 8e 8f 2dd
0 23 :6 0 1f
:2 0 51 a :3 0
93 :7 0 97 94
95 2dd 0 24
:6 0 1f :2 0 53
a :3 0 99 :7 0
9d 9a 9b 2dd
0 25 :6 0 1f
:2 0 55 a :3 0
9f :7 0 a3 a0
a1 2dd 0 26
:6 0 29 :2 0 57
a :3 0 a5 :7 0
a9 a6 a7 2dd
0 27 :6 0 2b
:2 0 5b 4 :3 0
59 ab ad :6 0
b0 ae 0 2dd
0 28 :6 0 1f
:2 0 5f 4 :3 0
5d b2 b4 :6 0
b7 b5 0 2dd
0 2a :6 0 13
:2 0 61 a :3 0
b9 :7 0 bd ba
bb 2dd 0 2c
:6 0 13 :2 0 65
4 :3 0 63 bf
c1 :6 0 c4 c2
0 2dd 0 2d
:6 0 1f :2 0 69
4 :3 0 67 c6
c8 :6 0 cb c9
0 2dd 0 2e
:6 0 1f :2 0 6b
a :3 0 cd :7 0
d1 ce cf 2dd
0 2f :6 0 1f
:2 0 6d a :3 0
d3 :7 0 d7 d4
d5 2dd 0 30
:6 0 1f :2 0 6f
a :3 0 d9 :7 0
dd da db 2dd
0 31 :6 0 1f
:2 0 71 a :3 0
df :7 0 e3 e0
e1 2dd 0 32
:6 0 13 :2 0 73
a :3 0 e5 :7 0
e9 e6 e7 2dd
0 33 :6 0 f2
f3 0 77 4
:3 0 75 eb ed
:6 0 f0 ee 0
2dd 0 34 :6 0
f8 f9 0 79
10 :3 0 11 :2 0
4 f4 :7 0 f7
f5 0 2dd 0
35 :6 0 36 :3 0
37 :3 0 36 :3 0
38 :3 0 fb fc
0 2 :4 0 7b
fd ff fa 101
100 :2 0 39 :3 0
3a :3 0 103 104
0 3b :4 0 36
:3 0 3c :3 0 107
108 0 2 :4 0
7d 109 10b 3d
:4 0 3e :2 0 3f
:3 0 7f 10e 110
:3 0 40 :4 0 3e
:2 0 41 :4 0 82
113 115 :3 0 3e
:2 0 3 :3 0 85
117 119 :3 0 3e
:2 0 41 :4 0 88
11b 11d :3 0 3e
:2 0 42 :4 0 8b
11f 121 :3 0 3e
:2 0 41 :4 0 8e
123 125 :3 0 3e
:2 0 5 :3 0 91
127 129 :3 0 3e
:2 0 41 :4 0 94
12b 12d :3 0 3e
:2 0 42 :4 0 97
12f 131 :3 0 3e
:2 0 43 :3 0 44
:3 0 41 :4 0 3e
:2 0 6 :3 0 9a
137 139 :3 0 3e
:2 0 41 :4 0 9d
13b 13d :3 0 45
:4 0 a0 135 140
46 :4 0 a3 134
143 a6 133 145
:3 0 3e :2 0 42
:4 0 a9 147 149
:3 0 3e :2 0 43
:3 0 44 :3 0 41
:4 0 3e :2 0 8
:3 0 ac 14f 151
:3 0 3e :2 0 41
:4 0 af 153 155
:3 0 45 :4 0 b2
14d 158 46 :4 0
b5 14c 15b b8
14b 15d :3 0 3e
:2 0 42 :4 0 bb
15f 161 :3 0 3e
:2 0 43 :3 0 47
:3 0 9 :3 0 be
165 167 46 :4 0
c0 164 16a c3
163 16c :3 0 3e
:2 0 42 :4 0 c6
16e 170 :3 0 3e
:2 0 43 :3 0 47
:3 0 b :3 0 c9
174 176 46 :4 0
cb 173 179 ce
172 17b :3 0 3e
:2 0 42 :4 0 d1
17d 17f :3 0 3e
:2 0 43 :3 0 47
:3 0 c :3 0 d4
183 185 46 :4 0
d6 182 188 d9
181 18a :3 0 3e
:2 0 42 :4 0 dc
18c 18e :3 0 3e
:2 0 43 :3 0 47
:3 0 d :3 0 df
192 194 46 :4 0
e1 191 197 e4
190 199 :3 0 3e
:2 0 42 :4 0 e7
19b 19d :3 0 3e
:2 0 41 :4 0 ea
19f 1a1 :3 0 3e
:2 0 e :3 0 ed
1a3 1a5 :3 0 3e
:2 0 41 :4 0 f0
1a7 1a9 :3 0 3e
:2 0 48 :4 0 f3
1ab 1ad :3 0 f6
105 1af :2 0 1b1
fb 1b2 102 1b1
0 1b3 fd 0
23d 36 :3 0 37
:3 0 1b4 1b5 0
36 :3 0 49 :3 0
1b7 1b8 0 2b
:2 0 2 :4 0 4a
:2 0 4b :2 0 2b
:2 0 ff 1bd 1bf
:3 0 102 1b9 1c1
1b6 1c3 1c2 :2 0
39 :3 0 4c :3 0
1c5 1c6 0 3b
:4 0 4d :4 0 3e
:2 0 3f :3 0 106
1ca 1cc :3 0 109
1c7 1ce :2 0 1d0
10c 1d1 1c4 1d0
0 1d2 10e 0
23d 1c :3 0 4e
:4 0 1d3 1d4 0
23d 1b :3 0 3
:3 0 1d6 1d7 0
23d 1a :3 0 5
:3 0 1d9 1da 0
23d 34 :3 0 e
:3 0 1dc 1dd 0
23d 27 :3 0 4f
:3 0 50 :3 0 1e0
1e1 0 1df 1e2
0 23d 10 :3 0
51 :3 0 1e4 1e5
0 52 :3 0 27
:3 0 1b :3 0 1a
:3 0 34 :3 0 110
1e7 1ec 1e6 1ed
0 23d 36 :3 0
37 :3 0 1ef 1f0
0 36 :3 0 49
:3 0 1f2 1f3 0
53 :2 0 2 :4 0
54 :2 0 4b :2 0
2b :2 0 115 1f8
1fa :3 0 118 1f4
1fc 1f1 1fe 1fd
:2 0 39 :3 0 4c
:3 0 200 201 0
3b :4 0 55 :4 0
3e :2 0 3f :3 0
11c 205 207 :3 0
3e :2 0 56 :4 0
11f 209 20b :3 0
3e :2 0 57 :4 0
122 20d 20f :3 0
3e :2 0 43 :3 0
47 :3 0 10 :3 0
51 :3 0 214 215
0 125 213 217
46 :4 0 127 212
21a 12a 211 21c
:3 0 3e :2 0 58
:4 0 12d 21e 220
:3 0 3e :2 0 41
:4 0 130 222 224
:3 0 3e :2 0 1b
:3 0 133 226 228
:3 0 3e :2 0 41
:4 0 136 22a 22c
:3 0 139 202 22e
:2 0 230 13c 231
1ff 230 0 232
13e 0 23d 59
:3 0 5a :3 0 233
234 0 10 :3 0
51 :3 0 236 237
0 1b :3 0 5b
:3 0 140 235 23b
:2 0 23d 144 2de
10 :3 0 5c :2 0
4 23e 23f 0
36 :3 0 37 :3 0
241 242 0 36
:3 0 49 :3 0 244
245 0 5d :2 0
2 :4 0 5e :2 0
4b :2 0 2b :2 0
14f 24a 24c :3 0
152 246 24e 243
250 24f :2 0 39
:3 0 4c :3 0 252
253 0 3b :4 0
5f :4 0 3e :2 0
3f :3 0 156 257
259 :3 0 159 254
25b :2 0 274 39
:3 0 4c :3 0 25d
25e 0 3b :4 0
60 :4 0 3e :2 0
10 :3 0 61 :3 0
263 264 0 15c
262 266 :3 0 3e
:2 0 58 :4 0 15f
268 26a :3 0 3e
:2 0 10 :3 0 62
:3 0 26d 26e 0
162 26c 270 :3 0
165 25f 272 :2 0
274 168 275 251
274 0 276 16b
0 286 63 :3 0
35 :3 0 10 :3 0
61 :3 0 64 :3 0
10 :3 0 62 :3 0
65 :3 0 66 :4 0
67 1 :a 0 282
:2 0 286 278 280
:2 0 f :3 0 35
:3 0 284 :2 0 286
16d 288 171 287
286 :2 0 2dc 68
:3 0 10 :3 0 51
:3 0 28b 28c 0
69 :3 0 28d 28e
0 2d4 36 :3 0
37 :3 0 290 291
0 36 :3 0 49
:3 0 293 294 0
5d :2 0 2 :4 0
6a :2 0 4b :2 0
2b :2 0 173 299
29b :3 0 176 295
29d 292 29f 29e
:2 0 39 :3 0 4c
:3 0 2a1 2a2 0
3b :4 0 6b :4 0
3e :2 0 3f :3 0
17a 2a6 2a8 :3 0
17d 2a3 2aa :2 0
2c4 39 :3 0 4c
:3 0 2ac 2ad 0
3b :4 0 6c :4 0
3e :2 0 69 :3 0
180 2b1 2b3 :3 0
3e :2 0 6d :4 0
183 2b5 2b7 :3 0
3e :2 0 6e :3 0
6f :3 0 2b :2 0
70 :2 0 186 2ba
2be 18a 2b9 2c0
:3 0 18d 2ae 2c2
:2 0 2c4 190 2c5
2a0 2c4 0 2c6
193 0 2d4 63
:3 0 35 :3 0 64
:3 0 10 :3 0 62
:3 0 65 :3 0 66
:4 0 71 1 :a 0
2d0 :2 0 2d4 2c8
2ce :2 0 f :3 0
35 :3 0 2d2 :2 0
2d4 195 2d7 :3 0
2d7 0 2d7 2d6
2d4 2d5 :6 0 2d9
1 :3 0 19a 2db
19c 2da 2d9 :2 0
2dc 19e :2 0 2de
1a1 2de 2dd 23d
2dc :6 0 2df :2 0
2 2c 2de 2e2
:3 0 2e1 2df 2e3
:8 0 
1c1
4
:3 0 1 3 1
7 1 b 1
f 1 13 1
17 1 1b 1
1f 1 23 9
6 a e 12
16 1a 1e 22
26 1 30 1
2e 1 37 1
35 1 3e 1
3c 1 45 1
43 1 4c 1
4a 1 53 1
51 1 5a 1
58 1 61 1
5f 1 68 1
66 1 6f 1
6d 1 74 1
7a 1 80 1
86 1 8c 1
92 1 98 1
9e 1 a4 1
ac 1 aa 1
b3 1 b1 1
b8 1 c0 1
be 1 c7 1
c5 1 cc 1
d2 1 d8 1
de 1 e4 1
ec 1 ea 1
f1 1 fe 1
10a 2 10d 10f
2 112 114 2
116 118 2 11a
11c 2 11e 120
2 122 124 2
126 128 2 12a
12c 2 12e 130
2 136 138 2
13a 13c 2 13e
13f 2 141 142
2 132 144 2
146 148 2 14e
150 2 152 154
2 156 157 2
159 15a 2 14a
15c 2 15e 160
1 166 2 168
169 2 162 16b
2 16d 16f 1
175 2 177 178
2 171 17a 2
17c 17e 1 184
2 186 187 2
180 189 2 18b
18d 1 193 2
195 196 2 18f
198 2 19a 19c
2 19e 1a0 2
1a2 1a4 2 1a6
1a8 2 1aa 1ac
4 106 10c 111
1ae 1 1b0 1
1b2 2 1bc 1be
3 1ba 1bb 1c0
2 1c9 1cb 2
1c8 1cd 1 1cf
1 1d1 4 1e8
1e9 1ea 1eb 2
1f7 1f9 3 1f5
1f6 1fb 2 204
206 2 208 20a
2 20c 20e 1
216 2 218 219
2 210 21b 2
21d 21f 2 221
223 2 225 227
2 229 22b 2
203 22d 1 22f
1 231 3 238
239 23a a 1b3
1d2 1d5 1d8 1db
1de 1e3 1ee 232
23c 2 249 24b
3 247 248 24d
2 256 258 2
255 25a 2 261
265 2 267 269
2 26b 26f 2
260 271 2 25c
273 1 275 3
276 281 285 1
240 2 298 29a
3 296 297 29c
2 2a5 2a7 2
2a4 2a9 2 2b0
2b2 2 2b4 2b6
3 2bb 2bc 2bd
2 2b8 2bf 2
2af 2c1 2 2ab
2c3 1 2c5 4
28f 2c6 2cf 2d3
1 2d7 1 28a
2 288 2db 1f
33 3a 41 48
4f 56 5d 64
6b 72 78 7e
84 8a 90 96
9c a2 a8 af
b6 bc c3 ca
d0 d6 dc e2
e8 ef f6 
1
4
0 
2e2
0
1
14
2
29
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
3c 1 0
b8 1 0
80 1 0
f 1 0
92 1 0
be 1 0
13 1 0
23 1 0
7 1 0
b1 1 0
9e 1 0
35 1 0
98 1 0
d2 1 0
c5 1 0
e4 1 0
5f 1 0
8c 1 0
d8 1 0
51 1 0
66 1 0
cc 1 0
7a 1 0
2e 1 0
3 1 0
86 1 0
de 1 0
2 0 1
a4 1 0
6d 1 0
b 1 0
58 1 0
17 1 0
74 1 0
1b 1 0
1f 1 0
4a 1 0
ea 1 0
aa 1 0
43 1 0
f1 1 0
0

/
SHOW ERRORS FUNCTION SP_U_CRI_SECURITY;
ALTER FUNCTION SP_U_CRI_SECURITY COMPILE DEBUG;
Prompt == FUNCTION FC_DEL_PROF_0_EFFORT ==
CREATE OR REPLACE FUNCTION FC_DEL_PROF_0_EFFORT wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
50
2 :e:
1FUNCTION:
1FC_DEL_PROF_0_EFFORT:
1H_PROJECT_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1RETURN:
1PLS_INTEGER:
1H_TSK_ASSIGNMENT_ID:
132:
1H_RES_ASSIGNMENT_ID:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
10:
1CURSOR:
1C_RA01:
1TA:
1TSK_ASSIGNMENT_ID:
1RES_ASSIGNMENT_ID:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1TASK_ID:
1RESOURCE_TYPE:
1PLANNED_WORK:
1SELECT TA.TSK_ASSIGNMENT_ID, TA.RES_ASSIGNMENT_ID :n         FROM TASK_ASSIGN+
1MENTS TA :n         WHERE TA.PROJECT_ID = h_project_id AND TA.TASK_ID <> TA.P+
1ROJECT_ID :n         AND TA.RESOURCE_TYPE = '1' AND TA.PLANNED_WORK = 0:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_DEL_PROF_0_EFFORT(:
1':
1);:
1CHECK_TRACE:
11:
123:
1+:
1FPUT:
1               ENTER:: FC_DEL_PROF_0_EFFORT(24) :: cplan.sql(20335) :: :
1OPEN:
1LOOP:
1FOUND:
1PMO_DB2M:
1SC_STATE:
1100:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1TRUE:
1=:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
153:
1           EXCEPTION:: FC_DEL_PROF_0_EFFORT(54) :: cplan.sql(20365) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1FC_BEFORE_D_RES_ASSIGN:
1RESOURCE_ASSIGNMENTS:
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_res_assignment_i+
1d:
175:
1           EXCEPTION:: FC_DEL_PROF_0_EFFORT(76) :: cplan.sql(20387) :: :
1CLOSE:
191:
1           EXCEPTION:: FC_DEL_PROF_0_EFFORT(92) :: cplan.sql(20403) :: :
197:
1                EXIT:: FC_DEL_PROF_0_EFFORT(98) :: cplan.sql(20409) :: :
1STATE:: :
0

0
0
248
2
0 a0 8d 90 :3 a0 b0 3f b4
:2 a0 2c 6a a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :11 a0 12a bd b7 11 a4 b1
:2 a0 6b :2 a0 6b 6e a5 b a
10 :2 a0 6b 6e :2 a0 6b 6e a5
b 6e 7e a0 b4 2e 6e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
e9 dd b3 :4 a0 e9 d3 5 :2 a0
f :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c :2 a0 6b a0
7e a0 6b b4 2e 5a a0 2b
b7 19 3c :3 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 6b d :3 a0 51
a5 b d :2 a0 6b a0 d :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
a0 47 :2 a0 e9 c1 :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :3 a0 6b 65
b7 a4 b1 11 68 4f 1d 17
b5 
248
2
0 3 7 2b 1f 23 27 1e
32 1b 37 3b 3f 43 60 4b
4f 52 53 5b 4a 7d 6b 47
6f 70 78 6a 99 88 8c 94
67 b4 a0 a4 ac af 87 bb
bf 84 d0 d3 d7 db df e3
e7 eb ef f3 f7 fb ff 103
107 10b 10f 113 117 11b 127 12c
12e 13a 13e 140 144 148 14b 14f
153 156 15b 15c 1 15e 163 167
16b 16e 173 177 17b 17e 183 184
186 18b 18e 192 193 198 19d 1a0
1a5 1a6 1ab 1ae 1b2 1b3 1b8 1bb
1c0 1c1 1c6 1c9 1ce 1cf 1d4 1d5
1da 1dc 1e0 1e3 1e7 1eb 1ee 1f2
1f6 1f9 1fc 201 204 207 20a 20b
210 211 1 213 218 21c 220 223
228 22d 230 234 235 23a 23b 240
242 246 249 24d 251 256 25a 25b
25f 263 267 26b 270 275 279 27d
281 286 28a 28e 291 294 298 29a
29e 2a2 2a5 2a8 2ac 2ae 2b2 2b6
2b9 2bd 2c1 2c4 2c8 2cb 2cf 2d2
2d3 2d8 2db 2df 2e5 2e7 2eb 2ee
2f2 2f6 2fa 306 30a 30f 313 316
317 31c 320 324 327 32a 32e 330
334 338 33b 33e 342 344 348 34c
34f 351 355 359 35d 360 364 368
36a 36b 370 1 374 378 37c 37f
383 387 38b 38f 392 396 39a 39d
3a0 3a5 3a8 3ab 3ae 3af 3b4 3b5
1 3b7 3bc 3c0 3c4 3c7 3cc 3d1
3d4 3d8 3d9 3de 3e1 3e6 3e7 3ec
3ef 3f4 3f5 3fa 3fd 401 402 407
40a 40f 410 415 418 41c 420 423
426 427 429 42a 42f 430 435 437
43b 43e 440 444 446 452 454 456
457 45c 460 462 46e 470 474 478
47c 47f 483 487 48b 48f 492 493
495 499 49d 4a1 4a4 4a8 4ac 4b0
4b4 4b8 4c4 4c8 4cd 4d1 4d4 4d5
4da 4de 4e2 4e5 4e8 4ec 4ee 4f2
4f6 4f9 4fc 500 502 506 50a 50d
50f 513 517 51b 51e 522 526 528
529 52e 1 532 536 53a 53d 541
545 549 54d 550 554 558 55b 55e
563 566 569 56c 56d 572 573 1
575 57a 57e 582 585 58a 58f 592
596 597 59c 59f 5a4 5a5 5aa 5ad
5b2 5b3 5b8 5bb 5bf 5c0 5c5 5c8
5cd 5ce 5d3 5d6 5da 5de 5e1 5e4
5e5 5e7 5e8 5ed 5ee 5f3 5f5 5f9
5fc 5fe 602 604 610 612 614 615
61a 61e 620 62c 62e 630 634 63b
63f 643 648 64a 64e 652 655 659
65d 65f 663 667 66b 66e 672 676
678 679 67e 1 682 686 68a 68d
691 695 699 69d 6a0 6a4 6a8 6ab
6ae 6b3 6b6 6b9 6bc 6bd 6c2 6c3
1 6c5 6ca 6ce 6d2 6d5 6da 6df
6e2 6e6 6e7 6ec 6ef 6f4 6f5 6fa
6fd 702 703 708 70b 70f 710 715
718 71d 71e 723 726 72a 72e 731
734 735 737 738 73d 73e 743 745
749 74c 74e 752 754 760 762 764
765 76a 76e 770 77c 77e 782 786
789 78d 791 794 797 79c 79f 7a2
7a5 7a6 7ab 7ac 1 7ae 7b3 7b7
7bb 7be 7c3 7c8 7cb 7cf 7d0 7d5
7d8 7dd 7de 7e3 7e6 7eb 7ec 7f1
7f4 7f8 7fc 7ff 800 805 806 80b
80d 811 814 818 81c 820 823 827
829 82d 82f 83b 83f 841 842 84b 
248
2
0 1 a 6 16 1a 21 :2 6
1 3 a :2 1 4 18 21 20
:2 18 :2 4 18 21 20 :2 18 :2 4 :3 10
:2 4 :2 16 2e 16 4 7 e 0
:2 7 11 14 27 2a f 20 10
13 20 31 34 3f 42 e 11
29 2c a :6 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
5c 62 65 :2 5c 73 91 8 :2 73
d 10 :2 73 1d 20 :2 73 25 28
:2 73 :2 7 52 :2 4 7 :2 11 23 :2 2d
39 3c 54 56 57 :2 54 :2 23 :3 7
:2 d 12 1e 65 68 :2 1e :2 7 5a
:3 4 9 :4 4 d 19 2e :3 7 a
11 :2 a :2 13 1f a 17 a :2 13
1f a :4 7 b :2 14 20 1d :2 29
:2 1d :3 a 39 :2 7 16 2d 41 a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 5e 60 61 :2 5e :2 2c :3 10 :2 16
1b 27 6e 71 :2 27 7e 81 :2 27
85 88 :2 27 94 97 :2 27 9f a2
:2 27 ae b1 b8 c1 c4 :2 b1 :2 27
:2 10 64 :2 d :2 a :4 16 :2 a 7 :3 4
7 1c :2 25 :2 7 16 2d 42 :2 16
:2 7 :2 10 1c 7 16 31 45 a
11 d 19 :3 17 d :2 16 22 d
1e d :2 16 22 d :4 a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 5e 60 61 :2 5e :2 2c :3 10 :2 16
1b 27 6e 71 :2 27 7e 81 :2 27
85 88 :2 27 94 97 :2 27 9f a2
:2 27 ae b1 b8 c1 c4 :2 b1 :2 27
:2 10 64 :2 d :2 a :4 16 :2 a 7 :4 4
8 1 7 d :3 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 5b 5d 5e :2 5b :2 29
:3 d :2 13 18 24 6b 6e :2 24 7b
7e :2 24 82 85 :2 24 91 94 :2 24
9c 9f :2 24 ab ae b5 be c1
:2 ae :2 24 :2 d 61 :2 a :2 7 :4 13 :2 7
4 :3 1 7 :2 11 23 :2 2d 39 3c
54 56 57 :2 54 :2 23 :3 7 :2 d 12
1e 65 68 :2 1e 75 78 :2 1e 7c
7f :2 1e 89 8c :2 95 :2 1e :2 7 5a
:3 4 b :2 14 4 :9 1 
248
4
0 :2 1 :6 3 2
:2 4 :2 1 :7 6 :7 7
:5 8 :6 9 :2 b 0
:2 b :4 c :2 d :7 e
:4 f c :5 b :b 12
:11 13 14 :2 13 :2 14
:2 13 :2 14 :2 13 :2 14
:4 13 :3 12 :11 17 :b 18
:3 17 :5 1b 1d :6 1e
:3 1f :5 20 1f :5 22
21 :3 1f :a 24 :2 25
:3 24 :4 29 :6 2a :5 2b
2a :5 2d 2c :3 2a
28 30 :5 31 :3 30
:2 32 :5 34 :11 35 :24 36
:3 35 :2 33 :6 32 2f
:3 1d :5 3b :7 3c :5 3d
:4 3f :6 40 :5 41 40
:5 43 42 :3 40 3e
46 :5 47 :3 46 :2 48
:5 4a :11 4b :24 4c :3 4b
:2 49 :6 48 45 :4 1d
50 11 :4 53 :5 54
52 56 :5 57 :3 56
:2 58 :5 5a :11 5b :24 5c
:3 5b :2 59 :6 58 55
:3 11 :11 61 :19 62 :3 61
:5 64 :2 11 :7 1 
84d
4
:3 0 1 :3 0 2
:a 0 243 1 :7 0
5 :2 0 3 4
:3 0 5 :3 0 6
:3 0 3 :5 0 1
7 6 :3 0 7
:3 0 8 :3 0 9
b 0 243 2
c :2 0 a :2 0
9 6 :3 0 a
:2 0 7 f 11
:6 0 14 12 0
241 0 9 :6 0
f 84 0 d
6 :3 0 b 16
18 :6 0 1b 19
0 241 0 b
:9 0 11 d :3 0
1d :7 0 20 1e
0 241 0 c
:6 0 8 :3 0 22
0 2 :5 0 f
:2 0 26 23 24
241 0 e :6 0
10 :3 0 11 :a 0
2 3e :4 0 28
2b 0 29 :3 0
12 :3 0 13 :3 0
12 :3 0 14 :3 0
15 :3 0 12 :3 0
12 :3 0 16 :3 0
3 :3 0 12 :3 0
17 :3 0 12 :3 0
16 :3 0 12 :3 0
18 :3 0 12 :3 0
19 :4 0 1a 1
:8 0 3f 28 2b
40 0 241 13
40 42 3f 41
:6 0 3e :7 0 40
1b :3 0 1c :3 0
43 44 0 1b
:3 0 1d :3 0 46
47 0 2 :4 0
15 48 4a 45
4c 4b :2 0 1e
:3 0 1f :3 0 4e
4f 0 20 :4 0
1b :3 0 21 :3 0
52 53 0 2
:4 0 17 54 56
22 :4 0 23 :2 0
24 :3 0 19 59
5b :3 0 25 :4 0
23 :2 0 26 :4 0
1c 5e 60 :3 0
23 :2 0 3 :3 0
1f 62 64 :3 0
23 :2 0 26 :4 0
22 66 68 :3 0
23 :2 0 27 :4 0
25 6a 6c :3 0
28 50 6e :2 0
70 2d 71 4d
70 0 72 2f
0 23f 1b :3 0
1c :3 0 73 74
0 1b :3 0 28
:3 0 76 77 0
29 :2 0 2 :4 0
2a :2 0 2b :2 0
29 :2 0 31 7c
7e :3 0 34 78
80 75 82 81
:2 0 1e :3 0 2c
:3 0 84 85 0
20 :4 0 2d :4 0
23 :2 0 24 :3 0
38 89 8b :3 0
3b 86 8d :2 0
8f 3e 90 83
8f 0 91 40
0 23f 2e :3 0
11 :4 0 95 :2 0
23f 93 96 :3 0
2f :3 0 11 :3 0
9 :3 0 b :4 0
9c :2 0 1ac 98
9d :3 0 42 :3 0
11 :3 0 30 :3 0
9e 9f :3 0 31
:3 0 32 :3 0 a1
a2 0 f :2 0
a3 a4 0 a6
45 ad 31 :3 0
32 :3 0 a7 a8
0 33 :2 0 a9
aa 0 ac 47
ae a0 a6 0
af 0 ac 0
af 49 0 1ac
31 :3 0 32 :3 0
b0 b1 0 31
:3 0 34 :2 0 35
:3 0 b3 b5 0
4e b4 b7 :3 0
b8 :2 0 36 :8 0
bc 51 bd b9
bc 0 be 53
0 1ac 15 :3 0
13 :3 0 9 :4 0
37 1 :8 0 d8
30 :4 0 c3 :3 0
38 :3 0 39 :2 0
57 c6 c7 :3 0
31 :3 0 32 :3 0
c9 ca 0 f
:2 0 cb cc 0
ce 5a d5 31
:3 0 32 :3 0 cf
d0 0 33 :2 0
d1 d2 0 d4
5c d6 c8 ce
0 d7 0 d4
0 d7 5e 0
d8 61 12b 3a
:3 0 31 :3 0 32
:3 0 da db 0
3b :3 0 dc dd
0 df 64 e1
66 e0 df :2 0
129 3c :3 0 31
:3 0 32 :3 0 e4
e5 0 3b :3 0
e6 e7 0 121
1b :3 0 1c :3 0
e9 ea 0 1b
:3 0 28 :3 0 ec
ed 0 3d :2 0
2 :4 0 3e :2 0
2b :2 0 29 :2 0
68 f2 f4 :3 0
6b ee f6 eb
f8 f7 :2 0 1e
:3 0 2c :3 0 fa
fb 0 20 :4 0
3f :4 0 23 :2 0
24 :3 0 6f ff
101 :3 0 23 :2 0
40 :4 0 72 103
105 :3 0 23 :2 0
41 :4 0 75 107
109 :3 0 23 :2 0
3b :3 0 78 10b
10d :3 0 23 :2 0
42 :4 0 7b 10f
111 :3 0 23 :2 0
43 :3 0 44 :3 0
29 :2 0 45 :2 0
7e 114 118 82
113 11a :3 0 85
fc 11c :2 0 11e
88 11f f9 11e
0 120 8a 0
121 8c 124 :3 0
124 0 124 123
121 122 :6 0 126
4 :3 0 8f 128
91 127 126 :2 0
129 93 :2 0 12b
0 12b 12a d8
129 :6 0 1ac 3
:3 0 e :3 0 31
:3 0 32 :3 0 12e
12f 0 12d 130
0 1ac c :3 0
46 :3 0 b :3 0
f :2 0 96 133
136 132 137 0
1ac 31 :3 0 32
:3 0 139 13a 0
e :3 0 13b 13c
0 1ac 47 :3 0
14 :3 0 b :4 0
48 1 :8 0 157
30 :4 0 142 :3 0
38 :3 0 39 :2 0
9b 145 146 :3 0
31 :3 0 32 :3 0
148 149 0 f
:2 0 14a 14b 0
14d 9e 154 31
:3 0 32 :3 0 14e
14f 0 33 :2 0
150 151 0 153
a0 155 147 14d
0 156 0 153
0 156 a2 0
157 a5 1aa 3a
:3 0 31 :3 0 32
:3 0 159 15a 0
3b :3 0 15b 15c
0 15e a8 160
aa 15f 15e :2 0
1a8 3c :3 0 31
:3 0 32 :3 0 163
164 0 3b :3 0
165 166 0 1a0
1b :3 0 1c :3 0
168 169 0 1b
:3 0 28 :3 0 16b
16c 0 3d :2 0
2 :4 0 49 :2 0
2b :2 0 29 :2 0
ac 171 173 :3 0
af 16d 175 16a
177 176 :2 0 1e
:3 0 2c :3 0 179
17a 0 20 :4 0
4a :4 0 23 :2 0
24 :3 0 b3 17e
180 :3 0 23 :2 0
40 :4 0 b6 182
184 :3 0 23 :2 0
41 :4 0 b9 186
188 :3 0 23 :2 0
3b :3 0 bc 18a
18c :3 0 23 :2 0
42 :4 0 bf 18e
190 :3 0 23 :2 0
43 :3 0 44 :3 0
29 :2 0 45 :2 0
c2 193 197 c6
192 199 :3 0 c9
17b 19b :2 0 19d
cc 19e 178 19d
0 19f ce 0
1a0 d0 1a3 :3 0
1a3 0 1a3 1a2
1a0 1a1 :6 0 1a5
6 :3 0 d3 1a7
d5 1a6 1a5 :2 0
1a8 d7 :2 0 1aa
0 1aa 1a9 157
1a8 :6 0 1ac 3
:3 0 da 1ae 2f
:4 0 1ac :4 0 23f
4b :3 0 11 :4 0
1b2 :2 0 1b8 1b0
0 31 :3 0 32
:3 0 1b3 1b4 0
3b :3 0 1b5 1b6
0 1b8 e3 20b
3a :3 0 31 :3 0
32 :3 0 1ba 1bb
0 3b :3 0 1bc
1bd 0 1bf e6
1c1 e8 1c0 1bf
:2 0 209 3c :3 0
31 :3 0 32 :3 0
1c4 1c5 0 3b
:3 0 1c6 1c7 0
201 1b :3 0 1c
:3 0 1c9 1ca 0
1b :3 0 28 :3 0
1cc 1cd 0 3d
:2 0 2 :4 0 4c
:2 0 2b :2 0 29
:2 0 ea 1d2 1d4
:3 0 ed 1ce 1d6
1cb 1d8 1d7 :2 0
1e :3 0 2c :3 0
1da 1db 0 20
:4 0 4d :4 0 23
:2 0 24 :3 0 f1
1df 1e1 :3 0 23
:2 0 40 :4 0 f4
1e3 1e5 :3 0 23
:2 0 41 :4 0 f7
1e7 1e9 :3 0 23
:2 0 3b :3 0 fa
1eb 1ed :3 0 23
:2 0 42 :4 0 fd
1ef 1f1 :3 0 23
:2 0 43 :3 0 44
:3 0 29 :2 0 45
:2 0 100 1f4 1f8
104 1f3 1fa :3 0
107 1dc 1fc :2 0
1fe 10a 1ff 1d9
1fe 0 200 10c
0 201 10e 204
:3 0 204 0 204
203 201 202 :6 0
206 8 :3 0 111
208 113 207 206
:2 0 209 115 :2 0
20b 0 20b 20a
1b8 209 :6 0 23f
1 :3 0 1b :3 0
1c :3 0 20d 20e
0 1b :3 0 28
:3 0 210 211 0
29 :2 0 2 :4 0
4e :2 0 2b :2 0
29 :2 0 118 216
218 :3 0 11b 212
21a 20f 21c 21b
:2 0 1e :3 0 2c
:3 0 21e 21f 0
20 :4 0 4f :4 0
23 :2 0 24 :3 0
11f 223 225 :3 0
23 :2 0 40 :4 0
122 227 229 :3 0
23 :2 0 50 :4 0
125 22b 22d :3 0
23 :2 0 31 :3 0
32 :3 0 230 231
0 128 22f 233
:3 0 12b 220 235
:2 0 237 12e 238
21d 237 0 239
130 0 23f 7
:3 0 31 :3 0 32
:3 0 23b 23c 0
23d :2 0 23f 132
242 :3 0 242 13a
242 241 23f 240
:6 0 243 :2 0 2
c 242 246 :3 0
245 243 247 :8 0

140
4
:3 0 1 3 1
8 1 10 1
e 1 17 1
15 1 1c 1
21 1 3d 1
49 1 55 2
58 5a 2 5d
5f 2 61 63
2 65 67 2
69 6b 4 51
57 5c 6d 1
6f 1 71 2
7b 7d 3 79
7a 7f 2 88
8a 2 87 8c
1 8e 1 90
2 99 9a 1
a5 1 ab 2
ad ae 1 b6
2 b2 b6 1
bb 1 bd 1
c5 2 c4 c5
1 cd 1 d3
2 d5 d6 2
c2 d7 1 de
1 d9 2 f1
f3 3 ef f0
f5 2 fe 100
2 102 104 2
106 108 2 10a
10c 2 10e 110
3 115 116 117
2 112 119 2
fd 11b 1 11d
1 11f 2 e8
120 1 124 1
e3 2 e1 128
2 134 135 1
144 2 143 144
1 14c 1 152
2 154 155 2
141 156 1 15d
1 158 2 170
172 3 16e 16f
174 2 17d 17f
2 181 183 2
185 187 2 189
18b 2 18d 18f
3 194 195 196
2 191 198 2
17c 19a 1 19c
1 19e 2 167
19f 1 1a3 1
162 2 160 1a7
8 9b af be
12b 131 138 13d
1aa 2 1b1 1b7
1 1be 1 1b9
2 1d1 1d3 3
1cf 1d0 1d5 2
1de 1e0 2 1e2
1e4 2 1e6 1e8
2 1ea 1ec 2
1ee 1f0 3 1f5
1f6 1f7 2 1f2
1f9 2 1dd 1fb
1 1fd 1 1ff
2 1c8 200 1
204 1 1c3 2
1c1 208 2 215
217 3 213 214
219 2 222 224
2 226 228 2
22a 22c 2 22e
232 2 221 234
1 236 1 238
7 72 91 94
1ae 20b 239 23e
5 13 1a 1f
25 3e 
1
4
0 
246
0
1
14
9
7
0 1 1 3 4 3 6 1
8 0 0 0 0 0 0 0
0 0 0 0 
e 1 0
28 1 2
1c 1 0
2 0 1
15 1 0
21 1 0
3 1 0
0

/
SHOW ERRORS FUNCTION FC_DEL_PROF_0_EFFORT;
ALTER FUNCTION FC_DEL_PROF_0_EFFORT COMPILE DEBUG;
/****************************************************************************************
 id = TSK_ASSIGN_ID
 bitflag:
        1 = Copy Schedule to Baseline (includes budgets)
        2 = Copy Planned to Schedule
        3 = Copy Proposed to Schedule
        4 = Copy Forecast to Schedule (includes budgets)
        5 = Copy Forecast  Scheduled to Planned
        6 = Move Planned to Schedule
        7 = Append Planned to Schedule
 bussiness rules:
    1. Do not copy date for completed tasks (MILESTONE_PERCENT = 100)
    2. If the task has ACTUAL do not change ETC, WORK_TODATE, SD, FD
    3. When copy Forecast Date to ..., ETC is Forecast Effort, and clear Forcast dates after copy
    4. If both Forcast dates exists ignor forcast start, consider only forcast finish and ETC
    5. Calculated Forecast Start should not be in the past (is >= NOW)
    6. When copy Forcast to and assignments exists forcast rollup wins, and clear Forcast dates after copy
    7. Actual Finish date does not rollup from Assignments to Task
    8. When copy Planned to Schedule clear Planned Dates, Duration  Effort
****************************************************************************************/
Prompt == FUNCTION FC_COMMIT_ASSIGN ==
CREATE OR REPLACE FUNCTION FC_COMMIT_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
1bb
2 :e:
1FUNCTION:
1FC_COMMIT_ASSIGN:
1H_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1SH_H_BITFLAG:
1PLS_INTEGER:
1SH_H_ROLLUP_FLAG:
11:
1RETURN:
1H_BITFLAG:
1H_ROLLUP_FLAG:
1COALESCE:
10:
1H_BITID:
1RAW:
136:
1PMO_CNST:
1SC_ZERO_BIT:
1H_BITID1:
1H_PROJECT_ID:
132:
1H_PROFILE_ID:
1H_ELEMENT_ID:
1H_RES_ASSIGNMENT_ID:
1H_DAYOFYEAR:
1DATE:
1H_RES_ID:
1H_TASK_ID:
1H_TSK_ASSIGNMENT_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_START_DATE:
1TIMESTAMP:
1H_FINISH_DATE:
1H_SCHED_WORK:
1H_BILLABLE:
1H_TOTAL:
1H_DAY_MIN:
1H_MIN_PER_DAY:
1H_CHANGE_FLAG:
1H_TYPE_ID:
1H_FROM_PRJ:
1H_TSK_PRJ:
1H_WORK:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1STMT:
18000:
1H_REC_STATUS:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
1CURSOR:
1C270:
1TA:
1TSK_ASSIGNMENT_ID:
1RESOURCE_ID:
1TASK_ASSIGNMENTS:
1JOIN:
1TMT_WBS:
1W:
1PROJECT_ID:
1ELEMENT_ID:
1TASK_ID:
1BIT_FLAG:
1RESOURCE_TYPE:
1PROJECT_ASSIGNMENT_ID:
1SELECT TA.TSK_ASSIGNMENT_ID, TA.RESOURCE_ID:n         FROM TASK_ASSIGNMENTS T+
1A JOIN TMT_WBS W:n         ON W.PROJECT_ID = TA.PROJECT_ID AND W.ELEMENT_ID =+
1 TA.TASK_ID:n         WHERE W.PROJECT_ID = h_project_id AND TA.BIT_FLAG = '0'+
1:n         AND TA.RESOURCE_TYPE = '0' AND TA.PROJECT_ASSIGNMENT_ID IS Null:
1CMM1:
1PMO_DB2M:
1REF_CURSOR:
1C27:
1DAY_YEAR:
1SCHED_MIN:
1BIT_SCHED:
1TASK_DAY_OF_YEAR:
1SELECT DAY_YEAR, SCHED_MIN, BIT_SCHED FROM TASK_DAY_OF_YEAR:n         WHERE P+
1ROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_id AND BIT_FLAG = '0':
1C54:
1SELECT TASK_ID, TSK_ASSIGNMENT_ID:n         FROM TASK_ASSIGNMENTS:n         W+
1HERE BIT_FLAG = '0' AND PROJECT_ASSIGNMENT_ID = h_id:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_COMMIT_ASSIGN(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
169:
1+:
1FPUT:
1               ENTER:: FC_COMMIT_ASSIGN(70) :: cplan.sql(20510) :: :
1MINUTE_PER_DAY:
1REC_STATUS:
1SELECT COALESCE(MINUTE_PER_DAY, 480), REC_STATUS:n      INTO h_min_per_day, h+
1_rec_status:n      FROM TMT_WBS :n      WHERE ELEMENT_ID = h_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
187:
1           EXCEPTION:: FC_COMMIT_ASSIGN(88) :: cplan.sql(20528) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1T:
195:
1        RETURN_ERROR:: FC_COMMIT_ASSIGN(96) :: cplan.sql(20536) :: :
1STATE:: :
1CANNOT_UPDATE_LOCKED_RECORD:
1 ID:: :
198:
1                EXIT:: FC_COMMIT_ASSIGN(99) :: cplan.sql(20539) :: :
1PMODEFINES:
1PMO_RETURN_ERROR:
1FALSE:
1SC_SQL_NO_DATA:
1RA:
1PROFILE_ID:
1RESOURCE_ASSIGNMENTS:
1MILESTONE_PERCENT:
1RES_ASSIGNMENT_ID:
1SELECT ta.PROJECT_ID, ra.PROFILE_ID,ra.ELEMENT_ID,  ta.RESOURCE_ID, CASE WHEN+
1 ta.PROJECT_ID = ta.TASK_ID THEN 1 ELSE 0 END, :n         CASE WHEN ta.PROJEC+
1T_ASSIGNMENT_ID IS NuLL THEN 0 ELSE 1 END:n         INTO h_project_id, h_prof+
1ile_id, h_element_id, h_res_id, h_tsk_prj, h_from_prj:n         FROM TASK_ASS+
1IGNMENTS ta, RESOURCE_ASSIGNMENTS ra :n         WHERE ta.TSK_ASSIGNMENT_ID = +
1h_id AND ta.MILESTONE_PERCENT < 10000 AND ta.RESOURCE_TYPE='0' :n         AND+
1 ra.RES_ASSIGNMENT_ID = ta.RES_ASSIGNMENT_ID:
1119:
1           EXCEPTION:: FC_COMMIT_ASSIGN(120) :: cplan.sql(20560) :: :
18:
1126:
1      RETURN_INVALID:: FC_COMMIT_ASSIGN(127) :: cplan.sql(20567) :: :
1RECORD_NOT_FOUND:
1129:
1                EXIT:: FC_COMMIT_ASSIGN(130) :: cplan.sql(20570) :: :
1PMO_RETURN_INVALID:
1ELSIF:
1134:
1        RETURN_ERROR:: FC_COMMIT_ASSIGN(135) :: cplan.sql(20575) :: :
1PROJECT_ASSIGNMENT_EXISTS:
1137:
1                EXIT:: FC_COMMIT_ASSIGN(138) :: cplan.sql(20578) :: :
1FC_DEL_PROF_0_EFFORT:
1IS NOT NULL:
1PLANNED_WORK:
1SELECT TSK_ASSIGNMENT_ID, RES_ASSIGNMENT_ID INTO h_tsk_assignment_id, h_res_a+
1ssignment_id :n            FROM TASK_ASSIGNMENTS :n            WHERE PROJECT_+
1ID = h_project_id AND TASK_ID = h_element_id :n            AND RESOURCE_ID = +
1h_profile_id AND RESOURCE_TYPE = '1' AND PLANNED_WORK = 0:
1162:
1           EXCEPTION:: FC_COMMIT_ASSIGN(163) :: cplan.sql(20603) :: :
1PROF_ASSIGNMENTS:
1SELECT 0 INTO h_temp_var:n               FROM PROF_ASSIGNMENTS :n            +
1   WHERE RES_ASSIGNMENT_ID = h_res_assignment_id:
1180:
1           EXCEPTION:: FC_COMMIT_ASSIGN(181) :: cplan.sql(20621) :: :
1SC_SQL_SUCCESS:
1REGULAR_COST:
1SPECIAL_COST:
1REGULAR_RATE:
1SPECIAL_RATE:
1BASELINE3_START:
1BASELINE3_FINISH:
1BASELINE3_WORK:
1BILLABLE:
1T_UNIT:
1C_EFFORT:
1C_UNIT:
1C_OCCURRENCE:
1C_CONTOUR:
1CONTOUR_TYPE:
1UNITS_MSP:
1CONSIDER:
1CAPITAL_EXPENSE:
1BASELINE3_SCH_FLAG:
1RATES_EDITED:
1ASSIGN_UNITS:
1RATE_ADJUSTMENT:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1BAK_ASSIGN_STRING:
1UPDATE PROF_ASSIGNMENTS SET (RESOURCE_ID,RESOURCE_TYPE,PROJECT_ASSIGNMENT_ID,+
1REGULAR_COST,SPECIAL_COST,:n                  REGULAR_RATE,SPECIAL_RATE,BASEL+
1INE3_START,BASELINE3_FINISH,BASELINE3_WORK,BILLABLE,T_UNIT,C_EFFORT,C_UNIT,C_+
1OCCURRENCE,C_CONTOUR,:n                  CONTOUR_TYPE,UNITS_MSP,CONSIDER,CAPI+
1TAL_EXPENSE,BASELINE3_SCH_FLAG,RATES_EDITED,ASSIGN_UNITS,RATE_ADJUSTMENT, :n +
1                 BAK_START_DT, BAK_FINISH_DT, BAK_WORK, BAK_ASSIGN_STRING) = +
1:n                  (SELECT h_profile_id,'1',PROJECT_ASSIGNMENT_ID,REGULAR_CO+
1ST,SPECIAL_COST,:n                  REGULAR_RATE,SPECIAL_RATE,BASELINE3_START+
1,BASELINE3_FINISH,BASELINE3_WORK,BILLABLE,T_UNIT,C_EFFORT,C_UNIT,C_OCCURRENCE+
1,C_CONTOUR,:n                  CONTOUR_TYPE,UNITS_MSP,CONSIDER,CAPITAL_EXPENS+
1E,BASELINE3_SCH_FLAG,RATES_EDITED,ASSIGN_UNITS,RATE_ADJUSTMENT, :n           +
1       BAK_START_DT, BAK_FINISH_DT, BAK_WORK, BAK_ASSIGN_STRING :n           +
1       FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id):n+
1                  WHERE RES_ASSIGNMENT_ID = h_res_assignment_id:
1FOUND:
1TRUE:
1100:
1208:
1           EXCEPTION:: FC_COMMIT_ASSIGN(209) :: cplan.sql(20649) :: :
1INSERT INTO PROF_ASSIGNMENTS (RES_ASSIGNMENT_ID,PROJECT_ID,TASK_ID,RESOURCE_I+
1D,RESOURCE_TYPE,PROJECT_ASSIGNMENT_ID,REGULAR_COST,SPECIAL_COST,:n           +
1       REGULAR_RATE,SPECIAL_RATE,BASELINE3_START,BASELINE3_FINISH,BASELINE3_W+
1ORK,BILLABLE,T_UNIT,C_EFFORT,C_UNIT,C_OCCURRENCE,C_CONTOUR,:n                +
1  CONTOUR_TYPE,UNITS_MSP,CONSIDER,CAPITAL_EXPENSE,BASELINE3_SCH_FLAG,RATES_ED+
1ITED,ASSIGN_UNITS,RATE_ADJUSTMENT, :n                  BAK_START_DT, BAK_FINI+
1SH_DT, BAK_WORK, BAK_ASSIGN_STRING) :n                  SELECT RES_ASSIGNMENT+
1_ID,PROJECT_ID,TASK_ID,RESOURCE_ID,RESOURCE_TYPE,PROJECT_ASSIGNMENT_ID,REGULA+
1R_COST,SPECIAL_COST,:n                  REGULAR_RATE,SPECIAL_RATE,BASELINE3_S+
1TART,BASELINE3_FINISH,BASELINE3_WORK,BILLABLE,T_UNIT,C_EFFORT,C_UNIT,C_OCCURR+
1ENCE,C_CONTOUR,:n                  CONTOUR_TYPE,UNITS_MSP,CONSIDER,CAPITAL_EX+
1PENSE,BASELINE3_SCH_FLAG,RATES_EDITED,ASSIGN_UNITS,RATE_ADJUSTMENT, :n       +
1           BAK_START_DT, BAK_FINISH_DT, BAK_WORK, BAK_ASSIGN_STRING  :n      +
1            FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_+
1id:
1235:
1           EXCEPTION:: FC_COMMIT_ASSIGN(236) :: cplan.sql(20676) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1254:
1           EXCEPTION:: FC_COMMIT_ASSIGN(255) :: cplan.sql(20695) :: :
1FC_BEFORE_D_RES_ASSIGN:
1DELETE FROM RESOURCE_ASSIGNMENTS WHERE RES_ASSIGNMENT_ID = h_res_assignment_i+
1d:
1276:
1           EXCEPTION:: FC_COMMIT_ASSIGN(277) :: cplan.sql(20717) :: :
1SELECT COALESCE(MINUTE_PER_DAY, 480) INTO h_min_per_day FROM TMT_WBS WHERE EL+
1EMENT_ID = h_project_id:
1293:
1           EXCEPTION:: FC_COMMIT_ASSIGN(294) :: cplan.sql(20734) :: :
1SELECT TSK_ASSIGNMENT_ID, RESOURCE_ID, TASK_ID, C_EFFORT FROM TASK_ASSIGNMENT+
1S :
1WHERE TSK_ASSIGNMENT_ID = ':
1' AND MILESTONE_PERCENT < 10000 AND RESOURCE_TYPE='0' AND BIT_FLAG = '0' :
13:
1TYPE_ID:
1SC_PROPOSAL:
1SC_PROJECT:
1SCHED_START:
1PLANNED_START:
1SCHED_FINISH:
1PLANNED_FINISH:
1SCHED_DURATION:
1PLANNED_DURATION:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1FORECAST_FINISH:
1FORECAST_EFFORT:
1ETC:
1FORECAST_DURATION:
1REC_DATETIME:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1ASSIGN_COUNT:
1WORK_TODATE:
1UPDATE TMT_WBS SET:n            TYPE_ID         = CASE WHEN TYPE_ID = pmo_cns+
1t.SC_PROPOSAL THEN pmo_cnst.SC_PROJECT ELSE TYPE_ID END,:n            SCHED_S+
1TART     = COALESCE(PLANNED_START, SCHED_START),:n            SCHED_FINISH   +
1 = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n            SCHED_DURATION  = CAS+
1E WHEN PLANNED_DURATION = 0 THEN SCHED_DURATION ELSE PLANNED_DURATION END,:n +
1           SCHED_EFFORT    = PLANNED_EFFORT,:n            PLANNED_START   = N+
1ull,:n            PLANNED_FINISH  = Null,:n            PLANNED_DURATION = 0,+
1:n            FORECAST_START  = Null,:n            FORECAST_FINISH = Null,:n +
1           FORECAST_EFFORT = PLANNED_EFFORT,:n            ETC             = P+
1LANNED_EFFORT,:n            FORECAST_DURATION = 0,:n            REC_DATETIME +
1= SYSTIMESTAMP:n            WHERE PROJECT_ID = h_project_id AND TYPE_ID IN (p+
1mo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,pmo_cnst.SC_TASK_TYPE2,pmo_cnst.SC_TAS+
1K_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.SC_PERSONAL_TASK,pmo_cnst.SC_ACTIVE_AD+
1M_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pmo_cnst.SC_WBS_CHANGE_REQUEST_TASK,pmo_+
1cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.SC_WBS_RISK_TASK,pmo_cnst.SC_WBS_ISSUE_+
1TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,pmo_cnst.SC_WBS_DEFECT_TASK,pmo_cnst.SC+
1_WBS_SERVICE_REQUEST_TASK) AND ASSIGN_COUNT = 0 AND WORK_TODATE = 0 AND SCHED+
1_EFFORT = 0:
1340:
1           EXCEPTION:: FC_COMMIT_ASSIGN(341) :: cplan.sql(20781) :: :
1OPEN:
1LOOP:
1!=:
1EXIT:
1SCHED_WORK:
1SCHED_LABOR_COST:
1PLANNED_LABOR_COST:
1SCHED_LABOR_REVENUE:
1PLANNED_LABOR_REVENUE:
1FORECAST_LABOR_COST:
1ACTUAL_LABOR_COST:
1FORECAST_LABOR_REVENUE:
1ACTUAL_LABOR_REVENUE:
1UPDATE TASK_ASSIGNMENTS SET:n               BIT_FLAG = '2',:n               S+
1CHED_START = COALESCE(PLANNED_START, SCHED_START),:n               SCHED_FINI+
1SH = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n               SCHED_DURATION =+
1 CASE WHEN PLANNED_DURATION > 0 THEN PLANNED_DURATION ELSE SCHED_DURATION END+
1,:n               SCHED_WORK = PLANNED_WORK,:n               ETC = PLANNED_WO+
1RK,:n               BAK_START_DT = COALESCE(PLANNED_START, SCHED_START),:n   +
1            BAK_FINISH_DT = COALESCE(PLANNED_FINISH, SCHED_FINISH),:n        +
1       BAK_WORK = PLANNED_WORK,:n               SCHED_LABOR_COST = CASE WHEN +
1PLANNED_LABOR_COST > 0.00 THEN PLANNED_LABOR_COST ELSE SCHED_LABOR_COST END,+
1:n               SCHED_LABOR_REVENUE = CASE WHEN PLANNED_LABOR_REVENUE > 0.00+
1 THEN PLANNED_LABOR_REVENUE ELSE SCHED_LABOR_REVENUE END,:n               FOR+
1ECAST_LABOR_COST = CASE WHEN BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/6+
10.00) * REGULAR_COST) + ACTUAL_LABOR_COST END,:n               FORECAST_LABOR+
1_REVENUE = CASE WHEN BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * +
1REGULAR_RATE) + ACTUAL_LABOR_REVENUE END,:n               PLANNED_START = Nul+
1l, PLANNED_FINISH = Null, PLANNED_DURATION = 0, PLANNED_WORK = 0,:n          +
1     FORECAST_START = Null, FORECAST_FINISH = Null, FORECAST_DURATION = 0:n  +
1             WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1390:
1           EXCEPTION:: FC_COMMIT_ASSIGN(391) :: cplan.sql(20831) :: :
1UPDATE TASK_DAY_OF_YEAR SET BIT_FLAG = '2':n               WHERE PROJECT_ID =+
1 h_project_id AND TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1410:
1           EXCEPTION:: FC_COMMIT_ASSIGN(411) :: cplan.sql(20851) :: :
1CLOSE:
1427:
1           EXCEPTION:: FC_COMMIT_ASSIGN(428) :: cplan.sql(20868) :: :
1ROLLUP_BITS:
1SC_ASSIGNMENT_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = pmo_cnst.SC_ASSIGNMENT_BIT:n         WHERE P+
1ROJECT_ID = h_project_id AND ASSIGN_COUNT > 0 AND WORK_TODATE = 0 AND SCHED_E+
1FFORT = 0:
1448:
1           EXCEPTION:: FC_COMMIT_ASSIGN(449) :: cplan.sql(20889) :: :
12:
1SELECT TSK_ASSIGNMENT_ID, RESOURCE_ID, TASK_ID, C_EFFORT FROM TASK_ASSIGNMENT+
1S WHERE PROJECT_ID = TASK_ID AND :
1PROJECT_ID = ':
1BUDGETS:
1B:
1ESTIMATED_BASELINE3:
1ESTIMATED_BASELINE2:
1ESTIMATED_BASELINE1:
1ESTIMATED_BUDGET:
1BUDGET_BASELINE3:
1BUDGET_BASELINE2:
1BUDGET_BASELINE1:
1BUDGET:
1UPDATE BUDGETS B SET:n               B.ESTIMATED_BASELINE3 = B.ESTIMATED_BASE+
1LINE2,:n               B.ESTIMATED_BASELINE2 = B.ESTIMATED_BASELINE1,:n      +
1         B.ESTIMATED_BASELINE1 = B.ESTIMATED_BUDGET,:n               B.BUDGET+
1_BASELINE3 = B.BUDGET_BASELINE2,:n               B.BUDGET_BASELINE2 = B.BUDGE+
1T_BASELINE1,:n               B.BUDGET_BASELINE1 = B.BUDGET:n               WH+
1ERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1508:
1           EXCEPTION:: FC_COMMIT_ASSIGN(509) :: cplan.sql(20949) :: :
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BASELINE3_DURATION:
1UNRESOLVED_DURATION:
1BASELINE3_LABOR_COST:
1BASELINE3_LABOR_REVENUE:
1BASELINE2_START:
1BASELINE1_START:
1BASELINE2_FINISH:
1BASELINE1_FINISH:
1BASELINE2_DURATION:
1BASELINE1_DURATION:
1BASELINE2_WORK:
1BASELINE1_WORK:
1BASELINE2_LABOR_COST:
1BASELINE1_LABOR_COST:
1BASELINE2_LABOR_REVENUE:
1BASELINE1_LABOR_REVENUE:
1B_REGULAR_COST:
1B_REGULAR_RATE:
1B_SPECIAL_COST:
1B_SPECIAL_RATE:
1UPDATE TASK_ASSIGNMENTS SET:n               BASELINE3_START		= CASE WHEN BASE+
1LINE3_SCH_FLAG = 0 THEN UNRESOLVED_START ELSE BASELINE3_START END,:n         +
1      BASELINE3_FINISH	= CASE WHEN BASELINE3_SCH_FLAG = 0 THEN UNRESOLVED_FIN+
1ISH ELSE BASELINE3_FINISH END,:n               BASELINE3_DURATION	= CASE WHEN+
1 BASELINE3_SCH_FLAG = 0 THEN UNRESOLVED_DURATION ELSE BASELINE3_DURATION END,+
1:n               BASELINE3_WORK		= CASE WHEN BASELINE3_SCH_FLAG = 0 THEN SCHE+
1D_WORK + PLANNED_WORK ELSE BASELINE3_WORK END,:n               BASELINE3_LABO+
1R_COST	= CASE WHEN BASELINE3_SCH_FLAG = 0 THEN SCHED_LABOR_COST + PLANNED_LAB+
1OR_COST ELSE BASELINE3_LABOR_COST END, :n               BASELINE3_LABOR_REVEN+
1UE = CASE WHEN BASELINE3_SCH_FLAG = 0 THEN SCHED_LABOR_REVENUE + PLANNED_LABO+
1R_REVENUE ELSE BASELINE3_LABOR_REVENUE END,:n               BASELINE2_START =+
1 BASELINE1_START, BASELINE2_FINISH = BASELINE1_FINISH, BASELINE2_DURATION = B+
1ASELINE1_DURATION, BASELINE2_WORK = BASELINE1_WORK,:n               BASELINE2+
1_LABOR_COST = BASELINE1_LABOR_COST, BASELINE2_LABOR_REVENUE = BASELINE1_LABOR+
1_REVENUE,:n               BASELINE1_START = UNRESOLVED_START, BASELINE1_FINIS+
1H = UNRESOLVED_FINISH, BASELINE1_DURATION = UNRESOLVED_DURATION, BASELINE1_WO+
1RK = SCHED_WORK + PLANNED_WORK,:n               BASELINE1_LABOR_COST = SCHED_+
1LABOR_COST + PLANNED_LABOR_COST, BASELINE1_LABOR_REVENUE = SCHED_LABOR_REVENU+
1E + PLANNED_LABOR_REVENUE,:n               B_REGULAR_COST = REGULAR_COST, B_R+
1EGULAR_RATE = REGULAR_RATE, B_SPECIAL_COST = SPECIAL_COST, B_SPECIAL_RATE = S+
1PECIAL_RATE:n               WHERE TSK_ASSIGNMENT_ID = h_id:
1540:
1           EXCEPTION:: FC_COMMIT_ASSIGN(541) :: cplan.sql(20981) :: :
1PROJECT_ASSIGNMENTS:
1ESTIMATED_BASELINE3_START:
1ESTIMATED_BASELINE2_START:
1ESTIMATED_BASELINE1_START:
1ESTIMATED_SCHED_START:
1ESTIMATED_PLANNED_START:
1ESTIMATED_BASELINE3_FINISH:
1ESTIMATED_BASELINE2_FINISH:
1ESTIMATED_BASELINE1_FINISH:
1ESTIMATED_SCHED_FINISH:
1ESTIMATED_PLANNED_FINISH:
1ESTIMATED_BASELINE3_EFFORT:
1ESTIMATED_BASELINE2_EFFORT:
1ESTIMATED_BASELINE1_EFFORT:
1ESTIMATED_SCHED_EFFORT:
1ESTIMATED_PLANNED_EFFORT:
1ESTIMATED_BASELINE3_COST:
1ESTIMATED_BASELINE2_COST:
1ESTIMATED_BASELINE1_COST:
1ESTIMATED_SCHED_COST:
1ESTIMATED_PLANNED_COST:
1ESTIMATED_BASELINE3_REVENUE:
1ESTIMATED_BASELINE2_REVENUE:
1ESTIMATED_BASELINE1_REVENUE:
1ESTIMATED_SCHED_REVENUE:
1ESTIMATED_PLANNED_REVENUE:
1BASELINE_START:
1BASELINE_FINISH:
1BASELINE_DURATION:
1BASELINE_WORK:
1BASELINE_LABOR_COST:
1BASELINE_LABOR_REVENUE:
1UPDATE PROJECT_ASSIGNMENTS SET:n               ESTIMATED_BASELINE3_START = ES+
1TIMATED_BASELINE2_START,:n               ESTIMATED_BASELINE2_START = ESTIMATE+
1D_BASELINE1_START,:n               ESTIMATED_BASELINE1_START = CASE WHEN ESTI+
1MATED_SCHED_START IS NOT NULL THEN ESTIMATED_SCHED_START ELSE ESTIMATED_PLANN+
1ED_START END,:n               ESTIMATED_BASELINE3_FINISH = ESTIMATED_BASELINE+
12_FINISH,:n               ESTIMATED_BASELINE2_FINISH = ESTIMATED_BASELINE1_FI+
1NISH,:n               ESTIMATED_BASELINE1_FINISH = CASE WHEN ESTIMATED_SCHED_+
1FINISH IS NOT NULL THEN ESTIMATED_SCHED_FINISH ELSE ESTIMATED_PLANNED_FINISH +
1END,:n               ESTIMATED_BASELINE3_EFFORT = ESTIMATED_BASELINE2_EFFORT,+
1:n               ESTIMATED_BASELINE2_EFFORT = ESTIMATED_BASELINE1_EFFORT,:n  +
1             ESTIMATED_BASELINE1_EFFORT = CASE WHEN ESTIMATED_SCHED_EFFORT > +
10 THEN ESTIMATED_SCHED_EFFORT ELSE ESTIMATED_PLANNED_EFFORT END,:n           +
1    ESTIMATED_BASELINE3_COST = ESTIMATED_BASELINE2_COST,:n               ESTI+
1MATED_BASELINE2_COST = ESTIMATED_BASELINE1_COST,:n               ESTIMATED_BA+
1SELINE1_COST = CASE WHEN ESTIMATED_SCHED_COST > 0.00 THEN ESTIMATED_SCHED_COS+
1T ELSE ESTIMATED_PLANNED_COST END,:n               ESTIMATED_BASELINE3_REVENU+
1E = ESTIMATED_BASELINE2_REVENUE,:n               ESTIMATED_BASELINE2_REVENUE +
1= ESTIMATED_BASELINE1_REVENUE,:n               ESTIMATED_BASELINE1_REVENUE = +
1CASE WHEN ESTIMATED_SCHED_REVENUE > 0.00 THEN ESTIMATED_SCHED_REVENUE ELSE ES+
1TIMATED_PLANNED_REVENUE END,:n               BASELINE_START = UNRESOLVED_STAR+
1T,:n               BASELINE_FINISH = UNRESOLVED_FINISH,:n               BASEL+
1INE_DURATION = UNRESOLVED_DURATION,:n               BASELINE_WORK = SCHED_WOR+
1K + PLANNED_WORK,:n               BASELINE_LABOR_COST = SCHED_LABOR_COST + PL+
1ANNED_LABOR_COST,:n               BASELINE_LABOR_REVENUE = SCHED_LABOR_REVENU+
1E + PLANNED_LABOR_REVENUE:n               WHERE PROJECT_ID = h_project_id:
1581:
1           EXCEPTION:: FC_COMMIT_ASSIGN(582) :: cplan.sql(21022) :: :
1SELECT PLANNED_WORK INTO h_day_min FROM TASK_ASSIGNMENTS WHERE BIT_FLAG = '0'+
1 AND TSK_ASSIGNMENT_ID = h_id:
1602:
1           EXCEPTION:: FC_COMMIT_ASSIGN(603) :: cplan.sql(21043) :: :
1IS NULL:
1CASEEND0000:
1SELECT TSK_ASSIGNMENT_ID, CASE WHEN C_EFFORT = 0 THEN 0 ELSE C_EFFORT + h_wor+
1k END:n               INTO h_prj_assignment_id, h_work:n               FROM T+
1ASK_ASSIGNMENTS WHERE BIT_FLAG = '2' AND TASK_ID = h_project_id AND RESOURCE_+
1ID = h_res_id:
1623:
1           EXCEPTION:: FC_COMMIT_ASSIGN(624) :: cplan.sql(21064) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_id:
1648:
1           EXCEPTION:: FC_COMMIT_ASSIGN(649) :: cplan.sql(21089) :: :
1EFFORT_WEEK:
1DELETE FROM EFFORT_WEEK WHERE TSK_ASSIGNMENT_ID = h_id:
1667:
1           EXCEPTION:: FC_COMMIT_ASSIGN(668) :: cplan.sql(21108) :: :
1RESOURCE_ASSIGN_ROLES:
1DELETE FROM RESOURCE_ASSIGN_ROLES WHERE RES_ASSIGNMENT_ID = h_id:
1686:
1           EXCEPTION:: FC_COMMIT_ASSIGN(687) :: cplan.sql(21127) :: :
1RESOURCE_ASSIGN_SKILLS:
1DELETE FROM RESOURCE_ASSIGN_SKILLS WHERE RES_ASSIGNMENT_ID = h_id:
1705:
1           EXCEPTION:: FC_COMMIT_ASSIGN(706) :: cplan.sql(21146) :: :
1UTL_RAW:
1BIT_OR:
1UPDATE TASK_DAY_OF_YEAR SET SCHED_MIN = SCHED_MIN + h_day_min,:n             +
1        BIT_SCHED = UTL_RAW.BIT_OR(BIT_SCHED, h_bitID):n                     +
1WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_prj_assignment_id A+
1ND DAY_YEAR = h_dayofyear:
1754:
1           EXCEPTION:: FC_COMMIT_ASSIGN(755) :: cplan.sql(21195) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_id AND DAY_YEAR = h_dayofyear:
1775:
1           EXCEPTION:: FC_COMMIT_ASSIGN(776) :: cplan.sql(21216) :: :
1UPDATE TASK_DAY_OF_YEAR SET TSK_ASSIGNMENT_ID = h_prj_assignment_id WHERE PRO+
1JECT_ID = h_project_id AND TSK_ASSIGNMENT_ID = h_id AND DAY_YEAR = h_dayofyea+
1r:
1794:
1           EXCEPTION:: FC_COMMIT_ASSIGN(795) :: cplan.sql(21235) :: :
1814:
1           EXCEPTION:: FC_COMMIT_ASSIGN(815) :: cplan.sql(21255) :: :
1830:
1           EXCEPTION:: FC_COMMIT_ASSIGN(831) :: cplan.sql(21271) :: :
1PARENT_ID:
1UPDATE TASK_DAY_OF_YEAR SET BIT_FLAG = '2', PARENT_ID = h_prj_assignment_id:n+
1               WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_id:
1850:
1           EXCEPTION:: FC_COMMIT_ASSIGN(851) :: cplan.sql(21291) :: :
1SD:
1SC_SS:
1FD:
1SC_SF:
1UPDATE TASK_ASSIGNMENTS SET:n                  BIT_FLAG = '2',:n             +
1     SD = pmo_cnst.SC_SS, FD = pmo_cnst.SC_SF,:n                  SCHED_START+
1 = PLANNED_START,:n                  SCHED_FINISH = PLANNED_FINISH,:n        +
1          SCHED_DURATION = PLANNED_DURATION,:n                  SCHED_WORK = +
1PLANNED_WORK,:n                  BAK_START_DT = PLANNED_START,:n             +
1     BAK_FINISH_DT = PLANNED_FINISH,:n                  BAK_WORK = PLANNED_WO+
1RK,:n                  SCHED_LABOR_COST = CASE WHEN PLANNED_LABOR_COST > 0.00+
1 THEN PLANNED_LABOR_COST ELSE SCHED_LABOR_COST END,:n                  SCHED_+
1LABOR_REVENUE = CASE WHEN PLANNED_LABOR_REVENUE > 0.00 THEN PLANNED_LABOR_REV+
1ENUE ELSE SCHED_LABOR_REVENUE END,:n                  ETC = PLANNED_WORK,:n  +
1                FORECAST_LABOR_COST = ((ETC+PLANNED_WORK/60.00) * REGULAR_COS+
1T) + ACTUAL_LABOR_COST,:n                  FORECAST_LABOR_REVENUE = CASE WHEN+
1 BILLABLE = 0 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * REGULAR_RATE) + ACTU+
1AL_LABOR_REVENUE END,:n                  PLANNED_START = NuLL, PLANNED_FINISH+
1 = NuLL, PLANNED_DURATION = 0, PLANNED_WORK = 0,:n                  FORECAST_+
1START = NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION = 0,:n               +
1   PROJECT_ASSIGNMENT_ID = NuLL:n                  WHERE TSK_ASSIGNMENT_ID = +
1h_id AND SCHED_WORK = 0 AND PLANNED_WORK > 0:
1888:
1           EXCEPTION:: FC_COMMIT_ASSIGN(889) :: cplan.sql(21329) :: :
1U_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n                     BIT_FLAG = '2',:n          +
1           SD = pmo_cnst.SC_SS,:n                     FD = pmo_cnst.SC_SF,:n +
1                    SCHED_START = PLANNED_START,:n                     SCHED_+
1FINISH = PLANNED_FINISH,:n                     SCHED_DURATION = PLANNED_DURAT+
1ION,:n                     SCHED_WORK = PLANNED_WORK,:n                     B+
1AK_START_DT = PLANNED_START,:n                     BAK_FINISH_DT = PLANNED_FI+
1NISH,:n                     BAK_WORK = PLANNED_WORK,:n                     SC+
1HED_LABOR_COST = CASE WHEN PLANNED_LABOR_COST > 0.00 THEN PLANNED_LABOR_COST +
1ELSE SCHED_LABOR_COST END,:n                     SCHED_LABOR_REVENUE = CASE W+
1HEN PLANNED_LABOR_REVENUE > 0.00 THEN PLANNED_LABOR_REVENUE ELSE SCHED_LABOR_+
1REVENUE END,:n                     ETC = PLANNED_WORK,:n                     +
1FORECAST_LABOR_COST = ((ETC+PLANNED_WORK/60.00) * REGULAR_COST) + ACTUAL_LABO+
1R_COST,:n                     FORECAST_LABOR_REVENUE = CASE WHEN BILLABLE = 0+
1 THEN 0.00 ELSE ((ETC+PLANNED_WORK/60.00) * REGULAR_RATE) + ACTUAL_LABOR_REVE+
1NUE END,:n                     PLANNED_START = NuLL, PLANNED_FINISH = NuLL, P+
1LANNED_DURATION = 0, PLANNED_WORK = 0,:n                     FORECAST_START =+
1 NuLL, FORECAST_FINISH = NuLL, FORECAST_DURATION = 0,:n                     P+
1ROJECT_ASSIGNMENT_ID = h_prj_assignment_id:n                     WHERE TSK_AS+
1SIGNMENT_ID = h_tsk_assignment_id:
1947:
1           EXCEPTION:: FC_COMMIT_ASSIGN(948) :: cplan.sql(21388) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = pmo_cnst.SC_ASSIGNMENT_BIT WHERE ELEMENT_ID +
1= h_task_id:
1968:
1           EXCEPTION:: FC_COMMIT_ASSIGN(969) :: cplan.sql(21409) :: :
1984:
1           EXCEPTION:: FC_COMMIT_ASSIGN(985) :: cplan.sql(21425) :: :
1>:
1UPDATE TASK_ASSIGNMENTS SET C_EFFORT = h_work WHERE TSK_ASSIGNMENT_ID = h_prj+
1_assignment_id:
11004:
1           EXCEPTION:: FC_COMMIT_ASSIGN(1005) :: cplan.sql(21445) :: :
1BEST:
1SELECT PROJECT_ASSIGNMENT_ID, BEST, SCHED_START, SCHED_FINISH, BILLABLE, REGU+
1LAR_COST, REGULAR_RATE:n                  INTO h_prj_assignment_id, h_sched_w+
1ork, h_start_date, h_finish_date, h_billable, h_reg_cost, h_reg_sale:n       +
1           FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID   = h_prj_assignment+
1_id:
11026:
1           EXCEPTION:: FC_COMMIT_ASSIGN(1027) :: cplan.sql(21467) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                     ESTIMATED_PLANNED_START +
1= NuLL,:n                     ESTIMATED_PLANNED_FINISH = NuLL,:n             +
1        ESTIMATED_PLANNED_EFFORT = 0,:n                     ESTIMATED_PLANNED+
1_COST = 0.00,:n                     ESTIMATED_PLANNED_REVENUE = 0.00,:n      +
1               ESTIMATED_SCHED_START = h_start_date,:n                     ES+
1TIMATED_SCHED_FINISH = h_finish_date,:n                     ESTIMATED_SCHED_E+
1FFORT = h_sched_work,:n                     ESTIMATED_SCHED_COST = (h_sched_w+
1ork / 60.0) * h_reg_cost,:n                     ESTIMATED_SCHED_REVENUE = 0.0+
10:n                     WHERE PROJECT_ID = h_project_id AND RESOURCE_ID = h_r+
1es_id:
11058:
1           EXCEPTION:: FC_COMMIT_ASSIGN(1059) :: cplan.sql(21499) :: :
1UPDATE PROJECT_ASSIGNMENTS SET:n                     ESTIMATED_PLANNED_START +
1= NuLL,:n                     ESTIMATED_PLANNED_FINISH = NuLL,:n             +
1        ESTIMATED_PLANNED_EFFORT = 0,:n                     ESTIMATED_PLANNED+
1_COST = 0.00,:n                     ESTIMATED_PLANNED_REVENUE = 0.00,:n      +
1               ESTIMATED_SCHED_START = h_start_date,:n                     ES+
1TIMATED_SCHED_FINISH = h_finish_date,:n                     ESTIMATED_SCHED_E+
1FFORT = h_sched_work,:n                     ESTIMATED_SCHED_COST = (h_sched_w+
1ork / 60.0) * h_reg_cost,:n                     ESTIMATED_SCHED_REVENUE = (h_+
1sched_work / 60.0) * h_reg_sale:n                     WHERE PROJECT_ID = h_pr+
1oject_id AND RESOURCE_ID = h_res_id:
11088:
1           EXCEPTION:: FC_COMMIT_ASSIGN(1089) :: cplan.sql(21529) :: :
11117:
1           EXCEPTION:: FC_COMMIT_ASSIGN(1118) :: cplan.sql(21558) :: :
11135:
1           EXCEPTION:: FC_COMMIT_ASSIGN(1136) :: cplan.sql(21576) :: :
1FC_ROLLUP:
1SC_NS:
1SC_NF:
1SELECT CASE WHEN (SD <> pmo_cnst.SC_NS) AND (FD <> pmo_cnst.SC_NF) AND (TYPE_+
1ID = pmo_cnst.SC_PROPOSAL) THEN 1 ELSE 0 END:n      INTO h_change_flag:n     +
1 FROM TMT_WBS WHERE ELEMENT_ID = h_project_id:
11157:
1           EXCEPTION:: FC_COMMIT_ASSIGN(1158) :: cplan.sql(21598) :: :
1FC_CHANGE_PROJ_TYPE:
1ELEMENT_TYPE:
1UPDATE RESOURCE_ASSIGNMENTS SET:n      ELEMENT_TYPE  = (SELECT TYPE_ID FROM T+
1MT_WBS WHERE ELEMENT_ID = h_project_id):n      WHERE ELEMENT_ID = h_project_i+
1d:
11183:
1           EXCEPTION:: FC_COMMIT_ASSIGN(1184) :: cplan.sql(21624) :: :
11193:
1                EXIT:: FC_COMMIT_ASSIGN(1194) :: cplan.sql(21634) :: :
0

0
0
193b
2
0 a0 8d 90 :3 a0 b0 3f 8f
a0 b0 3d 8f a0 51 b0 3d
b4 :2 a0 2c 6a a3 a0 1c a0
81 b0 a3 a0 1c :2 a0 51 a5
b 81 b0 a3 a0 51 a5 1c
:2 a0 6b 81 b0 a3 a0 51 a5
1c :2 a0 6b 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a0 f4 b4 bf c8 :1a a0 12a
bd b7 11 a4 b1 a3 :2 a0 6b
1c 81 b0 a0 f4 b4 bf c8
:9 a0 12a bd b7 11 a4 b1 a0
f4 b4 bf c8 :6 a0 12a bd b7
11 a4 b1 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
:3 a0 a5 b 6e a5 b b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c :8 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 :2 51
a5 b 7e 6e b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :3 a0 6b
:2 a0 6b :2 a0 a5 b 65 b7 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a :23 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :3 a0 6b :2 a0
6b a0 a5 b 65 a0 b7 :2 a0
51 a5 b 7e 51 b4 2e :2 a0
51 a5 b 7e 51 b4 2e a
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :3 a0 6b :2 a0 6b :2 a0 a5 b
65 b7 :2 19 3c :2 a0 51 a5 b
7e 51 b4 2e :3 a0 6b d :3 a0
a5 b d :2 a0 6b a0 d a0
b7 a0 7e b4 2e 5a a0 4d
d :d a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e b4 2e 5a
:4 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b a0 7e a0 6b
b4 2e 5a :3d a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :42 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :2 19 3c :3 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :3 a0
6b d :3 a0 51 a5 b d :2 a0
6b a0 d :3 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c b7 :2 19
3c :6 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e d b7 :2 a0 d :2 a0 51 a5
b 7e 51 b4 2e :3 a0 6b d
:3 a0 a5 b d :2 a0 6b a0 d
:46 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 e9 dd b3 :4 a0 e9 d3 5
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
2b b7 19 3c :39 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :6 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a0 47 :2 a0
e9 c1 :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c :9 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f a0 51 d
a0 51 d a0 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e d b7 :2 19 3c :3 a0 11c 11d
:6 a0 e9 d3 5 :2 a0 f :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 2b b7 19 3c
a0 51 :1e a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :41 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3a a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a6 9 51 :6 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 7e b4 2e :2 5a 52 10
a0 3b b7 19 3c :c a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 7e b4 2e :2 5a a 10 :2 a0
51 a5 b 7e 51 b4 2e a0
51 d b7 :3 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :3 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 51 d b7 :2 19
3c b7 :2 a0 d a0 51 d b7
:2 19 3c a0 51 d :2 a0 e9 dd
b3 :5 a0 e9 d3 5 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 2b b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e :f a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b a0 7e a0 6b b4
2e 5a :7 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c a0 b7
:2 a0 51 a5 b 7e 51 b4 2e
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 a0 47 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :8 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :37 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e a0 51 d :5 a0 :3 51 a5 b
d b7 19 3c b7 :2 a0 e9 dd
b3 :4 a0 e9 d3 5 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 2b b7 19
3c :36 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :6 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c a0 51
d :5 a0 :3 51 a5 b d :11 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:14 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :16 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :2 19 3c 93
4f b0 46 b7 a6 9 4f b7
9 a4 14 :6 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 a0 47 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f a0 7e 51 b4 2e :3 a0 a5
b d b7 19 3c :d a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e :3 a0
6b d :2 a0 6b :4 a0 a5 b d
b7 19 3c :8 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b 7e 51 b4
2e :2 a0 6b 51 d b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:3 a0 6b 65 b7 a4 b1 11 68
4f 1d 17 b5 
193b
2
0 3 7 2b 1f 23 27 1e
32 3f 3b 1b 47 53 4c 50
3a 5b 37 60 64 68 6c 89
74 78 80 84 73 b0 94 98
a0 a4 70 a8 a9 ab 93 d8
bb 90 bf c0 c8 cc d0 d3
ba 100 e3 b7 e7 e8 f0 f4
f8 fb e2 11d 10b df 10f 110
118 10a 13a 128 107 12c 12d 135
127 157 145 124 149 14a 152 144
174 162 141 166 167 16f 161 190
17f 183 18b 15e 1ac 197 19b 19e
19f 1a7 17e 1c9 1b7 17b 1bb 1bc
1c4 1b6 1e6 1d4 1b3 1d8 1d9 1e1
1d3 203 1f1 1d0 1f5 1f6 1fe 1f0
21f 20e 212 21a 1ed 237 226 22a
232 20d 253 242 246 20a 24e 241
26f 25e 262 23e 26a 25d 28b 27a
27e 25a 286 279 2a7 296 29a 276
2a2 295 2c3 2b2 2b6 292 2be 2b1
2df 2ce 2d2 2ae 2da 2cd 2fb 2ea
2ee 2ca 2f6 2e9 317 306 30a 2e6
312 305 333 322 326 302 32e 321
34f 33e 342 31e 34a 33d 36b 35a
35e 33a 366 359 387 376 37a 356
382 375 3a3 392 396 372 39e 391
3bf 3ae 3b2 38e 3ba 3ad 3dc 3ca
3aa 3ce 3cf 3d7 3c9 3f9 3e7 3c6
3eb 3ec 3f4 3e6 415 404 408 410
3e3 430 41c 420 428 42b 403 437
43b 400 44c 44f 453 457 45b 45f
463 467 46b 46f 473 477 47b 47f
483 487 48b 48f 493 497 49b 49f
4a3 4a7 4ab 4af 4b3 4b7 4bb 4c7
4cc 4ce 4da 4de 4fc 4e4 4e8 4ec
4ef 4f7 4e3 503 507 4e0 518 51b
51f 523 527 52b 52f 533 537 53b
53f 543 54f 554 556 562 566 568
56c 57d 57e 581 585 589 58d 591
595 599 59d 5a9 5ae 5b0 5bc 5c0
5c2 5c6 5ca 5cd 5d1 5d5 5d8 5dd
5de 1 5e0 5e5 5e9 5ed 5f0 5f5
5f9 5fd 600 605 606 608 60d 610
614 615 61a 61f 622 627 628 62d
630 634 635 63a 63d 642 643 648
64b 650 651 656 659 65d 661 665
666 668 66d 66e 670 671 676 679
67e 67f 684 687 68b 68f 693 694
696 69b 69c 69e 69f 6a4 6a7 6ac
6ad 6b2 6b3 6b8 6ba 6be 6c1 6c5
6c9 6cc 6d0 6d4 6d7 6da 6df 6e2
6e5 6e8 6e9 6ee 6ef 1 6f1 6f6
6fa 6fe 701 706 70b 70e 712 713
718 719 71e 720 724 727 72b 72f
733 737 73b 73f 743 747 753 757
75b 75e 762 766 768 76c 770 774
777 77b 77f 781 782 787 1 78b
78f 793 796 79a 79e 7a2 7a6 7a9
7ad 7b1 7b4 7b7 7bc 7bf 7c2 7c5
7c6 7cb 7cc 1 7ce 7d3 7d7 7db
7de 7e3 7e8 7eb 7ef 7f0 7f5 7f8
7fd 7fe 803 806 80b 80c 811 814
818 819 81e 821 826 827 82c 82f
833 837 83a 83d 83e 840 841 846
847 84c 84e 852 855 857 85b 85d
869 86b 86d 86e 873 877 879 885
887 88b 88f 892 895 896 898 89b
8a0 8a1 8a6 8aa 8ae 8b1 8b5 8b9
8bc 8bf 8c4 8c7 8ca 8cd 8ce 8d3
8d4 1 8d6 8db 8df 8e3 8e6 8eb
8f0 8f3 8f7 8f8 8fd 900 905 906
90b 90e 913 914 919 91c 920 924
928 92c 92f 930 932 937 938 93a
93b 940 943 948 949 94e 951 956
957 95c 95f 963 964 969 96c 971
972 977 978 97d 97f 983 986 98a
98e 991 995 999 99c 99f 9a4 9a7
9aa 9ad 9ae 9b3 9b4 1 9b6 9bb
9bf 9c3 9c6 9cb 9d0 9d3 9d7 9d8
9dd 9de 9e3 9e5 9e9 9ec 9f0 9f4
9f8 9fb 9ff a03 a06 a0a a0e a0f
a11 a15 a17 a1b a1e a22 a26 a29
a2d a30 a34 a37 a38 a3d a40 a44
a48 a4c a50 a54 a58 a5c a60 a64
a68 a6c a70 a74 a78 a7c a80 a84
a88 a8c a90 a94 a98 a9c aa0 aa4
aa8 aac ab0 ab4 ab8 abc ac0 ac4
ac8 acc ad8 adc ae0 ae3 ae7 aeb
aed af1 af5 af9 afc b00 b04 b06
b07 b0c 1 b10 b14 b18 b1b b1f
b23 b27 b2b b2e b32 b36 b39 b3c
b41 b44 b47 b4a b4b b50 b51 1
b53 b58 b5c b60 b63 b68 b6d b70
b74 b75 b7a b7d b82 b83 b88 b8b
b90 b91 b96 b99 b9d b9e ba3 ba6
bab bac bb1 bb4 bb8 bbc bbf bc2
bc3 bc5 bc6 bcb bcc bd1 bd3 bd7
bda bdc be0 be2 bee bf0 bf2 bf3
bf8 bfc bfe c0a c0c c10 c14 c17
c1b c1e c22 c25 c26 c2b c2e c32
c36 c39 c3d c41 c44 c47 c4c c4f
c52 c55 c56 c5b c5c 1 c5e c63
c67 c6b c6e c73 c78 c7b c7f c80
c85 c88 c8d c8e c93 c96 c9b c9c
ca1 ca4 ca8 cac cb0 cb4 cb7 cb8
cba cbf cc0 cc2 cc3 cc8 cc9 cce
cd0 cd4 cd7 cdb cdf ce2 ce6 cea
ced cf0 cf5 cf8 cfb cfe cff d04
d05 1 d07 d0c d10 d14 d17 d1c
d21 d24 d28 d29 d2e d2f d34 d36
d3a d3d d41 d45 d49 d4c d50 d54
d57 d5b d5c d5e d62 d66 d68 d6c
d70 d73 d74 d76 d79 d7c d7d d82
d86 d8a d8d d8e d90 d93 d96 d97
1 d9c da1 da5 da9 dac db0 db4
db7 dba dbf dc2 dc5 dc8 dc9 dce
dcf 1 dd1 dd6 dda dde de1 de6
deb dee df2 df3 df8 dfb e00 e01
e06 e09 e0e e0f e14 e17 e1b e1f
e23 e27 e2a e2b e2d e32 e33 e35
e36 e3b e3e e43 e44 e49 e4c e51
e52 e57 e5a e5e e5f e64 e67 e6c
e6d e72 e73 e78 e7a e7e e81 e85
e89 e8c e90 e94 e97 e9a e9f ea2
ea5 ea8 ea9 eae eaf 1 eb1 eb6
eba ebe ec1 ec6 ecb ece ed2 ed3
ed8 ed9 ede ee0 ee4 ee7 eeb eef
ef3 ef6 efa efe f01 f05 f09 f0a
f0c f10 f12 f16 f1a f1d f21 f25
f28 f29 f2b f2e f31 f32 f37 f3b
f3f f43 f46 f4a f4e f52 f56 f57
f59 f5d f61 f65 f68 f6c f70 f74
f76 f7a f7d f7e f83 f86 f8a f8b
f8f f93 f97 f9b f9f fa3 fa7 fab
faf fb3 fb7 fbb fbf fc3 fcf fd3
fd7 fda fde fe2 fe4 fe8 fec ff0
ff3 ff7 ffb ffd ffe 1003 1 1007
100b 100f 1012 1016 101a 101e 1022 1025
1029 102d 1030 1033 1038 103b 103e 1041
1042 1047 1048 1 104a 104f 1053 1057
105a 105f 1064 1067 106b 106c 1071 1074
1079 107a 107f 1082 1087 1088 108d 1090
1094 1095 109a 109d 10a2 10a3 10a8 10ab
10af 10b3 10b6 10b9 10ba 10bc 10bd 10c2
10c3 10c8 10ca 10ce 10d1 10d3 10d7 10d9
10e5 10e7 10e9 10ea 10ef 10f3 10f5 1101
1103 1107 110a 110b 1110 1113 1117 111b
111f 1123 112f 1133 1137 113a 113e 1142
1144 1148 114c 1150 1153 1157 115b 115d
115e 1163 1 1167 116b 116f 1172 1176
117a 117e 1182 1185 1189 118d 1190 1193
1198 119b 119e 11a1 11a2 11a7 11a8 1
11aa 11af 11b3 11b7 11ba 11bf 11c4 11c7
11cb 11cc 11d1 11d4 11d9 11da 11df 11e2
11e7 11e8 11ed 11f0 11f4 11f5 11fa 11fd
1202 1203 1208 120b 120f 1213 1216 1219
121a 121c 121d 1222 1223 1228 122a 122e
1231 1233 1237 1239 1245 1247 1249 124a
124f 1253 1255 1261 1263 1267 126b 126e
1272 1275 1279 127c 127d 1282 1285 1289
128d 1291 1295 1299 129d 12a1 12a5 12a9
12ad 12b1 12b5 12b9 12bd 12c1 12c5 12c9
12cd 12d1 12d5 12d9 12dd 12e1 12e5 12e9
12ed 12f1 12f5 12f9 12fd 1301 1305 1309
130d 1311 1315 1319 131d 1321 1325 1329
132d 1331 1335 1339 133d 1341 1345 1349
134d 1351 1355 1359 135d 1361 1365 1369
136d 1371 1375 1379 1385 1389 138e 1392
1395 1396 139b 139f 13a3 13a6 13a9 13ad
13af 13b3 13b7 13ba 13bd 13c1 13c3 13c7
13cb 13ce 13d0 13d4 13d8 13dc 13df 13e3
13e7 13e9 13ea 13ef 1 13f3 13f7 13fb
13fe 1402 1406 140a 140e 1411 1415 1419
141c 141f 1424 1427 142a 142d 142e 1433
1434 1 1436 143b 143f 1443 1446 144b
1450 1453 1457 1458 145d 1460 1465 1466
146b 146e 1473 1474 1479 147c 1480 1481
1486 1489 148e 148f 1494 1497 149b 149f
14a2 14a5 14a6 14a8 14a9 14ae 14af 14b4
14b6 14ba 14bd 14bf 14c3 14c5 14d1 14d3
14d5 14d6 14db 14df 14e1 14ed 14ef 14f1
14f5 14f9 14fd 1501 1505 1509 150d 1511
1515 1519 151d 1521 1525 1529 152d 1531
1535 1539 153d 1541 1545 1549 154d 1551
1555 1559 155d 1561 1565 1569 156d 1571
1575 1579 157d 1581 1585 1589 158d 1591
1595 1599 159d 15a1 15a5 15a9 15ad 15b1
15b5 15b9 15bd 15c1 15c5 15c9 15cd 15d1
15d5 15d9 15dd 15e1 15e5 15e9 15ed 15f1
15f5 15f9 1605 1609 160e 1612 1615 1616
161b 161f 1623 1626 1629 162d 162f 1633
1637 163a 163d 1641 1643 1647 164b 164e
1650 1654 1658 165c 165f 1663 1667 1669
166a 166f 1 1673 1677 167b 167e 1682
1686 168a 168e 1691 1695 1699 169c 169f
16a4 16a7 16aa 16ad 16ae 16b3 16b4 1
16b6 16bb 16bf 16c3 16c6 16cb 16d0 16d3
16d7 16d8 16dd 16e0 16e5 16e6 16eb 16ee
16f3 16f4 16f9 16fc 1700 1701 1706 1709
170e 170f 1714 1717 171b 171f 1722 1725
1726 1728 1729 172e 172f 1734 1736 173a
173d 173f 1743 1745 1751 1753 1755 1756
175b 175f 1761 176d 176f 1771 1775 1779
177c 1780 1784 1788 1794 1798 179d 17a1
17a4 17a5 17aa 17ae 17b2 17b5 17b8 17bc
17be 17c2 17c6 17c9 17cc 17d0 17d2 17d6
17da 17dd 17df 17e3 17e7 17eb 17ee 17f2
17f6 17f8 17f9 17fe 1 1802 1806 180a
180d 1811 1815 1819 181d 1820 1824 1828
182b 182e 1833 1836 1839 183c 183d 1842
1843 1 1845 184a 184e 1852 1855 185a
185f 1862 1866 1867 186c 186f 1874 1875
187a 187d 1882 1883 1888 188b 188f 1890
1895 1898 189d 189e 18a3 18a6 18aa 18ae
18b1 18b4 18b5 18b7 18b8 18bd 18be 18c3
18c5 18c9 18cc 18ce 18d2 18d4 18e0 18e2
18e4 18e5 18ea 18ee 18f0 18fc 18fe 1902
1906 190a 190d 1911 1915 1919 191d 1920
1921 1923 1927 192b 192f 1932 1936 193a
193e 1942 1946 1952 1956 195b 195f 1962
1963 1968 196c 1970 1973 1976 197a 197c
1980 1984 1987 198a 198e 1990 1994 1998
199b 199d 19a1 19a5 19a9 19ac 19b0 19b4
19b6 19b7 19bc 1 19c0 19c4 19c8 19cb
19cf 19d3 19d7 19db 19de 19e2 19e6 19e9
19ec 19f1 19f4 19f7 19fa 19fb 1a00 1a01
1 1a03 1a08 1a0c 1a10 1a13 1a18 1a1d
1a20 1a24 1a25 1a2a 1a2d 1a32 1a33 1a38
1a3b 1a40 1a41 1a46 1a49 1a4d 1a4e 1a53
1a56 1a5b 1a5c 1a61 1a64 1a68 1a6c 1a6f
1a72 1a73 1a75 1a76 1a7b 1a7c 1a81 1a83
1a87 1a8a 1a8c 1a90 1a92 1a9e 1aa0 1aa2
1aa3 1aa8 1aac 1aae 1aba 1abc 1abe 1ac2
1ac5 1ac7 1acb 1acf 1ad2 1ad6 1ada 1ade
1ae2 1ae6 1aea 1af6 1afa 1afe 1b01 1b05
1b09 1b0b 1b0f 1b13 1b17 1b1a 1b1e 1b22
1b24 1b25 1b2a 1 1b2e 1b32 1b36 1b39
1b3d 1b41 1b45 1b49 1b4c 1b50 1b54 1b57
1b5a 1b5f 1b62 1b65 1b68 1b69 1b6e 1b6f
1 1b71 1b76 1b7a 1b7e 1b81 1b86 1b8b
1b8e 1b92 1b93 1b98 1b9b 1ba0 1ba1 1ba6
1ba9 1bae 1baf 1bb4 1bb7 1bbb 1bbc 1bc1
1bc4 1bc9 1bca 1bcf 1bd2 1bd6 1bda 1bdd
1be0 1be1 1be3 1be4 1be9 1bea 1bef 1bf1
1bf5 1bf8 1bfa 1bfe 1c00 1c0c 1c0e 1c10
1c11 1c16 1c1a 1c1c 1c28 1c2a 1c2e 1c33
1c36 1c3b 1c3c 1c41 1c44 1c48 1c49 1c4e
1c51 1c56 1c57 1c5c 1c60 1c62 1c66 1c6a
1c6e 1c72 1c76 1c79 1c7a 1c7c 1c7f 1c82
1c83 1c88 1c8c 1c90 1c94 1c97 1c9b 1c9f
1ca3 1ca7 1ca8 1caa 1cae 1cb2 1cb6 1cb9
1cbd 1cc1 1cc5 1cc9 1ccd 1cd1 1cd5 1cd9
1cdd 1ce1 1ce5 1ce9 1ced 1cf1 1cf5 1cf9
1cfd 1d01 1d05 1d09 1d0d 1d11 1d15 1d19
1d1d 1d21 1d25 1d29 1d2d 1d31 1d35 1d39
1d3d 1d41 1d45 1d49 1d4d 1d51 1d55 1d59
1d5d 1d61 1d65 1d69 1d6d 1d71 1d75 1d79
1d7d 1d81 1d85 1d89 1d8d 1d91 1d95 1d99
1d9d 1da1 1da5 1da9 1dad 1db1 1db5 1db9
1dbd 1dc1 1dc5 1dc9 1dcd 1dd1 1dd5 1dd9
1de5 1de9 1dee 1df2 1df5 1df6 1dfb 1dff
1e03 1e06 1e09 1e0d 1e0f 1e13 1e17 1e1a
1e1d 1e21 1e23 1e27 1e2b 1e2e 1e30 1e34
1e38 1e3c 1e3f 1e43 1e47 1e49 1e4a 1e4f
1 1e53 1e57 1e5b 1e5e 1e62 1e66 1e6a
1e6e 1e71 1e75 1e79 1e7c 1e7f 1e84 1e87
1e8a 1e8d 1e8e 1e93 1e94 1 1e96 1e9b
1e9f 1ea3 1ea6 1eab 1eb0 1eb3 1eb7 1eb8
1ebd 1ec0 1ec5 1ec6 1ecb 1ece 1ed3 1ed4
1ed9 1edc 1ee0 1ee1 1ee6 1ee9 1eee 1eef
1ef4 1ef7 1efb 1eff 1f02 1f05 1f06 1f08
1f09 1f0e 1f0f 1f14 1f16 1f1a 1f1d 1f1f
1f23 1f25 1f31 1f33 1f35 1f36 1f3b 1f3f
1f41 1f4d 1f4f 1f53 1f57 1f5c 1f60 1f61
1f65 1f69 1f6d 1f71 1f76 1f7b 1f7f 1f83
1f87 1f8c 1f90 1f94 1f97 1f9a 1f9e 1fa0
1fa4 1fa8 1fab 1fae 1fb2 1fb4 1fb8 1fbc
1fbf 1fc3 1fc7 1fca 1fce 1fd1 1fd5 1fd8
1fd9 1fde 1fe1 1fe5 1feb 1fed 1ff1 1ff4
1ff8 1ffc 2000 2004 2008 200c 2010 2014
2018 201c 2020 2024 2028 202c 2030 2034
2038 203c 2040 2044 2048 204c 2050 2054
2058 205c 2060 2064 2068 206c 2070 2074
2078 207c 2080 2084 2088 208c 2090 2094
2098 209c 20a0 20a4 20a8 20ac 20b0 20b4
20b8 20bc 20c0 20c4 20c8 20cc 20d0 20d4
20d8 20e4 20e8 20ed 20f1 20f4 20f5 20fa
20fe 2102 2105 2108 210c 210e 2112 2116
2119 211c 2120 2122 2126 212a 212d 212f
2133 2137 213b 213e 2142 2146 2148 2149
214e 1 2152 2156 215a 215d 2161 2165
2169 216d 2170 2174 2178 217b 217e 2183
2186 2189 218c 218d 2192 2193 1 2195
219a 219e 21a2 21a5 21aa 21af 21b2 21b6
21b7 21bc 21bf 21c4 21c5 21ca 21cd 21d2
21d3 21d8 21db 21df 21e0 21e5 21e8 21ed
21ee 21f3 21f6 21fa 21fe 2201 2204 2205
2207 2208 220d 220e 2213 2215 2219 221c
221e 2222 2224 2230 2232 2234 2235 223a
223e 2240 224c 224e 2252 2256 225a 225e
2262 2266 2272 2276 227b 227f 2282 2283
2288 228c 2290 2293 2296 229a 229c 22a0
22a4 22a7 22aa 22ae 22b0 22b4 22b8 22bb
22bd 22c1 22c5 22c9 22cc 22d0 22d4 22d6
22d7 22dc 1 22e0 22e4 22e8 22eb 22ef
22f3 22f7 22fb 22fe 2302 2306 2309 230c
2311 2314 2317 231a 231b 2320 2321 1
2323 2328 232c 2330 2333 2338 233d 2340
2344 2345 234a 234d 2352 2353 2358 235b
2360 2361 2366 2369 236d 236e 2373 2376
237b 237c 2381 2384 2388 238c 238f 2392
2393 2395 2396 239b 239c 23a1 23a3 23a7
23aa 23ac 23b0 23b2 23be 23c0 23c2 23c3
23c8 23cc 23ce 23da 23dc 23de 23e2 23e9
23ed 23f1 23f6 23f8 23fc 2400 2403 2407
240b 240d 2411 2415 2419 241c 2420 2424
2426 2427 242c 1 2430 2434 2438 243b
243f 2443 2447 244b 244e 2452 2456 2459
245c 2461 2464 2467 246a 246b 2470 2471
1 2473 2478 247c 2480 2483 2488 248d
2490 2494 2495 249a 249d 24a2 24a3 24a8
24ab 24b0 24b1 24b6 24b9 24bd 24be 24c3
24c6 24cb 24cc 24d1 24d4 24d8 24dc 24df
24e2 24e3 24e5 24e6 24eb 24ec 24f1 24f3
24f7 24fa 24fc 2500 2502 250e 2510 2512
2513 2518 251c 251e 252a 252c 252e 2532
2535 2539 253d 2541 2545 2549 254d 2551
2555 2559 2565 2569 256e 2572 2575 2576
257b 257f 2583 2586 2589 258d 258f 2593
2597 259a 259d 25a1 25a3 25a7 25ab 25ae
25b0 25b4 25b8 25bc 25bf 25c3 25c7 25c9
25ca 25cf 1 25d3 25d7 25db 25de 25e2
25e6 25ea 25ee 25f1 25f5 25f9 25fc 25ff
2604 2607 260a 260d 260e 2613 2614 1
2616 261b 261f 2623 2626 262b 2630 2633
2637 2638 263d 2640 2645 2646 264b 264e
2653 2654 2659 265c 2660 2661 2666 2669
266e 266f 2674 2677 267b 267f 2682 2685
2686 2688 2689 268e 268f 2694 2696 269a
269d 269f 26a3 26a5 26b1 26b3 26b5 26b6
26bb 26bf 26c1 26cd 26cf 26d3 26d6 26da
26de 26e1 26e5 26e9 26ee 26f1 26f6 26f7
26fc 26ff 2703 2704 2709 270c 2711 2712
2717 271b 271d 2721 2725 2728 272c 2730
2734 2737 273b 273f 2743 2747 274b 274f
2753 2758 275d 2761 2765 2769 276e 2772
2776 2779 277c 2780 2782 2786 278a 278d
2790 2794 2796 279a 279e 27a1 27a5 27a9
27ac 27b0 27b3 27b7 27ba 27bb 27c0 27c3
27c7 27cd 27cf 27d3 27d6 27da 27dd 27e1
27e5 27e9 27ed 27f1 27f5 27f9 27fd 2801
2805 2809 280d 2811 2815 2819 281d 2821
2825 2829 282d 2831 2835 2839 283d 2841
2845 2849 284d 2851 2855 2861 2865 286a
286e 2871 2872 2877 287b 287f 2882 2885
2889 288b 288f 2893 2896 2899 289d 289f
28a3 28a7 28aa 28ac 28b0 28b4 28b8 28bb
28bf 28c3 28c5 28c6 28cb 1 28cf 28d3
28d7 28da 28de 28e2 28e6 28ea 28ed 28f1
28f5 28f8 28fb 2900 2903 2906 2909 290a
290f 2910 1 2912 2917 291b 291f 2922
2927 292c 292f 2933 2934 2939 293c 2941
2942 2947 294a 294f 2950 2955 2958 295c
295d 2962 2965 296a 296b 2970 2973 2977
297b 297e 2981 2982 2984 2985 298a 298b
2990 2992 2996 2999 299b 299f 29a1 29ad
29af 29b1 29b2 29b7 29bb 29bd 29c9 29cb
29cf 29d3 29d7 29db 29df 29e3 29e7 29eb
29ef 29f3 29f7 29fb 29ff 2a03 2a07 2a0b
2a0f 2a13 2a17 2a1b 2a1f 2a23 2a27 2a2b
2a2f 2a33 2a37 2a3b 2a3f 2a43 2a47 2a4b
2a4f 2a53 2a57 2a5b 2a5f 2a63 2a67 2a6b
2a6f 2a73 2a77 2a7b 2a7f 2a83 2a87 2a8b
2a8f 2a93 2a97 2a9b 2a9f 2aa3 2aa7 2aab
2aaf 2ab3 2ab7 2abb 2abf 2ac3 2ac7 2acb
2acf 2adb 2adf 2ae4 2ae8 2aeb 2aec 2af1
2af5 2af9 2afc 2aff 2b03 2b05 2b09 2b0d
2b10 2b13 2b17 2b19 2b1d 2b21 2b24 2b26
2b2a 2b2e 2b32 2b35 2b39 2b3d 2b3f 2b40
2b45 1 2b49 2b4d 2b51 2b54 2b58 2b5c
2b60 2b64 2b67 2b6b 2b6f 2b72 2b75 2b7a
2b7d 2b80 2b83 2b84 2b89 2b8a 1 2b8c
2b91 2b95 2b99 2b9c 2ba1 2ba6 2ba9 2bad
2bae 2bb3 2bb6 2bbb 2bbc 2bc1 2bc4 2bc9
2bca 2bcf 2bd2 2bd6 2bd7 2bdc 2bdf 2be4
2be5 2bea 2bed 2bf1 2bf5 2bf8 2bfb 2bfc
2bfe 2bff 2c04 2c05 2c0a 2c0c 2c10 2c13
2c15 2c19 2c1b 2c27 2c29 2c2b 2c2c 2c31
2c35 2c37 2c43 2c45 2c49 2c4d 2c51 2c55
2c59 2c5d 2c61 2c65 2c69 2c6d 2c71 2c75
2c79 2c7d 2c81 2c85 2c89 2c8d 2c91 2c95
2c99 2c9d 2ca1 2ca5 2ca9 2cad 2cb1 2cb5
2cb9 2cbd 2cc1 2cc5 2cc9 2ccd 2cd1 2cd5
2cd9 2cdd 2ce1 2ce5 2ce9 2ced 2cf1 2cf5
2cf9 2cfd 2d01 2d05 2d09 2d0d 2d11 2d15
2d19 2d1d 2d21 2d25 2d29 2d2d 2d39 2d3d
2d42 2d46 2d49 2d4a 2d4f 2d53 2d57 2d5a
2d5d 2d61 2d63 2d67 2d6b 2d6e 2d71 2d75
2d77 2d7b 2d7f 2d82 2d84 2d88 2d8c 2d90
2d93 2d97 2d9b 2d9d 2d9e 2da3 1 2da7
2dab 2daf 2db2 2db6 2dba 2dbe 2dc2 2dc5
2dc9 2dcd 2dd0 2dd3 2dd8 2ddb 2dde 2de1
2de2 2de7 2de8 1 2dea 2def 2df3 2df7
2dfa 2dff 2e04 2e07 2e0b 2e0c 2e11 2e14
2e19 2e1a 2e1f 2e22 2e27 2e28 2e2d 2e30
2e34 2e35 2e3a 2e3d 2e42 2e43 2e48 2e4b
2e4f 2e53 2e56 2e59 2e5a 2e5c 2e5d 2e62
2e63 2e68 2e6a 2e6e 2e71 2e73 2e77 2e79
2e85 2e87 2e89 2e8a 2e8f 2e93 2e95 2ea1
2ea3 2ea5 2ea6 2eab 2eae 2eb2 2eb6 2eba
2ebe 2ec2 2ec6 2ed2 2ed6 2eda 2edd 2ee1
2ee5 2ee7 2eeb 2eef 2ef3 2ef6 2efa 2efe
2f00 2f01 2f06 1 2f0a 2f0e 2f12 2f15
2f19 2f1d 2f21 2f25 2f28 2f2c 2f30 2f33
2f36 2f3b 2f3e 2f41 2f44 2f45 2f4a 2f4b
1 2f4d 2f52 2f56 2f5a 2f5d 2f62 2f67
2f6a 2f6e 2f6f 2f74 2f77 2f7c 2f7d 2f82
2f85 2f8a 2f8b 2f90 2f93 2f97 2f98 2f9d
2fa0 2fa5 2fa6 2fab 2fae 2fb2 2fb6 2fb9
2fbc 2fbd 2fbf 2fc0 2fc5 2fc6 2fcb 2fcd
2fd1 2fd4 2fd6 2fda 2fdc 2fe8 2fea 2fec
2fed 2ff2 2ff6 2ff8 3004 3006 300a 300e
3011 3015 3018 301c 301f 3020 3025 3028
302c 302f 3030 3035 3038 1 303b 3040
3044 304a 304c 3050 3053 3057 305b 305f
3063 3067 306b 306f 3073 3077 307b 307f
3083 308f 3093 3097 309a 309e 30a2 30a4
30a8 30ac 30b0 30b3 30b7 30bb 30bd 30be
30c3 1 30c7 30cb 30cf 30d2 30d6 30da
30de 30e2 30e5 30e9 30ed 30f0 30f3 30f8
30fb 30fe 3101 3102 3107 3108 1 310a
310f 3113 3117 311a 311f 3124 3127 312b
312c 3131 3134 3139 313a 313f 3142 3147
3148 314d 3150 3154 3155 315a 315d 3162
3163 3168 316b 316f 3173 3176 3179 317a
317c 317d 3182 3183 3188 318a 318e 3191
3193 3197 3199 31a5 31a7 31a9 31aa 31af
31b3 31b5 31c1 31c3 31c7 31cb 31ce 31d2
31d5 31d9 31dc 31dd 31e2 31e5 31e9 31ec
31ed 31f2 31f5 1 31f8 31fd 3201 3205
3208 3209 320b 320e 3211 3212 3217 321b
321e 3222 3224 3228 322c 3230 323c 3240
3245 3249 324c 324d 3252 3256 325a 325d
3260 3264 3266 326a 326e 3271 3274 3278
327a 327e 3282 3285 3287 328b 328f 3293
3296 329a 329e 32a0 32a1 32a6 1 32aa
32ae 32b2 32b5 32b9 32bd 32c1 32c5 32c8
32cc 32d0 32d3 32d6 32db 32de 32e1 32e4
32e5 32ea 32eb 1 32ed 32f2 32f6 32fa
32fd 3302 3307 330a 330e 330f 3314 3317
331c 331d 3322 3325 332a 332b 3330 3333
3337 3338 333d 3340 3345 3346 334b 334e
3352 3356 3359 335c 335d 335f 3360 3365
3366 336b 336d 3371 3374 3376 337a 337c
3388 338a 338c 338d 3392 3396 3398 33a4
33a6 33aa 33ae 33b2 33be 33c2 33c7 33cb
33ce 33cf 33d4 33d8 33dc 33df 33e2 33e6
33e8 33ec 33f0 33f3 33f6 33fa 33fc 3400
3404 3407 3409 340d 3411 3415 3418 341c
3420 3422 3423 3428 1 342c 3430 3434
3437 343b 343f 3443 3447 344a 344e 3452
3455 3458 345d 3460 3463 3466 3467 346c
346d 1 346f 3474 3478 347c 347f 3484
3489 348c 3490 3491 3496 3499 349e 349f
34a4 34a7 34ac 34ad 34b2 34b5 34b9 34ba
34bf 34c2 34c7 34c8 34cd 34d0 34d4 34d8
34db 34de 34df 34e1 34e2 34e7 34e8 34ed
34ef 34f3 34f6 34f8 34fc 34fe 350a 350c
350e 350f 3514 3518 351a 3526 3528 352c
3530 3534 3540 3544 3549 354d 3550 3551
3556 355a 355e 3561 3564 3568 356a 356e
3572 3575 3578 357c 357e 3582 3586 3589
358b 358f 3593 3597 359a 359e 35a2 35a4
35a5 35aa 1 35ae 35b2 35b6 35b9 35bd
35c1 35c5 35c9 35cc 35d0 35d4 35d7 35da
35df 35e2 35e5 35e8 35e9 35ee 35ef 1
35f1 35f6 35fa 35fe 3601 3606 360b 360e
3612 3613 3618 361b 3620 3621 3626 3629
362e 362f 3634 3637 363b 363c 3641 3644
3649 364a 364f 3652 3656 365a 365d 3660
3661 3663 3664 3669 366a 366f 3671 3675
3678 367a 367e 3680 368c 368e 3690 3691
3696 369a 369c 36a8 36aa 36ae 36b2 36b6
36c2 36c6 36cb 36cf 36d2 36d3 36d8 36dc
36e0 36e3 36e6 36ea 36ec 36f0 36f4 36f7
36fa 36fe 3700 3704 3708 370b 370d 3711
3715 3719 371c 3720 3724 3726 3727 372c
1 3730 3734 3738 373b 373f 3743 3747
374b 374e 3752 3756 3759 375c 3761 3764
3767 376a 376b 3770 3771 1 3773 3778
377c 3780 3783 3788 378d 3790 3794 3795
379a 379d 37a2 37a3 37a8 37ab 37b0 37b1
37b6 37b9 37bd 37be 37c3 37c6 37cb 37cc
37d1 37d4 37d8 37dc 37df 37e2 37e3 37e5
37e6 37eb 37ec 37f1 37f3 37f7 37fa 37fc
3800 3802 380e 3810 3812 3813 3818 381c
381e 382a 382c 3830 3833 3837 3839 383d
3841 3844 3846 384a 384e 3852 3856 3859
385d 385f 3863 3867 386a 386e 3871 3875
3879 387d 3882 3886 3887 388b 388f 3893
3897 389b 38a0 38a5 38a9 38ad 38b1 38b6
38ba 38be 38c1 38c4 38c8 38ca 38ce 38d2
38d5 38d8 38dc 38de 38e2 38e6 38e9 38ed
38f1 38f4 38f8 38fb 38ff 3902 3903 3908
390b 390f 3915 3917 391b 391e 3922 3926
3929 392a 392c 392f 3932 3933 3938 393c
3940 3944 3948 394c 3950 3954 3958 395c
3960 3964 3968 396c 3970 3974 3980 3984
3989 398d 3990 3991 3996 399a 399e 39a1
39a4 39a8 39aa 39ae 39b2 39b5 39b8 39bc
39be 39c2 39c6 39c9 39cb 39cf 39d3 39d7
39da 39de 39e2 39e4 39e5 39ea 1 39ee
39f2 39f6 39f9 39fd 3a01 3a05 3a09 3a0c
3a10 3a14 3a17 3a1a 3a1f 3a22 3a25 3a28
3a29 3a2e 3a2f 1 3a31 3a36 3a3a 3a3e
3a41 3a46 3a4b 3a4e 3a52 3a53 3a58 3a5b
3a60 3a61 3a66 3a69 3a6e 3a6f 3a74 3a77
3a7b 3a7c 3a81 3a84 3a89 3a8a 3a8f 3a92
3a96 3a9a 3a9d 3aa0 3aa1 3aa3 3aa4 3aa9
3aaa 3aaf 3ab1 3ab5 3ab8 3aba 3abe 3ac0
3acc 3ace 3ad0 3ad1 3ad6 3ada 3adc 3ae8
3aea 3aee 3af2 3af5 3af9 3afc 3b00 3b03
3b04 3b09 3b0c 3b10 3b14 3b18 3b1c 3b20
3b24 3b28 3b34 3b38 3b3d 3b41 3b44 3b45
3b4a 3b4e 3b52 3b55 3b58 3b5c 3b5e 3b62
3b66 3b69 3b6c 3b70 3b72 3b76 3b7a 3b7d
3b7f 3b83 3b87 3b8b 3b8e 3b92 3b96 3b98
3b99 3b9e 1 3ba2 3ba6 3baa 3bad 3bb1
3bb5 3bb9 3bbd 3bc0 3bc4 3bc8 3bcb 3bce
3bd3 3bd6 3bd9 3bdc 3bdd 3be2 3be3 1
3be5 3bea 3bee 3bf2 3bf5 3bfa 3bff 3c02
3c06 3c07 3c0c 3c0f 3c14 3c15 3c1a 3c1d
3c22 3c23 3c28 3c2b 3c2f 3c30 3c35 3c38
3c3d 3c3e 3c43 3c46 3c4a 3c4e 3c51 3c54
3c55 3c57 3c58 3c5d 3c5e 3c63 3c65 3c69
3c6c 3c6e 3c72 3c74 3c80 3c82 3c84 3c85
3c8a 3c8e 3c90 3c9c 3c9e 3ca0 3ca4 3ca8
3cac 3cb0 3cb4 3cb8 3cbc 3cc0 3cc4 3cd0
3cd4 3cd9 3cdd 3ce0 3ce1 3ce6 3cea 3cee
3cf1 3cf4 3cf8 3cfa 3cfe 3d02 3d05 3d08
3d0c 3d0e 3d12 3d16 3d19 3d1b 3d1f 3d23
3d27 3d2a 3d2e 3d32 3d34 3d35 3d3a 1
3d3e 3d42 3d46 3d49 3d4d 3d51 3d55 3d59
3d5c 3d60 3d64 3d67 3d6a 3d6f 3d72 3d75
3d78 3d79 3d7e 3d7f 1 3d81 3d86 3d8a
3d8e 3d91 3d96 3d9b 3d9e 3da2 3da3 3da8
3dab 3db0 3db1 3db6 3db9 3dbe 3dbf 3dc4
3dc7 3dcb 3dcc 3dd1 3dd4 3dd9 3dda 3ddf
3de2 3de6 3dea 3ded 3df0 3df1 3df3 3df4
3df9 3dfa 3dff 3e01 3e05 3e08 3e0a 3e0e
3e10 3e1c 3e1e 3e20 3e21 3e26 3e2a 3e2c
3e38 3e3a 3e3c 3e40 3e44 3e47 3e4b 3e4d
3e51 3e55 3e58 3e59 3e5b 3e5e 3e61 3e62
3e67 3e6b 3e6f 3e73 3e77 3e7b 3e7f 3e83
3e87 3e8b 3e97 3e9b 3ea0 3ea4 3ea7 3ea8
3ead 3eb1 3eb5 3eb8 3ebb 3ebf 3ec1 3ec5
3ec9 3ecc 3ecf 3ed3 3ed5 3ed9 3edd 3ee0
3ee2 3ee6 3eea 3eee 3ef1 3ef5 3ef9 3efb
3efc 3f01 1 3f05 3f09 3f0d 3f10 3f14
3f18 3f1c 3f20 3f23 3f27 3f2b 3f2e 3f31
3f36 3f39 3f3c 3f3f 3f40 3f45 3f46 1
3f48 3f4d 3f51 3f55 3f58 3f5d 3f62 3f65
3f69 3f6a 3f6f 3f72 3f77 3f78 3f7d 3f80
3f85 3f86 3f8b 3f8e 3f92 3f93 3f98 3f9b
3fa0 3fa1 3fa6 3fa9 3fad 3fb1 3fb4 3fb7
3fb8 3fba 3fbb 3fc0 3fc1 3fc6 3fc8 3fcc
3fcf 3fd1 3fd5 3fd7 3fe3 3fe5 3fe7 3fe8
3fed 3ff1 3ff3 3fff 4001 4003 4007 400b
400e 4010 4014 401b 401f 4023 4028 402a
402e 4032 4035 4039 403d 403f 4043 4047
404b 404e 4052 4056 4058 4059 405e 1
4062 4066 406a 406d 4071 4075 4079 407d
4080 4084 4088 408b 408e 4093 4096 4099
409c 409d 40a2 40a3 1 40a5 40aa 40ae
40b2 40b5 40ba 40bf 40c2 40c6 40c7 40cc
40cf 40d4 40d5 40da 40dd 40e2 40e3 40e8
40eb 40ef 40f0 40f5 40f8 40fd 40fe 4103
4106 410a 410e 4111 4114 4115 4117 4118
411d 411e 4123 4125 4129 412c 412e 4132
4134 4140 4142 4144 4145 414a 414e 4150
415c 415e 4162 4166 416a 416e 4172 4176
417a 417e 418a 418e 4193 4197 419a 419b
41a0 41a4 41a8 41ab 41ae 41b2 41b4 41b8
41bc 41bf 41c2 41c6 41c8 41cc 41d0 41d3
41d5 41d9 41dd 41e1 41e4 41e8 41ec 41ee
41ef 41f4 1 41f8 41fc 4200 4203 4207
420b 420f 4213 4216 421a 421e 4221 4224
4229 422c 422f 4232 4233 4238 4239 1
423b 4240 4244 4248 424b 4250 4255 4258
425c 425d 4262 4265 426a 426b 4270 4273
4278 4279 427e 4281 4285 4286 428b 428e
4293 4294 4299 429c 42a0 42a4 42a7 42aa
42ab 42ad 42ae 42b3 42b4 42b9 42bb 42bf
42c2 42c4 42c8 42ca 42d6 42d8 42da 42db
42e0 42e4 42e6 42f2 42f4 42f8 42fc 42ff
4300 4302 4305 4308 4309 430e 4312 4316
431a 431e 4322 4326 432a 432e 4332 4336
433a 433e 4342 4346 434a 434e 4352 4356
435a 435e 4362 4366 436a 436e 4372 4376
437a 437e 4382 4386 438a 438e 4392 4396
439a 439e 43a2 43a6 43aa 43ae 43b2 43b6
43ba 43be 43c2 43c6 43ca 43ce 43d2 43d6
43da 43de 43e2 43e6 43ea 43f6 43fa 43ff
4403 4406 4407 440c 4410 4414 4417 441a
441e 4420 4424 4428 442b 442e 4432 4434
4438 443c 443f 4441 4445 4449 444d 4450
4454 4458 445a 445b 4460 1 4464 4468
446c 446f 4473 4477 447b 447f 4482 4486
448a 448d 4490 4495 4498 449b 449e 449f
44a4 44a5 1 44a7 44ac 44b0 44b4 44b7
44bc 44c1 44c4 44c8 44c9 44ce 44d1 44d6
44d7 44dc 44df 44e4 44e5 44ea 44ed 44f1
44f2 44f7 44fa 44ff 4500 4505 4508 450c
4510 4513 4516 4517 4519 451a 451f 4520
4525 4527 452b 452e 4530 4534 4536 4542
4544 4546 4547 454c 4550 4552 455e 4560
4564 4568 456b 456c 456e 4571 4574 4575
457a 457e 4581 4585 4589 458d 4591 4595
4599 459c 459f 45a2 45a3 45a5 45a9 45ab
45af 45b2 45b4 45b8 45bc 45c1 45c5 45c6
45ca 45ce 45d2 45d6 45db 45e0 45e4 45e8
45ec 45f1 45f5 45f9 45fc 45ff 4603 4605
4609 460d 4610 4613 4617 4619 461d 4621
4624 4628 462c 462f 4633 4636 463a 463d
463e 4643 4646 464a 4650 4652 4656 4659
465d 4661 4665 4669 466d 4671 4675 4679
467d 4681 4685 4689 468d 4691 4695 4699
469d 46a1 46a5 46a9 46ad 46b1 46b5 46b9
46bd 46c1 46c5 46c9 46cd 46d1 46d5 46d9
46dd 46e1 46e5 46e9 46ed 46f1 46f5 46f9
46fd 4701 4705 4709 470d 4711 4715 4719
471d 4721 4725 4729 472d 4731 473d 4741
4746 474a 474d 474e 4753 4757 475b 475e
4761 4765 4767 476b 476f 4772 4775 4779
477b 477f 4783 4786 4788 478c 4790 4794
4797 479b 479f 47a1 47a2 47a7 1 47ab
47af 47b3 47b6 47ba 47be 47c2 47c6 47c9
47cd 47d1 47d4 47d7 47dc 47df 47e2 47e5
47e6 47eb 47ec 1 47ee 47f3 47f7 47fb
47fe 4803 4808 480b 480f 4810 4815 4818
481d 481e 4823 4826 482b 482c 4831 4834
4838 4839 483e 4841 4846 4847 484c 484f
4853 4857 485a 485d 485e 4860 4861 4866
4867 486c 486e 4872 4875 4877 487b 487d
4889 488b 488d 488e 4893 4897 4899 48a5
48a7 48ab 48af 48b3 48b7 48bb 48bf 48cb
48cf 48d4 48d8 48db 48dc 48e1 48e5 48e9
48ec 48ef 48f3 48f5 48f9 48fd 4900 4903
4907 4909 490d 4911 4914 4916 491a 491e
4922 4925 4929 492d 492f 4930 4935 1
4939 493d 4941 4944 4948 494c 4950 4954
4957 495b 495f 4962 4965 496a 496d 4970
4973 4974 4979 497a 1 497c 4981 4985
4989 498c 4991 4996 4999 499d 499e 49a3
49a6 49ab 49ac 49b1 49b4 49b9 49ba 49bf
49c2 49c6 49c7 49cc 49cf 49d4 49d5 49da
49dd 49e1 49e5 49e8 49eb 49ec 49ee 49ef
49f4 49f5 49fa 49fc 4a00 4a03 4a05 4a09
4a0b 4a17 4a19 4a1b 4a1c 4a21 4a25 4a27
4a33 4a35 4a37 4a3b 4a42 4a46 4a4a 4a4f
4a51 4a55 4a59 4a5c 4a60 4a64 4a66 4a6a
4a6e 4a72 4a75 4a79 4a7d 4a7f 4a80 4a85
1 4a89 4a8d 4a91 4a94 4a98 4a9c 4aa0
4aa4 4aa7 4aab 4aaf 4ab2 4ab5 4aba 4abd
4ac0 4ac3 4ac4 4ac9 4aca 1 4acc 4ad1
4ad5 4ad9 4adc 4ae1 4ae6 4ae9 4aed 4aee
4af3 4af6 4afb 4afc 4b01 4b04 4b09 4b0a
4b0f 4b12 4b16 4b17 4b1c 4b1f 4b24 4b25
4b2a 4b2d 4b31 4b35 4b38 4b3b 4b3c 4b3e
4b3f 4b44 4b45 4b4a 4b4c 4b50 4b53 4b55
4b59 4b5b 4b67 4b69 4b6b 4b6c 4b71 4b75
4b77 4b83 4b85 4b89 4b8d 4b90 4b91 4b93
4b96 4b99 4b9a 4b9f 4ba2 4ba6 4baa 4bad
4bae 4bb0 4bb3 4bb6 4bb7 4bbc 1 4bbf
4bc4 4bc8 4bcc 4bd0 4bd4 4bd8 4be4 4be8
4bed 4bf1 4bf4 4bf5 4bfa 4bfe 4c02 4c05
4c08 4c0c 4c0e 4c12 4c16 4c19 4c1c 4c20
4c22 4c26 4c2a 4c2d 4c2f 4c33 4c37 4c3b
4c3e 4c42 4c46 4c48 4c49 4c4e 1 4c52
4c56 4c5a 4c5d 4c61 4c65 4c69 4c6d 4c70
4c74 4c78 4c7b 4c7e 4c83 4c86 4c89 4c8c
4c8d 4c92 4c93 1 4c95 4c9a 4c9e 4ca2
4ca5 4caa 4caf 4cb2 4cb6 4cb7 4cbc 4cbf
4cc4 4cc5 4cca 4ccd 4cd2 4cd3 4cd8 4cdb
4cdf 4ce0 4ce5 4ce8 4ced 4cee 4cf3 4cf6
4cfa 4cfe 4d01 4d04 4d05 4d07 4d08 4d0d
4d0e 4d13 4d15 4d19 4d1c 4d1e 4d22 4d24
4d30 4d32 4d34 4d35 4d3a 4d3e 4d40 4d4c
4d4e 4d50 4d54 4d57 4d5b 4d5e 4d62 4d66
4d6a 4d6e 4d72 4d76 4d79 4d7c 4d7f 4d80
4d82 4d86 4d8a 4d8e 4d92 4d96 4d9a 4d9e
4da2 4da6 4daa 4dae 4db2 4db6 4dba 4dbe
4dc2 4dc6 4dca 4dd6 4dda 4dde 4de1 4de5
4de9 4deb 4def 4df3 4df7 4dfa 4dfe 4e02
4e04 4e05 4e0a 1 4e0e 4e12 4e16 4e19
4e1d 4e21 4e25 4e29 4e2c 4e30 4e34 4e37
4e3a 4e3f 4e42 4e45 4e48 4e49 4e4e 4e4f
1 4e51 4e56 4e5a 4e5e 4e61 4e66 4e6b
4e6e 4e72 4e73 4e78 4e7b 4e80 4e81 4e86
4e89 4e8e 4e8f 4e94 4e97 4e9b 4e9c 4ea1
4ea4 4ea9 4eaa 4eaf 4eb2 4eb6 4eba 4ebd
4ec0 4ec1 4ec3 4ec4 4ec9 4eca 4ecf 4ed1
4ed5 4ed8 4eda 4ede 4ee0 4eec 4eee 4ef0
4ef1 4ef6 4efa 4efc 4f08 4f0a 4f0e 4f12
4f15 4f16 4f18 4f1b 4f1e 4f1f 4f24 4f28
4f2c 4f30 4f34 4f38 4f3c 4f40 4f44 4f48
4f4c 4f50 4f54 4f58 4f5c 4f60 4f64 4f68
4f6c 4f70 4f74 4f80 4f84 4f89 4f8d 4f90
4f91 4f96 4f9a 4f9e 4fa1 4fa4 4fa8 4faa
4fae 4fb2 4fb5 4fb8 4fbc 4fbe 4fc2 4fc6
4fc9 4fcb 4fcf 4fd3 4fd7 4fda 4fde 4fe2
4fe4 4fe5 4fea 1 4fee 4ff2 4ff6 4ff9
4ffd 5001 5005 5009 500c 5010 5014 5017
501a 501f 5022 5025 5028 5029 502e 502f
1 5031 5036 503a 503e 5041 5046 504b
504e 5052 5053 5058 505b 5060 5061 5066
5069 506e 506f 5074 5077 507b 507c 5081
5084 5089 508a 508f 5092 5096 509a 509d
50a0 50a1 50a3 50a4 50a9 50aa 50af 50b1
50b5 50b8 50ba 50be 50c0 50cc 50ce 50d0
50d1 50d6 50da 50dc 50e8 50ea 50ec 50f0
50f4 50f8 50fc 5100 5104 5108 510c 5110
5114 5118 511c 5120 5124 5128 512c 5130
5134 5138 513c 5140 5144 5150 5154 5159
515d 5160 5161 5166 516a 516e 5171 5174
5178 517a 517e 5182 5185 5188 518c 518e
5192 5196 5199 519b 519f 51a3 51a7 51aa
51ae 51b2 51b4 51b5 51ba 1 51be 51c2
51c6 51c9 51cd 51d1 51d5 51d9 51dc 51e0
51e4 51e7 51ea 51ef 51f2 51f5 51f8 51f9
51fe 51ff 1 5201 5206 520a 520e 5211
5216 521b 521e 5222 5223 5228 522b 5230
5231 5236 5239 523e 523f 5244 5247 524b
524c 5251 5254 5259 525a 525f 5262 5266
526a 526d 5270 5271 5273 5274 5279 527a
527f 5281 5285 5288 528a 528e 5290 529c
529e 52a0 52a1 52a6 52aa 52ac 52b8 52ba
52bc 52c0 52c4 52c7 52c9 52cd 52d1 52d4
52dc 52de 52df 52e2 52e4 52e5 52ea 52ec
52ee 52f3 52f7 52fc 5300 5304 5308 530c
5310 5314 5320 5324 5329 532d 5330 5331
5336 533a 533e 5341 5344 5348 534a 534e
5352 5355 5358 535c 535e 5362 5366 5369
536b 536f 5373 5377 537a 537e 5382 5384
5385 538a 1 538e 5392 5396 5399 539d
53a1 53a5 53a9 53ac 53b0 53b4 53b7 53ba
53bf 53c2 53c5 53c8 53c9 53ce 53cf 1
53d1 53d6 53da 53de 53e1 53e6 53eb 53ee
53f2 53f3 53f8 53fb 5400 5401 5406 5409
540e 540f 5414 5417 541b 541c 5421 5424
5429 542a 542f 5432 5436 543a 543d 5440
5441 5443 5444 5449 544a 544f 5451 5455
5458 545a 545e 5460 546c 546e 5470 5471
5476 547a 547c 5488 548a 548c 5490 5497
549b 549f 54a4 54a6 54aa 54ae 54b1 54b5
54b9 54bb 54bf 54c3 54c7 54ca 54ce 54d2
54d4 54d5 54da 1 54de 54e2 54e6 54e9
54ed 54f1 54f5 54f9 54fc 5500 5504 5507
550a 550f 5512 5515 5518 5519 551e 551f
1 5521 5526 552a 552e 5531 5536 553b
553e 5542 5543 5548 554b 5550 5551 5556
5559 555e 555f 5564 5567 556b 556c 5571
5574 5579 557a 557f 5582 5586 558a 558d
5590 5591 5593 5594 5599 559a 559f 55a1
55a5 55a8 55aa 55ae 55b0 55bc 55be 55c0
55c1 55c6 55ca 55cc 55d8 55da 55de 55e1
55e4 55e5 55ea 55ee 55f2 55f6 55f7 55f9
55fd 55ff 5603 5606 560a 560e 5612 5616
561a 561e 5622 5626 562a 562e 5632 5636
563a 5646 564a 564e 5651 5655 5659 565b
565f 5663 5667 566a 566e 5672 5674 5675
567a 1 567e 5682 5686 5689 568d 5691
5695 5699 569c 56a0 56a4 56a7 56aa 56af
56b2 56b5 56b8 56b9 56be 56bf 1 56c1
56c6 56ca 56ce 56d1 56d6 56db 56de 56e2
56e3 56e8 56eb 56f0 56f1 56f6 56f9 56fe
56ff 5704 5707 570b 570c 5711 5714 5719
571a 571f 5722 5726 572a 572d 5730 5731
5733 5734 5739 573a 573f 5741 5745 5748
574a 574e 5750 575c 575e 5760 5761 5766
576a 576c 5778 577a 577e 5782 5785 5786
5788 578b 578e 578f 5794 5798 579c 57a0
57a3 57a7 57ab 57af 57b2 57b6 57ba 57be
57c2 57c3 57c5 57c9 57cb 57cf 57d2 57d6
57da 57de 57e2 57e6 57ea 57ee 57f2 57fe
5802 5807 580b 580e 580f 5814 5818 581c
581f 5822 5826 5828 582c 5830 5833 5836
583a 583c 5840 5844 5847 5849 584d 5851
5855 5858 585c 5860 5862 5863 5868 1
586c 5870 5874 5877 587b 587f 5883 5887
588a 588e 5892 5895 5898 589d 58a0 58a3
58a6 58a7 58ac 58ad 1 58af 58b4 58b8
58bc 58bf 58c4 58c9 58cc 58d0 58d1 58d6
58d9 58de 58df 58e4 58e7 58ec 58ed 58f2
58f5 58f9 58fa 58ff 5902 5907 5908 590d
5910 5914 5918 591b 591e 591f 5921 5922
5927 5928 592d 592f 5933 5936 5938 593c
593e 594a 594c 594e 594f 5954 5958 595a
5966 5968 596c 5970 5973 5976 5979 597a
597f 5983 5987 598a 598d 5991 5993 5997
599a 599e 59a2 59a5 59a9 59ad 59b0 59b3
59b8 59bb 59be 59c1 59c2 59c7 59c8 1
59ca 59cf 59d3 59d7 59da 59df 59e4 59e7
59eb 59ec 59f1 59f4 59f9 59fa 59ff 5a02
5a07 5a08 5a0d 5a10 5a14 5a18 5a1b 5a1c
5a21 5a22 5a27 5a29 5a2d 5a30 5a34 5a38
5a3c 5a3f 5a43 5a45 5a49 5a4b 5a57 5a5b
5a5d 5a5e 5a67 
193b
2
0 1 a 6 e 12 19 :3 6
13 :3 6 17 26 :2 6 1 3 a
:2 1 4 :2 e 1d e :2 4 :2 12 21
2a 3c :2 21 12 :2 4 c 10 f
c 20 :2 29 c :2 4 d 11 10
d 21 :2 2a d :2 4 11 1a 19
:2 11 :2 4 11 1a 19 :2 11 :2 4 11
1a 19 :2 11 :2 4 18 21 20 :2 18
:2 4 :3 10 :2 4 d 16 15 :2 d :2 4
e 17 16 :2 e :2 4 18 21 20
:2 18 :2 4 18 21 20 :2 18 :2 4 :3 11
:2 4 :3 12 :2 4 :2 11 20 11 :2 4 :2 f
1e f :2 4 :2 c 1b c :2 4 :2 e
1d e :2 4 :2 12 21 12 :2 4 :2 12
21 12 :2 4 :2 e 1d e :2 4 :2 f
1e f :2 4 :2 e 1d e :2 4 :2 b
1a b :2 4 :2 f 1e f :2 4 :2 14
23 14 :2 4 :2 f 19 f :2 4 :2 f
19 f :2 4 9 12 11 :2 9 :2 4
11 1a 19 :2 11 :2 4 :3 10 :2 4 :2 16
2e 16 4 7 e 0 :2 7 11
14 27 2a f 20 23 28 30
d f 1c 1f 2e 30 3d 40
10 12 1f 30 33 e 11 29
2c a :6 7 c 15 :3 c :2 7 e
0 :2 7 11 1b 26 35 10 1d
2e 42 4b a :6 7 e 0 :2 7
11 1a f 10 23 3b a :6 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 58 5e 61 :2 58
6f 89 8 :2 6f d 10 :2 6f 15
18 :2 6f b e :2 6f 13 16 1f
27 :2 1f 36 :2 16 :2 6f b e :2 6f
13 16 1f 27 :2 1f 3a :2 16 :2 6f
42 45 :2 6f :2 7 4e :2 4 7 :2 11
23 :2 2d 39 3c 50 52 53 :2 50
:2 23 :3 7 :2 d 12 1e 61 64 :2 1e
:2 7 56 :2 4 e 17 2d c 1b
c d 1a :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 57 59 5a :2 57 :2 29 :3 d
:2 13 18 24 67 6a :2 24 77 7a
:2 24 7e 81 :2 24 8d 90 :2 24 98
9b :2 24 a7 aa b1 ba bd :2 aa
:2 24 :2 d 5d :2 a :2 7 :4 13 :2 7 4
:3 1 7 e 1c 1f :2 7 22 24
:2 22 a :2 14 26 :2 30 3c 40 54
56 57 :2 54 :2 26 :3 a :2 10 15 21
64 67 :2 21 74 77 :2 21 7b 7e
:2 21 88 8b 94 9c :2 a5 :2 94 c3
:2 8b :2 21 cb ce :2 21 d6 d9 :2 21
de e1 :2 21 e6 e9 :2 21 :2 a 5a
:2 7 a :2 14 26 :2 30 3c 3f 53
55 56 :2 53 :2 26 :3 a :2 10 15 21
64 67 :2 21 :2 a 59 :3 7 e :2 19
2a :2 33 50 56 :2 e 7 28 :2 4
8 :2 11 1c 1a :2 25 :2 1a 7 11
14 20 23 2e 31 3e 41 58
5b 68 6b 14 17 f 1d 2b
39 43 4e f 20 24 39 10
13 27 30 33 51 54 e 11
25 28 :2 a :2 13 1f a 7 f
d :2 16 22 d 1d :2 a :2 f d
:2 16 22 d 10 :2 1a 2c :2 36 42
46 5a 5d 5e :2 5a :2 2c :3 10 :2 16
1b 27 6b 6e :2 27 7b 7e :2 27
82 85 :2 27 91 94 :2 27 9c 9f
:2 27 ab ae b5 be c1 :2 ae :2 27
:2 10 61 :2 d :2 a :4 16 :2 a 7 :3 35
b :2 14 1f 1d :2 28 :2 1d a d
:2 17 29 :2 33 3f 42 56 59 5a
:2 56 :2 29 :3 d :2 13 18 24 68 6b
:2 24 78 7b :2 24 7f 82 :2 24 8c
8f 98 a0 :2 a9 :2 98 bc :2 8f :2 24
:2 d 5d :2 a d :2 17 29 :2 33 3f
42 56 59 5a :2 56 :2 29 :3 d :2 13
18 24 68 6b :2 24 :2 d 5d :3 a
11 :2 1c 2f :2 38 4a :2 11 a 7
38 d 16 21 :2 d 24 26 :2 24
2c 35 41 :2 2c 44 46 :2 44 :3 d
:2 17 29 :2 33 3f 43 57 5a 5b
:2 57 :2 29 :3 d :2 13 18 24 68 6b
:2 24 78 7b :2 24 7f 82 :2 24 8c
8f 98 a0 :2 a9 :2 98 c5 :2 8f :2 24
cd d0 :2 24 d8 db :2 24 e0 e3
:2 24 e8 eb :2 24 :2 d 5e :2 a d
:2 17 29 :2 33 3f 42 56 59 5a
:2 56 :2 29 :3 d :2 13 18 24 68 6b
:2 24 :2 d 5d :3 a 11 :2 1c 2d :2 36
51 57 :2 11 a 48 38 :2 7 a
13 1e :2 a 21 23 :2 21 a 1f
:2 28 :2 a 19 2e :2 19 :2 a :2 13 1f
a 7 25 :4 e d a 21 a
14 27 3e 53 12 13 20 31
3b 11 1f 30 48 :2 d :2 16 22
d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5d 60 61 :2 5d
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 94 97
:2 2a 9f a2 :2 2a ae b1 b8 c1
c4 :2 b1 :2 2a :2 13 64 :2 10 :2 d :4 19
:2 d a :3 28 :4 e d 1e 15 16
2a :2 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
60 63 64 :2 60 :2 32 :3 16 :2 1c 21
2d 71 74 :2 2d 81 84 :2 2d 88
8b :2 2d 97 9a :2 2d a2 a5 :2 2d
b1 b4 bb c4 c7 :2 b4 :2 2d :2 16
67 :2 13 :2 10 :4 1c :2 10 d :3 2f 11
:2 1a 25 23 :2 2e :2 23 10 1a 30
3c 4a 60 6d 13 20 2d 3d
4e 5d 66 6d 76 7d 8a 13
20 2a 33 43 56 63 70 13
21 30 3a 1b 2c 42 4f 13
20 2d 3d 4e 5d 66 6d 76
7d 8a 13 20 2a 33 43 56
63 70 13 21 30 3a 18 2f
43 19 2d 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 63 66 67
:2 63 :2 35 :3 19 :2 1f 24 30 74 77
:2 30 84 87 :2 30 8b 8e :2 30 9a
9d :2 30 a5 a8 :2 30 b4 b7 be
c7 ca :2 b7 :2 30 :2 19 6a :2 16 :2 13
:4 1f :2 13 10 :4 3e 1f 31 43 4e
56 62 70 86 93 13 20 2d
3d 4e 5d 66 6d 76 7d 8a
13 20 2a 33 43 56 63 70
13 21 30 3a 1a 2c 37 3f
4b 59 6f 7c 13 20 2d 3d
4e 5d 66 6d 76 7d 8a 13
20 2a 33 43 56 63 70 13
21 30 3a 18 2f 43 13 1a
16 22 :3 20 16 :2 1f 2b 16 27
16 :2 1f 2b 16 :4 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :7 d 1c
33 47 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 60 63 64 :2 60
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
81 84 :2 2d 88 8b :2 2d 97 9a
:2 2d a2 a5 :2 2d b1 b4 bb c4
c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c
:2 10 d :3 2f d 22 :2 2b :2 d 1c
33 48 :2 1c :2 d :2 16 22 d 1c
37 4b 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 60 63 64 :2 60
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
81 84 :2 2d 88 8b :2 2d 97 9a
:2 2d a2 a5 :2 2d b1 b4 bb c4
c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c
:2 10 d :4 2f :2 a 28 25 :2 7 11
1a 34 47 55 62 :2 a :2 13 1f
a 7 f d :2 16 22 d 1d
:2 a :2 f d :2 16 22 d 10 :2 1a
2c :2 36 42 46 5a 5d 5e :2 5a
:2 2c :3 10 :2 16 1b 27 6b 6e :2 27
7b 7e :2 27 82 85 :2 27 91 94
:2 27 9c 9f :2 27 ab ae b5 be
c1 :2 ae :2 27 :2 10 61 :2 d :2 a :4 16
:2 a 7 :3 35 7 f e 11 :2 f
30 33 :2 f 13 16 :2 f 7 35
7 17 7 a 13 1e :2 a 21
23 :2 21 a 1f :2 28 :2 a 19 2e
:2 19 :2 a :2 13 1f a 14 d 29
33 3c 4d 56 66 d 1f 28
37 d 1f 28 38 d 29 43
57 d 1f :6 d 1f d 1f :2 d
1c 13 20 31 3d 46 4e 57
65 6e 7c 85 93 9c a9 b2
c3 cc df e8 fd 106 121 12a
142 14b 15c 165 177 180 198 1a1
1b4 1bd 1de 1f3 207 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5d
60 61 :2 5d :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a 7e 81 :2 2a 85 88
:2 2a 94 97 :2 2a 9f a2 :2 2a ae
b1 b8 c1 c4 :2 b1 :2 2a :2 13 64
:2 10 :2 d :4 19 :2 d a :3 25 a f
:4 a 13 1d 32 :3 d 10 15 :2 10
:2 19 25 10 1b 10 :2 19 25 10
:4 d 11 :2 1a 26 23 :2 2f :2 23 :3 10
3f :2 d 17 :2 10 1e 27 36 10
1f 28 38 10 2b 45 5b 10
1d 10 16 10 1f 28 37 10
20 29 39 10 1b 10 2d 4c
64 10 30 52 6d 10 30 4e
52 68 78 10 33 51 55 6b
7b 10 26 3d 53 10 27 3f
16 2a 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 60 63 64 :2 60
:2 32 :3 16 :2 1c 21 2d 71 74 :2 2d
81 84 :2 2d 88 8b :2 2d 97 9a
:2 2d a2 a5 :2 2d b1 b4 bb c4
c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c
:2 10 d :3 a 17 2c 16 23 34
48 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :4 a e 25 d 13 :3 d :2 16
22 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5d 60 61
:2 5d :2 2f :3 13 :2 19 1e 2a 6e 71
:2 2a 7e 81 :2 2a 85 88 :2 2a 94
97 :2 2a 9f a2 :2 2a ae b1 b8
c1 c4 :2 b1 :2 2a :2 13 64 :2 10 :2 d
:4 19 :2 d a :4 25 :2 7 11 1d 2b
34 10 1d 2e 43 57 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
5a 5d 5e :2 5a :2 2c :3 10 :2 16 1b
27 6b 6e :2 27 7b 7e :2 27 82
85 :2 27 91 94 :2 27 9c 9f :2 27
ab ae b5 be c1 :2 ae :2 27 :2 10
61 :2 d :2 a :4 16 :2 a 7 :3 4 7
14 :2 7 14 :2 7 d e 11 :2 d
23 26 :2 d 13 16 :2 d 7 :5 4
9 :2 12 :2 4 d 17 1d 27 32
:3 7 a f :2 a :2 13 1f a 15
a :2 13 1f a :4 7 b :2 14 20
1d :2 29 :2 1d :3 a 39 :2 7 c f
17 1f 10 12 28 2a 10 12
28 2a 10 12 28 2a 10 12
25 27 10 12 25 27 10 12
25 27 16 23 34 41 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
60 63 64 :2 60 :2 32 :3 16 :2 1c 21
2d 71 74 :2 2d 81 84 :2 2d 88
8b :2 2d 97 9a :2 2d a2 a5 :2 2d
b1 b4 bb c4 c7 :2 b4 :2 2d :2 16
67 :2 13 :2 10 :4 1c :2 10 d :3 11 17
10 2d 49 5f 10 2d 49 60
10 2f 4b 64 10 2c 48 55
67 10 31 4d 60 78 10 34
50 66 81 10 22 33 46 58
6d 81 92 10 27 3d 57 10
22 34 47 5a 6f 84 95 a2
10 27 3a 4e 68 7e 10 21
2f 40 4e 5f 6d 7e 16 2a
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 60 63 64 :2 60 :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d 81 84
:2 2d 88 8b :2 2d 97 9a :2 2d a2
a5 :2 2d b1 b4 bb c4 c7 :2 b4
:2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10 d
:3 11 17 10 2c 10 2c 10 36
5d 78 10 2d 10 2d 10 37
5f 7b 10 2d 10 2d 10 37
57 73 10 2b 10 2b 10 35
56 70 10 2e 10 2e 10 38
5c 79 10 21 10 22 10 24
10 20 2d 10 26 39 10 29
3f 16 23 10 17 13 1f :3 1d
13 :2 1c 28 13 24 13 :2 1c 28
13 :4 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 60 63 64
:2 60 :2 32 :3 16 :2 1c 21 2d 71 74
:2 2d 81 84 :2 2d 88 8b :2 2d 97
9a :2 2d a2 a5 :2 2d b1 b4 bb
c4 c7 :2 b4 :2 2d :2 16 67 :2 13 :2 10
:4 1c :2 10 d :4 11 :2 a f 17 29
38 4f 62 76 :2 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :4 11 :2 1a 26 23 :2 2f :2 23 10
:4 44 43 42 :2 10 15 10 58 :2 d
17 34 4d 58 15 2a 15 2c
3f 49 5a 68 :2 10 :2 19 25 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 60 63 64 :2 60 :2 32
:3 16 :2 1c 21 2d 71 74 :2 2d 81
84 :2 2d 88 8b :2 2d 97 9a :2 2d
a2 a5 :2 2d b1 b4 bb c4 c7
:2 b4 :2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10
d :4 11 :2 1a 25 23 :2 2e :2 23 10
:4 44 43 42 :2 10 13 1c 27 :2 13
2a 2c :2 2a 13 1e 13 2e 22
39 4d 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :3 10 22 34 48 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 69 6a :2 66 :2 38 :3 1c :2 22 27
33 77 7a :2 33 87 8a :2 33 8e
91 :2 33 9d a0 :2 33 a8 ab :2 33
b7 ba c1 ca cd :2 ba :2 33 :2 1c
6d :2 19 :2 16 :4 22 :2 16 13 :3 10 22
3e 52 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :3 10 22 3f 53 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 69 6a :2 66 :2 38 :3 1c :2 22 27
33 77 7a :2 33 87 8a :2 33 8e
91 :2 33 9d a0 :2 33 a8 ab :2 33
b7 ba c1 ca cd :2 ba :2 33 :2 1c
6d :2 19 :2 16 :4 22 :2 16 13 :3 10 13
1e 13 :4 10 66 10 27 :2 10 1b
10 :5 d 1a :2 d 12 :4 d 16 1f
2c 37 :3 10 13 17 :2 13 :2 1c 28
13 1d 13 :2 1c 28 13 :4 10 14
:2 1d 29 26 :2 32 :2 26 :3 13 42 :2 10
13 1c 25 :2 13 28 2a :2 28 1d
32 3e 4a 16 22 2a 31 3c
1c 29 3a 4e 66 71 16 1d
19 25 :3 23 19 :2 22 2e 19 2a
19 :2 22 2e 19 :4 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
66 69 6a :2 66 :2 38 :3 1c :2 22 27
33 77 7a :2 33 87 8a :2 33 8e
91 :2 33 9d a0 :2 33 a8 ab :2 33
b7 ba c1 ca cd :2 ba :2 33 :2 1c
6d :2 19 :2 16 :4 22 :2 16 13 :3 2c 17
:2 20 2b 29 :2 34 :2 29 16 25 3c
49 5a 6e 77 82 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 69
6c 6d :2 69 :2 3b :3 1f :2 25 2a 36
7a 7d :2 36 8a 8d :2 36 91 94
:2 36 a0 a3 :2 36 ab ae :2 36 ba
bd c4 cd d0 :2 bd :2 36 :2 1f 70
:2 1c :2 19 :4 25 :2 19 16 :4 44 20 35
49 63 70 81 95 9e a9 19
20 1c 28 :3 26 1c :2 25 31 1c
2d 1c :2 25 31 1c :4 19 16 1e
1c :2 25 31 1c 2c :2 19 :2 1e 1c
:2 25 31 1c 1f :2 29 3b :2 45 51
55 69 6c 6d :2 69 :2 3b :3 1f :2 25
2a 36 7a 7d :2 36 8a 8d :2 36
91 94 :2 36 a0 a3 :2 36 ab ae
:2 36 ba bd c4 cd d0 :2 bd :2 36
:2 1f 70 :2 1c :2 19 :4 25 :2 19 16 :7 13
10 2c 16 1f 28 :2 16 2b 2d
:2 2b 1d 32 46 60 6d 7e 92
9b a6 16 1d 19 25 :3 23 19
:2 22 2e 19 2a 19 :2 22 2e 19
:4 16 13 1b 19 :2 22 2e 19 29
:2 16 :2 1b 19 :2 22 2e 19 1c :2 26
38 :2 42 4e 52 66 69 6a :2 66
:2 38 :3 1c :2 22 27 33 77 7a :2 33
87 8a :2 33 8e 91 :2 33 9d a0
:2 33 a8 ab :2 33 b7 ba c1 ca
cd :2 ba :2 33 :2 1c 6d :2 19 :2 16 :4 22
:2 16 13 :4 2f 2c :2 10 d :2 11 10
16 :3 10 :2 19 25 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
60 63 64 :2 60 :2 32 :3 16 :2 1c 21
2d 71 74 :2 2d 81 84 :2 2d 88
8b :2 2d 97 9a :2 2d a2 a5 :2 2d
b1 b4 bb c4 c7 :2 b4 :2 2d :2 16
67 :2 13 :2 10 :4 1c :2 10 d :3 11 17
2c 3c 48 16 23 34 40 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 60 63 64 :2 60 :2 32 :3 16 :2 1c
21 2d 71 74 :2 2d 81 84 :2 2d
88 8b :2 2d 97 9a :2 2d a2 a5
:2 2d b1 b4 bb c4 c7 :2 b4 :2 2d
:2 16 67 :2 13 :2 10 :4 1c :2 10 d :3 11
10 19 24 :2 10 27 29 :2 27 1a
:2 13 18 21 28 2d 36 13 21
13 22 13 24 13 20 13 22
13 23 13 1e 13 30 4f 67
13 33 55 70 13 19 13 2b
2f 45 55 13 36 54 58 6e
7e 13 29 40 56 13 2a 42
13 19 2d 36 49 13 1a 16
22 :3 20 16 :2 1f 2b 16 27 16
:2 1f 2b 16 :4 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 63
66 67 :2 63 :2 35 :3 19 :2 1f 24 30
74 77 :2 30 84 87 :2 30 8b 8e
:2 30 9a 9d :2 30 a5 a8 :2 30 b4
b7 be c7 ca :2 b7 :2 30 :2 19 6a
:2 16 :2 13 :4 1f :2 13 10 :3 2b 13 1c
25 :2 13 28 2a :2 28 13 21 :2 13
26 36 44 59 65 68 6b :2 26
13 2c :2 10 2b 10 15 :4 10 19
22 2d :3 13 16 1a :2 16 :2 1f 2b
16 20 16 :2 1f 2b 16 :4 13 17
:2 20 2c 29 :2 35 :2 29 :3 16 45 :2 13
1d :2 16 1b 24 16 1b 24 16
24 16 25 16 27 16 23 16
25 16 26 16 21 16 33 52
6a 16 36 58 73 16 1c 16
2e 32 48 58 16 39 57 5b
71 81 16 2c 43 59 16 2d
45 16 2e 1c 30 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :3 10 1d 29
37 40 58 65 16 1d 19 25
:3 23 19 :2 22 2e 19 2a 19 :2 22
2e 19 :4 16 13 1b 19 :2 22 2e
19 29 :2 16 :2 1b 19 :2 22 2e 19
1c :2 26 38 :2 42 4e 52 66 69
6a :2 66 :2 38 :3 1c :2 22 27 33 77
7a :2 33 87 8a :2 33 8e 91 :2 33
9d a0 :2 33 a8 ab :2 33 b7 ba
c1 ca cd :2 ba :2 33 :2 1c 6d :2 19
:2 16 :4 22 :2 16 13 :4 10 14 d 13
19 :3 13 :2 1c 28 13 10 18 16
:2 1f 2b 16 26 :2 13 :2 18 16 :2 1f
2b 16 19 :2 23 35 :2 3f 4b 4f
63 66 67 :2 63 :2 35 :3 19 :2 1f 24
30 74 77 :2 30 84 87 :2 30 8b
8e :2 30 9a 9d :2 30 a5 a8 :2 30
b4 b7 be c7 ca :2 b7 :2 30 :2 19
6a :2 16 :2 13 :4 1f :2 13 10 :3 d 14
1d 28 :2 14 2b 2d :2 2b 13 35
3e 46 :2 35 49 4b :2 49 34 :2 13
1d 32 3d 4a 5e 16 1d 19
25 :3 23 19 :2 22 2e 19 2a 19
:2 22 2e 19 :4 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
6a 6b :2 66 :2 38 :3 1c :2 22 27 33
78 7b :2 33 88 8b :2 33 8f 92
:2 33 9e a1 :2 33 a9 ac :2 33 b8
bb c2 cb ce :2 bb :2 33 :2 1c 6e
:2 19 :2 16 :4 22 :2 16 13 :4 4e :3 10 1e
:2 10 23 33 41 56 62 65 68
:2 23 10 1a 31 37 44 52 5c
6a 18 2d 3b 49 58 64 70
18 2f 45 :2 13 :2 1c 28 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 63 67 68 :2 63 :2 35 :3 19
:2 1f 24 30 75 78 :2 30 85 88
:2 30 8c 8f :2 30 9b 9e :2 30 a6
a9 :2 30 b5 b8 bf c8 cb :2 b8
:2 30 :2 19 6b :2 16 :2 13 :4 1f :2 13 10
:3 d 13 1c 28 :2 13 2b 2d :2 2b
1d :6 16 2e 16 2f 16 2f 16
2e 45 16 1c 29 3a 48 16
1d 19 25 :3 23 19 :2 22 2e 19
2a 19 :2 22 2e 19 :4 16 13 1b
19 :2 22 2e 19 29 :2 16 :2 1b 19
:2 22 2e 19 1c :2 26 38 :2 42 4e
52 66 6a 6b :2 66 :2 38 :3 1c :2 22
27 33 78 7b :2 33 88 8b :2 33
8f 92 :2 33 9e a1 :2 33 a9 ac
:2 33 b8 bb c2 cb ce :2 bb :2 33
:2 1c 6e :2 19 :2 16 :4 22 :2 16 13 :4 2f
1d :6 16 2e 16 2f 16 2f 16
2e 45 16 31 48 1c 29 3a
48 16 1d 19 25 :3 23 19 :2 22
2e 19 2a 19 :2 22 2e 19 :4 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 66 6a 6b :2 66 :2 38
:3 1c :2 22 27 33 78 7b :2 33 88
8b :2 33 8f 92 :2 33 9e a1 :2 33
a9 ac :2 33 b8 bb c2 cb ce
:2 bb :2 33 :2 1c 6e :2 19 :2 16 :4 22 :2 16
13 :7 10 :4 d f d :3 11 :2 a d
a :3 7 11 1d 2b 34 4c 59
a 11 d 19 :3 17 d :2 16 22
d 1e d :2 16 22 d :4 a 7
f d :2 16 22 d 1d :2 a :2 f
d :2 16 22 d 10 :2 1a 2c :2 36
42 46 5a 5e 5f :2 5a :2 2c :3 10
:2 16 1b 27 6c 6f :2 27 7c 7f
:2 27 83 86 :2 27 92 95 :2 27 9d
a0 :2 27 ac af b6 bf c2 :2 af
:2 27 :2 10 62 :2 d :2 a :4 16 :2 a 7
:4 4 8 1 7 d :3 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 57 5b 5c :2 57
:2 29 :3 d :2 13 18 24 69 6c :2 24
79 7c :2 24 80 83 :2 24 8f 92
:2 24 9a 9d :2 24 a9 ac b3 bc
bf :2 ac :2 24 :2 d 5f :2 a :2 7 :4 13
:2 7 4 :3 1 7 15 17 :2 15 7
1a 24 :2 1a 7 19 :2 4 19 1f
28 34 3a 43 4f 59 62 :2 c
1a 27 :2 7 :2 10 1c 7 4 c
a :2 13 1f a 1a :2 7 :2 c a
:2 13 1f a d :2 17 29 :2 33 3f
43 57 5b 5c :2 57 :2 29 :3 d :2 13
18 24 69 6c :2 24 79 7c :2 24
80 83 :2 24 8f 92 :2 24 9a 9d
:2 24 a9 ac b3 bc bf :2 ac :2 24
:2 d 5f :2 a :2 7 :4 13 :2 7 4 :3 1
7 10 1f :2 7 22 24 :2 22 7
14 :2 1d :2 7 :2 10 1c 30 3e 4d
:2 1c 7 26 :2 4 e 7 1f 2c
3a 47 d 1a 7 e a 16
:3 14 a :2 13 1f a 1b a :2 13
1f a :4 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 57 5b
5c :2 57 :2 29 :3 d :2 13 18 24 69
6c :2 24 79 7c :2 24 80 83 :2 24
8f 92 :2 24 9a 9d :2 24 a9 ac
b3 bc bf :2 ac :2 24 :2 d 5f :2 a
:2 7 :4 13 :2 7 4 :3 1 7 :2 10 19
1b :2 19 7 :2 10 1c 7 1f :2 4
7 :2 11 23 :2 2d 39 3c 50 54
55 :2 50 :2 23 :3 7 :2 d 12 1e 63
66 :2 1e 73 76 :2 1e 7a 7d :2 1e
87 8a :2 93 :2 1e :2 7 58 :3 4 b
:2 14 4 :9 1 
193b
4
0 :2 1 :6 3 :4 4
:5 5 2 :2 6 :2 1
:6 8 :a 9 :a a :a b
:7 c :7 d :7 e :7 f
:5 10 :7 11 :7 12 :7 13
:7 14 :5 15 :5 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :7 25 :7 26 :5 27
:6 28 :2 2a 0 :2 2a
:4 2b :5 2c :8 2d :5 2e
:4 2f 2b :5 2a :7 32
:2 34 0 :2 34 :4 35
:5 36 35 :5 34 :2 38
0 :2 38 :2 39 3a
:3 3b 39 :5 38 :b 3e
:11 3f 40 :2 3f :2 40
:2 3f :2 40 :2 3f :2 41
:2 3f :9 41 :2 3f :2 42
:2 3f :9 42 :2 3f :2 42
:4 3f :3 3e :11 45 :b 46
:3 45 :3 4c :2 4d 4e
:2 4f 4c :5 50 4b
52 :5 53 :3 52 :2 54
:5 56 :11 57 :24 58 :3 57
:2 55 :6 54 51 :3 3d
:a 5e :11 5f :30 60 :3 5f
:11 62 :b 63 :3 62 :c 65
:3 5e :a 68 :c 6a :2 6b
:6 6c :4 6d :7 6e :4 6f
6a :5 70 69 72
:5 73 :3 72 :2 74 :5 76
:11 77 :24 78 :3 77 :2 75
:6 74 71 :3 68 :a 7d
:11 7e :20 7f :3 7e :11 81
:b 82 :3 81 :b 84 85
7d :14 85 :11 86 :30 87
:3 86 :11 89 :b 8a :3 89
:c 8c 85 :3 7d :9 8f
:5 91 :6 92 :5 93 94
8f :5 94 :3 95 :4 97
98 :4 99 :4 9a 97
:5 9b 96 9d :5 9e
:3 9d :2 9f :5 a1 :11 a2
:24 a3 :3 a2 :2 a0 :6 9f
9c :3 94 :5 a8 aa
ab :2 ac aa :5 ad
a9 af :5 b0 :3 af
:2 b1 :5 b3 :11 b4 :24 b5
:3 b4 :2 b2 :6 b1 ae
:3 a8 :a b9 :6 bb :b bc
:8 bd :4 be :4 bf :b c0
:8 c1 :4 c2 :3 c3 :2 c4
bb :6 c5 :5 c6 c5
:5 c8 c7 :3 c5 ba
cb :5 cc :3 cb :2 cd
:5 cf :11 d0 :24 d1 :3 d0
:2 ce :6 cd ca :4 b9
:9 d7 :b d8 :8 d9 :4 da
:8 db :b dc :8 dd :4 de
:3 df d7 :6 e0 :5 e1
e0 :5 e3 e2 :3 e0
d6 e6 :5 e7 :3 e6
:2 e8 :5 ea :11 eb :24 ec
:3 eb :2 e9 :6 e8 e5
:4 d5 :3 b9 :4 f2 :6 f3
:5 f4 f3 :5 f6 f5
:3 f3 f1 f9 :5 fa
:3 f9 :2 fb :5 fd :11 fe
:24 ff :3 fe :2 fc :6 fb
f8 :3 a8 :5 104 :7 105
:5 106 :4 108 :6 109 :5 10a
109 :5 10c 10b :3 109
107 10f :5 110 :3 10f
:2 111 :5 113 :11 114 :24 115
:3 114 :2 112 :6 111 10e
:6 a8 94 :3 8f :7 11d
:5 11e 11c 120 :5 121
:3 120 :2 122 :5 124 :11 125
:24 126 :3 125 :2 123 :6 122
11f :3 68 :2 12b :2 12c
:2 12b :2 12c :2 12b :2 12d
:3 12b 68 :3 12f :9 132
:5 134 :6 135 :5 136 139
:7 13a :4 13b :4 13c :4 13d
:2 13e 13f 140 141
142 143 :2 144 :2 145
146 :2 147 :24 148 139
:6 149 :5 14a 149 :5 14c
14b :3 149 138 14f
:5 150 :3 14f :2 151 :5 153
:11 154 :24 155 :3 154 :2 152
:6 151 14e :3 132 :5 15c
15e :6 15f :3 160 :5 161
160 :5 163 162 :3 160
:a 165 :2 166 :3 165 16a
16b :4 16c :4 16d :4 16e
:2 16f :2 170 :4 171 :4 172
:2 173 :4 174 :4 175 :6 176
:6 177 :4 178 :3 179 :2 17a
16a :6 17b :5 17c 17b
:5 17e 17d :3 17b 169
181 :5 182 :3 181 :2 183
:5 185 :11 186 :24 187 :3 186
:2 184 :6 183 180 :3 15e
:2 18d :4 18e 18d :6 18f
:5 190 18f :5 192 191
:3 18f 18c 195 :5 196
:3 195 :2 197 :5 199 :11 19a
:24 19b :3 19a :2 198 :6 197
194 :4 15e 19f 132
:4 1a3 :5 1a4 1a2 1a6
:5 1a7 :3 1a6 :2 1a8 :5 1aa
:11 1ab :24 1ac :3 1ab :2 1a9
:6 1a8 1a5 :6 132 :4 1b3
:5 1b4 1b3 :6 1b5 :5 1b6
1b5 :5 1b8 1b7 :3 1b5
1b2 1bb :5 1bc :3 1bb
:2 1bd :5 1bf :11 1c0 :24 1c1
:3 1c0 :2 1be :6 1bd 1ba
:3 12e :3 1c6 :3 1c7 1c9
1ca :2 1cb :2 1ca :2 1cb
:2 1ca :2 1cc :2 1ca 1c9
12e :3 68 :5 1d3 1d5
:8 1d6 :3 1d7 :5 1d8 1d7
:5 1da 1d9 :3 1d7 :a 1dd
:2 1de :3 1dd 1e2 1e4
:2 1e9 :4 1ea :4 1eb :4 1ec
:4 1ed :4 1ee :4 1ef :4 1f0
1e9 :6 1f1 :5 1f2 1f1
:5 1f4 1f3 :3 1f1 1e8
1f7 :5 1f8 :3 1f7 :2 1f9
:5 1fb :11 1fc :24 1fd :3 1fc
:2 1fa :6 1f9 1f6 :3 1e4
204 :4 205 :4 206 :4 207
:5 208 :5 209 :5 20a :8 20b
:4 20c :9 20d :6 20e :8 20f
:2 210 204 :6 211 :5 212
211 :5 214 213 :3 211
203 217 :5 218 :3 217
:2 219 :5 21b :11 21c :24 21d
:3 21c :2 21a :6 219 216
:3 1e4 223 :2 224 :2 225
:4 226 :2 227 :2 228 :4 229
:2 22a :2 22b :4 22c :2 22d
:2 22e :4 22f :2 230 :2 231
:4 232 :2 233 :2 234 :2 235
:3 236 :3 237 :3 238 :2 239
223 :6 23a :5 23b 23a
:5 23d 23c :3 23a 222
240 :5 241 :3 240 :2 242
:5 244 :11 245 :24 246 :3 245
:2 243 :6 242 23f :6 1e4
24d :7 252 :5 253 251
255 :5 256 :3 255 :2 257
:5 259 :11 25a :24 25b :3 25a
:2 258 :6 257 254 :3 24d
:12 260 :2 261 :3 260 :4 265
:2 266 :6 267 265 :5 268
264 26a :5 26b :3 26a
:2 26c :5 26e :11 26f :24 270
:3 26f :2 26d :6 26c 269
:3 24d :12 276 :9 277 :3 278
277 :4 27c :6 27d :5 27e
27d :5 280 27f :3 27d
27b 283 :5 284 :3 283
:2 285 :5 287 :11 288 :24 289
:3 288 :2 286 :6 285 282
:3 279 :4 28f :6 290 :5 291
290 :5 293 292 :3 290
28e 296 :5 297 :3 296
:2 298 :5 29a :11 29b :24 29c
:3 29b :2 299 :6 298 295
:3 279 :4 2a2 :6 2a3 :5 2a4
2a3 :5 2a6 2a5 :3 2a3
2a1 2a9 :5 2aa :3 2a9
:2 2ab :5 2ad :11 2ae :24 2af
:3 2ae :2 2ac :6 2ab 2a8
:3 279 :4 2b5 :6 2b6 :5 2b7
2b6 :5 2b9 2b8 :3 2b6
2b4 2bc :5 2bd :3 2bc
:2 2be :5 2c0 :11 2c1 :24 2c2
:3 2c1 :2 2bf :6 2be 2bb
:3 279 :3 2c7 279 :3 277
276 :3 2ca :3 2cb 2c9
:3 276 :3 2ce :5 2d3 2d5
:7 2d6 :3 2d7 :5 2d8 2d7
:5 2da 2d9 :3 2d7 :a 2dd
:2 2de :3 2dd :9 2e2 :4 2e4
:5 2e5 :6 2e6 2e4 :6 2e7
:5 2e8 2e7 :5 2ea 2e9
:3 2e7 2e3 2ed :5 2ee
:3 2ed :2 2ef :5 2f1 :11 2f2
:24 2f3 :3 2f2 :2 2f0 :6 2ef
2ec :3 2e2 :a 2f9 :8 2fb
:6 2fc :5 2fd 2fc :5 2ff
2fe :3 2fc 2fa 302
:5 303 :3 302 :2 304 :5 306
:11 307 :24 308 :3 307 :2 305
:6 304 301 :4 2f9 :a 30e
:6 30f :5 310 30f :5 312
311 :3 30f 30d 315
:5 316 :3 315 :2 317 :5 319
:11 31a :24 31b :3 31a :2 318
:6 317 314 :4 30c :3 2f9
320 2e2 :9 320 :a 322
:6 323 :5 324 323 :5 326
325 :3 323 321 329
:5 32a :3 329 :2 32b :5 32d
:11 32e :24 32f :3 32e :2 32c
:6 32b 328 :4 320 :3 2e2
2d5 334 24d :4 336
:5 337 335 339 :5 33a
:3 339 :2 33b :5 33d :11 33e
:24 33f :3 33e :2 33c :6 33b
338 :3 24d :4 345 :4 346
345 :6 347 :5 348 347
:5 34a 349 :3 347 344
34d :5 34e :3 34d :2 34f
:5 351 :11 352 :24 353 :3 352
:2 350 :6 34f 34c :3 24d
:9 358 35a 35b :6 35c
:2 35d :2 35e :2 35f :2 360
:2 361 :2 362 :2 363 :4 364
:4 365 :2 366 :5 367 :6 368
:4 369 :3 36a 36b :4 36c
35a :6 36d :5 36e 36d
:5 370 36f :3 36d 359
373 :5 374 :3 373 :2 375
:5 377 :11 378 :24 379 :3 378
:2 376 :6 375 372 :3 358
:9 37e :3 380 :b 381 :3 37e
358 :5 386 388 :6 389
:3 38a :5 38b 38a :5 38d
38c :3 38a :a 38f :2 390
:3 38f 394 395 :3 396
:3 397 :2 398 :2 399 :2 39a
:2 39b :2 39c :2 39d :2 39e
:4 39f :4 3a0 :2 3a1 :5 3a2
:6 3a3 :4 3a4 :3 3a5 :2 3a6
:2 3a7 394 :6 3a8 :5 3a9
3a8 :5 3ab 3aa :3 3a8
393 3ae :5 3af :3 3ae
:2 3b0 :5 3b2 :11 3b3 :24 3b4
:3 3b3 :2 3b1 :6 3b0 3ad
:3 388 :7 3bc :6 3bd :5 3be
3bd :5 3c0 3bf :3 3bd
3bb 3c3 :5 3c4 :3 3c3
:2 3c5 :5 3c7 :11 3c8 :24 3c9
:3 3c8 :2 3c6 :6 3c5 3c2
:4 388 3cd 383 :4 3d0
:5 3d1 3cf 3d3 :5 3d4
:3 3d3 :2 3d5 :5 3d7 :11 3d8
:24 3d9 :3 3d8 :2 3d6 :6 3d5
3d2 :3 383 :16 3de :6 3e0
:6 3e1 :5 3e2 3e1 :5 3e4
3e3 :3 3e1 3df 3e7
:5 3e8 :3 3e7 :2 3e9 :5 3eb
:11 3ec :24 3ed :3 3ec :2 3ea
:6 3e9 3e6 :6 3de :3 3f4
:b 3f5 :7 3f8 :7 3f9 :3 3fa
3f8 :5 3fb 3f7 3fd
:5 3fe :3 3fd :2 3ff :5 401
:11 402 :24 403 :3 402 :2 400
:6 3ff 3fc :3 383 :9 409
40b 40c 40d 40e
40f 410 :2 411 :2 412
:2 413 :3 414 415 :4 416
40b :6 417 :5 418 417
:5 41a 419 :3 417 40a
41d :5 41e :3 41d :2 41f
:5 421 :11 422 :24 423 :3 422
:2 420 :6 41f 41c :4 409
429 42a 42b 42c
42d 42e :2 42f :2 430
:2 431 :3 432 :3 433 :4 434
429 :6 435 :5 436 435
:5 438 437 :3 435 428
43b :5 43c :3 43b :2 43d
:5 43f :11 440 :24 441 :3 440
:2 43e :6 43d 43a :4 427
:3 409 383 :3 358 449
44a :5 24d 44c 44b
:3 1e2 :7 451 :6 452 :5 453
452 :5 455 454 :3 452
450 458 :5 459 :3 458
:2 45a :5 45c :11 45d :24 45e
:3 45d :2 45b :6 45a 457
:4 1d5 463 3d :4 467
:5 468 466 46a :5 46b
:3 46a :2 46c :5 46e :11 46f
:24 470 :3 46f :2 46d :6 46c
469 :3 3d :5 475 :6 476
:3 475 :9 47b 47c :3 47d
47b :5 47e 47a 480
:5 481 :3 480 :2 482 :5 484
:11 485 :24 486 :3 485 :2 483
:6 482 47f :3 3d :9 48b
:5 48c :a 48d :3 48b 491
:5 492 :2 493 491 :6 494
:5 495 494 :5 497 496
:3 494 490 49a :5 49b
:3 49a :2 49c :5 49e :11 49f
:24 4a0 :3 49f :2 49d :6 49c
499 :3 3d :7 4a5 :5 4a6
:3 4a5 :11 4a9 :19 4aa :3 4a9
:5 4ac :2 3d :7 1 
5a69
4
:3 0 1 :3 0 2
:a 0 1936 1 :7 0
5 37 0 3
4 :3 0 5 :3 0
6 :3 0 3 :5 0
1 7 6 :3 0
9 :2 0 7 8
:3 0 7 :7 0 b
a :3 0 8 :3 0
a :2 0 9 :7 0
10 e f :2 0
b :3 0 8 :3 0
12 14 0 1936
2 15 :2 0 f
:2 0 d 8 :3 0
18 :7 0 7 :3 0
1c 19 1a 1934
0 c :6 0 12
:2 0 12 8 :3 0
1e :7 0 e :3 0
9 :3 0 f 20
23 26 1f 24
1934 0 d :6 0
12 :2 0 16 11
:3 0 14 28 2a
2 :5 0 13 :3 0
14 :3 0 2c 2d
0 30 2b 2e
1934 0 10 :6 0
17 :2 0 1a 11
:3 0 18 32 34
2 :5 0 13 :3 0
14 :3 0 36 37
0 3a 35 38
1934 0 15 :6 0
17 :2 0 1e 6
:3 0 1c 3c 3e
:6 0 41 3f 0
1934 0 16 :6 0
17 :2 0 22 6
:3 0 20 43 45
:6 0 48 46 0
1934 0 18 :6 0
17 :2 0 26 6
:3 0 24 4a 4c
:6 0 4f 4d 0
1934 0 19 :6 0
2c 17b 0 2a
6 :3 0 28 51
53 :6 0 56 54
0 1934 0 1a
:6 0 17 :2 0 30
1c :3 0 58 :7 0
5b 59 0 1934
0 1b :6 0 6
:3 0 17 :2 0 2e
5d 5f :6 0 62
60 0 1934 0
1d :6 0 17 :2 0
34 6 :3 0 32
64 66 :6 0 69
67 0 1934 0
1e :6 0 17 :2 0
38 6 :3 0 36
6b 6d :6 0 70
6e 0 1934 0
1f :6 0 3e 20a
0 3c 6 :3 0
3a 72 74 :6 0
77 75 0 1934
0 20 :6 0 f
:2 0 40 22 :3 0
79 :7 0 7c 7a
0 1934 0 21
:6 0 22 :3 0 7e
:7 0 81 7f 0
1934 0 23 :6 0
f :2 0 42 8
:3 0 83 :7 0 87
84 85 1934 0
24 :6 0 f :2 0
44 8 :3 0 89
:7 0 8d 8a 8b
1934 0 25 :6 0
f :2 0 46 8
:3 0 8f :7 0 93
90 91 1934 0
26 :6 0 f :2 0
48 8 :3 0 95
:7 0 99 96 97
1934 0 27 :6 0
f :2 0 4a 8
:3 0 9b :7 0 9f
9c 9d 1934 0
28 :6 0 f :2 0
4c 8 :3 0 a1
:7 0 a5 a2 a3
1934 0 29 :6 0
f :2 0 4e 8
:3 0 a7 :7 0 ab
a8 a9 1934 0
2a :6 0 f :2 0
50 8 :3 0 ad
:7 0 b1 ae af
1934 0 2b :6 0
f :2 0 52 8
:3 0 b3 :7 0 b7
b4 b5 1934 0
2c :6 0 f :2 0
54 8 :3 0 b9
:7 0 bd ba bb
1934 0 2d :6 0
f :2 0 56 8
:3 0 bf :7 0 c3
c0 c1 1934 0
2e :6 0 32 :2 0
58 8 :3 0 c5
:7 0 c9 c6 c7
1934 0 2f :6 0
32 :2 0 5a 31
:3 0 cb :7 0 cf
cc cd 1934 0
30 :6 0 35 :2 0
5c 31 :3 0 d1
:7 0 d5 d2 d3
1934 0 33 :6 0
a :2 0 60 6
:3 0 5e d7 d9
:6 0 dc da 0
1934 0 34 :6 0
66 400 0 64
6 :3 0 62 de
e0 :6 0 e3 e1
0 1934 0 36
:9 0 68 38 :3 0
e5 :7 0 e8 e6
0 1934 0 37
:6 0 8 :3 0 ea
0 2 :5 0 f
:2 0 ee eb ec
1934 0 39 :6 0
3a :3 0 3b :a 0
2 10f :4 0 f0
f3 0 f1 :3 0
3c :3 0 3d :3 0
3c :3 0 3e :3 0
3f :3 0 3c :3 0
40 :3 0 41 :3 0
42 :3 0 42 :3 0
43 :3 0 3c :3 0
43 :3 0 42 :3 0
44 :3 0 3c :3 0
45 :3 0 42 :3 0
43 :3 0 16 :3 0
3c :3 0 46 :3 0
3c :3 0 47 :3 0
3c :3 0 48 :4 0
49 1 :8 0 110
f0 f3 111 0
1934 6a 111 113
110 112 :6 0 10f
:7 0 111 :3 0 6c
4b :3 0 4c :2 0
4 115 116 0
117 :7 0 11a 118
0 1934 0 4a
:6 0 3a :3 0 4d
:a 0 3 12a :4 0
11c 11f 0 11d
:3 0 4e :3 0 4f
:3 0 50 :3 0 51
:3 0 43 :3 0 16
:3 0 3d :3 0 3
:3 0 46 :4 0 52
1 :8 0 12b 11c
11f 12c 0 1934
6e 12c 12e 12b
12d :6 0 12a :7 0
12c 3a :3 0 53
:a 0 4 13b :5 0
130 133 0 131
:3 0 45 :3 0 3d
:3 0 3f :3 0 46
:3 0 48 :3 0 3
:4 0 54 1 :8 0
13c 130 133 13d
0 1934 70 13d
13f 13c 13e :6 0
13b :7 0 13d 55
:3 0 56 :3 0 140
141 0 55 :3 0
57 :3 0 143 144
0 2 :4 0 72
145 147 142 149
148 :2 0 58 :3 0
59 :3 0 14b 14c
0 5a :4 0 55
:3 0 5b :3 0 14f
150 0 2 :4 0
74 151 153 5c
:4 0 5d :2 0 5e
:3 0 76 156 158
:3 0 5f :4 0 5d
:2 0 60 :4 0 79
15b 15d :3 0 5d
:2 0 3 :3 0 7c
15f 161 :3 0 5d
:2 0 60 :4 0 7f
163 165 :3 0 5d
:2 0 61 :4 0 82
167 169 :3 0 5d
:2 0 e :3 0 62
:3 0 7 :3 0 85
16d 16f 63 :4 0
87 16c 172 8a
16b 174 :3 0 5d
:2 0 61 :4 0 8d
176 178 :3 0 5d
:2 0 e :3 0 62
:3 0 9 :3 0 90
17c 17e 63 :4 0
92 17b 181 95
17a 183 :3 0 5d
:2 0 64 :4 0 98
185 187 :3 0 9b
14d 189 :2 0 18b
a0 18c 14a 18b
0 18d a2 0
1932 55 :3 0 56
:3 0 18e 18f 0
55 :3 0 65 :3 0
191 192 0 a
:2 0 2 :4 0 66
:2 0 67 :2 0 a
:2 0 a4 197 199
:3 0 a7 193 19b
190 19d 19c :2 0
58 :3 0 68 :3 0
19f 1a0 0 5a
:4 0 69 :4 0 5d
:2 0 5e :3 0 ab
1a4 1a6 :3 0 ae
1a1 1a8 :2 0 1aa
b1 1ab 19e 1aa
0 1ac b3 0
1932 e :3 0 6a
:3 0 6b :3 0 28
:3 0 36 :3 0 41
:3 0 44 :3 0 3
:4 0 6c 1 :8 0
1bb 4b :3 0 6d
:3 0 1b6 1b7 0
6e :3 0 1b8 1b9
0 1bb b5 20e
6f :3 0 4b :3 0
6d :3 0 1bd 1be
0 6e :3 0 1bf
1c0 0 1c2 b8
1c4 ba 1c3 1c2
:2 0 20c 70 :3 0
4b :3 0 6d :3 0
1c7 1c8 0 6e
:3 0 1c9 1ca 0
204 55 :3 0 56
:3 0 1cc 1cd 0
55 :3 0 65 :3 0
1cf 1d0 0 71
:2 0 2 :4 0 72
:2 0 67 :2 0 a
:2 0 bc 1d5 1d7
:3 0 bf 1d1 1d9
1ce 1db 1da :2 0
58 :3 0 68 :3 0
1dd 1de 0 5a
:4 0 73 :4 0 5d
:2 0 5e :3 0 c3
1e2 1e4 :3 0 5d
:2 0 74 :4 0 c6
1e6 1e8 :3 0 5d
:2 0 75 :4 0 c9
1ea 1ec :3 0 5d
:2 0 6e :3 0 cc
1ee 1f0 :3 0 5d
:2 0 76 :4 0 cf
1f2 1f4 :3 0 5d
:2 0 77 :3 0 78
:3 0 a :2 0 79
:2 0 d2 1f7 1fb
d6 1f6 1fd :3 0
d9 1df 1ff :2 0
201 dc 202 1dc
201 0 203 de
0 204 e0 207
:3 0 207 0 207
206 204 205 :6 0
209 5 :3 0 e3
20b e5 20a 209
:2 0 20c e7 :2 0
20e 0 20e 20d
1bb 20c :6 0 1932
1 :3 0 77 :3 0
36 :3 0 a :2 0
a :2 0 ea 210
214 7a :2 0 7b
:4 0 f0 216 218
:3 0 55 :3 0 56
:3 0 21a 21b 0
55 :3 0 65 :3 0
21d 21e 0 17
:2 0 2 :4 0 7c
:2 0 67 :2 0 a
:2 0 f3 223 225
:3 0 f6 21f 227
21c 229 228 :2 0
58 :3 0 68 :3 0
22b 22c 0 5a
:4 0 7d :4 0 5d
:2 0 5e :3 0 fa
230 232 :3 0 5d
:2 0 74 :4 0 fd
234 236 :3 0 5d
:2 0 7e :4 0 100
238 23a :3 0 5d
:2 0 e :3 0 62
:3 0 13 :3 0 7f
:3 0 23f 240 0
103 23e 242 63
:4 0 105 23d 245
108 23c 247 :3 0
5d :2 0 80 :4 0
10b 249 24b :3 0
5d :2 0 60 :4 0
10e 24d 24f :3 0
5d :2 0 3 :3 0
111 251 253 :3 0
5d :2 0 60 :4 0
114 255 257 :3 0
117 22d 259 :2 0
25b 11a 25c 22a
25b 0 25d 11c
0 289 55 :3 0
56 :3 0 25e 25f
0 55 :3 0 65
:3 0 261 262 0
a :2 0 2 :4 0
81 :2 0 67 :2 0
a :2 0 11e 267
269 :3 0 121 263
26b 260 26d 26c
:2 0 58 :3 0 68
:3 0 26f 270 0
5a :4 0 82 :4 0
5d :2 0 5e :3 0
125 274 276 :3 0
128 271 278 :2 0
27a 12b 27b 26e
27a 0 27c 12d
0 289 b :3 0
83 :3 0 84 :3 0
27e 27f 0 13
:3 0 7f :3 0 281
282 0 3 :3 0
85 :3 0 12f 280
286 287 :2 0 289
133 28a 219 289
0 28b 137 0
1932 4b :3 0 6d
:3 0 28c 28d 0
4b :3 0 7a :2 0
86 :3 0 28f 291
0 13b 290 293
:3 0 294 :2 0 3c
:3 0 43 :3 0 87
:3 0 88 :3 0 87
:3 0 44 :3 0 3c
:3 0 3e :3 0 3c
:3 0 43 :3 0 3c
:3 0 45 :3 0 3c
:3 0 48 :3 0 16
:3 0 18 :3 0 19
:3 0 1d :3 0 2c
:3 0 2b :3 0 3f
:3 0 3c :3 0 89
:3 0 87 :3 0 3c
:3 0 3d :3 0 3
:3 0 3c :3 0 8a
:3 0 3c :3 0 47
:3 0 87 :3 0 8b
:3 0 3c :3 0 8b
:4 0 8c 1 :8 0
2bf 4b :3 0 6d
:3 0 2ba 2bb 0
6e :3 0 2bc 2bd
0 2bf 13e 312
6f :3 0 4b :3 0
6d :3 0 2c1 2c2
0 6e :3 0 2c3
2c4 0 2c6 141
2c8 143 2c7 2c6
:2 0 310 70 :3 0
4b :3 0 6d :3 0
2cb 2cc 0 6e
:3 0 2cd 2ce 0
308 55 :3 0 56
:3 0 2d0 2d1 0
55 :3 0 65 :3 0
2d3 2d4 0 71
:2 0 2 :4 0 8d
:2 0 67 :2 0 a
:2 0 145 2d9 2db
:3 0 148 2d5 2dd
2d2 2df 2de :2 0
58 :3 0 68 :3 0
2e1 2e2 0 5a
:4 0 8e :4 0 5d
:2 0 5e :3 0 14c
2e6 2e8 :3 0 5d
:2 0 74 :4 0 14f
2ea 2ec :3 0 5d
:2 0 75 :4 0 152
2ee 2f0 :3 0 5d
:2 0 6e :3 0 155
2f2 2f4 :3 0 5d
:2 0 76 :4 0 158
2f6 2f8 :3 0 5d
:2 0 77 :3 0 78
:3 0 a :2 0 79
:2 0 15b 2fb 2ff
15f 2fa 301 :3 0
162 2e3 303 :2 0
305 165 306 2e0
305 0 307 167
0 308 169 30b
:3 0 30b 0 30b
30a 308 309 :6 0
30d 7 :3 0 16c
30f 16e 30e 30d
:2 0 310 170 :2 0
312 0 312 311
2bf 310 :6 0 7bc
1 :3 0 4b :3 0
6d :3 0 314 315
0 4b :3 0 7a
:2 0 86 :3 0 317
319 0 175 318
31b :3 0 31c :2 0
55 :3 0 56 :3 0
31e 31f 0 55
:3 0 65 :3 0 321
322 0 8f :2 0
2 :4 0 90 :2 0
67 :2 0 a :2 0
178 327 329 :3 0
17b 323 32b 320
32d 32c :2 0 58
:3 0 68 :3 0 32f
330 0 5a :4 0
91 :4 0 5d :2 0
5e :3 0 17f 334
336 :3 0 5d :2 0
74 :4 0 182 338
33a :3 0 5d :2 0
7e :4 0 185 33c
33e :3 0 5d :2 0
e :3 0 62 :3 0
13 :3 0 92 :3 0
343 344 0 188
342 346 63 :4 0
18a 341 349 18d
340 34b :3 0 190
331 34d :2 0 34f
193 350 32e 34f
0 351 195 0
37d 55 :3 0 56
:3 0 352 353 0
55 :3 0 65 :3 0
355 356 0 a
:2 0 2 :4 0 93
:2 0 67 :2 0 a
:2 0 197 35b 35d
:3 0 19a 357 35f
354 361 360 :2 0
58 :3 0 68 :3 0
363 364 0 5a
:4 0 94 :4 0 5d
:2 0 5e :3 0 19e
368 36a :3 0 1a1
365 36c :2 0 36e
1a4 36f 362 36e
0 370 1a6 0
37d b :3 0 83
:3 0 95 :3 0 372
373 0 13 :3 0
92 :3 0 375 376
0 85 :3 0 1a8
374 379 37a :2 0
37d 96 :3 0 1ab
403 e :3 0 2c
:3 0 f :2 0 1af
37e 381 7a :2 0
f :2 0 1b4 383
385 :3 0 e :3 0
2b :3 0 f :2 0
1b7 387 38a 7a
:2 0 a :2 0 1bc
38c 38e :3 0 386
390 38f :2 0 55
:3 0 56 :3 0 392
393 0 55 :3 0
65 :3 0 395 396
0 17 :2 0 2
:4 0 97 :2 0 67
:2 0 a :2 0 1bf
39b 39d :3 0 1c2
397 39f 394 3a1
3a0 :2 0 58 :3 0
68 :3 0 3a3 3a4
0 5a :4 0 98
:4 0 5d :2 0 5e
:3 0 1c6 3a8 3aa
:3 0 5d :2 0 74
:4 0 1c9 3ac 3ae
:3 0 5d :2 0 7e
:4 0 1cc 3b0 3b2
:3 0 5d :2 0 e
:3 0 62 :3 0 13
:3 0 99 :3 0 3b7
3b8 0 1cf 3b6
3ba 63 :4 0 1d1
3b5 3bd 1d4 3b4
3bf :3 0 5d :2 0
80 :4 0 1d7 3c1
3c3 :3 0 5d :2 0
60 :4 0 1da 3c5
3c7 :3 0 5d :2 0
3 :3 0 1dd 3c9
3cb :3 0 5d :2 0
60 :4 0 1e0 3cd
3cf :3 0 1e3 3a5
3d1 :2 0 3d3 1e6
3d4 3a2 3d3 0
3d5 1e8 0 401
55 :3 0 56 :3 0
3d6 3d7 0 55
:3 0 65 :3 0 3d9
3da 0 a :2 0
2 :4 0 9a :2 0
67 :2 0 a :2 0
1ea 3df 3e1 :3 0
1ed 3db 3e3 3d8
3e5 3e4 :2 0 58
:3 0 68 :3 0 3e7
3e8 0 5a :4 0
9b :4 0 5d :2 0
5e :3 0 1f1 3ec
3ee :3 0 1f4 3e9
3f0 :2 0 3f2 1f7
3f3 3e6 3f2 0
3f4 1f9 0 401
b :3 0 83 :3 0
84 :3 0 3f6 3f7
0 13 :3 0 99
:3 0 3f9 3fa 0
3 :3 0 85 :3 0
1fb 3f8 3fe 3ff
:2 0 401 1ff 402
391 401 0 404
31d 37d 0 404
203 0 7bc e
:3 0 2c :3 0 f
:2 0 206 405 408
7a :2 0 a :2 0
20b 40a 40c :3 0
39 :3 0 4b :3 0
6d :3 0 40f 410
0 40e 411 0
41f 37 :3 0 9c
:3 0 16 :3 0 20e
414 416 413 417
0 41f 4b :3 0
6d :3 0 419 41a
0 39 :3 0 41b
41c 0 41f 96
:3 0 210 74a 18
:3 0 9d :2 0 214
421 422 :3 0 423
:2 0 1f :4 0 425
426 0 748 3d
:3 0 8b :3 0 1f
:3 0 1a :3 0 3f
:3 0 43 :3 0 16
:3 0 45 :3 0 19
:3 0 3e :3 0 18
:3 0 47 :3 0 9e
:4 0 9f 1 :8 0
43b 4b :3 0 6d
:3 0 436 437 0
6e :3 0 438 439
0 43b 216 48e
6f :3 0 4b :3 0
6d :3 0 43d 43e
0 6e :3 0 43f
440 0 442 219
444 21b 443 442
:2 0 48c 70 :3 0
4b :3 0 6d :3 0
447 448 0 6e
:3 0 449 44a 0
484 55 :3 0 56
:3 0 44c 44d 0
55 :3 0 65 :3 0
44f 450 0 71
:2 0 2 :4 0 a0
:2 0 67 :2 0 a
:2 0 21d 455 457
:3 0 220 451 459
44e 45b 45a :2 0
58 :3 0 68 :3 0
45d 45e 0 5a
:4 0 a1 :4 0 5d
:2 0 5e :3 0 224
462 464 :3 0 5d
:2 0 74 :4 0 227
466 468 :3 0 5d
:2 0 75 :4 0 22a
46a 46c :3 0 5d
:2 0 6e :3 0 22d
46e 470 :3 0 5d
:2 0 76 :4 0 230
472 474 :3 0 5d
:2 0 77 :3 0 78
:3 0 a :2 0 79
:2 0 233 477 47b
237 476 47d :3 0
23a 45f 47f :2 0
481 23d 482 45c
481 0 483 23f
0 484 241 487
:3 0 487 0 487
486 484 485 :6 0
489 9 :3 0 244
48b 246 48a 489
:2 0 48c 248 :2 0
48e 0 48e 48d
43b 48c :6 0 748
1 :3 0 1f :3 0
9d :2 0 24b 491
492 :3 0 493 :2 0
2e :3 0 a2 :3 0
8b :3 0 1a :4 0
a3 1 :8 0 49f
4b :3 0 6d :3 0
49a 49b 0 6e
:3 0 49c 49d 0
49f 24d 4f2 6f
:3 0 4b :3 0 6d
:3 0 4a1 4a2 0
6e :3 0 4a3 4a4
0 4a6 250 4a8
252 4a7 4a6 :2 0
4f0 70 :3 0 4b
:3 0 6d :3 0 4ab
4ac 0 6e :3 0
4ad 4ae 0 4e8
55 :3 0 56 :3 0
4b0 4b1 0 55
:3 0 65 :3 0 4b3
4b4 0 71 :2 0
2 :4 0 a4 :2 0
67 :2 0 a :2 0
254 4b9 4bb :3 0
257 4b5 4bd 4b2
4bf 4be :2 0 58
:3 0 68 :3 0 4c1
4c2 0 5a :4 0
a5 :4 0 5d :2 0
5e :3 0 25b 4c6
4c8 :3 0 5d :2 0
74 :4 0 25e 4ca
4cc :3 0 5d :2 0
75 :4 0 261 4ce
4d0 :3 0 5d :2 0
6e :3 0 264 4d2
4d4 :3 0 5d :2 0
76 :4 0 267 4d6
4d8 :3 0 5d :2 0
77 :3 0 78 :3 0
a :2 0 79 :2 0
26a 4db 4df 26e
4da 4e1 :3 0 271
4c3 4e3 :2 0 4e5
274 4e6 4c0 4e5
0 4e7 276 0
4e8 278 4eb :3 0
4eb 0 4eb 4ea
4e8 4e9 :6 0 4ed
b :3 0 27b 4ef
27d 4ee 4ed :2 0
4f0 27f :2 0 4f2
0 4f2 4f1 49f
4f0 :6 0 745 1
:3 0 4b :3 0 6d
:3 0 4f4 4f5 0
4b :3 0 7a :2 0
a6 :3 0 4f7 4f9
0 284 4f8 4fb
:3 0 4fc :2 0 a2
:3 0 3e :3 0 47
:3 0 48 :3 0 a7
:3 0 a8 :3 0 a9
:3 0 aa :3 0 ab
:3 0 ac :3 0 ad
:3 0 ae :3 0 af
:3 0 b0 :3 0 b1
:3 0 b2 :3 0 b3
:3 0 b4 :3 0 b5
:3 0 b6 :3 0 b7
:3 0 b8 :3 0 b9
:3 0 ba :3 0 bb
:3 0 bc :3 0 bd
:3 0 be :3 0 bf
:3 0 18 :3 0 48
:3 0 a7 :3 0 a8
:3 0 a9 :3 0 aa
:3 0 ab :3 0 ac
:3 0 ad :3 0 ae
:3 0 af :3 0 b0
:3 0 b1 :3 0 b2
:3 0 b3 :3 0 b4
:3 0 b5 :3 0 b6
:3 0 b7 :3 0 b8
:3 0 b9 :3 0 ba
:3 0 bb :3 0 bc
:3 0 bd :3 0 be
:3 0 bf :3 0 3f
:3 0 3d :3 0 1f
:3 0 8b :3 0 1a
:4 0 c0 1 :8 0
551 c1 :4 0 53c
:3 0 c2 :3 0 7a
:2 0 289 53f 540
:3 0 4b :3 0 6d
:3 0 542 543 0
f :2 0 544 545
0 547 28c 54e
4b :3 0 6d :3 0
548 549 0 c3
:2 0 54a 54b 0
54d 28e 54f 541
547 0 550 0
54d 0 550 290
0 551 293 5a4
6f :3 0 4b :3 0
6d :3 0 553 554
0 6e :3 0 555
556 0 558 296
55a 298 559 558
:2 0 5a2 70 :3 0
4b :3 0 6d :3 0
55d 55e 0 6e
:3 0 55f 560 0
59a 55 :3 0 56
:3 0 562 563 0
55 :3 0 65 :3 0
565 566 0 71
:2 0 2 :4 0 c4
:2 0 67 :2 0 a
:2 0 29a 56b 56d
:3 0 29d 567 56f
564 571 570 :2 0
58 :3 0 68 :3 0
573 574 0 5a
:4 0 c5 :4 0 5d
:2 0 5e :3 0 2a1
578 57a :3 0 5d
:2 0 74 :4 0 2a4
57c 57e :3 0 5d
:2 0 75 :4 0 2a7
580 582 :3 0 5d
:2 0 6e :3 0 2aa
584 586 :3 0 5d
:2 0 76 :4 0 2ad
588 58a :3 0 5d
:2 0 77 :3 0 78
:3 0 a :2 0 79
:2 0 2b0 58d 591
2b4 58c 593 :3 0
2b7 575 595 :2 0
597 2ba 598 572
597 0 599 2bc
0 59a 2be 59d
:3 0 59d 0 59d
59c 59a 59b :6 0
59f d :3 0 2c1
5a1 2c3 5a0 59f
:2 0 5a2 2c5 :2 0
5a4 0 5a4 5a3
551 5a2 :6 0 5a6
1 :3 0 2c8 655
a2 :3 0 8b :3 0
43 :3 0 45 :3 0
3e :3 0 47 :3 0
48 :3 0 a7 :3 0
a8 :3 0 a9 :3 0
aa :3 0 ab :3 0
ac :3 0 ad :3 0
ae :3 0 af :3 0
b0 :3 0 b1 :3 0
b2 :3 0 b3 :3 0
b4 :3 0 b5 :3 0
b6 :3 0 b7 :3 0
b8 :3 0 b9 :3 0
ba :3 0 bb :3 0
bc :3 0 bd :3 0
be :3 0 bf :3 0
8b :3 0 43 :3 0
45 :3 0 3e :3 0
47 :3 0 48 :3 0
a7 :3 0 a8 :3 0
a9 :3 0 aa :3 0
ab :3 0 ac :3 0
ad :3 0 ae :3 0
af :3 0 b0 :3 0
b1 :3 0 b2 :3 0
b3 :3 0 b4 :3 0
b5 :3 0 b6 :3 0
b7 :3 0 b8 :3 0
b9 :3 0 ba :3 0
bb :3 0 bc :3 0
bd :3 0 be :3 0
bf :3 0 3f :3 0
3d :3 0 1f :4 0
c6 1 :8 0 5ff
c1 :4 0 5ea :3 0
c2 :3 0 7a :2 0
2cc 5ed 5ee :3 0
4b :3 0 6d :3 0
5f0 5f1 0 f
:2 0 5f2 5f3 0
5f5 2cf 5fc 4b
:3 0 6d :3 0 5f6
5f7 0 c3 :2 0
5f8 5f9 0 5fb
2d1 5fd 5ef 5f5
0 5fe 0 5fb
0 5fe 2d3 0
5ff 2d6 652 6f
:3 0 4b :3 0 6d
:3 0 601 602 0
6e :3 0 603 604
0 606 2d9 608
2db 607 606 :2 0
650 70 :3 0 4b
:3 0 6d :3 0 60b
60c 0 6e :3 0
60d 60e 0 648
55 :3 0 56 :3 0
610 611 0 55
:3 0 65 :3 0 613
614 0 71 :2 0
2 :4 0 c7 :2 0
67 :2 0 a :2 0
2dd 619 61b :3 0
2e0 615 61d 612
61f 61e :2 0 58
:3 0 68 :3 0 621
622 0 5a :4 0
c8 :4 0 5d :2 0
5e :3 0 2e4 626
628 :3 0 5d :2 0
74 :4 0 2e7 62a
62c :3 0 5d :2 0
75 :4 0 2ea 62e
630 :3 0 5d :2 0
6e :3 0 2ed 632
634 :3 0 5d :2 0
76 :4 0 2f0 636
638 :3 0 5d :2 0
77 :3 0 78 :3 0
a :2 0 79 :2 0
2f3 63b 63f 2f7
63a 641 :3 0 2fa
623 643 :2 0 645
2fd 646 620 645
0 647 2ff 0
648 301 64b :3 0
64b 0 64b 64a
648 649 :6 0 64d
f :3 0 304 64f
306 64e 64d :2 0
650 308 :2 0 652
0 652 651 5ff
650 :6 0 654 1
:3 0 30b 656 4fd
5a6 0 657 0
654 0 657 30d
0 745 3f :3 0
3d :3 0 1f :4 0
c9 1 :8 0 671
c1 :4 0 65c :3 0
c2 :3 0 7a :2 0
312 65f 660 :3 0
4b :3 0 6d :3 0
662 663 0 f
:2 0 664 665 0
667 315 66e 4b
:3 0 6d :3 0 668
669 0 c3 :2 0
66a 66b 0 66d
317 66f 661 667
0 670 0 66d
0 670 319 0
671 31c 6c4 6f
:3 0 4b :3 0 6d
:3 0 673 674 0
6e :3 0 675 676
0 678 31f 67a
321 679 678 :2 0
6c2 70 :3 0 4b
:3 0 6d :3 0 67d
67e 0 6e :3 0
67f 680 0 6ba
55 :3 0 56 :3 0
682 683 0 55
:3 0 65 :3 0 685
686 0 71 :2 0
2 :4 0 ca :2 0
67 :2 0 a :2 0
323 68b 68d :3 0
326 687 68f 684
691 690 :2 0 58
:3 0 68 :3 0 693
694 0 5a :4 0
cb :4 0 5d :2 0
5e :3 0 32a 698
69a :3 0 5d :2 0
74 :4 0 32d 69c
69e :3 0 5d :2 0
75 :4 0 330 6a0
6a2 :3 0 5d :2 0
6e :3 0 333 6a4
6a6 :3 0 5d :2 0
76 :4 0 336 6a8
6aa :3 0 5d :2 0
77 :3 0 78 :3 0
a :2 0 79 :2 0
339 6ad 6b1 33d
6ac 6b3 :3 0 340
695 6b5 :2 0 6b7
343 6b8 692 6b7
0 6b9 345 0
6ba 347 6bd :3 0
6bd 0 6bd 6bc
6ba 6bb :6 0 6bf
11 :3 0 34a 6c1
34c 6c0 6bf :2 0
6c2 34e :2 0 6c4
0 6c4 6c3 671
6c2 :6 0 745 1
:3 0 39 :3 0 4b
:3 0 6d :3 0 6c7
6c8 0 6c6 6c9
0 745 37 :3 0
cc :3 0 1a :3 0
f :2 0 351 6cc
6cf 6cb 6d0 0
745 4b :3 0 6d
:3 0 6d2 6d3 0
39 :3 0 6d4 6d5
0 745 89 :3 0
8b :3 0 1a :4 0
cd 1 :8 0 6f0
c1 :4 0 6db :3 0
c2 :3 0 7a :2 0
356 6de 6df :3 0
4b :3 0 6d :3 0
6e1 6e2 0 f
:2 0 6e3 6e4 0
6e6 359 6ed 4b
:3 0 6d :3 0 6e7
6e8 0 c3 :2 0
6e9 6ea 0 6ec
35b 6ee 6e0 6e6
0 6ef 0 6ec
0 6ef 35d 0
6f0 360 743 6f
:3 0 4b :3 0 6d
:3 0 6f2 6f3 0
6e :3 0 6f4 6f5
0 6f7 363 6f9
365 6f8 6f7 :2 0
741 70 :3 0 4b
:3 0 6d :3 0 6fc
6fd 0 6e :3 0
6fe 6ff 0 739
55 :3 0 56 :3 0
701 702 0 55
:3 0 65 :3 0 704
705 0 71 :2 0
2 :4 0 ce :2 0
67 :2 0 a :2 0
367 70a 70c :3 0
36a 706 70e 703
710 70f :2 0 58
:3 0 68 :3 0 712
713 0 5a :4 0
cf :4 0 5d :2 0
5e :3 0 36e 717
719 :3 0 5d :2 0
74 :4 0 371 71b
71d :3 0 5d :2 0
75 :4 0 374 71f
721 :3 0 5d :2 0
6e :3 0 377 723
725 :3 0 5d :2 0
76 :4 0 37a 727
729 :3 0 5d :2 0
77 :3 0 78 :3 0
a :2 0 79 :2 0
37d 72c 730 381
72b 732 :3 0 384
714 734 :2 0 736
387 737 711 736
0 738 389 0
739 38b 73c :3 0
73c 0 73c 73b
739 73a :6 0 73e
13 :3 0 38e 740
390 73f 73e :2 0
741 392 :2 0 743
0 743 742 6f0
741 :6 0 745 1
:3 0 395 746 494
745 0 747 39d
0 748 39f 749
424 748 0 74b
40d 41f 0 74b
3a3 0 7bc e
:3 0 6a :3 0 28
:3 0 41 :3 0 44
:3 0 16 :4 0 d0
1 :8 0 758 4b
:3 0 6d :3 0 753
754 0 6e :3 0
755 756 0 758
3a6 7ab 6f :3 0
4b :3 0 6d :3 0
75a 75b 0 6e
:3 0 75c 75d 0
75f 3a9 761 3ab
760 75f :2 0 7a9
70 :3 0 4b :3 0
6d :3 0 764 765
0 6e :3 0 766
767 0 7a1 55
:3 0 56 :3 0 769
76a 0 55 :3 0
65 :3 0 76c 76d
0 71 :2 0 2
:4 0 d1 :2 0 67
:2 0 a :2 0 3ad
772 774 :3 0 3b0
76e 776 76b 778
777 :2 0 58 :3 0
68 :3 0 77a 77b
0 5a :4 0 d2
:4 0 5d :2 0 5e
:3 0 3b4 77f 781
:3 0 5d :2 0 74
:4 0 3b7 783 785
:3 0 5d :2 0 75
:4 0 3ba 787 789
:3 0 5d :2 0 6e
:3 0 3bd 78b 78d
:3 0 5d :2 0 76
:4 0 3c0 78f 791
:3 0 5d :2 0 77
:3 0 78 :3 0 a
:2 0 79 :2 0 3c3
794 798 3c7 793
79a :3 0 3ca 77c
79c :2 0 79e 3cd
79f 779 79e 0
7a0 3cf 0 7a1
3d1 7a4 :3 0 7a4
0 7a4 7a3 7a1
7a2 :6 0 7a6 15
:3 0 3d4 7a8 3d6
7a7 7a6 :2 0 7a9
3d8 :2 0 7ab 0
7ab 7aa 758 7a9
:6 0 7bc 1 :3 0
34 :3 0 d3 :4 0
5d :2 0 d4 :4 0
3db 7af 7b1 :3 0
5d :2 0 3 :3 0
3de 7b3 7b5 :3 0
5d :2 0 d5 :4 0
3e1 7b7 7b9 :3 0
7ad 7ba 0 7bc
3e4 aba 16 :3 0
3 :3 0 7bd 7be
0 ab9 e :3 0
c :3 0 f :2 0
3ea 7c0 7c3 7a
:2 0 d6 :2 0 3ef
7c5 7c7 :3 0 39
:3 0 4b :3 0 6d
:3 0 7ca 7cb 0
7c9 7cc 0 a2d
37 :3 0 9c :3 0
16 :3 0 3f2 7cf
7d1 7ce 7d2 0
a2d 4b :3 0 6d
:3 0 7d4 7d5 0
39 :3 0 7d6 7d7
0 a2d 41 :3 0
d7 :3 0 d7 :3 0
13 :3 0 d8 :3 0
13 :3 0 d9 :3 0
d7 :3 0 da :3 0
e :3 0 db :3 0
da :3 0 dc :3 0
e :3 0 dd :3 0
dc :3 0 de :3 0
df :3 0 de :3 0
df :3 0 e0 :3 0
e1 :3 0 db :3 0
dd :3 0 df :3 0
e2 :3 0 e3 :3 0
e4 :3 0 e1 :3 0
e5 :3 0 e1 :3 0
e6 :3 0 e7 :3 0
5e :3 0 43 :3 0
16 :3 0 d7 :3 0
13 :3 0 e8 :3 0
13 :3 0 e9 :3 0
13 :3 0 ea :3 0
13 :3 0 eb :3 0
13 :3 0 ec :3 0
13 :3 0 ed :3 0
13 :3 0 ee :3 0
13 :3 0 ef :3 0
13 :3 0 f0 :3 0
13 :3 0 f1 :3 0
13 :3 0 f2 :3 0
13 :3 0 f3 :3 0
13 :3 0 f4 :3 0
13 :3 0 f5 :3 0
13 :3 0 f6 :3 0
f7 :3 0 f8 :3 0
e0 :4 0 f9 1
:8 0 835 c1 :4 0
820 :3 0 c2 :3 0
7a :2 0 3f6 823
824 :3 0 4b :3 0
6d :3 0 826 827
0 f :2 0 828
829 0 82b 3f9
832 4b :3 0 6d
:3 0 82c 82d 0
c3 :2 0 82e 82f
0 831 3fb 833
825 82b 0 834
0 831 0 834
3fd 0 835 400
888 6f :3 0 4b
:3 0 6d :3 0 837
838 0 6e :3 0
839 83a 0 83c
403 83e 405 83d
83c :2 0 886 70
:3 0 4b :3 0 6d
:3 0 841 842 0
6e :3 0 843 844
0 87e 55 :3 0
56 :3 0 846 847
0 55 :3 0 65
:3 0 849 84a 0
71 :2 0 2 :4 0
fa :2 0 67 :2 0
a :2 0 407 84f
851 :3 0 40a 84b
853 848 855 854
:2 0 58 :3 0 68
:3 0 857 858 0
5a :4 0 fb :4 0
5d :2 0 5e :3 0
40e 85c 85e :3 0
5d :2 0 74 :4 0
411 860 862 :3 0
5d :2 0 75 :4 0
414 864 866 :3 0
5d :2 0 6e :3 0
417 868 86a :3 0
5d :2 0 76 :4 0
41a 86c 86e :3 0
5d :2 0 77 :3 0
78 :3 0 a :2 0
79 :2 0 41d 871
875 421 870 877
:3 0 424 859 879
:2 0 87b 427 87c
856 87b 0 87d
429 0 87e 42b
881 :3 0 881 0
881 880 87e 87f
:6 0 883 17 :3 0
42e 885 430 884
883 :2 0 886 432
:2 0 888 0 888
887 835 886 :6 0
a2d 1 :3 0 fc
:3 0 3b :4 0 88d
:2 0 a2d 88b 88e
:3 0 fd :3 0 3b
:3 0 1f :3 0 1d
:4 0 894 :2 0 9cc
890 895 :3 0 435
:3 0 3b :3 0 c1
:3 0 896 897 :3 0
4b :3 0 6d :3 0
899 89a 0 f
:2 0 89b 89c 0
89e 438 8a5 4b
:3 0 6d :3 0 89f
8a0 0 c3 :2 0
8a1 8a2 0 8a4
43a 8a6 898 89e
0 8a7 0 8a4
0 8a7 43c 0
9cc 4b :3 0 6d
:3 0 8a8 8a9 0
4b :3 0 fe :2 0
a6 :3 0 8ab 8ad
0 441 8ac 8af
:3 0 8b0 :2 0 ff
:8 0 8b4 444 8b5
8b1 8b4 0 8b6
446 0 9cc 3f
:3 0 46 :3 0 da
:3 0 e :3 0 db
:3 0 da :3 0 dc
:3 0 e :3 0 dd
:3 0 dc :3 0 de
:3 0 df :3 0 df
:3 0 de :3 0 100
:3 0 9e :3 0 e5
:3 0 9e :3 0 bc
:3 0 e :3 0 db
:3 0 da :3 0 bd
:3 0 e :3 0 dd
:3 0 dc :3 0 be
:3 0 9e :3 0 101
:3 0 102 :3 0 102
:3 0 101 :3 0 103
:3 0 104 :3 0 104
:3 0 103 :3 0 105
:3 0 ae :3 0 e5
:3 0 9e :3 0 a7
:3 0 106 :3 0 107
:3 0 ae :3 0 e5
:3 0 9e :3 0 a9
:3 0 108 :3 0 db
:3 0 dd :3 0 df
:3 0 9e :3 0 e2
:3 0 e3 :3 0 e6
:3 0 3d :3 0 1f
:4 0 109 1 :8 0
906 c1 :4 0 8f1
:3 0 c2 :3 0 7a
:2 0 44a 8f4 8f5
:3 0 4b :3 0 6d
:3 0 8f7 8f8 0
f :2 0 8f9 8fa
0 8fc 44d 903
4b :3 0 6d :3 0
8fd 8fe 0 c3
:2 0 8ff 900 0
902 44f 904 8f6
8fc 0 905 0
902 0 905 451
0 906 454 959
6f :3 0 4b :3 0
6d :3 0 908 909
0 6e :3 0 90a
90b 0 90d 457
90f 459 90e 90d
:2 0 957 70 :3 0
4b :3 0 6d :3 0
912 913 0 6e
:3 0 914 915 0
94f 55 :3 0 56
:3 0 917 918 0
55 :3 0 65 :3 0
91a 91b 0 71
:2 0 2 :4 0 10a
:2 0 67 :2 0 a
:2 0 45b 920 922
:3 0 45e 91c 924
919 926 925 :2 0
58 :3 0 68 :3 0
928 929 0 5a
:4 0 10b :4 0 5d
:2 0 5e :3 0 462
92d 92f :3 0 5d
:2 0 74 :4 0 465
931 933 :3 0 5d
:2 0 75 :4 0 468
935 937 :3 0 5d
:2 0 6e :3 0 46b
939 93b :3 0 5d
:2 0 76 :4 0 46e
93d 93f :3 0 5d
:2 0 77 :3 0 78
:3 0 a :2 0 79
:2 0 471 942 946
475 941 948 :3 0
478 92a 94a :2 0
94c 47b 94d 927
94c 0 94e 47d
0 94f 47f 952
:3 0 952 0 952
951 94f 950 :6 0
954 1a :3 0 482
956 484 955 954
:2 0 957 486 :2 0
959 0 959 958
906 957 :6 0 9cc
19 :3 0 51 :3 0
46 :3 0 43 :3 0
16 :3 0 3d :3 0
1f :4 0 10c 1
:8 0 977 c1 :4 0
962 :3 0 c2 :3 0
7a :2 0 48b 965
966 :3 0 4b :3 0
6d :3 0 968 969
0 f :2 0 96a
96b 0 96d 48e
974 4b :3 0 6d
:3 0 96e 96f 0
c3 :2 0 970 971
0 973 490 975
967 96d 0 976
0 973 0 976
492 0 977 495
9ca 6f :3 0 4b
:3 0 6d :3 0 979
97a 0 6e :3 0
97b 97c 0 97e
498 980 49a 97f
97e :2 0 9c8 70
:3 0 4b :3 0 6d
:3 0 983 984 0
6e :3 0 985 986
0 9c0 55 :3 0
56 :3 0 988 989
0 55 :3 0 65
:3 0 98b 98c 0
71 :2 0 2 :4 0
10d :2 0 67 :2 0
a :2 0 49c 991
993 :3 0 49f 98d
995 98a 997 996
:2 0 58 :3 0 68
:3 0 999 99a 0
5a :4 0 10e :4 0
5d :2 0 5e :3 0
4a3 99e 9a0 :3 0
5d :2 0 74 :4 0
4a6 9a2 9a4 :3 0
5d :2 0 75 :4 0
4a9 9a6 9a8 :3 0
5d :2 0 6e :3 0
4ac 9aa 9ac :3 0
5d :2 0 76 :4 0
4af 9ae 9b0 :3 0
5d :2 0 77 :3 0
78 :3 0 a :2 0
79 :2 0 4b2 9b3
9b7 4b6 9b2 9b9
:3 0 4b9 99b 9bb
:2 0 9bd 4bc 9be
998 9bd 0 9bf
4be 0 9c0 4c0
9c3 :3 0 9c3 0
9c3 9c2 9c0 9c1
:6 0 9c5 1c :3 0
4c3 9c7 4c5 9c6
9c5 :2 0 9c8 4c7
:2 0 9ca 0 9ca
9c9 977 9c8 :6 0
9cc 19 :3 0 4ca
9ce fd :4 0 9cc
:4 0 a2d 10f :3 0
3b :4 0 9d2 :2 0
9d8 9d0 0 4b
:3 0 6d :3 0 9d3
9d4 0 6e :3 0
9d5 9d6 0 9d8
4d0 a2b 6f :3 0
4b :3 0 6d :3 0
9da 9db 0 6e
:3 0 9dc 9dd 0
9df 4d3 9e1 4d5
9e0 9df :2 0 a29
70 :3 0 4b :3 0
6d :3 0 9e4 9e5
0 6e :3 0 9e6
9e7 0 a21 55
:3 0 56 :3 0 9e9
9ea 0 55 :3 0
65 :3 0 9ec 9ed
0 71 :2 0 2
:4 0 110 :2 0 67
:2 0 a :2 0 4d7
9f2 9f4 :3 0 4da
9ee 9f6 9eb 9f8
9f7 :2 0 58 :3 0
68 :3 0 9fa 9fb
0 5a :4 0 111
:4 0 5d :2 0 5e
:3 0 4de 9ff a01
:3 0 5d :2 0 74
:4 0 4e1 a03 a05
:3 0 5d :2 0 75
:4 0 4e4 a07 a09
:3 0 5d :2 0 6e
:3 0 4e7 a0b a0d
:3 0 5d :2 0 76
:4 0 4ea a0f a11
:3 0 5d :2 0 77
:3 0 78 :3 0 a
:2 0 79 :2 0 4ed
a14 a18 4f1 a13
a1a :3 0 4f4 9fc
a1c :2 0 a1e 4f7
a1f 9f9 a1e 0
a20 4f9 0 a21
4fb a24 :3 0 a24
0 a24 a23 a21
a22 :6 0 a26 1e
:3 0 4fe a28 500
a27 a26 :2 0 a29
502 :2 0 a2b 0
a2b a2a 9d8 a29
:6 0 a2d 1 :3 0
505 a2e 7c8 a2d
0 a2f 50d 0
ab9 41 :3 0 112
:3 0 13 :3 0 113
:3 0 43 :3 0 16
:3 0 f7 :3 0 f8
:3 0 e0 :4 0 114
1 :8 0 a4f c1
:4 0 a3a :3 0 c2
:3 0 7a :2 0 511
a3d a3e :3 0 4b
:3 0 6d :3 0 a40
a41 0 f :2 0
a42 a43 0 a45
514 a4c 4b :3 0
6d :3 0 a46 a47
0 c3 :2 0 a48
a49 0 a4b 516
a4d a3f a45 0
a4e 0 a4b 0
a4e 518 0 a4f
51b aa2 6f :3 0
4b :3 0 6d :3 0
a51 a52 0 6e
:3 0 a53 a54 0
a56 51e a58 520
a57 a56 :2 0 aa0
70 :3 0 4b :3 0
6d :3 0 a5b a5c
0 6e :3 0 a5d
a5e 0 a98 55
:3 0 56 :3 0 a60
a61 0 55 :3 0
65 :3 0 a63 a64
0 71 :2 0 2
:4 0 115 :2 0 67
:2 0 a :2 0 522
a69 a6b :3 0 525
a65 a6d a62 a6f
a6e :2 0 58 :3 0
68 :3 0 a71 a72
0 5a :4 0 116
:4 0 5d :2 0 5e
:3 0 529 a76 a78
:3 0 5d :2 0 74
:4 0 52c a7a a7c
:3 0 5d :2 0 75
:4 0 52f a7e a80
:3 0 5d :2 0 6e
:3 0 532 a82 a84
:3 0 5d :2 0 76
:4 0 535 a86 a88
:3 0 5d :2 0 77
:3 0 78 :3 0 a
:2 0 79 :2 0 538
a8b a8f 53c a8a
a91 :3 0 53f a73
a93 :2 0 a95 542
a96 a70 a95 0
a97 544 0 a98
546 a9b :3 0 a9b
0 a9b a9a a98
a99 :6 0 a9d 20
:3 0 549 a9f 54b
a9e a9d :2 0 aa0
54d :2 0 aa2 0
aa2 aa1 a4f aa0
:6 0 ab9 1 :3 0
2c :3 0 a :2 0
aa4 aa5 0 ab9
c :3 0 117 :2 0
aa7 aa8 0 ab9
34 :3 0 118 :4 0
5d :2 0 119 :4 0
550 aac aae :3 0
5d :2 0 3 :3 0
553 ab0 ab2 :3 0
5d :2 0 d5 :4 0
556 ab4 ab6 :3 0
aaa ab7 0 ab9
559 abb 295 7bc
0 abc 0 ab9
0 abc 560 0
1932 fc :3 0 4a
:3 0 34 :3 0 abe
abf 0 ac0 :2 0
1932 fd :3 0 4a
:3 0 3 :3 0 1d
:3 0 1e :3 0 2d
:4 0 ac9 :2 0 178c
ac3 aca :3 0 563
:3 0 4a :3 0 c1
:3 0 acb acc :3 0
4b :3 0 6d :3 0
ace acf 0 f
:2 0 ad0 ad1 0
ad3 568 ada 4b
:3 0 6d :3 0 ad4
ad5 0 c3 :2 0
ad6 ad7 0 ad9
56a adb acd ad3
0 adc 0 ad9
0 adc 56c 0
178c 4b :3 0 6d
:3 0 add ade 0
4b :3 0 fe :2 0
a6 :3 0 ae0 ae2
0 571 ae1 ae4
:3 0 ae5 :2 0 ff
:8 0 ae9 574 aea
ae6 ae9 0 aeb
576 0 178c c
:3 0 a :2 0 11a
:3 0 11b :3 0 11b
:3 0 11c :3 0 11b
:3 0 11d :3 0 11b
:3 0 11d :3 0 11b
:3 0 11e :3 0 11b
:3 0 11e :3 0 11b
:3 0 11f :3 0 11b
:3 0 120 :3 0 11b
:3 0 121 :3 0 11b
:3 0 121 :3 0 11b
:3 0 122 :3 0 11b
:3 0 122 :3 0 11b
:3 0 123 :3 0 43
:3 0 16 :3 0 44
:3 0 1e :4 0 124
1 :8 0 b22 c1
:4 0 b0d :3 0 c2
:3 0 7a :2 0 57a
b10 b11 :3 0 4b
:3 0 6d :3 0 b13
b14 0 f :2 0
b15 b16 0 b18
57d b1f 4b :3 0
6d :3 0 b19 b1a
0 c3 :2 0 b1b
b1c 0 b1e 57f
b20 b12 b18 0
b21 0 b1e 0
b21 581 0 b22
584 b75 6f :3 0
4b :3 0 6d :3 0
b24 b25 0 6e
:3 0 b26 b27 0
b29 587 b2b 589
b2a b29 :2 0 b73
70 :3 0 4b :3 0
6d :3 0 b2e b2f
0 6e :3 0 b30
b31 0 b6b 55
:3 0 56 :3 0 b33
b34 0 55 :3 0
65 :3 0 b36 b37
0 71 :2 0 2
:4 0 125 :2 0 67
:2 0 a :2 0 58b
b3c b3e :3 0 58e
b38 b40 b35 b42
b41 :2 0 58 :3 0
68 :3 0 b44 b45
0 5a :4 0 126
:4 0 5d :2 0 5e
:3 0 592 b49 b4b
:3 0 5d :2 0 74
:4 0 595 b4d b4f
:3 0 5d :2 0 75
:4 0 598 b51 b53
:3 0 5d :2 0 6e
:3 0 59b b55 b57
:3 0 5d :2 0 76
:4 0 59e b59 b5b
:3 0 5d :2 0 77
:3 0 78 :3 0 a
:2 0 79 :2 0 5a1
b5e b62 5a5 b5d
b64 :3 0 5a8 b46
b66 :2 0 b68 5ab
b69 b43 b68 0
b6a 5ad 0 b6b
5af b6e :3 0 b6e
0 b6e b6d b6b
b6c :6 0 b70 23
:3 0 5b2 b72 5b4
b71 b70 :2 0 b73
5b6 :2 0 b75 0
b75 b74 b22 b73
:6 0 cc8 22 :3 0
3f :3 0 ab :3 0
b8 :3 0 127 :3 0
ab :3 0 ac :3 0
b8 :3 0 128 :3 0
ac :3 0 129 :3 0
b8 :3 0 12a :3 0
129 :3 0 ad :3 0
b8 :3 0 100 :3 0
9e :3 0 ad :3 0
12b :3 0 b8 :3 0
101 :3 0 102 :3 0
12b :3 0 12c :3 0
b8 :3 0 103 :3 0
104 :3 0 12c :3 0
12d :3 0 12e :3 0
12f :3 0 130 :3 0
131 :3 0 132 :3 0
133 :3 0 134 :3 0
135 :3 0 136 :3 0
137 :3 0 138 :3 0
12e :3 0 127 :3 0
130 :3 0 128 :3 0
132 :3 0 12a :3 0
134 :3 0 100 :3 0
9e :3 0 136 :3 0
101 :3 0 102 :3 0
138 :3 0 103 :3 0
104 :3 0 139 :3 0
a7 :3 0 13a :3 0
a9 :3 0 13b :3 0
a8 :3 0 13c :3 0
aa :3 0 3d :3 0
3 :4 0 13d 1
:8 0 bce c1 :4 0
bb9 :3 0 c2 :3 0
7a :2 0 5bb bbc
bbd :3 0 4b :3 0
6d :3 0 bbf bc0
0 f :2 0 bc1
bc2 0 bc4 5be
bcb 4b :3 0 6d
:3 0 bc5 bc6 0
c3 :2 0 bc7 bc8
0 bca 5c0 bcc
bbe bc4 0 bcd
0 bca 0 bcd
5c2 0 bce 5c5
c21 6f :3 0 4b
:3 0 6d :3 0 bd0
bd1 0 6e :3 0
bd2 bd3 0 bd5
5c8 bd7 5ca bd6
bd5 :2 0 c1f 70
:3 0 4b :3 0 6d
:3 0 bda bdb 0
6e :3 0 bdc bdd
0 c17 55 :3 0
56 :3 0 bdf be0
0 55 :3 0 65
:3 0 be2 be3 0
71 :2 0 2 :4 0
13e :2 0 67 :2 0
a :2 0 5cc be8
bea :3 0 5cf be4
bec be1 bee bed
:2 0 58 :3 0 68
:3 0 bf0 bf1 0
5a :4 0 13f :4 0
5d :2 0 5e :3 0
5d3 bf5 bf7 :3 0
5d :2 0 74 :4 0
5d6 bf9 bfb :3 0
5d :2 0 75 :4 0
5d9 bfd bff :3 0
5d :2 0 6e :3 0
5dc c01 c03 :3 0
5d :2 0 76 :4 0
5df c05 c07 :3 0
5d :2 0 77 :3 0
78 :3 0 a :2 0
79 :2 0 5e2 c0a
c0e 5e6 c09 c10
:3 0 5e9 bf2 c12
:2 0 c14 5ec c15
bef c14 0 c16
5ee 0 c17 5f0
c1a :3 0 c1a 0
c1a c19 c17 c18
:6 0 c1c 25 :3 0
5f3 c1e 5f5 c1d
c1c :2 0 c1f 5f7
:2 0 c21 0 c21
c20 bce c1f :6 0
cc8 22 :3 0 140
:3 0 141 :3 0 142
:3 0 142 :3 0 143
:3 0 143 :3 0 144
:3 0 144 :3 0 145
:3 0 146 :3 0 147
:3 0 147 :3 0 148
:3 0 148 :3 0 149
:3 0 149 :3 0 14a
:3 0 14b :3 0 14c
:3 0 14c :3 0 14d
:3 0 14d :3 0 14e
:3 0 14e :3 0 14f
:3 0 150 :3 0 151
:3 0 151 :3 0 152
:3 0 152 :3 0 153
:3 0 153 :3 0 154
:3 0 155 :3 0 156
:3 0 156 :3 0 157
:3 0 157 :3 0 158
:3 0 158 :3 0 159
:3 0 15a :3 0 127
:3 0 15b :3 0 128
:3 0 15c :3 0 12a
:3 0 15d :3 0 100
:3 0 9e :3 0 15e
:3 0 101 :3 0 102
:3 0 15f :3 0 103
:3 0 104 :3 0 43
:3 0 16 :4 0 160
1 :8 0 c73 c1
:4 0 c5e :3 0 c2
:3 0 7a :2 0 5fc
c61 c62 :3 0 4b
:3 0 6d :3 0 c64
c65 0 f :2 0
c66 c67 0 c69
5ff c70 4b :3 0
6d :3 0 c6a c6b
0 c3 :2 0 c6c
c6d 0 c6f 601
c71 c63 c69 0
c72 0 c6f 0
c72 603 0 c73
606 cc6 6f :3 0
4b :3 0 6d :3 0
c75 c76 0 6e
:3 0 c77 c78 0
c7a 609 c7c 60b
c7b c7a :2 0 cc4
70 :3 0 4b :3 0
6d :3 0 c7f c80
0 6e :3 0 c81
c82 0 cbc 55
:3 0 56 :3 0 c84
c85 0 55 :3 0
65 :3 0 c87 c88
0 71 :2 0 2
:4 0 161 :2 0 67
:2 0 a :2 0 60d
c8d c8f :3 0 610
c89 c91 c86 c93
c92 :2 0 58 :3 0
68 :3 0 c95 c96
0 5a :4 0 162
:4 0 5d :2 0 5e
:3 0 614 c9a c9c
:3 0 5d :2 0 74
:4 0 617 c9e ca0
:3 0 5d :2 0 75
:4 0 61a ca2 ca4
:3 0 5d :2 0 6e
:3 0 61d ca6 ca8
:3 0 5d :2 0 76
:4 0 620 caa cac
:3 0 5d :2 0 77
:3 0 78 :3 0 a
:2 0 79 :2 0 623
caf cb3 627 cae
cb5 :3 0 62a c97
cb7 :2 0 cb9 62d
cba c94 cb9 0
cbb 62f 0 cbc
631 cbf :3 0 cbf
0 cbf cbe cbc
cbd :6 0 cc1 27
:3 0 634 cc3 636
cc2 cc1 :2 0 cc4
638 :2 0 cc6 0
cc6 cc5 c73 cc4
:6 0 cc8 22 :3 0
63b cca 63f cc9
cc8 :2 0 1719 117
:2 0 9e :3 0 27
:3 0 3f :3 0 46
:3 0 3d :3 0 3
:4 0 163 1 :8 0
cd8 4b :3 0 6d
:3 0 cd3 cd4 0
6e :3 0 cd5 cd6
0 cd8 641 d2b
6f :3 0 4b :3 0
6d :3 0 cda cdb
0 6e :3 0 cdc
cdd 0 cdf 644
ce1 646 ce0 cdf
:2 0 d29 70 :3 0
4b :3 0 6d :3 0
ce4 ce5 0 6e
:3 0 ce6 ce7 0
d21 55 :3 0 56
:3 0 ce9 cea 0
55 :3 0 65 :3 0
cec ced 0 71
:2 0 2 :4 0 164
:2 0 67 :2 0 a
:2 0 648 cf2 cf4
:3 0 64b cee cf6
ceb cf8 cf7 :2 0
58 :3 0 68 :3 0
cfa cfb 0 5a
:4 0 165 :4 0 5d
:2 0 5e :3 0 64f
cff d01 :3 0 5d
:2 0 74 :4 0 652
d03 d05 :3 0 5d
:2 0 75 :4 0 655
d07 d09 :3 0 5d
:2 0 6e :3 0 658
d0b d0d :3 0 5d
:2 0 76 :4 0 65b
d0f d11 :3 0 5d
:2 0 77 :3 0 78
:3 0 a :2 0 79
:2 0 65e d14 d18
662 d13 d1a :3 0
665 cfc d1c :2 0
d1e 668 d1f cf9
d1e 0 d20 66a
0 d21 66c d24
:3 0 d24 0 d24
d23 d21 d22 :6 0
d26 29 :3 0 66f
d28 671 d27 d26
:2 0 d29 673 :2 0
d2b 0 d2b d2a
cd8 d29 :6 0 1713
22 :3 0 4b :3 0
6d :3 0 d2d d2e
0 4b :3 0 fe
:2 0 a6 :3 0 d30
d32 0 678 d31
d34 :3 0 d35 :2 0
27 :3 0 166 :2 0
67b d38 d39 :3 0
d3a :2 0 d3b :2 0
d36 d3d d3c :2 0
167 :3 0 d3f :4 0
d41 67d d42 d3e
d41 0 d43 67f
0 1713 3d :3 0
b0 :3 0 b0 :3 0
2d :3 0 20 :3 0
2d :3 0 3f :3 0
46 :3 0 45 :3 0
16 :3 0 3e :3 0
1d :4 0 168 1
:8 0 d56 4b :3 0
6d :3 0 d51 d52
0 6e :3 0 d53
d54 0 d56 681
da9 6f :3 0 4b
:3 0 6d :3 0 d58
d59 0 6e :3 0
d5a d5b 0 d5d
684 d5f 686 d5e
d5d :2 0 da7 70
:3 0 4b :3 0 6d
:3 0 d62 d63 0
6e :3 0 d64 d65
0 d9f 55 :3 0
56 :3 0 d67 d68
0 55 :3 0 65
:3 0 d6a d6b 0
71 :2 0 2 :4 0
169 :2 0 67 :2 0
a :2 0 688 d70
d72 :3 0 68b d6c
d74 d69 d76 d75
:2 0 58 :3 0 68
:3 0 d78 d79 0
5a :4 0 16a :4 0
5d :2 0 5e :3 0
68f d7d d7f :3 0
5d :2 0 74 :4 0
692 d81 d83 :3 0
5d :2 0 75 :4 0
695 d85 d87 :3 0
5d :2 0 6e :3 0
698 d89 d8b :3 0
5d :2 0 76 :4 0
69b d8d d8f :3 0
5d :2 0 77 :3 0
78 :3 0 a :2 0
79 :2 0 69e d92
d96 6a2 d91 d98
:3 0 6a5 d7a d9a
:2 0 d9c 6a8 d9d
d77 d9c 0 d9e
6aa 0 d9f 6ac
da2 :3 0 da2 0
da2 da1 d9f da0
:6 0 da4 2b :3 0
6af da6 6b1 da5
da4 :2 0 da7 6b3
:2 0 da9 0 da9
da8 d56 da7 :6 0
1713 22 :3 0 4b
:3 0 6d :3 0 dab
dac 0 4b :3 0
7a :2 0 a6 :3 0
dae db0 0 6b8
daf db2 :3 0 db3
:2 0 20 :3 0 9d
:2 0 6bb db6 db7
:3 0 db8 :2 0 db9
:2 0 db4 dbb dba
:2 0 e :3 0 2c
:3 0 f :2 0 6bd
dbd dc0 7a :2 0
f :2 0 6c2 dc2
dc4 :3 0 26 :3 0
117 :2 0 dc6 dc7
0 dc9 6c5 f86
3f :3 0 3d :3 0
3 :4 0 16b 1
:8 0 de3 c1 :4 0
dce :3 0 c2 :3 0
7a :2 0 6c9 dd1
dd2 :3 0 4b :3 0
6d :3 0 dd4 dd5
0 f :2 0 dd6
dd7 0 dd9 6cc
de0 4b :3 0 6d
:3 0 dda ddb 0
c3 :2 0 ddc ddd
0 ddf 6ce de1
dd3 dd9 0 de2
0 ddf 0 de2
6d0 0 de3 6d3
e36 6f :3 0 4b
:3 0 6d :3 0 de5
de6 0 6e :3 0
de7 de8 0 dea
6d6 dec 6d8 deb
dea :2 0 e34 70
:3 0 4b :3 0 6d
:3 0 def df0 0
6e :3 0 df1 df2
0 e2c 55 :3 0
56 :3 0 df4 df5
0 55 :3 0 65
:3 0 df7 df8 0
71 :2 0 2 :4 0
16c :2 0 67 :2 0
a :2 0 6da dfd
dff :3 0 6dd df9
e01 df6 e03 e02
:2 0 58 :3 0 68
:3 0 e05 e06 0
5a :4 0 16d :4 0
5d :2 0 5e :3 0
6e1 e0a e0c :3 0
5d :2 0 74 :4 0
6e4 e0e e10 :3 0
5d :2 0 75 :4 0
6e7 e12 e14 :3 0
5d :2 0 6e :3 0
6ea e16 e18 :3 0
5d :2 0 76 :4 0
6ed e1a e1c :3 0
5d :2 0 77 :3 0
78 :3 0 a :2 0
79 :2 0 6f0 e1f
e23 6f4 e1e e25
:3 0 6f7 e07 e27
:2 0 e29 6fa e2a
e04 e29 0 e2b
6fc 0 e2c 6fe
e2f :3 0 e2f 0
e2f e2e e2c e2d
:6 0 e31 2d :3 0
701 e33 703 e32
e31 :2 0 e34 705
:2 0 e36 0 e36
e35 de3 e34 :6 0
f85 22 :3 0 16e
:3 0 3d :3 0 3
:4 0 16f 1 :8 0
e51 c1 :4 0 e3c
:3 0 c2 :3 0 7a
:2 0 70a e3f e40
:3 0 4b :3 0 6d
:3 0 e42 e43 0
f :2 0 e44 e45
0 e47 70d e4e
4b :3 0 6d :3 0
e48 e49 0 c3
:2 0 e4a e4b 0
e4d 70f e4f e41
e47 0 e50 0
e4d 0 e50 711
0 e51 714 ea4
6f :3 0 4b :3 0
6d :3 0 e53 e54
0 6e :3 0 e55
e56 0 e58 717
e5a 719 e59 e58
:2 0 ea2 70 :3 0
4b :3 0 6d :3 0
e5d e5e 0 6e
:3 0 e5f e60 0
e9a 55 :3 0 56
:3 0 e62 e63 0
55 :3 0 65 :3 0
e65 e66 0 71
:2 0 2 :4 0 170
:2 0 67 :2 0 a
:2 0 71b e6b e6d
:3 0 71e e67 e6f
e64 e71 e70 :2 0
58 :3 0 68 :3 0
e73 e74 0 5a
:4 0 171 :4 0 5d
:2 0 5e :3 0 722
e78 e7a :3 0 5d
:2 0 74 :4 0 725
e7c e7e :3 0 5d
:2 0 75 :4 0 728
e80 e82 :3 0 5d
:2 0 6e :3 0 72b
e84 e86 :3 0 5d
:2 0 76 :4 0 72e
e88 e8a :3 0 5d
:2 0 77 :3 0 78
:3 0 a :2 0 79
:2 0 731 e8d e91
735 e8c e93 :3 0
738 e75 e95 :2 0
e97 73b e98 e72
e97 0 e99 73d
0 e9a 73f e9d
:3 0 e9d 0 e9d
e9c e9a e9b :6 0
e9f 2f :3 0 742
ea1 744 ea0 e9f
:2 0 ea2 746 :2 0
ea4 0 ea4 ea3
e51 ea2 :6 0 f85
22 :3 0 172 :3 0
8b :3 0 3 :4 0
173 1 :8 0 ebf
c1 :4 0 eaa :3 0
c2 :3 0 7a :2 0
74b ead eae :3 0
4b :3 0 6d :3 0
eb0 eb1 0 f
:2 0 eb2 eb3 0
eb5 74e ebc 4b
:3 0 6d :3 0 eb6
eb7 0 c3 :2 0
eb8 eb9 0 ebb
750 ebd eaf eb5
0 ebe 0 ebb
0 ebe 752 0
ebf 755 f12 6f
:3 0 4b :3 0 6d
:3 0 ec1 ec2 0
6e :3 0 ec3 ec4
0 ec6 758 ec8
75a ec7 ec6 :2 0
f10 70 :3 0 4b
:3 0 6d :3 0 ecb
ecc 0 6e :3 0
ecd ece 0 f08
55 :3 0 56 :3 0
ed0 ed1 0 55
:3 0 65 :3 0 ed3
ed4 0 71 :2 0
2 :4 0 174 :2 0
67 :2 0 a :2 0
75c ed9 edb :3 0
75f ed5 edd ed2
edf ede :2 0 58
:3 0 68 :3 0 ee1
ee2 0 5a :4 0
175 :4 0 5d :2 0
5e :3 0 763 ee6
ee8 :3 0 5d :2 0
74 :4 0 766 eea
eec :3 0 5d :2 0
75 :4 0 769 eee
ef0 :3 0 5d :2 0
6e :3 0 76c ef2
ef4 :3 0 5d :2 0
76 :4 0 76f ef6
ef8 :3 0 5d :2 0
77 :3 0 78 :3 0
a :2 0 79 :2 0
772 efb eff 776
efa f01 :3 0 779
ee3 f03 :2 0 f05
77c f06 ee0 f05
0 f07 77e 0
f08 780 f0b :3 0
f0b 0 f0b f0a
f08 f09 :6 0 f0d
31 :3 0 783 f0f
785 f0e f0d :2 0
f10 787 :2 0 f12
0 f12 f11 ebf
f10 :6 0 f85 22
:3 0 176 :3 0 8b
:3 0 3 :4 0 177
1 :8 0 f2d c1
:4 0 f18 :3 0 c2
:3 0 7a :2 0 78c
f1b f1c :3 0 4b
:3 0 6d :3 0 f1e
f1f 0 f :2 0
f20 f21 0 f23
78f f2a 4b :3 0
6d :3 0 f24 f25
0 c3 :2 0 f26
f27 0 f29 791
f2b f1d f23 0
f2c 0 f29 0
f2c 793 0 f2d
796 f80 6f :3 0
4b :3 0 6d :3 0
f2f f30 0 6e
:3 0 f31 f32 0
f34 799 f36 79b
f35 f34 :2 0 f7e
70 :3 0 4b :3 0
6d :3 0 f39 f3a
0 6e :3 0 f3b
f3c 0 f76 55
:3 0 56 :3 0 f3e
f3f 0 55 :3 0
65 :3 0 f41 f42
0 71 :2 0 2
:4 0 178 :2 0 67
:2 0 a :2 0 79d
f47 f49 :3 0 7a0
f43 f4b f40 f4d
f4c :2 0 58 :3 0
68 :3 0 f4f f50
0 5a :4 0 179
:4 0 5d :2 0 5e
:3 0 7a4 f54 f56
:3 0 5d :2 0 74
:4 0 7a7 f58 f5a
:3 0 5d :2 0 75
:4 0 7aa f5c f5e
:3 0 5d :2 0 6e
:3 0 7ad f60 f62
:3 0 5d :2 0 76
:4 0 7b0 f64 f66
:3 0 5d :2 0 77
:3 0 78 :3 0 a
:2 0 79 :2 0 7b3
f69 f6d 7b7 f68
f6f :3 0 7ba f51
f71 :2 0 f73 7bd
f74 f4e f73 0
f75 7bf 0 f76
7c1 f79 :3 0 f79
0 f79 f78 f76
f77 :6 0 f7b 33
:3 0 7c4 f7d 7c6
f7c f7b :2 0 f7e
7c8 :2 0 f80 0
f80 f7f f2d f7e
:6 0 f85 22 :3 0
26 :3 0 a :2 0
f82 f83 0 f85
7cb f87 dc5 dc9
0 f88 0 f85
0 f88 7d1 0
f89 7d4 f91 20
:3 0 3 :3 0 f8a
f8b 0 f90 26
:3 0 f :2 0 f8d
f8e 0 f90 7d6
f92 dbc f89 0
f93 0 f90 0
f93 7d9 0 1713
27 :3 0 f :2 0
f94 f95 0 1713
fc :3 0 4d :4 0
f9a :2 0 1713 f98
f9b :3 0 fd :3 0
4d :3 0 1b :3 0
27 :3 0 10 :4 0
fa2 :2 0 11c0 f9d
fa3 :3 0 7dc :3 0
4d :3 0 c1 :3 0
fa4 fa5 :3 0 4b
:3 0 6d :3 0 fa7
fa8 0 f :2 0
fa9 faa 0 fac
7e0 fb3 4b :3 0
6d :3 0 fad fae
0 c3 :2 0 faf
fb0 0 fb2 7e2
fb4 fa6 fac 0
fb5 0 fb2 0
fb5 7e4 0 11c0
4b :3 0 6d :3 0
fb6 fb7 0 4b
:3 0 fe :2 0 a6
:3 0 fb9 fbb 0
7e9 fba fbd :3 0
fbe :2 0 ff :8 0
fc2 7ec fc3 fbf
fc2 0 fc4 7ee
0 11c0 e :3 0
26 :3 0 f :2 0
7f0 fc5 fc8 7a
:2 0 a :2 0 7f5
fca fcc :3 0 51
:3 0 4f :3 0 4f
:3 0 27 :3 0 50
:3 0 17a :3 0 17b
:3 0 50 :3 0 10
:3 0 43 :3 0 16
:3 0 3d :3 0 20
:3 0 4e :3 0 1b
:4 0 17c 1 :8 0
ff3 c1 :4 0 fde
:3 0 c2 :3 0 7a
:2 0 7fa fe1 fe2
:3 0 4b :3 0 6d
:3 0 fe4 fe5 0
f :2 0 fe6 fe7
0 fe9 7fd ff0
4b :3 0 6d :3 0
fea feb 0 c3
:2 0 fec fed 0
fef 7ff ff1 fe3
fe9 0 ff2 0
fef 0 ff2 801
0 ff3 804 1046
6f :3 0 4b :3 0
6d :3 0 ff5 ff6
0 6e :3 0 ff7
ff8 0 ffa 807
ffc 809 ffb ffa
:2 0 1044 70 :3 0
4b :3 0 6d :3 0
fff 1000 0 6e
:3 0 1001 1002 0
103c 55 :3 0 56
:3 0 1004 1005 0
55 :3 0 65 :3 0
1007 1008 0 71
:2 0 2 :4 0 17d
:2 0 67 :2 0 a
:2 0 80b 100d 100f
:3 0 80e 1009 1011
1006 1013 1012 :2 0
58 :3 0 68 :3 0
1015 1016 0 5a
:4 0 17e :4 0 5d
:2 0 5e :3 0 812
101a 101c :3 0 5d
:2 0 74 :4 0 815
101e 1020 :3 0 5d
:2 0 75 :4 0 818
1022 1024 :3 0 5d
:2 0 6e :3 0 81b
1026 1028 :3 0 5d
:2 0 76 :4 0 81e
102a 102c :3 0 5d
:2 0 77 :3 0 78
:3 0 a :2 0 79
:2 0 821 102f 1033
825 102e 1035 :3 0
828 1017 1037 :2 0
1039 82b 103a 1014
1039 0 103b 82d
0 103c 82f 103f
:3 0 103f 0 103f
103e 103c 103d :6 0
1041 36 :3 0 832
1043 834 1042 1041
:2 0 1044 836 :2 0
1046 0 1046 1045
ff3 1044 :6 0 113e
35 :3 0 4b :3 0
6d :3 0 1048 1049
0 4b :3 0 7a
:2 0 a6 :3 0 104b
104d 0 83b 104c
104f :3 0 1050 :2 0
51 :3 0 43 :3 0
16 :3 0 3d :3 0
3 :3 0 4e :3 0
1b :4 0 17f 1
:8 0 106f c1 :4 0
105a :3 0 c2 :3 0
7a :2 0 840 105d
105e :3 0 4b :3 0
6d :3 0 1060 1061
0 f :2 0 1062
1063 0 1065 843
106c 4b :3 0 6d
:3 0 1066 1067 0
c3 :2 0 1068 1069
0 106b 845 106d
105f 1065 0 106e
0 106b 0 106e
847 0 106f 84a
10c2 6f :3 0 4b
:3 0 6d :3 0 1071
1072 0 6e :3 0
1073 1074 0 1076
84d 1078 84f 1077
1076 :2 0 10c0 70
:3 0 4b :3 0 6d
:3 0 107b 107c 0
6e :3 0 107d 107e
0 10b8 55 :3 0
56 :3 0 1080 1081
0 55 :3 0 65
:3 0 1083 1084 0
71 :2 0 2 :4 0
180 :2 0 67 :2 0
a :2 0 851 1089
108b :3 0 854 1085
108d 1082 108f 108e
:2 0 58 :3 0 68
:3 0 1091 1092 0
5a :4 0 181 :4 0
5d :2 0 5e :3 0
858 1096 1098 :3 0
5d :2 0 74 :4 0
85b 109a 109c :3 0
5d :2 0 75 :4 0
85e 109e 10a0 :3 0
5d :2 0 6e :3 0
861 10a2 10a4 :3 0
5d :2 0 76 :4 0
864 10a6 10a8 :3 0
5d :2 0 77 :3 0
78 :3 0 a :2 0
79 :2 0 867 10ab
10af 86b 10aa 10b1
:3 0 86e 1093 10b3
:2 0 10b5 871 10b6
1090 10b5 0 10b7
873 0 10b8 875
10bb :3 0 10bb 0
10bb 10ba 10b8 10b9
:6 0 10bd 38 :3 0
878 10bf 87a 10be
10bd :2 0 10c0 87c
:2 0 10c2 0 10c2
10c1 106f 10c0 :6 0
10c4 35 :3 0 87f
113a 51 :3 0 3d
:3 0 20 :3 0 43
:3 0 16 :3 0 3d
:3 0 3 :3 0 4e
:3 0 1b :4 0 182
1 :8 0 10e4 c1
:4 0 10cf :3 0 c2
:3 0 7a :2 0 883
10d2 10d3 :3 0 4b
:3 0 6d :3 0 10d5
10d6 0 f :2 0
10d7 10d8 0 10da
886 10e1 4b :3 0
6d :3 0 10db 10dc
0 c3 :2 0 10dd
10de 0 10e0 888
10e2 10d4 10da 0
10e3 0 10e0 0
10e3 88a 0 10e4
88d 1137 6f :3 0
4b :3 0 6d :3 0
10e6 10e7 0 6e
:3 0 10e8 10e9 0
10eb 890 10ed 892
10ec 10eb :2 0 1135
70 :3 0 4b :3 0
6d :3 0 10f0 10f1
0 6e :3 0 10f2
10f3 0 112d 55
:3 0 56 :3 0 10f5
10f6 0 55 :3 0
65 :3 0 10f8 10f9
0 71 :2 0 2
:4 0 183 :2 0 67
:2 0 a :2 0 894
10fe 1100 :3 0 897
10fa 1102 10f7 1104
1103 :2 0 58 :3 0
68 :3 0 1106 1107
0 5a :4 0 184
:4 0 5d :2 0 5e
:3 0 89b 110b 110d
:3 0 5d :2 0 74
:4 0 89e 110f 1111
:3 0 5d :2 0 75
:4 0 8a1 1113 1115
:3 0 5d :2 0 6e
:3 0 8a4 1117 1119
:3 0 5d :2 0 76
:4 0 8a7 111b 111d
:3 0 5d :2 0 77
:3 0 78 :3 0 a
:2 0 79 :2 0 8aa
1120 1124 8ae 111f
1126 :3 0 8b1 1108
1128 :2 0 112a 8b4
112b 1105 112a 0
112c 8b6 0 112d
8b8 1130 :3 0 1130
0 1130 112f 112d
112e :6 0 1132 3a
:3 0 8bb 1134 8bd
1133 1132 :2 0 1135
8bf :2 0 1137 0
1137 1136 10e4 1135
:6 0 1139 35 :3 0
8c2 113b 1051 10c4
0 113c 0 1139
0 113c 8c4 0
113e 96 :3 0 8c7
11be e :3 0 26
:3 0 f :2 0 8ca
113f 1142 7a :2 0
117 :2 0 8cf 1144
1146 :3 0 51 :3 0
3d :3 0 20 :3 0
43 :3 0 16 :3 0
3d :3 0 3 :3 0
4e :3 0 1b :4 0
182 1 :8 0 1167
c1 :4 0 1152 :3 0
c2 :3 0 7a :2 0
8d4 1155 1156 :3 0
4b :3 0 6d :3 0
1158 1159 0 f
:2 0 115a 115b 0
115d 8d7 1164 4b
:3 0 6d :3 0 115e
115f 0 c3 :2 0
1160 1161 0 1163
8d9 1165 1157 115d
0 1166 0 1163
0 1166 8db 0
1167 8de 11ba 6f
:3 0 4b :3 0 6d
:3 0 1169 116a 0
6e :3 0 116b 116c
0 116e 8e1 1170
8e3 116f 116e :2 0
11b8 70 :3 0 4b
:3 0 6d :3 0 1173
1174 0 6e :3 0
1175 1176 0 11b0
55 :3 0 56 :3 0
1178 1179 0 55
:3 0 65 :3 0 117b
117c 0 71 :2 0
2 :4 0 185 :2 0
67 :2 0 a :2 0
8e5 1181 1183 :3 0
8e8 117d 1185 117a
1187 1186 :2 0 58
:3 0 68 :3 0 1189
118a 0 5a :4 0
186 :4 0 5d :2 0
5e :3 0 8ec 118e
1190 :3 0 5d :2 0
74 :4 0 8ef 1192
1194 :3 0 5d :2 0
75 :4 0 8f2 1196
1198 :3 0 5d :2 0
6e :3 0 8f5 119a
119c :3 0 5d :2 0
76 :4 0 8f8 119e
11a0 :3 0 5d :2 0
77 :3 0 78 :3 0
a :2 0 79 :2 0
8fb 11a3 11a7 8ff
11a2 11a9 :3 0 902
118b 11ab :2 0 11ad
905 11ae 1188 11ad
0 11af 907 0
11b0 909 11b3 :3 0
11b3 0 11b3 11b2
11b0 11b1 :6 0 11b5
3c :3 0 90c 11b7
90e 11b6 11b5 :2 0
11b8 910 :2 0 11ba
0 11ba 11b9 1167
11b8 :6 0 11bc 35
:3 0 913 11bd 1147
11bc 0 11bf fcd
113e 0 11bf 915
0 11c0 918 11c2
fd :4 0 11c0 :4 0
1713 10f :3 0 4d
:4 0 11c6 :2 0 11cc
11c4 0 4b :3 0
6d :3 0 11c7 11c8
0 6e :3 0 11c9
11ca 0 11cc 91d
121f 6f :3 0 4b
:3 0 6d :3 0 11ce
11cf 0 6e :3 0
11d0 11d1 0 11d3
920 11d5 922 11d4
11d3 :2 0 121d 70
:3 0 4b :3 0 6d
:3 0 11d8 11d9 0
6e :3 0 11da 11db
0 1215 55 :3 0
56 :3 0 11dd 11de
0 55 :3 0 65
:3 0 11e0 11e1 0
71 :2 0 2 :4 0
187 :2 0 67 :2 0
a :2 0 924 11e6
11e8 :3 0 927 11e2
11ea 11df 11ec 11eb
:2 0 58 :3 0 68
:3 0 11ee 11ef 0
5a :4 0 188 :4 0
5d :2 0 5e :3 0
92b 11f3 11f5 :3 0
5d :2 0 74 :4 0
92e 11f7 11f9 :3 0
5d :2 0 75 :4 0
931 11fb 11fd :3 0
5d :2 0 6e :3 0
934 11ff 1201 :3 0
5d :2 0 76 :4 0
937 1203 1205 :3 0
5d :2 0 77 :3 0
78 :3 0 a :2 0
79 :2 0 93a 1208
120c 93e 1207 120e
:3 0 941 11f0 1210
:2 0 1212 944 1213
11ed 1212 0 1214
946 0 1215 948
1218 :3 0 1218 0
1218 1217 1215 1216
:6 0 121a 3e :3 0
94b 121c 94d 121b
121a :2 0 121d 94f
:2 0 121f 0 121f
121e 11cc 121d :6 0
1713 22 :3 0 51
:3 0 46 :3 0 189
:3 0 20 :3 0 43
:3 0 16 :3 0 189
:3 0 3 :4 0 18a
1 :8 0 123f c1
:4 0 122a :3 0 c2
:3 0 7a :2 0 954
122d 122e :3 0 4b
:3 0 6d :3 0 1230
1231 0 f :2 0
1232 1233 0 1235
957 123c 4b :3 0
6d :3 0 1236 1237
0 c3 :2 0 1238
1239 0 123b 959
123d 122f 1235 0
123e 0 123b 0
123e 95b 0 123f
95e 1292 6f :3 0
4b :3 0 6d :3 0
1241 1242 0 6e
:3 0 1243 1244 0
1246 961 1248 963
1247 1246 :2 0 1290
70 :3 0 4b :3 0
6d :3 0 124b 124c
0 6e :3 0 124d
124e 0 1288 55
:3 0 56 :3 0 1250
1251 0 55 :3 0
65 :3 0 1253 1254
0 71 :2 0 2
:4 0 18b :2 0 67
:2 0 a :2 0 965
1259 125b :3 0 968
1255 125d 1252 125f
125e :2 0 58 :3 0
68 :3 0 1261 1262
0 5a :4 0 18c
:4 0 5d :2 0 5e
:3 0 96c 1266 1268
:3 0 5d :2 0 74
:4 0 96f 126a 126c
:3 0 5d :2 0 75
:4 0 972 126e 1270
:3 0 5d :2 0 6e
:3 0 975 1272 1274
:3 0 5d :2 0 76
:4 0 978 1276 1278
:3 0 5d :2 0 77
:3 0 78 :3 0 a
:2 0 79 :2 0 97b
127b 127f 97f 127a
1281 :3 0 982 1263
1283 :2 0 1285 985
1286 1260 1285 0
1287 987 0 1288
989 128b :3 0 128b
0 128b 128a 1288
1289 :6 0 128d 40
:3 0 98c 128f 98e
128e 128d :2 0 1290
990 :2 0 1292 0
1292 1291 123f 1290
:6 0 1713 22 :3 0
e :3 0 2c :3 0
f :2 0 993 1294
1297 7a :2 0 f
:2 0 998 1299 129b
:3 0 3f :3 0 46
:3 0 18d :3 0 13
:3 0 18e :3 0 18f
:3 0 13 :3 0 190
:3 0 da :3 0 db
:3 0 dc :3 0 dd
:3 0 de :3 0 df
:3 0 100 :3 0 9e
:3 0 bc :3 0 db
:3 0 bd :3 0 dd
:3 0 be :3 0 9e
:3 0 101 :3 0 102
:3 0 102 :3 0 101
:3 0 103 :3 0 104
:3 0 104 :3 0 103
:3 0 e5 :3 0 9e
:3 0 105 :3 0 e5
:3 0 9e :3 0 a7
:3 0 106 :3 0 107
:3 0 ae :3 0 e5
:3 0 9e :3 0 a9
:3 0 108 :3 0 db
:3 0 dd :3 0 df
:3 0 9e :3 0 e2
:3 0 e3 :3 0 e6
:3 0 48 :3 0 3d
:3 0 3 :3 0 100
:3 0 9e :4 0 191
1 :8 0 12ea c1
:4 0 12d5 :3 0 c2
:3 0 7a :2 0 99d
12d8 12d9 :3 0 4b
:3 0 6d :3 0 12db
12dc 0 f :2 0
12dd 12de 0 12e0
9a0 12e7 4b :3 0
6d :3 0 12e1 12e2
0 c3 :2 0 12e3
12e4 0 12e6 9a2
12e8 12da 12e0 0
12e9 0 12e6 0
12e9 9a4 0 12ea
9a7 133d 6f :3 0
4b :3 0 6d :3 0
12ec 12ed 0 6e
:3 0 12ee 12ef 0
12f1 9aa 12f3 9ac
12f2 12f1 :2 0 133b
70 :3 0 4b :3 0
6d :3 0 12f6 12f7
0 6e :3 0 12f8
12f9 0 1333 55
:3 0 56 :3 0 12fb
12fc 0 55 :3 0
65 :3 0 12fe 12ff
0 71 :2 0 2
:4 0 192 :2 0 67
:2 0 a :2 0 9ae
1304 1306 :3 0 9b1
1300 1308 12fd 130a
1309 :2 0 58 :3 0
68 :3 0 130c 130d
0 5a :4 0 193
:4 0 5d :2 0 5e
:3 0 9b5 1311 1313
:3 0 5d :2 0 74
:4 0 9b8 1315 1317
:3 0 5d :2 0 75
:4 0 9bb 1319 131b
:3 0 5d :2 0 6e
:3 0 9be 131d 131f
:3 0 5d :2 0 76
:4 0 9c1 1321 1323
:3 0 5d :2 0 77
:3 0 78 :3 0 a
:2 0 79 :2 0 9c4
1326 132a 9c8 1325
132c :3 0 9cb 130e
132e :2 0 1330 9ce
1331 130b 1330 0
1332 9d0 0 1333
9d2 1336 :3 0 1336
0 1336 1335 1333
1334 :6 0 1338 42
:3 0 9d5 133a 9d7
1339 1338 :2 0 133b
9d9 :2 0 133d 0
133d 133c 12ea 133b
:6 0 1359 22 :3 0
e :3 0 26 :3 0
f :2 0 9dc 133f
1342 7a :2 0 117
:2 0 9e1 1344 1346
:3 0 2e :3 0 d6
:2 0 1348 1349 0
1356 2f :3 0 194
:3 0 16 :3 0 20
:3 0 2e :3 0 f
:2 0 f :2 0 f
:2 0 9e4 134c 1353
134b 1354 0 1356
9eb 1357 1347 1356
0 1358 9ee 0
1359 9f0 170c fc
:3 0 53 :4 0 135d
:2 0 170b 135b 135e
:3 0 fd :3 0 53
:3 0 1e :3 0 1f
:4 0 1364 :2 0 1499
1360 1365 :3 0 9f3
:3 0 53 :3 0 c1
:3 0 1366 1367 :3 0
4b :3 0 6d :3 0
1369 136a 0 f
:2 0 136b 136c 0
136e 9f6 1375 4b
:3 0 6d :3 0 136f
1370 0 c3 :2 0
1371 1372 0 1374
9f8 1376 1368 136e
0 1377 0 1374
0 1377 9fa 0
1499 4b :3 0 6d
:3 0 1378 1379 0
4b :3 0 fe :2 0
a6 :3 0 137b 137d
0 9ff 137c 137f
:3 0 1380 :2 0 ff
:8 0 1384 a02 1385
1381 1384 0 1386
a04 0 1499 3f
:3 0 46 :3 0 18d
:3 0 13 :3 0 18e
:3 0 18f :3 0 13
:3 0 190 :3 0 da
:3 0 db :3 0 dc
:3 0 dd :3 0 de
:3 0 df :3 0 100
:3 0 9e :3 0 bc
:3 0 db :3 0 bd
:3 0 dd :3 0 be
:3 0 9e :3 0 101
:3 0 102 :3 0 102
:3 0 101 :3 0 103
:3 0 104 :3 0 104
:3 0 103 :3 0 e5
:3 0 9e :3 0 105
:3 0 e5 :3 0 9e
:3 0 a7 :3 0 106
:3 0 107 :3 0 ae
:3 0 e5 :3 0 9e
:3 0 a9 :3 0 108
:3 0 db :3 0 dd
:3 0 df :3 0 9e
:3 0 e2 :3 0 e3
:3 0 e6 :3 0 48
:3 0 20 :3 0 3d
:3 0 1f :4 0 195
1 :8 0 13d3 c1
:4 0 13be :3 0 c2
:3 0 7a :2 0 a08
13c1 13c2 :3 0 4b
:3 0 6d :3 0 13c4
13c5 0 f :2 0
13c6 13c7 0 13c9
a0b 13d0 4b :3 0
6d :3 0 13ca 13cb
0 c3 :2 0 13cc
13cd 0 13cf a0d
13d1 13c3 13c9 0
13d2 0 13cf 0
13d2 a0f 0 13d3
a12 1426 6f :3 0
4b :3 0 6d :3 0
13d5 13d6 0 6e
:3 0 13d7 13d8 0
13da a15 13dc a17
13db 13da :2 0 1424
70 :3 0 4b :3 0
6d :3 0 13df 13e0
0 6e :3 0 13e1
13e2 0 141c 55
:3 0 56 :3 0 13e4
13e5 0 55 :3 0
65 :3 0 13e7 13e8
0 71 :2 0 2
:4 0 196 :2 0 67
:2 0 a :2 0 a19
13ed 13ef :3 0 a1c
13e9 13f1 13e6 13f3
13f2 :2 0 58 :3 0
68 :3 0 13f5 13f6
0 5a :4 0 197
:4 0 5d :2 0 5e
:3 0 a20 13fa 13fc
:3 0 5d :2 0 74
:4 0 a23 13fe 1400
:3 0 5d :2 0 75
:4 0 a26 1402 1404
:3 0 5d :2 0 6e
:3 0 a29 1406 1408
:3 0 5d :2 0 76
:4 0 a2c 140a 140c
:3 0 5d :2 0 77
:3 0 78 :3 0 a
:2 0 79 :2 0 a2f
140f 1413 a33 140e
1415 :3 0 a36 13f7
1417 :2 0 1419 a39
141a 13f4 1419 0
141b a3b 0 141c
a3d 141f :3 0 141f
0 141f 141e 141c
141d :6 0 1421 45
:3 0 a40 1423 a42
1422 1421 :2 0 1424
a44 :2 0 1426 0
1426 1425 13d3 1424
:6 0 1499 44 :3 0
41 :3 0 112 :3 0
13 :3 0 113 :3 0
44 :3 0 1e :4 0
198 1 :8 0 1444
c1 :4 0 142f :3 0
c2 :3 0 7a :2 0
a49 1432 1433 :3 0
4b :3 0 6d :3 0
1435 1436 0 f
:2 0 1437 1438 0
143a a4c 1441 4b
:3 0 6d :3 0 143b
143c 0 c3 :2 0
143d 143e 0 1440
a4e 1442 1434 143a
0 1443 0 1440
0 1443 a50 0
1444 a53 1497 6f
:3 0 4b :3 0 6d
:3 0 1446 1447 0
6e :3 0 1448 1449
0 144b a56 144d
a58 144c 144b :2 0
1495 70 :3 0 4b
:3 0 6d :3 0 1450
1451 0 6e :3 0
1452 1453 0 148d
55 :3 0 56 :3 0
1455 1456 0 55
:3 0 65 :3 0 1458
1459 0 71 :2 0
2 :4 0 199 :2 0
67 :2 0 a :2 0
a5a 145e 1460 :3 0
a5d 145a 1462 1457
1464 1463 :2 0 58
:3 0 68 :3 0 1466
1467 0 5a :4 0
19a :4 0 5d :2 0
5e :3 0 a61 146b
146d :3 0 5d :2 0
74 :4 0 a64 146f
1471 :3 0 5d :2 0
75 :4 0 a67 1473
1475 :3 0 5d :2 0
6e :3 0 a6a 1477
1479 :3 0 5d :2 0
76 :4 0 a6d 147b
147d :3 0 5d :2 0
77 :3 0 78 :3 0
a :2 0 79 :2 0
a70 1480 1484 a74
147f 1486 :3 0 a77
1468 1488 :2 0 148a
a7a 148b 1465 148a
0 148c a7c 0
148d a7e 1490 :3 0
1490 0 1490 148f
148d 148e :6 0 1492
47 :3 0 a81 1494
a83 1493 1492 :2 0
1495 a85 :2 0 1497
0 1497 1496 1444
1495 :6 0 1499 44
:3 0 a88 149b fd
:4 0 1499 :4 0 170b
10f :3 0 53 :4 0
149f :2 0 14a5 149d
0 4b :3 0 6d
:3 0 14a0 14a1 0
6e :3 0 14a2 14a3
0 14a5 a8e 14f8
6f :3 0 4b :3 0
6d :3 0 14a7 14a8
0 6e :3 0 14a9
14aa 0 14ac a91
14ae a93 14ad 14ac
:2 0 14f6 70 :3 0
4b :3 0 6d :3 0
14b1 14b2 0 6e
:3 0 14b3 14b4 0
14ee 55 :3 0 56
:3 0 14b6 14b7 0
55 :3 0 65 :3 0
14b9 14ba 0 71
:2 0 2 :4 0 19b
:2 0 67 :2 0 a
:2 0 a95 14bf 14c1
:3 0 a98 14bb 14c3
14b8 14c5 14c4 :2 0
58 :3 0 68 :3 0
14c7 14c8 0 5a
:4 0 19c :4 0 5d
:2 0 5e :3 0 a9c
14cc 14ce :3 0 5d
:2 0 74 :4 0 a9f
14d0 14d2 :3 0 5d
:2 0 75 :4 0 aa2
14d4 14d6 :3 0 5d
:2 0 6e :3 0 aa5
14d8 14da :3 0 5d
:2 0 76 :4 0 aa8
14dc 14de :3 0 5d
:2 0 77 :3 0 78
:3 0 a :2 0 79
:2 0 aab 14e1 14e5
aaf 14e0 14e7 :3 0
ab2 14c9 14e9 :2 0
14eb ab5 14ec 14c6
14eb 0 14ed ab7
0 14ee ab9 14f1
:3 0 14f1 0 14f1
14f0 14ee 14ef :6 0
14f3 49 :3 0 abc
14f5 abe 14f4 14f3
:2 0 14f6 ac0 :2 0
14f8 0 14f8 14f7
14a5 14f6 :6 0 170b
22 :3 0 e :3 0
2c :3 0 f :2 0
ac3 14fa 14fd 7a
:2 0 a :2 0 ac8
14ff 1501 :3 0 1502
:2 0 e :3 0 2d
:3 0 f :2 0 acb
1504 1507 19d :2 0
f :2 0 ad0 1509
150b :3 0 150c :2 0
1503 150e 150d :2 0
3f :3 0 b0 :3 0
2d :3 0 3d :3 0
20 :4 0 19e 1
:8 0 152b c1 :4 0
1516 :3 0 c2 :3 0
7a :2 0 ad5 1519
151a :3 0 4b :3 0
6d :3 0 151c 151d
0 f :2 0 151e
151f 0 1521 ad8
1528 4b :3 0 6d
:3 0 1522 1523 0
c3 :2 0 1524 1525
0 1527 ada 1529
151b 1521 0 152a
0 1527 0 152a
adc 0 152b adf
157e 6f :3 0 4b
:3 0 6d :3 0 152d
152e 0 6e :3 0
152f 1530 0 1532
ae2 1534 ae4 1533
1532 :2 0 157c 70
:3 0 4b :3 0 6d
:3 0 1537 1538 0
6e :3 0 1539 153a
0 1574 55 :3 0
56 :3 0 153c 153d
0 55 :3 0 65
:3 0 153f 1540 0
71 :2 0 2 :4 0
19f :2 0 67 :2 0
a :2 0 ae6 1545
1547 :3 0 ae9 1541
1549 153e 154b 154a
:2 0 58 :3 0 68
:3 0 154d 154e 0
5a :4 0 1a0 :4 0
5d :2 0 5e :3 0
aed 1552 1554 :3 0
5d :2 0 74 :4 0
af0 1556 1558 :3 0
5d :2 0 75 :4 0
af3 155a 155c :3 0
5d :2 0 6e :3 0
af6 155e 1560 :3 0
5d :2 0 76 :4 0
af9 1562 1564 :3 0
5d :2 0 77 :3 0
78 :3 0 a :2 0
79 :2 0 afc 1567
156b b00 1566 156d
:3 0 b03 154f 156f
:2 0 1571 b06 1572
154c 1571 0 1573
b08 0 1574 b0a
1577 :3 0 1577 0
1577 1576 1574 1575
:6 0 1579 4b :3 0
b0d 157b b0f 157a
1579 :2 0 157c b11
:2 0 157e 0 157e
157d 152b 157c :6 0
1580 22 :3 0 b14
1581 150f 1580 0
1582 b16 0 170b
2e :3 0 d6 :2 0
1583 1584 0 170b
2f :3 0 194 :3 0
16 :3 0 20 :3 0
2e :3 0 f :2 0
f :2 0 f :2 0
b18 1587 158e 1586
158f 0 170b 48
:3 0 1a1 :3 0 da
:3 0 dc :3 0 ae
:3 0 a7 :3 0 a9
:3 0 20 :3 0 24
:3 0 21 :3 0 23
:3 0 25 :3 0 30
:3 0 33 :3 0 3f
:3 0 3d :3 0 20
:4 0 1a2 1 :8 0
15a8 4b :3 0 6d
:3 0 15a3 15a4 0
6e :3 0 15a5 15a6
0 15a8 b1f 15fb
6f :3 0 4b :3 0
6d :3 0 15aa 15ab
0 6e :3 0 15ac
15ad 0 15af b22
15b1 b24 15b0 15af
:2 0 15f9 70 :3 0
4b :3 0 6d :3 0
15b4 15b5 0 6e
:3 0 15b6 15b7 0
15f1 55 :3 0 56
:3 0 15b9 15ba 0
55 :3 0 65 :3 0
15bc 15bd 0 71
:2 0 2 :4 0 1a3
:2 0 67 :2 0 a
:2 0 b26 15c2 15c4
:3 0 b29 15be 15c6
15bb 15c8 15c7 :2 0
58 :3 0 68 :3 0
15ca 15cb 0 5a
:4 0 1a4 :4 0 5d
:2 0 5e :3 0 b2d
15cf 15d1 :3 0 5d
:2 0 74 :4 0 b30
15d3 15d5 :3 0 5d
:2 0 75 :4 0 b33
15d7 15d9 :3 0 5d
:2 0 6e :3 0 b36
15db 15dd :3 0 5d
:2 0 76 :4 0 b39
15df 15e1 :3 0 5d
:2 0 77 :3 0 78
:3 0 a :2 0 79
:2 0 b3c 15e4 15e8
b40 15e3 15ea :3 0
b43 15cc 15ec :2 0
15ee b46 15ef 15c9
15ee 0 15f0 b48
0 15f1 b4a 15f4
:3 0 15f4 0 15f4
15f3 15f1 15f2 :6 0
15f6 4d :3 0 b4d
15f8 b4f 15f7 15f6
:2 0 15f9 b51 :2 0
15fb 0 15fb 15fa
15a8 15f9 :6 0 170b
22 :3 0 e :3 0
25 :3 0 f :2 0
b54 15fd 1600 7a
:2 0 f :2 0 b59
1602 1604 :3 0 140
:3 0 145 :3 0 14a
:3 0 14f :3 0 154
:3 0 159 :3 0 144
:3 0 21 :3 0 149
:3 0 23 :3 0 14e
:3 0 24 :3 0 153
:3 0 24 :3 0 30
:3 0 158 :3 0 43
:3 0 16 :3 0 3e
:3 0 1d :4 0 1a5
1 :8 0 1630 c1
:4 0 161b :3 0 c2
:3 0 7a :2 0 b5e
161e 161f :3 0 4b
:3 0 6d :3 0 1621
1622 0 f :2 0
1623 1624 0 1626
b61 162d 4b :3 0
6d :3 0 1627 1628
0 c3 :2 0 1629
162a 0 162c b63
162e 1620 1626 0
162f 0 162c 0
162f b65 0 1630
b68 1683 6f :3 0
4b :3 0 6d :3 0
1632 1633 0 6e
:3 0 1634 1635 0
1637 b6b 1639 b6d
1638 1637 :2 0 1681
70 :3 0 4b :3 0
6d :3 0 163c 163d
0 6e :3 0 163e
163f 0 1679 55
:3 0 56 :3 0 1641
1642 0 55 :3 0
65 :3 0 1644 1645
0 71 :2 0 2
:4 0 1a6 :2 0 67
:2 0 a :2 0 b6f
164a 164c :3 0 b72
1646 164e 1643 1650
164f :2 0 58 :3 0
68 :3 0 1652 1653
0 5a :4 0 1a7
:4 0 5d :2 0 5e
:3 0 b76 1657 1659
:3 0 5d :2 0 74
:4 0 b79 165b 165d
:3 0 5d :2 0 75
:4 0 b7c 165f 1661
:3 0 5d :2 0 6e
:3 0 b7f 1663 1665
:3 0 5d :2 0 76
:4 0 b82 1667 1669
:3 0 5d :2 0 77
:3 0 78 :3 0 a
:2 0 79 :2 0 b85
166c 1670 b89 166b
1672 :3 0 b8c 1654
1674 :2 0 1676 b8f
1677 1651 1676 0
1678 b91 0 1679
b93 167c :3 0 167c
0 167c 167b 1679
167a :6 0 167e 4f
:3 0 b96 1680 b98
167f 167e :2 0 1681
b9a :2 0 1683 0
1683 1682 1630 1681
:6 0 1685 22 :3 0
b9d 1708 140 :3 0
145 :3 0 14a :3 0
14f :3 0 154 :3 0
159 :3 0 144 :3 0
21 :3 0 149 :3 0
23 :3 0 14e :3 0
24 :3 0 153 :3 0
24 :3 0 30 :3 0
158 :3 0 24 :3 0
33 :3 0 43 :3 0
16 :3 0 3e :3 0
1d :4 0 1a8 1
:8 0 16b2 c1 :4 0
169d :3 0 c2 :3 0
7a :2 0 ba1 16a0
16a1 :3 0 4b :3 0
6d :3 0 16a3 16a4
0 f :2 0 16a5
16a6 0 16a8 ba4
16af 4b :3 0 6d
:3 0 16a9 16aa 0
c3 :2 0 16ab 16ac
0 16ae ba6 16b0
16a2 16a8 0 16b1
0 16ae 0 16b1
ba8 0 16b2 bab
1705 6f :3 0 4b
:3 0 6d :3 0 16b4
16b5 0 6e :3 0
16b6 16b7 0 16b9
bae 16bb bb0 16ba
16b9 :2 0 1703 70
:3 0 4b :3 0 6d
:3 0 16be 16bf 0
6e :3 0 16c0 16c1
0 16fb 55 :3 0
56 :3 0 16c3 16c4
0 55 :3 0 65
:3 0 16c6 16c7 0
71 :2 0 2 :4 0
1a9 :2 0 67 :2 0
a :2 0 bb2 16cc
16ce :3 0 bb5 16c8
16d0 16c5 16d2 16d1
:2 0 58 :3 0 68
:3 0 16d4 16d5 0
5a :4 0 1aa :4 0
5d :2 0 5e :3 0
bb9 16d9 16db :3 0
5d :2 0 74 :4 0
bbc 16dd 16df :3 0
5d :2 0 75 :4 0
bbf 16e1 16e3 :3 0
5d :2 0 6e :3 0
bc2 16e5 16e7 :3 0
5d :2 0 76 :4 0
bc5 16e9 16eb :3 0
5d :2 0 77 :3 0
78 :3 0 a :2 0
79 :2 0 bc8 16ee
16f2 bcc 16ed 16f4
:3 0 bcf 16d6 16f6
:2 0 16f8 bd2 16f9
16d3 16f8 0 16fa
bd4 0 16fb bd6
16fe :3 0 16fe 0
16fe 16fd 16fb 16fc
:6 0 1700 51 :3 0
bd9 1702 bdb 1701
1700 :2 0 1703 bdd
:2 0 1705 0 1705
1704 16b2 1703 :6 0
1707 22 :3 0 be0
1709 1605 1685 0
170a 0 1707 0
170a be2 0 170b
be5 170d 129c 1359
0 170e 0 170b
0 170e bee 0
1713 167 :5 0 1711
53 0 1712 bf1
1711 1710 1713 bf3
1715 bff 1714 1713
:2 0 1719 0 1717
c01 1718 0 1717
:2 0 1719 c03 :2 0
171a aec 1719 0
178c 0 41 :3 0
112 :3 0 13 :3 0
113 :3 0 44 :3 0
1e :4 0 198 1
:8 0 1737 c1 :4 0
1722 :3 0 c2 :3 0
7a :2 0 c09 1725
1726 :3 0 4b :3 0
6d :3 0 1728 1729
0 f :2 0 172a
172b 0 172d c0c
1734 4b :3 0 6d
:3 0 172e 172f 0
c3 :2 0 1730 1731
0 1733 c0e 1735
1727 172d 0 1736
0 1733 0 1736
c10 0 1737 c13
178a 6f :3 0 4b
:3 0 6d :3 0 1739
173a 0 6e :3 0
173b 173c 0 173e
c16 1740 c18 173f
173e :2 0 1788 70
:3 0 4b :3 0 6d
:3 0 1743 1744 0
6e :3 0 1745 1746
0 1780 55 :3 0
56 :3 0 1748 1749
0 55 :3 0 65
:3 0 174b 174c 0
71 :2 0 2 :4 0
1ab :2 0 67 :2 0
a :2 0 c1a 1751
1753 :3 0 c1d 174d
1755 174a 1757 1756
:2 0 58 :3 0 68
:3 0 1759 175a 0
5a :4 0 1ac :4 0
5d :2 0 5e :3 0
c21 175e 1760 :3 0
5d :2 0 74 :4 0
c24 1762 1764 :3 0
5d :2 0 75 :4 0
c27 1766 1768 :3 0
5d :2 0 6e :3 0
c2a 176a 176c :3 0
5d :2 0 76 :4 0
c2d 176e 1770 :3 0
5d :2 0 77 :3 0
78 :3 0 a :2 0
79 :2 0 c30 1773
1777 c34 1772 1779
:3 0 c37 175b 177b
:2 0 177d c3a 177e
1758 177d 0 177f
c3c 0 1780 c3e
1783 :3 0 1783 0
1783 1782 1780 1781
:6 0 1785 53 :3 0
c41 1787 c43 1786
1785 :2 0 1788 c45
:2 0 178a 0 178a
1789 1737 1788 :6 0
178c 22 :3 0 c48
178e fd :4 0 178c
:4 0 1932 10f :3 0
4a :4 0 1792 :2 0
1798 1790 0 4b
:3 0 6d :3 0 1793
1794 0 6e :3 0
1795 1796 0 1798
c4e 17eb 6f :3 0
4b :3 0 6d :3 0
179a 179b 0 6e
:3 0 179c 179d 0
179f c51 17a1 c53
17a0 179f :2 0 17e9
70 :3 0 4b :3 0
6d :3 0 17a4 17a5
0 6e :3 0 17a6
17a7 0 17e1 55
:3 0 56 :3 0 17a9
17aa 0 55 :3 0
65 :3 0 17ac 17ad
0 71 :2 0 2
:4 0 1ad :2 0 67
:2 0 a :2 0 c55
17b2 17b4 :3 0 c58
17ae 17b6 17ab 17b8
17b7 :2 0 58 :3 0
68 :3 0 17ba 17bb
0 5a :4 0 1ae
:4 0 5d :2 0 5e
:3 0 c5c 17bf 17c1
:3 0 5d :2 0 74
:4 0 c5f 17c3 17c5
:3 0 5d :2 0 75
:4 0 c62 17c7 17c9
:3 0 5d :2 0 6e
:3 0 c65 17cb 17cd
:3 0 5d :2 0 76
:4 0 c68 17cf 17d1
:3 0 5d :2 0 77
:3 0 78 :3 0 a
:2 0 79 :2 0 c6b
17d4 17d8 c6f 17d3
17da :3 0 c72 17bc
17dc :2 0 17de c75
17df 17b9 17de 0
17e0 c77 0 17e1
c79 17e4 :3 0 17e4
0 17e4 17e3 17e1
17e2 :6 0 17e6 55
:3 0 c7c 17e8 c7e
17e7 17e6 :2 0 17e9
c80 :2 0 17eb 0
17eb 17ea 1798 17e9
:6 0 1932 1 :3 0
d :3 0 7a :2 0
a :2 0 c85 17ee
17f0 :3 0 2f :3 0
1af :3 0 16 :3 0
c88 17f3 17f5 17f2
17f6 0 17f8 c8a
17f9 17f1 17f8 0
17fa c8c 0 1932
18d :3 0 13 :3 0
1b0 :3 0 18f :3 0
13 :3 0 1b1 :3 0
d7 :3 0 13 :3 0
d8 :3 0 29 :3 0
41 :3 0 44 :3 0
16 :4 0 1b2 1
:8 0 180e 4b :3 0
6d :3 0 1809 180a
0 6e :3 0 180b
180c 0 180e c8e
1861 6f :3 0 4b
:3 0 6d :3 0 1810
1811 0 6e :3 0
1812 1813 0 1815
c91 1817 c93 1816
1815 :2 0 185f 70
:3 0 4b :3 0 6d
:3 0 181a 181b 0
6e :3 0 181c 181d
0 1857 55 :3 0
56 :3 0 181f 1820
0 55 :3 0 65
:3 0 1822 1823 0
71 :2 0 2 :4 0
1b3 :2 0 67 :2 0
a :2 0 c95 1828
182a :3 0 c98 1824
182c 1821 182e 182d
:2 0 58 :3 0 68
:3 0 1830 1831 0
5a :4 0 1b4 :4 0
5d :2 0 5e :3 0
c9c 1835 1837 :3 0
5d :2 0 74 :4 0
c9f 1839 183b :3 0
5d :2 0 75 :4 0
ca2 183d 183f :3 0
5d :2 0 6e :3 0
ca5 1841 1843 :3 0
5d :2 0 76 :4 0
ca8 1845 1847 :3 0
5d :2 0 77 :3 0
78 :3 0 a :2 0
79 :2 0 cab 184a
184e caf 1849 1850
:3 0 cb2 1832 1852
:2 0 1854 cb5 1855
182f 1854 0 1856
cb7 0 1857 cb9
185a :3 0 185a 0
185a 1859 1857 1858
:6 0 185c 57 :3 0
cbc 185e cbe 185d
185c :2 0 185f cc0
:2 0 1861 0 1861
1860 180e 185f :6 0
1932 1 :3 0 e
:3 0 29 :3 0 f
:2 0 cc3 1863 1866
7a :2 0 a :2 0
cc8 1868 186a :3 0
2a :3 0 13 :3 0
d8 :3 0 186d 186e
0 186c 186f 0
187b 4b :3 0 6d
:3 0 1871 1872 0
1b5 :3 0 16 :3 0
29 :3 0 2a :3 0
ccb 1874 1878 1873
1879 0 187b ccf
187c 186b 187b 0
187d cd2 0 1932
89 :3 0 1b6 :3 0
d7 :3 0 41 :3 0
44 :3 0 16 :3 0
44 :3 0 16 :4 0
1b7 1 :8 0 189c
c1 :4 0 1887 :3 0
c2 :3 0 7a :2 0
cd6 188a 188b :3 0
4b :3 0 6d :3 0
188d 188e 0 f
:2 0 188f 1890 0
1892 cd9 1899 4b
:3 0 6d :3 0 1893
1894 0 c3 :2 0
1895 1896 0 1898
cdb 189a 188c 1892
0 189b 0 1898
0 189b cdd 0
189c ce0 18ef 6f
:3 0 4b :3 0 6d
:3 0 189e 189f 0
6e :3 0 18a0 18a1
0 18a3 ce3 18a5
ce5 18a4 18a3 :2 0
18ed 70 :3 0 4b
:3 0 6d :3 0 18a8
18a9 0 6e :3 0
18aa 18ab 0 18e5
55 :3 0 56 :3 0
18ad 18ae 0 55
:3 0 65 :3 0 18b0
18b1 0 71 :2 0
2 :4 0 1b8 :2 0
67 :2 0 a :2 0
ce7 18b6 18b8 :3 0
cea 18b2 18ba 18af
18bc 18bb :2 0 58
:3 0 68 :3 0 18be
18bf 0 5a :4 0
1b9 :4 0 5d :2 0
5e :3 0 cee 18c3
18c5 :3 0 5d :2 0
74 :4 0 cf1 18c7
18c9 :3 0 5d :2 0
75 :4 0 cf4 18cb
18cd :3 0 5d :2 0
6e :3 0 cf7 18cf
18d1 :3 0 5d :2 0
76 :4 0 cfa 18d3
18d5 :3 0 5d :2 0
77 :3 0 78 :3 0
a :2 0 79 :2 0
cfd 18d8 18dc d01
18d7 18de :3 0 d04
18c0 18e0 :2 0 18e2
d07 18e3 18bd 18e2
0 18e4 d09 0
18e5 d0b 18e8 :3 0
18e8 0 18e8 18e7
18e5 18e6 :6 0 18ea
59 :3 0 d0e 18ec
d10 18eb 18ea :2 0
18ed d12 :2 0 18ef
0 18ef 18ee 189c
18ed :6 0 1932 1
:3 0 4b :3 0 6d
:3 0 18f1 18f2 0
7a :2 0 c3 :2 0
d17 18f4 18f6 :3 0
4b :3 0 6d :3 0
18f8 18f9 0 f
:2 0 18fa 18fb 0
18fd d1a 18fe 18f7
18fd 0 18ff d1c
0 1932 55 :3 0
56 :3 0 1900 1901
0 55 :3 0 65
:3 0 1903 1904 0
a :2 0 2 :4 0
1ba :2 0 67 :2 0
a :2 0 d1e 1909
190b :3 0 d21 1905
190d 1902 190f 190e
:2 0 58 :3 0 68
:3 0 1911 1912 0
5a :4 0 1bb :4 0
5d :2 0 5e :3 0
d25 1916 1918 :3 0
5d :2 0 74 :4 0
d28 191a 191c :3 0
5d :2 0 7e :4 0
d2b 191e 1920 :3 0
5d :2 0 4b :3 0
6d :3 0 1923 1924
0 d2e 1922 1926
:3 0 d31 1913 1928
:2 0 192a d34 192b
1910 192a 0 192c
d36 0 1932 b
:3 0 4b :3 0 6d
:3 0 192e 192f 0
1930 :2 0 1932 d38
1935 :3 0 1935 d48
1935 1934 1932 1933
:6 0 1936 :2 0 2
15 1935 1939 :3 0
1938 1936 193a :8 0

d6e
4
:3 0 1 3 1
9 1 d 3
8 c 11 1
17 2 21 22
1 1d 1 29
1 27 1 33
1 31 1 3d
1 3b 1 44
1 42 1 4b
1 49 1 52
1 50 1 57
1 5e 1 5c
1 65 1 63
1 6c 1 6a
1 73 1 71
1 78 1 7d
1 82 1 88
1 8e 1 94
1 9a 1 a0
1 a6 1 ac
1 b2 1 b8
1 be 1 c4
1 ca 1 d0
1 d8 1 d6
1 df 1 dd
1 e4 1 e9
1 10e 1 114
1 129 1 13a
1 146 1 152
2 155 157 2
15a 15c 2 15e
160 2 162 164
2 166 168 1
16e 2 170 171
2 16a 173 2
175 177 1 17d
2 17f 180 2
179 182 2 184
186 4 14e 154
159 188 1 18a
1 18c 2 196
198 3 194 195
19a 2 1a3 1a5
2 1a2 1a7 1
1a9 1 1ab 2
1b5 1ba 1 1c1
1 1bc 2 1d4
1d6 3 1d2 1d3
1d8 2 1e1 1e3
2 1e5 1e7 2
1e9 1eb 2 1ed
1ef 2 1f1 1f3
3 1f8 1f9 1fa
2 1f5 1fc 2
1e0 1fe 1 200
1 202 2 1cb
203 1 207 1
1c6 2 1c4 20b
3 211 212 213
1 217 2 215
217 2 222 224
3 220 221 226
2 22f 231 2
233 235 2 237
239 1 241 2
243 244 2 23b
246 2 248 24a
2 24c 24e 2
250 252 2 254
256 2 22e 258
1 25a 1 25c
2 266 268 3
264 265 26a 2
273 275 2 272
277 1 279 1
27b 3 283 284
285 3 25d 27c
288 1 28a 1
292 2 28e 292
2 2b9 2be 1
2c5 1 2c0 2
2d8 2da 3 2d6
2d7 2dc 2 2e5
2e7 2 2e9 2eb
2 2ed 2ef 2
2f1 2f3 2 2f5
2f7 3 2fc 2fd
2fe 2 2f9 300
2 2e4 302 1
304 1 306 2
2cf 307 1 30b
1 2ca 2 2c8
30f 1 31a 2
316 31a 2 326
328 3 324 325
32a 2 333 335
2 337 339 2
33b 33d 1 345
2 347 348 2
33f 34a 2 332
34c 1 34e 1
350 2 35a 35c
3 358 359 35e
2 367 369 2
366 36b 1 36d
1 36f 2 377
378 3 351 370
37b 2 37f 380
1 384 2 382
384 2 388 389
1 38d 2 38b
38d 2 39a 39c
3 398 399 39e
2 3a7 3a9 2
3ab 3ad 2 3af
3b1 1 3b9 2
3bb 3bc 2 3b3
3be 2 3c0 3c2
2 3c4 3c6 2
3c8 3ca 2 3cc
3ce 2 3a6 3d0
1 3d2 1 3d4
2 3de 3e0 3
3dc 3dd 3e2 2
3eb 3ed 2 3ea
3ef 1 3f1 1
3f3 3 3fb 3fc
3fd 3 3d5 3f4
400 2 403 402
2 406 407 1
40b 2 409 40b
1 415 3 412
418 41d 1 420
2 435 43a 1
441 1 43c 2
454 456 3 452
453 458 2 461
463 2 465 467
2 469 46b 2
46d 46f 2 471
473 3 478 479
47a 2 475 47c
2 460 47e 1
480 1 482 2
44b 483 1 487
1 446 2 444
48b 1 490 2
499 49e 1 4a5
1 4a0 2 4b8
4ba 3 4b6 4b7
4bc 2 4c5 4c7
2 4c9 4cb 2
4cd 4cf 2 4d1
4d3 2 4d5 4d7
3 4dc 4dd 4de
2 4d9 4e0 2
4c4 4e2 1 4e4
1 4e6 2 4af
4e7 1 4eb 1
4aa 2 4a8 4ef
1 4fa 2 4f6
4fa 1 53e 2
53d 53e 1 546
1 54c 2 54e
54f 2 53b 550
1 557 1 552
2 56a 56c 3
568 569 56e 2
577 579 2 57b
57d 2 57f 581
2 583 585 2
587 589 3 58e
58f 590 2 58b
592 2 576 594
1 596 1 598
2 561 599 1
59d 1 55c 2
55a 5a1 1 5a4
1 5ec 2 5eb
5ec 1 5f4 1
5fa 2 5fc 5fd
2 5e9 5fe 1
605 1 600 2
618 61a 3 616
617 61c 2 625
627 2 629 62b
2 62d 62f 2
631 633 2 635
637 3 63c 63d
63e 2 639 640
2 624 642 1
644 1 646 2
60f 647 1 64b
1 60a 2 608
64f 1 652 2
655 656 1 65e
2 65d 65e 1
666 1 66c 2
66e 66f 2 65b
670 1 677 1
672 2 68a 68c
3 688 689 68e
2 697 699 2
69b 69d 2 69f
6a1 2 6a3 6a5
2 6a7 6a9 3
6ae 6af 6b0 2
6ab 6b2 2 696
6b4 1 6b6 1
6b8 2 681 6b9
1 6bd 1 67c
2 67a 6c1 2
6cd 6ce 1 6dd
2 6dc 6dd 1
6e5 1 6eb 2
6ed 6ee 2 6da
6ef 1 6f6 1
6f1 2 709 70b
3 707 708 70d
2 716 718 2
71a 71c 2 71e
720 2 722 724
2 726 728 3
72d 72e 72f 2
72a 731 2 715
733 1 735 1
737 2 700 738
1 73c 1 6fb
2 6f9 740 7
4f2 657 6c4 6ca
6d1 6d6 743 1
746 3 427 48e
747 2 74a 749
2 752 757 1
75e 1 759 2
771 773 3 76f
770 775 2 77e
780 2 782 784
2 786 788 2
78a 78c 2 78e
790 3 795 796
797 2 792 799
2 77d 79b 1
79d 1 79f 2
768 7a0 1 7a4
1 763 2 761
7a8 2 7ae 7b0
2 7b2 7b4 2
7b6 7b8 5 312
404 74b 7ab 7bb
2 7c1 7c2 1
7c6 2 7c4 7c6
1 7d0 1 822
2 821 822 1
82a 1 830 2
832 833 2 81f
834 1 83b 1
836 2 84e 850
3 84c 84d 852
2 85b 85d 2
85f 861 2 863
865 2 867 869
2 86b 86d 3
872 873 874 2
86f 876 2 85a
878 1 87a 1
87c 2 845 87d
1 881 1 840
2 83e 885 2
891 892 1 89d
1 8a3 2 8a5
8a6 1 8ae 2
8aa 8ae 1 8b3
1 8b5 1 8f3
2 8f2 8f3 1
8fb 1 901 2
903 904 2 8f0
905 1 90c 1
907 2 91f 921
3 91d 91e 923
2 92c 92e 2
930 932 2 934
936 2 938 93a
2 93c 93e 3
943 944 945 2
940 947 2 92b
949 1 94b 1
94d 2 916 94e
1 952 1 911
2 90f 956 1
964 2 963 964
1 96c 1 972
2 974 975 2
961 976 1 97d
1 978 2 990
992 3 98e 98f
994 2 99d 99f
2 9a1 9a3 2
9a5 9a7 2 9a9
9ab 2 9ad 9af
3 9b4 9b5 9b6
2 9b1 9b8 2
99c 9ba 1 9bc
1 9be 2 987
9bf 1 9c3 1
982 2 980 9c7
5 893 8a7 8b6
959 9ca 2 9d1
9d7 1 9de 1
9d9 2 9f1 9f3
3 9ef 9f0 9f5
2 9fe a00 2
a02 a04 2 a06
a08 2 a0a a0c
2 a0e a10 3
a15 a16 a17 2
a12 a19 2 9fd
a1b 1 a1d 1
a1f 2 9e8 a20
1 a24 1 9e3
2 9e1 a28 7
7cd 7d3 7d8 888
88c 9ce a2b 1
a2e 1 a3c 2
a3b a3c 1 a44
1 a4a 2 a4c
a4d 2 a39 a4e
1 a55 1 a50
2 a68 a6a 3
a66 a67 a6c 2
a75 a77 2 a79
a7b 2 a7d a7f
2 a81 a83 2
a85 a87 3 a8c
a8d a8e 2 a89
a90 2 a74 a92
1 a94 1 a96
2 a5f a97 1
a9b 1 a5a 2
a58 a9f 2 aab
aad 2 aaf ab1
2 ab3 ab5 6
7bf a2f aa2 aa6
aa9 ab8 2 aba
abb 4 ac4 ac5
ac6 ac7 1 ad2
1 ad8 2 ada
adb 1 ae3 2
adf ae3 1 ae8
1 aea 1 b0f
2 b0e b0f 1
b17 1 b1d 2
b1f b20 2 b0c
b21 1 b28 1
b23 2 b3b b3d
3 b39 b3a b3f
2 b48 b4a 2
b4c b4e 2 b50
b52 2 b54 b56
2 b58 b5a 3
b5f b60 b61 2
b5c b63 2 b47
b65 1 b67 1
b69 2 b32 b6a
1 b6e 1 b2d
2 b2b b72 1
bbb 2 bba bbb
1 bc3 1 bc9
2 bcb bcc 2
bb8 bcd 1 bd4
1 bcf 2 be7
be9 3 be5 be6
beb 2 bf4 bf6
2 bf8 bfa 2
bfc bfe 2 c00
c02 2 c04 c06
3 c0b c0c c0d
2 c08 c0f 2
bf3 c11 1 c13
1 c15 2 bde
c16 1 c1a 1
bd9 2 bd7 c1e
1 c60 2 c5f
c60 1 c68 1
c6e 2 c70 c71
2 c5d c72 1
c79 1 c74 2
c8c c8e 3 c8a
c8b c90 2 c99
c9b 2 c9d c9f
2 ca1 ca3 2
ca5 ca7 2 ca9
cab 3 cb0 cb1
cb2 2 cad cb4
2 c98 cb6 1
cb8 1 cba 2
c83 cbb 1 cbf
1 c7e 2 c7c
cc3 3 b75 c21
cc6 1 aed 2
cd2 cd7 1 cde
1 cd9 2 cf1
cf3 3 cef cf0
cf5 2 cfe d00
2 d02 d04 2
d06 d08 2 d0a
d0c 2 d0e d10
3 d15 d16 d17
2 d12 d19 2
cfd d1b 1 d1d
1 d1f 2 ce8
d20 1 d24 1
ce3 2 ce1 d28
1 d33 2 d2f
d33 1 d37 1
d40 1 d42 2
d50 d55 1 d5c
1 d57 2 d6f
d71 3 d6d d6e
d73 2 d7c d7e
2 d80 d82 2
d84 d86 2 d88
d8a 2 d8c d8e
3 d93 d94 d95
2 d90 d97 2
d7b d99 1 d9b
1 d9d 2 d66
d9e 1 da2 1
d61 2 d5f da6
1 db1 2 dad
db1 1 db5 2
dbe dbf 1 dc3
2 dc1 dc3 1
dc8 1 dd0 2
dcf dd0 1 dd8
1 dde 2 de0
de1 2 dcd de2
1 de9 1 de4
2 dfc dfe 3
dfa dfb e00 2
e09 e0b 2 e0d
e0f 2 e11 e13
2 e15 e17 2
e19 e1b 3 e20
e21 e22 2 e1d
e24 2 e08 e26
1 e28 1 e2a
2 df3 e2b 1
e2f 1 dee 2
dec e33 1 e3e
2 e3d e3e 1
e46 1 e4c 2
e4e e4f 2 e3b
e50 1 e57 1
e52 2 e6a e6c
3 e68 e69 e6e
2 e77 e79 2
e7b e7d 2 e7f
e81 2 e83 e85
2 e87 e89 3
e8e e8f e90 2
e8b e92 2 e76
e94 1 e96 1
e98 2 e61 e99
1 e9d 1 e5c
2 e5a ea1 1
eac 2 eab eac
1 eb4 1 eba
2 ebc ebd 2
ea9 ebe 1 ec5
1 ec0 2 ed8
eda 3 ed6 ed7
edc 2 ee5 ee7
2 ee9 eeb 2
eed eef 2 ef1
ef3 2 ef5 ef7
3 efc efd efe
2 ef9 f00 2
ee4 f02 1 f04
1 f06 2 ecf
f07 1 f0b 1
eca 2 ec8 f0f
1 f1a 2 f19
f1a 1 f22 1
f28 2 f2a f2b
2 f17 f2c 1
f33 1 f2e 2
f46 f48 3 f44
f45 f4a 2 f53
f55 2 f57 f59
2 f5b f5d 2
f5f f61 2 f63
f65 3 f6a f6b
f6c 2 f67 f6e
2 f52 f70 1
f72 1 f74 2
f3d f75 1 f79
1 f38 2 f36
f7d 5 e36 ea4
f12 f80 f84 2
f86 f87 1 f88
2 f8c f8f 2
f91 f92 3 f9e
f9f fa0 1 fab
1 fb1 2 fb3
fb4 1 fbc 2
fb8 fbc 1 fc1
1 fc3 2 fc6
fc7 1 fcb 2
fc9 fcb 1 fe0
2 fdf fe0 1
fe8 1 fee 2
ff0 ff1 2 fdd
ff2 1 ff9 1
ff4 2 100c 100e
3 100a 100b 1010
2 1019 101b 2
101d 101f 2 1021
1023 2 1025 1027
2 1029 102b 3
1030 1031 1032 2
102d 1034 2 1018
1036 1 1038 1
103a 2 1003 103b
1 103f 1 ffe
2 ffc 1043 1
104e 2 104a 104e
1 105c 2 105b
105c 1 1064 1
106a 2 106c 106d
2 1059 106e 1
1075 1 1070 2
1088 108a 3 1086
1087 108c 2 1095
1097 2 1099 109b
2 109d 109f 2
10a1 10a3 2 10a5
10a7 3 10ac 10ad
10ae 2 10a9 10b0
2 1094 10b2 1
10b4 1 10b6 2
107f 10b7 1 10bb
1 107a 2 1078
10bf 1 10c2 1
10d1 2 10d0 10d1
1 10d9 1 10df
2 10e1 10e2 2
10ce 10e3 1 10ea
1 10e5 2 10fd
10ff 3 10fb 10fc
1101 2 110a 110c
2 110e 1110 2
1112 1114 2 1116
1118 2 111a 111c
3 1121 1122 1123
2 111e 1125 2
1109 1127 1 1129
1 112b 2 10f4
112c 1 1130 1
10ef 2 10ed 1134
1 1137 2 113a
113b 2 1046 113c
2 1140 1141 1
1145 2 1143 1145
1 1154 2 1153
1154 1 115c 1
1162 2 1164 1165
2 1151 1166 1
116d 1 1168 2
1180 1182 3 117e
117f 1184 2 118d
118f 2 1191 1193
2 1195 1197 2
1199 119b 2 119d
119f 3 11a4 11a5
11a6 2 11a1 11a8
2 118c 11aa 1
11ac 1 11ae 2
1177 11af 1 11b3
1 1172 2 1170
11b7 1 11ba 2
11be 11bd 4 fa1
fb5 fc4 11bf 2
11c5 11cb 1 11d2
1 11cd 2 11e5
11e7 3 11e3 11e4
11e9 2 11f2 11f4
2 11f6 11f8 2
11fa 11fc 2 11fe
1200 2 1202 1204
3 1209 120a 120b
2 1206 120d 2
11f1 120f 1 1211
1 1213 2 11dc
1214 1 1218 1
11d7 2 11d5 121c
1 122c 2 122b
122c 1 1234 1
123a 2 123c 123d
2 1229 123e 1
1245 1 1240 2
1258 125a 3 1256
1257 125c 2 1265
1267 2 1269 126b
2 126d 126f 2
1271 1273 2 1275
1277 3 127c 127d
127e 2 1279 1280
2 1264 1282 1
1284 1 1286 2
124f 1287 1 128b
1 124a 2 1248
128f 2 1295 1296
1 129a 2 1298
129a 1 12d7 2
12d6 12d7 1 12df
1 12e5 2 12e7
12e8 2 12d4 12e9
1 12f0 1 12eb
2 1303 1305 3
1301 1302 1307 2
1310 1312 2 1314
1316 2 1318 131a
2 131c 131e 2
1320 1322 3 1327
1328 1329 2 1324
132b 2 130f 132d
1 132f 1 1331
2 12fa 1332 1
1336 1 12f5 2
12f3 133a 2 1340
1341 1 1345 2
1343 1345 6 134d
134e 134f 1350 1351
1352 2 134a 1355
1 1357 2 133d
1358 2 1361 1362
1 136d 1 1373
2 1375 1376 1
137e 2 137a 137e
1 1383 1 1385
1 13c0 2 13bf
13c0 1 13c8 1
13ce 2 13d0 13d1
2 13bd 13d2 1
13d9 1 13d4 2
13ec 13ee 3 13ea
13eb 13f0 2 13f9
13fb 2 13fd 13ff
2 1401 1403 2
1405 1407 2 1409
140b 3 1410 1411
1412 2 140d 1414
2 13f8 1416 1
1418 1 141a 2
13e3 141b 1 141f
1 13de 2 13dc
1423 1 1431 2
1430 1431 1 1439
1 143f 2 1441
1442 2 142e 1443
1 144a 1 1445
2 145d 145f 3
145b 145c 1461 2
146a 146c 2 146e
1470 2 1472 1474
2 1476 1478 2
147a 147c 3 1481
1482 1483 2 147e
1485 2 1469 1487
1 1489 1 148b
2 1454 148c 1
1490 1 144f 2
144d 1494 5 1363
1377 1386 1426 1497
2 149e 14a4 1
14ab 1 14a6 2
14be 14c0 3 14bc
14bd 14c2 2 14cb
14cd 2 14cf 14d1
2 14d3 14d5 2
14d7 14d9 2 14db
14dd 3 14e2 14e3
14e4 2 14df 14e6
2 14ca 14e8 1
14ea 1 14ec 2
14b5 14ed 1 14f1
1 14b0 2 14ae
14f5 2 14fb 14fc
1 1500 2 14fe
1500 2 1505 1506
1 150a 2 1508
150a 1 1518 2
1517 1518 1 1520
1 1526 2 1528
1529 2 1515 152a
1 1531 1 152c
2 1544 1546 3
1542 1543 1548 2
1551 1553 2 1555
1557 2 1559 155b
2 155d 155f 2
1561 1563 3 1568
1569 156a 2 1565
156c 2 1550 156e
1 1570 1 1572
2 153b 1573 1
1577 1 1536 2
1534 157b 1 157e
1 1581 6 1588
1589 158a 158b 158c
158d 2 15a2 15a7
1 15ae 1 15a9
2 15c1 15c3 3
15bf 15c0 15c5 2
15ce 15d0 2 15d2
15d4 2 15d6 15d8
2 15da 15dc 2
15de 15e0 3 15e5
15e6 15e7 2 15e2
15e9 2 15cd 15eb
1 15ed 1 15ef
2 15b8 15f0 1
15f4 1 15b3 2
15b1 15f8 2 15fe
15ff 1 1603 2
1601 1603 1 161d
2 161c 161d 1
1625 1 162b 2
162d 162e 2 161a
162f 1 1636 1
1631 2 1649 164b
3 1647 1648 164d
2 1656 1658 2
165a 165c 2 165e
1660 2 1662 1664
2 1666 1668 3
166d 166e 166f 2
166a 1671 2 1655
1673 1 1675 1
1677 2 1640 1678
1 167c 1 163b
2 1639 1680 1
1683 1 169f 2
169e 169f 1 16a7
1 16ad 2 16af
16b0 2 169c 16b1
1 16b8 1 16b3
2 16cb 16cd 3
16c9 16ca 16cf 2
16d8 16da 2 16dc
16de 2 16e0 16e2
2 16e4 16e6 2
16e8 16ea 3 16ef
16f0 16f1 2 16ec
16f3 2 16d7 16f5
1 16f7 1 16f9
2 16c2 16fa 1
16fe 1 16bd 2
16bb 1702 1 1705
2 1708 1709 8
135c 149b 14f8 1582
1585 1590 15fb 170a
2 170c 170d 1
170f b d2b d43
da9 f93 f96 f99
11c2 121f 1292 170e
1712 1 ccb 1
1716 3 cca 1715
1718 1 1724 2
1723 1724 1 172c
1 1732 2 1734
1735 2 1721 1736
1 173d 1 1738
2 1750 1752 3
174e 174f 1754 2
175d 175f 2 1761
1763 2 1765 1767
2 1769 176b 2
176d 176f 3 1774
1775 1776 2 1771
1778 2 175c 177a
1 177c 1 177e
2 1747 177f 1
1783 1 1742 2
1740 1787 5 ac8
adc aeb 171a 178a
2 1791 1797 1
179e 1 1799 2
17b1 17b3 3 17af
17b0 17b5 2 17be
17c0 2 17c2 17c4
2 17c6 17c8 2
17ca 17cc 2 17ce
17d0 3 17d5 17d6
17d7 2 17d2 17d9
2 17bd 17db 1
17dd 1 17df 2
17a8 17e0 1 17e4
1 17a3 2 17a1
17e8 1 17ef 2
17ed 17ef 1 17f4
1 17f7 1 17f9
2 1808 180d 1
1814 1 180f 2
1827 1829 3 1825
1826 182b 2 1834
1836 2 1838 183a
2 183c 183e 2
1840 1842 2 1844
1846 3 184b 184c
184d 2 1848 184f
2 1833 1851 1
1853 1 1855 2
181e 1856 1 185a
1 1819 2 1817
185e 2 1864 1865
1 1869 2 1867
1869 3 1875 1876
1877 2 1870 187a
1 187c 1 1889
2 1888 1889 1
1891 1 1897 2
1899 189a 2 1886
189b 1 18a2 1
189d 2 18b5 18b7
3 18b3 18b4 18b9
2 18c2 18c4 2
18c6 18c8 2 18ca
18cc 2 18ce 18d0
2 18d2 18d4 3
18d9 18da 18db 2
18d6 18dd 2 18c1
18df 1 18e1 1
18e3 2 18ac 18e4
1 18e8 1 18a7
2 18a5 18ec 1
18f5 2 18f3 18f5
1 18fc 1 18fe
2 1908 190a 3
1906 1907 190c 2
1915 1917 2 1919
191b 2 191d 191f
2 1921 1925 2
1914 1927 1 1929
1 192b f 18d
1ac 20e 28b abc
ac1 178e 17eb 17fa
1861 187d 18ef 18ff
192c 1931 25 1b
25 2f 39 40
47 4e 55 5a
61 68 6f 76
7b 80 86 8c
92 98 9e a4
aa b0 b6 bc
c2 c8 ce d4
db e2 e7 ed
10f 119 12a 13b

1
4
0 
1939
0
1
a0
5a
2a
0 1 1 1 1 5 1 7
1 9 1 b 1 d 1 f
1 11 1 13 1 15 1 17
1 19 1a 19 1c 1 1e 1
20 1 22 23 22 25 22 27
22 29 22 2b 22 2d 22 2f
22 31 22 33 22 35 36 35
38 35 3a 35 3c 22 3e 22
40 22 42 22 44 45 44 47
22 49 22 4b 22 4d 22 4f
22 51 22 53 1 55 1 57
1 59 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

49 1 0
a0 1 0
be 1 0
9 1 0
9a 1 0
7d 1 0
6a 1 0
71 1 0
11c 1 3
31 1 0
130 1 4
2 0 1
d0 1 0
e4 1 0
d6 1 0
27 1 0
94 1 0
57 1 0
c4 1 0
b2 1 0
a6 1 0
114 1 0
dd 1 0
78 1 0
88 1 0
1d 1 0
17 1 0
82 1 0
8e 1 0
50 1 0
ac 1 0
63 1 0
3 1 0
e9 1 0
b8 1 0
42 1 0
5c 1 0
3b 1 0
170f 22 53
d 1 0
ca 1 0
f0 1 2
0

/
SHOW ERRORS FUNCTION FC_COMMIT_ASSIGN;
ALTER FUNCTION FC_COMMIT_ASSIGN COMPILE DEBUG;
Prompt == FUNCTION SP_COMMIT_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_COMMIT_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
46
2 :e:
1FUNCTION:
1SP_COMMIT_ASSIGN:
1ID001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_BITFLAG:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_COMMIT_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
11:
118:
1+:
1FPUT:
1               ENTER:: SP_COMMIT_ASSIGN(19) :: cplan.sql(21661) :: :
1SC_STATE:
1FC_COMMIT_ASSIGN:
14:
129:
1       RETURN_STATUS:: SP_COMMIT_ASSIGN(30) :: cplan.sql(21672) :: :
1 :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1TRUE:
1RETURN_ERROR_EXCEPTION:
116:
136:
1           EXCEPTION:: SP_COMMIT_ASSIGN(37) :: cplan.sql(21679) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1OTHERS:
1SQLCODE:
148:
1           EXCEPTION:: SP_COMMIT_ASSIGN(49) :: cplan.sql(21691) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
189
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d :2 a0 d :2 a0 6b :3 a0 51 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
189
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 72 5d 61 64 65 6d
5c 8e 7d 81 59 89 7c ae
99 9d 79 a1 a9 98 b5 b9
95 bd c1 c5 c8 cd ce 1
d0 d5 d9 dd e0 e5 e9 ed
f0 f5 f6 f8 fd 100 104 105
10a 10f 112 117 118 11d 120 124
125 12a 12d 132 133 138 13b 140
141 146 149 14d 151 155 156 158
15d 15e 160 161 166 169 16e 16f
174 175 17a 17c 180 183 187 18b
18e 192 196 199 19c 1a1 1a4 1a7
1aa 1ab 1b0 1b1 1 1b3 1b8 1bc
1c0 1c3 1c8 1cd 1d0 1d4 1d5 1da
1db 1e0 1e2 1e6 1e9 1ed 1f1 1f5
1f9 1fd 201 205 209 20c 210 214
218 21b 21c 21e 222 226 22a 22d
231 235 238 23b 240 243 246 249
24a 24f 250 1 252 257 25b 25f
262 267 26c 26f 273 274 279 27c
281 282 287 28a 28f 290 295 298
29c 2a0 2a4 2a8 2ab 2ac 2ae 2b3
2b4 2b6 2b7 2bc 2bf 2c4 2c5 2ca
2cd 2d2 2d3 2d8 2db 2df 2e0 2e5
2e8 2ed 2ee 2f3 2f4 2f9 2fb 2ff
302 306 30a 30d 311 315 318 31c
320 321 326 328 32c 330 333 337
33b 33e 342 346 349 34c 351 354
357 35a 35b 360 361 1 363 368
36c 370 373 378 37d 380 384 385
38a 38b 390 394 398 39b 3a0 3a5
3a8 3ac 3b0 3b3 3b4 3b9 3bc 3c1
3c2 3c7 3ca 3ce 3d2 3d5 3d6 3db
3dc 3e1 3e3 3e7 3ea 3ee 3f2 3f6
3fa 3fe 402 406 40a 40e 41a 41f
423 427 42b 42f 431 432 437 1
43b 43f 443 446 44a 44e 452 456
459 45d 461 464 467 46c 46f 472
475 476 47b 47c 1 47e 483 487
48b 48e 493 498 49b 49f 4a0 4a5
4a6 4ab 4af 4b3 4b6 4bb 4c0 4c3
4c7 4c8 4cd 4d0 4d5 4d6 4db 4de
4e2 4e6 4e9 4ec 4ed 4ef 4f0 4f5
4f6 4fb 4fd 501 504 508 50c 510
514 518 51c 520 52c 531 535 539
53d 541 543 547 549 555 557 559
55a 55f 563 565 571 575 577 578
581 
189
2
0 1 a 6 c :3 6 11 :2 6
1 3 a 13 a :2 1 4 9
12 11 :2 9 :2 4 :2 e 1d e :2 4
e 17 :3 e 4 7 :2 11 23 :2 2d
3a :2 23 :3 7 :2 d 19 25 :2 2f 43
:2 25 58 5e 61 :2 58 6f 89 8
:2 6f d 10 :2 6f 16 19 :2 6f b
e :2 6f 13 16 1f 27 :2 1f 34
:2 16 :2 6f 3c 3f :2 6f :2 7 4e :2 4
7 :2 11 23 :2 2d 39 3c 50 52
53 :2 50 :2 23 :3 7 :2 d 12 1e 61
64 :2 1e :2 7 56 :3 4 11 :2 4 c
:2 4 :2 d 19 2a 30 3b :2 19 4
7 :2 11 23 :2 2d 39 3c 50 52
53 :2 50 :2 23 :3 7 :2 d 12 1e 61
64 :2 1e 71 74 :2 1e 78 7b :2 1e
85 88 91 99 :2 a2 :2 91 ad :2 88
:2 1e b5 b8 :2 1e c0 c3 :2 1e c8
cb :2 1e d0 d3 :2 1e :2 7 56 :3 4
:2 f 21 :2 2a 34 3a :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
54 56 57 :2 54 :2 26 :3 a :2 10 15
21 64 67 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 5a :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
51 53 54 :2 51 :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 57 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
189
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :7 7
:6 8 :7 a :b c :11 d
e :2 d :2 e :2 d
:2 e :2 d :2 f :2 d
:9 f :2 d :2 f :4 d
:3 c :11 12 :b 13 :3 12
:3 18 :3 19 :a 1b :11 1d
:30 1e :3 1d :a 20 b
:3 23 :11 24 :b 25 :17 26
:3 24 :2 28 :3 29 :3 2a
2b 29 28 29
:3 2c :3 23 :2 2d :5 2f
:11 30 :b 31 :18 32 :3 30
:2 34 35 :3 36 37
35 34 35 :3 38
:2 2e :6 2d 22 :7 1

583
4
:3 0 1 :3 0 2
:a 0 184 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 6
:3 0 5 :7 0 9
8 :3 0 7 :3 0
8 :3 0 9 :2 0
4 b f 0
184 2 10 :2 0
d :2 0 c 4
:3 0 b :2 0 a
13 15 :6 0 18
16 0 182 0
a :6 0 20 21
0 e 6 :3 0
1a :7 0 1e 1b
1c 182 0 c
:6 0 26 27 0
10 8 :3 0 9
:2 0 4 22 :7 0
25 23 0 182
0 e :6 0 f
:3 0 10 :3 0 f
:3 0 11 :3 0 29
2a 0 2 :4 0
12 2b 2d 28
2f 2e :2 0 12
:3 0 13 :3 0 31
32 0 14 :4 0
f :3 0 15 :3 0
35 36 0 2
:4 0 14 37 39
16 :4 0 17 :2 0
18 :3 0 16 3c
3e :3 0 19 :4 0
17 :2 0 1a :4 0
19 41 43 :3 0
17 :2 0 3 :3 0
1c 45 47 :3 0
17 :2 0 1a :4 0
1f 49 4b :3 0
17 :2 0 1b :4 0
22 4d 4f :3 0
17 :2 0 1c :3 0
1d :3 0 5 :3 0
25 53 55 1e
:4 0 27 52 58
2a 51 5a :3 0
17 :2 0 1f :4 0
2d 5c 5e :3 0
30 33 60 :2 0
62 35 63 30
62 0 64 37
0 e2 f :3 0
10 :3 0 65 66
0 f :3 0 20
:3 0 68 69 0
21 :2 0 2 :4 0
22 :2 0 23 :2 0
21 :2 0 39 6e
70 :3 0 3c 6a
72 67 74 73
:2 0 12 :3 0 24
:3 0 76 77 0
14 :4 0 25 :4 0
17 :2 0 18 :3 0
40 7b 7d :3 0
43 78 7f :2 0
81 46 82 75
81 0 83 48
0 e2 c :3 0
5 :3 0 84 85
0 e2 a :3 0
3 :3 0 87 88
0 e2 8 :3 0
26 :3 0 8a 8b
0 27 :3 0 a
:3 0 c :3 0 21
:2 0 4a 8d 91
8c 92 0 e2
f :3 0 10 :3 0
94 95 0 f
:3 0 20 :3 0 97
98 0 28 :2 0
2 :4 0 29 :2 0
23 :2 0 21 :2 0
4e 9d 9f :3 0
51 99 a1 96
a3 a2 :2 0 12
:3 0 24 :3 0 a5
a6 0 14 :4 0
2a :4 0 17 :2 0
18 :3 0 55 aa
ac :3 0 17 :2 0
2b :4 0 58 ae
b0 :3 0 17 :2 0
2c :4 0 5b b2
b4 :3 0 17 :2 0
1c :3 0 1d :3 0
8 :3 0 26 :3 0
b9 ba 0 5e
b8 bc 1e :4 0
60 b7 bf 63
b6 c1 :3 0 17
:2 0 2d :4 0 66
c3 c5 :3 0 17
:2 0 1a :4 0 69
c7 c9 :3 0 17
:2 0 a :3 0 6c
cb cd :3 0 17
:2 0 1a :4 0 6f
cf d1 :3 0 72
a7 d3 :2 0 d5
75 d6 a4 d5
0 d7 77 0
e2 2e :3 0 2f
:3 0 d8 d9 0
8 :3 0 26 :3 0
db dc 0 a
:3 0 30 :3 0 79
da e0 :2 0 e2
7d 183 8 :3 0
31 :2 0 4 e3
e4 0 f :3 0
10 :3 0 e6 e7
0 f :3 0 20
:3 0 e9 ea 0
32 :2 0 2 :4 0
33 :2 0 23 :2 0
21 :2 0 85 ef
f1 :3 0 88 eb
f3 e8 f5 f4
:2 0 12 :3 0 24
:3 0 f7 f8 0
14 :4 0 34 :4 0
17 :2 0 18 :3 0
8c fc fe :3 0
8f f9 100 :2 0
119 12 :3 0 24
:3 0 102 103 0
14 :4 0 35 :4 0
17 :2 0 8 :3 0
36 :3 0 108 109
0 92 107 10b
:3 0 17 :2 0 2d
:4 0 95 10d 10f
:3 0 17 :2 0 8
:3 0 37 :3 0 112
113 0 98 111
115 :3 0 9b 104
117 :2 0 119 9e
11a f6 119 0
11b a1 0 12b
38 :3 0 e :3 0
8 :3 0 36 :3 0
39 :3 0 8 :3 0
37 :3 0 3a :3 0
3b :4 0 3c 1
:a 0 127 :2 0 12b
11d 125 :2 0 7
:3 0 e :3 0 129
:2 0 12b a3 12d
a7 12c 12b :2 0
181 3d :3 0 8
:3 0 26 :3 0 130
131 0 3e :3 0
132 133 0 179
f :3 0 10 :3 0
135 136 0 f
:3 0 20 :3 0 138
139 0 32 :2 0
2 :4 0 3f :2 0
23 :2 0 21 :2 0
a9 13e 140 :3 0
ac 13a 142 137
144 143 :2 0 12
:3 0 24 :3 0 146
147 0 14 :4 0
40 :4 0 17 :2 0
18 :3 0 b0 14b
14d :3 0 b3 148
14f :2 0 169 12
:3 0 24 :3 0 151
152 0 14 :4 0
41 :4 0 17 :2 0
3e :3 0 b6 156
158 :3 0 17 :2 0
42 :4 0 b9 15a
15c :3 0 17 :2 0
43 :3 0 44 :3 0
21 :2 0 45 :2 0
bc 15f 163 c0
15e 165 :3 0 c3
153 167 :2 0 169
c6 16a 145 169
0 16b c9 0
179 38 :3 0 e
:3 0 39 :3 0 8
:3 0 37 :3 0 3a
:3 0 3b :4 0 46
1 :a 0 175 :2 0
179 16d 173 :2 0
7 :3 0 e :3 0
177 :2 0 179 cb
17c :3 0 17c 0
17c 17b 179 17a
:6 0 17e 1 :3 0
d0 180 d2 17f
17e :2 0 181 d4
:2 0 183 d7 183
182 e2 181 :6 0
184 :2 0 2 10
183 187 :3 0 186
184 188 :8 0 
db
4
:3 0 1 3 1
7 2 6 a
1 14 1 12
1 19 1 1f
1 2c 1 38
2 3b 3d 2
40 42 2 44
46 2 48 4a
2 4c 4e 1
54 2 56 57
2 50 59 2
5b 5d 4 34
3a 3f 5f 1
61 1 63 2
6d 6f 3 6b
6c 71 2 7a
7c 2 79 7e
1 80 1 82
3 8e 8f 90
2 9c 9e 3
9a 9b a0 2
a9 ab 2 ad
af 2 b1 b3
1 bb 2 bd
be 2 b5 c0
2 c2 c4 2
c6 c8 2 ca
cc 2 ce d0
2 a8 d2 1
d4 1 d6 3
dd de df 7
64 83 86 89
93 d7 e1 2
ee f0 3 ec
ed f2 2 fb
fd 2 fa ff
2 106 10a 2
10c 10e 2 110
114 2 105 116
2 101 118 1
11a 3 11b 126
12a 1 e5 2
13d 13f 3 13b
13c 141 2 14a
14c 2 149 14e
2 155 157 2
159 15b 3 160
161 162 2 15d
164 2 154 166
2 150 168 1
16a 4 134 16b
174 178 1 17c
1 12f 2 12d
180 3 17 1d
24 
1
4
0 
187
0
1
14
2
6
0 1 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
2 0 1
3 1 0
19 1 0
12 1 0
7 1 0
1f 1 0
0

/
SHOW ERRORS FUNCTION SP_COMMIT_ASSIGN;
ALTER FUNCTION SP_COMMIT_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Accept ETC and/or FORECAST_START, Assign level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_ACPT_ETC_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_ACPT_ETC_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ac
2 :e:
1FUNCTION:
1SP_ACPT_ETC_ASSIGN:
1ID001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PRJ_ASSIGNMENT_ID:
1H_REC_USER:
1H_PROJECT_ID:
1H_TASK_ID:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_TA_START_DT:
1TIMESTAMP:
1H_TA_FINISH_DT:
1H_START_DATE:
1H_FINISH_DATE:
1H_FINISH_D:
1DATE:
1H_LAST_SUBMITTED:
1H_WEEK_OF:
1H_BIT_FLAG:
1H_EFFORT:
10:
1H_CONTOUR:
1H_BITFLAG:
1H_REMAINING:
1H_TOTAL:
1H_CONSTR_DT:
1H_DAYOFYEAR:
1H_FINISH_TIME:
18:
1H_MINUTE:
1H_CONSTR_TYPE:
1H_FF_FLAG:
1H_ETC:
1H_SCHED_WORK:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_SD:
1H_FD:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_MLST_PERCENT:
1H_PROJAFFECTED_START:
1H_WORK_TODATE:
1H_PASSED:
1H_NOT_EFFORT_PA:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ACPT_ETC_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_ACPT_ETC_ASSIGN(61) :: cplan.sql(21774) :: :
1PROJECT_ID:
1TASK_ID:
1PROJECT_ASSIGNMENT_ID:
1SCHED_WORK:
1PLANNED_WORK:
1FORECAST_START:
1FORECAST_FINISH:
1ETC:
1WORK_TODATE:
1C_CONTOUR:
1LAST_SUBMITTED:
1PLANNED_START:
1SCHED_START:
1PLANNED_FINISH:
1SCHED_FINISH:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1BIT_FLAG:
1MILESTONE_PERCENT:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT:n      PROJECT_ID,:n      TASK_ID,:n      PROJECT_ASSIGNMENT_ID,:n    +
1  SCHED_WORK+PLANNED_WORK,:n      FORECAST_START,:n      FORECAST_FINISH,:n  +
1    CASE WHEN h_bitflag = 2 AND FORECAST_START IS NuLL THEN 0 ELSE ETC END,:n+
1      SCHED_WORK+PLANNED_WORK - WORK_TODATE,:n      ETC,:n      C_CONTOUR,:n +
1     LAST_SUBMITTED,:n      CASE WHEN FORECAST_FINISH IS NOT NuLL AND FORECAS+
1T_START IS NuLL AND FORECAST_FINISH BETWEEN COALESCE(PLANNED_START, SCHED_STA+
1RT) AND COALESCE(PLANNED_FINISH, SCHED_FINISH) THEN 1 ELSE 0 END,:n      UNRE+
1SOLVED_START,:n      UNRESOLVED_FINISH,:n      BILLABLE,:n      CAPITAL_EXPEN+
1SE,:n      REGULAR_COST,:n      REGULAR_RATE,:n      BIT_FLAG,:n      MILESTO+
1NE_PERCENT,:n      RESOURCE_ID,:n      RESOURCE_TYPE,:n      WORK_TODATE:n   +
1   INTO:n      h_project_id,:n      h_task_id,:n      h_prj_assignment_id,:n +
1     h_sched_work,:n      h_start_date,:n      h_finish_date,:n      h_effort+
1,:n      h_remaining,:n      h_etc,:n      h_contour,:n      h_last_submitted+
1,:n      h_FF_flag,:n      h_ta_start_DT,:n      h_ta_finish_DT,:n      h_bil+
1lable,:n      h_capital_expense,:n      h_reg_cost,:n      h_reg_sale,:n     +
1 h_bit_flag,:n      h_mlst_percent,:n      h_res_id,:n      h_res_type,:n    +
1  h_work_todate:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID =+
1 h_tsk_assignment_id:n      AND (((SCHED_WORK+PLANNED_WORK) > 0:n      AND (S+
1CHED_WORK+PLANNED_WORK - WORK_TODATE) <> ETC):n      OR FORECAST_START IS NOT+
1 NULL OR FORECAST_FINISH IS NOT NULL):
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1140:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(141) :: cplan.sql(21854) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_NO_DATA:
1147:
1        RETURN_ERROR:: SP_ACPT_ETC_ASSIGN(148) :: cplan.sql(21861) :: :
1STATE:: :
1PMO_CNST:
1RECORD_NOT_FOUND:
1 ID:: :
1150:
1                EXIT:: SP_ACPT_ETC_ASSIGN(151) :: cplan.sql(21864) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1FC_ACPT_EFFORT:
1>:
1200000:
1169:
1        RETURN_ERROR:: SP_ACPT_ETC_ASSIGN(170) :: cplan.sql(21883) :: :
1172:
1                EXIT:: SP_ACPT_ETC_ASSIGN(173) :: cplan.sql(21886) :: :
1!=:
1SELECT ETC INTO h_total:n            FROM TASK_ASSIGNMENTS:n            WHERE+
1 TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1193:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(194) :: cplan.sql(21907) :: :
1UPDATE TASK_ASSIGNMENTS:n               SET ETC  = h_etc:n               WHER+
1E TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1FOUND:
1100:
1215:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(216) :: cplan.sql(21929) :: :
1FC_ROLLUP:
14:
1226:
1       RETURN_STATUS:: SP_ACPT_ETC_ASSIGN(227) :: cplan.sql(21940) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1233:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(234) :: cplan.sql(21947) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1245:
1           EXCEPTION:: SP_ACPT_ETC_ASSIGN(246) :: cplan.sql(21959) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
532
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d :2 a0 d :2 a0 d a0 4d d
a0 4d d :46 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:1c a0 a5 b d :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 51 a5
b :2 a0 a5 57 b7 a0 51 d
:2 a0 51 a5 b 7e 51 b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 19
3c b7 19 3c :3 a0 a5 b d
b7 :2 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
532
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
134 122 101 126 127 12f 121 150
13f 143 14b 11e 168 157 15b 163
13e 184 173 177 17f 13b 19c 18b
18f 197 172 1b8 1a7 1ab 1b3 16f
1d0 1bf 1c3 1cb 1a6 1ec 1db 1df
1e7 1a3 208 1f3 1f7 1fa 1fb 203
1da 224 213 217 1d7 21f 212 240
22f 233 20f 23b 22e 25c 24b 24f
22b 257 24a 278 267 26b 247 273
266 294 283 287 263 28f 282 2b0
29f 2a3 2ab 27f 2c8 2b7 2bb 2c3
29e 2e5 2d3 29b 2d7 2d8 2e0 2d2
301 2f0 2f4 2cf 2fc 2ef 31d 30c
310 2ec 318 30b 339 328 32c 308
334 327 355 344 348 324 350 343
371 360 364 340 36c 35f 38d 37c
380 35c 388 37b 3a9 398 39c 378
3a4 397 3c5 3b4 3b8 394 3c0 3b3
3e1 3d0 3d4 3b0 3dc 3cf 3fd 3ec
3f0 3f8 3cc 415 404 408 410 3eb
431 420 424 3e8 42c 41f 44d 43c
440 41c 448 43b 469 458 45c 438
464 457 485 474 478 454 480 473
4a1 490 494 49c 470 4bc 4a8 4ac
4b4 4b7 48f 4d8 4c7 4cb 48c 4d3
4c6 4f4 4e3 4e7 4c3 4ef 4e2 514
4ff 503 4df 507 50f 4fe 51b 51f
4fb 523 527 52b 52e 533 534 1
536 53b 53f 543 546 54b 54f 553
556 55b 55c 55e 563 566 56a 56b
570 575 578 57d 57e 583 586 58a
58b 590 593 598 599 59e 5a1 5a6
5a7 5ac 5af 5b3 5b7 5bb 5bc 5be
5c3 5c4 5c6 5c7 5cc 5cf 5d4 5d5
5da 5dd 5e2 5e3 5e8 5eb 5ef 5f0
5f5 5f8 5fd 5fe 603 606 60b 60c
611 612 617 619 61d 620 624 628
62b 62f 633 636 639 63e 641 644
647 648 64d 64e 1 650 655 659
65d 660 665 66a 66d 671 672 677
678 67d 67f 683 686 68a 68e 692
696 69a 69e 6a2 6a6 6aa 6ae 6af
6b3 6b7 6b8 6bc 6c0 6c4 6c8 6cc
6d0 6d4 6d8 6dc 6e0 6e4 6e8 6ec
6f0 6f4 6f8 6fc 700 704 708 70c
710 714 718 71c 720 724 728 72c
730 734 738 73c 740 744 748 74c
750 754 758 75c 760 764 768 76c
770 774 778 77c 780 784 788 78c
790 794 798 79c 7a0 7a4 7a8 7ac
7b0 7b4 7b8 7bc 7c0 7c4 7c8 7cc
7d0 7d4 7e0 7e4 7e8 7eb 7ef 7f3
7f5 7f9 7fd 801 804 808 80c 80e
80f 814 1 818 81c 820 823 827
82b 82f 833 836 83a 83e 841 844
849 84c 84f 852 853 858 859 1
85b 860 864 868 86b 870 875 878
87c 87d 882 885 88a 88b 890 893
898 899 89e 8a1 8a5 8a6 8ab 8ae
8b3 8b4 8b9 8bc 8c0 8c4 8c7 8ca
8cb 8cd 8ce 8d3 8d4 8d9 8db 8df
8e2 8e4 8e8 8ea 8f6 8f8 8fa 8fb
900 904 906 912 914 918 91c 91f
923 926 92a 92d 92e 933 936 93a
93e 941 945 949 94c 94f 954 957
95a 95d 95e 963 964 1 966 96b
96f 973 976 97b 980 983 987 988
98d 990 995 996 99b 99e 9a3 9a4
9a9 9ac 9b0 9b4 9b8 9bc 9bf 9c0
9c2 9c7 9c8 9ca 9cb 9d0 9d3 9d8
9d9 9de 9e1 9e6 9e7 9ec 9ef 9f3
9f4 9f9 9fc a01 a02 a07 a08 a0d
a0f a13 a16 a1a a1e a21 a25 a29
a2c a2f a34 a37 a3a a3d a3e a43
a44 1 a46 a4b a4f a53 a56 a5b
a60 a63 a67 a68 a6d a6e a73 a75
a79 a7c a80 a84 a87 a8b a8f a92
a96 a9a a9b aa0 aa2 aa6 aa9 aad
ab1 ab5 ab9 abd ac1 ac5 ac9 acd
ad1 ad5 ad9 add ae1 ae5 ae9 aed
af1 af5 af9 afd b01 b05 b09 b0d
b11 b15 b19 b1a b1c b20 b24 b28
b2b b2c b2e b31 b34 b35 b3a b3e
b42 b45 b49 b4d b50 b53 b58 b5b
b5e b61 b62 b67 b68 1 b6a b6f
b73 b77 b7a b7f b84 b87 b8b b8c
b91 b94 b99 b9a b9f ba2 ba7 ba8
bad bb0 bb4 bb8 bbc bbd bbf bc4
bc5 bc7 bc8 bcd bd0 bd5 bd6 bdb
bde be3 be4 be9 bec bf0 bf1 bf6
bf9 bfe bff c04 c05 c0a c0c c10
c13 c17 c1b c1e c22 c26 c29 c2c
c31 c34 c37 c3a c3b c40 c41 1
c43 c48 c4c c50 c53 c58 c5d c60
c64 c65 c6a c6b c70 c72 c76 c79
c7d c81 c84 c88 c8c c8f c90 c92
c96 c9a c9b ca0 ca2 ca6 ca9 cad
cb1 cb5 cb8 cb9 cbb cbe cc1 cc2
cc7 ccb ccf cd3 cd7 cdb ce7 ceb
cef cf2 cf6 cfa cfc d00 d04 d08
d0b d0f d13 d15 d16 d1b 1 d1f
d23 d27 d2a d2e d32 d36 d3a d3d
d41 d45 d48 d4b d50 d53 d56 d59
d5a d5f d60 1 d62 d67 d6b d6f
d72 d77 d7c d7f d83 d84 d89 d8c
d91 d92 d97 d9a d9f da0 da5 da8
dac dad db2 db5 dba dbb dc0 dc3
dc7 dcb dce dd1 dd2 dd4 dd5 dda
ddb de0 de2 de6 de9 deb def df1
dfd dff e01 e02 e07 e0b e0d e19
e1b e1f e23 e26 e27 e29 e2d e30
e34 e37 e38 e3a e3b e40 e44 e48
e4c e50 e54 e60 e64 e69 e6d e70
e71 e76 e7a e7e e81 e84 e88 e8a
e8e e92 e95 e98 e9c e9e ea2 ea6
ea9 eab eaf eb3 eb7 eba ebe ec2
ec4 ec5 eca 1 ece ed2 ed6 ed9
edd ee1 ee5 ee9 eec ef0 ef4 ef7
efa eff f02 f05 f08 f09 f0e f0f
1 f11 f16 f1a f1e f21 f26 f2b
f2e f32 f33 f38 f3b f40 f41 f46
f49 f4e f4f f54 f57 f5b f5c f61
f64 f69 f6a f6f f72 f76 f7a f7d
f80 f81 f83 f84 f89 f8a f8f f91
f95 f98 f9a f9e fa0 fac fae fb0
fb1 fb6 fba fbc fc8 fca fcc fd0
fd3 fd5 fd9 fdc fe0 fe4 fe8 fe9
feb fef ff1 ff5 ff9 ffc 1000 1004
1007 100b 100f 1012 1015 101a 101d 1020
1023 1024 1029 102a 1 102c 1031 1035
1039 103c 1041 1046 1049 104d 104e 1053
1056 105b 105c 1061 1064 1069 106a 106f
1072 1076 107a 107e 1082 1085 1086 1088
108d 108e 1090 1091 1096 1099 109e 109f
10a4 10a7 10ac 10ad 10b2 10b5 10b9 10ba
10bf 10c2 10c7 10c8 10cd 10ce 10d3 10d5
10d9 10dc 10e0 10e4 10e7 10eb 10ef 10f2
10f6 10fa 10fb 1100 1102 1106 110a 110d
1111 1115 1118 111c 1120 1123 1126 112b
112e 1131 1134 1135 113a 113b 1 113d
1142 1146 114a 114d 1152 1157 115a 115e
115f 1164 1165 116a 116e 1172 1175 117a
117f 1182 1186 118a 118d 118e 1193 1196
119b 119c 11a1 11a4 11a8 11ac 11af 11b0
11b5 11b6 11bb 11bd 11c1 11c4 11c8 11cc
11d0 11d4 11d8 11dc 11e0 11e4 11e8 11f4
11f9 11fd 1201 1205 1209 120b 120c 1211
1 1215 1219 121d 1220 1224 1228 122c
1230 1233 1237 123b 123e 1241 1246 1249
124c 124f 1250 1255 1256 1 1258 125d
1261 1265 1268 126d 1272 1275 1279 127a
127f 1280 1285 1289 128d 1290 1295 129a
129d 12a1 12a2 12a7 12aa 12af 12b0 12b5
12b8 12bc 12c0 12c3 12c6 12c7 12c9 12ca
12cf 12d0 12d5 12d7 12db 12de 12e2 12e6
12ea 12ee 12f2 12f6 12fa 1306 130b 130f
1313 1317 131b 131d 1321 1323 132f 1331
1333 1334 1339 133d 133f 134b 134f 1351
1352 135b 
532
2
0 1 a 6 c :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 18 21
20 :2 18 :2 4 f 18 17 :2 f :2 4
11 1a 19 :2 11 :2 4 e 17 16
:2 e :2 4 d 16 15 :2 d :2 4 f
18 17 :2 f :2 4 :3 12 :2 4 :3 13 :2 4
:3 11 :2 4 :3 12 :2 4 :3 f :2 4 :3 15 :2 4
:3 e :2 4 f 18 17 :2 f :2 4 :2 d
1c d :2 4 :2 e 1d e :2 4 :2 e
1d e :2 4 :2 10 1f 10 :2 4 :2 c
1b c :2 4 :3 10 :2 4 :3 10 :2 4 12
1b 1a :2 12 :2 4 :2 d 1c d :2 4
:2 12 21 12 :2 4 :2 e 1d e :2 4
:2 a 19 a :2 4 :2 11 20 11 :2 4
:2 f 1e f :2 4 :2 14 23 14 :2 4
:2 f 19 f :2 4 :2 f 19 f :2 4
:3 9 :2 4 :3 9 :2 4 :2 f 1e f :2 4
:2 16 25 16 :2 4 :2 11 20 11 :2 4
:2 13 22 13 :2 4 :3 19 :2 4 :2 12 21
12 :2 4 :2 d 1c d :2 4 :2 14 23
14 :2 4 e 17 :3 e 4 7 :2 11
23 :2 2d 3a :2 23 :3 7 :2 d 19 25
:2 2f 43 :2 25 5a 60 63 :2 5a 71
8d 8 :2 71 d 10 :2 71 16 19
:2 71 b e :2 71 13 16 1f 27
:2 1f 34 :2 16 :2 71 b e :2 71 13
16 :2 71 1b 1e :2 71 2a 2d :2 71
32 35 :2 71 :2 7 50 :2 4 7 :2 11
23 :2 2d 39 3c 52 54 55 :2 52
:2 23 :3 7 :2 d 12 1e 63 66 :2 1e
:2 7 58 :3 4 11 :2 4 1b :2 4 12
:2 4 14 :2 4 15 4 :4 7 12 :2 7
11 23 46 7 12 21 :3 7 11
31 4c 64 6d 7c 8d 96 a6
:22 7 c d 21 e 19 c 17
26 36 a 28 fffa 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 59 5c 5d :2 59
:2 29 :3 d :2 13 18 24 6a 6d :2 24
7a 7d :2 24 81 84 :2 24 90 93
:2 24 9b 9e :2 24 aa ad b4 bd
c0 :2 ad :2 24 :2 d 60 :2 a :2 7 :4 13
:2 7 4 :3 1 8 :2 11 1c 1a :2 25
:2 1a 7 a :2 14 26 :2 30 3c 40
56 59 5a :2 56 :2 26 :3 a :2 10 15
21 67 6a :2 21 77 7a :2 21 7e
81 :2 21 8b 8e 97 9f :2 a8 :2 97
bb :2 8e :2 21 c3 c6 :2 21 ce d1
:2 21 d6 d9 :2 21 ed f0 :2 21 :2 a
5d :2 7 a :2 14 26 :2 30 3c 3f
55 58 59 :2 55 :2 26 :3 a :2 10 15
21 67 6a :2 21 :2 a 5c :3 7 :2 12
26 :2 2f 41 f :2 7 35 :3 4 17
26 34 3f 54 25 33 41 50
5a 25 2c 37 49 54 25 35
41 54 25 31 3d 4d 57 25
34 3f :2 17 4 7 10 21 :2 7
24 26 :2 24 a :2 14 26 :2 30 3c
40 56 59 5a :2 56 :2 26 :3 a :2 10
15 21 67 6a :2 21 77 7a :2 21
7e 81 :2 21 8b 8e 97 9f :2 97
b1 :2 8e :2 21 b9 bc :2 21 c4 c7
:2 21 cc cf :2 21 e3 e6 :2 21 :2 a
5d :2 7 a :2 14 26 :2 30 3c 3f
55 58 59 :2 55 :2 26 :3 a :2 10 15
21 67 6a :2 21 :2 a 5c :3 7 :2 12
26 2f 40 :2 26 44 f :2 7 2d
7 12 7 a 13 1e :2 a 21
24 :2 21 14 1d 12 13 27 :2 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5f 62
63 :2 5f :2 2f :3 13 :2 19 1e 2a 70
73 :2 2a 80 83 :2 2a 87 8a :2 2a
96 99 :2 2a a1 a4 :2 2a b0 b3
ba c3 c6 :2 b3 :2 2a :2 13 66 :2 10
:2 d :4 19 :2 d a :3 26 d 16 1d
:2 d 22 20 2b 34 :2 22 :2 20 17
14 1b 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 62 65
66 :2 62 :2 32 :3 16 :2 1c 21 2d 73
76 :2 2d 83 86 :2 2d 8a 8d :2 2d
99 9c :2 2d a4 a7 :2 2d b3 b6
bd c6 c9 :2 b6 :2 2d :2 16 69 :2 13
:2 10 :4 1c :2 10 d :4 37 :2 a 26 :3 7
1a 24 :2 1a 7 :4 4 7 :2 11 23
:2 2d 39 3c 52 55 56 :2 52 :2 23
:3 7 :2 d 12 1e 64 67 :2 1e 74
77 :2 1e 7b 7e :2 1e 88 8b 94
9c :2 a5 :2 94 b0 :2 8b :2 1e b8 bb
:2 1e c3 c6 :2 1e cb ce :2 1e d4
d7 :2 1e :2 7 59 :3 4 :2 f 21 :2 2a
34 3b :2 4 1 9 12 9 a
:2 14 26 :2 30 3c 40 56 59 5a
:2 56 :2 26 :3 a :2 10 15 21 67 6a
:2 21 :3 a :2 10 15 39 5c 5f :2 68
:2 39 76 79 :2 39 81 84 :2 8d :2 39
:2 a 5d :3 7 c 15 1e 2c a
13 1e f e 7 e 7 e
7 29 :2 4 :2 9 7 :2 10 1c :2 7
:2 11 23 :2 2d 39 3d 53 56 57
:2 53 :2 23 :3 7 :2 d 12 1e 64 67
:2 1e :3 7 :2 d 12 36 42 45 :2 36
4d 50 :2 36 5c 5f 66 6f 72
:2 5f :2 36 :2 7 5a :2 4 7 c 1b
a 13 1e f e 7 e 7
e 7 :2 4 :4 10 :2 4 :8 1 
532
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :7 e :5 f
:5 10 :5 11 :5 12 :5 13
:5 14 :5 15 :7 16 :6 17
:6 18 :6 19 :6 1a :6 1b
:5 1c :5 1d :7 1e :6 1f
:6 20 :6 21 :6 22 :6 23
:6 24 :6 25 :6 26 :6 27
:5 28 :5 29 :6 2a :6 2b
:6 2c :6 2d :5 2e :6 2f
:6 30 :6 31 :7 33 :b 35
:11 36 37 :2 36 :2 37
:2 36 :2 37 :2 36 :2 38
:2 36 :9 38 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:4 36 :3 35 :11 3c :b 3d
:3 3c :3 44 :3 45 :3 46
:3 4a :3 4c 51 52
53 :2 54 55 56
:3 57 :3 58 59 5a
5b :9 5c 5d 5e
5f 60 61 62
63 64 65 66
67 69 6a 6b
6c 6d 6e 6f
70 71 72 73
74 75 76 77
78 79 7a 7b
7c 7d 7e 7f
80 :2 81 :2 82 :4 83
:2 84 51 :5 85 4f
87 :5 88 :3 87 :2 89
:5 8b :11 8c :24 8d :3 8c
:2 8a :6 89 86 :3 34
:a 92 :11 93 :30 94 :3 93
:11 96 :b 97 :3 96 :7 99
9a :2 99 :3 92 :6 9d
:5 9e :5 9f :4 a0 :5 a1
:3 a2 :3 9d :9 a6 :11 a9
:2e aa :3 a9 :11 ac :b ad
:3 ac :9 af b0 :2 af
a6 :3 b2 :9 b5 :2 b7
b8 :2 b9 b7 :5 ba
b6 bc :5 bd :3 bc
:2 be :5 c0 :11 c1 :24 c2
:3 c1 :2 bf :6 be bb
:3 b5 :d c7 c9 :2 ca
:2 cb c9 :6 cc :5 cd
cc :5 cf ce :3 cc
c8 d2 :5 d3 :3 d2
:2 d4 :5 d6 :11 d7 :24 d8
:3 d7 :2 d5 :6 d4 d1
:6 c7 :3 b5 :6 df b1
:3 a6 :11 e2 :30 e3 :3 e2
:a e5 34 :3 e8 :11 e9
:b ea :17 eb :3 e9 :2 ed
:3 ee :3 ef f0 ee
ed ee :3 f1 :3 e8
:2 f2 :5 f4 :11 f5 :b f6
:18 f7 :3 f5 :2 f9 fa
:3 fb fc fa f9
fa :3 fd :2 f3 :6 f2
e7 :7 1 
135d
4
:3 0 1 :3 0 2
:a 0 52d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 52d 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 52b
0 b :6 0 c
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 52b
0 d :6 0 c
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 52b
0 e :6 0 c
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 52b
0 f :6 0 c
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 52b
0 10 :6 0 13
:2 0 23 4 :3 0
21 3a 3c :6 0
3f 3d 0 52b
0 11 :6 0 29
13b 0 27 4
:3 0 25 41 43
:6 0 46 44 0
52b 0 12 :6 0
2d 16f 0 2b
15 :3 0 48 :7 0
4b 49 0 52b
0 14 :6 0 15
:3 0 4d :7 0 50
4e 0 52b 0
16 :6 0 31 1a3
0 2f 15 :3 0
52 :7 0 55 53
0 52b 0 17
:6 0 15 :3 0 57
:7 0 5a 58 0
52b 0 18 :6 0
35 1d7 0 33
1a :3 0 5c :7 0
5f 5d 0 52b
0 19 :6 0 1a
:3 0 61 :7 0 64
62 0 52b 0
1b :6 0 1f :2 0
39 1a :3 0 66
:7 0 69 67 0
52b 0 1c :6 0
4 :3 0 13 :2 0
37 6b 6d :6 0
70 6e 0 52b
0 1d :6 0 1f
:2 0 3b 6 :3 0
72 :7 0 76 73
74 52b 0 1e
:6 0 1f :2 0 3d
6 :3 0 78 :7 0
7c 79 7a 52b
0 20 :6 0 1f
:2 0 3f 6 :3 0
7e :7 0 82 7f
80 52b 0 21
:6 0 1f :2 0 41
6 :3 0 84 :7 0
88 85 86 52b
0 22 :6 0 45
29b 0 43 6
:3 0 8a :7 0 8e
8b 8c 52b 0
23 :6 0 27 :2 0
47 15 :3 0 90
:7 0 93 91 0
52b 0 24 :6 0
1a :3 0 95 :7 0
98 96 0 52b
0 25 :6 0 1f
:2 0 4b 4 :3 0
49 9a 9c :6 0
9f 9d 0 52b
0 26 :6 0 1f
:2 0 4d 6 :3 0
a1 :7 0 a5 a2
a3 52b 0 28
:6 0 1f :2 0 4f
6 :3 0 a7 :7 0
ab a8 a9 52b
0 29 :6 0 1f
:2 0 51 6 :3 0
ad :7 0 b1 ae
af 52b 0 2a
:6 0 1f :2 0 53
6 :3 0 b3 :7 0
b7 b4 b5 52b
0 2b :6 0 1f
:2 0 55 6 :3 0
b9 :7 0 bd ba
bb 52b 0 2c
:6 0 1f :2 0 57
6 :3 0 bf :7 0
c3 c0 c1 52b
0 2d :6 0 31
:2 0 59 6 :3 0
c5 :7 0 c9 c6
c7 52b 0 2e
:6 0 31 :2 0 5b
30 :3 0 cb :7 0
cf cc cd 52b
0 2f :6 0 5f
3e8 0 5d 30
:3 0 d1 :7 0 d5
d2 d3 52b 0
32 :6 0 1f :2 0
61 1a :3 0 d7
:7 0 da d8 0
52b 0 33 :6 0
1a :3 0 dc :7 0
df dd 0 52b
0 34 :6 0 1f
:2 0 63 6 :3 0
e1 :7 0 e5 e2
e3 52b 0 35
:6 0 1f :2 0 65
6 :3 0 e7 :7 0
eb e8 e9 52b
0 36 :6 0 1f
:2 0 67 6 :3 0
ed :7 0 f1 ee
ef 52b 0 37
:6 0 6b 48c 0
69 6 :3 0 f3
:7 0 f7 f4 f5
52b 0 38 :6 0
1f :2 0 6d 1a
:3 0 f9 :7 0 fc
fa 0 52b 0
39 :6 0 6 :3 0
fe :7 0 1f :2 0
102 ff 100 52b
0 3a :6 0 1f
:2 0 6f 6 :3 0
104 :7 0 108 105
106 52b 0 3b
:6 0 110 111 0
71 6 :3 0 10a
:7 0 10e 10b 10c
52b 0 3c :6 0
116 117 0 73
9 :3 0 a :2 0
4 112 :7 0 115
113 0 52b 0
3d :6 0 3e :3 0
3f :3 0 3e :3 0
40 :3 0 119 11a
0 2 :4 0 75
11b 11d 118 11f
11e :2 0 41 :3 0
42 :3 0 121 122
0 43 :4 0 3e
:3 0 44 :3 0 125
126 0 2 :4 0
77 127 129 45
:4 0 46 :2 0 47
:3 0 79 12c 12e
:3 0 48 :4 0 46
:2 0 49 :4 0 7c
131 133 :3 0 46
:2 0 3 :3 0 7f
135 137 :3 0 46
:2 0 49 :4 0 82
139 13b :3 0 46
:2 0 4a :4 0 85
13d 13f :3 0 46
:2 0 4b :3 0 4c
:3 0 5 :3 0 88
143 145 4d :4 0
8a 142 148 8d
141 14a :3 0 46
:2 0 4a :4 0 90
14c 14e :3 0 46
:2 0 49 :4 0 93
150 152 :3 0 46
:2 0 7 :3 0 96
154 156 :3 0 46
:2 0 49 :4 0 99
158 15a :3 0 46
:2 0 4e :4 0 9c
15c 15e :3 0 9f
123 160 :2 0 162
a4 163 120 162
0 164 a6 0
48b 3e :3 0 3f
:3 0 165 166 0
3e :3 0 4f :3 0
168 169 0 13
:2 0 2 :4 0 50
:2 0 51 :2 0 13
:2 0 a8 16e 170
:3 0 ab 16a 172
167 174 173 :2 0
41 :3 0 52 :3 0
176 177 0 43
:4 0 53 :4 0 46
:2 0 47 :3 0 af
17b 17d :3 0 b2
178 17f :2 0 181
b5 182 175 181
0 183 b7 0
48b 21 :3 0 5
:3 0 184 185 0
48b b :3 0 3
:3 0 187 188 0
48b e :3 0 7
:3 0 18a 18b 0
48b 17 :4 0 18d
18e 0 48b 18
:4 0 190 191 0
48b 54 :3 0 55
:3 0 56 :3 0 57
:3 0 58 :3 0 59
:3 0 5a :3 0 21
:3 0 59 :3 0 5b
:3 0 57 :3 0 58
:3 0 5c :3 0 5b
:3 0 5d :3 0 5e
:3 0 5a :3 0 59
:3 0 5a :3 0 4b
:3 0 5f :3 0 60
:3 0 4b :3 0 61
:3 0 62 :3 0 63
:3 0 64 :3 0 65
:3 0 66 :3 0 67
:3 0 68 :3 0 69
:3 0 6a :3 0 6b
:3 0 6c :3 0 5c
:3 0 f :3 0 10
:3 0 d :3 0 2c
:3 0 17 :3 0 18
:3 0 1e :3 0 22
:3 0 2b :3 0 20
:3 0 1b :3 0 2a
:3 0 14 :3 0 16
:3 0 35 :3 0 36
:3 0 2f :3 0 32
:3 0 1d :3 0 38
:3 0 11 :3 0 12
:3 0 3a :3 0 6d
:3 0 6e :3 0 b
:3 0 57 :3 0 58
:3 0 57 :3 0 58
:3 0 5c :3 0 5b
:3 0 59 :3 0 5a
:4 0 6f 1 :8 0
1df 9 :3 0 70
:3 0 1da 1db 0
71 :3 0 1dc 1dd
0 1df b9 232
72 :3 0 9 :3 0
70 :3 0 1e1 1e2
0 71 :3 0 1e3
1e4 0 1e6 bc
1e8 be 1e7 1e6
:2 0 230 73 :3 0
9 :3 0 70 :3 0
1eb 1ec 0 71
:3 0 1ed 1ee 0
228 3e :3 0 3f
:3 0 1f0 1f1 0
3e :3 0 4f :3 0
1f3 1f4 0 74
:2 0 2 :4 0 75
:2 0 51 :2 0 13
:2 0 c0 1f9 1fb
:3 0 c3 1f5 1fd
1f2 1ff 1fe :2 0
41 :3 0 52 :3 0
201 202 0 43
:4 0 76 :4 0 46
:2 0 47 :3 0 c7
206 208 :3 0 46
:2 0 77 :4 0 ca
20a 20c :3 0 46
:2 0 78 :4 0 cd
20e 210 :3 0 46
:2 0 71 :3 0 d0
212 214 :3 0 46
:2 0 79 :4 0 d3
216 218 :3 0 46
:2 0 7a :3 0 7b
:3 0 13 :2 0 7c
:2 0 d6 21b 21f
da 21a 221 :3 0
dd 203 223 :2 0
225 e0 226 200
225 0 227 e2
0 228 e4 22b
:3 0 22b 0 22b
22a 228 229 :6 0
22d 2 :3 0 e7
22f e9 22e 22d
:2 0 230 eb :2 0
232 0 232 231
1df 230 :6 0 48b
1 :3 0 9 :3 0
70 :3 0 234 235
0 9 :3 0 7d
:2 0 7e :3 0 237
239 0 f0 238
23b :3 0 23c :2 0
3e :3 0 3f :3 0
23e 23f 0 3e
:3 0 4f :3 0 241
242 0 c :2 0
2 :4 0 7f :2 0
51 :2 0 13 :2 0
f3 247 249 :3 0
f6 243 24b 240
24d 24c :2 0 41
:3 0 52 :3 0 24f
250 0 43 :4 0
80 :4 0 46 :2 0
47 :3 0 fa 254
256 :3 0 46 :2 0
77 :4 0 fd 258
25a :3 0 46 :2 0
81 :4 0 100 25c
25e :3 0 46 :2 0
4b :3 0 4c :3 0
82 :3 0 83 :3 0
263 264 0 103
262 266 4d :4 0
105 261 269 108
260 26b :3 0 46
:2 0 84 :4 0 10b
26d 26f :3 0 46
:2 0 49 :4 0 10e
271 273 :3 0 46
:2 0 b :3 0 111
275 277 :3 0 46
:2 0 49 :4 0 114
279 27b :3 0 117
251 27d :2 0 27f
11a 280 24e 27f
0 281 11c 0
2ab 3e :3 0 3f
:3 0 282 283 0
3e :3 0 4f :3 0
285 286 0 13
:2 0 2 :4 0 85
:2 0 51 :2 0 13
:2 0 11e 28b 28d
:3 0 121 287 28f
284 291 290 :2 0
41 :3 0 52 :3 0
293 294 0 43
:4 0 86 :4 0 46
:2 0 47 :3 0 125
298 29a :3 0 128
295 29c :2 0 29e
12b 29f 292 29e
0 2a0 12d 0
2ab 87 :3 0 88
:3 0 2a1 2a2 0
82 :3 0 83 :3 0
2a4 2a5 0 b
:3 0 89 :3 0 12f
2a3 2a9 :2 0 2ab
133 2ac 23d 2ab
0 2ad 137 0
48b 2e :3 0 8a
:3 0 f :3 0 10
:3 0 b :3 0 d
:3 0 2c :3 0 17
:3 0 18 :3 0 1e
:3 0 22 :3 0 2b
:3 0 20 :3 0 1b
:3 0 2a :3 0 14
:3 0 16 :3 0 35
:3 0 36 :3 0 2f
:3 0 32 :3 0 1d
:3 0 38 :3 0 11
:3 0 12 :3 0 3a
:3 0 21 :3 0 e
:3 0 139 2af 2ca
2ae 2cb 0 48b
4b :3 0 2e :3 0
1f :2 0 154 2cd
2d0 8b :2 0 8c
:2 0 159 2d2 2d4
:3 0 3e :3 0 3f
:3 0 2d6 2d7 0
3e :3 0 4f :3 0
2d9 2da 0 c
:2 0 2 :4 0 8d
:2 0 51 :2 0 13
:2 0 15c 2df 2e1
:3 0 15f 2db 2e3
2d8 2e5 2e4 :2 0
41 :3 0 52 :3 0
2e7 2e8 0 43
:4 0 8e :4 0 46
:2 0 47 :3 0 163
2ec 2ee :3 0 46
:2 0 77 :4 0 166
2f0 2f2 :3 0 46
:2 0 81 :4 0 169
2f4 2f6 :3 0 46
:2 0 4b :3 0 4c
:3 0 2e :3 0 16c
2fa 2fc 4d :4 0
16e 2f9 2ff 171
2f8 301 :3 0 46
:2 0 84 :4 0 174
303 305 :3 0 46
:2 0 49 :4 0 177
307 309 :3 0 46
:2 0 b :3 0 17a
30b 30d :3 0 46
:2 0 49 :4 0 17d
30f 311 :3 0 180
2e9 313 :2 0 315
183 316 2e6 315
0 317 185 0
343 3e :3 0 3f
:3 0 318 319 0
3e :3 0 4f :3 0
31b 31c 0 13
:2 0 2 :4 0 8f
:2 0 51 :2 0 13
:2 0 187 321 323
:3 0 18a 31d 325
31a 327 326 :2 0
41 :3 0 52 :3 0
329 32a 0 43
:4 0 90 :4 0 46
:2 0 47 :3 0 18e
32e 330 :3 0 191
32b 332 :2 0 334
194 335 328 334
0 336 196 0
343 87 :3 0 88
:3 0 337 338 0
4b :3 0 2e :3 0
1f :2 0 198 33a
33d b :3 0 89
:3 0 19b 339 341
:2 0 343 19f 43a
23 :3 0 1f :2 0
344 345 0 439
4b :3 0 2a :3 0
1f :2 0 1a3 347
34a 91 :2 0 13
:2 0 1a8 34c 34e
:3 0 5b :3 0 23
:3 0 6d :3 0 6e
:3 0 b :4 0 92
1 :8 0 35b 9
:3 0 70 :3 0 356
357 0 71 :3 0
358 359 0 35b
1ab 3ae 72 :3 0
9 :3 0 70 :3 0
35d 35e 0 71
:3 0 35f 360 0
362 1ae 364 1b0
363 362 :2 0 3ac
73 :3 0 9 :3 0
70 :3 0 367 368
0 71 :3 0 369
36a 0 3a4 3e
:3 0 3f :3 0 36c
36d 0 3e :3 0
4f :3 0 36f 370
0 74 :2 0 2
:4 0 93 :2 0 51
:2 0 13 :2 0 1b2
375 377 :3 0 1b5
371 379 36e 37b
37a :2 0 41 :3 0
52 :3 0 37d 37e
0 43 :4 0 94
:4 0 46 :2 0 47
:3 0 1b9 382 384
:3 0 46 :2 0 77
:4 0 1bc 386 388
:3 0 46 :2 0 78
:4 0 1bf 38a 38c
:3 0 46 :2 0 71
:3 0 1c2 38e 390
:3 0 46 :2 0 79
:4 0 1c5 392 394
:3 0 46 :2 0 7a
:3 0 7b :3 0 13
:2 0 7c :2 0 1c8
397 39b 1cc 396
39d :3 0 1cf 37f
39f :2 0 3a1 1d2
3a2 37c 3a1 0
3a3 1d4 0 3a4
1d6 3a7 :3 0 3a7
0 3a7 3a6 3a4
3a5 :6 0 3a9 4
:3 0 1d9 3ab 1db
3aa 3a9 :2 0 3ac
1dd :2 0 3ae 0
3ae 3ad 35b 3ac
:6 0 430 1 :3 0
4b :3 0 2b :3 0
1f :2 0 1e0 3b0
3b3 4b :3 0 8b
:2 0 23 :3 0 1f
:2 0 1e3 3b5 3b9
1e8 3b6 3bb :3 0
6d :3 0 5b :3 0
2b :3 0 6e :3 0
b :4 0 95 1
:8 0 3d8 96 :4 0
3c3 :3 0 89 :3 0
7d :2 0 1ed 3c6
3c7 :3 0 9 :3 0
70 :3 0 3c9 3ca
0 1f :2 0 3cb
3cc 0 3ce 1f0
3d5 9 :3 0 70
:3 0 3cf 3d0 0
97 :2 0 3d1 3d2
0 3d4 1f2 3d6
3c8 3ce 0 3d7
0 3d4 0 3d7
1f4 0 3d8 1f7
42b 72 :3 0 9
:3 0 70 :3 0 3da
3db 0 71 :3 0
3dc 3dd 0 3df
1fa 3e1 1fc 3e0
3df :2 0 429 73
:3 0 9 :3 0 70
:3 0 3e4 3e5 0
71 :3 0 3e6 3e7
0 421 3e :3 0
3f :3 0 3e9 3ea
0 3e :3 0 4f
:3 0 3ec 3ed 0
74 :2 0 2 :4 0
98 :2 0 51 :2 0
13 :2 0 1fe 3f2
3f4 :3 0 201 3ee
3f6 3eb 3f8 3f7
:2 0 41 :3 0 52
:3 0 3fa 3fb 0
43 :4 0 99 :4 0
46 :2 0 47 :3 0
205 3ff 401 :3 0
46 :2 0 77 :4 0
208 403 405 :3 0
46 :2 0 78 :4 0
20b 407 409 :3 0
46 :2 0 71 :3 0
20e 40b 40d :3 0
46 :2 0 79 :4 0
211 40f 411 :3 0
46 :2 0 7a :3 0
7b :3 0 13 :2 0
7c :2 0 214 414
418 218 413 41a
:3 0 21b 3fc 41c
:2 0 41e 21e 41f
3f9 41e 0 420
220 0 421 222
424 :3 0 424 0
424 423 421 422
:6 0 426 6 :3 0
225 428 227 427
426 :2 0 429 229
:2 0 42b 0 42b
42a 3d8 429 :6 0
42d 1 :3 0 22c
42e 3bc 42d 0
42f 22e 0 430
230 431 34f 430
0 432 233 0
439 2e :3 0 9a
:3 0 f :3 0 235
434 436 433 437
0 439 237 43b
2d5 343 0 43c
0 439 0 43c
23b 0 48b 3e
:3 0 3f :3 0 43d
43e 0 3e :3 0
4f :3 0 440 441
0 9b :2 0 2
:4 0 9c :2 0 51
:2 0 13 :2 0 23e
446 448 :3 0 241
442 44a 43f 44c
44b :2 0 41 :3 0
52 :3 0 44e 44f
0 43 :4 0 9d
:4 0 46 :2 0 47
:3 0 245 453 455
:3 0 46 :2 0 77
:4 0 248 457 459
:3 0 46 :2 0 81
:4 0 24b 45b 45d
:3 0 46 :2 0 4b
:3 0 4c :3 0 9
:3 0 70 :3 0 462
463 0 24e 461
465 4d :4 0 250
460 468 253 45f
46a :3 0 46 :2 0
84 :4 0 256 46c
46e :3 0 46 :2 0
49 :4 0 259 470
472 :3 0 46 :2 0
3 :3 0 25c 474
476 :3 0 46 :2 0
49 :4 0 25f 478
47a :3 0 262 450
47c :2 0 47e 265
47f 44d 47e 0
480 267 0 48b
87 :3 0 9e :3 0
481 482 0 9
:3 0 70 :3 0 484
485 0 3 :3 0
89 :3 0 269 483
489 :2 0 48b 26d
52c 9 :3 0 9f
:2 0 4 48c 48d
0 3e :3 0 3f
:3 0 48f 490 0
3e :3 0 4f :3 0
492 493 0 74
:2 0 2 :4 0 a0
:2 0 51 :2 0 13
:2 0 27b 498 49a
:3 0 27e 494 49c
491 49e 49d :2 0
41 :3 0 52 :3 0
4a0 4a1 0 43
:4 0 a1 :4 0 46
:2 0 47 :3 0 282
4a5 4a7 :3 0 285
4a2 4a9 :2 0 4c2
41 :3 0 52 :3 0
4ab 4ac 0 43
:4 0 a2 :4 0 46
:2 0 9 :3 0 a3
:3 0 4b1 4b2 0
288 4b0 4b4 :3 0
46 :2 0 84 :4 0
28b 4b6 4b8 :3 0
46 :2 0 9 :3 0
a4 :3 0 4bb 4bc
0 28e 4ba 4be
:3 0 291 4ad 4c0
:2 0 4c2 294 4c3
49f 4c2 0 4c4
297 0 4d4 a5
:3 0 3d :3 0 9
:3 0 a3 :3 0 a6
:3 0 9 :3 0 a4
:3 0 a7 :3 0 a8
:4 0 a9 1 :a 0
4d0 :2 0 4d4 4c6
4ce :2 0 8 :3 0
3d :3 0 4d2 :2 0
4d4 299 4d6 29d
4d5 4d4 :2 0 52a
73 :3 0 9 :3 0
70 :3 0 4d9 4da
0 71 :3 0 4db
4dc 0 522 3e
:3 0 3f :3 0 4de
4df 0 3e :3 0
4f :3 0 4e1 4e2
0 74 :2 0 2
:4 0 aa :2 0 51
:2 0 13 :2 0 29f
4e7 4e9 :3 0 2a2
4e3 4eb 4e0 4ed
4ec :2 0 41 :3 0
52 :3 0 4ef 4f0
0 43 :4 0 ab
:4 0 46 :2 0 47
:3 0 2a6 4f4 4f6
:3 0 2a9 4f1 4f8
:2 0 512 41 :3 0
52 :3 0 4fa 4fb
0 43 :4 0 78
:4 0 46 :2 0 71
:3 0 2ac 4ff 501
:3 0 46 :2 0 79
:4 0 2af 503 505
:3 0 46 :2 0 7a
:3 0 7b :3 0 13
:2 0 7c :2 0 2b2
508 50c 2b6 507
50e :3 0 2b9 4fc
510 :2 0 512 2bc
513 4ee 512 0
514 2bf 0 522
a5 :3 0 3d :3 0
a6 :3 0 9 :3 0
a4 :3 0 a7 :3 0
a8 :4 0 ac 1
:a 0 51e :2 0 522
516 51c :2 0 8
:3 0 3d :3 0 520
:2 0 522 2c1 525
:3 0 525 0 525
524 522 523 :6 0
527 1 :3 0 2c6
529 2c8 528 527
:2 0 52a 2ca :2 0
52c 2cd 52c 52b
48b 52a :6 0 52d
:2 0 2 14 52c
530 :3 0 52f 52d
531 :8 0 
2f9
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
42 1 40 1
47 1 4c 1
51 1 56 1
5b 1 60 1
65 1 6c 1
6a 1 71 1
77 1 7d 1
83 1 89 1
8f 1 94 1
9b 1 99 1
a0 1 a6 1
ac 1 b2 1
b8 1 be 1
c4 1 ca 1
d0 1 d6 1
db 1 e0 1
e6 1 ec 1
f2 1 f8 1
fd 1 103 1
109 1 10f 1
11c 1 128 2
12b 12d 2 130
132 2 134 136
2 138 13a 2
13c 13e 1 144
2 146 147 2
140 149 2 14b
14d 2 14f 151
2 153 155 2
157 159 2 15b
15d 4 124 12a
12f 15f 1 161
1 163 2 16d
16f 3 16b 16c
171 2 17a 17c
2 179 17e 1
180 1 182 2
1d9 1de 1 1e5
1 1e0 2 1f8
1fa 3 1f6 1f7
1fc 2 205 207
2 209 20b 2
20d 20f 2 211
213 2 215 217
3 21c 21d 21e
2 219 220 2
204 222 1 224
1 226 2 1ef
227 1 22b 1
1ea 2 1e8 22f
1 23a 2 236
23a 2 246 248
3 244 245 24a
2 253 255 2
257 259 2 25b
25d 1 265 2
267 268 2 25f
26a 2 26c 26e
2 270 272 2
274 276 2 278
27a 2 252 27c
1 27e 1 280
2 28a 28c 3
288 289 28e 2
297 299 2 296
29b 1 29d 1
29f 3 2a6 2a7
2a8 3 281 2a0
2aa 1 2ac 1a
2b0 2b1 2b2 2b3
2b4 2b5 2b6 2b7
2b8 2b9 2ba 2bb
2bc 2bd 2be 2bf
2c0 2c1 2c2 2c3
2c4 2c5 2c6 2c7
2c8 2c9 2 2ce
2cf 1 2d3 2
2d1 2d3 2 2de
2e0 3 2dc 2dd
2e2 2 2eb 2ed
2 2ef 2f1 2
2f3 2f5 1 2fb
2 2fd 2fe 2
2f7 300 2 302
304 2 306 308
2 30a 30c 2
30e 310 2 2ea
312 1 314 1
316 2 320 322
3 31e 31f 324
2 32d 32f 2
32c 331 1 333
1 335 2 33b
33c 3 33e 33f
340 3 317 336
342 2 348 349
1 34d 2 34b
34d 2 355 35a
1 361 1 35c
2 374 376 3
372 373 378 2
381 383 2 385
387 2 389 38b
2 38d 38f 2
391 393 3 398
399 39a 2 395
39c 2 380 39e
1 3a0 1 3a2
2 36b 3a3 1
3a7 1 366 2
364 3ab 2 3b1
3b2 2 3b7 3b8
1 3ba 2 3b4
3ba 1 3c5 2
3c4 3c5 1 3cd
1 3d3 2 3d5
3d6 2 3c2 3d7
1 3de 1 3d9
2 3f1 3f3 3
3ef 3f0 3f5 2
3fe 400 2 402
404 2 406 408
2 40a 40c 2
40e 410 3 415
416 417 2 412
419 2 3fd 41b
1 41d 1 41f
2 3e8 420 1
424 1 3e3 2
3e1 428 1 42b
1 42e 2 3ae
42f 1 431 1
435 3 346 432
438 2 43a 43b
2 445 447 3
443 444 449 2
452 454 2 456
458 2 45a 45c
1 464 2 466
467 2 45e 469
2 46b 46d 2
46f 471 2 473
475 2 477 479
2 451 47b 1
47d 1 47f 3
486 487 488 d
164 183 186 189
18c 18f 192 232
2ad 2cc 43c 480
48a 2 497 499
3 495 496 49b
2 4a4 4a6 2
4a3 4a8 2 4af
4b3 2 4b5 4b7
2 4b9 4bd 2
4ae 4bf 2 4aa
4c1 1 4c3 3
4c4 4cf 4d3 1
48e 2 4e6 4e8
3 4e4 4e5 4ea
2 4f3 4f5 2
4f2 4f7 2 4fe
500 2 502 504
3 509 50a 50b
2 506 50d 2
4fd 50f 2 4f9
511 1 513 4
4dd 514 51d 521
1 525 1 4d8
2 4d6 529 2b
1b 22 29 30
37 3e 45 4a
4f 54 59 5e
63 68 6f 75
7b 81 87 8d
92 97 9e a4
aa b0 b6 bc
c2 c8 ce d4
d9 de e4 ea
f0 f6 fb 101
107 10d 114 
1
4
0 
530
0
1
14
8
2f
0 1 2 1 4 1 6 1
0 0 0 0 0 0 0 0
0 0 0 0 
b 1 0
2 0 1
83 1 0
be 1 0
f2 1 0
56 1 0
16 1 0
ec 1 0
1d 1 0
b2 1 0
a0 1 0
40 1 0
d0 1 0
94 1 0
c4 1 0
109 1 0
60 1 0
71 1 0
3 1 0
47 1 0
51 1 0
e0 1 0
7d 1 0
b8 1 0
99 1 0
db 1 0
89 1 0
e6 1 0
32 1 0
f8 1 0
4c 1 0
fd 1 0
6a 1 0
8f 1 0
65 1 0
39 1 0
2b 1 0
7 1 0
d6 1 0
ca 1 0
5b 1 0
24 1 0
77 1 0
ac 1 0
a6 1 0
10f 1 0
103 1 0
0

/
SHOW ERRORS FUNCTION SP_ACPT_ETC_ASSIGN;
ALTER FUNCTION SP_ACPT_ETC_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Accept ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST DATES
    3 - ETC + FORECAST DATES
****************************************************************************************/
Prompt == FUNCTION SP_ACPT_ETC_WBS ==
CREATE OR REPLACE FUNCTION SP_ACPT_ETC_WBS wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ed
2 :e:
1FUNCTION:
1SP_ACPT_ETC_WBS:
1ID001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_PRJ_ASSIGNMENT_ID:
132:
1H_PROJECT_ID:
1H_RANK:
1200:
1H_REC_USER:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_TA_START_DT:
1TIMESTAMP:
1H_TA_FINISH_DT:
1H_START_DATE:
1H_FINISH_DATE:
1H_START_DT:
1H_FINISH_DT:
1H_FINISH_D:
1DATE:
1H_WEEK_OF:
1H_LAST_SUBMITTED:
1H_TASK_ID:
1H_TSK_ASSIGNMENT_ID:
1H_BIT_FLAG:
1H_BITFLAG:
10:
1H_CONTOUR:
1H_EFFORT:
1H_REMAINING:
1H_TOTAL:
1H_TYPE:
1H_PASSED:
1H_CONSTR_DT:
1H_DAYOFYEAR:
1H_FINISH_TIME:
18:
1H_MINUTE:
1H_CONSTR_TYPE:
1H_ETC:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_SCHED_START:
1H_SCHED_FINISH:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_SD:
1H_FD:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_TPH_DELETE:
1H_NOT_EFFORT_PA:
1H_FF_FLAG:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
1CURSOR:
1CAWTSK:
1PROJECT_ID:
1ELEMENT_ID:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1COALESCE:
1PLANNED_START:
1SCHED_START:
1FORECAST_FINISH:
1PLANNED_FINISH:
1SCHED_FINISH:
1TMT_WBS:
1RANK:
1TYPE_ID:
1PMO_CNST:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1WORK_TODATE:
1ETC:
1SELECT PROJECT_ID, ELEMENT_ID, SCHED_EFFORT+PLANNED_EFFORT,:n         CASE WH+
1EN FORECAST_START IS NULL THEN COALESCE(PLANNED_START, SCHED_START) ELSE FORE+
1CAST_START END,:n         CASE WHEN FORECAST_FINISH IS NULL THEN COALESCE(PLA+
1NNED_FINISH, SCHED_FINISH) ELSE FORECAST_FINISH END:n         FROM TMT_WBS WH+
1ERE RANK LIKE h_rank AND TYPE_ID IN (pmo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,+
1pmo_cnst.SC_TASK_TYPE2,pmo_cnst.SC_TASK_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.+
1SC_PERSONAL_TASK,pmo_cnst.SC_ACTIVE_ADM_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pm+
1o_cnst.SC_WBS_CHANGE_REQUEST_TASK,pmo_cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.S+
1C_WBS_RISK_TASK,pmo_cnst.SC_WBS_ISSUE_TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,p+
1mo_cnst.SC_WBS_DEFECT_TASK,pmo_cnst.SC_WBS_SERVICE_REQUEST_TASK):n         AN+
1D (((SCHED_EFFORT+PLANNED_EFFORT) > 0 AND ((SCHED_EFFORT+PLANNED_EFFORT-WORK_+
1TODATE) <> ETC)) OR:n         (FORECAST_START IS NOT NULL OR FORECAST_FINISH +
1IS NOT NULL)) ORDER BY COALESCE(PLANNED_START, SCHED_START):
1CAWASS:
1TSK_ASSIGNMENT_ID:
1PROJECT_ASSIGNMENT_ID:
1SCHED_WORK:
1PLANNED_WORK:
1C_CONTOUR:
1LAST_SUBMITTED:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1BIT_FLAG:
1MILESTONE_PERCENT:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1TASK_ID:
1SELECT:n         TSK_ASSIGNMENT_ID,:n         PROJECT_ASSIGNMENT_ID,:n       +
1  SCHED_WORK+PLANNED_WORK,:n         FORECAST_START,:n         FORECAST_FINIS+
1H,:n         CASE WHEN h_bitflag = 2 AND FORECAST_START IS NuLL THEN 0 ELSE E+
1TC END,:n         SCHED_WORK+PLANNED_WORK - WORK_TODATE,:n         ETC,:n    +
1     C_CONTOUR,:n         LAST_SUBMITTED,:n         CASE WHEN FORECAST_FINISH+
1 IS NOT NuLL AND FORECAST_START IS NuLL AND FORECAST_FINISH BETWEEN COALESCE(+
1PLANNED_START, SCHED_START) AND COALESCE(PLANNED_FINISH, SCHED_FINISH) THEN 1+
1 ELSE 0 END,:n         UNRESOLVED_START,:n         UNRESOLVED_FINISH,:n      +
1   BILLABLE,:n         CAPITAL_EXPENSE,:n         REGULAR_COST,:n         REG+
1ULAR_RATE,:n         BIT_FLAG,:n         MILESTONE_PERCENT,:n         RESOURC+
1E_ID,:n         RESOURCE_TYPE,:n         WORK_TODATE:n         FROM TASK_ASSI+
1GNMENTS:n         WHERE PROJECT_ID = h_project_id:n         AND TASK_ID = h_t+
1ask_id:n         AND (((SCHED_WORK+PLANNED_WORK) > 0:n         AND ((SCHED_WO+
1RK + PLANNED_WORK - WORK_TODATE) <> ETC)):n         OR (FORECAST_START IS NOT+
1 NULL OR FORECAST_FINISH IS NOT NULL)):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_ACPT_ETC_WBS(:
1':
1, :
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
1106:
1+:
1FPUT:
1               ENTER:: SP_ACPT_ETC_WBS(107) :: cplan.sql(22088) :: :
1RTRIM:
1SELECT RTRIM(RANK), TYPE_ID INTO h_rank, h_type:n      FROM TMT_WBS WHERE ELE+
1MENT_ID = id001/*HOST(h_id)*/:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1125:
1           EXCEPTION:: SP_ACPT_ETC_WBS(126) :: cplan.sql(22107) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_SUCCESS:
1IS NOT NULL:
1%:
1-:
1OPEN:
1LOOP:
1FOUND:
1100:
1!=:
1EXIT:
12:
1FC_ACPT_DURATION:
1FC_ACPT_EFFORT:
1ELSIF:
1CANNOT_ACCEPT_FROM_PROJECT_AFF:
1CLOSE:
1232:
1           EXCEPTION:: SP_ACPT_ETC_WBS(233) :: cplan.sql(22214) :: :
1>:
1CONSTRAINT_DT:
1CONSTRAINT_TYPE:
1SELECT CONSTRAINT_DT, CONSTRAINT_TYPE, FORECAST_START, FORECAST_FINISH:n     +
1             INTO h_constr_DT, h_constr_type, h_start_DT, h_finish_DT:n      +
1            FROM TMT_WBS WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_t+
1ask_id:
1256:
1           EXCEPTION:: SP_ACPT_ETC_WBS(257) :: cplan.sql(22238) :: :
1TO_DATE:
1UPDATE TMT_WBS SET:n                        CONSTRAINT_DT =:n                +
1        CASE:n                        WHEN h_constr_type IN (1,2,3,4) AND TO_+
1DATE(SubStr(h_constr_DT, 1, 10)) < TO_DATE(SubStr(h_finish_DT, 1, 10)) THEN h+
1_finish_DT:n                        WHEN h_constr_type IN (0,5,6,7) THEN h_fi+
1nish_DT:n                        ELSE h_constr_DT:n                        EN+
1D,:n                        CONSTRAINT_TYPE =:n                        CASE:n+
1                        WHEN h_constr_type IN (1,2,3,4) AND TO_DATE(SubStr(h_+
1constr_DT, 1, 10)) < TO_DATE(SubStr(h_finish_DT, 1, 10)) THEN 2:n            +
1            WHEN h_constr_type IN (0,5,6,7) THEN 2:n                        E+
1LSE h_constr_type:n                        END:n                        WHERE+
1 PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1TRUE:
1292:
1           EXCEPTION:: SP_ACPT_ETC_WBS(293) :: cplan.sql(22274) :: :
1UPDATE TMT_WBS SET CONSTRAINT_DT = h_finish_DT, CONSTRAINT_TYPE = 2:n        +
1                WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1312:
1           EXCEPTION:: SP_ACPT_ETC_WBS(313) :: cplan.sql(22294) :: :
1IS NULL:
1UPDATE TMT_WBS SET:n                        CONSTRAINT_DT =:n                +
1        CASE:n                        WHEN h_constr_type IN (0,5,6,7) AND TO_+
1DATE(SubStr(h_constr_DT, 1, 10)) > TO_DATE(SubStr(h_start_DT, 1, 10)) THEN h_+
1start_DT:n                        WHEN h_constr_type IN (1,2,3,4) THEN h_star+
1t_DT:n                        ELSE h_constr_DT:n                        END,+
1:n                        CONSTRAINT_TYPE =:n                        CASE:n  +
1                      WHEN h_constr_type IN (0,5,6,7) AND TO_DATE(SubStr(h_co+
1nstr_DT, 1, 10)) > TO_DATE(SubStr(h_start_DT, 1, 10)) THEN 6:n               +
1         WHEN h_constr_type IN (1,2,3,4) THEN 6:n                        ELSE+
1 h_constr_type:n                        END:n                        WHERE PR+
1OJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1347:
1           EXCEPTION:: SP_ACPT_ETC_WBS(348) :: cplan.sql(22329) :: :
1UPDATE TMT_WBS SET CONSTRAINT_DT = h_start_DT, CONSTRAINT_TYPE = 6:n         +
1               WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1367:
1           EXCEPTION:: SP_ACPT_ETC_WBS(368) :: cplan.sql(22349) :: :
1388:
1           EXCEPTION:: SP_ACPT_ETC_WBS(389) :: cplan.sql(22370) :: :
1NLEN:
1LENGTH:
1NOT:
1MOD:
14:
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1INVALID_RANK_LIKE:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_PROPOSED_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PROP+
1OSED_BIT):n            WHERE PROJECT_ID = h_project_id AND RANK LIKE h_rank:
1425:
1           EXCEPTION:: SP_ACPT_ETC_WBS(426) :: cplan.sql(22407) :: :
1FC_ROLLUP:
1442:
1       RETURN_STATUS:: SP_ACPT_ETC_WBS(443) :: cplan.sql(22424) :: :
1STATE:: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1449:
1           EXCEPTION:: SP_ACPT_ETC_WBS(450) :: cplan.sql(22431) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1461:
1           EXCEPTION:: SP_ACPT_ETC_WBS(462) :: cplan.sql(22443) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
930
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :3b a0 12a bd b7 11 a4 b1
a0 f4 b4 bf c8 :30 a0 12a bd
b7 11 a4 b1 a3 :2 a0 6b 1c
81 b0 :2 a0 6b :2 a0 6b 6e a5
b a 10 :2 a0 6b 6e :2 a0 6b
6e a5 b 6e 7e a0 b4 2e
6e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 d
:2 a0 d a0 51 d :8 a0 12a :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 7e b4 2e :2 5a a 10 :3 a0
7e 6e b4 2e :2 51 a5 b d
a0 7e 51 b4 2e d :2 a0 e9
dd b3 :7 a0 e9 d3 5 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 2b b7
19 3c :2 a0 51 a5 b 7e 51
b4 2e :2 a0 51 a5 b 7e 51
b4 2e :3 a0 6b d :7 a0 a5 b
d :2 a0 6b a0 d :3 a0 51 a5
b 7e 51 b4 2e d b7 19
3c b7 a0 4d d a0 4d d
:2 a0 e9 dd b3 :18 a0 e9 d3 5
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
2b b7 19 3c :1c a0 a5 b d
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 51 a5 b 7e 51 b4 2e
d a0 b7 :2 a0 51 a5 b a0
7e a0 6b b4 2e :3 a0 51 a5
b 7e 51 b4 2e d b7 :2 19
3c b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 a0 4d d a0 4d
d :d a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f a0 7e b4 2e 5a
a0 7e b4 2e 5a :1b a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :8 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :2 19
3c a0 b7 a0 7e b4 2e :2 5a
a0 7e b4 2e :2 5a a 10 a0
7e b4 2e 5a :1b a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :2 19 3c b7 19 3c b7 :2 19
3c b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
51 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b :2 7e 51 b4 2e
b4 2e 5a a 10 a3 a0 1c
51 81 b0 a0 7e b4 2e 5a
:4 a0 a5 b 51 a5 b d 51
7e 51 b4 2e a0 7e 51 b4
2e a 10 :2 a0 7e 51 b4 2e
d b7 19 3c b7 19 3c a0
7e 51 b4 2e 7e b4 2e :2 a0
7e 51 b4 2e 5a 7e 51 b4
2e 52 10 :2 a0 6b :2 a0 6b :2 a0
a5 57 b7 19 3c b7 a4 b1
11 4f :b a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :3 a0 a5 b d b7 19
3c b7 19 3c :2 a0 51 a5 b
7e 51 b4 2e :2 a0 6b :2 a0 6b
d a0 b7 :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 51 a5
b d b7 :2 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 :2 a0 6b :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
:2 a0 6b b4 2e 7e 6e b4 2e
7e :2 a0 6b b4 2e a5 57 b7
19 3c :9 a0 12a e9 dd :2 a0 65
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
:7 a0 12a e9 dd :2 a0 65 b7 a4
b1 11 4f b7 a6 9 a4 b1
11 68 4f 1d 17 b5 
930
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dd cb aa cf d0
d8 ca fa e8 c7 ec ed f5
e7 117 105 e4 109 10a 112 104
133 122 126 12e 101 14b 13a 13e
146 121 167 156 15a 162 11e 17f
16e 172 17a 155 19b 18a 18e 196
152 1b3 1a2 1a6 1ae 189 1cf 1be
1c2 1ca 186 1e7 1d6 1da 1e2 1bd
203 1f2 1f6 1fe 1ba 21f 20a 20e
211 212 21a 1f1 23c 22a 1ee 22e
22f 237 229 259 247 226 24b 24c
254 246 275 264 268 243 270 263
291 280 284 260 28c 27f 2ad 29c
2a0 27c 2a8 29b 2c9 2b8 2bc 298
2c4 2b7 2e5 2d4 2d8 2b4 2e0 2d3
301 2f0 2f4 2d0 2fc 2ef 31d 30c
310 2ec 318 30b 339 328 32c 334
308 351 340 344 34c 327 36e 35c
324 360 361 369 35b 38a 379 37d
358 385 378 3a6 395 399 375 3a1
394 3c2 3b1 3b5 391 3bd 3b0 3de
3cd 3d1 3ad 3d9 3cc 3fa 3e9 3ed
3c9 3f5 3e8 416 405 409 411 3e5
42e 41d 421 429 404 44a 439 43d
401 445 438 466 455 459 435 461
454 482 471 475 451 47d 470 49e
48d 491 46d 499 48c 4ba 4a9 4ad
489 4b5 4a8 4d6 4c5 4c9 4d1 4a5
4ee 4dd 4e1 4e9 4c4 50a 4f9 4fd
4c1 505 4f8 526 515 519 4f5 521
514 542 531 535 511 53d 530 55e
54d 551 52d 559 54c 57a 569 56d
549 575 568 596 585 589 591 565
5b1 59d 5a1 5a9 5ac 584 5b8 5bc
581 5cd 5d0 5d4 5d8 5dc 5e0 5e4
5e8 5ec 5f0 5f4 5f8 5fc 600 604
608 60c 610 614 618 61c 620 624
628 62c 630 634 638 63c 640 644
648 64c 650 654 658 65c 660 664
668 66c 670 674 678 67c 680 684
688 68c 690 694 698 69c 6a0 6a4
6a8 6ac 6b0 6b4 6b8 6bc 6c0 6cc
6d1 6d3 6df 6e3 6e5 6e9 6fa 6fb
6fe 702 706 70a 70e 712 716 71a
71e 722 726 72a 72e 732 736 73a
73e 742 746 74a 74e 752 756 75a
75e 762 766 76a 76e 772 776 77a
77e 782 786 78a 78e 792 796 79a
79e 7a2 7a6 7aa 7ae 7b2 7b6 7ba
7be 7c2 7ce 7d3 7d5 7e1 7e5 803
7eb 7ef 7f3 7f6 7fe 7ea 80a 80e
7e7 812 816 81a 81d 822 823 1
825 82a 82e 832 835 83a 83e 842
845 84a 84b 84d 852 855 859 85a
85f 864 867 86c 86d 872 875 879
87a 87f 882 887 888 88d 890 895
896 89b 89e 8a2 8a6 8aa 8ab 8ad
8b2 8b3 8b5 8b6 8bb 8be 8c3 8c4
8c9 8cc 8d1 8d2 8d7 8da 8de 8df
8e4 8e7 8ec 8ed 8f2 8f5 8fa 8fb
900 901 906 908 90c 90f 913 917
91a 91e 922 925 928 92d 930 933
936 937 93c 93d 1 93f 944 948
94c 94f 954 959 95c 960 961 966
967 96c 96e 972 975 979 97d 981
985 989 98d 991 994 998 99c 9a0
9a4 9a8 9ac 9b0 9b4 9b8 9c4 9c8
9cc 9cf 9d3 9d7 9d9 9dd 9e1 9e5
9e8 9ec 9f0 9f2 9f3 9f8 1 9fc
a00 a04 a07 a0b a0f a13 a17 a1a
a1e a22 a25 a28 a2d a30 a33 a36
a37 a3c a3d 1 a3f a44 a48 a4c
a4f a54 a59 a5c a60 a61 a66 a69
a6e a6f a74 a77 a7c a7d a82 a85
a89 a8a a8f a92 a97 a98 a9d aa0
aa4 aa8 aab aae aaf ab1 ab2 ab7
ab8 abd abf ac3 ac6 ac8 acc ace
ada adc ade adf ae4 ae8 aea af6
af8 afc b00 b03 b07 b0a b0e b11
b12 b17 b1a b1e b21 b22 b27 b2a
1 b2d b32 b36 b3a b3e b41 b46
b47 b4c b4f b52 b53 b55 b59 b5d
b60 b63 b64 b69 b6d b71 b75 b7a
b7e b7f b83 b87 b8b b8f b93 b97
b9b ba0 ba5 ba9 bad bb1 bb6 bba
bbe bc1 bc4 bc8 bca bce bd2 bd5
bd8 bdc bde be2 be6 be9 bed bf1
bf4 bf8 bfb bff c02 c03 c08 c0b
c0f c15 c17 c1b c1e c22 c26 c29
c2a c2c c2f c32 c33 c38 c3c c40
c43 c44 c46 c49 c4c c4d c52 c56
c5a c5e c61 c65 c69 c6d c71 c75
c79 c7d c81 c82 c84 c88 c8c c90
c93 c97 c9b c9f ca3 ca7 caa cab
cad cb0 cb3 cb4 cb9 cbd cbf cc3
cc6 cc8 ccc ccd cd1 cd5 cd6 cda
cde ce2 ce7 ceb cec cf0 cf4 cf8
cfc d00 d04 d08 d0c d10 d14 d18
d1c d20 d24 d28 d2c d30 d34 d38
d3c d40 d44 d48 d4c d51 d56 d5a
d5e d62 d67 d6b d6f d72 d75 d79
d7b d7f d83 d86 d89 d8d d8f d93
d97 d9a d9e da2 da5 da9 dac db0
db3 db4 db9 dbc dc0 dc6 dc8 dcc
dcf dd3 dd7 ddb ddf de3 de7 deb
def df3 df7 dfb dff e03 e07 e0b
e0f e13 e17 e1b e1f e23 e27 e2b
e2f e33 e37 e3b e3f e40 e42 e46
e4a e4e e51 e52 e54 e57 e5a e5b
e60 e64 e68 e6c e6f e70 e72 e75
e78 e79 e7e e82 e86 e88 e8c e90
e93 e94 e96 e9a e9d ea1 ea4 ea5
eaa eae eb2 eb6 eb9 eba ebc ebf
ec2 ec3 ec8 ecc ece ed2 ed6 ed9
edb edf ee6 eea eee ef3 ef5 ef9
efd f00 f04 f08 f0a f0e f12 f16
f19 f1d f21 f23 f24 f29 1 f2d
f31 f35 f38 f3c f40 f44 f48 f4b
f4f f53 f56 f59 f5e f61 f64 f67
f68 f6d f6e 1 f70 f75 f79 f7d
f80 f85 f8a f8d f91 f92 f97 f9a
f9f fa0 fa5 fa8 fad fae fb3 fb6
fba fbb fc0 fc3 fc8 fc9 fce fd1
fd5 fd9 fdc fdf fe0 fe2 fe3 fe8
fe9 fee ff0 ff4 ff7 ff9 ffd fff
100b 100d 100f 1010 1015 1019 101b 1027
1029 102d 1031 1034 1035 1037 103a 103d
103e 1043 1046 104a 104e 1051 1052 1054
1057 105a 105b 1060 1 1063 1068 106c
106d 1071 1075 1076 107a 107e 1082 1086
108a 108e 1092 1096 109a 109e 10a2 10a6
10aa 10ae 10ba 10be 10c2 10c5 10c9 10cd
10cf 10d3 10d7 10db 10de 10e2 10e6 10e8
10e9 10ee 1 10f2 10f6 10fa 10fd 1101
1105 1109 110d 1110 1114 1118 111b 111e
1123 1126 1129 112c 112d 1132 1133 1
1135 113a 113e 1142 1145 114a 114f 1152
1156 1157 115c 115f 1164 1165 116a 116d
1172 1173 1178 117b 117f 1180 1185 1188
118d 118e 1193 1196 119a 119e 11a1 11a4
11a5 11a7 11a8 11ad 11ae 11b3 11b5 11b9
11bc 11be 11c2 11c4 11d0 11d2 11d4 11d5
11da 11de 11e0 11ec 11ee 11f2 11f5 11f6
11fb 11fe 1202 1205 1206 120b 120e 1212
1216 121a 121e 1222 1226 122a 122e 1232
1236 123a 123e 1242 1246 124a 124e 1252
1256 125a 125e 1262 1266 126a 126e 1272
1276 127a 1286 128a 128f 1293 1296 1297
129c 12a0 12a4 12a7 12aa 12ae 12b0 12b4
12b8 12bb 12be 12c2 12c4 12c8 12cc 12cf
12d1 12d5 12d9 12dd 12e0 12e4 12e8 12ea
12eb 12f0 1 12f4 12f8 12fc 12ff 1303
1307 130b 130f 1312 1316 131a 131d 1320
1325 1328 132b 132e 132f 1334 1335 1
1337 133c 1340 1344 1347 134c 1351 1354
1358 1359 135e 1361 1366 1367 136c 136f
1374 1375 137a 137d 1381 1382 1387 138a
138f 1390 1395 1398 139c 13a0 13a3 13a6
13a7 13a9 13aa 13af 13b0 13b5 13b7 13bb
13be 13c0 13c4 13c6 13d2 13d4 13d6 13d7
13dc 13e0 13e2 13ee 13f0 13f2 13f6 13fa
13fe 1402 1406 140a 140e 1412 141e 1422
1427 142b 142e 142f 1434 1438 143c 143f
1442 1446 1448 144c 1450 1453 1456 145a
145c 1460 1464 1467 1469 146d 1471 1475
1478 147c 1480 1482 1483 1488 1 148c
1490 1494 1497 149b 149f 14a3 14a7 14aa
14ae 14b2 14b5 14b8 14bd 14c0 14c3 14c6
14c7 14cc 14cd 1 14cf 14d4 14d8 14dc
14df 14e4 14e9 14ec 14f0 14f1 14f6 14f9
14fe 14ff 1504 1507 150c 150d 1512 1515
1519 151a 151f 1522 1527 1528 152d 1530
1534 1538 153b 153e 153f 1541 1542 1547
1548 154d 154f 1553 1556 1558 155c 155e
156a 156c 156e 156f 1574 1578 157a 1586
1588 158a 158e 1592 1595 1599 159b 159f
15a2 15a3 15a8 15ab 15ae 15b2 15b5 15b6
15bb 15be 1 15c1 15c6 15ca 15cd 15ce
15d3 15d6 15da 15de 15e2 15e6 15ea 15ee
15f2 15f6 15fa 15fe 1602 1606 160a 160e
1612 1616 161a 161e 1622 1626 162a 162e
1632 1636 163a 163e 1642 164e 1652 1657
165b 165e 165f 1664 1668 166c 166f 1672
1676 1678 167c 1680 1683 1686 168a 168c
1690 1694 1697 1699 169d 16a1 16a5 16a8
16ac 16b0 16b2 16b3 16b8 1 16bc 16c0
16c4 16c7 16cb 16cf 16d3 16d7 16da 16de
16e2 16e5 16e8 16ed 16f0 16f3 16f6 16f7
16fc 16fd 1 16ff 1704 1708 170c 170f
1714 1719 171c 1720 1721 1726 1729 172e
172f 1734 1737 173c 173d 1742 1745 1749
174a 174f 1752 1757 1758 175d 1760 1764
1768 176b 176e 176f 1771 1772 1777 1778
177d 177f 1783 1786 1788 178c 178e 179a
179c 179e 179f 17a4 17a8 17aa 17b6 17b8
17ba 17be 17c2 17c6 17ca 17ce 17d2 17d6
17da 17e6 17ea 17ef 17f3 17f6 17f7 17fc
1800 1804 1807 180a 180e 1810 1814 1818
181b 181e 1822 1824 1828 182c 182f 1831
1835 1839 183d 1840 1844 1848 184a 184b
1850 1 1854 1858 185c 185f 1863 1867
186b 186f 1872 1876 187a 187d 1880 1885
1888 188b 188e 188f 1894 1895 1 1897
189c 18a0 18a4 18a7 18ac 18b1 18b4 18b8
18b9 18be 18c1 18c6 18c7 18cc 18cf 18d4
18d5 18da 18dd 18e1 18e2 18e7 18ea 18ef
18f0 18f5 18f8 18fc 1900 1903 1906 1907
1909 190a 190f 1910 1915 1917 191b 191e
1920 1924 1926 1932 1934 1936 1937 193c
1940 1942 194e 1950 1952 1956 195a 195d
195f 1963 1967 196a 196c 1970 1973 1975
1979 197d 1980 1982 1986 198d 1991 1995
199a 199c 19a0 19a4 19a7 19ab 19af 19b1
19b5 19b9 19bd 19c0 19c4 19c8 19ca 19cb
19d0 1 19d4 19d8 19dc 19df 19e3 19e7
19eb 19ef 19f2 19f6 19fa 19fd 1a00 1a05
1a08 1a0b 1a0e 1a0f 1a14 1a15 1 1a17
1a1c 1a20 1a24 1a27 1a2c 1a31 1a34 1a38
1a39 1a3e 1a41 1a46 1a47 1a4c 1a4f 1a54
1a55 1a5a 1a5d 1a61 1a62 1a67 1a6a 1a6f
1a70 1a75 1a78 1a7c 1a80 1a83 1a86 1a87
1a89 1a8a 1a8f 1a90 1a95 1a97 1a9b 1a9e
1aa0 1aa4 1aa6 1ab2 1ab4 1ab6 1ab7 1abc
1ac0 1ac2 1ace 1ad0 1ad4 1ad8 1adb 1adc
1ade 1ae1 1ae4 1ae5 1aea 1aed 1af1 1af5
1af8 1af9 1afb 1afe 1b01 1b04 1b05 1b0a
1b0b 1b10 1 1b13 1b30 1b1c 1b20 1b28
1b2b 1b1b 1b37 1b18 1b3b 1b3c 1b41 1b44
1b48 1b4c 1b50 1b54 1b55 1b57 1b5a 1b5b
1b5d 1b61 1b64 1b67 1b6a 1b6b 1b70 1b74
1b77 1b7a 1b7b 1 1b80 1b85 1b89 1b8d
1b90 1b93 1b94 1b99 1b9d 1b9f 1ba3 1ba6
1ba8 1bac 1baf 1bb3 1bb6 1bb9 1bba 1bbf
1bc2 1bc3 1bc8 1bcc 1bd0 1bd3 1bd6 1bd7
1bdc 1bdf 1be2 1be5 1be6 1 1beb 1bf0
1bf4 1bf8 1bfb 1bff 1c03 1c06 1c0a 1c0e
1c0f 1c14 1c16 1c1a 1c1d 1c1f 1c23 1c25
1c31 1c33 1c37 1c3b 1c3f 1c43 1c47 1c4b
1c4f 1c53 1c57 1c5b 1c5f 1c6b 1c6f 1c74
1c78 1c7b 1c7c 1c81 1c85 1c89 1c8c 1c8f
1c93 1c95 1c99 1c9d 1ca0 1ca3 1ca7 1ca9
1cad 1cb1 1cb4 1cb6 1cba 1cbe 1cc2 1cc5
1cc9 1ccd 1ccf 1cd0 1cd5 1 1cd9 1cdd
1ce1 1ce4 1ce8 1cec 1cf0 1cf4 1cf7 1cfb
1cff 1d02 1d05 1d0a 1d0d 1d10 1d13 1d14
1d19 1d1a 1 1d1c 1d21 1d25 1d29 1d2c
1d31 1d36 1d39 1d3d 1d3e 1d43 1d46 1d4b
1d4c 1d51 1d54 1d59 1d5a 1d5f 1d62 1d66
1d67 1d6c 1d6f 1d74 1d75 1d7a 1d7d 1d81
1d85 1d88 1d8b 1d8c 1d8e 1d8f 1d94 1d95
1d9a 1d9c 1da0 1da3 1da5 1da9 1dab 1db7
1db9 1dbb 1dbc 1dc1 1dc5 1dc7 1dd3 1dd5
1dd9 1ddd 1de1 1de2 1de4 1de8 1dea 1dee
1df1 1df3 1df7 1dfa 1dfe 1e02 1e05 1e06
1e08 1e0b 1e0e 1e0f 1e14 1e18 1e1c 1e1f
1e23 1e27 1e2a 1e2e 1e32 1e34 1e38 1e3c
1e3f 1e40 1e42 1e45 1e48 1e49 1e4e 1e52
1e56 1e59 1e5d 1e61 1e64 1e65 1e67 1e6b
1e6d 1e71 1e75 1e78 1e7c 1e80 1e83 1e87
1e8b 1e8e 1e91 1e96 1e99 1e9c 1e9f 1ea0
1ea5 1ea6 1 1ea8 1ead 1eb1 1eb5 1eb8
1ebd 1ec2 1ec5 1ec9 1eca 1ecf 1ed2 1ed7
1ed8 1edd 1ee0 1ee5 1ee6 1eeb 1eee 1ef2
1ef6 1efa 1efe 1f01 1f02 1f04 1f09 1f0a
1f0c 1f0d 1f12 1f15 1f1a 1f1b 1f20 1f23
1f28 1f29 1f2e 1f31 1f35 1f36 1f3b 1f3e
1f43 1f44 1f49 1f4a 1f4f 1f51 1f55 1f58
1f5c 1f60 1f63 1f67 1f6b 1f6e 1f72 1f76
1f77 1f7c 1f7e 1f82 1f86 1f89 1f8d 1f91
1f94 1f98 1f9c 1f9f 1fa2 1fa7 1faa 1fad
1fb0 1fb1 1fb6 1fb7 1 1fb9 1fbe 1fc2
1fc6 1fc9 1fce 1fd3 1fd6 1fda 1fdb 1fe0
1fe1 1fe6 1fea 1fee 1ff1 1ff6 1ffb 1ffe
2002 2006 2009 200a 200f 2012 2017 2018
201d 2020 2024 2028 202b 202c 2031 2032
2037 2039 203d 2040 2044 2048 204c 2050
2054 2058 205c 2060 2064 2070 2075 2079
207d 2081 2085 2087 2088 208d 1 2091
2095 2099 209c 20a0 20a4 20a8 20ac 20af
20b3 20b7 20ba 20bd 20c2 20c5 20c8 20cb
20cc 20d1 20d2 1 20d4 20d9 20dd 20e1
20e4 20e9 20ee 20f1 20f5 20f6 20fb 20fc
2101 2105 2109 210c 2111 2116 2119 211d
211e 2123 2126 212b 212c 2131 2134 2138
213c 213f 2142 2143 2145 2146 214b 214c
2151 2153 2157 215a 215e 2162 2166 216a
216e 2172 2176 2182 2187 218b 218f 2193
2197 2199 219d 219f 21ab 21ad 21af 21b0
21b5 21b9 21bb 21c7 21cb 21cd 21ce 21d7 
930
2
0 1 a 6 c :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 b 14 13 :2 b :2 4
f 18 17 :2 f :2 4 d 16 15
:2 d :2 4 f 18 17 :2 f :2 4 :3 12
:2 4 :3 13 :2 4 :3 11 :2 4 :3 12 :2 4 :3 f
:2 4 :3 10 :2 4 :3 f :2 4 :3 e :2 4 :3 15
:2 4 e 17 16 :2 e :2 4 18 21
20 :2 18 :2 4 f 18 17 :2 f :2 4
:2 e 1d e :2 4 :2 e 1d e :2 4
:2 d 1c d :2 4 :2 10 1f 10 :2 4
:2 c 1b c :2 4 :2 b 1a b :2 4
:2 d 1c d :2 4 :3 10 :2 4 :3 10 :2 4
12 1b 1a :2 12 :2 4 :2 d 1c d
:2 4 :2 12 21 12 :2 4 :2 a 19 a
:2 4 :2 f 1e f :2 4 :2 14 23 14
:2 4 :3 12 :2 4 :3 13 :2 4 :2 11 20 11
:2 4 :2 12 21 12 :2 4 :2 13 22 13
:2 4 :2 f 19 f :2 4 :2 f 19 f
:2 4 :3 9 :2 4 :3 9 :2 4 :2 f 1e f
:2 4 :2 16 25 16 :2 4 :2 11 20 11
:2 4 :2 14 23 14 :2 4 :2 e 1d e
:2 4 :3 10 :2 4 :2 16 2e 16 4 7
e 0 :2 7 11 1d 29 36 14
30 39 48 5a 14 31 3a 4a
5d f 1d 27 32 3e 47 4f
58 66 6f 7d 86 94 9d aa
b3 c4 cd e0 e9 fe 107 122
12b 143 14c 15d 166 178 181 199
1a2 1b5 1be 11 1e 38 45 54
64 b 29 50 59 68 a :6 7
e 0 :2 7 :3 a 15 :2 a 14 26
49 a 15 24 :3 a 14 34 4f
67 70 7f 90 99 a9 :b a f
10 1d e 18 11 1c 10 1d
2c 3c e 2c fffa :5 7 4 e
17 :3 e 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
57 5d 60 :2 57 6e 87 8 :2 6e
d 10 :2 6e 16 19 :2 6e b e
:2 6e 13 16 1f 27 :2 1f 34 :2 16
:2 6e b e :2 6e 13 16 :2 6e 1b
1e :2 6e 2a 2d :2 6e 32 35 :2 6e
:2 7 4d :2 4 7 :2 11 23 :2 2d 39
3c 4f 52 53 :2 4f :2 23 :3 7 :2 d
12 1e 61 64 :2 1e :2 7 56 :3 4
11 :2 4 12 :2 4 17 4 e 14
1b 28 30 c 1a 27 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 56 59 5a
:2 56 :2 29 :3 d :2 13 18 24 67 6a
:2 24 77 7a :2 24 7e 81 :2 24 8d
90 :2 24 98 9b :2 24 a7 aa b1
ba bd :2 aa :2 24 :2 d 5d :2 a :2 7
:4 13 :2 7 4 :3 1 8 :2 11 1c 1a
:2 25 :2 1a 7 :4 3b 3a 39 :3 7 11
18 1f 22 :2 18 27 2a :2 11 :2 7
13 14 :2 13 :2 7 c :4 7 10 1c
2a 35 3f 4d :3 a d 14 :2 d
:2 16 22 d 1a d :2 16 22 d
:4 a e :2 17 23 20 :2 2c :2 20 :3 d
3c :2 a d 16 20 :2 d 23 25
:2 23 10 19 24 :2 10 27 29 :2 27
10 25 :2 2e :2 10 1f 30 3e 49
57 66 :2 1f :2 10 :2 19 25 :2 10 1c
25 2f :2 1c 32 34 :2 1c 10 2b
:2 d 27 d 1d :2 d 1e :2 d 12
:4 d 16 :19 10 13 1a :2 13 :2 1c 28
13 20 13 :2 1c 28 13 :4 10 14
:2 1d 29 26 :2 32 :2 26 :3 13 42 :3 10
23 32 40 4b 60 25 33 41
50 5a 25 2c 37 49 54 25
35 41 54 25 31 3d 4d 57
25 34 3f :2 23 10 13 1c 2d
:2 13 30 32 :2 30 13 1f 28 32
:2 1f 35 37 :2 1f 13 10 34 16
1f 30 :2 16 35 33 :2 3e :2 33 13
26 2f 40 :2 26 43 45 :2 26 13
5d 34 :2 10 d 11 a 10 16
:3 10 :2 19 25 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5f
62 63 :2 5f :2 32 :3 16 :2 1c 21 2d
70 73 :2 2d 80 83 :2 2d 87 8a
:2 2d 96 99 :2 2d a1 a4 :2 2d b0
b3 ba c3 c6 :2 b3 :2 2d :2 16 66
:2 13 :2 10 :4 1c :2 10 d :3 a 11 1a
25 :2 11 28 2b :2 28 10 33 3c
46 :2 33 49 4b :2 49 32 :3 10 1e
:2 10 1f 10 1a 29 3a 4a 18
25 34 40 18 26 33 44 51
:2 13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 62
65 66 :2 62 :2 35 :3 19 :2 1f 24 30
73 76 :2 30 83 86 :2 30 8a 8d
:2 30 99 9c :2 30 a4 a7 :2 30 b3
b6 bd c6 c9 :2 b6 :2 30 :2 19 69
:2 16 :2 13 :4 1f :2 13 10 :3 4e :4 14 13
:4 17 16 20 19 1e 3d 45 4c
63 6b 72 8c 1e 3e 1e 19
1e 3d 45 4c 63 6b 72 :2 1e
1f 2c 3d 4a 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 68 6b
6c :2 68 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :4 30 20 2c 3c
49 1f 2c 3d 4a 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 68
6b 6c :2 68 :2 3b :3 1f :2 25 2a 36
79 7c :2 36 89 8c :2 36 90 93
:2 36 9f a2 :2 36 aa ad :2 36 b9
bc c3 cc cf :2 bc :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :7 13 10 2d
:4 18 17 16 :4 37 36 35 :2 16 :4 17
16 20 19 1e 3d 45 4c 63
6b 72 8b 1e 3e 1e 19 1e
3d 45 4c 63 6b 72 :2 1e 1f
2c 3d 4a 19 20 1c 28 :3 26
1c :2 25 31 1c 2d 1c :2 25 31
1c :4 19 16 1e 1c :2 25 31 1c
2c :2 19 :2 1e 1c :2 25 31 1c 1f
:2 29 3b :2 45 51 55 68 6b 6c
:2 68 :2 3b :3 1f :2 25 2a 36 79 7c
:2 36 89 8c :2 36 90 93 :2 36 9f
a2 :2 36 aa ad :2 36 b9 bc c3
cc cf :2 bc :2 36 :2 1f 6f :2 1c :2 19
:4 25 :2 19 16 :4 30 20 2c 3c 48
1f 2c 3d 4a 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 68 6b
6c :2 68 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :7 13 4d 2d :2 10
4e :2 d :4 a 7 b 50 a 10
:3 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6a 6d :2 27 7a 7d :2 27 81 84
:2 27 90 93 :2 27 9b 9e :2 27 aa
ad b4 bd c0 :2 ad :2 27 :2 10 60
:2 d :2 a :4 16 :2 a 7 :3 50 b 14
1e :2 b 21 23 :2 21 a 2b 34
3e :2 2b 41 43 44 :2 43 :2 41 2a
:2 a b :2 10 1e 10 b :4 f e
c 14 1d 24 :2 1d 2d :2 14 c
f 11 14 :2 11 1a 1f 22 :2 1f
:2 f c 14 19 1b :2 14 c 24
:2 c 23 :2 b 12 17 1a :2 17 :3 e
20 :2 25 29 :2 20 1f 2c 2f :2 2c
:2 e c :2 17 2b :2 34 47 4f :2 c
31 :2 b :2 a :3 47 14 20 2e 37
3e 4a 53 13 20 31 3b d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5c 5f 60 :2 5c :2 2f :3 13 :2 19
1e 2a 6d 70 :2 2a 7d 80 :2 2a
84 87 :2 2a 93 96 :2 2a 9e a1
:2 2a ad b0 b7 c0 c3 :2 b0 :2 2a
:2 13 63 :2 10 :2 d :4 19 :2 d a :3 47
a 1d 27 :2 1d a 47 :2 7 50
:2 4 7 10 21 :2 7 24 26 :2 24
7 :2 10 1c :2 25 7 4 28 a
13 24 :2 a 27 29 :2 27 7 :2 10
1c 25 36 :2 1c 7 2d 28 :2 4
7 :2 11 23 :2 2d 39 3c 4f 52
53 :2 4f :2 23 :3 7 :2 d 12 1e 61
64 :2 1e 71 74 :2 1e 78 7b :2 1e
85 88 91 99 :2 a2 :2 91 ad :2 88
:2 1e b5 b8 :2 1e c0 c3 :2 1e c8
cb :2 1e d1 d4 :2 1e :2 7 56 :3 4
:2 f 21 :2 2a 34 3b :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
53 56 57 :2 53 :2 26 :3 a :2 10 15
21 64 67 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 5a :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
50 53 54 :2 50 :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 57 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
930
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :7 b
:7 c :7 d :5 e :5 f
:5 10 :5 11 :5 12 :5 13
:5 14 :5 15 :5 16 :7 17
:7 18 :7 19 :6 1a :6 1b
:6 1c :6 1d :6 1e :6 1f
:6 20 :5 21 :5 22 :7 23
:6 24 :6 25 :6 26 :6 27
:6 28 :5 29 :5 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:5 30 :5 31 :6 32 :6 33
:6 34 :6 35 :6 36 :5 37
:6 38 :2 3a 0 :2 3a
:4 3b :5 3c :5 3d :22 3e
:6 3f :5 40 3b :5 3a
:2 42 0 :2 42 44
45 :2 46 47 48
:3 49 :3 4a 4b 4c
4d :9 4e 4f 50
51 52 53 54
55 56 57 58
59 5a :2 5b :2 5c
:2 5d :4 5e :2 5f 44
:5 42 :7 61 :b 63 :11 64
65 :2 64 :2 65 :2 64
:2 65 :2 64 :2 66 :2 64
:9 66 :2 64 :2 67 :2 64
:2 67 :2 64 :2 67 :2 64
:2 67 :2 64 :2 67 :4 64
:3 63 :11 6a :b 6b :3 6a
:3 6f :3 70 :3 71 :5 74
:3 75 74 :5 76 73
78 :5 79 :3 78 :2 7a
:5 7c :11 7d :24 7e :3 7d
:2 7b :6 7a 77 :3 62
:12 83 :c 84 :6 85 :5 89
8b :9 8c :3 8d :5 8e
8d :5 90 8f :3 8d
:a 93 :2 94 :3 93 :9 99
:9 9b :5 9d :a 9e :5 9f
:b a1 :3 9b 99 :3 a5
:3 a7 :5 aa ac ad
ae af b0 b1
b2 b3 b4 b5
b6 b7 b8 b9
ba bb bc bd
be bf c0 c1
c2 c3 :3 ad :3 c4
:5 c5 c4 :5 c7 c6
:3 c4 :a ca :2 cb :3 ca
:6 d0 :5 d1 :5 d2 :4 d3
:5 d4 :3 d5 :3 d0 :9 d7
:b d8 d9 d7 :b d9
:b da d9 :3 d7 ac
dc a3 :4 e0 :5 e1
df e3 :5 e4 :3 e3
:2 e5 :5 e7 :11 e8 :24 e9
:3 e8 :2 e6 :6 e5 e2
:3 a3 :16 f1 :3 f2 :3 f3
:4 f6 :4 f7 :5 f8 f6
:5 f9 f5 fb :5 fc
:3 fb :2 fd :5 ff :11 100
:24 101 :3 100 :2 fe :6 fd
fa :3 f1 :5 107 :5 109
10b 10c :8 10e :2 10f
110 112 :7 114 115
116 :4 118 10b :6 119
:5 11a 119 :5 11c 11b
:3 119 10a 11f :5 120
:3 11f :2 121 :5 123 :11 124
:24 125 :3 124 :2 122 :6 121
11e :4 109 :4 12b :4 12c
12b :6 12d :5 12e 12d
:5 130 12f :3 12d 12a
133 :5 134 :3 133 :2 135
:5 137 :11 138 :24 139 :3 138
:2 136 :6 135 132 :4 129
:3 109 13e 107 :e 13e
:5 140 142 143 :8 145
:2 146 147 149 :7 14b
14c 14d :4 14f 142
:6 150 :5 151 150 :5 153
152 :3 150 141 156
:5 157 :3 156 :2 158 :5 15a
:11 15b :24 15c :3 15b :2 159
:6 158 155 :4 140 :4 162
:4 163 162 :6 164 :5 165
164 :5 167 166 :3 164
161 16a :5 16b :3 16a
:2 16c :5 16e :11 16f :24 170
:3 16f :2 16d :6 16c 169
:4 160 :3 140 13e :3 107
:3 f1 a3 :3 99 8b
178 83 :4 17c :5 17d
17b 17f :5 180 :3 17f
:2 181 :5 183 :11 184 :24 185
:3 184 :2 182 :6 181 17e
:3 83 :19 18c :6 18e :5 190
:a 191 :c 192 :7 193 :3 192
:3 190 :15 196 :a 197 :3 196
:2 18f :3 18c :7 19c :4 19d
19c :6 19e :5 19f 19e
:5 1a1 1a0 :3 19e 19b
1a4 :5 1a5 :3 1a4 :2 1a6
:5 1a8 :11 1a9 :24 1aa :3 1a9
:2 1a7 :6 1a6 1a3 :3 18c
:6 1af :3 18c :3 83 :9 1b4
:7 1b5 1b6 1b4 :9 1b6
:9 1b7 1b6 :3 1b4 :11 1ba
:30 1bb :3 1ba :a 1bd 62
:3 1c0 :11 1c1 :b 1c2 :17 1c3
:3 1c1 :2 1c5 :3 1c6 :3 1c7
1c8 1c6 1c5 1c6
:3 1c9 :3 1c0 :2 1ca :5 1cc
:11 1cd :b 1ce :18 1cf :3 1cd
:2 1d1 1d2 :3 1d3 1d4
1d2 1d1 1d2 :3 1d5
:2 1cb :6 1ca 1bf :7 1

21d9
4
:3 0 1 :3 0 2
:a 0 92b 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 92b 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 929
0 b :6 0 f
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 929
0 d :6 0 c
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 929
0 e :6 0 c
:2 0 1b 4 :3 0
19 2c 2e :6 0
31 2f 0 929
0 10 :6 0 13
:2 0 1f 4 :3 0
1d 33 35 :6 0
38 36 0 929
0 11 :6 0 25
11e 0 23 4
:3 0 21 3a 3c
:6 0 3f 3d 0
929 0 12 :6 0
29 152 0 27
15 :3 0 41 :7 0
44 42 0 929
0 14 :6 0 15
:3 0 46 :7 0 49
47 0 929 0
16 :6 0 2d 186
0 2b 15 :3 0
4b :7 0 4e 4c
0 929 0 17
:6 0 15 :3 0 50
:7 0 53 51 0
929 0 18 :6 0
31 1ba 0 2f
15 :3 0 55 :7 0
58 56 0 929
0 19 :6 0 15
:3 0 5a :7 0 5d
5b 0 929 0
1a :6 0 35 1ee
0 33 1c :3 0
5f :7 0 62 60
0 929 0 1b
:6 0 1c :3 0 64
:7 0 67 65 0
929 0 1d :6 0
c :2 0 39 1c
:3 0 69 :7 0 6c
6a 0 929 0
1e :6 0 4 :3 0
c :2 0 37 6e
70 :6 0 73 71
0 929 0 1f
:6 0 13 :2 0 3d
4 :3 0 3b 75
77 :6 0 7a 78
0 929 0 20
:6 0 23 :2 0 41
4 :3 0 3f 7c
7e :6 0 81 7f
0 929 0 21
:6 0 23 :2 0 43
6 :3 0 83 :7 0
87 84 85 929
0 22 :6 0 23
:2 0 45 6 :3 0
89 :7 0 8d 8a
8b 929 0 24
:6 0 23 :2 0 47
6 :3 0 8f :7 0
93 90 91 929
0 25 :6 0 23
:2 0 49 6 :3 0
95 :7 0 99 96
97 929 0 26
:6 0 23 :2 0 4b
6 :3 0 9b :7 0
9f 9c 9d 929
0 27 :6 0 23
:2 0 4d 6 :3 0
a1 :7 0 a5 a2
a3 929 0 28
:6 0 51 324 0
4f 6 :3 0 a7
:7 0 ab a8 a9
929 0 29 :6 0
2d :2 0 53 15
:3 0 ad :7 0 b0
ae 0 929 0
2a :6 0 1c :3 0
b2 :7 0 b5 b3
0 929 0 2b
:6 0 23 :2 0 57
4 :3 0 55 b7
b9 :6 0 bc ba
0 929 0 2c
:6 0 23 :2 0 59
6 :3 0 be :7 0
c2 bf c0 929
0 2e :6 0 23
:2 0 5b 6 :3 0
c4 :7 0 c8 c5
c6 929 0 2f
:6 0 23 :2 0 5d
6 :3 0 ca :7 0
ce cb cc 929
0 30 :6 0 23
:2 0 5f 6 :3 0
d0 :7 0 d4 d1
d2 929 0 31
:6 0 63 401 0
61 6 :3 0 d6
:7 0 da d7 d8
929 0 32 :6 0
23 :2 0 65 15
:3 0 dc :7 0 df
dd 0 929 0
33 :6 0 15 :3 0
e1 :7 0 e4 e2
0 929 0 34
:6 0 23 :2 0 67
6 :3 0 e6 :7 0
ea e7 e8 929
0 35 :6 0 23
:2 0 69 6 :3 0
ec :7 0 f0 ed
ee 929 0 36
:6 0 3a :2 0 6b
6 :3 0 f2 :7 0
f6 f3 f4 929
0 37 :6 0 3a
:2 0 6d 39 :3 0
f8 :7 0 fc f9
fa 929 0 38
:6 0 71 4c1 0
6f 39 :3 0 fe
:7 0 102 ff 100
929 0 3b :6 0
23 :2 0 73 1c
:3 0 104 :7 0 107
105 0 929 0
3c :6 0 1c :3 0
109 :7 0 10c 10a
0 929 0 3d
:6 0 23 :2 0 75
6 :3 0 10e :7 0
112 10f 110 929
0 3e :6 0 23
:2 0 77 6 :3 0
114 :7 0 118 115
116 929 0 3f
:6 0 23 :2 0 79
6 :3 0 11a :7 0
11e 11b 11c 929
0 40 :6 0 23
:2 0 7b 6 :3 0
120 :7 0 124 121
122 929 0 41
:6 0 7f 581 0
7d 6 :3 0 126
:7 0 12a 127 128
929 0 42 :9 0
81 44 :3 0 12c
:7 0 12f 12d 0
929 0 43 :6 0
6 :3 0 131 0
2 :5 0 23 :2 0
135 132 133 929
0 45 :6 0 46
:3 0 47 :a 0 2
177 :4 0 137 13a
0 138 :3 0 48
:3 0 49 :3 0 4a
:3 0 4b :3 0 4c
:3 0 4d :3 0 4e
:3 0 4f :3 0 4c
:3 0 50 :3 0 4d
:3 0 51 :3 0 52
:3 0 50 :3 0 53
:3 0 54 :3 0 e
:3 0 55 :3 0 56
:3 0 57 :3 0 56
:3 0 58 :3 0 56
:3 0 59 :3 0 56
:3 0 5a :3 0 56
:3 0 5b :3 0 56
:3 0 5c :3 0 56
:3 0 5d :3 0 56
:3 0 5e :3 0 56
:3 0 5f :3 0 56
:3 0 60 :3 0 56
:3 0 61 :3 0 56
:3 0 62 :3 0 56
:3 0 63 :3 0 56
:3 0 64 :3 0 56
:3 0 65 :3 0 4a
:3 0 4b :3 0 4a
:3 0 4b :3 0 66
:3 0 67 :3 0 4c
:3 0 50 :3 0 4d
:3 0 4e :3 0 4f
:4 0 68 1 :8 0
178 137 13a 179
0 929 83 179
17b 178 17a :6 0
177 :7 0 179 46
:3 0 69 :a 0 3
1b2 :5 0 17d 180
0 17e :3 0 6a
:3 0 6b :3 0 6c
:3 0 6d :3 0 4c
:3 0 50 :3 0 22
:3 0 4c :3 0 67
:3 0 6c :3 0 6d
:3 0 66 :3 0 67
:3 0 6e :3 0 6f
:3 0 50 :3 0 4c
:3 0 50 :3 0 4d
:3 0 4e :3 0 4f
:3 0 4d :3 0 51
:3 0 52 :3 0 70
:3 0 71 :3 0 72
:3 0 73 :3 0 74
:3 0 75 :3 0 76
:3 0 77 :3 0 78
:3 0 79 :3 0 66
:3 0 7a :3 0 48
:3 0 d :3 0 7b
:3 0 1f :3 0 6c
:3 0 6d :3 0 6c
:3 0 6d :3 0 66
:3 0 67 :3 0 4c
:3 0 50 :4 0 7c
1 :8 0 1b3 17d
180 1b4 0 929
85 1b4 1b6 1b3
1b5 :6 0 1b2 :7 0
1b4 1be 1bf 0
87 9 :3 0 a
:2 0 4 1b8 1b9
0 1ba :7 0 1bd
1bb 0 929 0
7d :6 0 7e :3 0
7f :3 0 7e :3 0
80 :3 0 1c1 1c2
0 2 :4 0 89
1c3 1c5 1c0 1c7
1c6 :2 0 81 :3 0
82 :3 0 1c9 1ca
0 83 :4 0 7e
:3 0 84 :3 0 1cd
1ce 0 2 :4 0
8b 1cf 1d1 85
:4 0 86 :2 0 87
:3 0 8d 1d4 1d6
:3 0 88 :4 0 86
:2 0 89 :4 0 90
1d9 1db :3 0 86
:2 0 3 :3 0 93
1dd 1df :3 0 86
:2 0 89 :4 0 96
1e1 1e3 :3 0 86
:2 0 8a :4 0 99
1e5 1e7 :3 0 86
:2 0 4d :3 0 8b
:3 0 5 :3 0 9c
1eb 1ed 8c :4 0
9e 1ea 1f0 a1
1e9 1f2 :3 0 86
:2 0 8a :4 0 a4
1f4 1f6 :3 0 86
:2 0 89 :4 0 a7
1f8 1fa :3 0 86
:2 0 7 :3 0 aa
1fc 1fe :3 0 86
:2 0 89 :4 0 ad
200 202 :3 0 86
:2 0 8d :4 0 b0
204 206 :3 0 b3
1cb 208 :2 0 20a
b8 20b 1c8 20a
0 20c ba 0
889 7e :3 0 7f
:3 0 20d 20e 0
7e :3 0 8e :3 0
210 211 0 13
:2 0 2 :4 0 8f
:2 0 90 :2 0 13
:2 0 bc 216 218
:3 0 bf 212 21a
20f 21c 21b :2 0
81 :3 0 91 :3 0
21e 21f 0 83
:4 0 92 :4 0 86
:2 0 87 :3 0 c3
223 225 :3 0 c6
220 227 :2 0 229
c9 22a 21d 229
0 22b cb 0
889 22 :3 0 5
:3 0 22c 22d 0
889 10 :3 0 7
:3 0 22f 230 0
889 41 :3 0 23
:2 0 232 233 0
889 93 :3 0 54
:3 0 55 :3 0 e
:3 0 28 :3 0 53
:3 0 49 :3 0 3
:4 0 94 1 :8 0
243 9 :3 0 95
:3 0 23e 23f 0
96 :3 0 240 241
0 243 cd 296
97 :3 0 9 :3 0
95 :3 0 245 246
0 96 :3 0 247
248 0 24a d0
24c d2 24b 24a
:2 0 294 98 :3 0
9 :3 0 95 :3 0
24f 250 0 96
:3 0 251 252 0
28c 7e :3 0 7f
:3 0 254 255 0
7e :3 0 8e :3 0
257 258 0 99
:2 0 2 :4 0 9a
:2 0 90 :2 0 13
:2 0 d4 25d 25f
:3 0 d7 259 261
256 263 262 :2 0
81 :3 0 91 :3 0
265 266 0 83
:4 0 9b :4 0 86
:2 0 87 :3 0 db
26a 26c :3 0 86
:2 0 9c :4 0 de
26e 270 :3 0 86
:2 0 9d :4 0 e1
272 274 :3 0 86
:2 0 96 :3 0 e4
276 278 :3 0 86
:2 0 9e :4 0 e7
27a 27c :3 0 86
:2 0 9f :3 0 a0
:3 0 13 :2 0 a1
:2 0 ea 27f 283
ee 27e 285 :3 0
f1 267 287 :2 0
289 f4 28a 264
289 0 28b f6
0 28c f8 28f
:3 0 28f 0 28f
28e 28c 28d :6 0
291 4 :3 0 fb
293 fd 292 291
:2 0 294 ff :2 0
296 0 296 295
243 294 :6 0 889
1 :3 0 9 :3 0
95 :3 0 298 299
0 9 :3 0 a2
:2 0 a3 :3 0 29b
29d 0 104 29c
29f :3 0 2a0 :2 0
28 :3 0 a4 :2 0
107 2a3 2a4 :3 0
2a5 :2 0 2a6 :2 0
2a1 2a8 2a7 :2 0
e :3 0 9f :3 0
e :3 0 86 :2 0
a5 :4 0 109 2ad
2af :3 0 13 :2 0
f :2 0 10c 2ab
2b3 2aa 2b4 0
810 25 :3 0 a6
:2 0 13 :2 0 110
2b7 2b9 :3 0 2b6
2ba 0 810 a7
:3 0 47 :4 0 2bf
:2 0 810 2bd 2c0
:3 0 a8 :3 0 47
:3 0 d :3 0 1f
:3 0 25 :3 0 17
:3 0 18 :4 0 2c9
:2 0 6c2 2c2 2ca
:3 0 112 :3 0 47
:3 0 a9 :3 0 2cb
2cc :3 0 9 :3 0
95 :3 0 2ce 2cf
0 23 :2 0 2d0
2d1 0 2d3 118
2da 9 :3 0 95
:3 0 2d4 2d5 0
aa :2 0 2d6 2d7
0 2d9 11a 2db
2cd 2d3 0 2dc
0 2d9 0 2dc
11c 0 6c2 9
:3 0 95 :3 0 2dd
2de 0 9 :3 0
ab :2 0 a3 :3 0
2e0 2e2 0 121
2e1 2e4 :3 0 2e5
:2 0 ac :8 0 2e9
124 2ea 2e6 2e9
0 2eb 126 0
6c2 4d :3 0 25
:3 0 23 :2 0 128
2ec 2ef a2 :2 0
23 :2 0 12d 2f1
2f3 :3 0 4d :3 0
22 :3 0 23 :2 0
130 2f5 2f8 a2
:2 0 ad :2 0 135
2fa 2fc :3 0 45
:3 0 9 :3 0 95
:3 0 2ff 300 0
2fe 301 0 31d
43 :3 0 ae :3 0
d :3 0 1f :3 0
17 :3 0 18 :3 0
10 :3 0 138 304
30a 303 30b 0
31d 9 :3 0 95
:3 0 30d 30e 0
45 :3 0 30f 310
0 31d 29 :3 0
4d :3 0 29 :3 0
23 :2 0 13e 313
316 90 :2 0 13
:2 0 141 318 31a
:3 0 312 31b 0
31d 144 31e 2fd
31d 0 31f 149
0 320 14b 6bf
17 :4 0 321 322
0 6be 18 :4 0
324 325 0 6be
a7 :3 0 69 :4 0
32a :2 0 6be 328
32b :3 0 a8 :3 0
69 :3 0 20 :3 0
b :3 0 35 :3 0
17 :3 0 18 :3 0
25 :3 0 26 :3 0
30 :3 0 24 :3 0
1e :3 0 42 :3 0
14 :3 0 16 :3 0
3e :3 0 3f :3 0
38 :3 0 3b :3 0
21 :3 0 37 :3 0
11 :3 0 12 :3 0
36 :4 0 345 :2 0
3b7 32d 346 :3 0
14d :3 0 69 :3 0
a9 :3 0 347 348
:3 0 9 :3 0 95
:3 0 34a 34b 0
23 :2 0 34c 34d
0 34f 164 356
9 :3 0 95 :3 0
350 351 0 aa
:2 0 352 353 0
355 166 357 349
34f 0 358 0
355 0 358 168
0 3b7 9 :3 0
95 :3 0 359 35a
0 9 :3 0 ab
:2 0 a3 :3 0 35c
35e 0 16d 35d
360 :3 0 361 :2 0
ac :8 0 365 170
366 362 365 0
367 172 0 3b7
32 :3 0 af :3 0
d :3 0 1f :3 0
20 :3 0 b :3 0
35 :3 0 17 :3 0
18 :3 0 25 :3 0
26 :3 0 30 :3 0
24 :3 0 1e :3 0
42 :3 0 14 :3 0
16 :3 0 3e :3 0
3f :3 0 38 :3 0
3b :3 0 21 :3 0
37 :3 0 11 :3 0
12 :3 0 36 :3 0
22 :3 0 10 :3 0
174 369 384 368
385 0 3b7 4d
:3 0 32 :3 0 23
:2 0 18f 387 38a
a2 :2 0 23 :2 0
194 38c 38e :3 0
29 :3 0 4d :3 0
29 :3 0 23 :2 0
197 391 394 90
:2 0 13 :2 0 19a
396 398 :3 0 390
399 0 39c b0
:3 0 19d 3b5 4d
:3 0 32 :3 0 23
:2 0 19f 39d 3a0
56 :3 0 a2 :2 0
b1 :3 0 3a2 3a4
0 1a4 3a3 3a6
:3 0 41 :3 0 4d
:3 0 41 :3 0 23
:2 0 1a7 3a9 3ac
90 :2 0 13 :2 0
1aa 3ae 3b0 :3 0
3a8 3b1 0 3b3
1ad 3b4 3a7 3b3
0 3b6 38f 39c
0 3b6 1af 0
3b7 1b2 3b9 a8
:4 0 3b7 :4 0 6be
b2 :3 0 69 :4 0
3bd :2 0 3c3 3bb
0 9 :3 0 95
:3 0 3be 3bf 0
96 :3 0 3c0 3c1
0 3c3 1b8 416
97 :3 0 9 :3 0
95 :3 0 3c5 3c6
0 96 :3 0 3c7
3c8 0 3ca 1bb
3cc 1bd 3cb 3ca
:2 0 414 98 :3 0
9 :3 0 95 :3 0
3cf 3d0 0 96
:3 0 3d1 3d2 0
40c 7e :3 0 7f
:3 0 3d4 3d5 0
7e :3 0 8e :3 0
3d7 3d8 0 99
:2 0 2 :4 0 b3
:2 0 90 :2 0 13
:2 0 1bf 3dd 3df
:3 0 1c2 3d9 3e1
3d6 3e3 3e2 :2 0
81 :3 0 91 :3 0
3e5 3e6 0 83
:4 0 b4 :4 0 86
:2 0 87 :3 0 1c6
3ea 3ec :3 0 86
:2 0 9c :4 0 1c9
3ee 3f0 :3 0 86
:2 0 9d :4 0 1cc
3f2 3f4 :3 0 86
:2 0 96 :3 0 1cf
3f6 3f8 :3 0 86
:2 0 9e :4 0 1d2
3fa 3fc :3 0 86
:2 0 9f :3 0 a0
:3 0 13 :2 0 a1
:2 0 1d5 3ff 403
1d9 3fe 405 :3 0
1dc 3e7 407 :2 0
409 1df 40a 3e4
409 0 40b 1e1
0 40c 1e3 40f
:3 0 40f 0 40f
40e 40c 40d :6 0
411 8 :3 0 1e6
413 1e8 412 411
:2 0 414 1ea :2 0
416 0 416 415
3c3 414 :6 0 6be
6 :3 0 4d :3 0
22 :3 0 23 :2 0
1ed 418 41b ab
:2 0 13 :2 0 1f2
41d 41f :3 0 420
:2 0 4d :3 0 29
:3 0 23 :2 0 1f5
422 425 b5 :2 0
23 :2 0 1fa 427
429 :3 0 42a :2 0
421 42c 42b :2 0
19 :4 0 42e 42f
0 6bb 1a :4 0
431 432 0 6bb
b6 :3 0 b7 :3 0
4c :3 0 50 :3 0
2a :3 0 2f :3 0
19 :3 0 1a :3 0
53 :3 0 48 :3 0
d :3 0 49 :3 0
1f :4 0 b8 1
:8 0 447 9 :3 0
95 :3 0 442 443
0 96 :3 0 444
445 0 447 1fd
49a 97 :3 0 9
:3 0 95 :3 0 449
44a 0 96 :3 0
44b 44c 0 44e
200 450 202 44f
44e :2 0 498 98
:3 0 9 :3 0 95
:3 0 453 454 0
96 :3 0 455 456
0 490 7e :3 0
7f :3 0 458 459
0 7e :3 0 8e
:3 0 45b 45c 0
99 :2 0 2 :4 0
b9 :2 0 90 :2 0
13 :2 0 204 461
463 :3 0 207 45d
465 45a 467 466
:2 0 81 :3 0 91
:3 0 469 46a 0
83 :4 0 ba :4 0
86 :2 0 87 :3 0
20b 46e 470 :3 0
86 :2 0 9c :4 0
20e 472 474 :3 0
86 :2 0 9d :4 0
211 476 478 :3 0
86 :2 0 96 :3 0
214 47a 47c :3 0
86 :2 0 9e :4 0
217 47e 480 :3 0
86 :2 0 9f :3 0
a0 :3 0 13 :2 0
a1 :2 0 21a 483
487 21e 482 489
:3 0 221 46b 48b
:2 0 48d 224 48e
468 48d 0 48f
226 0 490 228
493 :3 0 493 0
493 492 490 491
:6 0 495 a :3 0
22b 497 22d 496
495 :2 0 498 22f
:2 0 49a 0 49a
499 447 498 :6 0
6bb 6 :3 0 1a
:3 0 a4 :2 0 232
49d 49e :3 0 49f
:2 0 2a :3 0 a4
:2 0 234 4a2 4a3
:3 0 4a4 :2 0 53
:3 0 b6 :3 0 2f
:3 0 bb :3 0 9f
:3 0 2a :3 0 bb
:3 0 9f :3 0 1a
:3 0 1a :3 0 2f
:3 0 1a :3 0 2a
:3 0 b7 :3 0 2f
:3 0 bb :3 0 9f
:3 0 2a :3 0 bb
:3 0 9f :3 0 1a
:3 0 2f :3 0 2f
:3 0 48 :3 0 d
:3 0 49 :3 0 1f
:4 0 bc 1 :8 0
4d7 a9 :4 0 4c2
:3 0 bd :3 0 a2
:2 0 238 4c5 4c6
:3 0 9 :3 0 95
:3 0 4c8 4c9 0
23 :2 0 4ca 4cb
0 4cd 23b 4d4
9 :3 0 95 :3 0
4ce 4cf 0 aa
:2 0 4d0 4d1 0
4d3 23d 4d5 4c7
4cd 0 4d6 0
4d3 0 4d6 23f
0 4d7 242 52a
97 :3 0 9 :3 0
95 :3 0 4d9 4da
0 96 :3 0 4db
4dc 0 4de 245
4e0 247 4df 4de
:2 0 528 98 :3 0
9 :3 0 95 :3 0
4e3 4e4 0 96
:3 0 4e5 4e6 0
520 7e :3 0 7f
:3 0 4e8 4e9 0
7e :3 0 8e :3 0
4eb 4ec 0 99
:2 0 2 :4 0 be
:2 0 90 :2 0 13
:2 0 249 4f1 4f3
:3 0 24c 4ed 4f5
4ea 4f7 4f6 :2 0
81 :3 0 91 :3 0
4f9 4fa 0 83
:4 0 bf :4 0 86
:2 0 87 :3 0 250
4fe 500 :3 0 86
:2 0 9c :4 0 253
502 504 :3 0 86
:2 0 9d :4 0 256
506 508 :3 0 86
:2 0 96 :3 0 259
50a 50c :3 0 86
:2 0 9e :4 0 25c
50e 510 :3 0 86
:2 0 9f :3 0 a0
:3 0 13 :2 0 a1
:2 0 25f 513 517
263 512 519 :3 0
266 4fb 51b :2 0
51d 269 51e 4f8
51d 0 51f 26b
0 520 26d 523
:3 0 523 0 523
522 520 521 :6 0
525 c :3 0 270
527 272 526 525
:2 0 528 274 :2 0
52a 0 52a 529
4d7 528 :6 0 52c
6 :3 0 277 5a1
53 :3 0 b6 :3 0
1a :3 0 b7 :3 0
48 :3 0 d :3 0
49 :3 0 1f :4 0
c0 1 :8 0 54b
a9 :4 0 536 :3 0
bd :3 0 a2 :2 0
27b 539 53a :3 0
9 :3 0 95 :3 0
53c 53d 0 23
:2 0 53e 53f 0
541 27e 548 9
:3 0 95 :3 0 542
543 0 aa :2 0
544 545 0 547
280 549 53b 541
0 54a 0 547
0 54a 282 0
54b 285 59e 97
:3 0 9 :3 0 95
:3 0 54d 54e 0
96 :3 0 54f 550
0 552 288 554
28a 553 552 :2 0
59c 98 :3 0 9
:3 0 95 :3 0 557
558 0 96 :3 0
559 55a 0 594
7e :3 0 7f :3 0
55c 55d 0 7e
:3 0 8e :3 0 55f
560 0 99 :2 0
2 :4 0 c1 :2 0
90 :2 0 13 :2 0
28c 565 567 :3 0
28f 561 569 55e
56b 56a :2 0 81
:3 0 91 :3 0 56d
56e 0 83 :4 0
c2 :4 0 86 :2 0
87 :3 0 293 572
574 :3 0 86 :2 0
9c :4 0 296 576
578 :3 0 86 :2 0
9d :4 0 299 57a
57c :3 0 86 :2 0
96 :3 0 29c 57e
580 :3 0 86 :2 0
9e :4 0 29f 582
584 :3 0 86 :2 0
9f :3 0 a0 :3 0
13 :2 0 a1 :2 0
2a2 587 58b 2a6
586 58d :3 0 2a9
56f 58f :2 0 591
2ac 592 56c 591
0 593 2ae 0
594 2b0 597 :3 0
597 0 597 596
594 595 :6 0 599
e :3 0 2b3 59b
2b5 59a 599 :2 0
59c 2b7 :2 0 59e
0 59e 59d 54b
59c :6 0 5a0 6
:3 0 2ba 5a2 4a5
52c 0 5a3 0
5a0 0 5a3 2bc
0 5a5 b0 :3 0
2bf 6b9 19 :3 0
a4 :2 0 2c1 5a7
5a8 :3 0 5a9 :2 0
5aa :2 0 1a :3 0
c3 :2 0 2c3 5ad
5ae :3 0 5af :2 0
5b0 :2 0 5ab 5b2
5b1 :2 0 2a :3 0
a4 :2 0 2c5 5b5
5b6 :3 0 5b7 :2 0
53 :3 0 b6 :3 0
2f :3 0 bb :3 0
9f :3 0 2a :3 0
bb :3 0 9f :3 0
19 :3 0 19 :3 0
2f :3 0 19 :3 0
2a :3 0 b7 :3 0
2f :3 0 bb :3 0
9f :3 0 2a :3 0
bb :3 0 9f :3 0
19 :3 0 2f :3 0
2f :3 0 48 :3 0
d :3 0 49 :3 0
1f :4 0 c4 1
:8 0 5ea a9 :4 0
5d5 :3 0 bd :3 0
a2 :2 0 2c9 5d8
5d9 :3 0 9 :3 0
95 :3 0 5db 5dc
0 23 :2 0 5dd
5de 0 5e0 2cc
5e7 9 :3 0 95
:3 0 5e1 5e2 0
aa :2 0 5e3 5e4
0 5e6 2ce 5e8
5da 5e0 0 5e9
0 5e6 0 5e9
2d0 0 5ea 2d3
63d 97 :3 0 9
:3 0 95 :3 0 5ec
5ed 0 96 :3 0
5ee 5ef 0 5f1
2d6 5f3 2d8 5f2
5f1 :2 0 63b 98
:3 0 9 :3 0 95
:3 0 5f6 5f7 0
96 :3 0 5f8 5f9
0 633 7e :3 0
7f :3 0 5fb 5fc
0 7e :3 0 8e
:3 0 5fe 5ff 0
99 :2 0 2 :4 0
c5 :2 0 90 :2 0
13 :2 0 2da 604
606 :3 0 2dd 600
608 5fd 60a 609
:2 0 81 :3 0 91
:3 0 60c 60d 0
83 :4 0 c6 :4 0
86 :2 0 87 :3 0
2e1 611 613 :3 0
86 :2 0 9c :4 0
2e4 615 617 :3 0
86 :2 0 9d :4 0
2e7 619 61b :3 0
86 :2 0 96 :3 0
2ea 61d 61f :3 0
86 :2 0 9e :4 0
2ed 621 623 :3 0
86 :2 0 9f :3 0
a0 :3 0 13 :2 0
a1 :2 0 2f0 626
62a 2f4 625 62c
:3 0 2f7 60e 62e
:2 0 630 2fa 631
60b 630 0 632
2fc 0 633 2fe
636 :3 0 636 0
636 635 633 634
:6 0 638 10 :3 0
301 63a 303 639
638 :2 0 63b 305
:2 0 63d 0 63d
63c 5ea 63b :6 0
63f 6 :3 0 308
6b4 53 :3 0 b6
:3 0 19 :3 0 b7
:3 0 48 :3 0 d
:3 0 49 :3 0 1f
:4 0 c7 1 :8 0
65e a9 :4 0 649
:3 0 bd :3 0 a2
:2 0 30c 64c 64d
:3 0 9 :3 0 95
:3 0 64f 650 0
23 :2 0 651 652
0 654 30f 65b
9 :3 0 95 :3 0
655 656 0 aa
:2 0 657 658 0
65a 311 65c 64e
654 0 65d 0
65a 0 65d 313
0 65e 316 6b1
97 :3 0 9 :3 0
95 :3 0 660 661
0 96 :3 0 662
663 0 665 319
667 31b 666 665
:2 0 6af 98 :3 0
9 :3 0 95 :3 0
66a 66b 0 96
:3 0 66c 66d 0
6a7 7e :3 0 7f
:3 0 66f 670 0
7e :3 0 8e :3 0
672 673 0 99
:2 0 2 :4 0 c8
:2 0 90 :2 0 13
:2 0 31d 678 67a
:3 0 320 674 67c
671 67e 67d :2 0
81 :3 0 91 :3 0
680 681 0 83
:4 0 c9 :4 0 86
:2 0 87 :3 0 324
685 687 :3 0 86
:2 0 9c :4 0 327
689 68b :3 0 86
:2 0 9d :4 0 32a
68d 68f :3 0 86
:2 0 96 :3 0 32d
691 693 :3 0 86
:2 0 9e :4 0 330
695 697 :3 0 86
:2 0 9f :3 0 a0
:3 0 13 :2 0 a1
:2 0 333 69a 69e
337 699 6a0 :3 0
33a 682 6a2 :2 0
6a4 33d 6a5 67f
6a4 0 6a6 33f
0 6a7 341 6aa
:3 0 6aa 0 6aa
6a9 6a7 6a8 :6 0
6ac 12 :3 0 344
6ae 346 6ad 6ac
:2 0 6af 348 :2 0
6b1 0 6b1 6b0
65e 6af :6 0 6b3
6 :3 0 34b 6b5
5b8 63f 0 6b6
0 6b3 0 6b6
34d 0 6b7 350
6b8 5b3 6b7 0
6ba 4a0 5a5 0
6ba 352 0 6bb
355 6bc 42d 6bb
0 6bd 35a 0
6be 35c 6c0 2f4
320 0 6c1 0
6be 0 6c1 363
0 6c2 366 6c4
a8 :4 0 6c2 :4 0
810 b2 :3 0 47
:4 0 6c8 :2 0 6ce
6c6 0 9 :3 0
95 :3 0 6c9 6ca
0 96 :3 0 6cb
6cc 0 6ce 36b
721 97 :3 0 9
:3 0 95 :3 0 6d0
6d1 0 96 :3 0
6d2 6d3 0 6d5
36e 6d7 370 6d6
6d5 :2 0 71f 98
:3 0 9 :3 0 95
:3 0 6da 6db 0
96 :3 0 6dc 6dd
0 717 7e :3 0
7f :3 0 6df 6e0
0 7e :3 0 8e
:3 0 6e2 6e3 0
99 :2 0 2 :4 0
ca :2 0 90 :2 0
13 :2 0 372 6e8
6ea :3 0 375 6e4
6ec 6e1 6ee 6ed
:2 0 81 :3 0 91
:3 0 6f0 6f1 0
83 :4 0 cb :4 0
86 :2 0 87 :3 0
379 6f5 6f7 :3 0
86 :2 0 9c :4 0
37c 6f9 6fb :3 0
86 :2 0 9d :4 0
37f 6fd 6ff :3 0
86 :2 0 96 :3 0
382 701 703 :3 0
86 :2 0 9e :4 0
385 705 707 :3 0
86 :2 0 9f :3 0
a0 :3 0 13 :2 0
a1 :2 0 388 70a
70e 38c 709 710
:3 0 38f 6f2 712
:2 0 714 392 715
6ef 714 0 716
394 0 717 396
71a :3 0 71a 0
71a 719 717 718
:6 0 71c 14 :3 0
399 71e 39b 71d
71c :2 0 71f 39d
:2 0 721 0 721
720 6ce 71f :6 0
810 1 :3 0 4d
:3 0 29 :3 0 23
:2 0 3a0 723 726
b5 :2 0 23 :2 0
3a5 728 72a :3 0
72b :2 0 4d :3 0
25 :3 0 23 :2 0
3a8 72d 730 b5
:2 0 a6 :2 0 13
:2 0 3ab 733 735
:3 0 3af 732 737
:3 0 738 :2 0 72c
73a 739 :2 0 a4
:2 0 3b2 6 :3 0
73d :7 0 23 :2 0
741 73e 73f 78e
0 cc :6 0 e
:3 0 3b4 743 744
:3 0 745 :2 0 cc
:3 0 4d :3 0 cd
:3 0 e :3 0 3b6
749 74b 23 :2 0
3b8 748 74e 747
74f 0 767 13
:2 0 ab :2 0 23
:2 0 3bd 752 754
:3 0 cc :3 0 ab
:2 0 23 :2 0 3c2
757 759 :3 0 755
75b 75a :2 0 cc
:3 0 cc :3 0 a6
:2 0 13 :2 0 3c5
75f 761 :3 0 75d
762 0 764 3c8
765 75c 764 0
766 3ca 0 767
3cc 768 746 767
0 769 3cf 0
78c cc :3 0 ab
:2 0 23 :2 0 3d3
76b 76d :3 0 ce
:2 0 3d6 76f 770
:3 0 cc :3 0 cf
:3 0 cf :2 0 d0
:2 0 3d8 774 776
:3 0 777 :2 0 ab
:2 0 23 :2 0 3dd
779 77b :3 0 771
77d 77c :2 0 d1
:3 0 d2 :3 0 77f
780 0 56 :3 0
d3 :3 0 782 783
0 e :3 0 bd
:3 0 3e0 781 787
:2 0 789 3e4 78a
77e 789 0 78b
3e6 0 78c 3e8
78f :3 0 78f 3eb
78f 78e 78c 78d
:6 0 80d 1 :3 0
53 :3 0 d4 :3 0
d5 :3 0 d6 :3 0
d4 :3 0 56 :3 0
d7 :3 0 48 :3 0
d :3 0 54 :3 0
e :4 0 d8 1
:8 0 7b2 a9 :4 0
79d :3 0 bd :3 0
a2 :2 0 3ef 7a0
7a1 :3 0 9 :3 0
95 :3 0 7a3 7a4
0 23 :2 0 7a5
7a6 0 7a8 3f2
7af 9 :3 0 95
:3 0 7a9 7aa 0
aa :2 0 7ab 7ac
0 7ae 3f4 7b0
7a2 7a8 0 7b1
0 7ae 0 7b1
3f6 0 7b2 3f9
805 97 :3 0 9
:3 0 95 :3 0 7b4
7b5 0 96 :3 0
7b6 7b7 0 7b9
3fc 7bb 3fe 7ba
7b9 :2 0 803 98
:3 0 9 :3 0 95
:3 0 7be 7bf 0
96 :3 0 7c0 7c1
0 7fb 7e :3 0
7f :3 0 7c3 7c4
0 7e :3 0 8e
:3 0 7c6 7c7 0
99 :2 0 2 :4 0
d9 :2 0 90 :2 0
13 :2 0 400 7cc
7ce :3 0 403 7c8
7d0 7c5 7d2 7d1
:2 0 81 :3 0 91
:3 0 7d4 7d5 0
83 :4 0 da :4 0
86 :2 0 87 :3 0
407 7d9 7db :3 0
86 :2 0 9c :4 0
40a 7dd 7df :3 0
86 :2 0 9d :4 0
40d 7e1 7e3 :3 0
86 :2 0 96 :3 0
410 7e5 7e7 :3 0
86 :2 0 9e :4 0
413 7e9 7eb :3 0
86 :2 0 9f :3 0
a0 :3 0 13 :2 0
a1 :2 0 416 7ee
7f2 41a 7ed 7f4
:3 0 41d 7d6 7f6
:2 0 7f8 420 7f9
7d3 7f8 0 7fa
422 0 7fb 424
7fe :3 0 7fe 0
7fe 7fd 7fb 7fc
:6 0 800 17 :3 0
427 802 429 801
800 :2 0 803 42b
:2 0 805 0 805
804 7b2 803 :6 0
80d 1 :3 0 32
:3 0 db :3 0 d
:3 0 42e 808 80a
807 80b 0 80d
430 80e 73b 80d
0 80f 434 0
810 436 811 2a9
810 0 812 43d
0 889 4d :3 0
41 :3 0 23 :2 0
43f 813 816 b5
:2 0 23 :2 0 444
818 81a :3 0 9
:3 0 95 :3 0 81c
81d 0 56 :3 0
b1 :3 0 81f 820
0 81e 821 0
824 b0 :3 0 447
839 4d :3 0 32
:3 0 23 :2 0 449
825 828 b5 :2 0
aa :2 0 44e 82a
82c :3 0 9 :3 0
95 :3 0 82e 82f
0 4d :3 0 32
:3 0 23 :2 0 451
831 834 830 835
0 837 454 838
82d 837 0 83a
81b 824 0 83a
456 0 889 7e
:3 0 7f :3 0 83b
83c 0 7e :3 0
8e :3 0 83e 83f
0 d0 :2 0 2
:4 0 dc :2 0 90
:2 0 13 :2 0 459
844 846 :3 0 45c
840 848 83d 84a
849 :2 0 81 :3 0
91 :3 0 84c 84d
0 83 :4 0 dd
:4 0 86 :2 0 87
:3 0 460 851 853
:3 0 86 :2 0 9c
:4 0 463 855 857
:3 0 86 :2 0 de
:4 0 466 859 85b
:3 0 86 :2 0 4d
:3 0 8b :3 0 9
:3 0 95 :3 0 860
861 0 469 85f
863 8c :4 0 46b
85e 866 46e 85d
868 :3 0 86 :2 0
df :4 0 471 86a
86c :3 0 86 :2 0
89 :4 0 474 86e
870 :3 0 86 :2 0
3 :3 0 477 872
874 :3 0 86 :2 0
89 :4 0 47a 876
878 :3 0 47d 84e
87a :2 0 87c 480
87d 84b 87c 0
87e 482 0 889
d1 :3 0 e0 :3 0
87f 880 0 9
:3 0 95 :3 0 882
883 0 3 :3 0
bd :3 0 484 881
887 :2 0 889 488
92a 9 :3 0 e1
:2 0 4 88a 88b
0 7e :3 0 7f
:3 0 88d 88e 0
7e :3 0 8e :3 0
890 891 0 99
:2 0 2 :4 0 e2
:2 0 90 :2 0 13
:2 0 493 896 898
:3 0 496 892 89a
88f 89c 89b :2 0
81 :3 0 91 :3 0
89e 89f 0 83
:4 0 e3 :4 0 86
:2 0 87 :3 0 49a
8a3 8a5 :3 0 49d
8a0 8a7 :2 0 8c0
81 :3 0 91 :3 0
8a9 8aa 0 83
:4 0 e4 :4 0 86
:2 0 9 :3 0 e5
:3 0 8af 8b0 0
4a0 8ae 8b2 :3 0
86 :2 0 df :4 0
4a3 8b4 8b6 :3 0
86 :2 0 9 :3 0
e6 :3 0 8b9 8ba
0 4a6 8b8 8bc
:3 0 4a9 8ab 8be
:2 0 8c0 4ac 8c1
89d 8c0 0 8c2
4af 0 8d2 a7
:3 0 7d :3 0 9
:3 0 e5 :3 0 e7
:3 0 9 :3 0 e6
:3 0 e8 :3 0 e9
:4 0 ea 1 :a 0
8ce :2 0 8d2 8c4
8cc :2 0 8 :3 0
7d :3 0 8d0 :2 0
8d2 4b1 8d4 4b5
8d3 8d2 :2 0 928
98 :3 0 9 :3 0
95 :3 0 8d7 8d8
0 96 :3 0 8d9
8da 0 920 7e
:3 0 7f :3 0 8dc
8dd 0 7e :3 0
8e :3 0 8df 8e0
0 99 :2 0 2
:4 0 eb :2 0 90
:2 0 13 :2 0 4b7
8e5 8e7 :3 0 4ba
8e1 8e9 8de 8eb
8ea :2 0 81 :3 0
91 :3 0 8ed 8ee
0 83 :4 0 ec
:4 0 86 :2 0 87
:3 0 4be 8f2 8f4
:3 0 4c1 8ef 8f6
:2 0 910 81 :3 0
91 :3 0 8f8 8f9
0 83 :4 0 9d
:4 0 86 :2 0 96
:3 0 4c4 8fd 8ff
:3 0 86 :2 0 9e
:4 0 4c7 901 903
:3 0 86 :2 0 9f
:3 0 a0 :3 0 13
:2 0 a1 :2 0 4ca
906 90a 4ce 905
90c :3 0 4d1 8fa
90e :2 0 910 4d4
911 8ec 910 0
912 4d7 0 920
a7 :3 0 7d :3 0
e7 :3 0 9 :3 0
e6 :3 0 e8 :3 0
e9 :4 0 ed 1
:a 0 91c :2 0 920
914 91a :2 0 8
:3 0 7d :3 0 91e
:2 0 920 4d9 923
:3 0 923 0 923
922 920 921 :6 0
925 1 :3 0 4de
927 4e0 926 925
:2 0 928 4e2 :2 0
92a 4e5 92a 929
889 928 :6 0 92b
:2 0 2 14 92a
92e :3 0 92d 92b
92f :8 0 
51a
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2d 1 2b 1
34 1 32 1
3b 1 39 1
40 1 45 1
4a 1 4f 1
54 1 59 1
5e 1 63 1
68 1 6f 1
6d 1 76 1
74 1 7d 1
7b 1 82 1
88 1 8e 1
94 1 9a 1
a0 1 a6 1
ac 1 b1 1
b8 1 b6 1
bd 1 c3 1
c9 1 cf 1
d5 1 db 1
e0 1 e5 1
eb 1 f1 1
f7 1 fd 1
103 1 108 1
10d 1 113 1
119 1 11f 1
125 1 12b 1
130 1 176 1
1b1 1 1b7 1
1c4 1 1d0 2
1d3 1d5 2 1d8
1da 2 1dc 1de
2 1e0 1e2 2
1e4 1e6 1 1ec
2 1ee 1ef 2
1e8 1f1 2 1f3
1f5 2 1f7 1f9
2 1fb 1fd 2
1ff 201 2 203
205 4 1cc 1d2
1d7 207 1 209
1 20b 2 215
217 3 213 214
219 2 222 224
2 221 226 1
228 1 22a 2
23d 242 1 249
1 244 2 25c
25e 3 25a 25b
260 2 269 26b
2 26d 26f 2
271 273 2 275
277 2 279 27b
3 280 281 282
2 27d 284 2
268 286 1 288
1 28a 2 253
28b 1 28f 1
24e 2 24c 293
1 29e 2 29a
29e 1 2a2 2
2ac 2ae 3 2b0
2b1 2b2 1 2b8
5 2c3 2c4 2c5
2c6 2c7 1 2d2
1 2d8 2 2da
2db 1 2e3 2
2df 2e3 1 2e8
1 2ea 2 2ed
2ee 1 2f2 2
2f0 2f2 2 2f6
2f7 1 2fb 2
2f9 2fb 5 305
306 307 308 309
2 314 315 2
317 319 4 302
30c 311 31c 1
31e 1 31f 16
32e 32f 330 331
332 333 334 335
336 337 338 339
33a 33b 33c 33d
33e 33f 340 341
342 343 1 34e
1 354 2 356
357 1 35f 2
35b 35f 1 364
1 366 1a 36a
36b 36c 36d 36e
36f 370 371 372
373 374 375 376
377 378 379 37a
37b 37c 37d 37e
37f 380 381 382
383 2 388 389
1 38d 2 38b
38d 2 392 393
2 395 397 1
39a 2 39e 39f
1 3a5 2 3a1
3a5 2 3aa 3ab
2 3ad 3af 1
3b2 2 3b5 3b4
5 344 358 367
386 3b6 2 3bc
3c2 1 3c9 1
3c4 2 3dc 3de
3 3da 3db 3e0
2 3e9 3eb 2
3ed 3ef 2 3f1
3f3 2 3f5 3f7
2 3f9 3fb 3
400 401 402 2
3fd 404 2 3e8
406 1 408 1
40a 2 3d3 40b
1 40f 1 3ce
2 3cc 413 2
419 41a 1 41e
2 41c 41e 2
423 424 1 428
2 426 428 2
441 446 1 44d
1 448 2 460
462 3 45e 45f
464 2 46d 46f
2 471 473 2
475 477 2 479
47b 2 47d 47f
3 484 485 486
2 481 488 2
46c 48a 1 48c
1 48e 2 457
48f 1 493 1
452 2 450 497
1 49c 1 4a1
1 4c4 2 4c3
4c4 1 4cc 1
4d2 2 4d4 4d5
2 4c1 4d6 1
4dd 1 4d8 2
4f0 4f2 3 4ee
4ef 4f4 2 4fd
4ff 2 501 503
2 505 507 2
509 50b 2 50d
50f 3 514 515
516 2 511 518
2 4fc 51a 1
51c 1 51e 2
4e7 51f 1 523
1 4e2 2 4e0
527 1 52a 1
538 2 537 538
1 540 1 546
2 548 549 2
535 54a 1 551
1 54c 2 564
566 3 562 563
568 2 571 573
2 575 577 2
579 57b 2 57d
57f 2 581 583
3 588 589 58a
2 585 58c 2
570 58e 1 590
1 592 2 55b
593 1 597 1
556 2 554 59b
1 59e 2 5a1
5a2 1 5a3 1
5a6 1 5ac 1
5b4 1 5d7 2
5d6 5d7 1 5df
1 5e5 2 5e7
5e8 2 5d4 5e9
1 5f0 1 5eb
2 603 605 3
601 602 607 2
610 612 2 614
616 2 618 61a
2 61c 61e 2
620 622 3 627
628 629 2 624
62b 2 60f 62d
1 62f 1 631
2 5fa 632 1
636 1 5f5 2
5f3 63a 1 63d
1 64b 2 64a
64b 1 653 1
659 2 65b 65c
2 648 65d 1
664 1 65f 2
677 679 3 675
676 67b 2 684
686 2 688 68a
2 68c 68e 2
690 692 2 694
696 3 69b 69c
69d 2 698 69f
2 683 6a1 1
6a3 1 6a5 2
66e 6a6 1 6aa
1 669 2 667
6ae 1 6b1 2
6b4 6b5 1 6b6
2 6b9 6b8 4
430 433 49a 6ba
1 6bc 6 323
326 329 3b9 416
6bd 2 6bf 6c0
4 2c8 2dc 2eb
6c1 2 6c7 6cd
1 6d4 1 6cf
2 6e7 6e9 3
6e5 6e6 6eb 2
6f4 6f6 2 6f8
6fa 2 6fc 6fe
2 700 702 2
704 706 3 70b
70c 70d 2 708
70f 2 6f3 711
1 713 1 715
2 6de 716 1
71a 1 6d9 2
6d7 71e 2 724
725 1 729 2
727 729 2 72e
72f 1 734 1
736 2 731 736
1 73c 1 742
1 74a 2 74c
74d 1 753 2
751 753 1 758
2 756 758 2
75e 760 1 763
1 765 2 750
766 1 768 1
76c 2 76a 76c
1 76e 2 772
775 1 77a 2
778 77a 3 784
785 786 1 788
1 78a 2 769
78b 1 740 1
79f 2 79e 79f
1 7a7 1 7ad
2 7af 7b0 2
79c 7b1 1 7b8
1 7b3 2 7cb
7cd 3 7c9 7ca
7cf 2 7d8 7da
2 7dc 7de 2
7e0 7e2 2 7e4
7e6 2 7e8 7ea
3 7ef 7f0 7f1
2 7ec 7f3 2
7d7 7f5 1 7f7
1 7f9 2 7c2
7fa 1 7fe 1
7bd 2 7bb 802
1 809 3 78f
805 80c 1 80e
6 2b5 2bb 2be
6c4 721 80f 1
811 2 814 815
1 819 2 817
819 1 822 2
826 827 1 82b
2 829 82b 2
832 833 1 836
2 839 838 2
843 845 3 841
842 847 2 850
852 2 854 856
2 858 85a 1
862 2 864 865
2 85c 867 2
869 86b 2 86d
86f 2 871 873
2 875 877 2
84f 879 1 87b
1 87d 3 884
885 886 a 20c
22b 22e 231 234
296 812 83a 87e
888 2 895 897
3 893 894 899
2 8a2 8a4 2
8a1 8a6 2 8ad
8b1 2 8b3 8b5
2 8b7 8bb 2
8ac 8bd 2 8a8
8bf 1 8c1 3
8c2 8cd 8d1 1
88c 2 8e4 8e6
3 8e2 8e3 8e8
2 8f1 8f3 2
8f0 8f5 2 8fc
8fe 2 900 902
3 907 908 909
2 904 90b 2
8fb 90d 2 8f7
90f 1 911 4
8db 912 91b 91f
1 923 1 8d6
2 8d4 927 34
1b 22 29 30
37 3e 43 48
4d 52 57 5c
61 66 6b 72
79 80 86 8c
92 98 9e a4
aa af b4 bb
c1 c7 cd d3
d9 de e3 e9
ef f5 fb 101
106 10b 111 117
11d 123 129 12e
134 177 1b2 1bc

1
4
0 
92e
0
1
28
19
39
0 1 1 1 4 1 6 6
8 6 a 6 c 6 e 6
10 6 12 1 14 1 1 17
1 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

b 1 0
2 0 1
e0 1 0
94 1 0
cf 1 0
f1 1 0
4f 1 0
74 1 0
119 1 0
16 1 0
c9 1 0
bd 1 0
39 1 0
db 1 0
fd 1 0
12b 1 0
b1 1 0
d5 1 0
73c 16 0
11f 1 0
68 1 0
8e 1 0
54 1 0
3 1 0
40 1 0
4a 1 0
137 1 2
10d 1 0
82 1 0
e5 1 0
b6 1 0
108 1 0
59 1 0
9a 1 0
113 1 0
6d 1 0
24 1 0
45 1 0
130 1 0
eb 1 0
7b 1 0
ac 1 0
63 1 0
a0 1 0
32 1 0
1d 1 0
17d 1 3
7 1 0
103 1 0
f7 1 0
5e 1 0
2b 1 0
88 1 0
125 1 0
c3 1 0
1b7 1 0
a6 1 0
0

/
SHOW ERRORS FUNCTION SP_ACPT_ETC_WBS;
ALTER FUNCTION SP_ACPT_ETC_WBS COMPILE DEBUG;
/****************************************************************************************
Reject ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_RJCT_ETC_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_RJCT_ETC_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
a3
2 :e:
1FUNCTION:
1SP_RJCT_ETC_ASSIGN:
1ID001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_TSK_ASSIGNMENT_ID:
132:
1H_PROJECT_ID:
1H_TASK_ID:
1H_START_DATE:
1TIMESTAMP:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_TEMP_SC_STATE:
1H_STEPS_EXIST:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1I_PERCENT_COMPLETE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_RJCT_ETC_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
130:
1+:
1FPUT:
1               ENTER:: SP_RJCT_ETC_ASSIGN(31) :: cplan.sql(22496) :: :
1PROJECT_ID:
1TASK_ID:
1BIT_FLAG:
1SCHED_WORK:
1PLANNED_WORK:
1WORK_TODATE:
1MILESTONE_PERCENT:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, TASK_ID, BIT_FLAG, SCHED_WORK+PLANNED_WORK, WORK_TODATE, M+
1ILESTONE_PERCENT:n      INTO h_project_id, h_task_id, h_bit_flag, h_sched_wor+
1k, h_work_todate, h_mlst_percent:n      FROM TASK_ASSIGNMENTS WHERE TSK_ASSIG+
1NMENT_ID = h_tsk_assignment_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
149:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(50) :: cplan.sql(22515) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
12:
1ETC:
1UPDATE TASK_ASSIGNMENTS SET ETC = SCHED_WORK - WORK_TODATE--, MILESTONE_PERCE+
1NT = (WORK_TODATE * 10000) / SCHED_WORK:n            WHERE TSK_ASSIGNMENT_ID +
1= h_tsk_assignment_id:
1FOUND:
1TRUE:
1100:
171:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(72) :: cplan.sql(22537) :: :
1ACTIVITIES:
1ETC_MODIFIED:
1ELEMENT_ID:
1TYPE_ID:
1PMO_CNST:
1SC_TIMESHEET_ACTIVITY:
1UPDATE ACTIVITIES:n            SET ETC_MODIFIED = 'N':n            WHERE TSK_+
1ASSIGNMENT_ID = h_tsk_assignment_id:n            AND TSK_ASSIGNMENT_ID <> ELE+
1MENT_ID:n            AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY:
194:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(95) :: cplan.sql(22560) :: :
1UPDATE TASK_ASSIGNMENTS SET ETC = PLANNED_WORK, WORK_TODATE = 0, MILESTONE_PE+
1RCENT = 0:n            WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1114:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(115) :: cplan.sql(22580) :: :
1TMT_WBS:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_SCHED_BIT:
1UPDATE TMT_WBS SET ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP_BITS, pmo_cnst.SC_SCH+
1ED_BIT) WHERE ELEMENT_ID = h_task_id:
1134:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(135) :: cplan.sql(22600) :: :
1FORECAST_START:
1FORECAST_FINISH:
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_i+
1d:
1155:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(156) :: cplan.sql(22621) :: :
1174:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(175) :: cplan.sql(22640) :: :
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0,:n               ETC = SCHED_WORK - WORK_TODATE--, MILEST+
1ONE_PERCENT = (WORK_TODATE * 10000) / SCHED_WORK:n               WHERE TSK_AS+
1SIGNMENT_ID = h_tsk_assignment_id:
1196:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(197) :: cplan.sql(22662) :: :
1UPDATE ACTIVITIES:n               SET ETC_MODIFIED = 'N':n               WHER+
1E TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n               AND TSK_ASSIGNMENT_+
1ID <> ELEMENT_ID:n               AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY:
1219:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(220) :: cplan.sql(22685) :: :
1UPDATE TASK_ASSIGNMENTS SET FORECAST_START = NuLL, FORECAST_FINISH = NuLL, FO+
1RECAST_DURATION = 0,:n               ETC = PLANNED_WORK, WORK_TODATE = 0, MIL+
1ESTONE_PERCENT = 0:n               WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment+
1_id:
1240:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(241) :: cplan.sql(22706) :: :
1260:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(261) :: cplan.sql(22726) :: :
1BITAND:
1>:
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000.00:
1-:
1<:
1SC_PERCENT_COMPLETE_BIT:
1ACTUAL_FINISH:
1SCHED_FINISH:
1UPDATE TASK_ASSIGNMENTS SET:n            ROLLUP_BITS = PMO_STPU.BIT_OR(ROLLUP+
1_BITS,pmo_cnst.SC_PERCENT_COMPLETE_BIT),:n            ACTUAL_FINISH = CASE:n +
1           WHEN ACTUAL_FINISH IS NULL AND ETC = 0 THEN SCHED_FINISH:n        +
1    ELSE ACTUAL_FINISH:n            END:n            WHERE TSK_ASSIGNMENT_ID +
1= h_tsk_assignment_id:
1292:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(293) :: cplan.sql(22758) :: :
1UPDATE TASK_ASSIGNMENTS SET:n         ACTUAL_FINISH = CASE:n         WHEN ACT+
1UAL_FINISH IS NULL AND ETC = 0 THEN SCHED_FINISH:n         ELSE ACTUAL_FINISH+
1:n         END:n         WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1317:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(318) :: cplan.sql(22783) :: :
1SC_SQL_SUCCESS:
1!=:
1FC_FIX_SUMMARY_TS:
1FC_ROLLUP:
14:
1332:
1       RETURN_STATUS:: SP_RJCT_ETC_ASSIGN(333) :: cplan.sql(22798) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1339:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(340) :: cplan.sql(22805) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1351:
1           EXCEPTION:: SP_RJCT_ETC_ASSIGN(352) :: cplan.sql(22817) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
862
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :3 a0 a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 d :2 a0 d :10 a0 12a :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 51
a5 b 7e 51 b4 2e :2 a0 :2 51
a5 b 7e 6e b4 2e :6 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :7 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :9 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :2 a0 51 a5 b 7e
51 b4 2e :6 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :9 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 a0 :2 51 a5 b
7e 6e b4 2e :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :9 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :a a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c b7 :2 19 3c :3 a0 51
a5 b 51 a5 b 5a 7e 51
b4 2e 5a :2 a0 51 a5 b 7e
51 b4 2e 5a a 10 :5 a0 a5
b 51 a5 b 7e :3 a0 a5 b
51 a5 b b4 2e 5a 7e 51
b4 2e 5a 7e :2 a0 51 a5 b
b4 2e a5 b d a0 7e 51
b4 2e 5a a0 :2 7e 51 b4 2e
b4 2e 52 10 :e a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 19 3c b7
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a :2 a0 51 a5 b
7e 51 b4 2e 5a a 10 :5 a0
a5 b d b7 19 3c :3 a0 a5
b d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
862
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dc cb cf d7 aa
f8 e3 e7 ea eb f3 ca 114
103 107 c7 10f 102 130 11f 123
ff 12b 11e 14c 13b 13f 11b 147
13a 168 157 15b 137 163 156 184
173 177 153 17f 172 1a0 18f 193
16f 19b 18e 1bc 1ab 1af 1b7 18b
1db 1c3 1c7 1cb 1ce 1d6 1aa 1e2
1e6 1a7 1ea 1ee 1f2 1f5 1fa 1fb
1 1fd 202 206 20a 20d 212 216
21a 21d 222 223 225 22a 22d 231
232 237 23c 23f 244 245 24a 24d
251 252 257 25a 25f 260 265 268
26d 26e 273 276 27a 27e 282 283
285 28a 28b 28d 28e 293 296 29b
29c 2a1 2a4 2a9 2aa 2af 2b2 2b6
2b7 2bc 2bf 2c4 2c5 2ca 2cd 2d2
2d3 2d8 2d9 2de 2e0 2e4 2e7 2eb
2ef 2f2 2f6 2fa 2fd 300 305 308
30b 30e 30f 314 315 1 317 31c
320 324 327 32c 331 334 338 339
33e 33f 344 346 34a 34d 351 355
359 35d 361 365 369 36d 371 375
379 37d 381 385 389 38d 391 395
399 39d 3a1 3a5 3b1 3b5 3b9 3bc
3c0 3c4 3c6 3ca 3ce 3d2 3d5 3d9
3dd 3df 3e0 3e5 1 3e9 3ed 3f1
3f4 3f8 3fc 400 404 407 40b 40f
412 415 41a 41d 420 423 424 429
42a 1 42c 431 435 439 43c 441
446 449 44d 44e 453 456 45b 45c
461 464 469 46a 46f 472 476 477
47c 47f 484 485 48a 48d 491 495
498 49b 49c 49e 49f 4a4 4a5 4aa
4ac 4b0 4b3 4b5 4b9 4bb 4c7 4c9
4cb 4cc 4d1 4d5 4d7 4e3 4e5 4e9
4ed 4f0 4f1 4f3 4f6 4f9 4fa 4ff
503 507 50a 50d 50e 510 513 518
519 51e 522 526 52a 52e 532 536
542 546 54b 54f 552 553 558 55c
560 563 566 56a 56c 570 574 577
57a 57e 580 584 588 58b 58d 591
595 599 59c 5a0 5a4 5a6 5a7 5ac
1 5b0 5b4 5b8 5bb 5bf 5c3 5c7
5cb 5ce 5d2 5d6 5d9 5dc 5e1 5e4
5e7 5ea 5eb 5f0 5f1 1 5f3 5f8
5fc 600 603 608 60d 610 614 615
61a 61d 622 623 628 62b 630 631
636 639 63d 63e 643 646 64b 64c
651 654 658 65c 65f 662 663 665
666 66b 66c 671 673 677 67a 67c
680 682 68e 690 692 693 698 69c
69e 6aa 6ac 6b0 6b4 6b8 6bc 6c0
6c4 6c8 6cc 6d0 6dc 6e0 6e5 6e9
6ec 6ed 6f2 6f6 6fa 6fd 700 704
706 70a 70e 711 714 718 71a 71e
722 725 727 72b 72f 733 736 73a
73e 740 741 746 1 74a 74e 752
755 759 75d 761 765 768 76c 770
773 776 77b 77e 781 784 785 78a
78b 1 78d 792 796 79a 79d 7a2
7a7 7aa 7ae 7af 7b4 7b7 7bc 7bd
7c2 7c5 7ca 7cb 7d0 7d3 7d7 7d8
7dd 7e0 7e5 7e6 7eb 7ee 7f2 7f6
7f9 7fc 7fd 7ff 800 805 806 80b
80d 811 814 816 81a 81c 828 82a
82c 82d 832 836 838 844 846 848
84c 850 854 858 85c 860 864 870
874 879 87d 880 881 886 88a 88e
891 894 898 89a 89e 8a2 8a5 8a8
8ac 8ae 8b2 8b6 8b9 8bb 8bf 8c3
8c7 8ca 8ce 8d2 8d4 8d5 8da 1
8de 8e2 8e6 8e9 8ed 8f1 8f5 8f9
8fc 900 904 907 90a 90f 912 915
918 919 91e 91f 1 921 926 92a
92e 931 936 93b 93e 942 943 948
94b 950 951 956 959 95e 95f 964
967 96b 96c 971 974 979 97a 97f
982 986 98a 98d 990 991 993 994
999 99a 99f 9a1 9a5 9a8 9aa 9ae
9b0 9bc 9be 9c0 9c1 9c6 9ca 9cc
9d8 9da 9dc 9e0 9e4 9e7 9eb 9ef
9f3 9f7 9fb 9ff a03 a07 a0b a17
a1b a20 a24 a27 a28 a2d a31 a35
a38 a3b a3f a41 a45 a49 a4c a4f
a53 a55 a59 a5d a60 a62 a66 a6a
a6e a71 a75 a79 a7b a7c a81 1
a85 a89 a8d a90 a94 a98 a9c aa0
aa3 aa7 aab aae ab1 ab6 ab9 abc
abf ac0 ac5 ac6 1 ac8 acd ad1
ad5 ad8 add ae2 ae5 ae9 aea aef
af2 af7 af8 afd b00 b05 b06 b0b
b0e b12 b13 b18 b1b b20 b21 b26
b29 b2d b31 b34 b37 b38 b3a b3b
b40 b41 b46 b48 b4c b4f b51 b55
b57 b63 b65 b67 b68 b6d b71 b73
b7f b81 b83 b87 b8b b8e b8f b91
b94 b97 b98 b9d ba1 ba5 ba9 bad
bb1 bb5 bc1 bc5 bca bce bd1 bd2
bd7 bdb bdf be2 be5 be9 beb bef
bf3 bf6 bf9 bfd bff c03 c07 c0a
c0c c10 c14 c18 c1b c1f c23 c25
c26 c2b 1 c2f c33 c37 c3a c3e
c42 c46 c4a c4d c51 c55 c58 c5b
c60 c63 c66 c69 c6a c6f c70 1
c72 c77 c7b c7f c82 c87 c8c c8f
c93 c94 c99 c9c ca1 ca2 ca7 caa
caf cb0 cb5 cb8 cbc cbd cc2 cc5
cca ccb cd0 cd3 cd7 cdb cde ce1
ce2 ce4 ce5 cea ceb cf0 cf2 cf6
cf9 cfb cff d01 d0d d0f d11 d12
d17 d1b d1d d29 d2b d2f d33 d37
d3b d3f d43 d47 d4b d4f d5b d5f
d64 d68 d6b d6c d71 d75 d79 d7c
d7f d83 d85 d89 d8d d90 d93 d97
d99 d9d da1 da4 da6 daa dae db2
db5 db9 dbd dbf dc0 dc5 1 dc9
dcd dd1 dd4 dd8 ddc de0 de4 de7
deb def df2 df5 dfa dfd e00 e03
e04 e09 e0a 1 e0c e11 e15 e19
e1c e21 e26 e29 e2d e2e e33 e36
e3b e3c e41 e44 e49 e4a e4f e52
e56 e57 e5c e5f e64 e65 e6a e6d
e71 e75 e78 e7b e7c e7e e7f e84
e85 e8a e8c e90 e93 e95 e99 e9b
ea7 ea9 eab eac eb1 eb5 eb7 ec3
ec5 ec7 ecb ecf ed2 ed5 ed6 ed8
edb ee0 ee1 ee6 eea eee ef2 ef6
efa efe f02 f06 f0a f16 f1a f1f
f23 f26 f27 f2c f30 f34 f37 f3a
f3e f40 f44 f48 f4b f4e f52 f54
f58 f5c f5f f61 f65 f69 f6d f70
f74 f78 f7a f7b f80 1 f84 f88
f8c f8f f93 f97 f9b f9f fa2 fa6
faa fad fb0 fb5 fb8 fbb fbe fbf
fc4 fc5 1 fc7 fcc fd0 fd4 fd7
fdc fe1 fe4 fe8 fe9 fee ff1 ff6
ff7 ffc fff 1004 1005 100a 100d 1011
1012 1017 101a 101f 1020 1025 1028 102c
1030 1033 1036 1037 1039 103a 103f 1040
1045 1047 104b 104e 1050 1054 1056 1062
1064 1066 1067 106c 1070 1072 107e 1080
1084 1088 108c 1090 1094 1098 109c 10a0
10a4 10b0 10b4 10b9 10bd 10c0 10c1 10c6
10ca 10ce 10d1 10d4 10d8 10da 10de 10e2
10e5 10e8 10ec 10ee 10f2 10f6 10f9 10fb
10ff 1103 1107 110a 110e 1112 1114 1115
111a 1 111e 1122 1126 1129 112d 1131
1135 1139 113c 1140 1144 1147 114a 114f
1152 1155 1158 1159 115e 115f 1 1161
1166 116a 116e 1171 1176 117b 117e 1182
1183 1188 118b 1190 1191 1196 1199 119e
119f 11a4 11a7 11ab 11ac 11b1 11b4 11b9
11ba 11bf 11c2 11c6 11ca 11cd 11d0 11d1
11d3 11d4 11d9 11da 11df 11e1 11e5 11e8
11ea 11ee 11f0 11fc 11fe 1200 1201 1206
120a 120c 1218 121a 121c 1220 1224 1228
122c 1230 1234 1238 123c 1240 1244 1250
1254 1259 125d 1260 1261 1266 126a 126e
1271 1274 1278 127a 127e 1282 1285 1288
128c 128e 1292 1296 1299 129b 129f 12a3
12a7 12aa 12ae 12b2 12b4 12b5 12ba 1
12be 12c2 12c6 12c9 12cd 12d1 12d5 12d9
12dc 12e0 12e4 12e7 12ea 12ef 12f2 12f5
12f8 12f9 12fe 12ff 1 1301 1306 130a
130e 1311 1316 131b 131e 1322 1323 1328
132b 1330 1331 1336 1339 133e 133f 1344
1347 134b 134c 1351 1354 1359 135a 135f
1362 1366 136a 136d 1370 1371 1373 1374
1379 137a 137f 1381 1385 1388 138a 138e
1390 139c 139e 13a0 13a1 13a6 13aa 13ac
13b8 13ba 13bc 13c0 13c4 13c7 13cb 13cf
13d3 13d7 13db 13df 13e3 13e7 13eb 13f7
13fb 1400 1404 1407 1408 140d 1411 1415
1418 141b 141f 1421 1425 1429 142c 142f
1433 1435 1439 143d 1440 1442 1446 144a
144e 1451 1455 1459 145b 145c 1461 1
1465 1469 146d 1470 1474 1478 147c 1480
1483 1487 148b 148e 1491 1496 1499 149c
149f 14a0 14a5 14a6 1 14a8 14ad 14b1
14b5 14b8 14bd 14c2 14c5 14c9 14ca 14cf
14d2 14d7 14d8 14dd 14e0 14e5 14e6 14eb
14ee 14f2 14f3 14f8 14fb 1500 1501 1506
1509 150d 1511 1514 1517 1518 151a 151b
1520 1521 1526 1528 152c 152f 1531 1535
1537 1543 1545 1547 1548 154d 1551 1553
155f 1561 1563 1567 156b 156e 1570 1574
1578 157b 157f 1583 1587 158a 158b 158d
1590 1591 1593 1596 1599 159c 159d 15a2
15a5 15a9 15ad 15b0 15b1 15b3 15b6 15b9
15ba 15bf 1 15c2 15c7 15cb 15cf 15d3
15d7 15db 15dc 15de 15e1 15e2 15e4 15e7
15eb 15ef 15f3 15f4 15f6 15f9 15fa 15fc
15fd 1602 1605 1608 160b 160c 1611 1614
1617 161b 161f 1622 1623 1625 1626 162b
162c 162e 1632 1636 1639 163c 163d 1642
1645 1649 164c 164f 1652 1653 1658 1659
1 165e 1663 1667 166b 166f 1673 1677
167b 167f 1683 1687 168b 168f 1693 1697
169b 16a7 16ab 16b0 16b4 16b7 16b8 16bd
16c1 16c5 16c8 16cb 16cf 16d1 16d5 16d9
16dc 16df 16e3 16e5 16e9 16ed 16f0 16f2
16f6 16fa 16fe 1701 1705 1709 170b 170c
1711 1 1715 1719 171d 1720 1724 1728
172c 1730 1733 1737 173b 173e 1741 1746
1749 174c 174f 1750 1755 1756 1 1758
175d 1761 1765 1768 176d 1772 1775 1779
177a 177f 1782 1787 1788 178d 1790 1795
1796 179b 179e 17a2 17a3 17a8 17ab 17b0
17b1 17b6 17b9 17bd 17c1 17c4 17c7 17c8
17ca 17cb 17d0 17d1 17d6 17d8 17dc 17df
17e1 17e5 17e7 17f3 17f5 17f7 17f8 17fd
1801 1803 180f 1811 1813 1817 181a 181c
1820 1824 1828 182c 1830 1834 1838 183c
1848 184c 1851 1855 1858 1859 185e 1862
1866 1869 186c 1870 1872 1876 187a 187d
1880 1884 1886 188a 188e 1891 1893 1897
189b 189f 18a2 18a6 18aa 18ac 18ad 18b2
1 18b6 18ba 18be 18c1 18c5 18c9 18cd
18d1 18d4 18d8 18dc 18df 18e2 18e7 18ea
18ed 18f0 18f1 18f6 18f7 1 18f9 18fe
1902 1906 1909 190e 1913 1916 191a 191b
1920 1923 1928 1929 192e 1931 1936 1937
193c 193f 1943 1944 1949 194c 1951 1952
1957 195a 195e 1962 1965 1968 1969 196b
196c 1971 1972 1977 1979 197d 1980 1982
1986 1988 1994 1996 1998 1999 199e 19a2
19a4 19b0 19b2 19b4 19b8 19bc 19bf 19c3
19c7 19ca 19ce 19d1 19d5 19d8 19d9 19de
19e1 19e5 19e9 19ec 19ed 19ef 19f2 19f5
19f6 19fb 1 19fe 1a03 1a07 1a0b 1a0f
1a13 1a17 1a18 1a1a 1a1e 1a20 1a24 1a27
1a2b 1a2f 1a33 1a34 1a36 1a3a 1a3e 1a42
1a45 1a49 1a4d 1a50 1a53 1a58 1a5b 1a5e
1a61 1a62 1a67 1a68 1 1a6a 1a6f 1a73
1a77 1a7a 1a7f 1a84 1a87 1a8b 1a8c 1a91
1a94 1a99 1a9a 1a9f 1aa2 1aa7 1aa8 1aad
1ab0 1ab4 1ab8 1abc 1ac0 1ac3 1ac4 1ac6
1acb 1acc 1ace 1acf 1ad4 1ad7 1adc 1add
1ae2 1ae5 1aea 1aeb 1af0 1af3 1af7 1af8
1afd 1b00 1b05 1b06 1b0b 1b0c 1b11 1b13
1b17 1b1a 1b1e 1b22 1b25 1b29 1b2d 1b30
1b34 1b38 1b39 1b3e 1b40 1b44 1b48 1b4b
1b4f 1b53 1b56 1b5a 1b5e 1b61 1b64 1b69
1b6c 1b6f 1b72 1b73 1b78 1b79 1 1b7b
1b80 1b84 1b88 1b8b 1b90 1b95 1b98 1b9c
1b9d 1ba2 1ba3 1ba8 1bac 1bb0 1bb3 1bb8
1bbd 1bc0 1bc4 1bc8 1bcb 1bcc 1bd1 1bd4
1bd9 1bda 1bdf 1be2 1be6 1bea 1bed 1bee
1bf3 1bf4 1bf9 1bfb 1bff 1c02 1c06 1c0a
1c0e 1c12 1c16 1c1a 1c1e 1c22 1c26 1c32
1c37 1c3b 1c3f 1c43 1c47 1c49 1c4a 1c4f
1 1c53 1c57 1c5b 1c5e 1c62 1c66 1c6a
1c6e 1c71 1c75 1c79 1c7c 1c7f 1c84 1c87
1c8a 1c8d 1c8e 1c93 1c94 1 1c96 1c9b
1c9f 1ca3 1ca6 1cab 1cb0 1cb3 1cb7 1cb8
1cbd 1cbe 1cc3 1cc7 1ccb 1cce 1cd3 1cd8
1cdb 1cdf 1ce0 1ce5 1ce8 1ced 1cee 1cf3
1cf6 1cfa 1cfe 1d01 1d04 1d05 1d07 1d08
1d0d 1d0e 1d13 1d15 1d19 1d1c 1d20 1d24
1d28 1d2c 1d30 1d34 1d38 1d44 1d49 1d4d
1d51 1d55 1d59 1d5b 1d5f 1d61 1d6d 1d6f
1d71 1d72 1d77 1d7b 1d7d 1d89 1d8d 1d8f
1d90 1d99 
862
2
0 1 a 6 c :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 18 21 20 :2 18 :2 4 11 1a
19 :2 11 :2 4 e 17 16 :2 e :2 4
:3 11 :2 4 f 18 17 :2 f :2 4 :2 e
1d e :2 4 :2 14 23 14 :2 4 :2 12
21 12 :2 4 :2 11 20 11 :2 4 :2 12
21 12 :2 4 :2 13 22 13 :2 4 :3 17
:2 4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 5a 60 63 :2 5a 71 8d
8 :2 71 d 10 :2 71 16 19 :2 71
b e :2 71 13 16 1f 27 :2 1f
34 :2 16 :2 71 b e :2 71 13 16
:2 71 1b 1e :2 71 2a 2d :2 71 32
35 :2 71 :2 7 50 :2 4 7 :2 11 23
:2 2d 39 3c 52 54 55 :2 52 :2 23
:3 7 :2 d 12 1e 63 66 :2 1e :2 7
58 :3 4 11 :2 4 1b 4 e 1a
23 2d 38 46 53 c 1a 25
31 3f 4e c 23 37 :2 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 59 5b 5c
:2 59 :2 29 :3 d :2 13 18 24 69 6c
:2 24 79 7c :2 24 80 83 :2 24 8f
92 :2 24 9a 9d :2 24 a9 ac b3
bc bf :2 ac :2 24 :2 d 5f :2 a :2 7
:4 13 :2 7 4 :3 1 7 10 1b :2 7
1e 20 :2 1e a 11 1d 20 :2 a
23 25 :2 23 14 29 2f 3c 13
27 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 5f 61 62 :2 5f :2 2f
:3 13 :2 19 1e 2a 6f 72 :2 2a 7f
82 :2 2a 86 89 :2 2a 95 98 :2 2a
a0 a3 :2 2a af b2 b9 c2 c5
:2 b2 :2 2a :2 13 65 :2 10 :2 d :4 19 :2 d
a :3 29 14 11 13 27 11 26
11 1b 24 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 61 62
:2 5f :2 2f :3 13 :2 19 1e 2a 6f 72
:2 2a 7f 82 :2 2a 86 89 :2 2a 95
98 :2 2a a0 a3 :2 2a af b2 b9
c2 c5 :2 b2 :2 2a :2 13 65 :2 10 :2 d
:4 19 :2 d a :4 29 14 29 2f 3d
4e 13 27 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 62 63
:2 5f :2 2f :3 13 :2 19 1e 2a 70 73
:2 2a 80 83 :2 2a 87 8a :2 2a 96
99 :2 2a a1 a4 :2 2a b0 b3 ba
c3 c6 :2 b3 :2 2a :2 13 66 :2 10 :2 d
:4 19 :2 d a :7 7 11 1d 2b 34
3b 48 51 65 72 a 11 d
19 :3 17 d :2 16 22 d 1e d
:2 16 22 d :4 a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 5c
5f 60 :2 5c :2 2c :3 10 :2 16 1b 27
6d 70 :2 27 7d 80 :2 27 84 87
:2 27 93 96 :2 27 9e a1 :2 27 ad
b0 b7 c0 c3 :2 b0 :2 27 :2 10 63
:2 d :2 a :4 16 :2 a 7 :4 22 a 13
1e :2 a 21 23 :2 21 14 29 40
58 13 27 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 62 63
:2 5f :2 2f :3 13 :2 19 1e 2a 70 73
:2 2a 80 83 :2 2a 87 8a :2 2a 96
99 :2 2a a1 a4 :2 2a b0 b3 ba
c3 c6 :2 b3 :2 2a :2 13 66 :2 10 :2 d
:4 19 :2 d a :3 25 14 20 2e 37
3e 4b 54 68 75 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 5f
62 63 :2 5f :2 2f :3 13 :2 19 1e 2a
70 73 :2 2a 80 83 :2 2a 87 8a
:2 2a 96 99 :2 2a a1 a4 :2 2a b0
b3 ba c3 c6 :2 b3 :2 2a :2 13 66
:2 10 :2 d :4 19 :2 d a :4 25 d 14
20 23 :2 d 26 28 :2 26 17 2c
43 5b 10 16 23 16 2a 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 62 65 66 :2 62 :2 32 :3 16 :2 1c
21 2d 73 76 :2 2d 83 86 :2 2d
8a 8d :2 2d 99 9c :2 2d a4 a7
:2 2d b3 b6 bd c6 c9 :2 b6 :2 2d
:2 16 69 :2 13 :2 10 :4 1c :2 10 d :3 2c
17 14 16 2a 14 29 14 1e
27 10 17 13 1f :3 1d 13 :2 1c
28 13 24 13 :2 1c 28 13 :4 10
d 15 13 :2 1c 28 13 23 :2 10
:2 15 13 :2 1c 28 13 16 :2 20 32
:2 3c 48 4c 62 65 66 :2 62 :2 32
:3 16 :2 1c 21 2d 73 76 :2 2d 83
86 :2 2d 8a 8d :2 2d 99 9c :2 2d
a4 a7 :2 2d b3 b6 bd c6 c9
:2 b6 :2 2d :2 16 69 :2 13 :2 10 :4 1c :2 10
d :4 2c 17 2c 43 5b 10 16
24 35 16 2a 10 17 13 1f
:3 1d 13 :2 1c 28 13 24 13 :2 1c
28 13 :4 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 62 65
66 :2 62 :2 32 :3 16 :2 1c 21 2d 73
76 :2 2d 83 86 :2 2d 8a 8d :2 2d
99 9c :2 2d a4 a7 :2 2d b3 b6
bd c6 c9 :2 b6 :2 2d :2 16 69 :2 13
:2 10 :4 1c :2 10 d :7 a 14 20 2e
37 3e 4b 54 68 75 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5f 62 63 :2 5f :2 2f :3 13 :2 19 1e
2a 70 73 :2 2a 80 83 :2 2a 87
8a :2 2a 96 99 :2 2a a1 a4 :2 2a
b0 b3 ba c3 c6 :2 b3 :2 2a :2 13
66 :2 10 :2 d :4 19 :2 d a :7 7 :4 4
9 10 19 24 :2 10 28 :2 9 8
2c 2e :2 2c 7 36 3f 4f :2 36
52 54 :2 52 35 :3 7 1d 25 2e
38 :2 2e 48 :2 25 4b 4d 28 32
:2 28 41 :2 4d :2 25 24 45 47 :2 24
23 51 53 28 38 :2 53 :2 23 :2 1d
7 b 1e 20 :2 1e a 26 39
3b 3c :2 3b :2 39 :2 a 14 d 1b
24 2b 37 40 d 12 2c 39
12 13 27 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 5f 62 63
:2 5f :2 2f :3 13 :2 19 1e 2a 70 73
:2 2a 80 83 :2 2a 87 8a :2 2a 96
99 :2 2a a1 a4 :2 2a b0 b3 ba
c3 c6 :2 b3 :2 2a :2 13 66 :2 10 :2 d
:4 19 :2 d a :4 3e :2 7 57 11 a
f 29 36 f 10 24 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
5c 5f 60 :2 5c :2 2c :3 10 :2 16 1b
27 6d 70 :2 27 7d 80 :2 27 84
87 :2 27 93 96 :2 27 9e a1 :2 27
ad b0 b7 c0 c3 :2 b0 :2 27 :2 10
63 :2 d :2 a :4 16 :2 a 7 :7 4 8
:2 11 1c 1a :2 25 :2 1a 7 3a 43
4e :2 3a 51 54 :2 51 39 :3 7 1a
2c 3a 4f :2 1a 7 57 :3 4 17
21 :2 17 4 7 :2 11 23 :2 2d 39
3c 52 55 56 :2 52 :2 23 :3 7 :2 d
12 1e 64 67 :2 1e 74 77 :2 1e
7b 7e :2 1e 88 8b 94 9c :2 a5
:2 94 b0 :2 8b :2 1e b8 bb :2 1e c3
c6 :2 1e cb ce :2 1e d4 d7 :2 1e
:2 7 59 :3 4 :2 f 21 :2 2a 34 3b
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 56 59 5a :2 56 :2 26
:3 a :2 10 15 21 67 6a :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 5d
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 53 56 57 :2 53 :2 23
:3 7 :2 d 12 1e 64 67 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 5a :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
862
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :5 b
:7 c :6 d :6 e :6 f
:6 10 :6 11 :6 12 :5 13
:7 15 :b 17 :11 18 19
:2 18 :2 19 :2 18 :2 19
:2 18 :2 1a :2 18 :9 1a
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1b :2 18 :2 1b
:2 18 :2 1b :4 18 :3 17
:11 1e :b 1f :3 1e :3 23
:3 24 :7 27 :6 28 :3 29
27 :5 2a 26 2c
:5 2d :3 2c :2 2e :5 30
:11 31 :24 32 :3 31 :2 2f
:6 2e 2b :3 16 :9 37
:a 38 :4 3a :2 3b 3a
:6 3c :5 3d 3c :5 3f
3e :3 3c 39 42
:5 43 :3 42 :2 44 :5 46
:11 47 :24 48 :3 47 :2 45
:6 44 41 :3 38 4e
4f :2 50 :2 51 :3 52
4e :6 53 :5 54 53
:5 56 55 :3 53 4d
59 :5 5a :3 59 :2 5b
:5 5d :11 5e :24 5f :3 5e
:2 5c :6 5b 58 :4 38
:5 65 :2 66 65 :6 67
:5 68 67 :5 6a 69
:3 67 64 6d :5 6e
:3 6d :2 6f :5 71 :11 72
:24 73 :3 72 :2 70 :6 6f
6c :4 63 :3 38 :a 7a
:6 7b :5 7c 7b :5 7e
7d :3 7b 79 81
:5 82 :3 81 :2 83 :5 85
:11 86 :24 87 :3 86 :2 84
:6 83 80 :4 37 :9 8c
:4 8e :2 8f 8e :6 90
:5 91 90 :5 93 92
:3 90 8d 96 :5 97
:3 96 :2 98 :5 9a :11 9b
:24 9c :3 9b :2 99 :6 98
95 :3 8c :a a2 :6 a3
:5 a4 a3 :5 a6 a5
:3 a3 a1 a9 :5 aa
:3 a9 :2 ab :5 ad :11 ae
:24 af :3 ae :2 ac :6 ab
a8 :4 8c :a b4 :4 b6
:3 b7 :2 b8 b6 :6 b9
:5 ba b9 :5 bc bb
:3 b9 b5 bf :5 c0
:3 bf :2 c1 :5 c3 :11 c4
:24 c5 :3 c4 :2 c2 :6 c1
be :3 b4 cb cc
:2 cd :2 ce :3 cf cb
:6 d0 :5 d1 d0 :5 d3
d2 :3 d0 ca d6
:5 d7 :3 d6 :2 d8 :5 da
:11 db :24 dc :3 db :2 d9
:6 d8 d5 :4 b4 :4 e2
:4 e3 :2 e4 e2 :6 e5
:5 e6 e5 :5 e8 e7
:3 e5 e1 eb :5 ec
:3 eb :2 ed :5 ef :11 f0
:24 f1 :3 f0 :2 ee :6 ed
ea :4 e0 :3 b4 :a f8
:6 f9 :5 fa f9 :5 fc
fb :3 f9 f7 ff
:5 100 :3 ff :2 101 :5 103
:11 104 :24 105 :3 104 :2 102
:6 101 fe :4 b3 :3 8c
8b :3 37 :1b 10c :c 10d
:5 10e :5 10d :2 10e :3 10d
:2 10e :2 10f :2 10e :5 10d
:10 110 112 :6 113 114
:3 115 116 :2 118 112
:6 119 :5 11a 119 :5 11c
11b :3 119 111 11f
:5 120 :3 11f :2 121 :5 123
:11 124 :24 125 :3 124 :2 122
:6 121 11e :6 110 10c
12c 12d :3 12e 12f
:2 131 12c :6 132 :5 133
132 :5 135 134 :3 132
12b 138 :5 139 :3 138
:2 13a :5 13c :11 13d :24 13e
:3 13d :2 13b :6 13a 137
:4 12a :3 10c :16 144 :8 146
:3 144 :6 149 :11 14c :30 14d
:3 14c :a 14f 16 :3 152
:11 153 :b 154 :17 155 :3 153
:2 157 :3 158 :3 159 15a
158 157 158 :3 15b
:3 152 :2 15c :5 15e :11 15f
:b 160 :18 161 :3 15f :2 163
164 :3 165 166 164
163 164 :3 167 :2 15d
:6 15c 151 :7 1 
1d9b
4
:3 0 1 :3 0 2
:a 0 85d 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 85d 2 14
:2 0 c :2 0 f
4 :3 0 c :2 0
d 17 19 :6 0
1c 1a 0 85b
0 b :6 0 c
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 85b
0 d :6 0 19
c7 0 17 4
:3 0 15 25 27
:6 0 2a 28 0
85b 0 e :6 0
14 :2 0 1d 10
:3 0 2c :7 0 2f
2d 0 85b 0
f :6 0 4 :3 0
12 :2 0 1b 31
33 :6 0 36 34
0 85b 0 11
:6 0 14 :2 0 1f
6 :3 0 38 :7 0
3c 39 3a 85b
0 13 :6 0 14
:2 0 21 6 :3 0
3e :7 0 42 3f
40 85b 0 15
:6 0 14 :2 0 23
6 :3 0 44 :7 0
48 45 46 85b
0 16 :6 0 14
:2 0 25 6 :3 0
4a :7 0 4e 4b
4c 85b 0 17
:6 0 14 :2 0 27
6 :3 0 50 :7 0
54 51 52 85b
0 18 :6 0 2b
1a7 0 29 6
:3 0 56 :7 0 5a
57 58 85b 0
19 :6 0 67 68
0 2d 6 :3 0
5c :7 0 5f 5d
0 85b 0 1a
:6 0 9 :3 0 a
:2 0 4 61 62
0 63 :7 0 66
64 0 85b 0
1b :6 0 1c :3 0
1d :3 0 1c :3 0
1e :3 0 6a 6b
0 2 :4 0 2f
6c 6e 69 70
6f :2 0 1f :3 0
20 :3 0 72 73
0 21 :4 0 1c
:3 0 22 :3 0 76
77 0 2 :4 0
31 78 7a 23
:4 0 24 :2 0 25
:3 0 33 7d 7f
:3 0 26 :4 0 24
:2 0 27 :4 0 36
82 84 :3 0 24
:2 0 3 :3 0 39
86 88 :3 0 24
:2 0 27 :4 0 3c
8a 8c :3 0 24
:2 0 28 :4 0 3f
8e 90 :3 0 24
:2 0 29 :3 0 2a
:3 0 5 :3 0 42
94 96 2b :4 0
44 93 99 47
92 9b :3 0 24
:2 0 28 :4 0 4a
9d 9f :3 0 24
:2 0 27 :4 0 4d
a1 a3 :3 0 24
:2 0 7 :3 0 50
a5 a7 :3 0 24
:2 0 27 :4 0 53
a9 ab :3 0 24
:2 0 2c :4 0 56
ad af :3 0 59
74 b1 :2 0 b3
5e b4 71 b3
0 b5 60 0
7bb 1c :3 0 1d
:3 0 b6 b7 0
1c :3 0 2d :3 0
b9 ba 0 12
:2 0 2 :4 0 2e
:2 0 2f :2 0 12
:2 0 62 bf c1
:3 0 65 bb c3
b8 c5 c4 :2 0
1f :3 0 30 :3 0
c7 c8 0 21
:4 0 31 :4 0 24
:2 0 25 :3 0 69
cc ce :3 0 6c
c9 d0 :2 0 d2
6f d3 c6 d2
0 d4 71 0
7bb 13 :3 0 5
:3 0 d5 d6 0
7bb b :3 0 3
:3 0 d8 d9 0
7bb 32 :3 0 33
:3 0 34 :3 0 35
:3 0 36 :3 0 37
:3 0 38 :3 0 d
:3 0 e :3 0 11
:3 0 17 :3 0 18
:3 0 19 :3 0 39
:3 0 3a :3 0 b
:4 0 3b 1 :8 0
f1 9 :3 0 3c
:3 0 ec ed 0
3d :3 0 ee ef
0 f1 73 144
3e :3 0 9 :3 0
3c :3 0 f3 f4
0 3d :3 0 f5
f6 0 f8 76
fa 78 f9 f8
:2 0 142 3f :3 0
9 :3 0 3c :3 0
fd fe 0 3d
:3 0 ff 100 0
13a 1c :3 0 1d
:3 0 102 103 0
1c :3 0 2d :3 0
105 106 0 40
:2 0 2 :4 0 41
:2 0 2f :2 0 12
:2 0 7a 10b 10d
:3 0 7d 107 10f
104 111 110 :2 0
1f :3 0 30 :3 0
113 114 0 21
:4 0 42 :4 0 24
:2 0 25 :3 0 81
118 11a :3 0 24
:2 0 43 :4 0 84
11c 11e :3 0 24
:2 0 44 :4 0 87
120 122 :3 0 24
:2 0 3d :3 0 8a
124 126 :3 0 24
:2 0 45 :4 0 8d
128 12a :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 90 12d 131
94 12c 133 :3 0
97 115 135 :2 0
137 9a 138 112
137 0 139 9c
0 13a 9e 13d
:3 0 13d 0 13d
13c 13a 13b :6 0
13f 2 :3 0 a1
141 a3 140 13f
:2 0 142 a5 :2 0
144 0 144 143
f1 142 :6 0 7bb
1 :3 0 29 :3 0
13 :3 0 14 :2 0
a8 146 149 49
:2 0 12 :2 0 ad
14b 14d :3 0 46
:3 0 11 :3 0 12
:2 0 12 :2 0 b0
14f 153 49 :2 0
4a :4 0 b6 155
157 :3 0 39 :3 0
4b :3 0 35 :3 0
37 :3 0 3a :3 0
b :4 0 4c 1
:8 0 175 4d :4 0
160 :3 0 4e :3 0
49 :2 0 bb 163
164 :3 0 9 :3 0
3c :3 0 166 167
0 14 :2 0 168
169 0 16b be
172 9 :3 0 3c
:3 0 16c 16d 0
4f :2 0 16e 16f
0 171 c0 173
165 16b 0 174
0 171 0 174
c2 0 175 c5
1c8 3e :3 0 9
:3 0 3c :3 0 177
178 0 3d :3 0
179 17a 0 17c
c8 17e ca 17d
17c :2 0 1c6 3f
:3 0 9 :3 0 3c
:3 0 181 182 0
3d :3 0 183 184
0 1be 1c :3 0
1d :3 0 186 187
0 1c :3 0 2d
:3 0 189 18a 0
40 :2 0 2 :4 0
50 :2 0 2f :2 0
12 :2 0 cc 18f
191 :3 0 cf 18b
193 188 195 194
:2 0 1f :3 0 30
:3 0 197 198 0
21 :4 0 51 :4 0
24 :2 0 25 :3 0
d3 19c 19e :3 0
24 :2 0 43 :4 0
d6 1a0 1a2 :3 0
24 :2 0 44 :4 0
d9 1a4 1a6 :3 0
24 :2 0 3d :3 0
dc 1a8 1aa :3 0
24 :2 0 45 :4 0
df 1ac 1ae :3 0
24 :2 0 46 :3 0
47 :3 0 12 :2 0
48 :2 0 e2 1b1
1b5 e6 1b0 1b7
:3 0 e9 199 1b9
:2 0 1bb ec 1bc
196 1bb 0 1bd
ee 0 1be f0
1c1 :3 0 1c1 0
1c1 1c0 1be 1bf
:6 0 1c3 4 :3 0
f3 1c5 f5 1c4
1c3 :2 0 1c6 f7
:2 0 1c8 0 1c8
1c7 175 1c6 :6 0
23e 1 :3 0 52
:3 0 53 :3 0 3a
:3 0 b :3 0 3a
:3 0 54 :3 0 55
:3 0 56 :3 0 57
:4 0 58 1 :8 0
1e9 4d :4 0 1d4
:3 0 4e :3 0 49
:2 0 fc 1d7 1d8
:3 0 9 :3 0 3c
:3 0 1da 1db 0
14 :2 0 1dc 1dd
0 1df ff 1e6
9 :3 0 3c :3 0
1e0 1e1 0 4f
:2 0 1e2 1e3 0
1e5 101 1e7 1d9
1df 0 1e8 0
1e5 0 1e8 103
0 1e9 106 23c
3e :3 0 9 :3 0
3c :3 0 1eb 1ec
0 3d :3 0 1ed
1ee 0 1f0 109
1f2 10b 1f1 1f0
:2 0 23a 3f :3 0
9 :3 0 3c :3 0
1f5 1f6 0 3d
:3 0 1f7 1f8 0
232 1c :3 0 1d
:3 0 1fa 1fb 0
1c :3 0 2d :3 0
1fd 1fe 0 40
:2 0 2 :4 0 59
:2 0 2f :2 0 12
:2 0 10d 203 205
:3 0 110 1ff 207
1fc 209 208 :2 0
1f :3 0 30 :3 0
20b 20c 0 21
:4 0 5a :4 0 24
:2 0 25 :3 0 114
210 212 :3 0 24
:2 0 43 :4 0 117
214 216 :3 0 24
:2 0 44 :4 0 11a
218 21a :3 0 24
:2 0 3d :3 0 11d
21c 21e :3 0 24
:2 0 45 :4 0 120
220 222 :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 123 225 229
127 224 22b :3 0
12a 20d 22d :2 0
22f 12d 230 20a
22f 0 231 12f
0 232 131 235
:3 0 235 0 235
234 232 233 :6 0
237 6 :3 0 134
239 136 238 237
:2 0 23a 138 :2 0
23c 0 23c 23b
1e9 23a :6 0 23e
1 :3 0 13b 2b2
39 :3 0 4b :3 0
36 :3 0 37 :3 0
38 :3 0 3a :3 0
b :4 0 5b 1
:8 0 25c 4d :4 0
247 :3 0 4e :3 0
49 :2 0 140 24a
24b :3 0 9 :3 0
3c :3 0 24d 24e
0 14 :2 0 24f
250 0 252 143
259 9 :3 0 3c
:3 0 253 254 0
4f :2 0 255 256
0 258 145 25a
24c 252 0 25b
0 258 0 25b
147 0 25c 14a
2af 3e :3 0 9
:3 0 3c :3 0 25e
25f 0 3d :3 0
260 261 0 263
14d 265 14f 264
263 :2 0 2ad 3f
:3 0 9 :3 0 3c
:3 0 268 269 0
3d :3 0 26a 26b
0 2a5 1c :3 0
1d :3 0 26d 26e
0 1c :3 0 2d
:3 0 270 271 0
40 :2 0 2 :4 0
5c :2 0 2f :2 0
12 :2 0 151 276
278 :3 0 154 272
27a 26f 27c 27b
:2 0 1f :3 0 30
:3 0 27e 27f 0
21 :4 0 5d :4 0
24 :2 0 25 :3 0
158 283 285 :3 0
24 :2 0 43 :4 0
15b 287 289 :3 0
24 :2 0 44 :4 0
15e 28b 28d :3 0
24 :2 0 3d :3 0
161 28f 291 :3 0
24 :2 0 45 :4 0
164 293 295 :3 0
24 :2 0 46 :3 0
47 :3 0 12 :2 0
48 :2 0 167 298
29c 16b 297 29e
:3 0 16e 280 2a0
:2 0 2a2 171 2a3
27d 2a2 0 2a4
173 0 2a5 175
2a8 :3 0 2a8 0
2a8 2a7 2a5 2a6
:6 0 2aa 8 :3 0
178 2ac 17a 2ab
2aa :2 0 2ad 17c
:2 0 2af 0 2af
2ae 25c 2ad :6 0
2b1 1 :3 0 17f
2b3 158 23e 0
2b4 0 2b1 0
2b4 181 0 329
5e :3 0 5f :3 0
60 :3 0 61 :3 0
5f :3 0 56 :3 0
62 :3 0 54 :3 0
e :4 0 63 1
:8 0 2d4 4d :4 0
2bf :3 0 4e :3 0
49 :2 0 186 2c2
2c3 :3 0 9 :3 0
3c :3 0 2c5 2c6
0 14 :2 0 2c7
2c8 0 2ca 189
2d1 9 :3 0 3c
:3 0 2cb 2cc 0
4f :2 0 2cd 2ce
0 2d0 18b 2d2
2c4 2ca 0 2d3
0 2d0 0 2d3
18d 0 2d4 190
327 3e :3 0 9
:3 0 3c :3 0 2d6
2d7 0 3d :3 0
2d8 2d9 0 2db
193 2dd 195 2dc
2db :2 0 325 3f
:3 0 9 :3 0 3c
:3 0 2e0 2e1 0
3d :3 0 2e2 2e3
0 31d 1c :3 0
1d :3 0 2e5 2e6
0 1c :3 0 2d
:3 0 2e8 2e9 0
40 :2 0 2 :4 0
64 :2 0 2f :2 0
12 :2 0 197 2ee
2f0 :3 0 19a 2ea
2f2 2e7 2f4 2f3
:2 0 1f :3 0 30
:3 0 2f6 2f7 0
21 :4 0 65 :4 0
24 :2 0 25 :3 0
19e 2fb 2fd :3 0
24 :2 0 43 :4 0
1a1 2ff 301 :3 0
24 :2 0 44 :4 0
1a4 303 305 :3 0
24 :2 0 3d :3 0
1a7 307 309 :3 0
24 :2 0 45 :4 0
1aa 30b 30d :3 0
24 :2 0 46 :3 0
47 :3 0 12 :2 0
48 :2 0 1ad 310
314 1b1 30f 316
:3 0 1b4 2f8 318
:2 0 31a 1b7 31b
2f5 31a 0 31c
1b9 0 31d 1bb
320 :3 0 320 0
320 31f 31d 31e
:6 0 322 a :3 0
1be 324 1c0 323
322 :2 0 325 1c2
:2 0 327 0 327
326 2d4 325 :6 0
329 1 :3 0 1c5
5fe 29 :3 0 13
:3 0 14 :2 0 1c8
32a 32d 49 :2 0
4a :2 0 1cd 32f
331 :3 0 39 :3 0
66 :3 0 67 :3 0
68 :3 0 3a :3 0
b :4 0 69 1
:8 0 34f 4d :4 0
33a :3 0 4e :3 0
49 :2 0 1d2 33d
33e :3 0 9 :3 0
3c :3 0 340 341
0 14 :2 0 342
343 0 345 1d5
34c 9 :3 0 3c
:3 0 346 347 0
4f :2 0 348 349
0 34b 1d7 34d
33f 345 0 34e
0 34b 0 34e
1d9 0 34f 1dc
3a2 3e :3 0 9
:3 0 3c :3 0 351
352 0 3d :3 0
353 354 0 356
1df 358 1e1 357
356 :2 0 3a0 3f
:3 0 9 :3 0 3c
:3 0 35b 35c 0
3d :3 0 35d 35e
0 398 1c :3 0
1d :3 0 360 361
0 1c :3 0 2d
:3 0 363 364 0
40 :2 0 2 :4 0
6a :2 0 2f :2 0
12 :2 0 1e3 369
36b :3 0 1e6 365
36d 362 36f 36e
:2 0 1f :3 0 30
:3 0 371 372 0
21 :4 0 6b :4 0
24 :2 0 25 :3 0
1ea 376 378 :3 0
24 :2 0 43 :4 0
1ed 37a 37c :3 0
24 :2 0 44 :4 0
1f0 37e 380 :3 0
24 :2 0 3d :3 0
1f3 382 384 :3 0
24 :2 0 45 :4 0
1f6 386 388 :3 0
24 :2 0 46 :3 0
47 :3 0 12 :2 0
48 :2 0 1f9 38b
38f 1fd 38a 391
:3 0 200 373 393
:2 0 395 203 396
370 395 0 397
205 0 398 207
39b :3 0 39b 0
39b 39a 398 399
:6 0 39d c :3 0
20a 39f 20c 39e
39d :2 0 3a0 20e
:2 0 3a2 0 3a2
3a1 34f 3a0 :6 0
418 1 :3 0 5e
:3 0 5f :3 0 60
:3 0 61 :3 0 5f
:3 0 56 :3 0 62
:3 0 54 :3 0 e
:4 0 63 1 :8 0
3c3 4d :4 0 3ae
:3 0 4e :3 0 49
:2 0 213 3b1 3b2
:3 0 9 :3 0 3c
:3 0 3b4 3b5 0
14 :2 0 3b6 3b7
0 3b9 216 3c0
9 :3 0 3c :3 0
3ba 3bb 0 4f
:2 0 3bc 3bd 0
3bf 218 3c1 3b3
3b9 0 3c2 0
3bf 0 3c2 21a
0 3c3 21d 416
3e :3 0 9 :3 0
3c :3 0 3c5 3c6
0 3d :3 0 3c7
3c8 0 3ca 220
3cc 222 3cb 3ca
:2 0 414 3f :3 0
9 :3 0 3c :3 0
3cf 3d0 0 3d
:3 0 3d1 3d2 0
40c 1c :3 0 1d
:3 0 3d4 3d5 0
1c :3 0 2d :3 0
3d7 3d8 0 40
:2 0 2 :4 0 6c
:2 0 2f :2 0 12
:2 0 224 3dd 3df
:3 0 227 3d9 3e1
3d6 3e3 3e2 :2 0
1f :3 0 30 :3 0
3e5 3e6 0 21
:4 0 6d :4 0 24
:2 0 25 :3 0 22b
3ea 3ec :3 0 24
:2 0 43 :4 0 22e
3ee 3f0 :3 0 24
:2 0 44 :4 0 231
3f2 3f4 :3 0 24
:2 0 3d :3 0 234
3f6 3f8 :3 0 24
:2 0 45 :4 0 237
3fa 3fc :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 23a 3ff 403
23e 3fe 405 :3 0
241 3e7 407 :2 0
409 244 40a 3e4
409 0 40b 246
0 40c 248 40f
:3 0 40f 0 40f
40e 40c 40d :6 0
411 e :3 0 24b
413 24d 412 411
:2 0 414 24f :2 0
416 0 416 415
3c3 414 :6 0 418
1 :3 0 252 5fa
46 :3 0 11 :3 0
12 :2 0 12 :2 0
255 419 41d 49
:2 0 4a :4 0 25b
41f 421 :3 0 39
:3 0 66 :3 0 67
:3 0 68 :3 0 4b
:3 0 35 :3 0 37
:3 0 3a :3 0 b
:4 0 6e 1 :8 0
442 4d :4 0 42d
:3 0 4e :3 0 49
:2 0 260 430 431
:3 0 9 :3 0 3c
:3 0 433 434 0
14 :2 0 435 436
0 438 263 43f
9 :3 0 3c :3 0
439 43a 0 4f
:2 0 43b 43c 0
43e 265 440 432
438 0 441 0
43e 0 441 267
0 442 26a 495
3e :3 0 9 :3 0
3c :3 0 444 445
0 3d :3 0 446
447 0 449 26d
44b 26f 44a 449
:2 0 493 3f :3 0
9 :3 0 3c :3 0
44e 44f 0 3d
:3 0 450 451 0
48b 1c :3 0 1d
:3 0 453 454 0
1c :3 0 2d :3 0
456 457 0 40
:2 0 2 :4 0 6f
:2 0 2f :2 0 12
:2 0 271 45c 45e
:3 0 274 458 460
455 462 461 :2 0
1f :3 0 30 :3 0
464 465 0 21
:4 0 70 :4 0 24
:2 0 25 :3 0 278
469 46b :3 0 24
:2 0 43 :4 0 27b
46d 46f :3 0 24
:2 0 44 :4 0 27e
471 473 :3 0 24
:2 0 3d :3 0 281
475 477 :3 0 24
:2 0 45 :4 0 284
479 47b :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 287 47e 482
28b 47d 484 :3 0
28e 466 486 :2 0
488 291 489 463
488 0 48a 293
0 48b 295 48e
:3 0 48e 0 48e
48d 48b 48c :6 0
490 10 :3 0 298
492 29a 491 490
:2 0 493 29c :2 0
495 0 495 494
442 493 :6 0 50b
1 :3 0 52 :3 0
53 :3 0 3a :3 0
b :3 0 3a :3 0
54 :3 0 55 :3 0
56 :3 0 57 :4 0
71 1 :8 0 4b6
4d :4 0 4a1 :3 0
4e :3 0 49 :2 0
2a1 4a4 4a5 :3 0
9 :3 0 3c :3 0
4a7 4a8 0 14
:2 0 4a9 4aa 0
4ac 2a4 4b3 9
:3 0 3c :3 0 4ad
4ae 0 4f :2 0
4af 4b0 0 4b2
2a6 4b4 4a6 4ac
0 4b5 0 4b2
0 4b5 2a8 0
4b6 2ab 509 3e
:3 0 9 :3 0 3c
:3 0 4b8 4b9 0
3d :3 0 4ba 4bb
0 4bd 2ae 4bf
2b0 4be 4bd :2 0
507 3f :3 0 9
:3 0 3c :3 0 4c2
4c3 0 3d :3 0
4c4 4c5 0 4ff
1c :3 0 1d :3 0
4c7 4c8 0 1c
:3 0 2d :3 0 4ca
4cb 0 40 :2 0
2 :4 0 72 :2 0
2f :2 0 12 :2 0
2b2 4d0 4d2 :3 0
2b5 4cc 4d4 4c9
4d6 4d5 :2 0 1f
:3 0 30 :3 0 4d8
4d9 0 21 :4 0
73 :4 0 24 :2 0
25 :3 0 2b9 4dd
4df :3 0 24 :2 0
43 :4 0 2bc 4e1
4e3 :3 0 24 :2 0
44 :4 0 2bf 4e5
4e7 :3 0 24 :2 0
3d :3 0 2c2 4e9
4eb :3 0 24 :2 0
45 :4 0 2c5 4ed
4ef :3 0 24 :2 0
46 :3 0 47 :3 0
12 :2 0 48 :2 0
2c8 4f2 4f6 2cc
4f1 4f8 :3 0 2cf
4da 4fa :2 0 4fc
2d2 4fd 4d7 4fc
0 4fe 2d4 0
4ff 2d6 502 :3 0
502 0 502 501
4ff 500 :6 0 504
12 :3 0 2d9 506
2db 505 504 :2 0
507 2dd :2 0 509
0 509 508 4b6
507 :6 0 50b 1
:3 0 2e0 582 39
:3 0 66 :3 0 67
:3 0 68 :3 0 4b
:3 0 36 :3 0 37
:3 0 38 :3 0 3a
:3 0 b :4 0 74
1 :8 0 52c 4d
:4 0 517 :3 0 4e
:3 0 49 :2 0 2e5
51a 51b :3 0 9
:3 0 3c :3 0 51d
51e 0 14 :2 0
51f 520 0 522
2e8 529 9 :3 0
3c :3 0 523 524
0 4f :2 0 525
526 0 528 2ea
52a 51c 522 0
52b 0 528 0
52b 2ec 0 52c
2ef 57f 3e :3 0
9 :3 0 3c :3 0
52e 52f 0 3d
:3 0 530 531 0
533 2f2 535 2f4
534 533 :2 0 57d
3f :3 0 9 :3 0
3c :3 0 538 539
0 3d :3 0 53a
53b 0 575 1c
:3 0 1d :3 0 53d
53e 0 1c :3 0
2d :3 0 540 541
0 40 :2 0 2
:4 0 75 :2 0 2f
:2 0 12 :2 0 2f6
546 548 :3 0 2f9
542 54a 53f 54c
54b :2 0 1f :3 0
30 :3 0 54e 54f
0 21 :4 0 76
:4 0 24 :2 0 25
:3 0 2fd 553 555
:3 0 24 :2 0 43
:4 0 300 557 559
:3 0 24 :2 0 44
:4 0 303 55b 55d
:3 0 24 :2 0 3d
:3 0 306 55f 561
:3 0 24 :2 0 45
:4 0 309 563 565
:3 0 24 :2 0 46
:3 0 47 :3 0 12
:2 0 48 :2 0 30c
568 56c 310 567
56e :3 0 313 550
570 :2 0 572 316
573 54d 572 0
574 318 0 575
31a 578 :3 0 578
0 578 577 575
576 :6 0 57a 14
:3 0 31d 57c 31f
57b 57a :2 0 57d
321 :2 0 57f 0
57f 57e 52c 57d
:6 0 581 1 :3 0
324 583 422 50b
0 584 0 581
0 584 326 0
5f9 5e :3 0 5f
:3 0 60 :3 0 61
:3 0 5f :3 0 56
:3 0 62 :3 0 54
:3 0 e :4 0 63
1 :8 0 5a4 4d
:4 0 58f :3 0 4e
:3 0 49 :2 0 32b
592 593 :3 0 9
:3 0 3c :3 0 595
596 0 14 :2 0
597 598 0 59a
32e 5a1 9 :3 0
3c :3 0 59b 59c
0 4f :2 0 59d
59e 0 5a0 330
5a2 594 59a 0
5a3 0 5a0 0
5a3 332 0 5a4
335 5f7 3e :3 0
9 :3 0 3c :3 0
5a6 5a7 0 3d
:3 0 5a8 5a9 0
5ab 338 5ad 33a
5ac 5ab :2 0 5f5
3f :3 0 9 :3 0
3c :3 0 5b0 5b1
0 3d :3 0 5b2
5b3 0 5ed 1c
:3 0 1d :3 0 5b5
5b6 0 1c :3 0
2d :3 0 5b8 5b9
0 40 :2 0 2
:4 0 77 :2 0 2f
:2 0 12 :2 0 33c
5be 5c0 :3 0 33f
5ba 5c2 5b7 5c4
5c3 :2 0 1f :3 0
30 :3 0 5c6 5c7
0 21 :4 0 78
:4 0 24 :2 0 25
:3 0 343 5cb 5cd
:3 0 24 :2 0 43
:4 0 346 5cf 5d1
:3 0 24 :2 0 44
:4 0 349 5d3 5d5
:3 0 24 :2 0 3d
:3 0 34c 5d7 5d9
:3 0 24 :2 0 45
:4 0 34f 5db 5dd
:3 0 24 :2 0 46
:3 0 47 :3 0 12
:2 0 48 :2 0 352
5e0 5e4 356 5df
5e6 :3 0 359 5c8
5e8 :2 0 5ea 35c
5eb 5c5 5ea 0
5ec 35e 0 5ed
360 5f0 :3 0 5f0
0 5f0 5ef 5ed
5ee :6 0 5f2 16
:3 0 363 5f4 365
5f3 5f2 :2 0 5f5
367 :2 0 5f7 0
5f7 5f6 5a4 5f5
:6 0 5f9 1 :3 0
36a 5fb 332 418
0 5fc 0 5f9
0 5fc 36d 0
5fd 370 5ff 14e
329 0 600 0
5fd 0 600 372
0 7bb 79 :3 0
29 :3 0 13 :3 0
14 :2 0 375 602
605 12 :2 0 378
601 608 609 :2 0
49 :2 0 12 :2 0
37d 60b 60d :3 0
60e :2 0 29 :3 0
19 :3 0 14 :2 0
380 610 613 7a
:2 0 14 :2 0 385
615 617 :3 0 618
:2 0 60f 61a 619
:2 0 1a :3 0 7b
:3 0 29 :3 0 7c
:3 0 18 :3 0 388
61f 621 14 :2 0
38a 61e 624 7d
:2 0 29 :3 0 7c
:3 0 17 :3 0 38d
628 62a 14 :2 0
38f 627 62d 392
626 62f :3 0 630
:2 0 7e :2 0 7f
:2 0 395 632 634
:3 0 635 :2 0 80
:2 0 29 :3 0 19
:3 0 14 :2 0 398
638 63b 39b 637
63d :3 0 39e 61d
63f 61c 640 0
6ce 1a :3 0 7a
:2 0 12 :2 0 3a2
643 645 :3 0 646
:2 0 1a :3 0 81
:2 0 80 :2 0 12
:2 0 3a5 64a 64c
:3 0 3a9 649 64e
:3 0 647 650 64f
:2 0 39 :3 0 5f
:3 0 60 :3 0 61
:3 0 5f :3 0 56
:3 0 82 :3 0 83
:3 0 83 :3 0 4b
:3 0 84 :3 0 83
:3 0 3a :3 0 b
:4 0 85 1 :8 0
676 4d :4 0 661
:3 0 4e :3 0 49
:2 0 3ae 664 665
:3 0 9 :3 0 3c
:3 0 667 668 0
14 :2 0 669 66a
0 66c 3b1 673
9 :3 0 3c :3 0
66d 66e 0 4f
:2 0 66f 670 0
672 3b3 674 666
66c 0 675 0
672 0 675 3b5
0 676 3b8 6c9
3e :3 0 9 :3 0
3c :3 0 678 679
0 3d :3 0 67a
67b 0 67d 3bb
67f 3bd 67e 67d
:2 0 6c7 3f :3 0
9 :3 0 3c :3 0
682 683 0 3d
:3 0 684 685 0
6bf 1c :3 0 1d
:3 0 687 688 0
1c :3 0 2d :3 0
68a 68b 0 40
:2 0 2 :4 0 86
:2 0 2f :2 0 12
:2 0 3bf 690 692
:3 0 3c2 68c 694
689 696 695 :2 0
1f :3 0 30 :3 0
698 699 0 21
:4 0 87 :4 0 24
:2 0 25 :3 0 3c6
69d 69f :3 0 24
:2 0 43 :4 0 3c9
6a1 6a3 :3 0 24
:2 0 44 :4 0 3cc
6a5 6a7 :3 0 24
:2 0 3d :3 0 3cf
6a9 6ab :3 0 24
:2 0 45 :4 0 3d2
6ad 6af :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 3d5 6b2 6b6
3d9 6b1 6b8 :3 0
3dc 69a 6ba :2 0
6bc 3df 6bd 697
6bc 0 6be 3e1
0 6bf 3e3 6c2
:3 0 6c2 0 6c2
6c1 6bf 6c0 :6 0
6c4 18 :3 0 3e6
6c6 3e8 6c5 6c4
:2 0 6c7 3ea :2 0
6c9 0 6c9 6c8
676 6c7 :6 0 6cb
1 :3 0 3ed 6cc
651 6cb 0 6cd
3ef 0 6ce 3f1
743 39 :3 0 83
:3 0 83 :3 0 4b
:3 0 84 :3 0 83
:3 0 3a :3 0 b
:4 0 88 1 :8 0
6ed 4d :4 0 6d8
:3 0 4e :3 0 49
:2 0 3f6 6db 6dc
:3 0 9 :3 0 3c
:3 0 6de 6df 0
14 :2 0 6e0 6e1
0 6e3 3f9 6ea
9 :3 0 3c :3 0
6e4 6e5 0 4f
:2 0 6e6 6e7 0
6e9 3fb 6eb 6dd
6e3 0 6ec 0
6e9 0 6ec 3fd
0 6ed 400 740
3e :3 0 9 :3 0
3c :3 0 6ef 6f0
0 3d :3 0 6f1
6f2 0 6f4 403
6f6 405 6f5 6f4
:2 0 73e 3f :3 0
9 :3 0 3c :3 0
6f9 6fa 0 3d
:3 0 6fb 6fc 0
736 1c :3 0 1d
:3 0 6fe 6ff 0
1c :3 0 2d :3 0
701 702 0 40
:2 0 2 :4 0 89
:2 0 2f :2 0 12
:2 0 407 707 709
:3 0 40a 703 70b
700 70d 70c :2 0
1f :3 0 30 :3 0
70f 710 0 21
:4 0 8a :4 0 24
:2 0 25 :3 0 40e
714 716 :3 0 24
:2 0 43 :4 0 411
718 71a :3 0 24
:2 0 44 :4 0 414
71c 71e :3 0 24
:2 0 3d :3 0 417
720 722 :3 0 24
:2 0 45 :4 0 41a
724 726 :3 0 24
:2 0 46 :3 0 47
:3 0 12 :2 0 48
:2 0 41d 729 72d
421 728 72f :3 0
424 711 731 :2 0
733 427 734 70e
733 0 735 429
0 736 42b 739
:3 0 739 0 739
738 736 737 :6 0
73b 1a :3 0 42e
73d 430 73c 73b
:2 0 73e 432 :2 0
740 0 740 73f
6ed 73e :6 0 742
1 :3 0 435 744
61b 6ce 0 745
0 742 0 745
437 0 7bb 9
:3 0 3c :3 0 746
747 0 9 :3 0
49 :2 0 8b :3 0
749 74b 0 43c
74a 74d :3 0 74e
:2 0 29 :3 0 13
:3 0 14 :2 0 43f
750 753 8c :2 0
4a :2 0 444 755
757 :3 0 758 :2 0
74f 75a 759 :2 0
15 :3 0 8d :3 0
d :3 0 b :3 0
13 :3 0 447 75d
761 75c 762 0
764 44b 765 75b
764 0 766 44d
0 7bb 15 :3 0
8e :3 0 d :3 0
44f 768 76a 767
76b 0 7bb 1c
:3 0 1d :3 0 76d
76e 0 1c :3 0
2d :3 0 770 771
0 8f :2 0 2
:4 0 90 :2 0 2f
:2 0 12 :2 0 451
776 778 :3 0 454
772 77a 76f 77c
77b :2 0 1f :3 0
30 :3 0 77e 77f
0 21 :4 0 91
:4 0 24 :2 0 25
:3 0 458 783 785
:3 0 24 :2 0 43
:4 0 45b 787 789
:3 0 24 :2 0 92
:4 0 45e 78b 78d
:3 0 24 :2 0 29
:3 0 2a :3 0 9
:3 0 3c :3 0 792
793 0 461 791
795 2b :4 0 463
790 798 466 78f
79a :3 0 24 :2 0
93 :4 0 469 79c
79e :3 0 24 :2 0
27 :4 0 46c 7a0
7a2 :3 0 24 :2 0
3 :3 0 46f 7a4
7a6 :3 0 24 :2 0
27 :4 0 472 7a8
7aa :3 0 475 780
7ac :2 0 7ae 478
7af 77d 7ae 0
7b0 47a 0 7bb
94 :3 0 95 :3 0
7b1 7b2 0 9
:3 0 3c :3 0 7b4
7b5 0 3 :3 0
4e :3 0 47c 7b3
7b9 :2 0 7bb 480
85c 9 :3 0 96
:2 0 4 7bc 7bd
0 1c :3 0 1d
:3 0 7bf 7c0 0
1c :3 0 2d :3 0
7c2 7c3 0 40
:2 0 2 :4 0 97
:2 0 2f :2 0 12
:2 0 48c 7c8 7ca
:3 0 48f 7c4 7cc
7c1 7ce 7cd :2 0
1f :3 0 30 :3 0
7d0 7d1 0 21
:4 0 98 :4 0 24
:2 0 25 :3 0 493
7d5 7d7 :3 0 496
7d2 7d9 :2 0 7f2
1f :3 0 30 :3 0
7db 7dc 0 21
:4 0 99 :4 0 24
:2 0 9 :3 0 9a
:3 0 7e1 7e2 0
499 7e0 7e4 :3 0
24 :2 0 93 :4 0
49c 7e6 7e8 :3 0
24 :2 0 9 :3 0
9b :3 0 7eb 7ec
0 49f 7ea 7ee
:3 0 4a2 7dd 7f0
:2 0 7f2 4a5 7f3
7cf 7f2 0 7f4
4a8 0 804 9c
:3 0 1b :3 0 9
:3 0 9a :3 0 9d
:3 0 9 :3 0 9b
:3 0 9e :3 0 9f
:4 0 a0 1 :a 0
800 :2 0 804 7f6
7fe :2 0 8 :3 0
1b :3 0 802 :2 0
804 4aa 806 4ae
805 804 :2 0 85a
3f :3 0 9 :3 0
3c :3 0 809 80a
0 3d :3 0 80b
80c 0 852 1c
:3 0 1d :3 0 80e
80f 0 1c :3 0
2d :3 0 811 812
0 40 :2 0 2
:4 0 a1 :2 0 2f
:2 0 12 :2 0 4b0
817 819 :3 0 4b3
813 81b 810 81d
81c :2 0 1f :3 0
30 :3 0 81f 820
0 21 :4 0 a2
:4 0 24 :2 0 25
:3 0 4b7 824 826
:3 0 4ba 821 828
:2 0 842 1f :3 0
30 :3 0 82a 82b
0 21 :4 0 44
:4 0 24 :2 0 3d
:3 0 4bd 82f 831
:3 0 24 :2 0 45
:4 0 4c0 833 835
:3 0 24 :2 0 46
:3 0 47 :3 0 12
:2 0 48 :2 0 4c3
838 83c 4c7 837
83e :3 0 4ca 82c
840 :2 0 842 4cd
843 81e 842 0
844 4d0 0 852
9c :3 0 1b :3 0
9d :3 0 9 :3 0
9b :3 0 9e :3 0
9f :4 0 a3 1
:a 0 84e :2 0 852
846 84c :2 0 8
:3 0 1b :3 0 850
:2 0 852 4d2 855
:3 0 855 0 855
854 852 853 :6 0
857 1 :3 0 4d7
859 4d9 858 857
:2 0 85a 4db :2 0
85c 4de 85c 85b
7bb 85a :6 0 85d
:2 0 2 14 85c
860 :3 0 85f 85d
861 :8 0 
4ec
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2b 1 32 1
30 1 37 1
3d 1 43 1
49 1 4f 1
55 1 5b 1
60 1 6d 1
79 2 7c 7e
2 81 83 2
85 87 2 89
8b 2 8d 8f
1 95 2 97
98 2 91 9a
2 9c 9e 2
a0 a2 2 a4
a6 2 a8 aa
2 ac ae 4
75 7b 80 b0
1 b2 1 b4
2 be c0 3
bc bd c2 2
cb cd 2 ca
cf 1 d1 1
d3 2 eb f0
1 f7 1 f2
2 10a 10c 3
108 109 10e 2
117 119 2 11b
11d 2 11f 121
2 123 125 2
127 129 3 12e
12f 130 2 12b
132 2 116 134
1 136 1 138
2 101 139 1
13d 1 fc 2
fa 141 2 147
148 1 14c 2
14a 14c 3 150
151 152 1 156
2 154 156 1
162 2 161 162
1 16a 1 170
2 172 173 2
15f 174 1 17b
1 176 2 18e
190 3 18c 18d
192 2 19b 19d
2 19f 1a1 2
1a3 1a5 2 1a7
1a9 2 1ab 1ad
3 1b2 1b3 1b4
2 1af 1b6 2
19a 1b8 1 1ba
1 1bc 2 185
1bd 1 1c1 1
180 2 17e 1c5
1 1d6 2 1d5
1d6 1 1de 1
1e4 2 1e6 1e7
2 1d3 1e8 1
1ef 1 1ea 2
202 204 3 200
201 206 2 20f
211 2 213 215
2 217 219 2
21b 21d 2 21f
221 3 226 227
228 2 223 22a
2 20e 22c 1
22e 1 230 2
1f9 231 1 235
1 1f4 2 1f2
239 2 1c8 23c
1 249 2 248
249 1 251 1
257 2 259 25a
2 246 25b 1
262 1 25d 2
275 277 3 273
274 279 2 282
284 2 286 288
2 28a 28c 2
28e 290 2 292
294 3 299 29a
29b 2 296 29d
2 281 29f 1
2a1 1 2a3 2
26c 2a4 1 2a8
1 267 2 265
2ac 1 2af 2
2b2 2b3 1 2c1
2 2c0 2c1 1
2c9 1 2cf 2
2d1 2d2 2 2be
2d3 1 2da 1
2d5 2 2ed 2ef
3 2eb 2ec 2f1
2 2fa 2fc 2
2fe 300 2 302
304 2 306 308
2 30a 30c 3
311 312 313 2
30e 315 2 2f9
317 1 319 1
31b 2 2e4 31c
1 320 1 2df
2 2dd 324 2
2b4 327 2 32b
32c 1 330 2
32e 330 1 33c
2 33b 33c 1
344 1 34a 2
34c 34d 2 339
34e 1 355 1
350 2 368 36a
3 366 367 36c
2 375 377 2
379 37b 2 37d
37f 2 381 383
2 385 387 3
38c 38d 38e 2
389 390 2 374
392 1 394 1
396 2 35f 397
1 39b 1 35a
2 358 39f 1
3b0 2 3af 3b0
1 3b8 1 3be
2 3c0 3c1 2
3ad 3c2 1 3c9
1 3c4 2 3dc
3de 3 3da 3db
3e0 2 3e9 3eb
2 3ed 3ef 2
3f1 3f3 2 3f5
3f7 2 3f9 3fb
3 400 401 402
2 3fd 404 2
3e8 406 1 408
1 40a 2 3d3
40b 1 40f 1
3ce 2 3cc 413
2 3a2 416 3
41a 41b 41c 1
420 2 41e 420
1 42f 2 42e
42f 1 437 1
43d 2 43f 440
2 42c 441 1
448 1 443 2
45b 45d 3 459
45a 45f 2 468
46a 2 46c 46e
2 470 472 2
474 476 2 478
47a 3 47f 480
481 2 47c 483
2 467 485 1
487 1 489 2
452 48a 1 48e
1 44d 2 44b
492 1 4a3 2
4a2 4a3 1 4ab
1 4b1 2 4b3
4b4 2 4a0 4b5
1 4bc 1 4b7
2 4cf 4d1 3
4cd 4ce 4d3 2
4dc 4de 2 4e0
4e2 2 4e4 4e6
2 4e8 4ea 2
4ec 4ee 3 4f3
4f4 4f5 2 4f0
4f7 2 4db 4f9
1 4fb 1 4fd
2 4c6 4fe 1
502 1 4c1 2
4bf 506 2 495
509 1 519 2
518 519 1 521
1 527 2 529
52a 2 516 52b
1 532 1 52d
2 545 547 3
543 544 549 2
552 554 2 556
558 2 55a 55c
2 55e 560 2
562 564 3 569
56a 56b 2 566
56d 2 551 56f
1 571 1 573
2 53c 574 1
578 1 537 2
535 57c 1 57f
2 582 583 1
591 2 590 591
1 599 1 59f
2 5a1 5a2 2
58e 5a3 1 5aa
1 5a5 2 5bd
5bf 3 5bb 5bc
5c1 2 5ca 5cc
2 5ce 5d0 2
5d2 5d4 2 5d6
5d8 2 5da 5dc
3 5e1 5e2 5e3
2 5de 5e5 2
5c9 5e7 1 5e9
1 5eb 2 5b4
5ec 1 5f0 1
5af 2 5ad 5f4
2 584 5f7 2
5fa 5fb 1 5fc
2 5fe 5ff 2
603 604 2 606
607 1 60c 2
60a 60c 2 611
612 1 616 2
614 616 1 620
2 622 623 1
629 2 62b 62c
2 625 62e 2
631 633 2 639
63a 2 636 63c
1 63e 1 644
2 642 644 1
64b 1 64d 2
648 64d 1 663
2 662 663 1
66b 1 671 2
673 674 2 660
675 1 67c 1
677 2 68f 691
3 68d 68e 693
2 69c 69e 2
6a0 6a2 2 6a4
6a6 2 6a8 6aa
2 6ac 6ae 3
6b3 6b4 6b5 2
6b0 6b7 2 69b
6b9 1 6bb 1
6bd 2 686 6be
1 6c2 1 681
2 67f 6c6 1
6c9 1 6cc 2
641 6cd 1 6da
2 6d9 6da 1
6e2 1 6e8 2
6ea 6eb 2 6d7
6ec 1 6f3 1
6ee 2 706 708
3 704 705 70a
2 713 715 2
717 719 2 71b
71d 2 71f 721
2 723 725 3
72a 72b 72c 2
727 72e 2 712
730 1 732 1
734 2 6fd 735
1 739 1 6f8
2 6f6 73d 1
740 2 743 744
1 74c 2 748
74c 2 751 752
1 756 2 754
756 3 75e 75f
760 1 763 1
765 1 769 2
775 777 3 773
774 779 2 782
784 2 786 788
2 78a 78c 1
794 2 796 797
2 78e 799 2
79b 79d 2 79f
7a1 2 7a3 7a5
2 7a7 7a9 2
781 7ab 1 7ad
1 7af 3 7b6
7b7 7b8 b b5
d4 d7 da 144
600 745 766 76c
7b0 7ba 2 7c7
7c9 3 7c5 7c6
7cb 2 7d4 7d6
2 7d3 7d8 2
7df 7e3 2 7e5
7e7 2 7e9 7ed
2 7de 7ef 2
7da 7f1 1 7f3
3 7f4 7ff 803
1 7be 2 816
818 3 814 815
81a 2 823 825
2 822 827 2
82e 830 2 832
834 3 839 83a
83b 2 836 83d
2 82d 83f 2
829 841 1 843
4 80d 844 84d
851 1 855 1
808 2 806 859
d 1b 22 29
2e 35 3b 41
47 4d 53 59
5e 65 
1
4
0 
860
0
1
28
1c
11
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 0 0 0 0
0 0 0 0 0 0 0 0

b 1 0
55 1 0
16 1 0
2 0 1
3d 1 0
3 1 0
2b 1 0
37 1 0
49 1 0
24 1 0
4f 1 0
30 1 0
43 1 0
1d 1 0
7 1 0
5b 1 0
60 1 0
0

/
SHOW ERRORS FUNCTION SP_RJCT_ETC_ASSIGN;
ALTER FUNCTION SP_RJCT_ETC_ASSIGN COMPILE DEBUG;
/****************************************************************************************
Reject ETC and/or FORECAST_START, WBS level
  Bitflag =
    1 - ETC
    2 - FORECAST_START
    3 - ETC + FORECAST_START
****************************************************************************************/
Prompt == FUNCTION SP_RJCT_ETC_WBS ==
CREATE OR REPLACE FUNCTION SP_RJCT_ETC_WBS wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
ec
2 :e:
1FUNCTION:
1SP_RJCT_ETC_WBS:
1ID001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_FINISH_DATE:
1TIMESTAMP:
1H_PROJECT_ID:
132:
1H_RANK:
1200:
1H_START_DATE:
1H_TASK_ID:
1H_TSK_ASSIGNMENT_ID:
1H_BIT_FLAG:
11:
1H_BITFLAG:
10:
1H_EFFORT:
1H_TYPE:
1H_START_D:
1DATE:
1H_TEMP_SC_STATE:
1H_TEMP_VAR:
1H_TEMP_SC_NODATA:
1H_STEPS_EXIST:
1H_SCHED_WORK:
1H_WORK_TODATE:
1H_MLST_PERCENT:
1H_TEMP_SC_STATE_ALERT:
1H_ALERT_ID:
1H_REC_USER:
1H_CALLTYPE:
1H_TABLE_TYPE:
1I_STEPS_EXIST:
1I_PERCENT_COMPLETE:
1CURSOR:
1CAWTSKR:
1ELEMENT_ID:
1SCHED_EFFORT:
1PLANNED_EFFORT:
1FORECAST_START:
1SCHED_START:
1FORECAST_FINISH:
1SCHED_FINISH:
1TMT_WBS:
1PROJECT_ID:
1RANK:
1TYPE_ID:
1PMO_CNST:
1SC_TASK:
1SC_TASK_TYPE1:
1SC_TASK_TYPE2:
1SC_TASK_TYPE3:
1SC_MILESTONE:
1SC_PERSONAL_TASK:
1SC_ACTIVE_ADM_TASK:
1SC_INACTIVE_ADM_TASK:
1SC_WBS_CHANGE_REQUEST_TASK:
1SC_WBS_ACTION_ITEM_TASK:
1SC_WBS_RISK_TASK:
1SC_WBS_ISSUE_TASK:
1SC_WBS_REQUIREMENT_TASK:
1SC_WBS_DEFECT_TASK:
1SC_WBS_SERVICE_REQUEST_TASK:
1WORK_TODATE:
1ETC:
1SELECT ELEMENT_ID, SCHED_EFFORT+PLANNED_EFFORT,:n         CASE WHEN FORECAST_+
1START IS NULL THEN SCHED_START ELSE FORECAST_START END,:n         CASE WHEN F+
1ORECAST_FINISH IS NULL THEN SCHED_FINISH ELSE FORECAST_FINISH END:n         F+
1ROM TMT_WBS:n         WHERE PROJECT_ID = h_project_id AND RANK LIKE h_rank AN+
1D TYPE_ID IN (pmo_cnst.SC_TASK,pmo_cnst.SC_TASK_TYPE1,pmo_cnst.SC_TASK_TYPE2,+
1pmo_cnst.SC_TASK_TYPE3,pmo_cnst.SC_MILESTONE,pmo_cnst.SC_PERSONAL_TASK,pmo_cn+
1st.SC_ACTIVE_ADM_TASK,pmo_cnst.SC_INACTIVE_ADM_TASK,pmo_cnst.SC_WBS_CHANGE_RE+
1QUEST_TASK,pmo_cnst.SC_WBS_ACTION_ITEM_TASK,pmo_cnst.SC_WBS_RISK_TASK,pmo_cns+
1t.SC_WBS_ISSUE_TASK,pmo_cnst.SC_WBS_REQUIREMENT_TASK,pmo_cnst.SC_WBS_DEFECT_T+
1ASK,pmo_cnst.SC_WBS_SERVICE_REQUEST_TASK):n         AND (((SCHED_EFFORT+PLANN+
1ED_EFFORT) > 0 AND ((SCHED_EFFORT+PLANNED_EFFORT-WORK_TODATE) <> ETC)):n     +
1    OR (FORECAST_START IS NOT NULL OR FORECAST_FINISH IS NOT NULL)):
1CAWASSR:
1TSK_ASSIGNMENT_ID:
1BIT_FLAG:
1BEST:
1SCHED_WORK:
1PLANNED_WORK:
1MILESTONE_PERCENT:
1TASK_ASSIGNMENTS:
1TASK_ID:
1SELECT TSK_ASSIGNMENT_ID, BIT_FLAG, BEST, SCHED_WORK+PLANNED_WORK, WORK_TODAT+
1E, MILESTONE_PERCENT:n         FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_+
1ID = h_project_id:n         AND TASK_ID = h_task_id:n         AND (((SCHED_WO+
1RK+PLANNED_WORK) > 0 AND ((SCHED_WORK+PLANNED_WORK-WORK_TODATE) <> ETC)):n   +
1      OR (FORECAST_START IS NOT NULL OR FORECAST_FINISH IS NOT NULL)):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_RJCT_ETC_WBS(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
160:
1+:
1FPUT:
1               ENTER:: SP_RJCT_ETC_WBS(61) :: cplan.sql(22900) :: :
13:
1SCETCFORCASTREJECTED:
1RTRIM:
1SELECT PROJECT_ID, RTRIM(RANK), TYPE_ID:n      INTO h_project_id, h_rank, h_t+
1ype:n      FROM TMT_WBS WHERE ELEMENT_ID = id001:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
185:
1           EXCEPTION:: SP_RJCT_ETC_WBS(86) :: cplan.sql(22925) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
1SC_SQL_SUCCESS:
1IS NOT NULL:
1%:
1-:
1START_FINISH_DATE:
1SELECT START_FINISH_DATE INTO h_start_D FROM TMT_WBS WHERE ELEMENT_ID = h_pro+
1ject_id:
1105:
1           EXCEPTION:: SP_RJCT_ETC_WBS(106) :: cplan.sql(22945) :: :
1OPEN:
1LOOP:
1FOUND:
1100:
1!=:
1EXIT:
12:
1FORECAST_DURATION:
1UPDATE TMT_WBS SET:n                  FORECAST_START = NULL,:n               +
1   FORECAST_FINISH = NULL,:n                  FORECAST_DURATION = 0:n        +
1          WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_task_id:
1TRUE:
1147:
1           EXCEPTION:: SP_RJCT_ETC_WBS(148) :: cplan.sql(22987) :: :
1FC_ISSUE_ALERT:
1CONTINUE0000:
1ACTIVITIES:
1ETC_MODIFIED:
1SC_TIMESHEET_ACTIVITY:
1UPDATE ACTIVITIES:n                        SET ETC_MODIFIED = 'N':n          +
1              WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n                +
1        AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n                        AND TYPE+
1_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY:
1198:
1           EXCEPTION:: SP_RJCT_ETC_WBS(199) :: cplan.sql(23038) :: :
1BAK_ASSIGN_STRING:
1UPDATE TASK_ASSIGNMENTS SET:n                                BAK_ASSIGN_STRIN+
1G = NULL:n                           WHERE TSK_ASSIGNMENT_ID = H_TSK_ASSIGNME+
1NT_ID:
1PROPOSED_START:
1PROPOSED_FINISH:
1PROPOSED_WORK:
1BAK_START_DT:
1BAK_FINISH_DT:
1BAK_WORK:
1ASSIGN_STRING:
1ACTUAL_FINISH:
1UPDATE TASK_ASSIGNMENTS SET:n                           PROPOSED_START      =+
1 SCHED_START,:n                           PROPOSED_FINISH     = SCHED_FINISH,+
1:n                           PROPOSED_WORK       = SCHED_WORK,:n             +
1              BAK_START_DT        = SCHED_START,:n                           +
1BAK_FINISH_DT       = SCHED_FINISH,:n                           BAK_WORK     +
1       = SCHED_WORK,:n                           BAK_ASSIGN_STRING   = ASSIGN+
1_STRING,:n                           BEST                = SCHED_WORK,:n     +
1                      ETC                 = SCHED_WORK - WORK_TODATE,:n      +
1                     ACTUAL_FINISH       = NULL:n                           W+
1HERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1233:
1           EXCEPTION:: SP_RJCT_ETC_WBS(234) :: cplan.sql(23073) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           SCHED_WORK	= SCHED_WO+
1RK,:n                           ETC			= SCHED_WORK - WORK_TODATE:n           +
1                WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1263:
1           EXCEPTION:: SP_RJCT_ETC_WBS(264) :: cplan.sql(23103) :: :
1ACTUAL_DURATION:
1UPDATE TASK_ASSIGNMENTS SET:n                        ETC					= PLANNED_WORK, +
1:n                        MILESTONE_PERCENT	= 0 ,:n                        AC+
1TUAL_FINISH		= NULL, :n                        ACTUAL_DURATION		= 0:n        +
1                WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1288:
1           EXCEPTION:: SP_RJCT_ETC_WBS(289) :: cplan.sql(23128) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                        FORECAST_START = NULL,:n+
1                        FORECAST_FINISH = NULL,:n                        FORE+
1CAST_DURATION = 0:n                        WHERE TSK_ASSIGNMENT_ID = h_tsk_as+
1signment_id:
1315:
1           EXCEPTION:: SP_RJCT_ETC_WBS(316) :: cplan.sql(23155) :: :
1UPDATE ACTIVITIES:n                           SET ETC_MODIFIED = 'N':n       +
1                    WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:n          +
1                 AND TSK_ASSIGNMENT_ID <> ELEMENT_ID:n                       +
1    AND TYPE_ID = pmo_cnst.SC_TIMESHEET_ACTIVITY:
1340:
1           EXCEPTION:: SP_RJCT_ETC_WBS(341) :: cplan.sql(23180) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           FORECAST_START = NULL+
1,:n                           FORECAST_FINISH = NULL,:n                      +
1     FORECAST_DURATION = 0,:n                           SCHED_WORK = CASE WHE+
1N PROPOSED_WORK > WORK_TODATE THEN PROPOSED_WORK ELSE SCHED_WORK END,:n      +
1                     ETC = CASE WHEN PROPOSED_WORK > WORK_TODATE THEN PROPOSE+
1D_WORK - WORK_TODATE ELSE 0 END/*,:n                           MILESTONE_PERC+
1ENT = (WORK_TODATE * 10000) / SCHED_WORK*/:n                           WHERE +
1TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1366:
1           EXCEPTION:: SP_RJCT_ETC_WBS(367) :: cplan.sql(23206) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           FORECAST_START = NULL+
1,:n                           FORECAST_FINISH = NULL,:n                      +
1     FORECAST_DURATION = 0,:n                           ETC = PLANNED_WORK, M+
1ILESTONE_PERCENT = 0:n                           WHERE TSK_ASSIGNMENT_ID = h_+
1tsk_assignment_id:
1390:
1           EXCEPTION:: SP_RJCT_ETC_WBS(391) :: cplan.sql(23230) :: :
1SC_SQL_NO_DATA:
1BITAND:
1>:
1TRUNC:
1TO_NUMBER:
1/:
1*:
110000.00:
1<:
1ROLLUP_BITS:
1PMO_STPU:
1BIT_OR:
1SC_PERCENT_COMPLETE_BIT:
1UPDATE TASK_ASSIGNMENTS SET:n                           ROLLUP_BITS = PMO_STP+
1U.BIT_OR(ROLLUP_BITS,pmo_cnst.SC_PERCENT_COMPLETE_BIT),:n                    +
1       ACTUAL_FINISH = CASE:n                           WHEN ACTUAL_FINISH IS+
1 NULL AND ETC = 0 THEN SCHED_FINISH:n                           ELSE ACTUAL_F+
1INISH:n                           END:n                           WHERE TSK_A+
1SSIGNMENT_ID = h_tsk_assignment_id:
1434:
1           EXCEPTION:: SP_RJCT_ETC_WBS(435) :: cplan.sql(23274) :: :
1UPDATE TASK_ASSIGNMENTS SET:n                           ACTUAL_FINISH = CASE +
1WHEN (ACTUAL_FINISH IS NULL) AND ETC = 0 THEN SCHED_FINISH ELSE ACTUAL_FINISH+
1 END:n                           WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_i+
1d:
1455:
1           EXCEPTION:: SP_RJCT_ETC_WBS(456) :: cplan.sql(23295) :: :
1FC_FIX_SUMMARY_TS:
1CLOSE:
1480:
1           EXCEPTION:: SP_RJCT_ETC_WBS(481) :: cplan.sql(23320) :: :
1CONSTRAINT_TYPE:
1TO_DATE:
1CONSTRAINT_DT:
1UPDATE TMT_WBS SET:n            CONSTRAINT_TYPE =:n            CASE:n        +
1    WHEN TO_DATE(SubStr(SCHED_START, 1, 10)) <> TO_DATE(SubStr(h_start_D, 1, +
110)) THEN 6:n            ELSE 0:n            END,:n            CONSTRAINT_DT +
1=:n            CASE:n            WHEN TO_DATE(SubStr(SCHED_START, 1, 10)) <> +
1TO_DATE(SubStr(h_start_D, 1, 10)) THEN SCHED_START:n            ELSE NULL:n  +
1          END:n            WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h+
1_task_id:
1512:
1           EXCEPTION:: SP_RJCT_ETC_WBS(513) :: cplan.sql(23352) :: :
1531:
1           EXCEPTION:: SP_RJCT_ETC_WBS(532) :: cplan.sql(23371) :: :
1FC_ROLLUP:
14:
1543:
1       RETURN_STATUS:: SP_RJCT_ETC_WBS(544) :: cplan.sql(23383) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1550:
1           EXCEPTION:: SP_RJCT_ETC_WBS(551) :: cplan.sql(23390) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1562:
1           EXCEPTION:: SP_RJCT_ETC_WBS(563) :: cplan.sql(23402) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
b49
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 81 b0 a0 f4 b4
bf c8 :35 a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :14 a0 12a
bd b7 11 a4 b1 a3 :2 a0 6b
1c 81 b0 :2 a0 6b :2 a0 6b 6e
a5 b a 10 :2 a0 6b 6e :2 a0
6b 6e a5 b 6e 7e a0 b4
2e 6e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :3 a0 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
d :2 a0 d a0 51 d a0 6e
d :a a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b a0 7e a0
6b b4 2e 5a a0 7e b4 2e
:2 5a a 10 :3 a0 7e 6e b4 2e
:2 51 a5 b d a0 7e 51 b4
2e d :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 e9 dd b3
:6 a0 e9 d3 5 :2 a0 f :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 2b b7 19 3c
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 51 a5 b 7e 51 b4 2e
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 51 d :8 a0 51 a5 b a5
b d b7 a0 3b b7 :2 19 3c
b7 :2 a0 e9 dd b3 :8 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c a0 51 d
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 :2 51 a5 b 7e 6e b4 2e
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b :2 7e 51 b4 2e
b4 2e :4 a0 12a :17 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 :8 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
b7 :8 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c b7 :2 a0 51 a5
b 7e 51 b4 2e :6 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 a0 :2 51
a5 b 7e 6e b4 2e :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :10 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :9 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c b7 :2 19 3c b7 :2 19 3c
:2 a0 6b a0 7e a0 6b b4 2e
5a a0 51 d b7 19 3c a0
51 d :8 a0 51 a5 b a5 b
d :2 a0 51 a5 b 7e 51 b4
2e :3 a0 51 a5 b 51 a5 b
5a 7e 51 b4 2e 5a :2 a0 51
a5 b 7e 51 b4 2e 5a a
10 :5 a0 a5 b 51 a5 b 7e
:3 a0 a5 b 51 a5 b b4 2e
5a 7e 51 b4 2e 5a 7e :2 a0
51 a5 b b4 2e a5 b d
a0 7e 51 b4 2e 5a a0 :2 7e
51 b4 2e b4 2e 52 10 :e a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :2 19 3c :5 a0 a5 b d b7
19 3c b7 19 3c b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :14 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f 93 4f
b0 46 b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b :2 7e 51 b4 2e
b4 2e :3 a0 a5 b d b7 19
3c b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
b49
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 82 71
75 7d 70 9f 8d 6d 91 92
9a 8c bc aa 89 ae af b7
a9 d8 c7 cb d3 a6 f4 df
e3 e6 e7 ef c6 111 ff c3
103 104 10c fe 12e 11c fb 120
121 129 11b 14a 139 13d 118 145
138 166 155 159 135 161 154 182
171 175 151 17d 170 19e 18d 191
199 16d 1b9 1a5 1a9 1b1 1b4 18c
1d5 1c4 1c8 189 1d0 1c3 1f1 1e0
1e4 1c0 1ec 1df 20d 1fc 200 1dc
208 1fb 229 218 21c 1f8 224 217
245 234 238 214 240 233 261 250
254 230 25c 24f 27d 26c 270 24c
278 26b 29a 288 268 28c 28d 295
287 2b7 2a5 284 2a9 2aa 2b2 2a4
2d3 2c2 2c6 2a1 2ce 2c1 2ef 2de
2e2 2be 2ea 2dd 30b 2fa 2fe 2da
306 2f9 327 316 31a 322 2f6 312
32e 33f 340 343 347 34b 34f 353
357 35b 35f 363 367 36b 36f 373
377 37b 37f 383 387 38b 38f 393
397 39b 39f 3a3 3a7 3ab 3af 3b3
3b7 3bb 3bf 3c3 3c7 3cb 3cf 3d3
3d7 3db 3df 3e3 3e7 3eb 3ef 3f3
3f7 3fb 3ff 403 407 40b 40f 413
417 41b 427 42c 42e 43a 43e 440
444 455 456 459 45d 461 465 469
46d 471 475 479 47d 481 485 489
48d 491 495 499 49d 4a1 4a5 4a9
4ad 4b9 4be 4c0 4cc 4d0 4ee 4d6
4da 4de 4e1 4e9 4d5 4f5 4f9 4d2
4fd 501 505 508 50d 50e 1 510
515 519 51d 520 525 529 52d 530
535 536 538 53d 540 544 545 54a
54f 552 557 558 55d 560 564 565
56a 56d 572 573 578 57b 580 581
586 589 58d 591 595 596 598 59d
59e 5a0 5a1 5a6 5a9 5ae 5af 5b4
5b7 5bc 5bd 5c2 5c5 5c9 5ca 5cf
5d2 5d7 5d8 5dd 5e0 5e5 5e6 5eb
5ec 5f1 5f3 5f7 5fa 5fe 602 605
609 60d 610 613 618 61b 61e 621
622 627 628 1 62a 62f 633 637
63a 63f 644 647 64b 64c 651 652
657 659 65d 660 664 668 66c 670
674 678 67c 67f 683 687 68c 690
694 698 69c 6a0 6a4 6a8 6ac 6b0
6b4 6b8 6c4 6c8 6cc 6cf 6d3 6d7
6d9 6dd 6e1 6e5 6e8 6ec 6f0 6f2
6f3 6f8 1 6fc 700 704 707 70b
70f 713 717 71a 71e 722 725 728
72d 730 733 736 737 73c 73d 1
73f 744 748 74c 74f 754 759 75c
760 761 766 769 76e 76f 774 777
77c 77d 782 785 789 78a 78f 792
797 798 79d 7a0 7a4 7a8 7ab 7ae
7af 7b1 7b2 7b7 7b8 7bd 7bf 7c3
7c6 7c8 7cc 7ce 7da 7dc 7de 7df
7e4 7e8 7ea 7f6 7f8 7fc 800 803
807 80a 80e 811 812 817 81a 81e
821 822 827 82a 1 82d 832 836
83a 83e 841 846 847 84c 84f 852
853 855 859 85d 860 863 864 869
86d 871 875 879 87d 881 88d 891
895 898 89c 8a0 8a2 8a6 8aa 8ae
8b1 8b5 8b9 8bb 8bc 8c1 1 8c5
8c9 8cd 8d0 8d4 8d8 8dc 8e0 8e3
8e7 8eb 8ee 8f1 8f6 8f9 8fc 8ff
900 905 906 1 908 90d 911 915
918 91d 922 925 929 92a 92f 932
937 938 93d 940 945 946 94b 94e
952 953 958 95b 960 961 966 969
96d 971 974 977 978 97a 97b 980
981 986 988 98c 98f 991 995 997
9a3 9a5 9a7 9a8 9ad 9b1 9b3 9bf
9c1 9c5 9c9 9ce 9d2 9d3 9d7 9db
9df 9e3 9e7 9eb 9f0 9f5 9f9 9fd
a01 a06 a0a a0e a11 a14 a18 a1a
a1e a22 a25 a28 a2c a2e a32 a36
a39 a3d a41 a44 a48 a4b a4f a52
a53 a58 a5b a5f a65 a67 a6b a6e
a72 a76 a79 a7a a7c a7f a82 a83
a88 a8c a90 a93 a94 a96 a99 a9c
a9d aa2 aa6 aaa aae ab2 ab6 aba
abe ac2 ace ad2 ad7 adb ade adf
ae4 ae8 aec aef af2 af6 af8 afc
b00 b03 b06 b0a b0c b10 b14 b17
b19 b1d b21 b25 b28 b2c b30 b32
b33 b38 1 b3c b40 b44 b47 b4b
b4f b53 b57 b5a b5e b62 b65 b68
b6d b70 b73 b76 b77 b7c b7d 1
b7f b84 b88 b8c b8f b94 b99 b9c
ba0 ba1 ba6 ba9 bae baf bb4 bb7
bbc bbd bc2 bc5 bc9 bca bcf bd2
bd7 bd8 bdd be0 be4 be8 beb bee
bef bf1 bf2 bf7 bf8 bfd bff c03
c06 c08 c0c c0e c1a c1c c1e c1f
c24 c28 c2a c36 c38 c3c c3f c43
c47 c4b c4f c53 c57 c5b c5f c63
c66 c67 c69 c6a c6c c70 c72 c76
c7c c7e c82 c86 c89 c8b c8f c93
c98 c9c c9d ca1 ca5 ca9 cad cb1
cb5 cb9 cbd cc2 cc7 ccb ccf cd3
cd8 cdc ce0 ce3 ce6 cea cec cf0
cf4 cf7 cfa cfe d00 d04 d08 d0b
d0f d13 d16 d1a d1d d21 d24 d25
d2a d2d d31 d37 d39 d3d d40 d44
d47 d4b d4f d53 d56 d57 d59 d5c
d5f d60 d65 d69 d6d d70 d73 d74
d76 d79 d7e d7f d84 d88 d8c d90
d94 d98 d9c da0 da4 da8 db4 db8
dbd dc1 dc4 dc5 dca dce dd2 dd5
dd8 ddc dde de2 de6 de9 dec df0
df2 df6 dfa dfd dff e03 e07 e0b
e0e e12 e16 e18 e19 e1e 1 e22
e26 e2a e2d e31 e35 e39 e3d e40
e44 e48 e4b e4e e53 e56 e59 e5c
e5d e62 e63 1 e65 e6a e6e e72
e75 e7a e7f e82 e86 e87 e8c e8f
e94 e95 e9a e9d ea2 ea3 ea8 eab
eaf eb0 eb5 eb8 ebd ebe ec3 ec6
eca ece ed1 ed4 ed5 ed7 ed8 edd
ede ee3 ee5 ee9 eec eee ef2 ef4
f00 f02 f04 f05 f0a f0e f10 f1c
f1e f22 f26 f29 f2a f2c f2f f32
f35 f36 f3b f3c f41 f45 f49 f4d
f51 f5d f61 f65 f69 f6d f71 f75
f79 f7d f81 f85 f89 f8d f91 f95
f99 f9d fa1 fa5 fa9 fad fb1 fb5
fb9 fc5 fc9 fce fd2 fd5 fd6 fdb
fdf fe3 fe6 fe9 fed fef ff3 ff7
ffa ffd 1001 1003 1007 100b 100e 1010
1014 1018 101c 101f 1023 1027 1029 102a
102f 1 1033 1037 103b 103e 1042 1046
104a 104e 1051 1055 1059 105c 105f 1064
1067 106a 106d 106e 1073 1074 1 1076
107b 107f 1083 1086 108b 1090 1093 1097
1098 109d 10a0 10a5 10a6 10ab 10ae 10b3
10b4 10b9 10bc 10c0 10c1 10c6 10c9 10ce
10cf 10d4 10d7 10db 10df 10e2 10e5 10e6
10e8 10e9 10ee 10ef 10f4 10f6 10fa 10fd
10ff 1103 1105 1111 1113 1115 1116 111b
111f 1121 112d 112f 1131 1135 1139 113d
1141 1145 1149 114d 1151 115d 1161 1166
116a 116d 116e 1173 1177 117b 117e 1181
1185 1187 118b 118f 1192 1195 1199 119b
119f 11a3 11a6 11a8 11ac 11b0 11b4 11b7
11bb 11bf 11c1 11c2 11c7 1 11cb 11cf
11d3 11d6 11da 11de 11e2 11e6 11e9 11ed
11f1 11f4 11f7 11fc 11ff 1202 1205 1206
120b 120c 1 120e 1213 1217 121b 121e
1223 1228 122b 122f 1230 1235 1238 123d
123e 1243 1246 124b 124c 1251 1254 1258
1259 125e 1261 1266 1267 126c 126f 1273
1277 127a 127d 127e 1280 1281 1286 1287
128c 128e 1292 1295 1297 129b 129d 12a9
12ab 12ad 12ae 12b3 12b7 12b9 12c5 12c7
12c9 12cd 12d1 12d4 12d6 12da 12de 12e2
12e6 12ea 12ee 12f2 12f6 1302 1306 130b
130f 1312 1313 1318 131c 1320 1323 1326
132a 132c 1330 1334 1337 133a 133e 1340
1344 1348 134b 134d 1351 1355 1359 135c
1360 1364 1366 1367 136c 1 1370 1374
1378 137b 137f 1383 1387 138b 138e 1392
1396 1399 139c 13a1 13a4 13a7 13aa 13ab
13b0 13b1 1 13b3 13b8 13bc 13c0 13c3
13c8 13cd 13d0 13d4 13d5 13da 13dd 13e2
13e3 13e8 13eb 13f0 13f1 13f6 13f9 13fd
13fe 1403 1406 140b 140c 1411 1414 1418
141c 141f 1422 1423 1425 1426 142b 142c
1431 1433 1437 143a 143c 1440 1442 144e
1450 1452 1453 1458 145c 145e 146a 146c
146e 1472 1476 1479 147b 147f 1483 1486
1487 1489 148c 148f 1490 1495 1499 149d
14a1 14a5 14a9 14ad 14b9 14bd 14c2 14c6
14c9 14ca 14cf 14d3 14d7 14da 14dd 14e1
14e3 14e7 14eb 14ee 14f1 14f5 14f7 14fb
14ff 1502 1504 1508 150c 1510 1513 1517
151b 151d 151e 1523 1 1527 152b 152f
1532 1536 153a 153e 1542 1545 1549 154d
1550 1553 1558 155b 155e 1561 1562 1567
1568 1 156a 156f 1573 1577 157a 157f
1584 1587 158b 158c 1591 1594 1599 159a
159f 15a2 15a7 15a8 15ad 15b0 15b4 15b5
15ba 15bd 15c2 15c3 15c8 15cb 15cf 15d3
15d6 15d9 15da 15dc 15dd 15e2 15e3 15e8
15ea 15ee 15f1 15f3 15f7 15f9 1605 1607
1609 160a 160f 1613 1615 1621 1623 1625
1629 162d 1630 1633 1634 1636 1639 163e
163f 1644 1648 164c 1650 1654 1658 165c
1660 1664 1668 1674 1678 167d 1681 1684
1685 168a 168e 1692 1695 1698 169c 169e
16a2 16a6 16a9 16ac 16b0 16b2 16b6 16ba
16bd 16bf 16c3 16c7 16cb 16ce 16d2 16d6
16d8 16d9 16de 1 16e2 16e6 16ea 16ed
16f1 16f5 16f9 16fd 1700 1704 1708 170b
170e 1713 1716 1719 171c 171d 1722 1723
1 1725 172a 172e 1732 1735 173a 173f
1742 1746 1747 174c 174f 1754 1755 175a
175d 1762 1763 1768 176b 176f 1770 1775
1778 177d 177e 1783 1786 178a 178e 1791
1794 1795 1797 1798 179d 179e 17a3 17a5
17a9 17ac 17ae 17b2 17b4 17c0 17c2 17c4
17c5 17ca 17ce 17d0 17dc 17de 17e2 17e6
17ea 17ee 17f2 17f6 17fa 17fe 1802 1806
180a 180e 1812 1816 181a 181e 182a 182e
1833 1837 183a 183b 1840 1844 1848 184b
184e 1852 1854 1858 185c 185f 1862 1866
1868 186c 1870 1873 1875 1879 187d 1881
1884 1888 188c 188e 188f 1894 1 1898
189c 18a0 18a3 18a7 18ab 18af 18b3 18b6
18ba 18be 18c1 18c4 18c9 18cc 18cf 18d2
18d3 18d8 18d9 1 18db 18e0 18e4 18e8
18eb 18f0 18f5 18f8 18fc 18fd 1902 1905
190a 190b 1910 1913 1918 1919 191e 1921
1925 1926 192b 192e 1933 1934 1939 193c
1940 1944 1947 194a 194b 194d 194e 1953
1954 1959 195b 195f 1962 1964 1968 196a
1976 1978 197a 197b 1980 1984 1986 1992
1994 1996 199a 199e 19a2 19a6 19aa 19ae
19b2 19b6 19ba 19c6 19ca 19cf 19d3 19d6
19d7 19dc 19e0 19e4 19e7 19ea 19ee 19f0
19f4 19f8 19fb 19fe 1a02 1a04 1a08 1a0c
1a0f 1a11 1a15 1a19 1a1d 1a20 1a24 1a28
1a2a 1a2b 1a30 1 1a34 1a38 1a3c 1a3f
1a43 1a47 1a4b 1a4f 1a52 1a56 1a5a 1a5d
1a60 1a65 1a68 1a6b 1a6e 1a6f 1a74 1a75
1 1a77 1a7c 1a80 1a84 1a87 1a8c 1a91
1a94 1a98 1a99 1a9e 1aa1 1aa6 1aa7 1aac
1aaf 1ab4 1ab5 1aba 1abd 1ac1 1ac2 1ac7
1aca 1acf 1ad0 1ad5 1ad8 1adc 1ae0 1ae3
1ae6 1ae7 1ae9 1aea 1aef 1af0 1af5 1af7
1afb 1afe 1b00 1b04 1b06 1b12 1b14 1b16
1b17 1b1c 1b20 1b22 1b2e 1b30 1b32 1b36
1b3a 1b3d 1b3f 1b43 1b47 1b4a 1b4c 1b50
1b54 1b57 1b5b 1b5f 1b62 1b66 1b69 1b6d
1b70 1b71 1b76 1b79 1b7d 1b80 1b84 1b86
1b8a 1b8d 1b91 1b94 1b98 1b9c 1ba0 1ba4
1ba8 1bac 1bb0 1bb4 1bb8 1bbb 1bbc 1bbe
1bbf 1bc1 1bc5 1bc9 1bcd 1bd0 1bd1 1bd3
1bd6 1bd9 1bda 1bdf 1be3 1be7 1beb 1bee
1bef 1bf1 1bf4 1bf5 1bf7 1bfa 1bfd 1c00
1c01 1c06 1c09 1c0d 1c11 1c14 1c15 1c17
1c1a 1c1d 1c1e 1c23 1 1c26 1c2b 1c2f
1c33 1c37 1c3b 1c3f 1c40 1c42 1c45 1c46
1c48 1c4b 1c4f 1c53 1c57 1c58 1c5a 1c5d
1c5e 1c60 1c61 1c66 1c69 1c6c 1c6f 1c70
1c75 1c78 1c7b 1c7f 1c83 1c86 1c87 1c89
1c8a 1c8f 1c90 1c92 1c96 1c9a 1c9d 1ca0
1ca1 1ca6 1ca9 1cad 1cb0 1cb3 1cb6 1cb7
1cbc 1cbd 1 1cc2 1cc7 1ccb 1ccf 1cd3
1cd7 1cdb 1cdf 1ce3 1ce7 1ceb 1cef 1cf3
1cf7 1cfb 1cff 1d0b 1d0f 1d14 1d18 1d1b
1d1c 1d21 1d25 1d29 1d2c 1d2f 1d33 1d35
1d39 1d3d 1d40 1d43 1d47 1d49 1d4d 1d51
1d54 1d56 1d5a 1d5e 1d62 1d65 1d69 1d6d
1d6f 1d70 1d75 1 1d79 1d7d 1d81 1d84
1d88 1d8c 1d90 1d94 1d97 1d9b 1d9f 1da2
1da5 1daa 1dad 1db0 1db3 1db4 1db9 1dba
1 1dbc 1dc1 1dc5 1dc9 1dcc 1dd1 1dd6
1dd9 1ddd 1dde 1de3 1de6 1deb 1dec 1df1
1df4 1df9 1dfa 1dff 1e02 1e06 1e07 1e0c
1e0f 1e14 1e15 1e1a 1e1d 1e21 1e25 1e28
1e2b 1e2c 1e2e 1e2f 1e34 1e35 1e3a 1e3c
1e40 1e43 1e45 1e49 1e4b 1e57 1e59 1e5b
1e5c 1e61 1e65 1e67 1e73 1e75 1e77 1e7b
1e7f 1e83 1e87 1e8b 1e8f 1e93 1e97 1ea3
1ea7 1eac 1eb0 1eb3 1eb4 1eb9 1ebd 1ec1
1ec4 1ec7 1ecb 1ecd 1ed1 1ed5 1ed8 1edb
1edf 1ee1 1ee5 1ee9 1eec 1eee 1ef2 1ef6
1efa 1efd 1f01 1f05 1f07 1f08 1f0d 1
1f11 1f15 1f19 1f1c 1f20 1f24 1f28 1f2c
1f2f 1f33 1f37 1f3a 1f3d 1f42 1f45 1f48
1f4b 1f4c 1f51 1f52 1 1f54 1f59 1f5d
1f61 1f64 1f69 1f6e 1f71 1f75 1f76 1f7b
1f7e 1f83 1f84 1f89 1f8c 1f91 1f92 1f97
1f9a 1f9e 1f9f 1fa4 1fa7 1fac 1fad 1fb2
1fb5 1fb9 1fbd 1fc0 1fc3 1fc4 1fc6 1fc7
1fcc 1fcd 1fd2 1fd4 1fd8 1fdb 1fdd 1fe1
1fe3 1fef 1ff1 1ff3 1ff4 1ff9 1ffd 1fff
200b 200d 200f 2013 2017 201a 201e 2022
2026 202a 202e 202f 2031 2035 2037 203b
203e 2040 2044 2047 2049 204d 2054 2058
205c 2061 2063 2067 206b 206e 2072 2076
2078 207c 2080 2084 2087 208b 208f 2091
2092 2097 1 209b 209f 20a3 20a6 20aa
20ae 20b2 20b6 20b9 20bd 20c1 20c4 20c7
20cc 20cf 20d2 20d5 20d6 20db 20dc 1
20de 20e3 20e7 20eb 20ee 20f3 20f8 20fb
20ff 2100 2105 2108 210d 210e 2113 2116
211b 211c 2121 2124 2128 2129 212e 2131
2136 2137 213c 213f 2143 2147 214a 214d
214e 2150 2151 2156 2157 215c 215e 2162
2165 2167 216b 216d 2179 217b 217d 217e
2183 2187 2189 2195 2197 2199 219d 21a1
21a4 21a8 21ac 21b0 21b4 21b8 21bc 21c0
21c4 21c8 21cc 21d0 21d4 21d8 21dc 21e0
21e4 21e8 21ec 21f0 21f4 2200 2204 2209
220d 2210 2211 2216 221a 221e 2221 2224
2228 222a 222e 2232 2235 2238 223c 223e
2242 2246 2249 224b 224f 2253 2257 225a
225e 2262 2264 2265 226a 1 226e 2272
2276 2279 227d 2281 2285 2289 228c 2290
2294 2297 229a 229f 22a2 22a5 22a8 22a9
22ae 22af 1 22b1 22b6 22ba 22be 22c1
22c6 22cb 22ce 22d2 22d3 22d8 22db 22e0
22e1 22e6 22e9 22ee 22ef 22f4 22f7 22fb
22fc 2301 2304 2309 230a 230f 2312 2316
231a 231d 2320 2321 2323 2324 2329 232a
232f 2331 2335 2338 233a 233e 2340 234c
234e 2350 2351 2356 235a 235c 2368 236a
2372 2374 2375 2378 237a 237e 2385 2389
238d 2392 2394 2398 239c 239f 23a3 23a7
23a9 23ad 23b1 23b5 23b8 23bc 23c0 23c2
23c3 23c8 1 23cc 23d0 23d4 23d7 23db
23df 23e3 23e7 23ea 23ee 23f2 23f5 23f8
23fd 2400 2403 2406 2407 240c 240d 1
240f 2414 2418 241c 241f 2424 2429 242c
2430 2431 2436 2439 243e 243f 2444 2447
244c 244d 2452 2455 2459 245a 245f 2462
2467 2468 246d 2470 2474 2478 247b 247e
247f 2481 2482 2487 2488 248d 248f 2493
2496 2498 249c 249e 24aa 24ac 24ae 24af
24b4 24b8 24ba 24c6 24c8 24cc 24d0 24d3
24d4 24d6 24d9 24dc 24df 24e0 24e5 24e6
24eb 24ef 24f3 24f7 24f8 24fa 24fe 2500
2504 2507 2509 250d 2510 2514 2518 251b
251f 2523 2526 2529 252e 2531 2534 2537
2538 253d 253e 1 2540 2545 2549 254d
2550 2555 255a 255d 2561 2562 2567 256a
256f 2570 2575 2578 257d 257e 2583 2586
258a 258e 2592 2596 2599 259a 259c 25a1
25a2 25a4 25a5 25aa 25ad 25b2 25b3 25b8
25bb 25c0 25c1 25c6 25c9 25cd 25ce 25d3
25d6 25db 25dc 25e1 25e2 25e7 25e9 25ed
25f0 25f4 25f8 25fb 25ff 2603 2606 260a
260e 260f 2614 2616 261a 261e 2621 2625
2629 262c 2630 2634 2637 263a 263f 2642
2645 2648 2649 264e 264f 1 2651 2656
265a 265e 2661 2666 266b 266e 2672 2673
2678 2679 267e 2682 2686 2689 268e 2693
2696 269a 269e 26a1 26a2 26a7 26aa 26af
26b0 26b5 26b8 26bc 26c0 26c3 26c4 26c9
26ca 26cf 26d1 26d5 26d8 26dc 26e0 26e4
26e8 26ec 26f0 26f4 26f8 26fc 2708 270d
2711 2715 2719 271d 271f 2720 2725 1
2729 272d 2731 2734 2738 273c 2740 2744
2747 274b 274f 2752 2755 275a 275d 2760
2763 2764 2769 276a 1 276c 2771 2775
2779 277c 2781 2786 2789 278d 278e 2793
2794 2799 279d 27a1 27a4 27a9 27ae 27b1
27b5 27b6 27bb 27be 27c3 27c4 27c9 27cc
27d0 27d4 27d7 27da 27db 27dd 27de 27e3
27e4 27e9 27eb 27ef 27f2 27f6 27fa 27fe
2802 2806 280a 280e 281a 281f 2823 2827
282b 282f 2831 2835 2837 2843 2845 2847
2848 284d 2851 2853 285f 2863 2865 2866
286f 
b49
2
0 1 a 6 c :3 6 11 :3 6
12 :2 6 1 3 a 13 a :2 1
4 :3 12 :2 4 11 1a 19 :2 11 :2 4
b 14 13 :2 b :2 4 :3 11 :2 4 e
17 16 :2 e :2 4 18 21 20 :2 18
:2 4 f 18 17 :2 f :2 4 :2 e 1d
e :2 4 :2 d 1c d :2 4 :2 b 1a
b :2 4 :3 e :2 4 :2 14 23 14 :2 4
:2 f 1e f :2 4 :2 15 24 15 :2 4
:2 12 21 12 :2 4 :2 11 20 11 :2 4
:2 12 21 12 :2 4 :2 13 22 13 :2 4
:2 1a 29 1a :2 4 f 18 17 :2 f
:2 4 f 18 17 :2 f :2 4 :2 f 1e
f :2 4 :2 11 20 11 :2 4 :2 12 2a
12 :2 4 :3 17 4 7 e 0 :2 7
11 1d 2a 14 30 41 14 31
43 f 10 1d 2e 38 43 4f
58 60 69 77 80 8e 97 a5
ae bb c4 d5 de f1 fa 10f
118 133 13c 154 15d 16e 177 189
192 1aa 1b3 1c6 1cf 11 1e 38
45 54 64 e 2c a :6 7 e
0 :2 7 11 24 2e 34 3f 4d
5a f 10 1d e 18 11 1c
34 3f 4c 5c e 2c a :5 7
4 e 17 :3 e 4 7 :2 11 23
:2 2d 3a :2 23 :3 7 :2 d 19 25 :2 2f
43 :2 25 57 5d 60 :2 57 6e 87
8 :2 6e d 10 :2 6e 16 19 :2 6e
b e :2 6e 13 16 1f 27 :2 1f
34 :2 16 :2 6e b e :2 6e 13 16
:2 6e 1b 1e :2 6e 2a 2d :2 6e 32
35 :2 6e :2 7 4d :2 4 7 :2 11 23
:2 2d 39 3c 4f 51 52 :2 4f :2 23
:3 7 :2 d 12 1e 60 63 :2 1e :2 7
55 :3 4 11 :2 4 12 :2 4 12 :2 4
12 4 e 1a 20 27 c 1a
22 c 1a 27 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 56 58 59 :2 56 :2 29
:3 d :2 13 18 24 66 69 :2 24 76
79 :2 24 7d 80 :2 24 8c 8f :2 24
97 9a :2 24 a6 a9 b0 b9 bc
:2 a9 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 :4 3b 3a 39 :3 7 11 18 1f
22 :2 18 27 2a :2 11 :2 7 13 14
:2 13 7 11 28 37 45 52 :2 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 59 5c
5d :2 59 :2 2c :3 10 :2 16 1b 27 6a
6d :2 27 7a 7d :2 27 81 84 :2 27
90 93 :2 27 9b 9e :2 27 aa ad
b4 bd c0 :2 ad :2 27 :2 10 60 :2 d
:2 a :4 16 :2 a 7 :3 50 7 c :4 7
10 1d 28 32 40 :3 a d 15
:2 d :2 16 22 d 1b d :2 16 22
d :4 a e :2 17 23 20 :2 2c :2 20
:3 d 3c :2 a d 16 20 :2 d 23
25 :2 23 10 19 24 :2 10 27 29
:2 27 1a :3 13 19 26 37 44 13
1a 16 22 :3 20 16 :2 1f 2b 16
27 16 :2 1f 2b 16 :4 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 62 65 66 :2 62 :2 35 :3 19 :2 1f
24 30 73 76 :2 30 83 86 :2 30
8a 8d :2 30 99 9c :2 30 a4 a7
:2 30 b3 b6 bd c6 c9 :2 b6 :2 30
:2 19 69 :2 16 :2 13 :4 1f :2 13 10 :3 2b
10 20 :2 10 29 38 44 4f 5b
67 29 37 :2 67 :2 29 10 2b 15
10 :4 d 27 d 12 :4 d 16 23
38 44 50 5e 6d :3 10 13 1b
:2 13 :2 1c 28 13 21 13 :2 1c 28
13 :4 10 14 :2 1d 29 26 :2 32 :2 26
:3 13 42 :3 10 24 10 13 1c 27
:2 13 2a 2c :2 2a 16 1d 29 2c
:2 16 2f 31 :2 2f 20 1d 1f 33
1d 32 1d 27 30 19 20 1c
28 :3 26 1c :2 25 31 1c 2d 1c
:2 25 31 1c :4 19 16 1e 1c :2 25
31 1c 2c :2 19 :2 1e 1c :2 25 31
1c 1f :2 29 3b :2 45 51 55 68
6b 6c :2 68 :2 3b :3 1f :2 25 2a 36
79 7c :2 36 89 8c :2 36 90 93
:2 36 9f a2 :2 36 aa ad :2 36 b9
bc c3 cc cf :2 bc :2 36 :2 1f 6f
:2 1c :2 19 :4 25 :2 19 16 :3 35 19 22
2e :2 19 31 33 34 :2 33 :2 31 20
21 22 36 19 23 1c 32 1c
32 1c 32 1c 32 1c 32 1c
32 1c 32 1c 32 1c 32 3f
1c 22 36 1c 23 1f 2b :3 29
1f :2 28 34 1f 30 1f :2 28 34
1f :4 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 6b 6e 6f
:2 6b :2 3e :3 22 :2 28 2d 39 7c 7f
:2 39 8c 8f :2 39 93 96 :2 39 a2
a5 :2 39 ad b0 :2 39 bc bf c6
cf d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c
:4 28 :2 1c 19 :4 36 23 1c 29 1c
24 31 22 36 1c 23 1f 2b
:3 29 1f :2 28 34 1f 30 1f :2 28
34 1f :4 1c 19 21 1f :2 28 34
1f 2f :2 1c :2 21 1f :2 28 34 1f
22 :2 2c 3e :2 48 54 58 6b 6e
6f :2 6b :2 3e :3 22 :2 28 2d 39 7c
7f :2 39 8c 8f :2 39 93 96 :2 39
a2 a5 :2 39 ad b0 :2 39 bc bf
c6 cf d2 :2 bf :2 39 :2 22 72 :2 1f
:2 1c :4 28 :2 1c 19 :7 16 35 20 19
23 :3 19 1f 33 19 20 1c 28
:3 26 1c :2 25 31 1c 2d 1c :2 25
31 1c :4 19 16 1e 1c :2 25 31
1c 2c :2 19 :2 1e 1c :2 25 31 1c
1f :2 29 3b :2 45 51 55 68 6b
6c :2 68 :2 3b :3 1f :2 25 2a 36 79
7c :2 36 89 8c :2 36 90 93 :2 36
9f a2 :2 36 aa ad :2 36 b9 bc
c3 cc cf :2 bc :2 36 :2 1f 6f :2 1c
:2 19 :4 25 :2 19 16 :7 13 2e 16 1f
2a :2 16 2d 2f :2 2d 20 :3 19 1f
33 19 20 1c 28 :3 26 1c :2 25
31 1c 2d 1c :2 25 31 1c :4 19
16 1e 1c :2 25 31 1c 2c :2 19
:2 1e 1c :2 25 31 1c 1f :2 29 3b
:2 45 51 55 68 6b 6c :2 68 :2 3b
:3 1f :2 25 2a 36 79 7c :2 36 89
8c :2 36 90 93 :2 36 9f a2 :2 36
aa ad :2 36 b9 bc c3 cc cf
:2 bc :2 36 :2 1f 6f :2 1c :2 19 :4 25 :2 19
16 :4 31 19 20 2c 2f :2 19 32
34 :2 32 23 20 22 36 20 35
20 2a 33 1c 23 1f 2b :3 29
1f :2 28 34 1f 30 1f :2 28 34
1f :4 1c 19 21 1f :2 28 34 1f
2f :2 1c :2 21 1f :2 28 34 1f 22
:2 2c 3e :2 48 54 58 6b 6e 6f
:2 6b :2 3e :3 22 :2 28 2d 39 7c 7f
:2 39 8c 8f :2 39 93 96 :2 39 a2
a5 :2 39 ad b0 :2 39 bc bf c6
cf d2 :2 bf :2 39 :2 22 72 :2 1f :2 1c
:4 28 :2 1c 19 :3 38 23 :4 1c 33 43
54 67 1c 2c 3c 4d 5d 22
36 1c 23 1f 2b :3 29 1f :2 28
34 1f 30 1f :2 28 34 1f :4 1c
19 21 1f :2 28 34 1f 2f :2 1c
:2 21 1f :2 28 34 1f 22 :2 2c 3e
:2 48 54 58 6b 6e 6f :2 6b :2 3e
:3 22 :2 28 2d 39 7c 7f :2 39 8c
8f :2 39 93 96 :2 39 a2 a5 :2 39
ad b0 :2 39 bc bf c6 cf d2
:2 bf :2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c
19 :4 38 23 :4 1c 22 30 22 36
1c 23 1f 2b :3 29 1f :2 28 34
1f 30 1f :2 28 34 1f :4 1c 19
21 1f :2 28 34 1f 2f :2 1c :2 21
1f :2 28 34 1f 22 :2 2c 3e :2 48
54 58 6b 6e 6f :2 6b :2 3e :3 22
:2 28 2d 39 7c 7f :2 39 8c 8f
:2 39 93 96 :2 39 a2 a5 :2 39 ad
b0 :2 39 bc bf c6 cf d2 :2 bf
:2 39 :2 22 72 :2 1f :2 1c :4 28 :2 1c 19
:7 16 :4 13 :4 10 14 :2 1d 28 26 :2 31
:2 26 :2 13 27 13 41 :3 10 20 :2 10
29 38 44 59 65 2b 34 42
:2 2b :2 29 10 13 1c 2e :2 13 31
33 :2 31 18 1f 28 33 :2 1f 37
:2 18 17 3b 3d :2 3b 16 45 4e
5e :2 45 61 63 :2 61 44 :3 16 2c
34 3d 47 :2 3d 57 :2 34 5a 5c
28 32 :2 28 41 :2 5c :2 34 33 45
47 :2 33 32 51 53 28 38 :2 53
:2 32 :2 2c 16 1a 2d 2f :2 2d 19
35 48 4a 4b :2 4a :2 48 :2 19 23
1c 2a 33 3a 46 4f 1c 21
3b 48 21 22 36 1c 23 1f
2b :3 29 1f :2 28 34 1f 30 1f
:2 28 34 1f :4 1c 19 21 1f :2 28
34 1f 2f :2 1c :2 21 1f :2 28 34
1f 22 :2 2c 3e :2 48 54 58 6b
6e 6f :2 6b :2 3e :3 22 :2 28 2d 39
7c 7f :2 39 8c 8f :2 39 93 96
:2 39 a2 a5 :2 39 ad b0 :2 39 bc
bf c6 cf d2 :2 bf :2 39 :2 22 72
:2 1f :2 1c :4 28 :2 1c 19 :4 4d 23 1c
37 52 5f 71 22 36 1c 23
1f 2b :3 29 1f :2 28 34 1f 30
1f :2 28 34 1f :4 1c 19 21 1f
:2 28 34 1f 2f :2 1c :2 21 1f :2 28
34 1f 22 :2 2c 3e :2 48 54 58
6b 6e 6f :2 6b :2 3e :3 22 :2 28 2d
39 7c 7f :2 39 8c 8f :2 39 93
96 :2 39 a2 a5 :2 39 ad b0 :2 39
bc bf c6 cf d2 :2 bf :2 39 :2 22
72 :2 1f :2 1c :4 28 :2 1c 19 :8 16 29
3b 49 5e :2 29 16 66 :2 13 35
:2 10 d 11 a 10 16 :3 10 :2 19
25 10 d 15 13 :2 1c 28 13
23 :2 10 :2 15 13 :2 1c 28 13 16
:2 20 32 :2 3c 48 4c 5f 62 63
:2 5f :2 32 :3 16 :2 1c 21 2d 70 73
:2 2d 80 83 :2 2d 87 8a :2 2d 96
99 :2 2d a1 a4 :2 2d b0 b3 ba
c3 c6 :2 b3 :2 2d :2 16 66 :2 13 :2 10
:4 1c :2 10 d :7 a 14 d 12 1a
21 39 41 48 d 12 1a 21
39 41 48 60 13 20 31 3e
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 5c 5f 60 :2 5c :2 2f :3 13
:2 19 1e 2a 6d 70 :2 2a 7d 80
:2 2a 84 87 :2 2a 93 96 :2 2a 9e
a1 :2 2a ad b0 b7 c0 c3 :2 b0
:2 2a :2 13 63 :2 10 :2 d :4 19 :2 d a
:3 7 c a :3 7 b 50 a 10
:3 a :2 13 1f a 7 f d :2 16
22 d 1d :2 a :2 f d :2 16 22
d 10 :2 1a 2c :2 36 42 46 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6a 6d :2 27 7a 7d :2 27 81 84
:2 27 90 93 :2 27 9b 9e :2 27 aa
ad b4 bd c0 :2 ad :2 27 :2 10 60
:2 d :2 a :4 16 :2 a 7 :3 50 a 13
1d :2 a 20 22 23 :2 22 :2 20 a
1d 27 :2 1d a 25 :2 7 50 :2 4
7 :2 11 23 :2 2d 39 3c 4f 52
53 :2 4f :2 23 :3 7 :2 d 12 1e 61
64 :2 1e 71 74 :2 1e 78 7b :2 1e
85 88 91 99 :2 a2 :2 91 ad :2 88
:2 1e b5 b8 :2 1e c0 c3 :2 1e c8
cb :2 1e d1 d4 :2 1e :2 7 56 :3 4
:2 f 21 :2 2a 34 3b :2 4 1 9
12 9 a :2 14 26 :2 30 3c 40
53 56 57 :2 53 :2 26 :3 a :2 10 15
21 64 67 :2 21 :3 a :2 10 15 39
5c 5f :2 68 :2 39 76 79 :2 39 81
84 :2 8d :2 39 :2 a 5a :3 7 c 15
1e 2c a 13 1e f e 7
e 7 e 7 29 :2 4 :2 9 7
:2 10 1c :2 7 :2 11 23 :2 2d 39 3d
50 53 54 :2 50 :2 23 :3 7 :2 d 12
1e 61 64 :2 1e :3 7 :2 d 12 36
42 45 :2 36 4d 50 :2 36 5c 5f
66 6f 72 :2 5f :2 36 :2 7 57 :2 4
7 c 1b a 13 1e f e
7 e 7 e 7 :2 4 :4 10 :2 4
:8 1 
b49
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:5 8 :7 9 :7 a :5 b
:7 c :7 d :7 e :6 f
:6 10 :6 11 :5 12 :6 13
:6 14 :6 15 :6 16 :6 17
:6 18 :6 19 :6 1a :7 1b
:7 1c :6 1d :6 1e :6 1f
:5 20 :2 22 0 :2 22
:3 23 :3 24 :3 25 26
:23 27 :6 28 :2 29 23
:5 22 :2 2b 0 :2 2b
:7 2c 2d :2 2e :2 2f
:6 30 :2 31 2c :5 2b
:7 33 :b 35 :11 36 37
:2 36 :2 37 :2 36 :2 37
:2 36 :2 38 :2 36 :9 38
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :2 36 :2 39
:2 36 :2 39 :4 36 :3 35
:11 3c :b 3d :3 3c :3 43
:3 46 :3 47 :3 48 :4 4b
:3 4c :3 4d 4b :5 4e
4a 50 :5 51 :3 50
:2 52 :5 54 :11 55 :24 56
:3 55 :2 53 :6 52 4f
:3 34 :12 5c :c 5d :6 5e
:6 61 :5 62 60 64
:5 65 :3 64 :2 66 :5 68
:11 69 :24 6a :3 69 :2 67
:6 66 63 :3 5c :5 6f
71 :8 72 :3 73 :5 74
73 :5 76 75 :3 73
:a 79 :2 7a :3 79 :9 7e
:9 80 83 84 85
86 :4 87 83 :6 88
:5 89 88 :5 8b 8a
:3 88 82 8e :5 8f
:3 8e :2 90 :5 92 :11 93
:24 94 :3 93 :2 91 :6 90
8d :3 80 :3 9a :7 9b
:2 9c :5 9b 80 :2 9e
9d :3 80 7e :5 a3
a5 :a a6 :3 a7 :5 a8
a7 :5 aa a9 :3 a7
:a ad :2 ae :3 ad :3 b2
:9 b3 :a b4 b6 b7
:2 b8 :2 b9 :3 ba b6
:6 bb :5 bc bb :5 be
bd :3 bb b5 c1
:5 c2 :3 c1 :2 c3 :5 c5
:11 c6 :24 c7 :3 c6 :2 c4
:6 c3 c0 :3 b4 :c cc
cd ce :2 cf cd
d2 :2 d3 :2 d4 :2 d5
:2 d6 :2 d7 :2 d8 :2 d9
:2 da :3 db dc :2 dd
d2 :6 de :5 df de
:5 e1 e0 :3 de d1
e4 :5 e5 :3 e4 :2 e6
:5 e8 :11 e9 :24 ea :3 e9
:2 e7 :6 e6 e3 :4 cc
f8 :2 f9 :3 fa :2 fb
f8 :6 fc :5 fd fc
:5 ff fe :3 fc f7
102 :5 103 :3 102 :2 104
:5 106 :11 107 :24 108 :3 107
:2 105 :6 104 101 :4 ee
:3 cc b4 10f :2 110
111 112 113 :2 114
10f :6 115 :5 116 115
:5 118 117 :3 115 10e
11b :5 11c :3 11b :2 11d
:5 11f :11 120 :24 121 :3 120
:2 11e :6 11d 11a :4 10d
:3 b4 b3 :9 128 12b
12c 12d 12e :2 12f
12b :6 130 :5 131 130
:5 133 132 :3 130 12a
136 :5 137 :3 136 :2 138
:5 13a :11 13b :24 13c :3 13b
:2 139 :6 138 135 :4 128
:a 142 144 145 :2 146
:2 147 :3 148 144 :6 149
:5 14a 149 :5 14c 14b
:3 149 143 14f :5 150
:3 14f :2 151 :5 153 :11 154
:24 155 :3 154 :2 152 :6 151
14e :3 142 15b 15c
15d 15e :5 15f :5 160
:2 162 15b :6 163 :5 164
163 :5 166 165 :3 163
15a 169 :5 16a :3 169
:2 16b :5 16d :11 16e :24 16f
:3 16e :2 16c :6 16b 168
:4 142 175 176 177
178 :3 179 :2 17a 175
:6 17b :5 17c 17b :5 17e
17d :3 17b 174 181
:5 182 :3 181 :2 183 :5 185
:11 186 :24 187 :3 186 :2 184
:6 183 180 :4 173 :3 142
140 :3 128 127 :3 b3
:a 18f :3 190 :3 18f :3 194
:6 195 :5 196 :3 195 :9 199
:1b 19a :c 19b :5 19c :5 19b
:2 19c :3 19b :2 19c :2 19d
:2 19c :5 19b :10 19e 1a0
:6 1a1 1a2 :3 1a3 1a4
:2 1a6 1a0 :6 1a7 :5 1a8
1a7 :5 1aa 1a9 :3 1a7
19f 1ad :5 1ae :3 1ad
:2 1af :5 1b1 :11 1b2 :24 1b3
:3 1b2 :2 1b0 :6 1af 1ac
:4 19e 1b9 :5 1ba :2 1bb
1b9 :6 1bc :5 1bd 1bc
:5 1bf 1be :3 1bc 1b8
1c2 :5 1c3 :3 1c2 :2 1c4
:5 1c6 :11 1c7 :24 1c8 :3 1c7
:2 1c5 :6 1c4 1c1 :4 1b7
:3 19e :8 1d1 :3 19a :3 199
a5 1d4 a0 :4 1d8
:5 1d9 1d7 1db :5 1dc
:3 1db :2 1dd :5 1df :11 1e0
:24 1e1 :3 1e0 :2 1de :6 1dd
1da :4 a0 :3 7e 1e9
1ea :6 1ec 1ef :7 1f1
:4 1f4 1e9 :6 1f5 :5 1f6
1f5 :5 1f8 1f7 :3 1f5
1e8 1fb :5 1fc :3 1fb
:2 1fd :5 1ff :11 200 :24 201
:3 200 :2 1fe :6 1fd 1fa
:3 71 205 206 :3 71
207 5c :4 20b :5 20c
20a 20e :5 20f :3 20e
:2 210 :5 212 :11 213 :24 214
:3 213 :2 211 :6 210 20d
:3 5c :c 219 :6 21a :3 219
:3 5c :11 21f :30 220 :3 21f
:a 222 34 :3 225 :11 226
:b 227 :17 228 :3 226 :2 22a
:3 22b :3 22c 22d 22b
22a 22b :3 22e :3 225
:2 22f :5 231 :11 232 :b 233
:18 234 :3 232 :2 236 237
:3 238 239 237 236
237 :3 23a :2 230 :6 22f
224 :7 1 
2871
4
:3 0 1 :3 0 2
:a 0 b44 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 6 :3 0
5 :7 0 9 8
:3 0 4 :3 0 7
:7 0 d c :3 0
8 :3 0 9 :3 0
a :2 0 4 11
12 0 f 13
0 b44 2 14
:2 0 e :2 0 d
c :3 0 17 :7 0
1a 18 0 b42
0 b :6 0 10
:2 0 11 4 :3 0
f 1c 1e :6 0
21 1f 0 b42
0 d :6 0 17
c3 0 15 4
:3 0 13 23 25
:6 0 28 26 0
b42 0 f :6 0
e :2 0 1b c
:3 0 2a :7 0 2d
2b 0 b42 0
11 :6 0 4 :3 0
e :2 0 19 2f
31 :6 0 34 32
0 b42 0 12
:6 0 15 :2 0 1f
4 :3 0 1d 36
38 :6 0 3b 39
0 b42 0 13
:6 0 17 :2 0 23
4 :3 0 21 3d
3f :6 0 42 40
0 b42 0 14
:6 0 17 :2 0 25
6 :3 0 44 :7 0
48 45 46 b42
0 16 :6 0 17
:2 0 27 6 :3 0
4a :7 0 4e 4b
4c b42 0 18
:6 0 2b 189 0
29 6 :3 0 50
:7 0 54 51 52
b42 0 19 :6 0
17 :2 0 2d 1b
:3 0 56 :7 0 59
57 0 b42 0
1a :6 0 6 :3 0
5b :7 0 17 :2 0
5f 5c 5d b42
0 1c :6 0 17
:2 0 2f 6 :3 0
61 :7 0 65 62
63 b42 0 1d
:6 0 17 :2 0 31
6 :3 0 67 :7 0
6b 68 69 b42
0 1e :6 0 17
:2 0 33 6 :3 0
6d :7 0 71 6e
6f b42 0 1f
:6 0 17 :2 0 35
6 :3 0 73 :7 0
77 74 75 b42
0 20 :6 0 17
:2 0 37 6 :3 0
79 :7 0 7d 7a
7b b42 0 21
:6 0 17 :2 0 39
6 :3 0 7f :7 0
83 80 81 b42
0 22 :6 0 e
:2 0 3b 6 :3 0
85 :7 0 89 86
87 b42 0 23
:6 0 e :2 0 3f
4 :3 0 3d 8b
8d :6 0 90 8e
0 b42 0 24
:6 0 17 :2 0 43
4 :3 0 41 92
94 :6 0 97 95
0 b42 0 25
:6 0 17 :2 0 45
6 :3 0 99 :7 0
9d 9a 9b b42
0 26 :6 0 17
:2 0 47 6 :3 0
9f :7 0 a3 a0
a1 b42 0 27
:6 0 4b 312 0
49 6 :3 0 a5
0 2 :5 0 a9
a6 a7 b42 0
28 :6 0 2a :3 0
6 :3 0 ab :7 0
ae ac 0 b42
0 29 :6 0 2b
:a 0 2 ea :5 0
b0 b3 0 b1
:3 0 2c :3 0 2d
:3 0 2e :3 0 2f
:3 0 30 :3 0 2f
:3 0 31 :3 0 32
:3 0 31 :3 0 33
:3 0 34 :3 0 d
:3 0 35 :3 0 f
:3 0 36 :3 0 37
:3 0 38 :3 0 37
:3 0 39 :3 0 37
:3 0 3a :3 0 37
:3 0 3b :3 0 37
:3 0 3c :3 0 37
:3 0 3d :3 0 37
:3 0 3e :3 0 37
:3 0 3f :3 0 37
:3 0 40 :3 0 37
:3 0 41 :3 0 37
:3 0 42 :3 0 37
:3 0 43 :3 0 37
:3 0 44 :3 0 37
:3 0 45 :3 0 37
:3 0 46 :3 0 2d
:3 0 2e :3 0 2d
:3 0 2e :3 0 47
:3 0 48 :3 0 2f
:3 0 31 :4 0 49
1 :8 0 eb b0
b3 ec 0 b42
4d ec ee eb
ed :6 0 ea :7 0
ec 2a :3 0 4a
:a 0 3 109 :5 0
f0 f3 0 f1
:3 0 4b :3 0 4c
:3 0 4d :3 0 4e
:3 0 4f :3 0 47
:3 0 50 :3 0 51
:3 0 34 :3 0 d
:3 0 52 :3 0 12
:3 0 4e :3 0 4f
:3 0 4e :3 0 4f
:3 0 47 :3 0 48
:3 0 2f :3 0 31
:4 0 53 1 :8 0
10a f0 f3 10b
0 b42 4f 10b
10d 10a 10c :6 0
109 :7 0 10b 115
116 0 51 9
:3 0 a :2 0 4
10f 110 0 111
:7 0 114 112 0
b42 0 54 :6 0
55 :3 0 56 :3 0
55 :3 0 57 :3 0
118 119 0 2
:4 0 53 11a 11c
117 11e 11d :2 0
58 :3 0 59 :3 0
120 121 0 5a
:4 0 55 :3 0 5b
:3 0 124 125 0
2 :4 0 55 126
128 5c :4 0 5d
:2 0 5e :3 0 57
12b 12d :3 0 5f
:4 0 5d :2 0 60
:4 0 5a 130 132
:3 0 5d :2 0 3
:3 0 5d 134 136
:3 0 5d :2 0 60
:4 0 60 138 13a
:3 0 5d :2 0 61
:4 0 63 13c 13e
:3 0 5d :2 0 62
:3 0 63 :3 0 5
:3 0 66 142 144
64 :4 0 68 141
147 6b 140 149
:3 0 5d :2 0 61
:4 0 6e 14b 14d
:3 0 5d :2 0 60
:4 0 71 14f 151
:3 0 5d :2 0 7
:3 0 74 153 155
:3 0 5d :2 0 60
:4 0 77 157 159
:3 0 5d :2 0 65
:4 0 7a 15b 15d
:3 0 7d 122 15f
:2 0 161 82 162
11f 161 0 163
84 0 aa2 55
:3 0 56 :3 0 164
165 0 55 :3 0
66 :3 0 167 168
0 15 :2 0 2
:4 0 67 :2 0 68
:2 0 15 :2 0 86
16d 16f :3 0 89
169 171 166 173
172 :2 0 58 :3 0
69 :3 0 175 176
0 5a :4 0 6a
:4 0 5d :2 0 5e
:3 0 8d 17a 17c
:3 0 90 177 17e
:2 0 180 93 181
174 180 0 182
95 0 aa2 16
:3 0 5 :3 0 183
184 0 aa2 25
:3 0 7 :3 0 186
187 0 aa2 26
:3 0 6b :2 0 189
18a 0 aa2 24
:3 0 6c :4 0 18c
18d 0 aa2 34
:3 0 6d :3 0 35
:3 0 36 :3 0 d
:3 0 f :3 0 19
:3 0 33 :3 0 2c
:3 0 3 :4 0 6e
1 :8 0 19f 9
:3 0 6f :3 0 19a
19b 0 70 :3 0
19c 19d 0 19f
97 1f2 71 :3 0
9 :3 0 6f :3 0
1a1 1a2 0 70
:3 0 1a3 1a4 0
1a6 9a 1a8 9c
1a7 1a6 :2 0 1f0
72 :3 0 9 :3 0
6f :3 0 1ab 1ac
0 70 :3 0 1ad
1ae 0 1e8 55
:3 0 56 :3 0 1b0
1b1 0 55 :3 0
66 :3 0 1b3 1b4
0 73 :2 0 2
:4 0 74 :2 0 68
:2 0 15 :2 0 9e
1b9 1bb :3 0 a1
1b5 1bd 1b2 1bf
1be :2 0 58 :3 0
69 :3 0 1c1 1c2
0 5a :4 0 75
:4 0 5d :2 0 5e
:3 0 a5 1c6 1c8
:3 0 5d :2 0 76
:4 0 a8 1ca 1cc
:3 0 5d :2 0 77
:4 0 ab 1ce 1d0
:3 0 5d :2 0 70
:3 0 ae 1d2 1d4
:3 0 5d :2 0 78
:4 0 b1 1d6 1d8
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 b4
1db 1df b8 1da
1e1 :3 0 bb 1c3
1e3 :2 0 1e5 be
1e6 1c0 1e5 0
1e7 c0 0 1e8
c2 1eb :3 0 1eb
0 1eb 1ea 1e8
1e9 :6 0 1ed 4
:3 0 c5 1ef c7
1ee 1ed :2 0 1f0
c9 :2 0 1f2 0
1f2 1f1 19f 1f0
:6 0 aa2 1 :3 0
9 :3 0 6f :3 0
1f4 1f5 0 9
:3 0 7c :2 0 7d
:3 0 1f7 1f9 0
ce 1f8 1fb :3 0
1fc :2 0 19 :3 0
7e :2 0 d1 1ff
200 :3 0 201 :2 0
202 :2 0 1fd 204
203 :2 0 f :3 0
79 :3 0 f :3 0
5d :2 0 7f :4 0
d3 209 20b :3 0
15 :2 0 10 :2 0
d6 207 20f 206
210 0 a51 18
:3 0 80 :2 0 15
:2 0 da 213 215
:3 0 212 216 0
a51 81 :3 0 1a
:3 0 33 :3 0 2c
:3 0 d :4 0 82
1 :8 0 223 9
:3 0 6f :3 0 21e
21f 0 70 :3 0
220 221 0 223
dc 276 71 :3 0
9 :3 0 6f :3 0
225 226 0 70
:3 0 227 228 0
22a df 22c e1
22b 22a :2 0 274
72 :3 0 9 :3 0
6f :3 0 22f 230
0 70 :3 0 231
232 0 26c 55
:3 0 56 :3 0 234
235 0 55 :3 0
66 :3 0 237 238
0 73 :2 0 2
:4 0 83 :2 0 68
:2 0 15 :2 0 e3
23d 23f :3 0 e6
239 241 236 243
242 :2 0 58 :3 0
69 :3 0 245 246
0 5a :4 0 84
:4 0 5d :2 0 5e
:3 0 ea 24a 24c
:3 0 5d :2 0 76
:4 0 ed 24e 250
:3 0 5d :2 0 77
:4 0 f0 252 254
:3 0 5d :2 0 70
:3 0 f3 256 258
:3 0 5d :2 0 78
:4 0 f6 25a 25c
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 f9
25f 263 fd 25e
265 :3 0 100 247
267 :2 0 269 103
26a 244 269 0
26b 105 0 26c
107 26f :3 0 26f
0 26f 26e 26c
26d :6 0 271 6
:3 0 10a 273 10c
272 271 :2 0 274
10e :2 0 276 0
276 275 223 274
:6 0 a51 1 :3 0
85 :3 0 2b :4 0
27b :2 0 a51 279
27c :3 0 86 :3 0
2b :3 0 12 :3 0
18 :3 0 11 :3 0
b :4 0 284 :2 0
9db 27e 285 :3 0
111 :3 0 2b :3 0
87 :3 0 286 287
:3 0 9 :3 0 6f
:3 0 289 28a 0
17 :2 0 28b 28c
0 28e 116 295
9 :3 0 6f :3 0
28f 290 0 88
:2 0 291 292 0
294 118 296 288
28e 0 297 0
294 0 297 11a
0 9db 9 :3 0
6f :3 0 298 299
0 9 :3 0 89
:2 0 7d :3 0 29b
29d 0 11f 29c
29f :3 0 2a0 :2 0
8a :8 0 2a4 122
2a5 2a1 2a4 0
2a6 124 0 9db
62 :3 0 18 :3 0
17 :2 0 126 2a7
2aa 7c :2 0 17
:2 0 12b 2ac 2ae
:3 0 62 :3 0 16
:3 0 17 :2 0 12e
2b0 2b3 7c :2 0
8b :2 0 133 2b5
2b7 :3 0 33 :3 0
2f :3 0 31 :3 0
8c :3 0 34 :3 0
d :3 0 2c :3 0
12 :4 0 8d 1
:8 0 2d7 87 :4 0
2c2 :3 0 8e :3 0
7c :2 0 138 2c5
2c6 :3 0 9 :3 0
6f :3 0 2c8 2c9
0 17 :2 0 2ca
2cb 0 2cd 13b
2d4 9 :3 0 6f
:3 0 2ce 2cf 0
88 :2 0 2d0 2d1
0 2d3 13d 2d5
2c7 2cd 0 2d6
0 2d3 0 2d6
13f 0 2d7 142
32a 71 :3 0 9
:3 0 6f :3 0 2d9
2da 0 70 :3 0
2db 2dc 0 2de
145 2e0 147 2df
2de :2 0 328 72
:3 0 9 :3 0 6f
:3 0 2e3 2e4 0
70 :3 0 2e5 2e6
0 320 55 :3 0
56 :3 0 2e8 2e9
0 55 :3 0 66
:3 0 2eb 2ec 0
73 :2 0 2 :4 0
8f :2 0 68 :2 0
15 :2 0 149 2f1
2f3 :3 0 14c 2ed
2f5 2ea 2f7 2f6
:2 0 58 :3 0 69
:3 0 2f9 2fa 0
5a :4 0 90 :4 0
5d :2 0 5e :3 0
150 2fe 300 :3 0
5d :2 0 76 :4 0
153 302 304 :3 0
5d :2 0 77 :4 0
156 306 308 :3 0
5d :2 0 70 :3 0
159 30a 30c :3 0
5d :2 0 78 :4 0
15c 30e 310 :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 15f 313
317 163 312 319
:3 0 166 2fb 31b
:2 0 31d 169 31e
2f8 31d 0 31f
16b 0 320 16d
323 :3 0 323 0
323 322 320 321
:6 0 325 9 :3 0
170 327 172 326
325 :2 0 328 174
:2 0 32a 0 32a
329 2d7 328 :6 0
33d 8 :3 0 27
:3 0 15 :2 0 32c
32d 0 33d 23
:3 0 91 :3 0 24
:3 0 12 :3 0 25
:3 0 26 :3 0 62
:3 0 27 :3 0 17
:2 0 177 335 338
17a 330 33a 32f
33b 0 33d 180
341 92 :3 0 33e
:4 0 340 184 342
2b8 33d 0 343
0 340 0 343
186 0 344 189
955 85 :3 0 4a
:4 0 348 :2 0 954
346 349 :3 0 86
:3 0 4a :3 0 13
:3 0 14 :3 0 1d
:3 0 20 :3 0 21
:3 0 22 :4 0 353
:2 0 8f3 34b 354
:3 0 18b :3 0 4a
:3 0 87 :3 0 355
356 :3 0 9 :3 0
6f :3 0 358 359
0 17 :2 0 35a
35b 0 35d 192
364 9 :3 0 6f
:3 0 35e 35f 0
88 :2 0 360 361
0 363 194 365
357 35d 0 366
0 363 0 366
196 0 8f3 9
:3 0 6f :3 0 367
368 0 9 :3 0
89 :2 0 7d :3 0
36a 36c 0 19b
36b 36e :3 0 36f
:2 0 8a :8 0 373
19e 374 370 373
0 375 1a0 0
8f3 1e :3 0 17
:2 0 376 377 0
8f3 62 :3 0 16
:3 0 17 :2 0 1a2
379 37c 7c :2 0
15 :2 0 1a7 37e
380 :3 0 79 :3 0
14 :3 0 15 :2 0
15 :2 0 1aa 382
386 7c :2 0 8b
:4 0 1b0 388 38a
:3 0 93 :3 0 94
:3 0 4b :3 0 13
:3 0 4b :3 0 2c
:3 0 36 :3 0 37
:3 0 95 :4 0 96
1 :8 0 3ab 87
:4 0 396 :3 0 8e
:3 0 7c :2 0 1b5
399 39a :3 0 9
:3 0 6f :3 0 39c
39d 0 17 :2 0
39e 39f 0 3a1
1b8 3a8 9 :3 0
6f :3 0 3a2 3a3
0 88 :2 0 3a4
3a5 0 3a7 1ba
3a9 39b 3a1 0
3aa 0 3a7 0
3aa 1bc 0 3ab
1bf 3fe 71 :3 0
9 :3 0 6f :3 0
3ad 3ae 0 70
:3 0 3af 3b0 0
3b2 1c2 3b4 1c4
3b3 3b2 :2 0 3fc
72 :3 0 9 :3 0
6f :3 0 3b7 3b8
0 70 :3 0 3b9
3ba 0 3f4 55
:3 0 56 :3 0 3bc
3bd 0 55 :3 0
66 :3 0 3bf 3c0
0 73 :2 0 2
:4 0 97 :2 0 68
:2 0 15 :2 0 1c6
3c5 3c7 :3 0 1c9
3c1 3c9 3be 3cb
3ca :2 0 58 :3 0
69 :3 0 3cd 3ce
0 5a :4 0 98
:4 0 5d :2 0 5e
:3 0 1cd 3d2 3d4
:3 0 5d :2 0 76
:4 0 1d0 3d6 3d8
:3 0 5d :2 0 77
:4 0 1d3 3da 3dc
:3 0 5d :2 0 70
:3 0 1d6 3de 3e0
:3 0 5d :2 0 78
:4 0 1d9 3e2 3e4
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 1dc
3e7 3eb 1e0 3e6
3ed :3 0 1e3 3cf
3ef :2 0 3f1 1e6
3f2 3cc 3f1 0
3f3 1e8 0 3f4
1ea 3f7 :3 0 3f7
0 3f7 3f6 3f4
3f5 :6 0 3f9 c
:3 0 1ed 3fb 1ef
3fa 3f9 :2 0 3fc
1f1 :2 0 3fe 0
3fe 3fd 3ab 3fc
:6 0 50b b :3 0
62 :3 0 1d :3 0
17 :2 0 1f4 400
403 7c :2 0 80
:2 0 15 :2 0 1f7
406 408 :3 0 1fb
405 40a :3 0 51
:3 0 99 :3 0 4b
:3 0 13 :4 0 9a
1 :8 0 493 51
:3 0 9b :3 0 30
:3 0 9c :3 0 32
:3 0 9d :3 0 4e
:3 0 9e :3 0 30
:3 0 9f :3 0 32
:3 0 a0 :3 0 4e
:3 0 99 :3 0 a1
:3 0 4d :3 0 4e
:3 0 48 :3 0 4e
:3 0 47 :3 0 a2
:3 0 4b :3 0 13
:4 0 a3 1 :8 0
43e 87 :4 0 429
:3 0 8e :3 0 7c
:2 0 200 42c 42d
:3 0 9 :3 0 6f
:3 0 42f 430 0
17 :2 0 431 432
0 434 203 43b
9 :3 0 6f :3 0
435 436 0 88
:2 0 437 438 0
43a 205 43c 42e
434 0 43d 0
43a 0 43d 207
0 43e 20a 491
71 :3 0 9 :3 0
6f :3 0 440 441
0 70 :3 0 442
443 0 445 20d
447 20f 446 445
:2 0 48f 72 :3 0
9 :3 0 6f :3 0
44a 44b 0 70
:3 0 44c 44d 0
487 55 :3 0 56
:3 0 44f 450 0
55 :3 0 66 :3 0
452 453 0 73
:2 0 2 :4 0 a4
:2 0 68 :2 0 15
:2 0 211 458 45a
:3 0 214 454 45c
451 45e 45d :2 0
58 :3 0 69 :3 0
460 461 0 5a
:4 0 a5 :4 0 5d
:2 0 5e :3 0 218
465 467 :3 0 5d
:2 0 76 :4 0 21b
469 46b :3 0 5d
:2 0 77 :4 0 21e
46d 46f :3 0 5d
:2 0 70 :3 0 221
471 473 :3 0 5d
:2 0 78 :4 0 224
475 477 :3 0 5d
:2 0 79 :3 0 7a
:3 0 15 :2 0 7b
:2 0 227 47a 47e
22b 479 480 :3 0
22e 462 482 :2 0
484 231 485 45f
484 0 486 233
0 487 235 48a
:3 0 48a 0 48a
489 487 488 :6 0
48c e :3 0 238
48e 23a 48d 48c
:2 0 48f 23c :2 0
491 0 491 490
43e 48f :6 0 493
b :3 0 23f 508
51 :3 0 4e :3 0
4e :3 0 48 :3 0
4e :3 0 47 :3 0
4b :3 0 13 :4 0
a6 1 :8 0 4b2
87 :4 0 49d :3 0
8e :3 0 7c :2 0
244 4a0 4a1 :3 0
9 :3 0 6f :3 0
4a3 4a4 0 17
:2 0 4a5 4a6 0
4a8 247 4af 9
:3 0 6f :3 0 4a9
4aa 0 88 :2 0
4ab 4ac 0 4ae
249 4b0 4a2 4a8
0 4b1 0 4ae
0 4b1 24b 0
4b2 24e 505 71
:3 0 9 :3 0 6f
:3 0 4b4 4b5 0
70 :3 0 4b6 4b7
0 4b9 251 4bb
253 4ba 4b9 :2 0
503 72 :3 0 9
:3 0 6f :3 0 4be
4bf 0 70 :3 0
4c0 4c1 0 4fb
55 :3 0 56 :3 0
4c3 4c4 0 55
:3 0 66 :3 0 4c6
4c7 0 73 :2 0
2 :4 0 a7 :2 0
68 :2 0 15 :2 0
255 4cc 4ce :3 0
258 4c8 4d0 4c5
4d2 4d1 :2 0 58
:3 0 69 :3 0 4d4
4d5 0 5a :4 0
a8 :4 0 5d :2 0
5e :3 0 25c 4d9
4db :3 0 5d :2 0
76 :4 0 25f 4dd
4df :3 0 5d :2 0
77 :4 0 262 4e1
4e3 :3 0 5d :2 0
70 :3 0 265 4e5
4e7 :3 0 5d :2 0
78 :4 0 268 4e9
4eb :3 0 5d :2 0
79 :3 0 7a :3 0
15 :2 0 7b :2 0
26b 4ee 4f2 26f
4ed 4f4 :3 0 272
4d6 4f6 :2 0 4f8
275 4f9 4d3 4f8
0 4fa 277 0
4fb 279 4fe :3 0
4fe 0 4fe 4fd
4fb 4fc :6 0 500
10 :3 0 27c 502
27e 501 500 :2 0
503 280 :2 0 505
0 505 504 4b2
503 :6 0 507 b
:3 0 283 509 40b
493 0 50a 0
507 0 50a 285
0 50b 288 580
51 :3 0 48 :3 0
4f :3 0 50 :3 0
a2 :3 0 a9 :3 0
4b :3 0 13 :4 0
aa 1 :8 0 52a
87 :4 0 515 :3 0
8e :3 0 7c :2 0
28d 518 519 :3 0
9 :3 0 6f :3 0
51b 51c 0 17
:2 0 51d 51e 0
520 290 527 9
:3 0 6f :3 0 521
522 0 88 :2 0
523 524 0 526
292 528 51a 520
0 529 0 526
0 529 294 0
52a 297 57d 71
:3 0 9 :3 0 6f
:3 0 52c 52d 0
70 :3 0 52e 52f
0 531 29a 533
29c 532 531 :2 0
57b 72 :3 0 9
:3 0 6f :3 0 536
537 0 70 :3 0
538 539 0 573
55 :3 0 56 :3 0
53b 53c 0 55
:3 0 66 :3 0 53e
53f 0 73 :2 0
2 :4 0 ab :2 0
68 :2 0 15 :2 0
29e 544 546 :3 0
2a1 540 548 53d
54a 549 :2 0 58
:3 0 69 :3 0 54c
54d 0 5a :4 0
ac :4 0 5d :2 0
5e :3 0 2a5 551
553 :3 0 5d :2 0
76 :4 0 2a8 555
557 :3 0 5d :2 0
77 :4 0 2ab 559
55b :3 0 5d :2 0
70 :3 0 2ae 55d
55f :3 0 5d :2 0
78 :4 0 2b1 561
563 :3 0 5d :2 0
79 :3 0 7a :3 0
15 :2 0 7b :2 0
2b4 566 56a 2b8
565 56c :3 0 2bb
54e 56e :2 0 570
2be 571 54b 570
0 572 2c0 0
573 2c2 576 :3 0
576 0 576 575
573 574 :6 0 578
12 :3 0 2c5 57a
2c7 579 578 :2 0
57b 2c9 :2 0 57d
0 57d 57c 52a
57b :6 0 57f b
:3 0 2cc 581 38b
50b 0 582 0
57f 0 582 2ce
0 583 2d1 776
62 :3 0 16 :3 0
17 :2 0 2d3 584
587 7c :2 0 8b
:2 0 2d8 589 58b
:3 0 51 :3 0 2f
:3 0 31 :3 0 8c
:3 0 4b :3 0 13
:4 0 ad 1 :8 0
5a9 87 :4 0 594
:3 0 8e :3 0 7c
:2 0 2dd 597 598
:3 0 9 :3 0 6f
:3 0 59a 59b 0
17 :2 0 59c 59d
0 59f 2e0 5a6
9 :3 0 6f :3 0
5a0 5a1 0 88
:2 0 5a2 5a3 0
5a5 2e2 5a7 599
59f 0 5a8 0
5a5 0 5a8 2e4
0 5a9 2e7 5fc
71 :3 0 9 :3 0
6f :3 0 5ab 5ac
0 70 :3 0 5ad
5ae 0 5b0 2ea
5b2 2ec 5b1 5b0
:2 0 5fa 72 :3 0
9 :3 0 6f :3 0
5b5 5b6 0 70
:3 0 5b7 5b8 0
5f2 55 :3 0 56
:3 0 5ba 5bb 0
55 :3 0 66 :3 0
5bd 5be 0 73
:2 0 2 :4 0 ae
:2 0 68 :2 0 15
:2 0 2ee 5c3 5c5
:3 0 2f1 5bf 5c7
5bc 5c9 5c8 :2 0
58 :3 0 69 :3 0
5cb 5cc 0 5a
:4 0 af :4 0 5d
:2 0 5e :3 0 2f5
5d0 5d2 :3 0 5d
:2 0 76 :4 0 2f8
5d4 5d6 :3 0 5d
:2 0 77 :4 0 2fb
5d8 5da :3 0 5d
:2 0 70 :3 0 2fe
5dc 5de :3 0 5d
:2 0 78 :4 0 301
5e0 5e2 :3 0 5d
:2 0 79 :3 0 7a
:3 0 15 :2 0 7b
:2 0 304 5e5 5e9
308 5e4 5eb :3 0
30b 5cd 5ed :2 0
5ef 30e 5f0 5ca
5ef 0 5f1 310
0 5f2 312 5f5
:3 0 5f5 0 5f5
5f4 5f2 5f3 :6 0
5f7 14 :3 0 315
5f9 317 5f8 5f7
:2 0 5fa 319 :2 0
5fc 0 5fc 5fb
5a9 5fa :6 0 5fe
b :3 0 31c 772
79 :3 0 14 :3 0
15 :2 0 15 :2 0
31e 5ff 603 7c
:2 0 8b :4 0 324
605 607 :3 0 93
:3 0 94 :3 0 4b
:3 0 13 :3 0 4b
:3 0 2c :3 0 36
:3 0 37 :3 0 95
:4 0 b0 1 :8 0
628 87 :4 0 613
:3 0 8e :3 0 7c
:2 0 329 616 617
:3 0 9 :3 0 6f
:3 0 619 61a 0
17 :2 0 61b 61c
0 61e 32c 625
9 :3 0 6f :3 0
61f 620 0 88
:2 0 621 622 0
624 32e 626 618
61e 0 627 0
624 0 627 330
0 628 333 67b
71 :3 0 9 :3 0
6f :3 0 62a 62b
0 70 :3 0 62c
62d 0 62f 336
631 338 630 62f
:2 0 679 72 :3 0
9 :3 0 6f :3 0
634 635 0 70
:3 0 636 637 0
671 55 :3 0 56
:3 0 639 63a 0
55 :3 0 66 :3 0
63c 63d 0 73
:2 0 2 :4 0 b1
:2 0 68 :2 0 15
:2 0 33a 642 644
:3 0 33d 63e 646
63b 648 647 :2 0
58 :3 0 69 :3 0
64a 64b 0 5a
:4 0 b2 :4 0 5d
:2 0 5e :3 0 341
64f 651 :3 0 5d
:2 0 76 :4 0 344
653 655 :3 0 5d
:2 0 77 :4 0 347
657 659 :3 0 5d
:2 0 70 :3 0 34a
65b 65d :3 0 5d
:2 0 78 :4 0 34d
65f 661 :3 0 5d
:2 0 79 :3 0 7a
:3 0 15 :2 0 7b
:2 0 350 664 668
354 663 66a :3 0
357 64c 66c :2 0
66e 35a 66f 649
66e 0 670 35c
0 671 35e 674
:3 0 674 0 674
673 671 672 :6 0
676 16 :3 0 361
678 363 677 676
:2 0 679 365 :2 0
67b 0 67b 67a
628 679 :6 0 6f8
b :3 0 51 :3 0
2f :3 0 31 :3 0
8c :3 0 4e :3 0
9d :3 0 47 :3 0
9d :3 0 4e :3 0
48 :3 0 9d :3 0
47 :3 0 9d :3 0
47 :3 0 4b :3 0
13 :4 0 b3 1
:8 0 6a3 87 :4 0
68e :3 0 8e :3 0
7c :2 0 36a 691
692 :3 0 9 :3 0
6f :3 0 694 695
0 17 :2 0 696
697 0 699 36d
6a0 9 :3 0 6f
:3 0 69a 69b 0
88 :2 0 69c 69d
0 69f 36f 6a1
693 699 0 6a2
0 69f 0 6a2
371 0 6a3 374
6f6 71 :3 0 9
:3 0 6f :3 0 6a5
6a6 0 70 :3 0
6a7 6a8 0 6aa
377 6ac 379 6ab
6aa :2 0 6f4 72
:3 0 9 :3 0 6f
:3 0 6af 6b0 0
70 :3 0 6b1 6b2
0 6ec 55 :3 0
56 :3 0 6b4 6b5
0 55 :3 0 66
:3 0 6b7 6b8 0
73 :2 0 2 :4 0
b4 :2 0 68 :2 0
15 :2 0 37b 6bd
6bf :3 0 37e 6b9
6c1 6b6 6c3 6c2
:2 0 58 :3 0 69
:3 0 6c5 6c6 0
5a :4 0 b5 :4 0
5d :2 0 5e :3 0
382 6ca 6cc :3 0
5d :2 0 76 :4 0
385 6ce 6d0 :3 0
5d :2 0 77 :4 0
388 6d2 6d4 :3 0
5d :2 0 70 :3 0
38b 6d6 6d8 :3 0
5d :2 0 78 :4 0
38e 6da 6dc :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 391 6df
6e3 395 6de 6e5
:3 0 398 6c7 6e7
:2 0 6e9 39b 6ea
6c4 6e9 0 6eb
39d 0 6ec 39f
6ef :3 0 6ef 0
6ef 6ee 6ec 6ed
:6 0 6f1 18 :3 0
3a2 6f3 3a4 6f2
6f1 :2 0 6f4 3a6
:2 0 6f6 0 6f6
6f5 6a3 6f4 :6 0
6f8 b :3 0 3a9
76e 51 :3 0 2f
:3 0 31 :3 0 8c
:3 0 48 :3 0 4f
:3 0 50 :3 0 4b
:3 0 13 :4 0 b6
1 :8 0 718 87
:4 0 703 :3 0 8e
:3 0 7c :2 0 3ae
706 707 :3 0 9
:3 0 6f :3 0 709
70a 0 17 :2 0
70b 70c 0 70e
3b1 715 9 :3 0
6f :3 0 70f 710
0 88 :2 0 711
712 0 714 3b3
716 708 70e 0
717 0 714 0
717 3b5 0 718
3b8 76b 71 :3 0
9 :3 0 6f :3 0
71a 71b 0 70
:3 0 71c 71d 0
71f 3bb 721 3bd
720 71f :2 0 769
72 :3 0 9 :3 0
6f :3 0 724 725
0 70 :3 0 726
727 0 761 55
:3 0 56 :3 0 729
72a 0 55 :3 0
66 :3 0 72c 72d
0 73 :2 0 2
:4 0 b7 :2 0 68
:2 0 15 :2 0 3bf
732 734 :3 0 3c2
72e 736 72b 738
737 :2 0 58 :3 0
69 :3 0 73a 73b
0 5a :4 0 b8
:4 0 5d :2 0 5e
:3 0 3c6 73f 741
:3 0 5d :2 0 76
:4 0 3c9 743 745
:3 0 5d :2 0 77
:4 0 3cc 747 749
:3 0 5d :2 0 70
:3 0 3cf 74b 74d
:3 0 5d :2 0 78
:4 0 3d2 74f 751
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 3d5
754 758 3d9 753
75a :3 0 3dc 73c
75c :2 0 75e 3df
75f 739 75e 0
760 3e1 0 761
3e3 764 :3 0 764
0 764 763 761
762 :6 0 766 1a
:3 0 3e6 768 3e8
767 766 :2 0 769
3ea :2 0 76b 0
76b 76a 718 769
:6 0 76d b :3 0
3ed 76f 608 6f8
0 770 0 76d
0 770 3ef 0
771 3f2 773 58c
5fe 0 774 0
771 0 774 3f4
0 775 3f7 777
381 583 0 778
0 775 0 778
3f9 0 8f3 9
:3 0 6f :3 0 779
77a 0 9 :3 0
7c :2 0 b9 :3 0
77c 77e 0 3fe
77d 780 :3 0 781
:2 0 1e :3 0 15
:2 0 783 784 0
786 401 787 782
786 0 788 403
0 8f3 27 :3 0
17 :2 0 789 78a
0 8f3 23 :3 0
91 :3 0 24 :3 0
13 :3 0 25 :3 0
26 :3 0 62 :3 0
27 :3 0 17 :2 0
405 792 795 408
78d 797 78c 798
0 8f3 62 :3 0
1e :3 0 17 :2 0
40e 79a 79d 7c
:2 0 17 :2 0 413
79f 7a1 :3 0 ba
:3 0 62 :3 0 16
:3 0 17 :2 0 416
7a4 7a7 15 :2 0
419 7a3 7aa 7ab
:2 0 7c :2 0 15
:2 0 41e 7ad 7af
:3 0 7b0 :2 0 62
:3 0 22 :3 0 17
:2 0 421 7b2 7b5
bb :2 0 17 :2 0
426 7b7 7b9 :3 0
7ba :2 0 7b1 7bc
7bb :2 0 29 :3 0
bc :3 0 62 :3 0
bd :3 0 21 :3 0
429 7c1 7c3 17
:2 0 42b 7c0 7c6
be :2 0 62 :3 0
bd :3 0 20 :3 0
42e 7ca 7cc 17
:2 0 430 7c9 7cf
433 7c8 7d1 :3 0
7d2 :2 0 bf :2 0
c0 :2 0 436 7d4
7d6 :3 0 7d7 :2 0
80 :2 0 62 :3 0
22 :3 0 17 :2 0
439 7da 7dd 43c
7d9 7df :3 0 43f
7bf 7e1 7be 7e2
0 8ed 29 :3 0
bb :2 0 15 :2 0
443 7e5 7e7 :3 0
7e8 :2 0 29 :3 0
c1 :2 0 80 :2 0
15 :2 0 446 7ec
7ee :3 0 44a 7eb
7f0 :3 0 7e9 7f2
7f1 :2 0 51 :3 0
c2 :3 0 c3 :3 0
c4 :3 0 c2 :3 0
37 :3 0 c5 :3 0
a2 :3 0 a2 :3 0
48 :3 0 32 :3 0
a2 :3 0 4b :3 0
13 :4 0 c6 1
:8 0 818 87 :4 0
803 :3 0 8e :3 0
7c :2 0 44f 806
807 :3 0 9 :3 0
6f :3 0 809 80a
0 17 :2 0 80b
80c 0 80e 452
815 9 :3 0 6f
:3 0 80f 810 0
88 :2 0 811 812
0 814 454 816
808 80e 0 817
0 814 0 817
456 0 818 459
86b 71 :3 0 9
:3 0 6f :3 0 81a
81b 0 70 :3 0
81c 81d 0 81f
45c 821 45e 820
81f :2 0 869 72
:3 0 9 :3 0 6f
:3 0 824 825 0
70 :3 0 826 827
0 861 55 :3 0
56 :3 0 829 82a
0 55 :3 0 66
:3 0 82c 82d 0
73 :2 0 2 :4 0
c7 :2 0 68 :2 0
15 :2 0 460 832
834 :3 0 463 82e
836 82b 838 837
:2 0 58 :3 0 69
:3 0 83a 83b 0
5a :4 0 c8 :4 0
5d :2 0 5e :3 0
467 83f 841 :3 0
5d :2 0 76 :4 0
46a 843 845 :3 0
5d :2 0 77 :4 0
46d 847 849 :3 0
5d :2 0 70 :3 0
470 84b 84d :3 0
5d :2 0 78 :4 0
473 84f 851 :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 476 854
858 47a 853 85a
:3 0 47d 83c 85c
:2 0 85e 480 85f
839 85e 0 860
482 0 861 484
864 :3 0 864 0
864 863 861 862
:6 0 866 1c :3 0
487 868 489 867
866 :2 0 869 48b
:2 0 86b 0 86b
86a 818 869 :6 0
86d b :3 0 48e
8e2 51 :3 0 a2
:3 0 a2 :3 0 48
:3 0 32 :3 0 a2
:3 0 4b :3 0 13
:4 0 c9 1 :8 0
88c 87 :4 0 877
:3 0 8e :3 0 7c
:2 0 492 87a 87b
:3 0 9 :3 0 6f
:3 0 87d 87e 0
17 :2 0 87f 880
0 882 495 889
9 :3 0 6f :3 0
883 884 0 88
:2 0 885 886 0
888 497 88a 87c
882 0 88b 0
888 0 88b 499
0 88c 49c 8df
71 :3 0 9 :3 0
6f :3 0 88e 88f
0 70 :3 0 890
891 0 893 49f
895 4a1 894 893
:2 0 8dd 72 :3 0
9 :3 0 6f :3 0
898 899 0 70
:3 0 89a 89b 0
8d5 55 :3 0 56
:3 0 89d 89e 0
55 :3 0 66 :3 0
8a0 8a1 0 73
:2 0 2 :4 0 ca
:2 0 68 :2 0 15
:2 0 4a3 8a6 8a8
:3 0 4a6 8a2 8aa
89f 8ac 8ab :2 0
58 :3 0 69 :3 0
8ae 8af 0 5a
:4 0 cb :4 0 5d
:2 0 5e :3 0 4aa
8b3 8b5 :3 0 5d
:2 0 76 :4 0 4ad
8b7 8b9 :3 0 5d
:2 0 77 :4 0 4b0
8bb 8bd :3 0 5d
:2 0 70 :3 0 4b3
8bf 8c1 :3 0 5d
:2 0 78 :4 0 4b6
8c3 8c5 :3 0 5d
:2 0 79 :3 0 7a
:3 0 15 :2 0 7b
:2 0 4b9 8c8 8cc
4bd 8c7 8ce :3 0
4c0 8b0 8d0 :2 0
8d2 4c3 8d3 8ad
8d2 0 8d4 4c5
0 8d5 4c7 8d8
:3 0 8d8 0 8d8
8d7 8d5 8d6 :6 0
8da 1e :3 0 4ca
8dc 4cc 8db 8da
:2 0 8dd 4ce :2 0
8df 0 8df 8de
88c 8dd :6 0 8e1
b :3 0 4d1 8e3
7f3 86d 0 8e4
0 8e1 0 8e4
4d3 0 8ed 1c
:3 0 cc :3 0 d
:3 0 13 :3 0 16
:3 0 4d6 8e6 8ea
8e5 8eb 0 8ed
4da 8ee 7bd 8ed
0 8ef 4de 0
8f0 4e0 8f1 7a2
8f0 0 8f2 4e2
0 8f3 4e4 8f5
86 :4 0 8f3 :4 0
954 cd :3 0 4a
:4 0 8f9 :2 0 8ff
8f7 0 9 :3 0
6f :3 0 8fa 8fb
0 70 :3 0 8fc
8fd 0 8ff 4ee
952 71 :3 0 9
:3 0 6f :3 0 901
902 0 70 :3 0
903 904 0 906
4f1 908 4f3 907
906 :2 0 950 72
:3 0 9 :3 0 6f
:3 0 90b 90c 0
70 :3 0 90d 90e
0 948 55 :3 0
56 :3 0 910 911
0 55 :3 0 66
:3 0 913 914 0
73 :2 0 2 :4 0
ce :2 0 68 :2 0
15 :2 0 4f5 919
91b :3 0 4f8 915
91d 912 91f 91e
:2 0 58 :3 0 69
:3 0 921 922 0
5a :4 0 cf :4 0
5d :2 0 5e :3 0
4fc 926 928 :3 0
5d :2 0 76 :4 0
4ff 92a 92c :3 0
5d :2 0 77 :4 0
502 92e 930 :3 0
5d :2 0 70 :3 0
505 932 934 :3 0
5d :2 0 78 :4 0
508 936 938 :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 50b 93b
93f 50f 93a 941
:3 0 512 923 943
:2 0 945 515 946
920 945 0 947
517 0 948 519
94b :3 0 94b 0
94b 94a 948 949
:6 0 94d 20 :3 0
51c 94f 51e 94e
94d :2 0 950 520
:2 0 952 0 952
951 8ff 950 :6 0
954 8 :3 0 523
956 2af 344 0
957 0 954 0
957 527 0 9db
33 :3 0 d0 :3 0
d1 :3 0 79 :3 0
30 :3 0 d1 :3 0
79 :3 0 1a :3 0
d2 :3 0 d1 :3 0
79 :3 0 30 :3 0
d1 :3 0 79 :3 0
1a :3 0 30 :3 0
34 :3 0 d :3 0
2c :3 0 12 :4 0
d3 1 :8 0 982
87 :4 0 96d :3 0
8e :3 0 7c :2 0
52c 970 971 :3 0
9 :3 0 6f :3 0
973 974 0 17
:2 0 975 976 0
978 52f 97f 9
:3 0 6f :3 0 979
97a 0 88 :2 0
97b 97c 0 97e
531 980 972 978
0 981 0 97e
0 981 533 0
982 536 9d5 71
:3 0 9 :3 0 6f
:3 0 984 985 0
70 :3 0 986 987
0 989 539 98b
53b 98a 989 :2 0
9d3 72 :3 0 9
:3 0 6f :3 0 98e
98f 0 70 :3 0
990 991 0 9cb
55 :3 0 56 :3 0
993 994 0 55
:3 0 66 :3 0 996
997 0 73 :2 0
2 :4 0 d4 :2 0
68 :2 0 15 :2 0
53d 99c 99e :3 0
540 998 9a0 995
9a2 9a1 :2 0 58
:3 0 69 :3 0 9a4
9a5 0 5a :4 0
d5 :4 0 5d :2 0
5e :3 0 544 9a9
9ab :3 0 5d :2 0
76 :4 0 547 9ad
9af :3 0 5d :2 0
77 :4 0 54a 9b1
9b3 :3 0 5d :2 0
70 :3 0 54d 9b5
9b7 :3 0 5d :2 0
78 :4 0 550 9b9
9bb :3 0 5d :2 0
79 :3 0 7a :3 0
15 :2 0 7b :2 0
553 9be 9c2 557
9bd 9c4 :3 0 55a
9a6 9c6 :2 0 9c8
55d 9c9 9a3 9c8
0 9ca 55f 0
9cb 561 9ce :3 0
9ce 0 9ce 9cd
9cb 9cc :6 0 9d0
22 :3 0 564 9d2
566 9d1 9d0 :2 0
9d3 568 :2 0 9d5
0 9d5 9d4 982
9d3 :6 0 9db 8
:3 0 92 :5 0 9d9
24 0 9da 56b
9d9 9d8 9db 56d
9dd 86 :4 0 9db
:4 0 a51 cd :3 0
2b :4 0 9e1 :2 0
9e7 9df 0 9
:3 0 6f :3 0 9e2
9e3 0 70 :3 0
9e4 9e5 0 9e7
574 a3a 71 :3 0
9 :3 0 6f :3 0
9e9 9ea 0 70
:3 0 9eb 9ec 0
9ee 577 9f0 579
9ef 9ee :2 0 a38
72 :3 0 9 :3 0
6f :3 0 9f3 9f4
0 70 :3 0 9f5
9f6 0 a30 55
:3 0 56 :3 0 9f8
9f9 0 55 :3 0
66 :3 0 9fb 9fc
0 73 :2 0 2
:4 0 d6 :2 0 68
:2 0 15 :2 0 57b
a01 a03 :3 0 57e
9fd a05 9fa a07
a06 :2 0 58 :3 0
69 :3 0 a09 a0a
0 5a :4 0 d7
:4 0 5d :2 0 5e
:3 0 582 a0e a10
:3 0 5d :2 0 76
:4 0 585 a12 a14
:3 0 5d :2 0 77
:4 0 588 a16 a18
:3 0 5d :2 0 70
:3 0 58b a1a a1c
:3 0 5d :2 0 78
:4 0 58e a1e a20
:3 0 5d :2 0 79
:3 0 7a :3 0 15
:2 0 7b :2 0 591
a23 a27 595 a22
a29 :3 0 598 a0b
a2b :2 0 a2d 59b
a2e a08 a2d 0
a2f 59d 0 a30
59f a33 :3 0 a33
0 a33 a32 a30
a31 :6 0 a35 24
:3 0 5a2 a37 5a4
a36 a35 :2 0 a38
5a6 :2 0 a3a 0
a3a a39 9e7 a38
:6 0 a51 1 :3 0
62 :3 0 18 :3 0
17 :2 0 5a9 a3c
a3f bb :2 0 80
:2 0 15 :2 0 5ac
a42 a44 :3 0 5b0
a41 a46 :3 0 1c
:3 0 d8 :3 0 d
:3 0 5b3 a49 a4b
a48 a4c 0 a4e
5b5 a4f a47 a4e
0 a50 5b7 0
a51 5b9 a52 205
a51 0 a53 5c1
0 aa2 55 :3 0
56 :3 0 a54 a55
0 55 :3 0 66
:3 0 a57 a58 0
d9 :2 0 2 :4 0
da :2 0 68 :2 0
15 :2 0 5c3 a5d
a5f :3 0 5c6 a59
a61 a56 a63 a62
:2 0 58 :3 0 69
:3 0 a65 a66 0
5a :4 0 db :4 0
5d :2 0 5e :3 0
5ca a6a a6c :3 0
5d :2 0 76 :4 0
5cd a6e a70 :3 0
5d :2 0 dc :4 0
5d0 a72 a74 :3 0
5d :2 0 62 :3 0
63 :3 0 9 :3 0
6f :3 0 a79 a7a
0 5d3 a78 a7c
64 :4 0 5d5 a77
a7f 5d8 a76 a81
:3 0 5d :2 0 dd
:4 0 5db a83 a85
:3 0 5d :2 0 60
:4 0 5de a87 a89
:3 0 5d :2 0 3
:3 0 5e1 a8b a8d
:3 0 5d :2 0 60
:4 0 5e4 a8f a91
:3 0 5e7 a67 a93
:2 0 a95 5ea a96
a64 a95 0 a97
5ec 0 aa2 de
:3 0 df :3 0 a98
a99 0 9 :3 0
6f :3 0 a9b a9c
0 3 :3 0 8e
:3 0 5ee a9a aa0
:2 0 aa2 5f2 b43
9 :3 0 e0 :2 0
4 aa3 aa4 0
55 :3 0 56 :3 0
aa6 aa7 0 55
:3 0 66 :3 0 aa9
aaa 0 73 :2 0
2 :4 0 e1 :2 0
68 :2 0 15 :2 0
5fd aaf ab1 :3 0
600 aab ab3 aa8
ab5 ab4 :2 0 58
:3 0 69 :3 0 ab7
ab8 0 5a :4 0
e2 :4 0 5d :2 0
5e :3 0 604 abc
abe :3 0 607 ab9
ac0 :2 0 ad9 58
:3 0 69 :3 0 ac2
ac3 0 5a :4 0
e3 :4 0 5d :2 0
9 :3 0 e4 :3 0
ac8 ac9 0 60a
ac7 acb :3 0 5d
:2 0 dd :4 0 60d
acd acf :3 0 5d
:2 0 9 :3 0 e5
:3 0 ad2 ad3 0
610 ad1 ad5 :3 0
613 ac4 ad7 :2 0
ad9 616 ada ab6
ad9 0 adb 619
0 aeb 85 :3 0
54 :3 0 9 :3 0
e4 :3 0 e6 :3 0
9 :3 0 e5 :3 0
e7 :3 0 e8 :4 0
e9 1 :a 0 ae7
:2 0 aeb add ae5
:2 0 8 :3 0 54
:3 0 ae9 :2 0 aeb
61b aed 61f aec
aeb :2 0 b41 72
:3 0 9 :3 0 6f
:3 0 af0 af1 0
70 :3 0 af2 af3
0 b39 55 :3 0
56 :3 0 af5 af6
0 55 :3 0 66
:3 0 af8 af9 0
73 :2 0 2 :4 0
ea :2 0 68 :2 0
15 :2 0 621 afe
b00 :3 0 624 afa
b02 af7 b04 b03
:2 0 58 :3 0 69
:3 0 b06 b07 0
5a :4 0 eb :4 0
5d :2 0 5e :3 0
628 b0b b0d :3 0
62b b08 b0f :2 0
b29 58 :3 0 69
:3 0 b11 b12 0
5a :4 0 77 :4 0
5d :2 0 70 :3 0
62e b16 b18 :3 0
5d :2 0 78 :4 0
631 b1a b1c :3 0
5d :2 0 79 :3 0
7a :3 0 15 :2 0
7b :2 0 634 b1f
b23 638 b1e b25
:3 0 63b b13 b27
:2 0 b29 63e b2a
b05 b29 0 b2b
641 0 b39 85
:3 0 54 :3 0 e6
:3 0 9 :3 0 e5
:3 0 e7 :3 0 e8
:4 0 ec 1 :a 0
b35 :2 0 b39 b2d
b33 :2 0 8 :3 0
54 :3 0 b37 :2 0
b39 643 b3c :3 0
b3c 0 b3c b3b
b39 b3a :6 0 b3e
1 :3 0 648 b40
64a b3f b3e :2 0
b41 64c :2 0 b43
64f b43 b42 aa2
b41 :6 0 b44 :2 0
2 14 b43 b47
:3 0 b46 b44 b48
:8 0 
66c
4
:3 0 1 3 1
7 1 b 3
6 a e 1
16 1 1d 1
1b 1 24 1
22 1 29 1
30 1 2e 1
37 1 35 1
3e 1 3c 1
43 1 49 1
4f 1 55 1
5a 1 60 1
66 1 6c 1
72 1 78 1
7e 1 84 1
8c 1 8a 1
93 1 91 1
98 1 9e 1
a4 1 aa 1
e9 1 108 1
10e 1 11b 1
127 2 12a 12c
2 12f 131 2
133 135 2 137
139 2 13b 13d
1 143 2 145
146 2 13f 148
2 14a 14c 2
14e 150 2 152
154 2 156 158
2 15a 15c 4
123 129 12e 15e
1 160 1 162
2 16c 16e 3
16a 16b 170 2
179 17b 2 178
17d 1 17f 1
181 2 199 19e
1 1a5 1 1a0
2 1b8 1ba 3
1b6 1b7 1bc 2
1c5 1c7 2 1c9
1cb 2 1cd 1cf
2 1d1 1d3 2
1d5 1d7 3 1dc
1dd 1de 2 1d9
1e0 2 1c4 1e2
1 1e4 1 1e6
2 1af 1e7 1
1eb 1 1aa 2
1a8 1ef 1 1fa
2 1f6 1fa 1
1fe 2 208 20a
3 20c 20d 20e
1 214 2 21d
222 1 229 1
224 2 23c 23e
3 23a 23b 240
2 249 24b 2
24d 24f 2 251
253 2 255 257
2 259 25b 3
260 261 262 2
25d 264 2 248
266 1 268 1
26a 2 233 26b
1 26f 1 22e
2 22c 273 4
27f 280 281 282
1 28d 1 293
2 295 296 1
29e 2 29a 29e
1 2a3 1 2a5
2 2a8 2a9 1
2ad 2 2ab 2ad
2 2b1 2b2 1
2b6 2 2b4 2b6
1 2c4 2 2c3
2c4 1 2cc 1
2d2 2 2d4 2d5
2 2c1 2d6 1
2dd 1 2d8 2
2f0 2f2 3 2ee
2ef 2f4 2 2fd
2ff 2 301 303
2 305 307 2
309 30b 2 30d
30f 3 314 315
316 2 311 318
2 2fc 31a 1
31c 1 31e 2
2e7 31f 1 323
1 2e2 2 2e0
327 2 336 337
5 331 332 333
334 339 3 32a
32e 33c 1 33f
2 341 342 1
343 6 34c 34d
34e 34f 350 351
1 35c 1 362
2 364 365 1
36d 2 369 36d
1 372 1 374
2 37a 37b 1
37f 2 37d 37f
3 383 384 385
1 389 2 387
389 1 398 2
397 398 1 3a0
1 3a6 2 3a8
3a9 2 395 3aa
1 3b1 1 3ac
2 3c4 3c6 3
3c2 3c3 3c8 2
3d1 3d3 2 3d5
3d7 2 3d9 3db
2 3dd 3df 2
3e1 3e3 3 3e8
3e9 3ea 2 3e5
3ec 2 3d0 3ee
1 3f0 1 3f2
2 3bb 3f3 1
3f7 1 3b6 2
3b4 3fb 2 401
402 1 407 1
409 2 404 409
1 42b 2 42a
42b 1 433 1
439 2 43b 43c
2 428 43d 1
444 1 43f 2
457 459 3 455
456 45b 2 464
466 2 468 46a
2 46c 46e 2
470 472 2 474
476 3 47b 47c
47d 2 478 47f
2 463 481 1
483 1 485 2
44e 486 1 48a
1 449 2 447
48e 2 410 491
1 49f 2 49e
49f 1 4a7 1
4ad 2 4af 4b0
2 49c 4b1 1
4b8 1 4b3 2
4cb 4cd 3 4c9
4ca 4cf 2 4d8
4da 2 4dc 4de
2 4e0 4e2 2
4e4 4e6 2 4e8
4ea 3 4ef 4f0
4f1 2 4ec 4f3
2 4d7 4f5 1
4f7 1 4f9 2
4c2 4fa 1 4fe
1 4bd 2 4bb
502 1 505 2
508 509 2 3fe
50a 1 517 2
516 517 1 51f
1 525 2 527
528 2 514 529
1 530 1 52b
2 543 545 3
541 542 547 2
550 552 2 554
556 2 558 55a
2 55c 55e 2
560 562 3 567
568 569 2 564
56b 2 54f 56d
1 56f 1 571
2 53a 572 1
576 1 535 2
533 57a 1 57d
2 580 581 1
582 2 585 586
1 58a 2 588
58a 1 596 2
595 596 1 59e
1 5a4 2 5a6
5a7 2 593 5a8
1 5af 1 5aa
2 5c2 5c4 3
5c0 5c1 5c6 2
5cf 5d1 2 5d3
5d5 2 5d7 5d9
2 5db 5dd 2
5df 5e1 3 5e6
5e7 5e8 2 5e3
5ea 2 5ce 5ec
1 5ee 1 5f0
2 5b9 5f1 1
5f5 1 5b4 2
5b2 5f9 1 5fc
3 600 601 602
1 606 2 604
606 1 615 2
614 615 1 61d
1 623 2 625
626 2 612 627
1 62e 1 629
2 641 643 3
63f 640 645 2
64e 650 2 652
654 2 656 658
2 65a 65c 2
65e 660 3 665
666 667 2 662
669 2 64d 66b
1 66d 1 66f
2 638 670 1
674 1 633 2
631 678 1 690
2 68f 690 1
698 1 69e 2
6a0 6a1 2 68d
6a2 1 6a9 1
6a4 2 6bc 6be
3 6ba 6bb 6c0
2 6c9 6cb 2
6cd 6cf 2 6d1
6d3 2 6d5 6d7
2 6d9 6db 3
6e0 6e1 6e2 2
6dd 6e4 2 6c8
6e6 1 6e8 1
6ea 2 6b3 6eb
1 6ef 1 6ae
2 6ac 6f3 2
67b 6f6 1 705
2 704 705 1
70d 1 713 2
715 716 2 702
717 1 71e 1
719 2 731 733
3 72f 730 735
2 73e 740 2
742 744 2 746
748 2 74a 74c
2 74e 750 3
755 756 757 2
752 759 2 73d
75b 1 75d 1
75f 2 728 760
1 764 1 723
2 721 768 1
76b 2 76e 76f
1 770 2 772
773 1 774 2
776 777 1 77f
2 77b 77f 1
785 1 787 2
793 794 5 78e
78f 790 791 796
2 79b 79c 1
7a0 2 79e 7a0
2 7a5 7a6 2
7a8 7a9 1 7ae
2 7ac 7ae 2
7b3 7b4 1 7b8
2 7b6 7b8 1
7c2 2 7c4 7c5
1 7cb 2 7cd
7ce 2 7c7 7d0
2 7d3 7d5 2
7db 7dc 2 7d8
7de 1 7e0 1
7e6 2 7e4 7e6
1 7ed 1 7ef
2 7ea 7ef 1
805 2 804 805
1 80d 1 813
2 815 816 2
802 817 1 81e
1 819 2 831
833 3 82f 830
835 2 83e 840
2 842 844 2
846 848 2 84a
84c 2 84e 850
3 855 856 857
2 852 859 2
83d 85b 1 85d
1 85f 2 828
860 1 864 1
823 2 821 868
1 86b 1 879
2 878 879 1
881 1 887 2
889 88a 2 876
88b 1 892 1
88d 2 8a5 8a7
3 8a3 8a4 8a9
2 8b2 8b4 2
8b6 8b8 2 8ba
8bc 2 8be 8c0
2 8c2 8c4 3
8c9 8ca 8cb 2
8c6 8cd 2 8b1
8cf 1 8d1 1
8d3 2 89c 8d4
1 8d8 1 897
2 895 8dc 1
8df 2 8e2 8e3
3 8e7 8e8 8e9
3 7e3 8e4 8ec
1 8ee 1 8ef
1 8f1 9 352
366 375 378 778
788 78b 799 8f2
2 8f8 8fe 1
905 1 900 2
918 91a 3 916
917 91c 2 925
927 2 929 92b
2 92d 92f 2
931 933 2 935
937 3 93c 93d
93e 2 939 940
2 924 942 1
944 1 946 2
90f 947 1 94b
1 90a 2 908
94f 3 347 8f5
952 2 955 956
1 96f 2 96e
96f 1 977 1
97d 2 97f 980
2 96c 981 1
988 1 983 2
99b 99d 3 999
99a 99f 2 9a8
9aa 2 9ac 9ae
2 9b0 9b2 2
9b4 9b6 2 9b8
9ba 3 9bf 9c0
9c1 2 9bc 9c3
2 9a7 9c5 1
9c7 1 9c9 2
992 9ca 1 9ce
1 98d 2 98b
9d2 1 9d7 6
283 297 2a6 957
9d5 9da 2 9e0
9e6 1 9ed 1
9e8 2 a00 a02
3 9fe 9ff a04
2 a0d a0f 2
a11 a13 2 a15
a17 2 a19 a1b
2 a1d a1f 3
a24 a25 a26 2
a21 a28 2 a0c
a2a 1 a2c 1
a2e 2 9f7 a2f
1 a33 1 9f2
2 9f0 a37 2
a3d a3e 1 a43
1 a45 2 a40
a45 1 a4a 1
a4d 1 a4f 7
211 217 276 27a
9dd a3a a50 1
a52 2 a5c a5e
3 a5a a5b a60
2 a69 a6b 2
a6d a6f 2 a71
a73 1 a7b 2
a7d a7e 2 a75
a80 2 a82 a84
2 a86 a88 2
a8a a8c 2 a8e
a90 2 a68 a92
1 a94 1 a96
3 a9d a9e a9f
a 163 182 185
188 18b 18e 1f2
a53 a97 aa1 2
aae ab0 3 aac
aad ab2 2 abb
abd 2 aba abf
2 ac6 aca 2
acc ace 2 ad0
ad4 2 ac5 ad6
2 ac1 ad8 1
ada 3 adb ae6
aea 1 aa5 2
afd aff 3 afb
afc b01 2 b0a
b0c 2 b09 b0e
2 b15 b17 2
b19 b1b 3 b20
b21 b22 2 b1d
b24 2 b14 b26
2 b10 b28 1
b2a 4 af4 b2b
b34 b38 1 b3c
1 aef 2 aed
b40 1c 19 20
27 2c 33 3a
41 47 4d 53
58 5e 64 6a
70 76 7c 82
88 8f 96 9c
a2 a8 ad ea
109 113 
1
4
0 
b47
0
1
28
26
21
0 1 1 1 4 1 6 1
8 9 8 b c b e b
10 b 12 b 14 b 16 b
18 b 1a b 1c b 1e 8
20 8 22 1 24 1 0 0

b 1 0
60 1 0
7e 1 0
16 1 0
35 1 0
98 1 0
2 0 1
9d7 8 24
84 1 0
5a 1 0
49 1 0
3 1 0
29 1 0
8a 1 0
f0 1 3
43 1 0
72 1 0
2e 1 0
22 1 0
78 1 0
a4 1 0
3c 1 0
6c 1 0
9e 1 0
4f 1 0
55 1 0
1b 1 0
66 1 0
7 1 0
91 1 0
b0 1 2
aa 1 0
10e 1 0
0

/
SHOW ERRORS FUNCTION SP_RJCT_ETC_WBS;
ALTER FUNCTION SP_RJCT_ETC_WBS COMPILE DEBUG;
Prompt == FUNCTION SP_U_WP_FORECAST ==
CREATE OR REPLACE FUNCTION SP_U_WP_FORECAST wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
139
2 :e:
1FUNCTION:
1SP_U_WP_FORECAST:
1ID001:
1VARCHAR2:
1START_DATE001:
1TIMESTAMP:
1FINISH_DATE001:
1ACC_REJ_BITFLAG:
1PLS_INTEGER:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_REC_STATUS:
11:
1H_PROJECT_ID:
132:
1H_TASK_ID:
1H_PRJ_ASSIGNMENT_ID:
1H_TSK_ASSIGNMENT_ID:
1H_RES_ASSIGNMENT_ID:
1H_RES_ID:
1H_REC_USER:
1H_SECURITY_ID:
1H_START_DATE:
1H_FINISH_DATE:
1H_START_DT:
1H_FINISH_DT:
1H_FORECAST_START:
1H_FORECAST_FINISH:
1H_ACTUAL_START:
1H_RANK:
1200:
1H_MLST_PERCENT:
10:
1H_TYPE:
1H_REG_COST:
1NUMBER:
10.00:
1H_REG_SALE:
1H_TA_START_DT:
1H_TA_FINISH_DT:
1H_LAST_SUBMITTED:
1DATE:
1H_PROJAFFECTED_START:
1H_DAYOFYEAR:
1H_WEEK_OF:
1H_BIT_FLAG:
1H_BILLABLE:
1H_CAPITAL_EXPENSE:
1H_ETC:
1H_TOTAL:
1H_SCHED_WORK:
1H_CONTINUE:
1H_EFFORT:
1H_CONTOUR:
1H_BITFLAG:
1H_ACC_REJ_BITFLAG:
1H_REMAINING:
1H_FF:
1H_TEMP_VAR:
1H_TEMP_SC_STATE:
1H_ALERT_FLAG:
1H_ALERT_ID:
1NULL_RETURN:
1LONG:
1ORA_TEMP_SC_STATE:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_WP_FORECAST(:
1':
1, :
1COALESCE:
1NULLIF:
1'':
1NULL:
1TO_CHAR:
1);:
1CHECK_TRACE:
168:
1+:
1FPUT:
1               ENTER:: SP_U_WP_FORECAST(69) :: cplan.sql(23487) :: :
1:
1=:
1PMO_CNST:
1SC_ACCEPT_REJECT_FORECAST:
1PROJECT_ID:
1RES_ASSIGNMENT_ID:
1PROJECT_ASSIGNMENT_ID:
1ACTUAL_START:
1MILESTONE_PERCENT:
1BIT_FLAG:
1FORECAST_START:
1SCHED_START:
1FORECAST_FINISH:
1SCHED_FINISH:
1TASK_ID:
1RESOURCE_ID:
1SCHED_WORK:
1PLANNED_WORK:
1WORK_TODATE:
1ETC:
1C_CONTOUR:
1LAST_SUBMITTED:
1UNRESOLVED_START:
1UNRESOLVED_FINISH:
1BILLABLE:
1CAPITAL_EXPENSE:
1REGULAR_COST:
1REGULAR_RATE:
1TASK_ASSIGNMENTS:
1TSK_ASSIGNMENT_ID:
1SELECT PROJECT_ID, RES_ASSIGNMENT_ID, PROJECT_ASSIGNMENT_ID, ACTUAL_START, MI+
1LESTONE_PERCENT, BIT_FLAG, :n      COALESCE(FORECAST_START,SCHED_START), COAL+
1ESCE(FORECAST_FINISH,SCHED_FINISH), FORECAST_START, FORECAST_FINISH, TASK_ID,+
1 RESOURCE_ID, SCHED_WORK, (PLANNED_WORK + SCHED_WORK - WORK_TODATE), ETC,:n  +
1    C_CONTOUR, LAST_SUBMITTED, UNRESOLVED_START, UNRESOLVED_FINISH, BILLABLE,+
1 CAPITAL_EXPENSE, REGULAR_COST, REGULAR_RATE:n      INTO h_project_id, h_res_+
1assignment_id, h_prj_assignment_id, h_actual_start, h_mlst_percent, h_bit_fla+
1g,:n      h_start_DT, h_finish_DT, h_forecast_start, h_forecast_finish, h_tas+
1k_id, h_res_id, h_sched_work,h_remaining, h_etc,:n      h_contour, h_last_sub+
1mitted, h_ta_start_DT, h_ta_finish_DT, h_billable, h_capital_expense, h_reg_c+
1ost, h_reg_sale:n      FROM TASK_ASSIGNMENTS:n      WHERE TSK_ASSIGNMENT_ID =+
1 id001:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
1104:
1           EXCEPTION:: SP_U_WP_FORECAST(105) :: cplan.sql(23523) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1SC_SQL_NO_DATA:
1112:
1        RETURN_ERROR:: SP_U_WP_FORECAST(113) :: cplan.sql(23531) :: :
1STATE:: :
1RECORD_NOT_FOUND:
1 ID:: :
1115:
1                EXIT:: SP_U_WP_FORECAST(116) :: cplan.sql(23534) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1REC_STATUS:
1TMT_WBS:
1ELEMENT_ID:
1SELECT REC_STATUS:n      INTO h_rec_status:n      FROM TMT_WBS:n      WHERE P+
1ROJECT_ID = h_project_id:n      AND ELEMENT_ID = h_task_id:
1134:
1           EXCEPTION:: SP_U_WP_FORECAST(135) :: cplan.sql(23553) :: :
1T:
1141:
1        RETURN_ERROR:: SP_U_WP_FORECAST(142) :: cplan.sql(23560) :: :
1CANNOT_UPDATE_LOCKED_RECORD:
1144:
1                EXIT:: SP_U_WP_FORECAST(145) :: cplan.sql(23563) :: :
110000:
1151:
1        RETURN_ERROR:: SP_U_WP_FORECAST(152) :: cplan.sql(23570) :: :
1ASSIGNMENT_ALREADY_CLOSED:
1154:
1                EXIT:: SP_U_WP_FORECAST(155) :: cplan.sql(23573) :: :
1IS NOT NULL:
1PMO_ORASTD:
1STRNCMP:
110:
1<:
1162:
1        RETURN_ERROR:: SP_U_WP_FORECAST(163) :: cplan.sql(23581) :: :
1F_DATE_EARLIER_THAN_S_DATE:
1165:
1                EXIT:: SP_U_WP_FORECAST(166) :: cplan.sql(23584) :: :
1MAX:
1WEEK_OF:
1TIMESHEET_APPROVAL_STATUS:
1CURRENT_STATE:
1SC_APV_STATE_RM_APPROVED:
1SC_APV_STATE_PM_APPROVED:
1SC_APV_STATE_SUBMITTED:
1SELECT MAX(WEEK_OF) + 7      INTO h_week_of FROM TIMESHEET_APPROVAL_STATUS:n +
1     WHERE ELEMENT_ID = h_project_id AND RESOURCE_ID = h_res_id:n      AND CU+
1RRENT_STATE IN (pmo_cnst.SC_APV_STATE_RM_APPROVED,pmo_cnst.SC_APV_STATE_PM_AP+
1PROVED,pmo_cnst.SC_APV_STATE_SUBMITTED):
1184:
1           EXCEPTION:: SP_U_WP_FORECAST(185) :: cplan.sql(23603) :: :
1STRCMP:
1!=:
1SCETCFORCASTCHANGED:
1FC_ISSUE_ALERT:
1SCREDUCEDETC:
1IS NULL:
1FORECAST_DURATION:
1UPDATE TASK_ASSIGNMENTS SET:n         FORECAST_START  = start_date001,:n     +
1    FORECAST_FINISH = finish_date001,:n         FORECAST_DURATION = 0:n      +
1   WHERE TSK_ASSIGNMENT_ID = id001:
1FOUND:
1100:
1230:
1           EXCEPTION:: SP_U_WP_FORECAST(231) :: cplan.sql(23649) :: :
1UPDATE TASK_ASSIGNMENTS SET:n            FORECAST_START  = start_date001,:n  +
1          FORECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = id001:
1257:
1           EXCEPTION:: SP_U_WP_FORECAST(258) :: cplan.sql(23676) :: :
1UPDATE TASK_ASSIGNMENTS SET:n            FORECAST_FINISH = finish_date001,:n +
1           FORECAST_DURATION = 0:n            WHERE TSK_ASSIGNMENT_ID = id001:
1289:
1           EXCEPTION:: SP_U_WP_FORECAST(290) :: cplan.sql(23708) :: :
1>:
1313:
1        RETURN_ERROR:: SP_U_WP_FORECAST(314) :: cplan.sql(23732) :: :
1FORECAST_APPROVAL_EXISTS:
1316:
1                EXIT:: SP_U_WP_FORECAST(317) :: cplan.sql(23735) :: :
1324:
1        RETURN_ERROR:: SP_U_WP_FORECAST(325) :: cplan.sql(23743) :: :
1CANNOT_UPDATE_HAS_ACTUAL:
1327:
1                EXIT:: SP_U_WP_FORECAST(328) :: cplan.sql(23746) :: :
1ELSIF:
1DB2TIMESTAMP:
1DAY_YEAR:
1TIME:
1PMO_STPU:
1FIRST_AVAIL_TIME:
1BIT_SCHED:
1CALENDAR_DAY_OF_YEAR:
1TO_DATE:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.FIRST_AVAIL+
1_TIME(BIT_SCHED))) INTO h_start_date:n                  FROM CALENDAR_DAY_OF_+
1YEAR:n                  WHERE ELEMENT_ID = h_project_id:n                  AN+
1D DAY_YEAR = TO_DATE(SubStr(start_date001, 1, 10)):
1350:
1           EXCEPTION:: SP_U_WP_FORECAST(351) :: cplan.sql(23769) :: :
1DUAL:
1SELECT  (PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(start_date001, 1, 10)), PMO_O+
1RASTD.TIME('08::00')))  INTO  h_start_date FROM DUAL:
1367:
1           EXCEPTION:: SP_U_WP_FORECAST(368) :: cplan.sql(23786) :: :
1374:
1        RETURN_ERROR:: SP_U_WP_FORECAST(375) :: cplan.sql(23793) :: :
1377:
1                EXIT:: SP_U_WP_FORECAST(378) :: cplan.sql(23796) :: :
1390:
1        RETURN_ERROR:: SP_U_WP_FORECAST(391) :: cplan.sql(23809) :: :
1INVALID_PARAMS:
1393:
1                EXIT:: SP_U_WP_FORECAST(394) :: cplan.sql(23812) :: :
1<=:
18:
1399:
1      RETURN_INVALID:: SP_U_WP_FORECAST(400) :: cplan.sql(23818) :: :
1402:
1                EXIT:: SP_U_WP_FORECAST(403) :: cplan.sql(23821) :: :
1PMO_RETURN_INVALID_SP:
1LAST_AVAIL_TIME:
1SELECT PMO_ORASTD.DB2TIMESTAMP(DAY_YEAR, PMO_ORASTD.TIME(PMO_STPU.LAST_AVAIL_+
1TIME(BIT_SCHED))) INTO h_finish_date:n                  FROM CALENDAR_DAY_OF_+
1YEAR:n                  WHERE ELEMENT_ID = h_project_id:n                  AN+
1D DAY_YEAR = TO_DATE(SubStr(finish_date001, 1, 10)):
1431:
1           EXCEPTION:: SP_U_WP_FORECAST(432) :: cplan.sql(23850) :: :
1SELECT  (PMO_ORASTD.DB2TIMESTAMP(TO_DATE(SubStr(finish_date001, 1, 10)), PMO_+
1ORASTD.TIME('17::00')))  INTO  h_finish_date FROM DUAL:
1449:
1           EXCEPTION:: SP_U_WP_FORECAST(450) :: cplan.sql(23868) :: :
1457:
1        RETURN_ERROR:: SP_U_WP_FORECAST(458) :: cplan.sql(23876) :: :
1460:
1                EXIT:: SP_U_WP_FORECAST(461) :: cplan.sql(23879) :: :
1UPDATE TASK_ASSIGNMENTS SET:n               FORECAST_START  = h_start_date,:n+
1               FORECAST_FINISH = h_finish_date,:n               FORECAST_DURA+
1TION = 0:n               WHERE TSK_ASSIGNMENT_ID = id001:
1491:
1           EXCEPTION:: SP_U_WP_FORECAST(492) :: cplan.sql(23910) :: :
1COUNT:
1TASK_DAY_OF_YEAR:
1SELECT COUNT('X') INTO h_temp_var:n                     FROM DUAL:n          +
1           WHERE EXISTS (SELECT DAY_YEAR FROM TASK_DAY_OF_YEAR:n             +
1        WHERE PROJECT_ID = h_project_id AND ((TSK_ASSIGNMENT_ID = h_prj_assig+
1nment_id) OR (TSK_ASSIGNMENT_ID = h_tsk_assignment_id)):n                    +
1 AND DAY_YEAR = TO_DATE(SubStr(finish_date001, 1, 10))):
1516:
1           EXCEPTION:: SP_U_WP_FORECAST(517) :: cplan.sql(23935) :: :
1524:
1        RETURN_ERROR:: SP_U_WP_FORECAST(525) :: cplan.sql(23943) :: :
1PROJECT_ASSIGNMENT_REMAINING:
1527:
1                EXIT:: SP_U_WP_FORECAST(528) :: cplan.sql(23946) :: :
1SELECT COUNT('X') INTO h_temp_var:n                     FROM DUAL:n          +
1           WHERE EXISTS (SELECT DAY_YEAR FROM TASK_DAY_OF_YEAR:n             +
1        WHERE PROJECT_ID = h_project_id AND ((TSK_ASSIGNMENT_ID = h_prj_assig+
1nment_id) OR (TSK_ASSIGNMENT_ID = h_tsk_assignment_id)):n                    +
1 AND DAY_YEAR = TO_DATE(SubStr(start_date001, 1, 10))):
1549:
1           EXCEPTION:: SP_U_WP_FORECAST(550) :: cplan.sql(23968) :: :
1557:
1        RETURN_ERROR:: SP_U_WP_FORECAST(558) :: cplan.sql(23976) :: :
1560:
1                EXIT:: SP_U_WP_FORECAST(561) :: cplan.sql(23979) :: :
1SUM:
1SCHED_MIN:
1PARENT_ID:
1SELECT SUM(SCHED_MIN) INTO h_total FROM TASK_DAY_OF_YEAR:n                   +
1     WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_prj_assignment_id AND +
1DAY_YEAR >= TO_DATE(SubStr(start_date001, 1, 10)):
1580:
1           EXCEPTION:: SP_U_WP_FORECAST(581) :: cplan.sql(23999) :: :
1586:
1        RETURN_ERROR:: SP_U_WP_FORECAST(587) :: cplan.sql(24005) :: :
1589:
1                EXIT:: SP_U_WP_FORECAST(590) :: cplan.sql(24008) :: :
1597:
1        RETURN_ERROR:: SP_U_WP_FORECAST(598) :: cplan.sql(24016) :: :
1TASK_ASSIGNMENT_ERROR:
1600:
1                EXIT:: SP_U_WP_FORECAST(601) :: cplan.sql(24019) :: :
12:
1FC_ACPT_ETC_ASSIGN:
1U_ASSIGN_STRING:
13:
1FC_ROLLUP:
14:
1651:
1       RETURN_STATUS:: SP_U_WP_FORECAST(652) :: cplan.sql(24070) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1659:
1           EXCEPTION:: SP_U_WP_FORECAST(660) :: cplan.sql(24078) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1671:
1           EXCEPTION:: SP_U_WP_FORECAST(672) :: cplan.sql(24090) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
121a
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 1c
51 81 b0 a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a3 a0 1c
81 b0 a3 a0 1c 81 b0 a3
a0 1c 81 b0 a3 a0 1c 81
b0 a3 a0 1c 81 b0 a3 a0
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 1c 51
81 b0 a3 a0 1c 51 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 1c 81 b0
a3 a0 1c 51 81 b0 a3 :2 a0
6b 1c 81 b0 :2 a0 6b :2 a0 6b
6e a5 b a 10 :2 a0 6b 6e
:2 a0 6b 6e a5 b 6e 7e a0
b4 2e 6e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :2 a0 6e 7e a0
b4 2e 7e 6e b4 2e 6e a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e :2 a0 6e 7e a0 b4
2e 7e 6e b4 2e 6e a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e :3 a0 a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c a0 6e
d a0 6e d a0 51 d :2 a0
d :2 a0 d :2 a0 d :2 a0 d :2 a0
51 a5 b 7e 51 b4 2e 5a
:3 a0 6b d b7 19 3c :37 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :7 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 :2 51 a5
b 7e 6e b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c a0 7e b4 2e :2 5a a0 7e
b4 2e :2 5a a 10 :2 a0 6b :2 a0
51 a5 b 7e 51 b4 2e :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :4 a0 6b
a5 b 6e a5 b b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e a5
57 b7 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 19
3c b7 19 3c a0 4d d :f a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 d :2 a0 6b :2 a0 a5 b
7e 51 b4 2e 5a :2 a0 51 a5
b a0 7e a0 6b b4 2e 5a
a 10 a0 6e d a0 51 d
:3 a0 6b d :6 a0 51 a5 b d
:2 a0 6b a0 d a0 6e d a0
51 d :3 a0 6b d :6 a0 51 a5
b d :2 a0 6b a0 d b7 19
3c a0 7e b4 2e :2 5a :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
5a a 10 :2 a0 d b7 19 3c
a0 7e b4 2e :2 5a a0 7e b4
2e :2 5a a 10 :8 a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f b7 a0 7e b4
2e 5a a0 7e b4 2e 5a a
10 :6 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e a0 51 d b7 19
3c b7 19 3c a0 7e b4 2e
5a a0 7e b4 2e 5a a 10
:6 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e a0 51 d b7 19 3c
b7 19 3c :2 a0 51 a5 b 7e
51 b4 2e a0 7e b4 2e :2 5a
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 d b7
19 3c a0 7e b4 2e :2 5a a0
7e b4 2e :2 5a a 10 :2 a0 6b
:2 a0 a5 b 7e 51 b4 2e 5a
a 10 :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c a0 7e b4 2e
5a a0 7e b4 2e 5a :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
:2 a0 d :2 a0 6b :2 a0 51 a5 b
7e 51 b4 2e a0 4d d a0
b7 :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e :10 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :9 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 19 3c a0 b7 19 a0 7e
b4 2e 5a :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :2 a0 51 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b 51 :2 a0 a5
57 b7 :2 19 3c b7 a0 51 d
a0 4d d b7 :2 19 3c a0 7e
b4 2e 5a a0 7e b4 2e :2 5a
:2 a0 6b :2 a0 51 a5 b 7e 51
b4 2e 5a a 10 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 a0 b7 a0 7e
b4 2e :2 5a :2 a0 6b :2 a0 51 a5
b 7e 51 b4 2e 5a a 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
:2 19 3c a0 7e b4 2e :2 5a :2 a0
6b :2 a0 51 a5 b 7e 51 b4
2e 5a a 10 a0 51 d b7
a0 51 d b7 :2 19 3c :2 a0 6b
:2 a0 51 a5 b 7e 51 b4 2e
a0 4d d a0 b7 :2 a0 6b :2 a0
a5 b 7e 51 b4 2e :10 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 6b a0 7e a0 6b b4 2e
5a :9 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 19 3c a0 b7
19 :2 a0 6b :2 a0 51 a5 b 7e
51 b4 2e :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :2 a0 51 a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
b7 19 3c :2 a0 6b 51 :2 a0 a5
57 b7 :2 19 3c b7 a0 4d d
b7 :2 19 3c :2 a0 d a0 51 d
:2 a0 51 a5 b a0 7e a0 6b
b4 2e :8 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a0 7e b4 2e 5a
a0 7e b4 2e 5a a0 51 d
:f a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b :2 a0 a5
57 b7 19 3c a0 b7 a0 7e
b4 2e 5a a0 51 d :f a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:c a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b a0 7e
a0 51 a5 b b4 2e :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e :4 a0 6b a5
b 6e a5 b b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e a5 57
b7 19 3c :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 19 3c
b7 :2 19 3c b7 19 :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 19 3c b7
19 3c a0 51 d :2 a0 d a0
7e b4 2e 5a a0 7e b4 2e
:2 5a a 10 :2 a0 d b7 19 3c
:18 a0 51 a5 b d a0 51 d
:5 a0 :3 51 a5 b d a0 7e b4
2e 5a a0 51 d :5 a0 :3 51 a5
b d b7 19 3c b7 :2 19 3c
b7 19 3c b7 :2 19 3c :2 a0 6b
:2 a0 a5 b 7e 51 b4 2e 5a
:2 a0 51 a5 b a0 7e a0 6b
b4 2e 5a a 10 a0 6e d
a0 51 d :3 a0 6b d :6 a0 51
a5 b d :2 a0 6b a0 d a0
6e d a0 51 d :3 a0 6b d
:6 a0 51 a5 b d :2 a0 6b a0
d b7 19 3c :3 a0 a5 b d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 6b :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e :2 a0 6b b4 2e 7e
6e b4 2e 7e :2 a0 6b b4 2e
a5 57 b7 19 3c :9 a0 12a e9
dd :2 a0 65 b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e a5 57 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c :7 a0 12a e9 dd :2 a0
65 b7 a4 b1 11 4f b7 a6
9 a4 b1 11 68 4f 1d 17
b5 
121a
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 6f 6b 59 77 56
7c 80 84 88 8b 8f ac 97
9b 9e 9f a7 96 c9 b7 93
bb bc c4 b6 e6 d4 b3 d8
d9 e1 d3 103 f1 d0 f5 f6
fe f0 120 10e ed 112 113 11b
10d 13d 12b 10a 12f 130 138 12a
15a 148 127 14c 14d 155 147 177
165 144 169 16a 172 164 194 182
161 186 187 18f 181 1b0 19f 1a3
1ab 17e 1c8 1b7 1bb 1c3 19e 1e4
1d3 1d7 1df 19b 1fc 1eb 1ef 1f7
1d2 218 207 20b 213 1cf 230 21f
223 22b 206 24c 23b 23f 247 203
268 253 257 25a 25b 263 23a 284
273 277 237 27f 272 2a0 28f 293
26f 29b 28e 2bc 2ab 2af 28b 2b7
2aa 2d8 2c7 2cb 2a7 2d3 2c6 2f4
2e3 2e7 2ef 2c3 30c 2fb 2ff 307
2e2 328 317 31b 323 2df 340 32f
333 33b 316 35c 34b 34f 357 313
374 363 367 36f 34a 391 37f 347
383 384 38c 37e 3ad 39c 3a0 37b
3a8 39b 3c9 3b8 3bc 398 3c4 3b7
3e5 3d4 3d8 3b4 3e0 3d3 401 3f0
3f4 3d0 3fc 3ef 41d 40c 410 3ec
418 40b 439 428 42c 408 434 427
455 444 448 424 450 443 471 460
464 440 46c 45f 48d 47c 480 45c
488 47b 4a9 498 49c 478 4a4 497
4c5 4b4 4b8 494 4c0 4b3 4e1 4d0
4d4 4b0 4dc 4cf 4fd 4ec 4f0 4cc
4f8 4eb 519 508 50c 4e8 514 507
535 524 528 504 530 523 552 540
520 544 545 54d 53f 56e 55d 561
569 53c 589 575 579 581 584 55c
5a9 594 598 559 59c 5a4 593 5b0
5b4 590 5b8 5bc 5c0 5c3 5c8 5c9
1 5cb 5d0 5d4 5d8 5db 5e0 5e4
5e8 5eb 5f0 5f1 5f3 5f8 5fb 5ff
600 605 60a 60d 612 613 618 61b
61f 620 625 628 62d 62e 633 636
63b 63c 641 644 648 64c 651 654
658 659 65e 661 666 667 66c 671
672 674 679 67a 67c 67d 682 685
68a 68b 690 693 697 69b 6a0 6a3
6a7 6a8 6ad 6b0 6b5 6b6 6bb 6c0
6c1 6c3 6c8 6c9 6cb 6cc 6d1 6d4
6d9 6da 6df 6e2 6e6 6ea 6ee 6ef
6f1 6f6 6f7 6f9 6fa 6ff 702 707
708 70d 710 715 716 71b 71e 722
723 728 72b 730 731 736 739 73e
73f 744 745 74a 74c 750 753 757
75b 75e 762 766 769 76c 771 774
777 77a 77b 780 781 1 783 788
78c 790 793 798 79d 7a0 7a4 7a5
7aa 7ab 7b0 7b2 7b6 7b9 7bd 7c2
7c6 7ca 7cf 7d3 7d7 7da 7de 7e2
7e6 7ea 7ee 7f2 7f6 7fa 7fe 802
806 80a 80e 812 816 819 81a 81c
81f 822 823 828 82b 82f 833 837
83a 83e 840 844 847 84b 84f 853
857 85b 85f 863 867 86b 86f 873
877 87b 87f 883 887 88b 88f 893
897 89b 89f 8a3 8a7 8ab 8af 8b3
8b7 8bb 8bf 8c3 8c7 8cb 8cf 8d3
8d7 8db 8df 8e3 8e7 8eb 8ef 8f3
8f7 8fb 8ff 903 907 90b 90f 913
917 91b 91f 923 92f 933 937 93a
93e 942 944 948 94c 950 953 957
95b 95d 95e 963 1 967 96b 96f
972 976 97a 97e 982 985 989 98d
990 993 998 99b 99e 9a1 9a2 9a7
9a8 1 9aa 9af 9b3 9b7 9ba 9bf
9c4 9c7 9cb 9cc 9d1 9d4 9d9 9da
9df 9e2 9e7 9e8 9ed 9f0 9f4 9f5
9fa 9fd a02 a03 a08 a0b a0f a13
a16 a19 a1a a1c a1d a22 a23 a28
a2a a2e a31 a33 a37 a39 a45 a47
a49 a4a a4f a53 a55 a61 a63 a67
a6b a6e a72 a75 a79 a7c a7d a82
a85 a89 a8d a90 a94 a98 a9b a9e
aa3 aa6 aa9 aac aad ab2 ab3 1
ab5 aba abe ac2 ac5 aca acf ad2
ad6 ad7 adc adf ae4 ae5 aea aed
af2 af3 af8 afb aff b03 b07 b0b
b0e b0f b11 b16 b17 b19 b1a b1f
b22 b27 b28 b2d b30 b35 b36 b3b
b3e b42 b43 b48 b4b b50 b51 b56
b57 b5c b5e b62 b65 b69 b6d b70
b74 b78 b7b b7e b83 b86 b89 b8c
b8d b92 b93 1 b95 b9a b9e ba2
ba5 baa baf bb2 bb6 bb7 bbc bbd
bc2 bc4 bc8 bcb bcf bd3 bd6 bda
bde be1 be5 be9 bea bef bf1 bf5
bf8 bfc c00 c04 c08 c0c c10 c14
c20 c24 c28 c2b c2f c33 c35 c39
c3d c41 c44 c48 c4c c4e c4f c54
1 c58 c5c c60 c63 c67 c6b c6f
c73 c76 c7a c7e c81 c84 c89 c8c
c8f c92 c93 c98 c99 1 c9b ca0
ca4 ca8 cab cb0 cb5 cb8 cbc cbd
cc2 cc5 cca ccb cd0 cd3 cd8 cd9
cde ce1 ce5 ce6 ceb cee cf3 cf4
cf9 cfc d00 d04 d07 d0a d0b d0d
d0e d13 d14 d19 d1b d1f d22 d24
d28 d2a d36 d38 d3a d3b d40 d44
d46 d52 d54 d58 d5c d5f d62 d63
d65 d68 d6d d6e d73 d77 d7b d7e
d82 d86 d89 d8c d91 d94 d97 d9a
d9b da0 da1 1 da3 da8 dac db0
db3 db8 dbd dc0 dc4 dc5 dca dcd
dd2 dd3 dd8 ddb de0 de1 de6 de9
ded df1 df5 df9 dfc dfd dff e04
e05 e07 e08 e0d e10 e15 e16 e1b
e1e e23 e24 e29 e2c e30 e31 e36
e39 e3e e3f e44 e45 e4a e4c e50
e53 e57 e5b e5e e62 e66 e69 e6c
e71 e74 e77 e7a e7b e80 e81 1
e83 e88 e8c e90 e93 e98 e9d ea0
ea4 ea5 eaa eab eb0 eb2 eb6 eb9
ebd ec1 ec4 ec8 ecc ecf ed3 ed7
ed8 edd edf ee3 ee6 eea eee ef1
ef2 ef4 ef7 efa efb f00 f04 f08
f0b f0f f13 f16 f19 f1e f21 f24
f27 f28 f2d f2e 1 f30 f35 f39
f3d f40 f45 f4a f4d f51 f52 f57
f5a f5f f60 f65 f68 f6d f6e f73
f76 f7a f7e f82 f86 f89 f8a f8c
f91 f92 f94 f95 f9a f9d fa2 fa3
fa8 fab fb0 fb1 fb6 fb9 fbd fbe
fc3 fc6 fcb fcc fd1 fd2 fd7 fd9
fdd fe0 fe4 fe8 feb fef ff3 ff6
ff9 ffe 1001 1004 1007 1008 100d 100e
1 1010 1015 1019 101d 1020 1025 102a
102d 1031 1032 1037 1038 103d 103f 1043
1046 104a 104e 1051 1055 1059 105c 1060
1064 1065 106a 106c 1070 1073 1077 107a
107b 1080 1083 1086 108a 108d 108e 1093
1096 1 1099 109e 10a2 10a6 10a9 10ad
10b1 10b4 10b5 10b7 10ba 10bd 10be 10c3
10c7 10cb 10ce 10d2 10d6 10d9 10dc 10e1
10e4 10e7 10ea 10eb 10f0 10f1 1 10f3
10f8 10fc 1100 1103 1108 110d 1110 1114
1115 111a 111d 1122 1123 1128 112b 1130
1131 1136 1139 113d 1141 1145 1149 114c
114d 114f 1154 1155 1157 1158 115d 1160
1165 1166 116b 116e 1173 1174 1179 117c
1180 1181 1186 1189 118e 118f 1194 1195
119a 119c 11a0 11a3 11a7 11ab 11ae 11b2
11b6 11b9 11bc 11c1 11c4 11c7 11ca 11cb
11d0 11d1 1 11d3 11d8 11dc 11e0 11e3
11e8 11ed 11f0 11f4 11f5 11fa 11fb 1200
1202 1206 1209 120d 1211 1214 1218 121c
121f 1223 1227 1228 122d 122f 1233 1236
1238 123c 123f 1243 1244 1248 124c 1250
1254 1258 125c 1260 1264 1268 126c 1270
1274 1278 127c 1280 1284 1290 1294 1298
129b 129f 12a3 12a5 12a9 12ad 12b1 12b4
12b8 12bc 12be 12bf 12c4 1 12c8 12cc
12d0 12d3 12d7 12db 12df 12e3 12e6 12ea
12ee 12f1 12f4 12f9 12fc 12ff 1302 1303
1308 1309 1 130b 1310 1314 1318 131b
1320 1325 1328 132c 132d 1332 1335 133a
133b 1340 1343 1348 1349 134e 1351 1355
1356 135b 135e 1363 1364 1369 136c 1370
1374 1377 137a 137b 137d 137e 1383 1384
1389 138b 138f 1392 1394 1398 139a 13a6
13a8 13aa 13ab 13b0 13b4 13b6 13c2 13c4
13c8 13cc 13d0 13d4 13d8 13db 13df 13e3
13e4 13e6 13e9 13ec 13ed 13f2 13f5 13f9
13fd 1400 1401 1403 1407 140a 140e 1411
1412 1417 1 141a 141f 1423 1428 142c
1430 1433 1437 143b 143f 1443 1446 144a
144e 1452 1456 145a 145e 1462 1465 1466
1468 146c 1470 1474 1477 147b 147f 1483
1488 148c 1490 1493 1497 149b 149f 14a3
14a6 14aa 14ae 14b2 14b6 14ba 14be 14c2
14c5 14c6 14c8 14cc 14d0 14d4 14d7 14db
14df 14e1 14e5 14e8 14ec 14ef 14f0 14f5
14f8 14fb 14ff 1503 1506 150a 150e 1511
1512 1514 1517 151a 151b 1520 1 1523
1528 152c 1530 1534 1536 153a 153d 1541
1544 1545 154a 154d 1550 1554 1557 1558
155d 1560 1 1563 1568 156c 1570 1574
1578 157c 1580 1584 1588 1594 1598 159d
15a1 15a4 15a5 15aa 15ae 15b2 15b5 15b8
15bc 15be 15c2 15c6 15c9 15cc 15d0 15d2
15d6 15da 15dd 15df 15e3 15e7 15eb 15ee
15f2 15f6 15f8 15f9 15fe 1 1602 1606
160a 160d 1611 1615 1619 161d 1620 1624
1628 162b 162e 1633 1636 1639 163c 163d
1642 1643 1 1645 164a 164e 1652 1655
165a 165f 1662 1666 1667 166c 166f 1674
1675 167a 167d 1682 1683 1688 168b 168f
1690 1695 1698 169d 169e 16a3 16a6 16aa
16ae 16b1 16b4 16b5 16b7 16b8 16bd 16be
16c3 16c5 16c9 16cc 16ce 16d2 16d4 16e0
16e2 16e4 16e5 16ea 16ee 16f0 16fc 16fe
1700 1704 1707 1708 170d 1710 1714 1717
1718 171d 1 1720 1725 1729 172d 1731
1735 1739 173d 1749 174d 1752 1756 1759
175a 175f 1763 1767 176a 176d 1771 1773
1777 177b 177e 1781 1785 1787 178b 178f
1792 1794 1798 179c 17a0 17a3 17a7 17ab
17ad 17ae 17b3 1 17b7 17bb 17bf 17c2
17c6 17ca 17ce 17d2 17d5 17d9 17dd 17e0
17e3 17e8 17eb 17ee 17f1 17f2 17f7 17f8
1 17fa 17ff 1803 1807 180a 180f 1814
1817 181b 181c 1821 1824 1829 182a 182f
1832 1837 1838 183d 1840 1844 1845 184a
184d 1852 1853 1858 185b 185f 1863 1866
1869 186a 186c 186d 1872 1873 1878 187a
187e 1881 1883 1887 1889 1895 1897 1899
189a 189f 18a3 18a5 18b1 18b3 18b7 18bb
18be 18c2 18c6 18c9 18ca 18cc 18cf 18d2
18d3 18d8 18dc 18df 18e3 18e5 18e9 18ec
18ee 18f2 18f5 18f9 18fc 18fd 1902 1905
1909 190c 190d 1912 1 1915 191a 191e
1922 1926 192a 192e 1932 193e 1942 1947
194b 194e 194f 1954 1958 195c 195f 1962
1966 1968 196c 1970 1973 1976 197a 197c
1980 1984 1987 1989 198d 1991 1995 1998
199c 19a0 19a2 19a3 19a8 1 19ac 19b0
19b4 19b7 19bb 19bf 19c3 19c7 19ca 19ce
19d2 19d5 19d8 19dd 19e0 19e3 19e6 19e7
19ec 19ed 1 19ef 19f4 19f8 19fc 19ff
1a04 1a09 1a0c 1a10 1a11 1a16 1a19 1a1e
1a1f 1a24 1a27 1a2c 1a2d 1a32 1a35 1a39
1a3a 1a3f 1a42 1a47 1a48 1a4d 1a50 1a54
1a58 1a5b 1a5e 1a5f 1a61 1a62 1a67 1a68
1a6d 1a6f 1a73 1a76 1a78 1a7c 1a7e 1a8a
1a8c 1a8e 1a8f 1a94 1a98 1a9a 1aa6 1aa8
1aac 1ab0 1ab3 1ab7 1abb 1abe 1abf 1ac1
1ac4 1ac7 1ac8 1acd 1ad1 1ad4 1ad8 1ada
1ade 1ae1 1ae3 1ae7 1aea 1aee 1af2 1af5
1af6 1af8 1afb 1afe 1aff 1b04 1b08 1b0b
1b0c 1b11 1b14 1b17 1b1b 1b1f 1b22 1b26
1b2a 1b2d 1b2e 1b30 1b33 1b36 1b37 1b3c
1 1b3f 1b44 1b48 1b4c 1b50 1b52 1b56
1b59 1b5d 1b60 1b61 1b66 1b69 1b6c 1b70
1b73 1b74 1b79 1b7c 1 1b7f 1b84 1b88
1b8c 1b8f 1b93 1b97 1b98 1b9a 1b9d 1ba0
1ba1 1ba6 1 1ba9 1bae 1bb2 1bb6 1bb9
1bbd 1bc1 1bc4 1bc7 1bcc 1bcf 1bd2 1bd5
1bd6 1bdb 1bdc 1 1bde 1be3 1be7 1beb
1bee 1bf3 1bf8 1bfb 1bff 1c00 1c05 1c08
1c0d 1c0e 1c13 1c16 1c1b 1c1c 1c21 1c24
1c28 1c2c 1c30 1c34 1c37 1c38 1c3a 1c3f
1c40 1c42 1c43 1c48 1c4b 1c50 1c51 1c56
1c59 1c5e 1c5f 1c64 1c67 1c6b 1c6c 1c71
1c74 1c79 1c7a 1c7f 1c80 1c85 1c87 1c8b
1c8e 1c92 1c96 1c99 1c9d 1ca1 1ca4 1ca7
1cac 1caf 1cb2 1cb5 1cb6 1cbb 1cbc 1
1cbe 1cc3 1cc7 1ccb 1cce 1cd3 1cd8 1cdb
1cdf 1ce0 1ce5 1ce6 1ceb 1ced 1cf1 1cf4
1cf8 1cfc 1cff 1d03 1d07 1d0a 1d0e 1d12
1d13 1d18 1d1a 1d1e 1d21 1d25 1d28 1d29
1d2e 1d31 1d35 1d38 1d39 1d3e 1d41 1d45
1d49 1d4c 1d50 1d54 1d57 1d5a 1d5f 1d62
1d65 1d68 1d69 1d6e 1d6f 1 1d71 1d76
1d7a 1d7e 1d81 1d86 1d8b 1d8e 1d92 1d93
1d98 1d9b 1da0 1da1 1da6 1da9 1dae 1daf
1db4 1db7 1dbb 1dbf 1dc3 1dc7 1dca 1dcb
1dcd 1dd2 1dd3 1dd5 1dd6 1ddb 1dde 1de3
1de4 1de9 1dec 1df1 1df2 1df7 1dfa 1dfe
1dff 1e04 1e07 1e0c 1e0d 1e12 1e13 1e18
1e1a 1e1e 1e21 1e25 1e29 1e2c 1e30 1e34
1e37 1e3a 1e3f 1e42 1e45 1e48 1e49 1e4e
1e4f 1 1e51 1e56 1e5a 1e5e 1e61 1e66
1e6b 1e6e 1e72 1e73 1e78 1e79 1e7e 1e80
1e84 1e87 1e8b 1e8f 1e92 1e96 1e9a 1e9d
1ea1 1ea5 1ea6 1eab 1ead 1eb1 1eb4 1eb8
1ebc 1ec0 1ec4 1ec8 1ecb 1ecf 1ed3 1ed6
1ed7 1ed9 1edc 1edf 1ee0 1ee5 1ee9 1eea
1eee 1ef2 1ef4 1ef8 1efc 1eff 1f03 1f07
1f0a 1f0b 1f0d 1f10 1f13 1f14 1f19 1f1d
1f21 1f25 1f29 1f2d 1f31 1f35 1f39 1f3d
1f41 1f45 1f49 1f4d 1f51 1f55 1f59 1f65
1f69 1f6d 1f70 1f74 1f78 1f7a 1f7e 1f82
1f86 1f89 1f8d 1f91 1f93 1f94 1f99 1
1f9d 1fa1 1fa5 1fa8 1fac 1fb0 1fb4 1fb8
1fbb 1fbf 1fc3 1fc6 1fc9 1fce 1fd1 1fd4
1fd7 1fd8 1fdd 1fde 1 1fe0 1fe5 1fe9
1fed 1ff0 1ff5 1ffa 1ffd 2001 2002 2007
200a 200f 2010 2015 2018 201d 201e 2023
2026 202a 202b 2030 2033 2038 2039 203e
2041 2045 2049 204c 204f 2050 2052 2053
2058 2059 205e 2060 2064 2067 2069 206d
206f 207b 207d 207f 2080 2085 2089 208b
2097 2099 209d 20a1 20a4 20a8 20ab 20af
20b2 20b3 20b8 20bb 20bf 20c3 20c7 20cb
20cf 20d3 20d7 20db 20df 20eb 20ef 20f3
20f6 20fa 20fe 2100 2104 2108 210c 210f
2113 2117 2119 211a 211f 1 2123 2127
212b 212e 2132 2136 213a 213e 2141 2145
2149 214c 214f 2154 2157 215a 215d 215e
2163 2164 1 2166 216b 216f 2173 2176
217b 2180 2183 2187 2188 218d 2190 2195
2196 219b 219e 21a3 21a4 21a9 21ac 21b0
21b1 21b6 21b9 21be 21bf 21c4 21c7 21cb
21cf 21d2 21d5 21d6 21d8 21d9 21de 21df
21e4 21e6 21ea 21ed 21ef 21f3 21f5 2201
2203 2205 2206 220b 220f 2211 221d 221f
2221 2225 2228 222c 222e 2232 2236 2239
223a 223f 2242 2246 224a 224d 2251 2255
2258 225b 2260 2263 2266 2269 226a 226f
2270 1 2272 2277 227b 227f 2282 2287
228c 228f 2293 2294 2299 229c 22a1 22a2
22a7 22aa 22af 22b0 22b5 22b8 22bc 22c0
22c3 22c4 22c6 22cb 22cc 22ce 22cf 22d4
22d7 22dc 22dd 22e2 22e5 22ea 22eb 22f0
22f3 22f7 22f8 22fd 2300 2305 2306 230b
230c 2311 2313 2317 231a 231e 2322 2325
2329 232d 2330 2333 2338 233b 233e 2341
2342 2347 2348 1 234a 234f 2353 2357
235a 235f 2364 2367 236b 236c 2371 2372
2377 2379 237d 2380 2384 2388 238b 238e
2392 2396 2397 239c 239e 23a2 23a6 23a9
23ab 23af 23b2 23b6 23ba 23bb 23bf 23c1
23c5 23c9 23cc 23d0 23d3 23d4 23d9 23dc
23e0 23e3 23e4 23e9 23ec 23ef 23f3 23f7
23fa 23fe 2402 2405 2406 2408 240b 240e
240f 2414 1 2417 241c 2420 2424 2427
242b 242f 2432 2435 243a 243d 2440 2443
2444 2449 244a 1 244c 2451 2455 2459
245c 2461 2466 2469 246d 246e 2473 2476
247b 247c 2481 2484 2489 248a 248f 2492
2496 249a 249e 24a2 24a5 24a6 24a8 24ad
24ae 24b0 24b1 24b6 24b9 24be 24bf 24c4
24c7 24cc 24cd 24d2 24d5 24d9 24da 24df
24e2 24e7 24e8 24ed 24ee 24f3 24f5 24f9
24fc 2500 2504 2507 250b 250f 2512 2515
251a 251d 2520 2523 2524 2529 252a 1
252c 2531 2535 2539 253c 2541 2546 2549
254d 254e 2553 2554 2559 255b 255f 2562
2566 256a 256d 2571 2575 2578 257c 2580
2581 2586 258a 258c 2590 2593 2594 2599
259c 259f 25a3 25a7 25aa 25ae 25b2 25b5
25b6 25b8 25bb 25be 25bf 25c4 1 25c7
25cc 25d0 25d4 25d7 25db 25df 25e2 25e5
25ea 25ed 25f0 25f3 25f4 25f9 25fa 1
25fc 2601 2605 2609 260c 2611 2616 2619
261d 261e 2623 2626 262b 262c 2631 2634
2639 263a 263f 2642 2646 264a 264e 2652
2655 2656 2658 265d 265e 2660 2661 2666
2667 266c 266e 2672 2675 2679 267d 2680
2684 2688 268b 268e 2693 2696 2699 269c
269d 26a2 26a3 1 26a5 26aa 26ae 26b2
26b5 26ba 26bf 26c2 26c6 26c7 26cc 26cd
26d2 26d4 26d8 26db 26df 26e3 26e6 26ea
26ee 26f1 26f5 26f6 26fb 26fd 2701 2705
2708 270c 270f 2710 2715 2718 271b 271f
2723 2726 272a 272e 2731 2732 2734 2737
273a 273b 2740 1 2743 2748 274c 274f
2753 2755 2759 275c 2760 2762 2766 276a
276d 2771 2775 2778 277c 2780 2783 2784
2786 2789 278c 278d 2792 2796 2797 279b
279f 27a1 27a5 27a9 27ac 27b0 27b4 27b5
27b7 27ba 27bd 27be 27c3 27c7 27cb 27cf
27d3 27d7 27db 27df 27e3 27e7 27eb 27ef
27f3 27f7 27fb 27ff 2803 280f 2813 2817
281a 281e 2822 2824 2828 282c 2830 2833
2837 283b 283d 283e 2843 1 2847 284b
284f 2852 2856 285a 285e 2862 2865 2869
286d 2870 2873 2878 287b 287e 2881 2882
2887 2888 1 288a 288f 2893 2897 289a
289f 28a4 28a7 28ab 28ac 28b1 28b4 28b9
28ba 28bf 28c2 28c7 28c8 28cd 28d0 28d4
28d5 28da 28dd 28e2 28e3 28e8 28eb 28ef
28f3 28f6 28f9 28fa 28fc 28fd 2902 2903
2908 290a 290e 2911 2913 2917 2919 2925
2927 2929 292a 292f 2933 2935 2941 2943
2947 294b 294e 2952 2955 2959 295c 295d
2962 2965 2969 296d 2971 2975 2979 297d
2981 2985 2989 2995 2999 299d 29a0 29a4
29a8 29aa 29ae 29b2 29b6 29b9 29bd 29c1
29c3 29c4 29c9 1 29cd 29d1 29d5 29d8
29dc 29e0 29e4 29e8 29eb 29ef 29f3 29f6
29f9 29fe 2a01 2a04 2a07 2a08 2a0d 2a0e
1 2a10 2a15 2a19 2a1d 2a20 2a25 2a2a
2a2d 2a31 2a32 2a37 2a3a 2a3f 2a40 2a45
2a48 2a4d 2a4e 2a53 2a56 2a5a 2a5b 2a60
2a63 2a68 2a69 2a6e 2a71 2a75 2a79 2a7c
2a7f 2a80 2a82 2a83 2a88 2a89 2a8e 2a90
2a94 2a97 2a99 2a9d 2a9f 2aab 2aad 2aaf
2ab0 2ab5 2ab9 2abb 2ac7 2ac9 2acb 2acf
2ad2 2ad6 2ad8 2adc 2ae0 2ae4 2ae7 2aeb
2aef 2af2 2af3 2af5 2af8 2afb 2afc 2b01
2b05 2b09 2b0c 2b10 2b14 2b17 2b1a 2b1f
2b22 2b25 2b28 2b29 2b2e 2b2f 1 2b31
2b36 2b3a 2b3e 2b41 2b46 2b4b 2b4e 2b52
2b53 2b58 2b5b 2b60 2b61 2b66 2b69 2b6e
2b6f 2b74 2b77 2b7b 2b7f 2b82 2b83 2b85
2b8a 2b8b 2b8d 2b8e 2b93 2b96 2b9b 2b9c
2ba1 2ba4 2ba9 2baa 2baf 2bb2 2bb6 2bb7
2bbc 2bbf 2bc4 2bc5 2bca 2bcb 2bd0 2bd2
2bd6 2bd9 2bdd 2be1 2be4 2be8 2bec 2bef
2bf2 2bf7 2bfa 2bfd 2c00 2c01 2c06 2c07
1 2c09 2c0e 2c12 2c16 2c19 2c1e 2c23
2c26 2c2a 2c2b 2c30 2c31 2c36 2c38 2c3c
2c3f 2c43 2c47 2c4a 2c4d 2c51 2c55 2c56
2c5b 2c5d 2c61 2c65 2c68 2c6a 2c6e 2c6f
2c73 2c75 2c79 2c7d 2c80 2c84 2c88 2c8c
2c90 2c93 2c97 2c9b 2c9f 2ca2 2ca3 2ca5
2ca9 2cac 2cb0 2cb3 2cb4 2cb9 2cbd 2cc1
2cc5 2cc9 2ccd 2cd1 2cd5 2cd9 2ce5 2ce9
2cee 2cf2 2cf5 2cf6 2cfb 2cff 2d03 2d06
2d09 2d0d 2d0f 2d13 2d17 2d1a 2d1d 2d21
2d23 2d27 2d2b 2d2e 2d30 2d34 2d38 2d3c
2d3f 2d43 2d47 2d49 2d4a 2d4f 1 2d53
2d57 2d5b 2d5e 2d62 2d66 2d6a 2d6e 2d71
2d75 2d79 2d7c 2d7f 2d84 2d87 2d8a 2d8d
2d8e 2d93 2d94 1 2d96 2d9b 2d9f 2da3
2da6 2dab 2db0 2db3 2db7 2db8 2dbd 2dc0
2dc5 2dc6 2dcb 2dce 2dd3 2dd4 2dd9 2ddc
2de0 2de1 2de6 2de9 2dee 2def 2df4 2df7
2dfb 2dff 2e02 2e05 2e06 2e08 2e09 2e0e
2e0f 2e14 2e16 2e1a 2e1d 2e1f 2e23 2e25
2e31 2e33 2e35 2e36 2e3b 2e3f 2e41 2e4d
2e4f 2e51 2e55 2e58 2e59 2e5e 2e61 2e65
2e68 2e69 2e6e 2e71 2e75 2e78 2e7c 2e80
2e84 2e88 2e8c 2e90 2e94 2e98 2e9c 2ea0
2ea4 2ea8 2eac 2eb0 2eb4 2eb8 2ec4 2ec8
2ecc 2ecf 2ed3 2ed7 2ed9 2edd 2ee1 2ee5
2ee8 2eec 2ef0 2ef2 2ef3 2ef8 1 2efc
2f00 2f04 2f07 2f0b 2f0f 2f13 2f17 2f1a
2f1e 2f22 2f25 2f28 2f2d 2f30 2f33 2f36
2f37 2f3c 2f3d 1 2f3f 2f44 2f48 2f4c
2f4f 2f54 2f59 2f5c 2f60 2f61 2f66 2f69
2f6e 2f6f 2f74 2f77 2f7c 2f7d 2f82 2f85
2f89 2f8a 2f8f 2f92 2f97 2f98 2f9d 2fa0
2fa4 2fa8 2fab 2fae 2faf 2fb1 2fb2 2fb7
2fb8 2fbd 2fbf 2fc3 2fc6 2fc8 2fcc 2fce
2fda 2fdc 2fde 2fdf 2fe4 2fe8 2fea 2ff6
2ff8 2ffc 3000 3003 3004 3006 3009 300c
300d 3012 3016 301a 301d 3021 3025 3028
302b 3030 3033 3036 3039 303a 303f 3040
1 3042 3047 304b 304f 3052 3057 305c
305f 3063 3064 3069 306c 3071 3072 3077
307a 307f 3080 3085 3088 308c 3090 3094
3098 309b 309c 309e 30a3 30a4 30a6 30a7
30ac 30af 30b4 30b5 30ba 30bd 30c2 30c3
30c8 30cb 30cf 30d0 30d5 30d8 30dd 30de
30e3 30e4 30e9 30eb 30ef 30f2 30f6 30fa
30fd 3101 3105 3108 310b 3110 3113 3116
3119 311a 311f 3120 1 3122 3127 312b
312f 3132 3137 313c 313f 3143 3144 3149
314a 314f 3151 3155 3158 315c 3160 3163
3167 316b 316e 3172 3176 3177 317c 317e
3182 3185 3189 318b 318f 3192 3193 3198
319b 319f 31a2 31a6 31aa 31ae 31b2 31b6
31ba 31be 31c2 31c6 31ca 31ce 31d2 31d6
31da 31de 31e2 31ee 31f2 31f6 31f9 31fd
3201 3203 3207 320b 320f 3212 3216 321a
321c 321d 3222 1 3226 322a 322e 3231
3235 3239 323d 3241 3244 3248 324c 324f
3252 3257 325a 325d 3260 3261 3266 3267
1 3269 326e 3272 3276 3279 327e 3283
3286 328a 328b 3290 3293 3298 3299 329e
32a1 32a6 32a7 32ac 32af 32b3 32b4 32b9
32bc 32c1 32c2 32c7 32ca 32ce 32d2 32d5
32d8 32d9 32db 32dc 32e1 32e2 32e7 32e9
32ed 32f0 32f2 32f6 32f8 3304 3306 3308
3309 330e 3312 3314 3320 3322 3326 332a
332d 332e 3330 3333 3336 3337 333c 3340
3344 3347 334b 334f 3352 3355 335a 335d
3360 3363 3364 3369 336a 1 336c 3371
3375 3379 337c 3381 3386 3389 338d 338e
3393 3396 339b 339c 33a1 33a4 33a9 33aa
33af 33b2 33b6 33ba 33be 33c2 33c5 33c6
33c8 33cd 33ce 33d0 33d1 33d6 33d9 33de
33df 33e4 33e7 33ec 33ed 33f2 33f5 33f9
33fa 33ff 3402 3407 3408 340d 340e 3413
3415 3419 341c 3420 3424 3427 342b 342f
3432 3435 343a 343d 3440 3443 3444 3449
344a 1 344c 3451 3455 3459 345c 3461
3466 3469 346d 346e 3473 3474 3479 347b
347f 3482 3486 348a 348d 3491 3495 3498
349c 34a0 34a1 34a6 34a8 34ac 34b0 34b4
34b8 34bc 34c0 34c4 34c8 34cc 34d0 34d4
34d8 34e4 34e8 34ec 34ef 34f3 34f7 34f9
34fd 3501 3505 3508 350c 3510 3512 3513
3518 1 351c 3520 3524 3527 352b 352f
3533 3537 353a 353e 3542 3545 3548 354d
3550 3553 3556 3557 355c 355d 1 355f
3564 3568 356c 356f 3574 3579 357c 3580
3581 3586 3589 358e 358f 3594 3597 359c
359d 35a2 35a5 35a9 35aa 35af 35b2 35b7
35b8 35bd 35c0 35c4 35c8 35cb 35ce 35cf
35d1 35d2 35d7 35d8 35dd 35df 35e3 35e6
35e8 35ec 35ee 35fa 35fc 35fe 35ff 3604
3608 360a 3616 3618 361c 3620 3623 3624
3626 362a 362d 3631 3634 3635 3637 3638
363d 3641 3645 3648 364c 3650 3653 3656
365b 365e 3661 3664 3665 366a 366b 1
366d 3672 3676 367a 367d 3682 3687 368a
368e 368f 3694 3697 369c 369d 36a2 36a5
36aa 36ab 36b0 36b3 36b7 36bb 36bf 36c3
36c6 36c7 36c9 36ce 36cf 36d1 36d2 36d7
36da 36df 36e0 36e5 36e8 36ed 36ee 36f3
36f6 36fa 36fb 3700 3703 3708 3709 370e
370f 3714 3716 371a 371d 3721 3725 3728
372c 3730 3733 3736 373b 373e 3741 3744
3745 374a 374b 1 374d 3752 3756 375a
375d 3762 3767 376a 376e 376f 3774 3775
377a 377c 3780 3783 3787 378b 378e 3792
3796 3799 379d 37a1 37a2 37a7 37a9 37ad
37b0 37b2 37b6 37ba 37bd 37bf 37c3 37c7
37cb 37ce 37d2 37d6 37d9 37dc 37e1 37e4
37e7 37ea 37eb 37f0 37f1 1 37f3 37f8
37fc 3800 3803 3808 380d 3810 3814 3815
381a 381d 3822 3823 3828 382b 3830 3831
3836 3839 383d 3841 3845 3849 384c 384d
384f 3854 3855 3857 3858 385d 3860 3865
3866 386b 386e 3873 3874 3879 387c 3880
3881 3886 3889 388e 388f 3894 3895 389a
389c 38a0 38a3 38a7 38ab 38ae 38b2 38b6
38b9 38bc 38c1 38c4 38c7 38ca 38cb 38d0
38d1 1 38d3 38d8 38dc 38e0 38e3 38e8
38ed 38f0 38f4 38f5 38fa 38fb 3900 3902
3906 3909 390d 3911 3914 3918 391c 391f
3923 3927 3928 392d 392f 3933 3937 393a
393c 3940 3943 3947 394a 394e 3952 3956
395a 395e 3961 3962 3967 396a 396e 3971
3972 3977 397a 1 397d 3982 3986 398a
398e 3990 3994 3997 399b 399f 39a3 39a7
39ab 39af 39b3 39b7 39bb 39bf 39c3 39c7
39cb 39cf 39d3 39d7 39db 39df 39e3 39e7
39eb 39ef 39f3 39f7 39fa 39fb 39fd 3a01
3a05 3a08 3a0c 3a10 3a14 3a18 3a1c 3a20
3a23 3a26 3a29 3a2a 3a2c 3a30 3a34 3a37
3a38 3a3d 3a40 3a44 3a47 3a4b 3a4f 3a53
3a57 3a5b 3a5f 3a62 3a65 3a68 3a69 3a6b
3a6f 3a71 3a75 3a78 3a7a 3a7e 3a82 3a85
3a87 3a8b 3a8e 3a90 3a94 3a98 3a9b 3a9f
3aa3 3aa6 3aaa 3aae 3aaf 3ab1 3ab4 3ab7
3ab8 3abd 3ac0 3ac4 3ac8 3acb 3acc 3ace
3ad2 3ad5 3ad9 3adc 3add 3ae2 1 3ae5
3aea 3aee 3af3 3af7 3afb 3afe 3b02 3b06
3b0a 3b0e 3b11 3b15 3b19 3b1d 3b21 3b25
3b29 3b2d 3b30 3b31 3b33 3b37 3b3b 3b3f
3b42 3b46 3b4a 3b4e 3b53 3b57 3b5b 3b5e
3b62 3b66 3b6a 3b6e 3b71 3b75 3b79 3b7d
3b81 3b85 3b89 3b8d 3b90 3b91 3b93 3b97
3b9b 3b9f 3ba2 3ba6 3baa 3bac 3bb0 3bb3
3bb7 3bbb 3bbf 3bc0 3bc2 3bc6 3bca 3bce
3bd1 3bd5 3bd9 3bdc 3bdf 3be4 3be7 3bea
3bed 3bee 3bf3 3bf4 1 3bf6 3bfb 3bff
3c03 3c06 3c0b 3c10 3c13 3c17 3c18 3c1d
3c20 3c25 3c26 3c2b 3c2e 3c33 3c34 3c39
3c3c 3c40 3c44 3c48 3c4c 3c4f 3c50 3c52
3c57 3c58 3c5a 3c5b 3c60 3c63 3c68 3c69
3c6e 3c71 3c76 3c77 3c7c 3c7f 3c83 3c84
3c89 3c8c 3c91 3c92 3c97 3c98 3c9d 3c9f
3ca3 3ca6 3caa 3cae 3cb1 3cb5 3cb9 3cbc
3cc0 3cc4 3cc5 3cca 3ccc 3cd0 3cd4 3cd7
3cdb 3cdf 3ce2 3ce6 3cea 3ced 3cf0 3cf5
3cf8 3cfb 3cfe 3cff 3d04 3d05 1 3d07
3d0c 3d10 3d14 3d17 3d1c 3d21 3d24 3d28
3d29 3d2e 3d2f 3d34 3d38 3d3c 3d3f 3d44
3d49 3d4c 3d50 3d54 3d57 3d58 3d5d 3d60
3d65 3d66 3d6b 3d6e 3d72 3d76 3d79 3d7a
3d7f 3d80 3d85 3d87 3d8b 3d8e 3d92 3d96
3d9a 3d9e 3da2 3da6 3daa 3dae 3db2 3dbe
3dc3 3dc7 3dcb 3dcf 3dd3 3dd5 3dd6 3ddb
1 3ddf 3de3 3de7 3dea 3dee 3df2 3df6
3dfa 3dfd 3e01 3e05 3e08 3e0b 3e10 3e13
3e16 3e19 3e1a 3e1f 3e20 1 3e22 3e27
3e2b 3e2f 3e32 3e37 3e3c 3e3f 3e43 3e44
3e49 3e4a 3e4f 3e53 3e57 3e5a 3e5f 3e64
3e67 3e6b 3e6c 3e71 3e74 3e79 3e7a 3e7f
3e82 3e86 3e8a 3e8d 3e90 3e91 3e93 3e94
3e99 3e9a 3e9f 3ea1 3ea5 3ea8 3eac 3eb0
3eb4 3eb8 3ebc 3ec0 3ec4 3ed0 3ed5 3ed9
3edd 3ee1 3ee5 3ee7 3eeb 3eed 3ef9 3efb
3efd 3efe 3f03 3f07 3f09 3f15 3f19 3f1b
3f1c 3f25 
121a
2
0 1 a 6 c :3 6 14 :3 6
15 :3 6 16 :3 6 12 :2 6 1 3
a 13 a :2 1 4 11 1a 19
:2 11 :2 4 11 1a 19 :2 11 :2 4 e
17 16 :2 e :2 4 18 21 20 :2 18
:2 4 18 21 20 :2 18 :2 4 18 21
20 :2 18 :2 4 d 16 15 :2 d :2 4
f 18 17 :2 f :2 4 12 1b 1a
:2 12 :2 4 :3 11 :2 4 :3 12 :2 4 :3 f :2 4
:3 10 :2 4 :3 15 :2 4 :3 16 :2 4 :3 13 :2 4
b 14 13 :2 b :2 4 :2 13 22 13
:2 4 :2 b 1a b :2 4 :2 f 19 f
:2 4 :2 f 19 f :2 4 :3 12 :2 4 :3 13
:2 4 :3 15 :2 4 :3 19 :2 4 :3 10 :2 4 :3 e
:2 4 f 18 17 :2 f :2 4 :2 f 1e
f :2 4 :2 16 25 16 :2 4 :2 a 19
a :2 4 :2 c 1b c :2 4 :2 11 20
11 :2 4 :2 f 1e f :2 4 :2 d 1c
d :2 4 :2 e 1d e :2 4 :2 e 1d
e :2 4 :2 16 25 16 :2 4 :2 10 1f
10 :2 4 :2 9 18 9 :2 4 :2 f 1e
f :2 4 :2 14 23 14 :2 4 :2 11 20
11 :2 4 f 18 17 :2 f :2 4 :3 10
:2 4 :2 16 2e 16 :2 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 58 5e
61 :2 58 6f 89 8 :2 6f d 10
:2 6f 16 19 :2 6f b e :2 6f 13
16 1f 26 2b 2e :2 26 3c 3f
:2 26 44 :2 1f 4d :2 16 :2 6f b e
:2 6f 13 16 1f 26 2b 2e :2 26
3d 40 :2 26 45 :2 1f 4e :2 16 :2 6f
b e :2 6f 13 16 1f 27 :2 1f
39 :2 16 :2 6f b e :2 6f 13 16
:2 6f 1b 1e :2 6f 2a 2d :2 6f 32
35 :2 6f :2 7 4e :2 4 7 :2 11 23
:2 2d 39 3c 50 52 53 :2 50 :2 23
:3 7 :2 d 12 1e 61 64 :2 1e :2 7
56 :3 4 14 :2 4 15 :2 4 12 :2 4
14 :2 4 15 :2 4 1b :2 4 19 4
8 11 24 :2 8 27 29 :2 27 :2 7
1c :2 25 7 2c :2 4 e 1a 2d
44 52 65 7 10 1f 2d 36
46 55 65 76 7f 8c 99 a8
b5 c3 7 12 22 34 47 51
62 70 c 1a 2f 44 54 64
7 13 20 32 45 50 5a 67
74 7 12 24 33 43 4f 62
6e c d 21 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 57 5a 5b :2 57 :2 29
:3 d :2 13 18 24 68 6b :2 24 78
7b :2 24 7f 82 :2 24 8e 91 :2 24
99 9c :2 24 a8 ab b2 bb be
:2 ab :2 24 :2 d 5e :2 a :2 7 :4 13 :2 7
4 :3 1 8 :2 11 1c 1a :2 25 :2 1a
7 a :2 14 26 :2 30 3c 40 54
57 58 :2 54 :2 26 :3 a :2 10 15 21
65 68 :2 21 75 78 :2 21 7c 7f
:2 21 89 8c 95 9d :2 a6 :2 95 b9
:2 8c :2 21 c1 c4 :2 21 cc cf :2 21
d4 d7 :2 21 dd e0 :2 21 :2 a 5b
:2 7 a :2 14 26 :2 30 3c 3f 53
56 57 :2 53 :2 26 :3 a :2 10 15 21
65 68 :2 21 :2 a 5a :3 7 :2 12 26
:2 2f 41 48 :2 7 35 :2 4 e :2 c
d 1a b 18 :2 7 :2 10 1c 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 57 5a 5b :2 57 :2 29
:3 d :2 13 18 24 68 6b :2 24 78
7b :2 24 7f 82 :2 24 8e 91 :2 24
99 9c :2 24 a8 ab b2 bb be
:2 ab :2 24 :2 d 5e :2 a :2 7 :4 13 :2 7
4 :3 1 7 e 1c 1f :2 7 22
24 :2 22 a :2 14 26 :2 30 3c 40
54 57 58 :2 54 :2 26 :3 a :2 10 15
21 65 68 :2 21 75 78 :2 21 7c
7f :2 21 89 8c 95 9d :2 a6 :2 95
c4 :2 8c :2 21 cc cf :2 21 d7 da
:2 21 df e2 :2 21 e8 eb :2 21 :2 a
5b :2 7 a :2 14 26 :2 30 3c 3f
53 56 57 :2 53 :2 26 :3 a :2 10 15
21 65 68 :2 21 :2 a 5a :3 7 :2 12
26 :2 2f 4c 53 :2 7 28 :2 4 7
10 20 :2 7 23 25 :2 23 a :2 14
26 :2 30 3c 40 54 57 58 :2 54
:2 26 :3 a :2 10 15 21 65 68 :2 21
75 78 :2 21 7c 7f :2 21 89 8c
95 9d :2 a6 :2 95 c2 :2 8c :2 21 ca
cd :2 21 d5 d8 :2 21 dd e0 :2 21
e6 e9 :2 21 :2 a 5b :2 7 a :2 14
26 :2 30 3c 3f 53 56 57 :2 53
:2 26 :3 a :2 10 15 21 65 68 :2 21
:2 a 5a :3 7 :2 12 26 :2 2f 4a 51
:2 7 2b :2 4 :4 9 8 7 :4 2b 2a
29 :2 7 a :2 15 1d 2c 3a :2 a
3e 40 :2 3e d :2 17 29 :2 33 3f
43 57 5a 5b :2 57 :2 29 :3 d :2 13
18 24 68 6b :2 24 78 7b :2 24
7f 82 :2 24 8c 8f 98 a0 :2 a9
:2 98 c6 :2 8f :2 24 ce d1 :2 24 d9
dc :2 24 e1 e4 :2 24 ea ed :2 24
:2 d 5e :2 a d :2 17 29 :2 33 3f
42 56 59 5a :2 56 :2 29 :3 d :2 13
18 24 68 6b :2 24 :2 d 5d :3 a
:2 15 29 :2 32 4e 55 :2 a 42 :2 7
48 :3 4 11 4 e 12 29 38
d 1a 2b 39 b 1d 26 3f
48 61 6a :2 7 :2 10 1c 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 57 5a 5b :2 57 :2 29 :3 d
:2 13 18 24 68 6b :2 24 78 7b
:2 24 7f 82 :2 24 8e 91 :2 24 99
9c :2 24 a8 ab b2 bb be :2 ab
:2 24 :2 d 5e :2 a :2 7 :4 13 :2 7 4
:3 1 4 12 4 8 :2 13 1a 24
:2 8 30 32 :2 30 7 3a a 1d
:2 3a 23 20 :2 2c :2 20 39 :3 7 15
:2 7 17 :2 7 1c :2 25 :2 7 16 25
31 46 52 60 :2 16 :2 7 :2 10 1c
:2 7 15 :2 7 17 :2 7 1c :2 25 :2 7
16 25 31 46 52 60 :2 16 :2 7
:2 10 1c 7 47 :2 4 :4 9 8 7
29 :2 34 3c 4a 56 :2 29 5a 5c
:2 5a 28 :3 7 17 7 5f :2 4 :4 9
8 7 :4 27 26 25 :2 7 11 a
1c a 1c a 10 24 a 11
d 19 :3 17 d :2 16 22 d 1e
d :2 16 22 d :4 a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
5a 5d 5e :2 5a :2 2c :3 10 :2 16 1b
27 6b 6e :2 27 7b 7e :2 27 82
85 :2 27 91 94 :2 27 9c 9f :2 27
ab ae b5 be c1 :2 ae :2 27 :2 10
61 :2 d :2 a :4 16 :2 a 7 :4 40 :4 b
a :4 27 26 :2 a 14 d 1f d
13 27 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 5d 60 61 :2 5d
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 94 97
:2 2a 9f a2 :2 2a ae b1 b8 c1
c4 :2 b1 :2 2a :2 13 64 :2 10 :2 d :4 19
:2 d a :3 45 d :2 18 20 2f 42
:2 d 46 48 :2 46 d 1b d 4a
:2 a 45 :2 7 :4 b a :4 28 27 :2 a
14 d 1f d 13 27 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
5d 60 61 :2 5d :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 94 97 :2 2a 9f a2 :2 2a
ae b1 b8 c1 c4 :2 b1 :2 2a :2 13
64 :2 10 :2 d :4 19 :2 d a :3 47 d
:2 18 20 2e 40 :2 d 44 46 :2 44
d 1b d 48 :2 a 47 :2 7 a
13 1f :2 a 22 24 :2 22 :4 f e
d 30 :2 3b 43 52 5f :2 30 63
65 :2 63 2f :3 d 1e d 68 :2 a
:4 f e d :4 2d 2c 2b :2 d 4e
:2 59 60 12 :2 4e 21 23 :2 21 4d
:2 d 10 :2 1a 2c :2 36 42 46 5a
5d 5e :2 5a :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 7b 7e :2 27 82 85
:2 27 8f 92 9b a3 :2 ac :2 9b c7
:2 92 :2 27 cf d2 :2 27 da dd :2 27
e2 e5 :2 27 ee f1 :2 27 :2 10 61
:2 d 10 :2 1a 2c :2 36 42 45 59
5c 5d :2 59 :2 2c :3 10 :2 16 1b 27
6b 6e :2 27 :2 10 60 :3 d :2 18 2c
:2 35 4f 59 :2 d 26 :2 a :4 e d
:4 11 10 13 :2 1d 2f :2 39 45 49
5d 60 61 :2 5d :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a 7e 81 :2 2a 85
88 :2 2a 92 95 9e a6 :2 af :2 9e
ca :2 95 :2 2a d2 d5 :2 2a dd e0
:2 2a e5 e8 :2 2a ee f1 :2 2a :2 13
64 :2 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 :2 1b
2f :2 38 52 59 :2 10 2d :3 d 19
d 10 :2 1b 23 31 40 :2 10 44
46 :2 44 10 20 10 d 48 13
:2 1e 26 34 40 :2 13 44 47 :2 44
1a 25 32 3c 47 4c 55 66
78 18 19 26 17 22 2a 31
:2 13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 63
66 67 :2 63 :2 35 :3 19 :2 1f 24 30
74 77 :2 30 84 87 :2 30 8b 8e
:2 30 9a 9d :2 30 a5 a8 :2 30 b4
b7 be c7 ca :2 b7 :2 30 :2 19 6a
:2 16 :2 13 :4 1f :2 13 10 :3 49 14 :2 1d
28 26 :2 31 :2 26 13 1f 2a 37
3f 46 5e 69 80 92 :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :4 41 :2 10 d 49 48
:4 14 :2 13 :2 1d 2f :2 39 45 49 5d
60 61 :2 5d :2 2f :3 13 :2 19 1e 2a
6e 71 :2 2a 7e 81 :2 2a 85 88
:2 2a 92 95 9e a6 :2 9e aa :2 95
:2 2a b2 b5 :2 2a bd c0 :2 2a c5
c8 :2 2a ce d1 :2 2a :2 13 64 :2 10
13 :2 1d 2f :2 39 45 48 5c 5f
60 :2 5c :2 2f :3 13 :2 19 1e 2a 6e
71 :2 2a :2 13 63 :3 10 :2 1b 2f 32
39 :2 10 2c 48 :2 d 29 d 19
:2 d 1d d :4 a :4 e d :4 12 11
10 2f :2 3a 42 51 60 :2 2f 64
66 :2 64 2e :2 10 13 :2 1d 2f :2 39
45 49 5d 60 61 :2 5d :2 2f :3 13
:2 19 1e 2a 6e 71 :2 2a 7e 81
:2 2a 85 88 :2 2a 92 95 9e a6
:2 af :2 9e c0 :2 95 :2 2a c8 cb :2 2a
d3 d6 :2 2a db de :2 2a e4 e7
:2 2a :2 13 64 :2 10 13 :2 1d 2f :2 39
45 48 5c 5f 60 :2 5c :2 2f :3 13
:2 19 1e 2a 6e 71 :2 2a :2 13 63
:3 10 :2 1b 2f :2 38 48 4f :2 10 d
69 :4 15 14 13 39 :2 44 4c 5b
15 :2 39 19 1c :2 19 38 :3 13 :2 1d
2f :2 39 45 48 5c 5f 60 :2 5c
:2 2f :3 13 :2 19 1e 2a 6e 71 :2 2a
7e 81 :2 2a 85 88 :2 2a 92 95
9e a6 :2 af :2 9e ca :2 95 :2 2a :2 13
63 :2 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 :2 1b
31 :2 3a 54 :2 10 1f 69 :2 d :4 12
11 10 2f :2 3a 42 51 5e :2 2f
62 64 :2 62 2e :3 10 18 10 67
10 18 10 :4 d 10 :2 1b 23 32
42 :2 10 46 48 :2 46 10 21 10
d 4a 13 :2 1e 25 34 :2 13 41
44 :2 41 1a 25 32 3c 47 4c
55 65 77 18 19 26 17 22
2a 31 :2 13 :2 1c 28 13 10 18
16 :2 1f 2b 16 26 :2 13 :2 18 16
:2 1f 2b 16 19 :2 23 35 :2 3f 4b
4f 63 66 67 :2 63 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 84 87 :2 30
8b 8e :2 30 9a 9d :2 30 a5 a8
:2 30 b4 b7 be c7 ca :2 b7 :2 30
:2 19 6a :2 16 :2 13 :4 1f :2 13 10 :3 46
14 :2 1d 28 26 :2 31 :2 26 13 1f
2a 37 3f 46 5f 6a 81 94
:2 16 :2 1f 2b 16 13 1b 19 :2 22
2e 19 29 :2 16 :2 1b 19 :2 22 2e
19 1c :2 26 38 :2 42 4e 52 66
69 6a :2 66 :2 38 :3 1c :2 22 27 33
77 7a :2 33 87 8a :2 33 8e 91
:2 33 9d a0 :2 33 a8 ab :2 33 b7
ba c1 ca cd :2 ba :2 33 :2 1c 6d
:2 19 :2 16 :4 22 :2 16 13 :4 41 :2 10 d
46 4a 13 :2 1e 26 35 44 :2 13
48 4a :2 48 13 :2 1d 2f :2 39 45
49 5d 60 61 :2 5d :2 2f :3 13 :2 19
1e 2a 6e 71 :2 2a 7e 81 :2 2a
85 88 :2 2a 92 95 9e a6 :2 9e
aa :2 95 :2 2a b2 b5 :2 2a bd c0
:2 2a c5 c8 :2 2a ce d1 :2 2a :2 13
64 :2 10 13 :2 1d 2f :2 39 45 48
5c 5f 60 :2 5c :2 2f :3 13 :2 19 1e
2a 6e 71 :2 2a :2 13 63 :3 10 :2 1b
2f 32 39 :2 10 4c 4a :2 d 2a
d 1e d :5 a 18 :2 a 18 a
d 16 29 :2 d 2f 2c :2 38 :2 2c
17 10 22 10 22 10 16 2a
10 17 13 1f :3 1d 13 :2 1c 28
13 24 13 :2 1c 28 13 :4 10 d
15 13 :2 1c 28 13 23 :2 10 :2 15
13 :2 1c 28 13 16 :2 20 32 :2 3c
48 4c 60 63 64 :2 60 :2 32 :3 16
:2 1c 21 2d 71 74 :2 2d 81 84
:2 2d 88 8b :2 2d 97 9a :2 2d a2
a5 :2 2d b1 b4 bb c4 c7 :2 b4
:2 2d :2 16 67 :2 13 :2 10 :4 1c :2 10 d
:4 52 :4 11 10 :4 14 :2 13 21 13 1d
2d 1b 2b 39 1c 29 3c 50
69 7d 1a 25 2d 34 :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :3 30 16 1f 2b :2 16
2e 30 :2 2e 19 :2 23 35 :2 3f 4b
4f 63 66 67 :2 63 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 84 87 :2 30
8b 8e :2 30 98 9b a4 ac :2 b5
:2 a4 d4 :2 9b :2 30 dc df :2 30 e7
ea :2 30 ef f2 :2 30 106 109 :2 30
:2 19 6a :2 16 19 :2 23 35 :2 3f 4b
4e 62 65 66 :2 62 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 :2 19 69 :3 16
:2 21 35 :2 3e 5c 1e :2 16 32 :2 13
10 30 :4 17 16 13 21 13 1d
2d 1b 2b 39 1c 29 3c 50
69 7d 1a 25 2d 34 :2 16 :2 1f
2b 16 13 1b 19 :2 22 2e 19
29 :2 16 :2 1b 19 :2 22 2e 19 1c
:2 26 38 :2 42 4e 52 66 69 6a
:2 66 :2 38 :3 1c :2 22 27 33 77 7a
:2 33 87 8a :2 33 8e 91 :2 33 9d
a0 :2 33 a8 ab :2 33 b7 ba c1
ca cd :2 ba :2 33 :2 1c 6d :2 19 :2 16
:4 22 :2 16 13 :3 32 16 1f 2b :2 16
2e 30 :2 2e 19 :2 23 35 :2 3f 4b
4f 63 66 67 :2 63 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 84 87 :2 30
8b 8e :2 30 98 9b a4 ac :2 b5
:2 a4 d4 :2 9b :2 30 dc df :2 30 e7
ea :2 30 ef f2 :2 30 106 109 :2 30
:2 19 6a :2 16 19 :2 23 35 :2 3f 4b
4e 62 65 66 :2 62 :2 35 :3 19 :2 1f
24 30 74 77 :2 30 :2 19 69 :3 16
:2 21 35 :2 3e 5c 1e :2 16 32 20
24 34 41 1f 2c 3d 49 61
6d 75 7c :2 19 :2 22 2e 19 16
1e 1c :2 25 31 1c 2c :2 19 :2 1e
1c :2 25 31 1c 1f :2 29 3b :2 45
51 55 69 6c 6d :2 69 :2 3b :3 1f
:2 25 2a 36 7a 7d :2 36 8a 8d
:2 36 91 94 :2 36 a0 a3 :2 36 ab
ae :2 36 ba bd c4 cd d0 :2 bd
:2 36 :2 1f 70 :2 1c :2 19 :4 25 :2 19 16
:3 13 19 22 2b :2 19 30 2e 39
40 :2 30 :2 2e 1c :2 26 38 :2 42 4e
52 66 69 6a :2 66 :2 38 :3 1c :2 22
27 33 77 7a :2 33 87 8a :2 33
8e 91 :2 33 9b 9e a7 af :2 b8
:2 a7 d7 :2 9e :2 33 df e2 :2 33 ea
ed :2 33 f2 f5 :2 33 109 10c :2 33
:2 1c 6d :2 19 1c :2 26 38 :2 42 4e
51 65 68 69 :2 65 :2 38 :3 1c :2 22
27 33 77 7a :2 33 :2 1c 6c :3 19
:2 24 38 :2 41 5f 21 :2 19 43 :2 16
:4 13 32 30 16 :2 20 32 :2 3c 48
4c 60 63 64 :2 60 :2 32 :3 16 :2 1c
21 2d 71 74 :2 2d 81 84 :2 2d
88 8b :2 2d 95 98 a1 a9 :2 b2
:2 a1 ca :2 98 :2 2d d2 d5 :2 2d dd
e0 :2 2d e5 e8 :2 2d fc ff :2 2d
:2 16 67 :2 13 16 :2 20 32 :2 3c 48
4b 5f 62 63 :2 5f :2 32 :3 16 :2 1c
21 2d 71 74 :2 2d :2 16 66 :3 13
:2 1e 32 :2 3b 52 1b :2 13 :4 10 32
:3 d 1a :2 d 24 d :4 11 10 :4 2d
2c 2b :3 10 20 10 4c :3 d 20
33 41 4c 29 3e 4c 29 3b
47 51 29 37 3e 49 4f 29
38 48 54 29 35 48 54 :2 20
:2 d 1b :2 d 20 30 3e 53 5f
62 65 :2 20 d :4 11 :2 10 1e :2 10
23 33 41 56 62 65 68 :2 23
10 32 :2 d :4 a 26 :2 7 :4 4 8
:2 13 1a 24 :2 8 30 32 :2 30 7
3a a 1d :2 3a 23 20 :2 2c :2 20
39 :3 7 15 :2 7 17 :2 7 1c :2 25
:2 7 16 25 31 46 52 60 :2 16
:2 7 :2 10 1c :2 7 15 :2 7 17 :2 7
1c :2 25 :2 7 16 25 31 46 52
60 :2 16 :2 7 :2 10 1c 7 47 :3 4
17 21 :2 17 4 7 :2 11 23 :2 2d
39 3c 50 53 54 :2 50 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e 72 75
:2 1e 79 7c :2 1e 86 89 92 9a
:2 a3 :2 92 ae :2 89 :2 1e b6 b9 :2 1e
c1 c4 :2 1e c9 cc :2 1e d2 d5
:2 1e :2 7 57 :3 4 :2 f 21 :2 2a 34
3b :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 54 57 58 :2 54
:2 26 :3 a :2 10 15 21 65 68 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
5b :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 51 54 55 :2 51
:2 23 :3 7 :2 d 12 1e 62 65 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 58 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
121a
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 :4 7 2
:4 8 :2 1 :7 a :7 b
:7 c :7 d :7 e :7 f
:7 10 :7 11 :7 12 :5 13
:5 14 :5 15 :5 16 :5 17
:5 18 :5 19 :7 1a :6 1b
:6 1c :6 1d :6 1e :5 1f
:5 20 :5 21 :5 22 :5 23
:5 24 :7 25 :6 26 :6 27
:6 28 :6 29 :6 2a :6 2b
:6 2c :6 2d :6 2e :6 2f
:6 30 :6 31 :6 32 :6 33
:6 34 :7 35 :5 36 :6 37
:7 39 :b 3b :11 3c 3d
:2 3c :2 3d :2 3c :2 3d
:2 3c :2 3e :2 3c :12 3e
:2 3c :2 3f :2 3c :12 3f
:2 3c :2 40 :2 3c :9 40
:2 3c :2 41 :2 3c :2 41
:2 3c :2 41 :2 3c :2 41
:2 3c :2 41 :4 3c :3 3b
:11 44 :b 45 :3 44 :3 4b
:3 4c :3 4e :3 50 :3 51
:3 52 :3 53 :a 54 :5 55
:3 54 :6 59 :f 5a :8 5b
:6 5c :9 5d :8 5e 5f
:2 60 59 :5 61 58
63 :5 64 :3 63 :2 65
:5 67 :11 68 :24 69 :3 68
:2 66 :6 65 62 :3 3a
:a 6f :11 70 :30 71 :3 70
:11 73 :b 74 :3 73 :a 76
:3 6f 7a 7b 7c
:2 7d :2 7e 7a :5 7f
79 81 :5 82 :3 81
:2 83 :5 85 :11 86 :24 87
:3 86 :2 84 :6 83 80
:3 3a :a 8c :11 8d :30 8e
:3 8d :11 90 :b 91 :3 90
:a 93 :3 8c :9 96 :11 97
:30 98 :3 97 :11 9a :b 9b
:3 9a :a 9d :3 96 :e a0
:c a1 :11 a2 :30 a3 :3 a2
:11 a5 :b a6 :3 a5 :a a8
:3 a1 :3 a0 :3 ac :4 ae
:4 af :7 b0 ae :5 b1
ad b3 :5 b4 :3 b3
:2 b5 :5 b7 :11 b8 :24 b9
:3 b8 :2 b6 :6 b5 b2
:3 3a :3 bf :d c0 :2 c1
:2 c0 :6 c1 :3 c0 :3 c2
:3 c3 :5 c4 :a c5 :5 c6
:3 c8 :3 c9 :5 ca :a cb
:5 cc c1 :2 c0 :15 d0
:3 d1 :3 d0 :e d4 d6
:2 d7 :2 d8 d9 :2 da
d6 :6 db :5 dc db
:5 de dd :3 db d5
e1 :5 e2 :3 e1 :2 e3
:5 e5 :11 e6 :24 e7 :3 e6
:2 e4 :6 e3 e0 :4 d4
:c ee f2 :2 f3 f4
:2 f5 f2 :6 f6 :5 f7
f6 :5 f9 f8 :3 f6
f1 fc :5 fd :3 fc
:2 fe :5 100 :11 101 :24 102
:3 101 :2 ff :6 fe fb
:3 ee :c 109 :3 10b :3 109
:3 ee :c 10f 112 :2 113
114 :2 115 112 :6 116
:5 117 116 :5 119 118
:3 116 111 11c :5 11d
:3 11c :2 11e :5 120 :11 121
:24 122 :3 121 :2 11f :6 11e
11b :3 10f :c 12a :3 12c
:3 12a :3 10f :9 130 :15 133
:3 134 :3 133 :12 137 138
:2 137 :4 138 :3 137 :11 139
:30 13a :3 139 :11 13c :b 13d
:3 13c :a 13f 138 :2 137
:5 142 :5 143 :11 144 :30 145
:3 144 :11 147 :b 148 :3 147
:a 14a :3 143 :3 14e :c 14f
:3 150 151 14f :c 151
:9 153 154 :2 155 :4 156
153 :5 157 152 159
:5 15a :3 159 :2 15b :5 15d
:11 15e :24 15f :3 15e :2 15c
:6 15b 158 :3 151 :a 164
:a 167 :5 168 166 16a
:5 16b :3 16a :2 16c :5 16e
:11 16f :24 170 :3 16f :2 16d
:6 16c 169 :6 164 175
151 14f :5 175 :11 176
:2e 177 :3 176 :11 179 :b 17a
:3 179 :8 17c 175 :3 14f
142 :3 17f :3 180 17e
:3 142 :5 183 :15 185 :11 186
:30 187 :3 186 :11 189 :b 18a
:3 189 :a 18c 18d 185
:b 18d 18e :2 18d :4 18e
:3 18d :11 18f :20 190 :3 18f
:11 192 :b 193 :3 192 :9 195
18e :3 185 :15 198 :3 199
198 :3 19b 19a :3 198
:c 19f :3 1a0 1a1 19f
:b 1a1 :9 1a4 1a5 :2 1a6
:4 1a7 1a4 :5 1a8 1a3
1aa :5 1ab :3 1aa :2 1ac
:5 1ae :11 1af :24 1b0 :3 1af
:2 1ad :6 1ac 1a9 :3 1a1
:a 1b6 :a 1b9 :5 1ba 1b8
1bc :5 1bd :3 1bc :2 1be
:5 1c0 :11 1c1 :24 1c2 :3 1c1
:2 1bf :6 1be 1bb :6 1b6
1c7 1a1 19f :c 1c7
:11 1c9 :2e 1ca :3 1c9 :11 1cc
:b 1cd :3 1cc :8 1cf 1c7
:3 19f 183 :3 1d2 1d1
:3 183 :3 1d5 :3 1d6 :b 1d9
1db :2 1dc :2 1dd 1de
:2 1df 1db :6 1e0 :5 1e1
1e0 :5 1e3 1e2 :3 1e0
1da 1e6 :5 1e7 :3 1e6
:2 1e8 :5 1ea :11 1eb :24 1ec
:3 1eb :2 1e9 :6 1e8 1e5
:4 1d9 :5 1f3 :5 1f5 :3 1f6
:2 1f8 1f9 :2 1fa :6 1fb
:4 1fc 1f8 :5 1fd 1f7
1ff :5 200 :3 1ff :2 201
:5 203 :11 204 :24 205 :3 204
:2 202 :6 201 1fe :3 1f5
:9 209 :11 20c :30 20d :3 20c
:11 20f :b 210 :3 20f :7 212
213 :2 212 :3 209 215
1f5 :5 215 :3 217 :2 219
21a :2 21b :6 21c :4 21d
219 :5 21e 218 220
:5 221 :3 220 :2 222 :5 224
:11 225 :24 226 :3 225 :2 223
:6 222 21f :3 215 :9 22b
:11 22d :30 22e :3 22d :11 230
:b 231 :3 230 :7 233 234
:2 233 22b :4 23b :8 23c
23b :5 23d 23a 23f
:5 240 :3 23f :2 241 :5 243
:11 244 :24 245 :3 244 :2 242
:6 241 23e :3 235 :d 249
:11 24a :30 24b :3 24a :11 24d
:b 24e :3 24d :7 250 251
:2 250 :3 249 235 :3 22b
215 1f5 :11 255 :30 256
:3 255 :11 258 :b 259 :3 258
:7 25b 25c :2 25b 254
:3 1f5 :3 1f3 :3 261 :3 262
:d 264 :3 265 :3 264 :5 268
:3 269 :4 26a :5 26b :4 26c
:4 26d :3 268 :3 26f :b 270
:5 272 :3 273 :b 274 :3 272
1f0 :3 1d9 :3 130 ec
:3 d4 :d 27a :2 27b :2 27a
:6 27b :3 27a :3 27c :3 27d
:5 27e :a 27f :5 280 :3 282
:3 283 :5 284 :a 285 :5 286
27b :2 27a :6 289 :11 28b
:30 28c :3 28b :a 28e 3a
:3 292 :11 293 :b 294 :17 295
:3 293 :2 297 :3 298 :3 299
29a 298 297 298
:3 29b :3 292 :2 29c :5 29e
:11 29f :b 2a0 :18 2a1 :3 29f
:2 2a3 2a4 :3 2a5 2a6
2a4 2a3 2a4 :3 2a7
:2 29d :6 29c 291 :7 1

3f27
4
:3 0 1 :3 0 2
:a 0 1215 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 6
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :7 0 d c
:3 0 d :2 0 b
9 :3 0 8 :7 0
11 10 :3 0 4
:3 0 a :7 0 15
14 :3 0 b :3 0
c :3 0 d :2 0
4 19 1a 0
17 1b 0 1215
2 1c :2 0 11
:2 0 15 4 :3 0
f :2 0 13 1f
21 :6 0 24 22
0 1213 0 e
:6 0 11 :2 0 19
4 :3 0 17 26
28 :6 0 2b 29
0 1213 0 10
:6 0 11 :2 0 1d
4 :3 0 1b 2d
2f :6 0 32 30
0 1213 0 12
:6 0 11 :2 0 21
4 :3 0 1f 34
36 :6 0 39 37
0 1213 0 13
:6 0 11 :2 0 25
4 :3 0 23 3b
3d :6 0 40 3e
0 1213 0 14
:6 0 11 :2 0 29
4 :3 0 27 42
44 :6 0 47 45
0 1213 0 15
:6 0 11 :2 0 2d
4 :3 0 2b 49
4b :6 0 4e 4c
0 1213 0 16
:6 0 11 :2 0 31
4 :3 0 2f 50
52 :6 0 55 53
0 1213 0 17
:6 0 37 19b 0
35 4 :3 0 33
57 59 :6 0 5c
5a 0 1213 0
18 :6 0 3b 1cf
0 39 6 :3 0
5e :7 0 61 5f
0 1213 0 19
:6 0 6 :3 0 63
:7 0 66 64 0
1213 0 1a :6 0
3f 203 0 3d
6 :3 0 68 :7 0
6b 69 0 1213
0 1b :6 0 6
:3 0 6d :7 0 70
6e 0 1213 0
1c :6 0 43 237
0 41 6 :3 0
72 :7 0 75 73
0 1213 0 1d
:6 0 6 :3 0 77
:7 0 7a 78 0
1213 0 1e :6 0
23 :2 0 47 6
:3 0 7c :7 0 7f
7d 0 1213 0
1f :6 0 4 :3 0
21 :2 0 45 81
83 :6 0 86 84
0 1213 0 20
:6 0 23 :2 0 49
9 :3 0 88 :7 0
8c 89 8a 1213
0 22 :6 0 27
:2 0 4b 9 :3 0
8e :7 0 92 8f
90 1213 0 24
:6 0 27 :2 0 4d
26 :3 0 94 :7 0
98 95 96 1213
0 25 :6 0 51
2df 0 4f 26
:3 0 9a :7 0 9e
9b 9c 1213 0
28 :6 0 55 313
0 53 6 :3 0
a0 :7 0 a3 a1
0 1213 0 29
:6 0 6 :3 0 a5
:7 0 a8 a6 0
1213 0 2a :6 0
59 347 0 57
2c :3 0 aa :7 0
ad ab 0 1213
0 2b :6 0 2c
:3 0 af :7 0 b2
b0 0 1213 0
2d :6 0 f :2 0
5b 2c :3 0 b4
:7 0 b7 b5 0
1213 0 2e :6 0
2c :3 0 b9 :7 0
bc ba 0 1213
0 2f :6 0 23
:2 0 5f 4 :3 0
5d be c0 :6 0
c3 c1 0 1213
0 30 :6 0 23
:2 0 61 9 :3 0
c5 :7 0 c9 c6
c7 1213 0 31
:6 0 23 :2 0 63
9 :3 0 cb :7 0
cf cc cd 1213
0 32 :6 0 23
:2 0 65 9 :3 0
d1 :7 0 d5 d2
d3 1213 0 33
:6 0 23 :2 0 67
9 :3 0 d7 :7 0
db d8 d9 1213
0 34 :6 0 23
:2 0 69 9 :3 0
dd :7 0 e1 de
df 1213 0 35
:6 0 23 :2 0 6b
9 :3 0 e3 :7 0
e7 e4 e5 1213
0 36 :6 0 23
:2 0 6d 9 :3 0
e9 :7 0 ed ea
eb 1213 0 37
:6 0 23 :2 0 6f
9 :3 0 ef :7 0
f3 f0 f1 1213
0 38 :6 0 23
:2 0 71 9 :3 0
f5 :7 0 f9 f6
f7 1213 0 39
:6 0 23 :2 0 73
9 :3 0 fb :7 0
ff fc fd 1213
0 3a :6 0 23
:2 0 75 9 :3 0
101 :7 0 105 102
103 1213 0 3b
:6 0 23 :2 0 77
9 :3 0 107 :7 0
10b 108 109 1213
0 3c :6 0 23
:2 0 79 9 :3 0
10d :7 0 111 10e
10f 1213 0 3d
:6 0 23 :2 0 7b
9 :3 0 113 :7 0
117 114 115 1213
0 3e :6 0 11
:2 0 7d 9 :3 0
119 :7 0 11d 11a
11b 1213 0 3f
:6 0 83 559 0
81 4 :3 0 7f
11f 121 :6 0 124
122 0 1213 0
40 :6 0 131 132
0 85 42 :3 0
126 :7 0 129 127
0 1213 0 41
:6 0 9 :3 0 12b
0 2 :5 0 23
:2 0 12f 12c 12d
1213 0 43 :6 0
137 138 0 87
c :3 0 d :2 0
4 133 :7 0 136
134 0 1213 0
44 :6 0 45 :3 0
46 :3 0 45 :3 0
47 :3 0 13a 13b
0 2 :4 0 89
13c 13e 139 140
13f :2 0 48 :3 0
49 :3 0 142 143
0 4a :4 0 45
:3 0 4b :3 0 146
147 0 2 :4 0
8b 148 14a 4c
:4 0 4d :2 0 4e
:3 0 8d 14d 14f
:3 0 4f :4 0 4d
:2 0 50 :4 0 90
152 154 :3 0 4d
:2 0 3 :3 0 93
156 158 :3 0 4d
:2 0 50 :4 0 96
15a 15c :3 0 4d
:2 0 51 :4 0 99
15e 160 :3 0 4d
:2 0 52 :3 0 53
:3 0 50 :4 0 4d
:2 0 5 :3 0 9c
166 168 :3 0 4d
:2 0 50 :4 0 9f
16a 16c :3 0 54
:4 0 a2 164 16f
55 :4 0 a5 163
172 a8 162 174
:3 0 4d :2 0 51
:4 0 ab 176 178
:3 0 4d :2 0 52
:3 0 53 :3 0 50
:4 0 4d :2 0 7
:3 0 ae 17e 180
:3 0 4d :2 0 50
:4 0 b1 182 184
:3 0 54 :4 0 b4
17c 187 55 :4 0
b7 17b 18a ba
17a 18c :3 0 4d
:2 0 51 :4 0 bd
18e 190 :3 0 4d
:2 0 52 :3 0 56
:3 0 8 :3 0 c0
194 196 55 :4 0
c2 193 199 c5
192 19b :3 0 4d
:2 0 51 :4 0 c8
19d 19f :3 0 4d
:2 0 50 :4 0 cb
1a1 1a3 :3 0 4d
:2 0 a :3 0 ce
1a5 1a7 :3 0 4d
:2 0 50 :4 0 d1
1a9 1ab :3 0 4d
:2 0 57 :4 0 d4
1ad 1af :3 0 d7
144 1b1 :2 0 1b3
dc 1b4 141 1b3
0 1b5 de 0
1173 45 :3 0 46
:3 0 1b6 1b7 0
45 :3 0 58 :3 0
1b9 1ba 0 f
:2 0 2 :4 0 59
:2 0 5a :2 0 f
:2 0 e0 1bf 1c1
:3 0 e3 1bb 1c3
1b8 1c5 1c4 :2 0
48 :3 0 5b :3 0
1c7 1c8 0 4a
:4 0 5c :4 0 4d
:2 0 4e :3 0 e7
1cc 1ce :3 0 ea
1c9 1d0 :2 0 1d2
ed 1d3 1c6 1d2
0 1d4 ef 0
1173 19 :3 0 5d
:4 0 1d5 1d6 0
1173 1a :3 0 5d
:4 0 1d8 1d9 0
1173 36 :3 0 f
:2 0 1db 1dc 0
1173 19 :3 0 5
:3 0 1de 1df 0
1173 1a :3 0 7
:3 0 1e1 1e2 0
1173 14 :3 0 3
:3 0 1e4 1e5 0
1173 3a :3 0 8
:3 0 1e7 1e8 0
1173 52 :3 0 3a
:3 0 23 :2 0 f1
1ea 1ed 5e :2 0
f :2 0 f6 1ef
1f1 :3 0 1f2 :2 0
3a :3 0 5f :3 0
60 :3 0 1f5 1f6
0 1f4 1f7 0
1f9 f9 1fa 1f3
1f9 0 1fb fb
0 1173 61 :3 0
62 :3 0 63 :3 0
64 :3 0 65 :3 0
66 :3 0 52 :3 0
67 :3 0 68 :3 0
52 :3 0 69 :3 0
6a :3 0 67 :3 0
69 :3 0 6b :3 0
6c :3 0 6d :3 0
6e :3 0 6d :3 0
6f :3 0 70 :3 0
71 :3 0 72 :3 0
73 :3 0 74 :3 0
75 :3 0 76 :3 0
77 :3 0 78 :3 0
10 :3 0 15 :3 0
13 :3 0 1f :3 0
22 :3 0 30 :3 0
1b :3 0 1c :3 0
1d :3 0 1e :3 0
12 :3 0 16 :3 0
35 :3 0 3b :3 0
33 :3 0 38 :3 0
2b :3 0 29 :3 0
2a :3 0 31 :3 0
32 :3 0 25 :3 0
28 :3 0 79 :3 0
7a :3 0 3 :4 0
7b 1 :8 0 239
c :3 0 7c :3 0
234 235 0 7d
:3 0 236 237 0
239 fd 28c 7e
:3 0 c :3 0 7c
:3 0 23b 23c 0
7d :3 0 23d 23e
0 240 100 242
102 241 240 :2 0
28a 7f :3 0 c
:3 0 7c :3 0 245
246 0 7d :3 0
247 248 0 282
45 :3 0 46 :3 0
24a 24b 0 45
:3 0 58 :3 0 24d
24e 0 80 :2 0
2 :4 0 81 :2 0
5a :2 0 f :2 0
104 253 255 :3 0
107 24f 257 24c
259 258 :2 0 48
:3 0 5b :3 0 25b
25c 0 4a :4 0
82 :4 0 4d :2 0
4e :3 0 10b 260
262 :3 0 4d :2 0
83 :4 0 10e 264
266 :3 0 4d :2 0
84 :4 0 111 268
26a :3 0 4d :2 0
7d :3 0 114 26c
26e :3 0 4d :2 0
85 :4 0 117 270
272 :3 0 4d :2 0
86 :3 0 87 :3 0
f :2 0 88 :2 0
11a 275 279 11e
274 27b :3 0 121
25d 27d :2 0 27f
124 280 25a 27f
0 281 126 0
282 128 285 :3 0
285 0 285 284
282 283 :6 0 287
2 :3 0 12b 289
12d 288 287 :2 0
28a 12f :2 0 28c
0 28c 28b 239
28a :6 0 1173 1
:3 0 c :3 0 7c
:3 0 28e 28f 0
c :3 0 5e :2 0
89 :3 0 291 293
0 134 292 295
:3 0 296 :2 0 45
:3 0 46 :3 0 298
299 0 45 :3 0
58 :3 0 29b 29c
0 11 :2 0 2
:4 0 8a :2 0 5a
:2 0 f :2 0 137
2a1 2a3 :3 0 13a
29d 2a5 29a 2a7
2a6 :2 0 48 :3 0
5b :3 0 2a9 2aa
0 4a :4 0 8b
:4 0 4d :2 0 4e
:3 0 13e 2ae 2b0
:3 0 4d :2 0 83
:4 0 141 2b2 2b4
:3 0 4d :2 0 8c
:4 0 144 2b6 2b8
:3 0 4d :2 0 52
:3 0 56 :3 0 5f
:3 0 8d :3 0 2bd
2be 0 147 2bc
2c0 55 :4 0 149
2bb 2c3 14c 2ba
2c5 :3 0 4d :2 0
8e :4 0 14f 2c7
2c9 :3 0 4d :2 0
50 :4 0 152 2cb
2cd :3 0 4d :2 0
3 :3 0 155 2cf
2d1 :3 0 4d :2 0
50 :4 0 158 2d3
2d5 :3 0 15b 2ab
2d7 :2 0 2d9 15e
2da 2a8 2d9 0
2db 160 0 305
45 :3 0 46 :3 0
2dc 2dd 0 45
:3 0 58 :3 0 2df
2e0 0 f :2 0
2 :4 0 8f :2 0
5a :2 0 f :2 0
162 2e5 2e7 :3 0
165 2e1 2e9 2de
2eb 2ea :2 0 48
:3 0 5b :3 0 2ed
2ee 0 4a :4 0
90 :4 0 4d :2 0
4e :3 0 169 2f2
2f4 :3 0 16c 2ef
2f6 :2 0 2f8 16f
2f9 2ec 2f8 0
2fa 171 0 305
91 :3 0 92 :3 0
2fb 2fc 0 5f
:3 0 8d :3 0 2fe
2ff 0 3 :3 0
93 :3 0 173 2fd
303 :2 0 305 177
306 297 305 0
307 17b 0 1173
94 :3 0 e :3 0
95 :3 0 61 :3 0
10 :3 0 96 :3 0
12 :4 0 97 1
:8 0 315 c :3 0
7c :3 0 310 311
0 7d :3 0 312
313 0 315 17d
368 7e :3 0 c
:3 0 7c :3 0 317
318 0 7d :3 0
319 31a 0 31c
180 31e 182 31d
31c :2 0 366 7f
:3 0 c :3 0 7c
:3 0 321 322 0
7d :3 0 323 324
0 35e 45 :3 0
46 :3 0 326 327
0 45 :3 0 58
:3 0 329 32a 0
80 :2 0 2 :4 0
98 :2 0 5a :2 0
f :2 0 184 32f
331 :3 0 187 32b
333 328 335 334
:2 0 48 :3 0 5b
:3 0 337 338 0
4a :4 0 99 :4 0
4d :2 0 4e :3 0
18b 33c 33e :3 0
4d :2 0 83 :4 0
18e 340 342 :3 0
4d :2 0 84 :4 0
191 344 346 :3 0
4d :2 0 7d :3 0
194 348 34a :3 0
4d :2 0 85 :4 0
197 34c 34e :3 0
4d :2 0 86 :3 0
87 :3 0 f :2 0
88 :2 0 19a 351
355 19e 350 357
:3 0 1a1 339 359
:2 0 35b 1a4 35c
336 35b 0 35d
1a6 0 35e 1a8
361 :3 0 361 0
361 360 35e 35f
:6 0 363 4 :3 0
1ab 365 1ad 364
363 :2 0 366 1af
:2 0 368 0 368
367 315 366 :6 0
1173 1 :3 0 86
:3 0 e :3 0 f
:2 0 f :2 0 1b2
36a 36e 5e :2 0
9a :4 0 1b8 370
372 :3 0 45 :3 0
46 :3 0 374 375
0 45 :3 0 58
:3 0 377 378 0
11 :2 0 2 :4 0
9b :2 0 5a :2 0
f :2 0 1bb 37d
37f :3 0 1be 379
381 376 383 382
:2 0 48 :3 0 5b
:3 0 385 386 0
4a :4 0 9c :4 0
4d :2 0 4e :3 0
1c2 38a 38c :3 0
4d :2 0 83 :4 0
1c5 38e 390 :3 0
4d :2 0 8c :4 0
1c8 392 394 :3 0
4d :2 0 52 :3 0
56 :3 0 5f :3 0
9d :3 0 399 39a
0 1cb 398 39c
55 :4 0 1cd 397
39f 1d0 396 3a1
:3 0 4d :2 0 8e
:4 0 1d3 3a3 3a5
:3 0 4d :2 0 50
:4 0 1d6 3a7 3a9
:3 0 4d :2 0 3
:3 0 1d9 3ab 3ad
:3 0 4d :2 0 50
:4 0 1dc 3af 3b1
:3 0 1df 387 3b3
:2 0 3b5 1e2 3b6
384 3b5 0 3b7
1e4 0 3e1 45
:3 0 46 :3 0 3b8
3b9 0 45 :3 0
58 :3 0 3bb 3bc
0 f :2 0 2
:4 0 9e :2 0 5a
:2 0 f :2 0 1e6
3c1 3c3 :3 0 1e9
3bd 3c5 3ba 3c7
3c6 :2 0 48 :3 0
5b :3 0 3c9 3ca
0 4a :4 0 9f
:4 0 4d :2 0 4e
:3 0 1ed 3ce 3d0
:3 0 1f0 3cb 3d2
:2 0 3d4 1f3 3d5
3c8 3d4 0 3d6
1f5 0 3e1 91
:3 0 92 :3 0 3d7
3d8 0 5f :3 0
9d :3 0 3da 3db
0 3 :3 0 93
:3 0 1f7 3d9 3df
:2 0 3e1 1fb 3e2
373 3e1 0 3e3
1ff 0 1173 52
:3 0 22 :3 0 23
:2 0 201 3e4 3e7
5e :2 0 a0 :2 0
206 3e9 3eb :3 0
45 :3 0 46 :3 0
3ed 3ee 0 45
:3 0 58 :3 0 3f0
3f1 0 11 :2 0
2 :4 0 a1 :2 0
5a :2 0 f :2 0
209 3f6 3f8 :3 0
20c 3f2 3fa 3ef
3fc 3fb :2 0 48
:3 0 5b :3 0 3fe
3ff 0 4a :4 0
a2 :4 0 4d :2 0
4e :3 0 210 403
405 :3 0 4d :2 0
83 :4 0 213 407
409 :3 0 4d :2 0
8c :4 0 216 40b
40d :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 a3 :3 0
412 413 0 219
411 415 55 :4 0
21b 410 418 21e
40f 41a :3 0 4d
:2 0 8e :4 0 221
41c 41e :3 0 4d
:2 0 50 :4 0 224
420 422 :3 0 4d
:2 0 3 :3 0 227
424 426 :3 0 4d
:2 0 50 :4 0 22a
428 42a :3 0 22d
400 42c :2 0 42e
230 42f 3fd 42e
0 430 232 0
45a 45 :3 0 46
:3 0 431 432 0
45 :3 0 58 :3 0
434 435 0 f
:2 0 2 :4 0 a4
:2 0 5a :2 0 f
:2 0 234 43a 43c
:3 0 237 436 43e
433 440 43f :2 0
48 :3 0 5b :3 0
442 443 0 4a
:4 0 a5 :4 0 4d
:2 0 4e :3 0 23b
447 449 :3 0 23e
444 44b :2 0 44d
241 44e 441 44d
0 44f 243 0
45a 91 :3 0 92
:3 0 450 451 0
5f :3 0 a3 :3 0
453 454 0 3
:3 0 93 :3 0 245
452 458 :2 0 45a
249 45b 3ec 45a
0 45c 24d 0
1173 5 :3 0 a6
:2 0 24f 45e 45f
:3 0 460 :2 0 461
:2 0 7 :3 0 a6
:2 0 251 464 465
:3 0 466 :2 0 467
:2 0 462 469 468
:2 0 a7 :3 0 a8
:3 0 46b 46c 0
1a :3 0 19 :3 0
a9 :2 0 253 46d
471 aa :2 0 23
:2 0 259 473 475
:3 0 45 :3 0 46
:3 0 477 478 0
45 :3 0 58 :3 0
47a 47b 0 11
:2 0 2 :4 0 ab
:2 0 5a :2 0 f
:2 0 25c 480 482
:3 0 25f 47c 484
479 486 485 :2 0
48 :3 0 5b :3 0
488 489 0 4a
:4 0 ac :4 0 4d
:2 0 4e :3 0 263
48d 48f :3 0 4d
:2 0 83 :4 0 266
491 493 :3 0 4d
:2 0 8c :4 0 269
495 497 :3 0 4d
:2 0 52 :3 0 56
:3 0 5f :3 0 ad
:3 0 49c 49d 0
26c 49b 49f 55
:4 0 26e 49a 4a2
271 499 4a4 :3 0
4d :2 0 8e :4 0
274 4a6 4a8 :3 0
4d :2 0 50 :4 0
277 4aa 4ac :3 0
4d :2 0 3 :3 0
27a 4ae 4b0 :3 0
4d :2 0 50 :4 0
27d 4b2 4b4 :3 0
280 48a 4b6 :2 0
4b8 283 4b9 487
4b8 0 4ba 285
0 4e4 45 :3 0
46 :3 0 4bb 4bc
0 45 :3 0 58
:3 0 4be 4bf 0
f :2 0 2 :4 0
ae :2 0 5a :2 0
f :2 0 287 4c4
4c6 :3 0 28a 4c0
4c8 4bd 4ca 4c9
:2 0 48 :3 0 5b
:3 0 4cc 4cd 0
4a :4 0 af :4 0
4d :2 0 4e :3 0
28e 4d1 4d3 :3 0
291 4ce 4d5 :2 0
4d7 294 4d8 4cb
4d7 0 4d9 296
0 4e4 91 :3 0
92 :3 0 4da 4db
0 5f :3 0 ad
:3 0 4dd 4de 0
3 :3 0 93 :3 0
298 4dc 4e2 :2 0
4e4 29c 4e5 476
4e4 0 4e6 2a0
0 4e7 2a2 4e8
46a 4e7 0 4e9
2a4 0 1173 2f
:4 0 4ea 4eb 0
1173 b0 :3 0 b1
:3 0 2f :3 0 b2
:3 0 96 :3 0 10
:3 0 6c :3 0 16
:3 0 b3 :3 0 5f
:3 0 b4 :3 0 5f
:3 0 b5 :3 0 5f
:3 0 b6 :4 0 b7
1 :8 0 502 c
:3 0 7c :3 0 4fd
4fe 0 7d :3 0
4ff 500 0 502
2a6 555 7e :3 0
c :3 0 7c :3 0
504 505 0 7d
:3 0 506 507 0
509 2a9 50b 2ab
50a 509 :2 0 553
7f :3 0 c :3 0
7c :3 0 50e 50f
0 7d :3 0 510
511 0 54b 45
:3 0 46 :3 0 513
514 0 45 :3 0
58 :3 0 516 517
0 80 :2 0 2
:4 0 b8 :2 0 5a
:2 0 f :2 0 2ad
51c 51e :3 0 2b0
518 520 515 522
521 :2 0 48 :3 0
5b :3 0 524 525
0 4a :4 0 b9
:4 0 4d :2 0 4e
:3 0 2b4 529 52b
:3 0 4d :2 0 83
:4 0 2b7 52d 52f
:3 0 4d :2 0 84
:4 0 2ba 531 533
:3 0 4d :2 0 7d
:3 0 2bd 535 537
:3 0 4d :2 0 85
:4 0 2c0 539 53b
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 2c3
53e 542 2c7 53d
544 :3 0 2ca 526
546 :2 0 548 2cd
549 523 548 0
54a 2cf 0 54b
2d1 54e :3 0 54e
0 54e 54d 54b
54c :6 0 550 6
:3 0 2d4 552 2d6
551 550 :2 0 553
2d8 :2 0 555 0
555 554 502 553
:6 0 1173 1 :3 0
17 :3 0 a :3 0
557 558 0 1173
a7 :3 0 ba :3 0
55a 55b 0 16
:3 0 17 :3 0 2db
55c 55f 5e :2 0
23 :2 0 2e0 561
563 :3 0 564 :2 0
52 :3 0 3a :3 0
23 :2 0 2e3 566
569 5f :3 0 bb
:2 0 60 :3 0 56b
56d 0 2e8 56c
56f :3 0 570 :2 0
565 572 571 :2 0
40 :3 0 bc :4 0
574 575 0 5a8
3f :3 0 f :2 0
577 578 0 5a8
43 :3 0 c :3 0
7c :3 0 57b 57c
0 57a 57d 0
5a8 41 :3 0 bd
:3 0 40 :3 0 14
:3 0 17 :3 0 3f
:3 0 23 :2 0 2eb
580 586 57f 587
0 5a8 c :3 0
7c :3 0 589 58a
0 43 :3 0 58b
58c 0 5a8 40
:3 0 be :4 0 58e
58f 0 5a8 3f
:3 0 23 :2 0 591
592 0 5a8 43
:3 0 c :3 0 7c
:3 0 595 596 0
594 597 0 5a8
41 :3 0 bd :3 0
40 :3 0 14 :3 0
17 :3 0 3f :3 0
23 :2 0 2f1 59a
5a0 599 5a1 0
5a8 c :3 0 7c
:3 0 5a3 5a4 0
43 :3 0 5a5 5a6
0 5a8 2f7 5a9
573 5a8 0 5aa
302 0 1173 19
:3 0 a6 :2 0 304
5ac 5ad :3 0 5ae
:2 0 5af :2 0 a7
:3 0 a8 :3 0 5b1
5b2 0 19 :3 0
1b :3 0 a9 :2 0
306 5b3 5b7 5e
:2 0 23 :2 0 30c
5b9 5bb :3 0 5bc
:2 0 5b0 5be 5bd
:2 0 19 :3 0 1b
:3 0 5c0 5c1 0
5c3 30f 5c4 5bf
5c3 0 5c5 311
0 1173 5 :3 0
bf :2 0 313 5c7
5c8 :3 0 5c9 :2 0
5ca :2 0 7 :3 0
bf :2 0 315 5cd
5ce :3 0 5cf :2 0
5d0 :2 0 5cb 5d2
5d1 :2 0 79 :3 0
67 :3 0 5 :3 0
69 :3 0 7 :3 0
c0 :3 0 7a :3 0
3 :4 0 c1 1
:8 0 5f2 c2 :4 0
5dd :3 0 93 :3 0
5e :2 0 319 5e0
5e1 :3 0 c :3 0
7c :3 0 5e3 5e4
0 23 :2 0 5e5
5e6 0 5e8 31c
5ef c :3 0 7c
:3 0 5e9 5ea 0
c3 :2 0 5eb 5ec
0 5ee 31e 5f0
5e2 5e8 0 5f1
0 5ee 0 5f1
320 0 5f2 323
645 7e :3 0 c
:3 0 7c :3 0 5f4
5f5 0 7d :3 0
5f6 5f7 0 5f9
326 5fb 328 5fa
5f9 :2 0 643 7f
:3 0 c :3 0 7c
:3 0 5fe 5ff 0
7d :3 0 600 601
0 63b 45 :3 0
46 :3 0 603 604
0 45 :3 0 58
:3 0 606 607 0
80 :2 0 2 :4 0
c4 :2 0 5a :2 0
f :2 0 32a 60c
60e :3 0 32d 608
610 605 612 611
:2 0 48 :3 0 5b
:3 0 614 615 0
4a :4 0 c5 :4 0
4d :2 0 4e :3 0
331 619 61b :3 0
4d :2 0 83 :4 0
334 61d 61f :3 0
4d :2 0 84 :4 0
337 621 623 :3 0
4d :2 0 7d :3 0
33a 625 627 :3 0
4d :2 0 85 :4 0
33d 629 62b :3 0
4d :2 0 86 :3 0
87 :3 0 f :2 0
88 :2 0 340 62e
632 344 62d 634
:3 0 347 616 636
:2 0 638 34a 639
613 638 0 63a
34c 0 63b 34e
63e :3 0 63e 0
63e 63d 63b 63c
:6 0 640 8 :3 0
351 642 353 641
640 :2 0 643 355
:2 0 645 0 645
644 5f2 643 :6 0
647 1 :3 0 358
10cb 5 :3 0 bf
:2 0 35a 649 64a
:3 0 64b :2 0 1d
:3 0 a6 :2 0 35c
64e 64f :3 0 650
:2 0 64c 652 651
:2 0 79 :3 0 67
:3 0 5 :3 0 c0
:3 0 7a :3 0 3
:4 0 c6 1 :8 0
670 c2 :4 0 65b
:3 0 93 :3 0 5e
:2 0 360 65e 65f
:3 0 c :3 0 7c
:3 0 661 662 0
23 :2 0 663 664
0 666 363 66d
c :3 0 7c :3 0
667 668 0 c3
:2 0 669 66a 0
66c 365 66e 660
666 0 66f 0
66c 0 66f 367
0 670 36a 6c3
7e :3 0 c :3 0
7c :3 0 672 673
0 7d :3 0 674
675 0 677 36d
679 36f 678 677
:2 0 6c1 7f :3 0
c :3 0 7c :3 0
67c 67d 0 7d
:3 0 67e 67f 0
6b9 45 :3 0 46
:3 0 681 682 0
45 :3 0 58 :3 0
684 685 0 80
:2 0 2 :4 0 c7
:2 0 5a :2 0 f
:2 0 371 68a 68c
:3 0 374 686 68e
683 690 68f :2 0
48 :3 0 5b :3 0
692 693 0 4a
:4 0 c8 :4 0 4d
:2 0 4e :3 0 378
697 699 :3 0 4d
:2 0 83 :4 0 37b
69b 69d :3 0 4d
:2 0 84 :4 0 37e
69f 6a1 :3 0 4d
:2 0 7d :3 0 381
6a3 6a5 :3 0 4d
:2 0 85 :4 0 384
6a7 6a9 :3 0 4d
:2 0 86 :3 0 87
:3 0 f :2 0 88
:2 0 387 6ac 6b0
38b 6ab 6b2 :3 0
38e 694 6b4 :2 0
6b6 391 6b7 691
6b6 0 6b8 393
0 6b9 395 6bc
:3 0 6bc 0 6bc
6bb 6b9 6ba :6 0
6be a :3 0 398
6c0 39a 6bf 6be
:2 0 6c1 39c :2 0
6c3 0 6c3 6c2
670 6c1 :6 0 6d7
1 :3 0 a7 :3 0
a8 :3 0 6c5 6c6
0 1a :3 0 1e
:3 0 a9 :2 0 39f
6c7 6cb 5e :2 0
23 :2 0 3a5 6cd
6cf :3 0 36 :3 0
23 :2 0 6d1 6d2
0 6d4 3a8 6d5
6d0 6d4 0 6d6
3aa 0 6d7 3ac
6d8 653 6d7 0
6d9 3af 0 10ca
7 :3 0 bf :2 0
3b1 6db 6dc :3 0
6dd :2 0 1e :3 0
a6 :2 0 3b3 6e0
6e1 :3 0 6e2 :2 0
6de 6e4 6e3 :2 0
79 :3 0 69 :3 0
7 :3 0 c0 :3 0
7a :3 0 3 :4 0
c9 1 :8 0 702
c2 :4 0 6ed :3 0
93 :3 0 5e :2 0
3b7 6f0 6f1 :3 0
c :3 0 7c :3 0
6f3 6f4 0 23
:2 0 6f5 6f6 0
6f8 3ba 6ff c
:3 0 7c :3 0 6f9
6fa 0 c3 :2 0
6fb 6fc 0 6fe
3bc 700 6f2 6f8
0 701 0 6fe
0 701 3be 0
702 3c1 755 7e
:3 0 c :3 0 7c
:3 0 704 705 0
7d :3 0 706 707
0 709 3c4 70b
3c6 70a 709 :2 0
753 7f :3 0 c
:3 0 7c :3 0 70e
70f 0 7d :3 0
710 711 0 74b
45 :3 0 46 :3 0
713 714 0 45
:3 0 58 :3 0 716
717 0 80 :2 0
2 :4 0 ca :2 0
5a :2 0 f :2 0
3c8 71c 71e :3 0
3cb 718 720 715
722 721 :2 0 48
:3 0 5b :3 0 724
725 0 4a :4 0
cb :4 0 4d :2 0
4e :3 0 3cf 729
72b :3 0 4d :2 0
83 :4 0 3d2 72d
72f :3 0 4d :2 0
84 :4 0 3d5 731
733 :3 0 4d :2 0
7d :3 0 3d8 735
737 :3 0 4d :2 0
85 :4 0 3db 739
73b :3 0 4d :2 0
86 :3 0 87 :3 0
f :2 0 88 :2 0
3de 73e 742 3e2
73d 744 :3 0 3e5
726 746 :2 0 748
3e8 749 723 748
0 74a 3ea 0
74b 3ec 74e :3 0
74e 0 74e 74d
74b 74c :6 0 750
c :3 0 3ef 752
3f1 751 750 :2 0
753 3f3 :2 0 755
0 755 754 702
753 :6 0 769 1
:3 0 a7 :3 0 a8
:3 0 757 758 0
19 :3 0 1d :3 0
a9 :2 0 3f6 759
75d 5e :2 0 23
:2 0 3fc 75f 761
:3 0 36 :3 0 23
:2 0 763 764 0
766 3ff 767 762
766 0 768 401
0 769 403 76a
6e5 769 0 76b
406 0 10ca 52
:3 0 36 :3 0 23
:2 0 408 76c 76f
5e :2 0 f :2 0
40d 771 773 :3 0
1a :3 0 a6 :2 0
410 776 777 :3 0
778 :2 0 779 :2 0
a7 :3 0 a8 :3 0
77b 77c 0 1a
:3 0 1c :3 0 a9
:2 0 412 77d 781
5e :2 0 23 :2 0
418 783 785 :3 0
786 :2 0 77a 788
787 :2 0 1a :3 0
1c :3 0 78a 78b
0 78d 41b 78e
789 78d 0 78f
41d 0 10c7 2f
:3 0 a6 :2 0 41f
791 792 :3 0 793
:2 0 794 :2 0 1a
:3 0 a6 :2 0 421
797 798 :3 0 799
:2 0 79a :2 0 795
79c 79b :2 0 a7
:3 0 ba :3 0 79e
79f 0 2f :3 0
1a :3 0 423 7a0
7a3 cc :2 0 23
:2 0 428 7a5 7a7
:3 0 7a8 :2 0 79d
7aa 7a9 :2 0 45
:3 0 46 :3 0 7ac
7ad 0 45 :3 0
58 :3 0 7af 7b0
0 11 :2 0 2
:4 0 cd :2 0 5a
:2 0 f :2 0 42b
7b5 7b7 :3 0 42e
7b1 7b9 7ae 7bb
7ba :2 0 48 :3 0
5b :3 0 7bd 7be
0 4a :4 0 ce
:4 0 4d :2 0 4e
:3 0 432 7c2 7c4
:3 0 4d :2 0 83
:4 0 435 7c6 7c8
:3 0 4d :2 0 8c
:4 0 438 7ca 7cc
:3 0 4d :2 0 52
:3 0 56 :3 0 5f
:3 0 cf :3 0 7d1
7d2 0 43b 7d0
7d4 55 :4 0 43d
7cf 7d7 440 7ce
7d9 :3 0 4d :2 0
8e :4 0 443 7db
7dd :3 0 4d :2 0
50 :4 0 446 7df
7e1 :3 0 4d :2 0
16 :3 0 449 7e3
7e5 :3 0 4d :2 0
50 :4 0 44c 7e7
7e9 :3 0 44f 7bf
7eb :2 0 7ed 452
7ee 7bc 7ed 0
7ef 454 0 819
45 :3 0 46 :3 0
7f0 7f1 0 45
:3 0 58 :3 0 7f3
7f4 0 f :2 0
2 :4 0 d0 :2 0
5a :2 0 f :2 0
456 7f9 7fb :3 0
459 7f5 7fd 7f2
7ff 7fe :2 0 48
:3 0 5b :3 0 801
802 0 4a :4 0
d1 :4 0 4d :2 0
4e :3 0 45d 806
808 :3 0 460 803
80a :2 0 80c 463
80d 800 80c 0
80e 465 0 819
91 :3 0 92 :3 0
80f 810 0 5f
:3 0 cf :3 0 812
813 0 16 :3 0
93 :3 0 467 811
817 :2 0 819 46b
81a 7ab 819 0
81b 46f 0 10c7
5 :3 0 a6 :2 0
471 81d 81e :3 0
81f :2 0 1f :3 0
a6 :2 0 473 822
823 :3 0 824 :2 0
45 :3 0 46 :3 0
826 827 0 45
:3 0 58 :3 0 829
82a 0 11 :2 0
2 :4 0 d2 :2 0
5a :2 0 f :2 0
475 82f 831 :3 0
478 82b 833 828
835 834 :2 0 48
:3 0 5b :3 0 837
838 0 4a :4 0
d3 :4 0 4d :2 0
4e :3 0 47c 83c
83e :3 0 4d :2 0
83 :4 0 47f 840
842 :3 0 4d :2 0
8c :4 0 482 844
846 :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 d4 :3 0
84b 84c 0 485
84a 84e 55 :4 0
487 849 851 48a
848 853 :3 0 4d
:2 0 8e :4 0 48d
855 857 :3 0 4d
:2 0 50 :4 0 490
859 85b :3 0 4d
:2 0 3 :3 0 493
85d 85f :3 0 4d
:2 0 50 :4 0 496
861 863 :3 0 499
839 865 :2 0 867
49c 868 836 867
0 869 49e 0
893 45 :3 0 46
:3 0 86a 86b 0
45 :3 0 58 :3 0
86d 86e 0 f
:2 0 2 :4 0 d5
:2 0 5a :2 0 f
:2 0 4a0 873 875
:3 0 4a3 86f 877
86c 879 878 :2 0
48 :3 0 5b :3 0
87b 87c 0 4a
:4 0 d6 :4 0 4d
:2 0 4e :3 0 4a7
880 882 :3 0 4aa
87d 884 :2 0 886
4ad 887 87a 886
0 888 4af 0
893 91 :3 0 92
:3 0 889 88a 0
5f :3 0 d4 :3 0
88c 88d 0 3
:3 0 93 :3 0 4b1
88b 891 :2 0 893
4b5 894 825 893
0 895 4b9 0
a07 37 :3 0 33
:3 0 896 897 0
a07 a7 :3 0 a8
:3 0 899 89a 0
19 :3 0 29 :3 0
a9 :2 0 4bb 89b
89f 5e :2 0 23
:2 0 4c1 8a1 8a3
:3 0 19 :4 0 8a5
8a6 0 8a9 d7
:3 0 4c4 a05 a7
:3 0 a8 :3 0 8aa
8ab 0 19 :3 0
1b :3 0 a9 :2 0
4c6 8ac 8b0 bb
:2 0 23 :2 0 4cc
8b2 8b4 :3 0 a7
:3 0 d8 :3 0 d9
:3 0 a7 :3 0 da
:3 0 db :3 0 dc
:3 0 dd :3 0 19
:3 0 de :3 0 96
:3 0 10 :3 0 d9
:3 0 df :3 0 86
:3 0 5 :4 0 e0
1 :8 0 8cc c
:3 0 7c :3 0 8c7
8c8 0 7d :3 0
8c9 8ca 0 8cc
4cf 91f 7e :3 0
c :3 0 7c :3 0
8ce 8cf 0 7d
:3 0 8d0 8d1 0
8d3 4d2 8d5 4d4
8d4 8d3 :2 0 91d
7f :3 0 c :3 0
7c :3 0 8d8 8d9
0 7d :3 0 8da
8db 0 915 45
:3 0 46 :3 0 8dd
8de 0 45 :3 0
58 :3 0 8e0 8e1
0 80 :2 0 2
:4 0 e1 :2 0 5a
:2 0 f :2 0 4d6
8e6 8e8 :3 0 4d9
8e2 8ea 8df 8ec
8eb :2 0 48 :3 0
5b :3 0 8ee 8ef
0 4a :4 0 e2
:4 0 4d :2 0 4e
:3 0 4dd 8f3 8f5
:3 0 4d :2 0 83
:4 0 4e0 8f7 8f9
:3 0 4d :2 0 84
:4 0 4e3 8fb 8fd
:3 0 4d :2 0 7d
:3 0 4e6 8ff 901
:3 0 4d :2 0 85
:4 0 4e9 903 905
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 4ec
908 90c 4f0 907
90e :3 0 4f3 8f0
910 :2 0 912 4f6
913 8ed 912 0
914 4f8 0 915
4fa 918 :3 0 918
0 918 917 915
916 :6 0 91a e
:3 0 4fd 91c 4ff
91b 91a :2 0 91d
501 :2 0 91f 0
91f 91e 8cc 91d
:6 0 993 1 :3 0
c :3 0 7c :3 0
921 922 0 c
:3 0 5e :2 0 89
:3 0 924 926 0
506 925 928 :3 0
929 :2 0 a7 :3 0
d8 :3 0 df :3 0
86 :3 0 5 :3 0
a7 :3 0 da :3 0
19 :3 0 e3 :4 0
e4 1 :8 0 93a
c :3 0 7c :3 0
935 936 0 7d
:3 0 937 938 0
93a 509 98d 7e
:3 0 c :3 0 7c
:3 0 93c 93d 0
7d :3 0 93e 93f
0 941 50c 943
50e 942 941 :2 0
98b 7f :3 0 c
:3 0 7c :3 0 946
947 0 7d :3 0
948 949 0 983
45 :3 0 46 :3 0
94b 94c 0 45
:3 0 58 :3 0 94e
94f 0 80 :2 0
2 :4 0 e5 :2 0
5a :2 0 f :2 0
510 954 956 :3 0
513 950 958 94d
95a 959 :2 0 48
:3 0 5b :3 0 95c
95d 0 4a :4 0
e6 :4 0 4d :2 0
4e :3 0 517 961
963 :3 0 4d :2 0
83 :4 0 51a 965
967 :3 0 4d :2 0
84 :4 0 51d 969
96b :3 0 4d :2 0
7d :3 0 520 96d
96f :3 0 4d :2 0
85 :4 0 523 971
973 :3 0 4d :2 0
86 :3 0 87 :3 0
f :2 0 88 :2 0
526 976 97a 52a
975 97c :3 0 52d
95e 97e :2 0 980
530 981 95b 980
0 982 532 0
983 534 986 :3 0
986 0 986 985
983 984 :6 0 988
10 :3 0 537 98a
539 989 988 :2 0
98b 53b :2 0 98d
0 98d 98c 93a
98b :6 0 98f 1
:3 0 53e 990 92a
98f 0 991 540
0 993 d7 :3 0
542 994 8b5 993
0 a06 7 :3 0
bf :2 0 545 996
997 :3 0 998 :2 0
45 :3 0 46 :3 0
99a 99b 0 45
:3 0 58 :3 0 99d
99e 0 11 :2 0
2 :4 0 e7 :2 0
5a :2 0 f :2 0
547 9a3 9a5 :3 0
54a 99f 9a7 99c
9a9 9a8 :2 0 48
:3 0 5b :3 0 9ab
9ac 0 4a :4 0
e8 :4 0 4d :2 0
4e :3 0 54e 9b0
9b2 :3 0 4d :2 0
83 :4 0 551 9b4
9b6 :3 0 4d :2 0
8c :4 0 554 9b8
9ba :3 0 4d :2 0
52 :3 0 56 :3 0
23 :2 0 557 9be
9c0 55 :4 0 559
9bd 9c3 55c 9bc
9c5 :3 0 4d :2 0
8e :4 0 55f 9c7
9c9 :3 0 4d :2 0
50 :4 0 562 9cb
9cd :3 0 4d :2 0
3 :3 0 565 9cf
9d1 :3 0 4d :2 0
50 :4 0 568 9d3
9d5 :3 0 56b 9ad
9d7 :2 0 9d9 56e
9da 9aa 9d9 0
9db 570 0 a03
45 :3 0 46 :3 0
9dc 9dd 0 45
:3 0 58 :3 0 9df
9e0 0 f :2 0
2 :4 0 e9 :2 0
5a :2 0 f :2 0
572 9e5 9e7 :3 0
575 9e1 9e9 9de
9eb 9ea :2 0 48
:3 0 5b :3 0 9ed
9ee 0 4a :4 0
ea :4 0 4d :2 0
4e :3 0 579 9f2
9f4 :3 0 57c 9ef
9f6 :2 0 9f8 57f
9f9 9ec 9f8 0
9fa 581 0 a03
91 :3 0 92 :3 0
9fb 9fc 0 23
:2 0 3 :3 0 93
:3 0 583 9fd a01
:2 0 a03 587 a04
999 a03 0 a06
8a4 8a9 0 a06
58b 0 a07 58f
a0f 37 :3 0 23
:2 0 a08 a09 0
a0e 19 :4 0 a0b
a0c 0 a0e 593
a10 820 a07 0
a11 0 a0e 0
a11 596 0 10c7
7 :3 0 a6 :2 0
599 a13 a14 :3 0
a15 :2 0 5 :3 0
bf :2 0 59b a18
a19 :3 0 a1a :2 0
a1b :2 0 a7 :3 0
a8 :3 0 a1d a1e
0 1a :3 0 29
:3 0 a9 :2 0 59d
a1f a23 aa :2 0
23 :2 0 5a3 a25
a27 :3 0 a28 :2 0
a1c a2a a29 :2 0
45 :3 0 46 :3 0
a2c a2d 0 45
:3 0 58 :3 0 a2f
a30 0 11 :2 0
2 :4 0 eb :2 0
5a :2 0 f :2 0
5a6 a35 a37 :3 0
5a9 a31 a39 a2e
a3b a3a :2 0 48
:3 0 5b :3 0 a3d
a3e 0 4a :4 0
ec :4 0 4d :2 0
4e :3 0 5ad a42
a44 :3 0 4d :2 0
83 :4 0 5b0 a46
a48 :3 0 4d :2 0
8c :4 0 5b3 a4a
a4c :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 ed :3 0
a51 a52 0 5b6
a50 a54 55 :4 0
5b8 a4f a57 5bb
a4e a59 :3 0 4d
:2 0 8e :4 0 5be
a5b a5d :3 0 4d
:2 0 50 :4 0 5c1
a5f a61 :3 0 4d
:2 0 3 :3 0 5c4
a63 a65 :3 0 4d
:2 0 50 :4 0 5c7
a67 a69 :3 0 5ca
a3f a6b :2 0 a6d
5cd a6e a3c a6d
0 a6f 5cf 0
a9a 45 :3 0 46
:3 0 a70 a71 0
45 :3 0 58 :3 0
a73 a74 0 f
:2 0 2 :4 0 ee
:2 0 5a :2 0 f
:2 0 5d1 a79 a7b
:3 0 5d4 a75 a7d
a72 a7f a7e :2 0
48 :3 0 5b :3 0
a81 a82 0 4a
:4 0 ef :4 0 4d
:2 0 4e :3 0 5d8
a86 a88 :3 0 5db
a83 a8a :2 0 a8c
5de a8d a80 a8c
0 a8e 5e0 0
a9a 91 :3 0 92
:3 0 a8f a90 0
5f :3 0 ed :3 0
a92 a93 0 3
:3 0 93 :3 0 5e2
a91 a97 :2 0 a9a
d7 :3 0 5e6 b0e
2b :3 0 a6 :2 0
5ea a9c a9d :3 0
a9e :2 0 a9f :2 0
a7 :3 0 a8 :3 0
aa1 aa2 0 1a
:3 0 2b :3 0 a9
:2 0 5ec aa3 aa7
f0 :2 0 23 :2 0
5f2 aa9 aab :3 0
aac :2 0 aa0 aae
aad :2 0 45 :3 0
46 :3 0 ab0 ab1
0 45 :3 0 58
:3 0 ab3 ab4 0
f1 :2 0 2 :4 0
f2 :2 0 5a :2 0
f :2 0 5f5 ab9
abb :3 0 5f8 ab5
abd ab2 abf abe
:2 0 48 :3 0 5b
:3 0 ac1 ac2 0
4a :4 0 f3 :4 0
4d :2 0 4e :3 0
5fc ac6 ac8 :3 0
4d :2 0 83 :4 0
5ff aca acc :3 0
4d :2 0 8c :4 0
602 ace ad0 :3 0
4d :2 0 52 :3 0
56 :3 0 5f :3 0
d4 :3 0 ad5 ad6
0 605 ad4 ad8
55 :4 0 607 ad3
adb 60a ad2 add
:3 0 60d ac3 adf
:2 0 ae1 610 ae2
ac0 ae1 0 ae3
612 0 b0c 45
:3 0 46 :3 0 ae4
ae5 0 45 :3 0
58 :3 0 ae7 ae8
0 f :2 0 2
:4 0 f4 :2 0 5a
:2 0 f :2 0 614
aed aef :3 0 617
ae9 af1 ae6 af3
af2 :2 0 48 :3 0
5b :3 0 af5 af6
0 4a :4 0 f5
:4 0 4d :2 0 4e
:3 0 61b afa afc
:3 0 61e af7 afe
:2 0 b00 621 b01
af4 b00 0 b02
623 0 b0c 91
:3 0 f6 :3 0 b03
b04 0 5f :3 0
d4 :3 0 b06 b07
0 93 :3 0 625
b05 b0a :2 0 b0c
628 b0d aaf b0c
0 b0f a2b a9a
0 b0f 62c 0
ca4 5 :3 0 bf
:2 0 62f b11 b12
:3 0 b13 :2 0 b14
:2 0 a7 :3 0 a8
:3 0 b16 b17 0
1a :3 0 1c :3 0
a9 :2 0 631 b18
b1c aa :2 0 23
:2 0 637 b1e b20
:3 0 b21 :2 0 b15
b23 b22 :2 0 3c
:3 0 f :2 0 b25
b26 0 b28 63a
b2d 3c :3 0 23
:2 0 b29 b2a 0
b2c 63c b2e b24
b28 0 b2f 0
b2c 0 b2f 63e
0 ca4 a7 :3 0
a8 :3 0 b30 b31
0 1a :3 0 2a
:3 0 a9 :2 0 641
b32 b36 5e :2 0
23 :2 0 647 b38
b3a :3 0 1a :4 0
b3c b3d 0 b40
d7 :3 0 64a ca2
a7 :3 0 ba :3 0
b41 b42 0 1a
:3 0 1c :3 0 64c
b43 b46 bb :2 0
23 :2 0 651 b48
b4a :3 0 a7 :3 0
d8 :3 0 d9 :3 0
a7 :3 0 da :3 0
db :3 0 f7 :3 0
dd :3 0 1a :3 0
de :3 0 96 :3 0
10 :3 0 d9 :3 0
df :3 0 86 :3 0
7 :4 0 f8 1
:8 0 b62 c :3 0
7c :3 0 b5d b5e
0 7d :3 0 b5f
b60 0 b62 654
bb5 7e :3 0 c
:3 0 7c :3 0 b64
b65 0 7d :3 0
b66 b67 0 b69
657 b6b 659 b6a
b69 :2 0 bb3 7f
:3 0 c :3 0 7c
:3 0 b6e b6f 0
7d :3 0 b70 b71
0 bab 45 :3 0
46 :3 0 b73 b74
0 45 :3 0 58
:3 0 b76 b77 0
80 :2 0 2 :4 0
f9 :2 0 5a :2 0
f :2 0 65b b7c
b7e :3 0 65e b78
b80 b75 b82 b81
:2 0 48 :3 0 5b
:3 0 b84 b85 0
4a :4 0 fa :4 0
4d :2 0 4e :3 0
662 b89 b8b :3 0
4d :2 0 83 :4 0
665 b8d b8f :3 0
4d :2 0 84 :4 0
668 b91 b93 :3 0
4d :2 0 7d :3 0
66b b95 b97 :3 0
4d :2 0 85 :4 0
66e b99 b9b :3 0
4d :2 0 86 :3 0
87 :3 0 f :2 0
88 :2 0 671 b9e
ba2 675 b9d ba4
:3 0 678 b86 ba6
:2 0 ba8 67b ba9
b83 ba8 0 baa
67d 0 bab 67f
bae :3 0 bae 0
bae bad bab bac
:6 0 bb0 12 :3 0
682 bb2 684 bb1
bb0 :2 0 bb3 686
:2 0 bb5 0 bb5
bb4 b62 bb3 :6 0
c29 1 :3 0 c
:3 0 7c :3 0 bb7
bb8 0 c :3 0
5e :2 0 89 :3 0
bba bbc 0 68b
bbb bbe :3 0 bbf
:2 0 a7 :3 0 d8
:3 0 df :3 0 86
:3 0 7 :3 0 a7
:3 0 da :3 0 1a
:3 0 e3 :4 0 fb
1 :8 0 bd0 c
:3 0 7c :3 0 bcb
bcc 0 7d :3 0
bcd bce 0 bd0
68e c23 7e :3 0
c :3 0 7c :3 0
bd2 bd3 0 7d
:3 0 bd4 bd5 0
bd7 691 bd9 693
bd8 bd7 :2 0 c21
7f :3 0 c :3 0
7c :3 0 bdc bdd
0 7d :3 0 bde
bdf 0 c19 45
:3 0 46 :3 0 be1
be2 0 45 :3 0
58 :3 0 be4 be5
0 80 :2 0 2
:4 0 fc :2 0 5a
:2 0 f :2 0 695
bea bec :3 0 698
be6 bee be3 bf0
bef :2 0 48 :3 0
5b :3 0 bf2 bf3
0 4a :4 0 fd
:4 0 4d :2 0 4e
:3 0 69c bf7 bf9
:3 0 4d :2 0 83
:4 0 69f bfb bfd
:3 0 4d :2 0 84
:4 0 6a2 bff c01
:3 0 4d :2 0 7d
:3 0 6a5 c03 c05
:3 0 4d :2 0 85
:4 0 6a8 c07 c09
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 6ab
c0c c10 6af c0b
c12 :3 0 6b2 bf4
c14 :2 0 c16 6b5
c17 bf1 c16 0
c18 6b7 0 c19
6b9 c1c :3 0 c1c
0 c1c c1b c19
c1a :6 0 c1e 14
:3 0 6bc c20 6be
c1f c1e :2 0 c21
6c0 :2 0 c23 0
c23 c22 bd0 c21
:6 0 c25 1 :3 0
6c3 c26 bc0 c25
0 c27 6c5 0
c29 d7 :3 0 6c7
c2a b4b c29 0
ca3 a7 :3 0 a8
:3 0 c2b c2c 0
1a :3 0 29 :3 0
a9 :2 0 6ca c2d
c31 5e :2 0 23
:2 0 6d0 c33 c35
:3 0 45 :3 0 46
:3 0 c37 c38 0
45 :3 0 58 :3 0
c3a c3b 0 11
:2 0 2 :4 0 fe
:2 0 5a :2 0 f
:2 0 6d3 c40 c42
:3 0 6d6 c3c c44
c39 c46 c45 :2 0
48 :3 0 5b :3 0
c48 c49 0 4a
:4 0 ff :4 0 4d
:2 0 4e :3 0 6da
c4d c4f :3 0 4d
:2 0 83 :4 0 6dd
c51 c53 :3 0 4d
:2 0 8c :4 0 6e0
c55 c57 :3 0 4d
:2 0 52 :3 0 56
:3 0 23 :2 0 6e3
c5b c5d 55 :4 0
6e5 c5a c60 6e8
c59 c62 :3 0 4d
:2 0 8e :4 0 6eb
c64 c66 :3 0 4d
:2 0 50 :4 0 6ee
c68 c6a :3 0 4d
:2 0 3 :3 0 6f1
c6c c6e :3 0 4d
:2 0 50 :4 0 6f4
c70 c72 :3 0 6f7
c4a c74 :2 0 c76
6fa c77 c47 c76
0 c78 6fc 0
ca0 45 :3 0 46
:3 0 c79 c7a 0
45 :3 0 58 :3 0
c7c c7d 0 f
:2 0 2 :4 0 100
:2 0 5a :2 0 f
:2 0 6fe c82 c84
:3 0 701 c7e c86
c7b c88 c87 :2 0
48 :3 0 5b :3 0
c8a c8b 0 4a
:4 0 101 :4 0 4d
:2 0 4e :3 0 705
c8f c91 :3 0 708
c8c c93 :2 0 c95
70b c96 c89 c95
0 c97 70d 0
ca0 91 :3 0 92
:3 0 c98 c99 0
23 :2 0 3 :3 0
93 :3 0 70f c9a
c9e :2 0 ca0 713
ca1 c36 ca0 0
ca3 b3b b40 0
ca3 717 0 ca4
71b ca9 1a :4 0
ca5 ca6 0 ca8
71f caa a16 ca4
0 cab 0 ca8
0 cab 721 0
10c7 17 :3 0 a
:3 0 cac cad 0
10c7 3d :3 0 23
:2 0 caf cb0 0
10c7 52 :3 0 3a
:3 0 23 :2 0 724
cb2 cb5 5f :3 0
bb :2 0 60 :3 0
cb7 cb9 0 729
cb8 cbb :3 0 79
:3 0 67 :3 0 19
:3 0 69 :3 0 1a
:3 0 c0 :3 0 7a
:3 0 3 :4 0 102
1 :8 0 cdb c2
:4 0 cc6 :3 0 93
:3 0 5e :2 0 72e
cc9 cca :3 0 c
:3 0 7c :3 0 ccc
ccd 0 23 :2 0
cce ccf 0 cd1
731 cd8 c :3 0
7c :3 0 cd2 cd3
0 c3 :2 0 cd4
cd5 0 cd7 733
cd9 ccb cd1 0
cda 0 cd7 0
cda 735 0 cdb
738 d2e 7e :3 0
c :3 0 7c :3 0
cdd cde 0 7d
:3 0 cdf ce0 0
ce2 73b ce4 73d
ce3 ce2 :2 0 d2c
7f :3 0 c :3 0
7c :3 0 ce7 ce8
0 7d :3 0 ce9
cea 0 d24 45
:3 0 46 :3 0 cec
ced 0 45 :3 0
58 :3 0 cef cf0
0 80 :2 0 2
:4 0 103 :2 0 5a
:2 0 f :2 0 73f
cf5 cf7 :3 0 742
cf1 cf9 cee cfb
cfa :2 0 48 :3 0
5b :3 0 cfd cfe
0 4a :4 0 104
:4 0 4d :2 0 4e
:3 0 746 d02 d04
:3 0 4d :2 0 83
:4 0 749 d06 d08
:3 0 4d :2 0 84
:4 0 74c d0a d0c
:3 0 4d :2 0 7d
:3 0 74f d0e d10
:3 0 4d :2 0 85
:4 0 752 d12 d14
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 755
d17 d1b 759 d16
d1d :3 0 75c cff
d1f :2 0 d21 75f
d22 cfc d21 0
d23 761 0 d24
763 d27 :3 0 d27
0 d27 d26 d24
d25 :6 0 d29 16
:3 0 766 d2b 768
d2a d29 :2 0 d2c
76a :2 0 d2e 0
d2e d2d cdb d2c
:6 0 d30 1 :3 0
76d 10c4 13 :3 0
a6 :2 0 76f d32
d33 :3 0 d34 :2 0
7 :3 0 a6 :2 0
771 d37 d38 :3 0
d39 :2 0 3d :3 0
23 :2 0 d3b d3c
0 e22 105 :3 0
3d :3 0 e3 :3 0
d9 :3 0 106 :3 0
61 :3 0 10 :3 0
7a :3 0 13 :3 0
7a :3 0 14 :3 0
d9 :3 0 df :3 0
86 :3 0 7 :4 0
107 1 :8 0 d53
c :3 0 7c :3 0
d4e d4f 0 7d
:3 0 d50 d51 0
d53 773 da6 7e
:3 0 c :3 0 7c
:3 0 d55 d56 0
7d :3 0 d57 d58
0 d5a 776 d5c
778 d5b d5a :2 0
da4 7f :3 0 c
:3 0 7c :3 0 d5f
d60 0 7d :3 0
d61 d62 0 d9c
45 :3 0 46 :3 0
d64 d65 0 45
:3 0 58 :3 0 d67
d68 0 80 :2 0
2 :4 0 108 :2 0
5a :2 0 f :2 0
77a d6d d6f :3 0
77d d69 d71 d66
d73 d72 :2 0 48
:3 0 5b :3 0 d75
d76 0 4a :4 0
109 :4 0 4d :2 0
4e :3 0 781 d7a
d7c :3 0 4d :2 0
83 :4 0 784 d7e
d80 :3 0 4d :2 0
84 :4 0 787 d82
d84 :3 0 4d :2 0
7d :3 0 78a d86
d88 :3 0 4d :2 0
85 :4 0 78d d8a
d8c :3 0 4d :2 0
86 :3 0 87 :3 0
f :2 0 88 :2 0
790 d8f d93 794
d8e d95 :3 0 797
d77 d97 :2 0 d99
79a d9a d74 d99
0 d9b 79c 0
d9c 79e d9f :3 0
d9f 0 d9f d9e
d9c d9d :6 0 da1
18 :3 0 7a1 da3
7a3 da2 da1 :2 0
da4 7a5 :2 0 da6
0 da6 da5 d53
da4 :6 0 e22 1
:3 0 52 :3 0 3d
:3 0 23 :2 0 7a8
da8 dab 5e :2 0
23 :2 0 7ad dad
daf :3 0 45 :3 0
46 :3 0 db1 db2
0 45 :3 0 58
:3 0 db4 db5 0
11 :2 0 2 :4 0
10a :2 0 5a :2 0
f :2 0 7b0 dba
dbc :3 0 7b3 db6
dbe db3 dc0 dbf
:2 0 48 :3 0 5b
:3 0 dc2 dc3 0
4a :4 0 10b :4 0
4d :2 0 4e :3 0
7b7 dc7 dc9 :3 0
4d :2 0 83 :4 0
7ba dcb dcd :3 0
4d :2 0 8c :4 0
7bd dcf dd1 :3 0
4d :2 0 52 :3 0
56 :3 0 5f :3 0
10c :3 0 dd6 dd7
0 7c0 dd5 dd9
55 :4 0 7c2 dd4
ddc 7c5 dd3 dde
:3 0 4d :2 0 8e
:4 0 7c8 de0 de2
:3 0 4d :2 0 50
:4 0 7cb de4 de6
:3 0 4d :2 0 14
:3 0 7ce de8 dea
:3 0 4d :2 0 50
:4 0 7d1 dec dee
:3 0 7d4 dc4 df0
:2 0 df2 7d7 df3
dc1 df2 0 df4
7d9 0 e1e 45
:3 0 46 :3 0 df5
df6 0 45 :3 0
58 :3 0 df8 df9
0 f :2 0 2
:4 0 10d :2 0 5a
:2 0 f :2 0 7db
dfe e00 :3 0 7de
dfa e02 df7 e04
e03 :2 0 48 :3 0
5b :3 0 e06 e07
0 4a :4 0 10e
:4 0 4d :2 0 4e
:3 0 7e2 e0b e0d
:3 0 7e5 e08 e0f
:2 0 e11 7e8 e12
e05 e11 0 e13
7ea 0 e1e 91
:3 0 92 :3 0 e14
e15 0 5f :3 0
10c :3 0 e17 e18
0 14 :3 0 93
:3 0 7ec e16 e1c
:2 0 e1e 7f0 e1f
db0 e1e 0 e20
7f4 0 e22 d7
:3 0 7f6 1064 5
:3 0 a6 :2 0 7fa
e24 e25 :3 0 e26
:2 0 3d :3 0 23
:2 0 e28 e29 0
ff4 105 :3 0 3d
:3 0 e3 :3 0 d9
:3 0 106 :3 0 61
:3 0 10 :3 0 7a
:3 0 13 :3 0 7a
:3 0 14 :3 0 d9
:3 0 df :3 0 86
:3 0 5 :4 0 10f
1 :8 0 e40 c
:3 0 7c :3 0 e3b
e3c 0 7d :3 0
e3d e3e 0 e40
7fc e93 7e :3 0
c :3 0 7c :3 0
e42 e43 0 7d
:3 0 e44 e45 0
e47 7ff e49 801
e48 e47 :2 0 e91
7f :3 0 c :3 0
7c :3 0 e4c e4d
0 7d :3 0 e4e
e4f 0 e89 45
:3 0 46 :3 0 e51
e52 0 45 :3 0
58 :3 0 e54 e55
0 80 :2 0 2
:4 0 110 :2 0 5a
:2 0 f :2 0 803
e5a e5c :3 0 806
e56 e5e e53 e60
e5f :2 0 48 :3 0
5b :3 0 e62 e63
0 4a :4 0 111
:4 0 4d :2 0 4e
:3 0 80a e67 e69
:3 0 4d :2 0 83
:4 0 80d e6b e6d
:3 0 4d :2 0 84
:4 0 810 e6f e71
:3 0 4d :2 0 7d
:3 0 813 e73 e75
:3 0 4d :2 0 85
:4 0 816 e77 e79
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 819
e7c e80 81d e7b
e82 :3 0 820 e64
e84 :2 0 e86 823
e87 e61 e86 0
e88 825 0 e89
827 e8c :3 0 e8c
0 e8c e8b e89
e8a :6 0 e8e 1a
:3 0 82a e90 82c
e8f e8e :2 0 e91
82e :2 0 e93 0
e93 e92 e40 e91
:6 0 ff4 1 :3 0
52 :3 0 3d :3 0
23 :2 0 831 e95
e98 5e :2 0 23
:2 0 836 e9a e9c
:3 0 45 :3 0 46
:3 0 e9e e9f 0
45 :3 0 58 :3 0
ea1 ea2 0 11
:2 0 2 :4 0 112
:2 0 5a :2 0 f
:2 0 839 ea7 ea9
:3 0 83c ea3 eab
ea0 ead eac :2 0
48 :3 0 5b :3 0
eaf eb0 0 4a
:4 0 113 :4 0 4d
:2 0 4e :3 0 840
eb4 eb6 :3 0 4d
:2 0 83 :4 0 843
eb8 eba :3 0 4d
:2 0 8c :4 0 846
ebc ebe :3 0 4d
:2 0 52 :3 0 56
:3 0 5f :3 0 10c
:3 0 ec3 ec4 0
849 ec2 ec6 55
:4 0 84b ec1 ec9
84e ec0 ecb :3 0
4d :2 0 8e :4 0
851 ecd ecf :3 0
4d :2 0 50 :4 0
854 ed1 ed3 :3 0
4d :2 0 14 :3 0
857 ed5 ed7 :3 0
4d :2 0 50 :4 0
85a ed9 edb :3 0
85d eb1 edd :2 0
edf 860 ee0 eae
edf 0 ee1 862
0 f0b 45 :3 0
46 :3 0 ee2 ee3
0 45 :3 0 58
:3 0 ee5 ee6 0
f :2 0 2 :4 0
114 :2 0 5a :2 0
f :2 0 864 eeb
eed :3 0 867 ee7
eef ee4 ef1 ef0
:2 0 48 :3 0 5b
:3 0 ef3 ef4 0
4a :4 0 115 :4 0
4d :2 0 4e :3 0
86b ef8 efa :3 0
86e ef5 efc :2 0
efe 871 eff ef2
efe 0 f00 873
0 f0b 91 :3 0
92 :3 0 f01 f02
0 5f :3 0 10c
:3 0 f04 f05 0
14 :3 0 93 :3 0
875 f03 f09 :2 0
f0b 879 ff1 116
:3 0 117 :3 0 34
:3 0 106 :3 0 61
:3 0 10 :3 0 118
:3 0 13 :3 0 d9
:3 0 df :3 0 86
:3 0 5 :4 0 119
1 :8 0 f1e c
:3 0 7c :3 0 f19
f1a 0 7d :3 0
f1b f1c 0 f1e
87d f71 7e :3 0
c :3 0 7c :3 0
f20 f21 0 7d
:3 0 f22 f23 0
f25 880 f27 882
f26 f25 :2 0 f6f
7f :3 0 c :3 0
7c :3 0 f2a f2b
0 7d :3 0 f2c
f2d 0 f67 45
:3 0 46 :3 0 f2f
f30 0 45 :3 0
58 :3 0 f32 f33
0 80 :2 0 2
:4 0 11a :2 0 5a
:2 0 f :2 0 884
f38 f3a :3 0 887
f34 f3c f31 f3e
f3d :2 0 48 :3 0
5b :3 0 f40 f41
0 4a :4 0 11b
:4 0 4d :2 0 4e
:3 0 88b f45 f47
:3 0 4d :2 0 83
:4 0 88e f49 f4b
:3 0 4d :2 0 84
:4 0 891 f4d f4f
:3 0 4d :2 0 7d
:3 0 894 f51 f53
:3 0 4d :2 0 85
:4 0 897 f55 f57
:3 0 4d :2 0 86
:3 0 87 :3 0 f
:2 0 88 :2 0 89a
f5a f5e 89e f59
f60 :3 0 8a1 f42
f62 :2 0 f64 8a4
f65 f3f f64 0
f66 8a6 0 f67
8a8 f6a :3 0 f6a
0 f6a f69 f67
f68 :6 0 f6c 1c
:3 0 8ab f6e 8ad
f6d f6c :2 0 f6f
8af :2 0 f71 0
f71 f70 f1e f6f
:6 0 ff0 1 :3 0
52 :3 0 34 :3 0
23 :2 0 8b2 f73
f76 52 :3 0 aa
:2 0 33 :3 0 23
:2 0 8b5 f78 f7c
8ba f79 f7e :3 0
45 :3 0 46 :3 0
f80 f81 0 45
:3 0 58 :3 0 f83
f84 0 11 :2 0
2 :4 0 11c :2 0
5a :2 0 f :2 0
8bd f89 f8b :3 0
8c0 f85 f8d f82
f8f f8e :2 0 48
:3 0 5b :3 0 f91
f92 0 4a :4 0
11d :4 0 4d :2 0
4e :3 0 8c4 f96
f98 :3 0 4d :2 0
83 :4 0 8c7 f9a
f9c :3 0 4d :2 0
8c :4 0 8ca f9e
fa0 :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 10c :3 0
fa5 fa6 0 8cd
fa4 fa8 55 :4 0
8cf fa3 fab 8d2
fa2 fad :3 0 4d
:2 0 8e :4 0 8d5
faf fb1 :3 0 4d
:2 0 50 :4 0 8d8
fb3 fb5 :3 0 4d
:2 0 14 :3 0 8db
fb7 fb9 :3 0 4d
:2 0 50 :4 0 8de
fbb fbd :3 0 8e1
f93 fbf :2 0 fc1
8e4 fc2 f90 fc1
0 fc3 8e6 0
fed 45 :3 0 46
:3 0 fc4 fc5 0
45 :3 0 58 :3 0
fc7 fc8 0 f
:2 0 2 :4 0 11e
:2 0 5a :2 0 f
:2 0 8e8 fcd fcf
:3 0 8eb fc9 fd1
fc6 fd3 fd2 :2 0
48 :3 0 5b :3 0
fd5 fd6 0 4a
:4 0 11f :4 0 4d
:2 0 4e :3 0 8ef
fda fdc :3 0 8f2
fd7 fde :2 0 fe0
8f5 fe1 fd4 fe0
0 fe2 8f7 0
fed 91 :3 0 92
:3 0 fe3 fe4 0
5f :3 0 10c :3 0
fe6 fe7 0 14
:3 0 93 :3 0 8f9
fe5 feb :2 0 fed
8fd fee f7f fed
0 fef 901 0
ff0 903 ff2 e9d
f0b 0 ff3 0
ff0 0 ff3 906
0 ff4 909 ff5
e27 ff4 0 1066
45 :3 0 46 :3 0
ff6 ff7 0 45
:3 0 58 :3 0 ff9
ffa 0 11 :2 0
2 :4 0 120 :2 0
5a :2 0 f :2 0
90d fff 1001 :3 0
910 ffb 1003 ff8
1005 1004 :2 0 48
:3 0 5b :3 0 1007
1008 0 4a :4 0
121 :4 0 4d :2 0
4e :3 0 914 100c
100e :3 0 4d :2 0
83 :4 0 917 1010
1012 :3 0 4d :2 0
8c :4 0 91a 1014
1016 :3 0 4d :2 0
52 :3 0 56 :3 0
5f :3 0 122 :3 0
101b 101c 0 91d
101a 101e 55 :4 0
91f 1019 1021 922
1018 1023 :3 0 4d
:2 0 8e :4 0 925
1025 1027 :3 0 4d
:2 0 50 :4 0 928
1029 102b :3 0 4d
:2 0 14 :3 0 92b
102d 102f :3 0 4d
:2 0 50 :4 0 92e
1031 1033 :3 0 931
1009 1035 :2 0 1037
934 1038 1006 1037
0 1039 936 0
1063 45 :3 0 46
:3 0 103a 103b 0
45 :3 0 58 :3 0
103d 103e 0 f
:2 0 2 :4 0 123
:2 0 5a :2 0 f
:2 0 938 1043 1045
:3 0 93b 103f 1047
103c 1049 1048 :2 0
48 :3 0 5b :3 0
104b 104c 0 4a
:4 0 124 :4 0 4d
:2 0 4e :3 0 93f
1050 1052 :3 0 942
104d 1054 :2 0 1056
945 1057 104a 1056
0 1058 947 0
1063 91 :3 0 92
:3 0 1059 105a 0
5f :3 0 122 :3 0
105c 105d 0 14
:3 0 93 :3 0 949
105b 1061 :2 0 1063
94d 1065 d3a e22
0 1066 0 1063
0 1066 951 0
1067 955 1068 d35
1067 0 1069 957
0 10c3 39 :3 0
125 :2 0 106a 106b
0 10c3 14 :3 0
3 :3 0 106d 106e
0 10c3 19 :3 0
bf :2 0 959 1071
1072 :3 0 1073 :2 0
2b :3 0 a6 :2 0
95b 1076 1077 :3 0
1078 :2 0 1079 :2 0
1074 107b 107a :2 0
19 :3 0 1b :3 0
107d 107e 0 1080
95d 1081 107c 1080
0 1082 95f 0
10c3 3e :3 0 126
:3 0 10 :3 0 12
:3 0 14 :3 0 13
:3 0 19 :3 0 1a
:3 0 2b :3 0 30
:3 0 37 :3 0 3b
:3 0 35 :3 0 33
:3 0 38 :3 0 3c
:3 0 39 :3 0 29
:3 0 2a :3 0 25
:3 0 28 :3 0 31
:3 0 32 :3 0 17
:3 0 23 :2 0 961
1084 109c 1083 109d
0 10c3 3d :3 0
125 :2 0 109f 10a0
0 10c3 3e :3 0
127 :3 0 10 :3 0
14 :3 0 3d :3 0
23 :2 0 23 :2 0
23 :2 0 979 10a3
10aa 10a2 10ab 0
10c3 13 :3 0 a6
:2 0 980 10ae 10af
:3 0 10b0 :2 0 3d
:3 0 128 :2 0 10b2
10b3 0 10c0 3e
:3 0 127 :3 0 10
:3 0 13 :3 0 3d
:3 0 23 :2 0 23
:2 0 23 :2 0 982
10b6 10bd 10b5 10be
0 10c0 989 10c1
10b1 10c0 0 10c2
98c 0 10c3 98e
10c5 cbc d30 0
10c6 0 10c3 0
10c6 997 0 10c7
99a 10c8 774 10c7
0 10c9 9a2 0
10ca 9a4 10cc 5d3
647 0 10cd 0
10ca 0 10cd 9a8
0 1173 a7 :3 0
ba :3 0 10ce 10cf
0 16 :3 0 17
:3 0 9ab 10d0 10d3
5e :2 0 23 :2 0
9b0 10d5 10d7 :3 0
10d8 :2 0 52 :3 0
3a :3 0 23 :2 0
9b3 10da 10dd 5f
:3 0 bb :2 0 60
:3 0 10df 10e1 0
9b8 10e0 10e3 :3 0
10e4 :2 0 10d9 10e6
10e5 :2 0 40 :3 0
bc :4 0 10e8 10e9
0 111c 3f :3 0
125 :2 0 10eb 10ec
0 111c 43 :3 0
c :3 0 7c :3 0
10ef 10f0 0 10ee
10f1 0 111c 41
:3 0 bd :3 0 40
:3 0 14 :3 0 17
:3 0 3f :3 0 23
:2 0 9bb 10f4 10fa
10f3 10fb 0 111c
c :3 0 7c :3 0
10fd 10fe 0 43
:3 0 10ff 1100 0
111c 40 :3 0 be
:4 0 1102 1103 0
111c 3f :3 0 125
:2 0 1105 1106 0
111c 43 :3 0 c
:3 0 7c :3 0 1109
110a 0 1108 110b
0 111c 41 :3 0
bd :3 0 40 :3 0
14 :3 0 17 :3 0
3f :3 0 23 :2 0
9c1 110e 1114 110d
1115 0 111c c
:3 0 7c :3 0 1117
1118 0 43 :3 0
1119 111a 0 111c
9c7 111d 10e7 111c
0 111e 9d2 0
1173 3e :3 0 129
:3 0 10 :3 0 9d4
1120 1122 111f 1123
0 1173 45 :3 0
46 :3 0 1125 1126
0 45 :3 0 58
:3 0 1128 1129 0
12a :2 0 2 :4 0
12b :2 0 5a :2 0
f :2 0 9d6 112e
1130 :3 0 9d9 112a
1132 1127 1134 1133
:2 0 48 :3 0 5b
:3 0 1136 1137 0
4a :4 0 12c :4 0
4d :2 0 4e :3 0
9dd 113b 113d :3 0
4d :2 0 83 :4 0
9e0 113f 1141 :3 0
4d :2 0 8c :4 0
9e3 1143 1145 :3 0
4d :2 0 52 :3 0
56 :3 0 c :3 0
7c :3 0 114a 114b
0 9e6 1149 114d
55 :4 0 9e8 1148
1150 9eb 1147 1152
:3 0 4d :2 0 8e
:4 0 9ee 1154 1156
:3 0 4d :2 0 50
:4 0 9f1 1158 115a
:3 0 4d :2 0 3
:3 0 9f4 115c 115e
:3 0 4d :2 0 50
:4 0 9f7 1160 1162
:3 0 9fa 1138 1164
:2 0 1166 9fd 1167
1135 1166 0 1168
9ff 0 1173 91
:3 0 12d :3 0 1169
116a 0 c :3 0
7c :3 0 116c 116d
0 3 :3 0 93
:3 0 a01 116b 1171
:2 0 1173 a05 1214
c :3 0 12e :2 0
4 1174 1175 0
45 :3 0 46 :3 0
1177 1178 0 45
:3 0 58 :3 0 117a
117b 0 80 :2 0
2 :4 0 12f :2 0
5a :2 0 f :2 0
a20 1180 1182 :3 0
a23 117c 1184 1179
1186 1185 :2 0 48
:3 0 5b :3 0 1188
1189 0 4a :4 0
130 :4 0 4d :2 0
4e :3 0 a27 118d
118f :3 0 a2a 118a
1191 :2 0 11aa 48
:3 0 5b :3 0 1193
1194 0 4a :4 0
131 :4 0 4d :2 0
c :3 0 b3 :3 0
1199 119a 0 a2d
1198 119c :3 0 4d
:2 0 8e :4 0 a30
119e 11a0 :3 0 4d
:2 0 c :3 0 132
:3 0 11a3 11a4 0
a33 11a2 11a6 :3 0
a36 1195 11a8 :2 0
11aa a39 11ab 1187
11aa 0 11ac a3c
0 11bc 133 :3 0
44 :3 0 c :3 0
b3 :3 0 134 :3 0
c :3 0 132 :3 0
135 :3 0 e3 :4 0
136 1 :a 0 11b8
:2 0 11bc 11ae 11b6
:2 0 b :3 0 44
:3 0 11ba :2 0 11bc
a3e 11be a42 11bd
11bc :2 0 1212 7f
:3 0 c :3 0 7c
:3 0 11c1 11c2 0
7d :3 0 11c3 11c4
0 120a 45 :3 0
46 :3 0 11c6 11c7
0 45 :3 0 58
:3 0 11c9 11ca 0
80 :2 0 2 :4 0
137 :2 0 5a :2 0
f :2 0 a44 11cf
11d1 :3 0 a47 11cb
11d3 11c8 11d5 11d4
:2 0 48 :3 0 5b
:3 0 11d7 11d8 0
4a :4 0 138 :4 0
4d :2 0 4e :3 0
a4b 11dc 11de :3 0
a4e 11d9 11e0 :2 0
11fa 48 :3 0 5b
:3 0 11e2 11e3 0
4a :4 0 84 :4 0
4d :2 0 7d :3 0
a51 11e7 11e9 :3 0
4d :2 0 85 :4 0
a54 11eb 11ed :3 0
4d :2 0 86 :3 0
87 :3 0 f :2 0
88 :2 0 a57 11f0
11f4 a5b 11ef 11f6
:3 0 a5e 11e4 11f8
:2 0 11fa a61 11fb
11d6 11fa 0 11fc
a64 0 120a 133
:3 0 44 :3 0 134
:3 0 c :3 0 132
:3 0 135 :3 0 e3
:4 0 139 1 :a 0
1206 :2 0 120a 11fe
1204 :2 0 b :3 0
44 :3 0 1208 :2 0
120a a66 120d :3 0
120d 0 120d 120c
120a 120b :6 0 120f
1 :3 0 a6b 1211
a6d 1210 120f :2 0
1212 a6f :2 0 1214
a72 1214 1213 1173
1212 :6 0 1215 :2 0
2 1c 1214 1218
:3 0 1217 1215 1219
:8 0 
aa2
4
:3 0 1 3 1
7 1 b 1
f 1 13 5
6 a e 12
16 1 20 1
1e 1 27 1
25 1 2e 1
2c 1 35 1
33 1 3c 1
3a 1 43 1
41 1 4a 1
48 1 51 1
4f 1 58 1
56 1 5d 1
62 1 67 1
6c 1 71 1
76 1 7b 1
82 1 80 1
87 1 8d 1
93 1 99 1
9f 1 a4 1
a9 1 ae 1
b3 1 b8 1
bf 1 bd 1
c4 1 ca 1
d0 1 d6 1
dc 1 e2 1
e8 1 ee 1
f4 1 fa 1
100 1 106 1
10c 1 112 1
118 1 120 1
11e 1 125 1
12a 1 130 1
13d 1 149 2
14c 14e 2 151
153 2 155 157
2 159 15b 2
15d 15f 2 165
167 2 169 16b
2 16d 16e 2
170 171 2 161
173 2 175 177
2 17d 17f 2
181 183 2 185
186 2 188 189
2 179 18b 2
18d 18f 1 195
2 197 198 2
191 19a 2 19c
19e 2 1a0 1a2
2 1a4 1a6 2
1a8 1aa 2 1ac
1ae 4 145 14b
150 1b0 1 1b2
1 1b4 2 1be
1c0 3 1bc 1bd
1c2 2 1cb 1cd
2 1ca 1cf 1
1d1 1 1d3 2
1eb 1ec 1 1f0
2 1ee 1f0 1
1f8 1 1fa 2
233 238 1 23f
1 23a 2 252
254 3 250 251
256 2 25f 261
2 263 265 2
267 269 2 26b
26d 2 26f 271
3 276 277 278
2 273 27a 2
25e 27c 1 27e
1 280 2 249
281 1 285 1
244 2 242 289
1 294 2 290
294 2 2a0 2a2
3 29e 29f 2a4
2 2ad 2af 2
2b1 2b3 2 2b5
2b7 1 2bf 2
2c1 2c2 2 2b9
2c4 2 2c6 2c8
2 2ca 2cc 2
2ce 2d0 2 2d2
2d4 2 2ac 2d6
1 2d8 1 2da
2 2e4 2e6 3
2e2 2e3 2e8 2
2f1 2f3 2 2f0
2f5 1 2f7 1
2f9 3 300 301
302 3 2db 2fa
304 1 306 2
30f 314 1 31b
1 316 2 32e
330 3 32c 32d
332 2 33b 33d
2 33f 341 2
343 345 2 347
349 2 34b 34d
3 352 353 354
2 34f 356 2
33a 358 1 35a
1 35c 2 325
35d 1 361 1
320 2 31e 365
3 36b 36c 36d
1 371 2 36f
371 2 37c 37e
3 37a 37b 380
2 389 38b 2
38d 38f 2 391
393 1 39b 2
39d 39e 2 395
3a0 2 3a2 3a4
2 3a6 3a8 2
3aa 3ac 2 3ae
3b0 2 388 3b2
1 3b4 1 3b6
2 3c0 3c2 3
3be 3bf 3c4 2
3cd 3cf 2 3cc
3d1 1 3d3 1
3d5 3 3dc 3dd
3de 3 3b7 3d6
3e0 1 3e2 2
3e5 3e6 1 3ea
2 3e8 3ea 2
3f5 3f7 3 3f3
3f4 3f9 2 402
404 2 406 408
2 40a 40c 1
414 2 416 417
2 40e 419 2
41b 41d 2 41f
421 2 423 425
2 427 429 2
401 42b 1 42d
1 42f 2 439
43b 3 437 438
43d 2 446 448
2 445 44a 1
44c 1 44e 3
455 456 457 3
430 44f 459 1
45b 1 45d 1
463 3 46e 46f
470 1 474 2
472 474 2 47f
481 3 47d 47e
483 2 48c 48e
2 490 492 2
494 496 1 49e
2 4a0 4a1 2
498 4a3 2 4a5
4a7 2 4a9 4ab
2 4ad 4af 2
4b1 4b3 2 48b
4b5 1 4b7 1
4b9 2 4c3 4c5
3 4c1 4c2 4c7
2 4d0 4d2 2
4cf 4d4 1 4d6
1 4d8 3 4df
4e0 4e1 3 4ba
4d9 4e3 1 4e5
1 4e6 1 4e8
2 4fc 501 1
508 1 503 2
51b 51d 3 519
51a 51f 2 528
52a 2 52c 52e
2 530 532 2
534 536 2 538
53a 3 53f 540
541 2 53c 543
2 527 545 1
547 1 549 2
512 54a 1 54e
1 50d 2 50b
552 2 55d 55e
1 562 2 560
562 2 567 568
1 56e 2 56a
56e 5 581 582
583 584 585 5
59b 59c 59d 59e
59f a 576 579
57e 588 58d 590
593 598 5a2 5a7
1 5a9 1 5ab
3 5b4 5b5 5b6
1 5ba 2 5b8
5ba 1 5c2 1
5c4 1 5c6 1
5cc 1 5df 2
5de 5df 1 5e7
1 5ed 2 5ef
5f0 2 5dc 5f1
1 5f8 1 5f3
2 60b 60d 3
609 60a 60f 2
618 61a 2 61c
61e 2 620 622
2 624 626 2
628 62a 3 62f
630 631 2 62c
633 2 617 635
1 637 1 639
2 602 63a 1
63e 1 5fd 2
5fb 642 1 645
1 648 1 64d
1 65d 2 65c
65d 1 665 1
66b 2 66d 66e
2 65a 66f 1
676 1 671 2
689 68b 3 687
688 68d 2 696
698 2 69a 69c
2 69e 6a0 2
6a2 6a4 2 6a6
6a8 3 6ad 6ae
6af 2 6aa 6b1
2 695 6b3 1
6b5 1 6b7 2
680 6b8 1 6bc
1 67b 2 679
6c0 3 6c8 6c9
6ca 1 6ce 2
6cc 6ce 1 6d3
1 6d5 2 6c3
6d6 1 6d8 1
6da 1 6df 1
6ef 2 6ee 6ef
1 6f7 1 6fd
2 6ff 700 2
6ec 701 1 708
1 703 2 71b
71d 3 719 71a
71f 2 728 72a
2 72c 72e 2
730 732 2 734
736 2 738 73a
3 73f 740 741
2 73c 743 2
727 745 1 747
1 749 2 712
74a 1 74e 1
70d 2 70b 752
3 75a 75b 75c
1 760 2 75e
760 1 765 1
767 2 755 768
1 76a 2 76d
76e 1 772 2
770 772 1 775
3 77e 77f 780
1 784 2 782
784 1 78c 1
78e 1 790 1
796 2 7a1 7a2
1 7a6 2 7a4
7a6 2 7b4 7b6
3 7b2 7b3 7b8
2 7c1 7c3 2
7c5 7c7 2 7c9
7cb 1 7d3 2
7d5 7d6 2 7cd
7d8 2 7da 7dc
2 7de 7e0 2
7e2 7e4 2 7e6
7e8 2 7c0 7ea
1 7ec 1 7ee
2 7f8 7fa 3
7f6 7f7 7fc 2
805 807 2 804
809 1 80b 1
80d 3 814 815
816 3 7ef 80e
818 1 81a 1
81c 1 821 2
82e 830 3 82c
82d 832 2 83b
83d 2 83f 841
2 843 845 1
84d 2 84f 850
2 847 852 2
854 856 2 858
85a 2 85c 85e
2 860 862 2
83a 864 1 866
1 868 2 872
874 3 870 871
876 2 87f 881
2 87e 883 1
885 1 887 3
88e 88f 890 3
869 888 892 1
894 3 89c 89d
89e 1 8a2 2
8a0 8a2 1 8a7
3 8ad 8ae 8af
1 8b3 2 8b1
8b3 2 8c6 8cb
1 8d2 1 8cd
2 8e5 8e7 3
8e3 8e4 8e9 2
8f2 8f4 2 8f6
8f8 2 8fa 8fc
2 8fe 900 2
902 904 3 909
90a 90b 2 906
90d 2 8f1 90f
1 911 1 913
2 8dc 914 1
918 1 8d7 2
8d5 91c 1 927
2 923 927 2
934 939 1 940
1 93b 2 953
955 3 951 952
957 2 960 962
2 964 966 2
968 96a 2 96c
96e 2 970 972
3 977 978 979
2 974 97b 2
95f 97d 1 97f
1 981 2 94a
982 1 986 1
945 2 943 98a
1 98d 1 990
2 91f 991 1
995 2 9a2 9a4
3 9a0 9a1 9a6
2 9af 9b1 2
9b3 9b5 2 9b7
9b9 1 9bf 2
9c1 9c2 2 9bb
9c4 2 9c6 9c8
2 9ca 9cc 2
9ce 9d0 2 9d2
9d4 2 9ae 9d6
1 9d8 1 9da
2 9e4 9e6 3
9e2 9e3 9e8 2
9f1 9f3 2 9f0
9f5 1 9f7 1
9f9 3 9fe 9ff
a00 3 9db 9fa
a02 3 a05 994
a04 3 895 898
a06 2 a0a a0d
2 a0f a10 1
a12 1 a17 3
a20 a21 a22 1
a26 2 a24 a26
2 a34 a36 3
a32 a33 a38 2
a41 a43 2 a45
a47 2 a49 a4b
1 a53 2 a55
a56 2 a4d a58
2 a5a a5c 2
a5e a60 2 a62
a64 2 a66 a68
2 a40 a6a 1
a6c 1 a6e 2
a78 a7a 3 a76
a77 a7c 2 a85
a87 2 a84 a89
1 a8b 1 a8d
3 a94 a95 a96
3 a6f a8e a98
1 a9b 3 aa4
aa5 aa6 1 aaa
2 aa8 aaa 2
ab8 aba 3 ab6
ab7 abc 2 ac5
ac7 2 ac9 acb
2 acd acf 1
ad7 2 ad9 ada
2 ad1 adc 2
ac4 ade 1 ae0
1 ae2 2 aec
aee 3 aea aeb
af0 2 af9 afb
2 af8 afd 1
aff 1 b01 2
b08 b09 3 ae3
b02 b0b 2 b0e
b0d 1 b10 3
b19 b1a b1b 1
b1f 2 b1d b1f
1 b27 1 b2b
2 b2d b2e 3
b33 b34 b35 1
b39 2 b37 b39
1 b3e 2 b44
b45 1 b49 2
b47 b49 2 b5c
b61 1 b68 1
b63 2 b7b b7d
3 b79 b7a b7f
2 b88 b8a 2
b8c b8e 2 b90
b92 2 b94 b96
2 b98 b9a 3
b9f ba0 ba1 2
b9c ba3 2 b87
ba5 1 ba7 1
ba9 2 b72 baa
1 bae 1 b6d
2 b6b bb2 1
bbd 2 bb9 bbd
2 bca bcf 1
bd6 1 bd1 2
be9 beb 3 be7
be8 bed 2 bf6
bf8 2 bfa bfc
2 bfe c00 2
c02 c04 2 c06
c08 3 c0d c0e
c0f 2 c0a c11
2 bf5 c13 1
c15 1 c17 2
be0 c18 1 c1c
1 bdb 2 bd9
c20 1 c23 1
c26 2 bb5 c27
3 c2e c2f c30
1 c34 2 c32
c34 2 c3f c41
3 c3d c3e c43
2 c4c c4e 2
c50 c52 2 c54
c56 1 c5c 2
c5e c5f 2 c58
c61 2 c63 c65
2 c67 c69 2
c6b c6d 2 c6f
c71 2 c4b c73
1 c75 1 c77
2 c81 c83 3
c7f c80 c85 2
c8e c90 2 c8d
c92 1 c94 1
c96 3 c9b c9c
c9d 3 c78 c97
c9f 3 ca2 c2a
ca1 3 b0f b2f
ca3 1 ca7 2
ca9 caa 2 cb3
cb4 1 cba 2
cb6 cba 1 cc8
2 cc7 cc8 1
cd0 1 cd6 2
cd8 cd9 2 cc5
cda 1 ce1 1
cdc 2 cf4 cf6
3 cf2 cf3 cf8
2 d01 d03 2
d05 d07 2 d09
d0b 2 d0d d0f
2 d11 d13 3
d18 d19 d1a 2
d15 d1c 2 d00
d1e 1 d20 1
d22 2 ceb d23
1 d27 1 ce6
2 ce4 d2b 1
d2e 1 d31 1
d36 2 d4d d52
1 d59 1 d54
2 d6c d6e 3
d6a d6b d70 2
d79 d7b 2 d7d
d7f 2 d81 d83
2 d85 d87 2
d89 d8b 3 d90
d91 d92 2 d8d
d94 2 d78 d96
1 d98 1 d9a
2 d63 d9b 1
d9f 1 d5e 2
d5c da3 2 da9
daa 1 dae 2
dac dae 2 db9
dbb 3 db7 db8
dbd 2 dc6 dc8
2 dca dcc 2
dce dd0 1 dd8
2 dda ddb 2
dd2 ddd 2 ddf
de1 2 de3 de5
2 de7 de9 2
deb ded 2 dc5
def 1 df1 1
df3 2 dfd dff
3 dfb dfc e01
2 e0a e0c 2
e09 e0e 1 e10
1 e12 3 e19
e1a e1b 3 df4
e13 e1d 1 e1f
3 d3d da6 e20
1 e23 2 e3a
e3f 1 e46 1
e41 2 e59 e5b
3 e57 e58 e5d
2 e66 e68 2
e6a e6c 2 e6e
e70 2 e72 e74
2 e76 e78 3
e7d e7e e7f 2
e7a e81 2 e65
e83 1 e85 1
e87 2 e50 e88
1 e8c 1 e4b
2 e49 e90 2
e96 e97 1 e9b
2 e99 e9b 2
ea6 ea8 3 ea4
ea5 eaa 2 eb3
eb5 2 eb7 eb9
2 ebb ebd 1
ec5 2 ec7 ec8
2 ebf eca 2
ecc ece 2 ed0
ed2 2 ed4 ed6
2 ed8 eda 2
eb2 edc 1 ede
1 ee0 2 eea
eec 3 ee8 ee9
eee 2 ef7 ef9
2 ef6 efb 1
efd 1 eff 3
f06 f07 f08 3
ee1 f00 f0a 2
f18 f1d 1 f24
1 f1f 2 f37
f39 3 f35 f36
f3b 2 f44 f46
2 f48 f4a 2
f4c f4e 2 f50
f52 2 f54 f56
3 f5b f5c f5d
2 f58 f5f 2
f43 f61 1 f63
1 f65 2 f2e
f66 1 f6a 1
f29 2 f27 f6e
2 f74 f75 2
f7a f7b 1 f7d
2 f77 f7d 2
f88 f8a 3 f86
f87 f8c 2 f95
f97 2 f99 f9b
2 f9d f9f 1
fa7 2 fa9 faa
2 fa1 fac 2
fae fb0 2 fb2
fb4 2 fb6 fb8
2 fba fbc 2
f94 fbe 1 fc0
1 fc2 2 fcc
fce 3 fca fcb
fd0 2 fd9 fdb
2 fd8 fdd 1
fdf 1 fe1 3
fe8 fe9 fea 3
fc3 fe2 fec 1
fee 2 f71 fef
2 ff1 ff2 3
e2a e93 ff3 2
ffe 1000 3 ffc
ffd 1002 2 100b
100d 2 100f 1011
2 1013 1015 1
101d 2 101f 1020
2 1017 1022 2
1024 1026 2 1028
102a 2 102c 102e
2 1030 1032 2
100a 1034 1 1036
1 1038 2 1042
1044 3 1040 1041
1046 2 104f 1051
2 104e 1053 1
1055 1 1057 3
105e 105f 1060 3
1039 1058 1062 3
1064 ff5 1065 1
1066 1 1068 1
1070 1 1075 1
107f 1 1081 17
1085 1086 1087 1088
1089 108a 108b 108c
108d 108e 108f 1090
1091 1092 1093 1094
1095 1096 1097 1098
1099 109a 109b 6
10a4 10a5 10a6 10a7
10a8 10a9 1 10ad
6 10b7 10b8 10b9
10ba 10bb 10bc 2
10b4 10bf 1 10c1
8 1069 106c 106f
1082 109e 10a1 10ac
10c2 2 10c4 10c5
7 78f 81b a11
cab cae cb1 10c6
1 10c8 3 6d9
76b 10c9 2 10cb
10cc 2 10d1 10d2
1 10d6 2 10d4
10d6 2 10db 10dc
1 10e2 2 10de
10e2 5 10f5 10f6
10f7 10f8 10f9 5
110f 1110 1111 1112
1113 a 10ea 10ed
10f2 10fc 1101 1104
1107 110c 1116 111b
1 111d 1 1121
2 112d 112f 3
112b 112c 1131 2
113a 113c 2 113e
1140 2 1142 1144
1 114c 2 114e
114f 2 1146 1151
2 1153 1155 2
1157 1159 2 115b
115d 2 115f 1161
2 1139 1163 1
1165 1 1167 3
116e 116f 1170 1a
1b5 1d4 1d7 1da
1dd 1e0 1e3 1e6
1e9 1fb 28c 307
368 3e3 45c 4e9
4ec 555 559 5aa
5c5 10cd 111e 1124
1168 1172 2 117f
1181 3 117d 117e
1183 2 118c 118e
2 118b 1190 2
1197 119b 2 119d
119f 2 11a1 11a5
2 1196 11a7 2
1192 11a9 1 11ab
3 11ac 11b7 11bb
1 1176 2 11ce
11d0 3 11cc 11cd
11d2 2 11db 11dd
2 11da 11df 2
11e6 11e8 2 11ea
11ec 3 11f1 11f2
11f3 2 11ee 11f5
2 11e5 11f7 2
11e1 11f9 1 11fb
4 11c5 11fc 1205
1209 1 120d 1
11c0 2 11be 1211
2f 23 2a 31
38 3f 46 4d
54 5b 60 65
6a 6f 74 79
7e 85 8b 91
97 9d a2 a7
ac b1 b6 bb
c2 c8 ce d4
da e0 e6 ec
f2 f8 fe 104
10a 110 116 11c
123 128 12e 135

1
4
0 
1218
0
1
28
1e
35
0 1 2 1 4 1 6 1
8 1 a 1 c 1 e 1
10 1 12 1 14 1 16 1
18 1 1a 1 1c 1 0 0
0 0 0 0 0 0 0 0

13 1 0
100 1 0
10c 1 0
76 1 0
87 1 0
62 1 0
3a 1 0
33 1 0
d0 1 0
118 1 0
99 1 0
fa 1 0
125 1 0
b3 1 0
112 1 0
a9 1 0
e8 1 0
67 1 0
1e 1 0
3 1 0
9f 1 0
5d 1 0
11e 1 0
c4 1 0
56 1 0
f4 1 0
dc 1 0
6c 1 0
106 1 0
d6 1 0
41 1 0
ca 1 0
2c 1 0
80 1 0
ae 1 0
a4 1 0
7b 1 0
12a 1 0
7 1 0
bd 1 0
b8 1 0
8d 1 0
48 1 0
25 1 0
2 0 1
71 1 0
f 1 0
93 1 0
e2 1 0
4f 1 0
ee 1 0
b 1 0
130 1 0
0

/
SHOW ERRORS FUNCTION SP_U_WP_FORECAST;
ALTER FUNCTION SP_U_WP_FORECAST COMPILE DEBUG;
/*****************************************************************************/
Prompt == FUNCTION SP_U_ASSIGN_DESCR ==
CREATE OR REPLACE FUNCTION SP_U_ASSIGN_DESCR wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
57
2 :e:
1FUNCTION:
1SP_U_ASSIGN_DESCR:
1PRJ_ID:
1VARCHAR2:
1RES_ID001:
1DESCRIPTION001:
1REC_USER001:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_U_ASSIGN_DESCR(:
1':
1, :
1);:
1CHECK_TRACE:
11:
120:
1+:
1FPUT:
1               ENTER:: SP_U_ASSIGN_DESCR(21) :: cplan.sql(24127) :: :
1IS NULL:
132:
125:
1        RETURN_ERROR:: SP_U_ASSIGN_DESCR(26) :: cplan.sql(24132) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
1 ID:: :
128:
1                EXIT:: SP_U_ASSIGN_DESCR(29) :: cplan.sql(24135) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1PROJECT_ASSIGNMENTS:
1DESCRIPTION:
1RESOURCE_ID:
1PROJECT_ID:
1UPDATE PROJECT_ASSIGNMENTS:n      SET DESCRIPTION = description001:n      WHE+
1RE RESOURCE_ID = res_id001:n      AND PROJECT_ID = prj_id:
1FOUND:
1=:
1SC_STATE:
10:
1100:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
151:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(52) :: cplan.sql(24158) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
14:
157:
1       RETURN_STATUS:: SP_U_ASSIGN_DESCR(58) :: cplan.sql(24164) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
164:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(65) :: cplan.sql(24171) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
176:
1           EXCEPTION:: SP_U_ASSIGN_DESCR(77) :: cplan.sql(24183) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
283
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c a0 7e b4
2e 5a a0 7e b4 2e 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 19 3c :7 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
283
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 5e
5a 30 66 59 6b 6f 73 56
77 7b 9b 83 87 8b 8e 96
82 a2 a6 7f aa ae b2 b5
ba bb 1 bd c2 c6 ca cd
d2 d6 da dd e2 e3 e5 ea
ed f1 f2 f7 fc ff 104 105
10a 10d 111 112 117 11a 11f 120
125 128 12d 12e 133 136 13b 13c
141 144 148 149 14e 151 156 157
15c 15f 164 165 16a 16d 172 173
178 17b 17f 180 185 188 18d 18e
193 196 19b 19c 1a1 1a4 1a9 1aa
1af 1b2 1b6 1b7 1bc 1bf 1c4 1c5
1ca 1cd 1d2 1d3 1d8 1d9 1de 1e0
1e4 1e7 1eb 1ef 1f2 1f6 1fa 1fd
200 205 208 20b 20e 20f 214 215
1 217 21c 220 224 227 22c 231
234 238 239 23e 23f 244 246 24a
24d 251 254 255 25a 25d 261 264
265 26a 1 26d 272 276 27a 27d
281 285 288 28b 290 293 296 299
29a 29f 2a0 1 2a2 2a7 2ab 2af
2b2 2b7 2bc 2bf 2c3 2c4 2c9 2cc
2d1 2d2 2d7 2da 2df 2e0 2e5 2e8
2ec 2f0 2f4 2f8 2fb 2fc 2fe 303
304 306 307 30c 30f 314 315 31a
31d 322 323 328 32b 32f 330 335
338 33d 33e 343 344 349 34b 34f
352 356 35a 35d 361 365 368 36b
370 373 376 379 37a 37f 380 1
382 387 38b 38f 392 397 39c 39f
3a3 3a4 3a9 3aa 3af 3b1 3b5 3b8
3bc 3c0 3c3 3c7 3cb 3ce 3d2 3d6
3d7 3dc 3de 3e2 3e5 3e9 3ed 3f1
3f5 3f9 3fd 401 40d 411 416 41a
41d 41e 423 427 42b 42e 431 435
437 43b 43f 442 445 449 44b 44f
453 456 458 45c 460 464 467 46b
46f 471 472 477 1 47b 47f 483
486 48a 48e 492 496 499 49d 4a1
4a4 4a7 4ac 4af 4b2 4b5 4b6 4bb
4bc 1 4be 4c3 4c7 4cb 4ce 4d3
4d8 4db 4df 4e0 4e5 4e8 4ed 4ee
4f3 4f6 4fb 4fc 501 504 508 509
50e 511 516 517 51c 51f 523 527
52a 52d 52e 530 531 536 537 53c
53e 542 545 547 54b 54d 559 55b
55d 55e 563 567 569 575 577 57b
57f 582 586 58a 58d 590 595 598
59b 59e 59f 5a4 5a5 1 5a7 5ac
5b0 5b4 5b7 5bc 5c1 5c4 5c8 5c9
5ce 5d1 5d6 5d7 5dc 5df 5e4 5e5
5ea 5ed 5f1 5f5 5f9 5fd 600 601
603 608 609 60b 60c 611 614 619
61a 61f 622 627 628 62d 630 634
635 63a 63d 642 643 648 649 64e
650 654 657 65b 65f 662 666 66a
66d 671 675 676 67b 67d 681 685
688 68c 690 693 697 69b 69e 6a1
6a6 6a9 6ac 6af 6b0 6b5 6b6 1
6b8 6bd 6c1 6c5 6c8 6cd 6d2 6d5
6d9 6da 6df 6e0 6e5 6e9 6ed 6f0
6f5 6fa 6fd 701 705 708 709 70e
711 716 717 71c 71f 723 727 72a
72b 730 731 736 738 73c 73f 743
747 74b 74f 753 757 75b 75f 763
76f 774 778 77c 780 784 786 787
78c 1 790 794 798 79b 79f 7a3
7a7 7ab 7ae 7b2 7b6 7b9 7bc 7c1
7c4 7c7 7ca 7cb 7d0 7d1 1 7d3
7d8 7dc 7e0 7e3 7e8 7ed 7f0 7f4
7f5 7fa 7fb 800 804 808 80b 810
815 818 81c 81d 822 825 82a 82b
830 833 837 83b 83e 841 842 844
845 84a 84b 850 852 856 859 85d
861 865 869 86d 871 875 881 886
88a 88e 892 896 898 89c 89e 8aa
8ac 8ae 8af 8b4 8b8 8ba 8c6 8ca
8cc 8cd 8d6 
283
2
0 1 a 6 d :3 6 10 :3 6
15 :3 6 12 :2 6 1 3 a 13
a :2 1 4 e 17 :3 e 4 7
:2 11 23 :2 2d 3a :2 23 :3 7 :2 d 19
25 :2 2f 43 :2 25 59 5f 62 :2 59
70 8b 8 :2 70 d 10 :2 70 17
1a :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 28 2b :2 70 b e
:2 70 13 16 :2 70 1b 1e :2 70 2d
30 :2 70 b e :2 70 13 16 :2 70
1b 1e :2 70 2a 2d :2 70 32 35
:2 70 :2 7 4f :2 4 7 :2 11 23 :2 2d
39 3c 51 53 54 :2 51 :2 23 :3 7
:2 d 12 1e 62 65 :2 1e :2 7 57
:2 4 :4 8 7 :4 1c 1b :2 7 a :2 14
26 :2 30 3c 40 55 57 58 :2 55
:2 26 :3 a :2 10 15 21 65 68 :2 21
75 78 :2 21 7c 7f :2 21 89 8c
95 9d :2 a6 :2 95 b7 :2 8c :2 21 bf
c2 :2 21 ca cd :2 21 d2 d5 :2 21
dc df :2 21 :2 a 5b :2 7 a :2 14
26 :2 30 3c 3f 54 56 57 :2 54
:2 26 :3 a :2 10 15 21 65 68 :2 21
:2 a 5a :3 7 :2 12 26 :2 2f 3f 47
:2 7 2f :2 4 e b 19 d 1b
b 18 7 e a 16 :3 14 a
:2 13 1f a 1b a :2 13 1f a
:4 7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 58 5a 5b :2 58
:2 29 :3 d :2 13 18 24 68 6b :2 24
78 7b :2 24 7f 82 :2 24 8e 91
:2 24 99 9c :2 24 a8 ab b2 bb
be :2 ab :2 24 :2 d 5e :2 a :2 7 :4 13
:2 7 4 :3 1 7 :2 11 23 :2 2d 39
3c 51 53 54 :2 51 :2 23 :3 7 :2 d
12 1e 62 65 :2 1e 72 75 :2 1e
79 7c :2 1e 86 89 92 9a :2 a3
:2 92 ae :2 89 :2 1e b6 b9 :2 1e c1
c4 :2 1e c9 cc :2 1e d3 d6 :2 1e
:2 7 57 :3 4 :2 f 21 :2 2a 34 3c
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 55 57 58 :2 55 :2 26
:3 a :2 10 15 21 65 68 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 5b
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 52 54 55 :2 52 :2 23
:3 7 :2 d 12 1e 62 65 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 58 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
283
4
0 :2 1 :4 3 :4 4
:4 5 :4 6 2 :4 7
:2 1 :7 a :b c :11 d
e :2 d :2 e :2 d
:2 e :2 d :2 f :2 d
:2 f :2 d :2 f :2 d
:2 f :2 d :2 10 :2 d
:2 10 :2 d :2 10 :2 d
:2 10 :2 d :2 11 :2 d
:2 11 :2 d :2 11 :2 d
:2 11 :2 d :2 11 :4 d
:3 c :11 14 :b 15 :3 14
:c 18 :11 19 :30 1a :3 19
:11 1c :b 1d :3 1c :a 1f
:3 18 24 :2 25 :2 26
:2 27 24 :6 28 :5 29
28 :5 2b 2a :3 28
23 2e :5 2f :3 2e
:2 30 :5 32 :11 33 :24 34
:3 33 :2 31 :6 30 2d
:3 b :11 39 :30 3a :3 39
:a 3c b :3 3f :11 40
:b 41 :17 42 :3 40 :2 44
:3 45 :3 46 47 45
44 45 :3 48 :3 3f
:2 49 :5 4b :11 4c :b 4d
:18 4e :3 4c :2 50 51
:3 52 53 51 50
51 :3 54 :2 4a :6 49
3e :7 1 
8d8
4
:3 0 1 :3 0 2
:a 0 27e 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
56 0 7 4
:3 0 5 :7 0 9
8 :3 0 4 :3 0
6 :7 0 d c
:3 0 15 16 0
b 4 :3 0 7
:7 0 11 10 :3 0
8 :3 0 9 :3 0
a :2 0 4 13
17 0 27e 2
18 :2 0 21 22
0 10 9 :3 0
a :2 0 4 1b
1c 0 1d :7 0
20 1e 0 27c
0 b :6 0 c
:3 0 d :3 0 c
:3 0 e :3 0 24
25 0 2 :4 0
12 26 28 23
2a 29 :2 0 f
:3 0 10 :3 0 2c
2d 0 11 :4 0
c :3 0 12 :3 0
30 31 0 2
:4 0 14 32 34
13 :4 0 14 :2 0
15 :3 0 16 37
39 :3 0 16 :4 0
14 :2 0 17 :4 0
19 3c 3e :3 0
14 :2 0 3 :3 0
1c 40 42 :3 0
14 :2 0 17 :4 0
1f 44 46 :3 0
14 :2 0 18 :4 0
22 48 4a :3 0
14 :2 0 17 :4 0
25 4c 4e :3 0
14 :2 0 5 :3 0
28 50 52 :3 0
14 :2 0 17 :4 0
2b 54 56 :3 0
14 :2 0 18 :4 0
2e 58 5a :3 0
14 :2 0 17 :4 0
31 5c 5e :3 0
14 :2 0 6 :3 0
34 60 62 :3 0
14 :2 0 17 :4 0
37 64 66 :3 0
14 :2 0 18 :4 0
3a 68 6a :3 0
14 :2 0 17 :4 0
3d 6c 6e :3 0
14 :2 0 7 :3 0
40 70 72 :3 0
14 :2 0 17 :4 0
43 74 76 :3 0
14 :2 0 19 :4 0
46 78 7a :3 0
49 2e 7c :2 0
7e 4e 7f 2b
7e 0 80 50
0 1dc c :3 0
d :3 0 81 82
0 c :3 0 1a
:3 0 84 85 0
1b :2 0 2 :4 0
1c :2 0 1d :2 0
1b :2 0 52 8a
8c :3 0 55 86
8e 83 90 8f
:2 0 f :3 0 1e
:3 0 92 93 0
11 :4 0 1f :4 0
14 :2 0 15 :3 0
59 97 99 :3 0
5c 94 9b :2 0
9d 5f 9e 91
9d 0 9f 61
0 1dc 3 :3 0
20 :2 0 63 a1
a2 :3 0 a3 :2 0
5 :3 0 20 :2 0
65 a6 a7 :3 0
a8 :2 0 a4 aa
a9 :2 0 c :3 0
d :3 0 ac ad
0 c :3 0 1a
:3 0 af b0 0
21 :2 0 2 :4 0
22 :2 0 1d :2 0
1b :2 0 67 b5
b7 :3 0 6a b1
b9 ae bb ba
:2 0 f :3 0 1e
:3 0 bd be 0
11 :4 0 23 :4 0
14 :2 0 15 :3 0
6e c2 c4 :3 0
14 :2 0 24 :4 0
71 c6 c8 :3 0
14 :2 0 25 :4 0
74 ca cc :3 0
14 :2 0 26 :3 0
27 :3 0 28 :3 0
29 :3 0 d1 d2
0 77 d0 d4
2a :4 0 79 cf
d7 7c ce d9
:3 0 14 :2 0 2b
:4 0 7f db dd
:3 0 14 :2 0 17
:4 0 82 df e1
:3 0 14 :2 0 3
:3 0 85 e3 e5
:3 0 14 :2 0 17
:4 0 88 e7 e9
:3 0 8b bf eb
:2 0 ed 8e ee
bc ed 0 ef
90 0 119 c
:3 0 d :3 0 f0
f1 0 c :3 0
1a :3 0 f3 f4
0 1b :2 0 2
:4 0 2c :2 0 1d
:2 0 1b :2 0 92
f9 fb :3 0 95
f5 fd f2 ff
fe :2 0 f :3 0
1e :3 0 101 102
0 11 :4 0 2d
:4 0 14 :2 0 15
:3 0 99 106 108
:3 0 9c 103 10a
:2 0 10c 9f 10d
100 10c 0 10e
a1 0 119 2e
:3 0 2f :3 0 10f
110 0 28 :3 0
29 :3 0 112 113
0 3 :3 0 30
:3 0 a3 111 117
:2 0 119 a7 11a
ab 119 0 11b
ab 0 1dc 31
:3 0 32 :3 0 6
:3 0 33 :3 0 5
:3 0 34 :3 0 3
:4 0 35 1 :8 0
139 36 :4 0 124
:3 0 30 :3 0 37
:2 0 af 127 128
:3 0 9 :3 0 38
:3 0 12a 12b 0
39 :2 0 12c 12d
0 12f b2 136
9 :3 0 38 :3 0
130 131 0 3a
:2 0 132 133 0
135 b4 137 129
12f 0 138 0
135 0 138 b6
0 139 b9 18c
3b :3 0 9 :3 0
38 :3 0 13b 13c
0 3c :3 0 13d
13e 0 140 bc
142 be 141 140
:2 0 18a 3d :3 0
9 :3 0 38 :3 0
145 146 0 3c
:3 0 147 148 0
182 c :3 0 d
:3 0 14a 14b 0
c :3 0 1a :3 0
14d 14e 0 3e
:2 0 2 :4 0 3f
:2 0 1d :2 0 1b
:2 0 c0 153 155
:3 0 c3 14f 157
14c 159 158 :2 0
f :3 0 1e :3 0
15b 15c 0 11
:4 0 40 :4 0 14
:2 0 15 :3 0 c7
160 162 :3 0 14
:2 0 24 :4 0 ca
164 166 :3 0 14
:2 0 41 :4 0 cd
168 16a :3 0 14
:2 0 3c :3 0 d0
16c 16e :3 0 14
:2 0 42 :4 0 d3
170 172 :3 0 14
:2 0 43 :3 0 44
:3 0 1b :2 0 45
:2 0 d6 175 179
da 174 17b :3 0
dd 15d 17d :2 0
17f e0 180 15a
17f 0 181 e2
0 182 e4 185
:3 0 185 0 185
184 182 183 :6 0
187 2 :3 0 e7
189 e9 188 187
:2 0 18a eb :2 0
18c 0 18c 18b
139 18a :6 0 1dc
1 :3 0 c :3 0
d :3 0 18e 18f
0 c :3 0 1a
:3 0 191 192 0
46 :2 0 2 :4 0
47 :2 0 1d :2 0
1b :2 0 ee 197
199 :3 0 f1 193
19b 190 19d 19c
:2 0 f :3 0 1e
:3 0 19f 1a0 0
11 :4 0 48 :4 0
14 :2 0 15 :3 0
f5 1a4 1a6 :3 0
14 :2 0 24 :4 0
f8 1a8 1aa :3 0
14 :2 0 25 :4 0
fb 1ac 1ae :3 0
14 :2 0 26 :3 0
27 :3 0 9 :3 0
38 :3 0 1b3 1b4
0 fe 1b2 1b6
2a :4 0 100 1b1
1b9 103 1b0 1bb
:3 0 14 :2 0 2b
:4 0 106 1bd 1bf
:3 0 14 :2 0 17
:4 0 109 1c1 1c3
:3 0 14 :2 0 3
:3 0 10c 1c5 1c7
:3 0 14 :2 0 17
:4 0 10f 1c9 1cb
:3 0 112 1a1 1cd
:2 0 1cf 115 1d0
19e 1cf 0 1d1
117 0 1dc 2e
:3 0 49 :3 0 1d2
1d3 0 9 :3 0
38 :3 0 1d5 1d6
0 3 :3 0 30
:3 0 119 1d4 1da
:2 0 1dc 11d 27d
9 :3 0 4a :2 0
4 1dd 1de 0
c :3 0 d :3 0
1e0 1e1 0 c
:3 0 1a :3 0 1e3
1e4 0 3e :2 0
2 :4 0 4b :2 0
1d :2 0 1b :2 0
124 1e9 1eb :3 0
127 1e5 1ed 1e2
1ef 1ee :2 0 f
:3 0 1e :3 0 1f1
1f2 0 11 :4 0
4c :4 0 14 :2 0
15 :3 0 12b 1f6
1f8 :3 0 12e 1f3
1fa :2 0 213 f
:3 0 1e :3 0 1fc
1fd 0 11 :4 0
4d :4 0 14 :2 0
9 :3 0 4e :3 0
202 203 0 131
201 205 :3 0 14
:2 0 2b :4 0 134
207 209 :3 0 14
:2 0 9 :3 0 4f
:3 0 20c 20d 0
137 20b 20f :3 0
13a 1fe 211 :2 0
213 13d 214 1f0
213 0 215 140
0 225 50 :3 0
b :3 0 9 :3 0
4e :3 0 51 :3 0
9 :3 0 4f :3 0
52 :3 0 53 :4 0
54 1 :a 0 221
:2 0 225 217 21f
:2 0 8 :3 0 b
:3 0 223 :2 0 225
142 227 146 226
225 :2 0 27b 3d
:3 0 9 :3 0 38
:3 0 22a 22b 0
3c :3 0 22c 22d
0 273 c :3 0
d :3 0 22f 230
0 c :3 0 1a
:3 0 232 233 0
3e :2 0 2 :4 0
55 :2 0 1d :2 0
1b :2 0 148 238
23a :3 0 14b 234
23c 231 23e 23d
:2 0 f :3 0 1e
:3 0 240 241 0
11 :4 0 56 :4 0
14 :2 0 15 :3 0
14f 245 247 :3 0
152 242 249 :2 0
263 f :3 0 1e
:3 0 24b 24c 0
11 :4 0 41 :4 0
14 :2 0 3c :3 0
155 250 252 :3 0
14 :2 0 42 :4 0
158 254 256 :3 0
14 :2 0 43 :3 0
44 :3 0 1b :2 0
45 :2 0 15b 259
25d 15f 258 25f
:3 0 162 24d 261
:2 0 263 165 264
23f 263 0 265
168 0 273 50
:3 0 b :3 0 51
:3 0 9 :3 0 4f
:3 0 52 :3 0 53
:4 0 57 1 :a 0
26f :2 0 273 267
26d :2 0 8 :3 0
b :3 0 271 :2 0
273 16a 276 :3 0
276 0 276 275
273 274 :6 0 278
1 :3 0 16f 27a
171 279 278 :2 0
27b 173 :2 0 27d
176 27d 27c 1dc
27b :6 0 27e :2 0
2 18 27d 281
:3 0 280 27e 282
:8 0 
178
4
:3 0 1 3 1
7 1 b 1
f 4 6 a
e 12 1 1a
1 27 1 33
2 36 38 2
3b 3d 2 3f
41 2 43 45
2 47 49 2
4b 4d 2 4f
51 2 53 55
2 57 59 2
5b 5d 2 5f
61 2 63 65
2 67 69 2
6b 6d 2 6f
71 2 73 75
2 77 79 4
2f 35 3a 7b
1 7d 1 7f
2 89 8b 3
87 88 8d 2
96 98 2 95
9a 1 9c 1
9e 1 a0 1
a5 2 b4 b6
3 b2 b3 b8
2 c1 c3 2
c5 c7 2 c9
cb 1 d3 2
d5 d6 2 cd
d8 2 da dc
2 de e0 2
e2 e4 2 e6
e8 2 c0 ea
1 ec 1 ee
2 f8 fa 3
f6 f7 fc 2
105 107 2 104
109 1 10b 1
10d 3 114 115
116 3 ef 10e
118 1 11a 1
126 2 125 126
1 12e 1 134
2 136 137 2
123 138 1 13f
1 13a 2 152
154 3 150 151
156 2 15f 161
2 163 165 2
167 169 2 16b
16d 2 16f 171
3 176 177 178
2 173 17a 2
15e 17c 1 17e
1 180 2 149
181 1 185 1
144 2 142 189
2 196 198 3
194 195 19a 2
1a3 1a5 2 1a7
1a9 2 1ab 1ad
1 1b5 2 1b7
1b8 2 1af 1ba
2 1bc 1be 2
1c0 1c2 2 1c4
1c6 2 1c8 1ca
2 1a2 1cc 1
1ce 1 1d0 3
1d7 1d8 1d9 6
80 9f 11b 18c
1d1 1db 2 1e8
1ea 3 1e6 1e7
1ec 2 1f5 1f7
2 1f4 1f9 2
200 204 2 206
208 2 20a 20e
2 1ff 210 2
1fb 212 1 214
3 215 220 224
1 1df 2 237
239 3 235 236
23b 2 244 246
2 243 248 2
24f 251 2 253
255 3 25a 25b
25c 2 257 25e
2 24e 260 2
24a 262 1 264
4 22e 265 26e
272 1 276 1
229 2 227 27a
1 1f 
1
4
0 
281
0
1
14
4
6
0 1 2 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
f 1 0
b 1 0
7 1 0
2 0 1
3 1 0
1a 1 0
0

/
SHOW ERRORS FUNCTION SP_U_ASSIGN_DESCR;
ALTER FUNCTION SP_U_ASSIGN_DESCR COMPILE DEBUG;
/****************************************************************************************/
Prompt == FUNCTION SP_TEST_ASSIGN ==
CREATE OR REPLACE FUNCTION SP_TEST_ASSIGN wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
bc
2 :e:
1FUNCTION:
1SP_TEST_ASSIGN:
1RANK001:
1VARCHAR2:
1BITFLAG001:
1PLS_INTEGER:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_RANK:
1200:
1H_FULL_NAME:
1255:
1H_PROJECT_ID:
132:
1H_RES_ASSIGNMENT_ID:
1H_TSK_ASSIGNMENT_ID:
1H_SECURITY_ID:
1H_RES_ID:
1H_RES_TYPE:
11:
1H_PARTICIPANT:
10:
1H_BITFLAG:
1CURSOR:
1C_RPA0:
1ELEMENT_ID:
1TMT_WBS:
1TYPE_ID:
1PMO_CNST:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1RANK:
1SELECT ELEMENT_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (pmo_cnst.SC_PROJEC+
1T,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PROJ_TYPE2,pmo_cnst+
1.SC_PROJ_TYPE3) AND RANK LIKE h_rank || '%':
1C_RPA1:
1RES_ASSIGNMENT_ID:
1TSK_ASSIGNMENT_ID:
1RESOURCE_ID:
1RESOURCE_TYPE:
1TASK_ASSIGNMENTS:
1PROJECT_ID:
1TASK_ID:
1SELECT RES_ASSIGNMENT_ID, TSK_ASSIGNMENT_ID, RESOURCE_ID, RESOURCE_TYPE:n    +
1     FROM TASK_ASSIGNMENTS:n         WHERE PROJECT_ID = h_project_id AND TASK+
1_ID = h_project_id:
1C_FPA1:
1RA:
1PARTICIPANT:
1SECURITY_ID:
1RESOURCE_ASSIGNMENTS:
1PROJECT_ASSIGNMENTS:
1PA:
1SELECT ra.RESOURCE_ID, ra.RESOURCE_TYPE, ra.PARTICIPANT, ra.SECURITY_ID:n    +
1     FROM RESOURCE_ASSIGNMENTS ra:n         WHERE ELEMENT_ID = h_project_id A+
1ND NOT EXISTS (:n         SELECT 'X' FROM PROJECT_ASSIGNMENTS pa WHERE pa.PRO+
1JECT_ID = h_project_id AND pa.RESOURCE_ID = ra.RESOURCE_ID):
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_TEST_ASSIGN(:
1':
1, :
1COALESCE:
1TO_CHAR:
1NULL:
1);:
1CHECK_TRACE:
141:
1+:
1FPUT:
1               ENTER:: SP_TEST_ASSIGN(42) :: cplan.sql(24241) :: :
1OPEN:
1LOOP:
1FOUND:
1SC_STATE:
1100:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
1=:
1COUNT:
1DUAL:
1PROJECT_ASSIGNMENT_ID:
1SELECT COUNT('X') INTO h_bitflag FROM DUAL WHERE EXISTS (SELECT 'X' FROM TASK+
1_ASSIGNMENTS:n               WHERE PROJECT_ASSIGNMENT_ID = h_tsk_assignment_i+
1d AND RESOURCE_ID = h_res_id):
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
187:
1           EXCEPTION:: SP_TEST_ASSIGN(88) :: cplan.sql(24287) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1UPDATE TASK_ASSIGNMENTS SET PROJECT_ASSIGNMENT_ID = NuLL:n                  W+
1HERE PROJECT_ASSIGNMENT_ID = h_tsk_assignment_id:
1TRUE:
1108:
1           EXCEPTION:: SP_TEST_ASSIGN(109) :: cplan.sql(24308) :: :
1TASK_DAY_OF_YEAR:
1PARENT_ID:
1UPDATE TASK_DAY_OF_YEAR SET PARENT_ID = TSK_ASSIGNMENT_ID:n                  +
1WHERE PROJECT_ID = h_project_id AND PARENT_ID = h_tsk_assignment_id:
1128:
1           EXCEPTION:: SP_TEST_ASSIGN(129) :: cplan.sql(24328) :: :
1DELETE FROM RESOURCE_ASSIGNMENTS:n               WHERE RES_ASSIGNMENT_ID = h_+
1res_assignment_id:n               AND SECURITY_ID = 'SCPROJECTASSIGNMENT':
1150:
1           EXCEPTION:: SP_TEST_ASSIGN(151) :: cplan.sql(24350) :: :
1DELETE FROM PROJECT_ASSIGNMENTS WHERE PROJECT_ID = h_project_id AND RESOURCE_+
1ID = h_res_id:
1170:
1           EXCEPTION:: SP_TEST_ASSIGN(171) :: cplan.sql(24370) :: :
1NICK_NAME:
1RESOURCES:
1SELECT NICK_NAME || ';' INTO h_full_name:n                     FROM RESOURCES+
1:n                     WHERE RESOURCE_ID = h_res_id:
1188:
1           EXCEPTION:: SP_TEST_ASSIGN(189) :: cplan.sql(24388) :: :
1PROFILE_NAME:
1PROFILES:
1PROFILE_ID:
1SELECT PROFILE_NAME || ';' INTO h_full_name:n                     FROM PROFIL+
1ES:n                     WHERE PROFILE_ID = h_res_id:
1205:
1           EXCEPTION:: SP_TEST_ASSIGN(206) :: cplan.sql(24405) :: :
1ASSIGN_NAMES:
1REPLACE:
1UPDATE TMT_WBS SET ASSIGN_NAMES = REPLACE (ASSIGN_NAMES, h_full_name, ''):n  +
1                WHERE PROJECT_ID = h_project_id AND ELEMENT_ID = h_project_id:
1226:
1           EXCEPTION:: SP_TEST_ASSIGN(227) :: cplan.sql(24426) :: :
1PMO_STPU:
1BIT_ANDNOT:
1UPDATE RESOURCE_ASSIGNMENTS SET PARTICIPANT = PMO_STPU.BIT_ANDNOT(PARTICIPANT+
1,4096):n                  WHERE RES_ASSIGNMENT_ID = h_res_assignment_id:
1246:
1           EXCEPTION:: SP_TEST_ASSIGN(247) :: cplan.sql(24446) :: :
1DELETE FROM TASK_ASSIGNMENTS WHERE TSK_ASSIGNMENT_ID = h_tsk_assignment_id:
1266:
1           EXCEPTION:: SP_TEST_ASSIGN(267) :: cplan.sql(24466) :: :
1DELETE FROM TASK_DAY_OF_YEAR WHERE PROJECT_ID = h_project_id AND TSK_ASSIGNME+
1NT_ID = h_tsk_assignment_id:
1285:
1           EXCEPTION:: SP_TEST_ASSIGN(286) :: cplan.sql(24485) :: :
1CLOSE:
1301:
1           EXCEPTION:: SP_TEST_ASSIGN(302) :: cplan.sql(24501) :: :
1COMMIT:
1ELSIF:
1SELECT NICK_NAME || ';' INTO h_full_name:n                  FROM RESOURCES:n +
1                 WHERE RESOURCE_ID = h_res_id:
1334:
1           EXCEPTION:: SP_TEST_ASSIGN(335) :: cplan.sql(24534) :: :
1SELECT PROFILE_NAME || ';' INTO h_full_name:n                  FROM PROFILES+
1:n                  WHERE PROFILE_ID = h_res_id:
1351:
1           EXCEPTION:: SP_TEST_ASSIGN(352) :: cplan.sql(24551) :: :
1INSTR:
1UPDATE TMT_WBS SET ASSIGN_NAMES = CASE:n               WHEN InStr(ASSIGN_NAME+
1S, h_full_name) > 0 THEN ASSIGN_NAMES:n               ELSE ASSIGN_NAMES || h_+
1full_name END:n               WHERE PROJECT_ID = h_project_id AND ELEMENT_ID +
1= h_project_id:
1374:
1           EXCEPTION:: SP_TEST_ASSIGN(375) :: cplan.sql(24574) :: :
1ELEMENT_TYPE_BITS:
1ROLLUP_BITS:
1SC_ASSIGNMENT_BIT:
1INSERT INTO PROJECT_ASSIGNMENTS (PROJECT_ID, RESOURCE_ID, PARTICIPANT, SECURI+
1TY_ID, RESOURCE_TYPE, ELEMENT_TYPE_BITS,ROLLUP_BITS):n               VALUES(h+
1_project_id, h_res_id, h_participant, h_security_id, h_res_type, 1, pmo_cnst.+
1SC_ASSIGNMENT_BIT):
1394:
1           EXCEPTION:: SP_TEST_ASSIGN(395) :: cplan.sql(24594) :: :
1411:
1           EXCEPTION:: SP_TEST_ASSIGN(412) :: cplan.sql(24611) :: :
1430:
1           EXCEPTION:: SP_TEST_ASSIGN(431) :: cplan.sql(24630) :: :
14:
1436:
1       RETURN_STATUS:: SP_TEST_ASSIGN(437) :: cplan.sql(24636) :: :
1STATE:: :
1 ID:: :
1PMODEFINES:
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1443:
1           EXCEPTION:: SP_TEST_ASSIGN(444) :: cplan.sql(24643) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1455:
1           EXCEPTION:: SP_TEST_ASSIGN(456) :: cplan.sql(24655) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
a60
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 a0 51
a5 1c 81 b0 a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 51 a5 1c 81 b0
a3 a0 1c 51 81 b0 a3 a0
1c 51 81 b0 a0 f4 b4 bf
c8 :f a0 12a bd b7 11 a4 b1
a0 f4 b4 bf c8 :9 a0 12a bd
b7 11 a4 b1 a0 f4 b4 bf
c8 :15 a0 12a bd b7 11 a4 b1
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e :3 a0 a5
b 6e a5 b b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 d :2 a0 d :2 a0 e9
dd b3 :3 a0 e9 d3 :2 a0 f :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c :2 a0 6b a0 7e a0
6b b4 2e 5a a0 2b b7 19
3c :2 a0 51 a5 b 7e 51 b4
2e :2 a0 e9 dd b3 :6 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c a0 51 d
:8 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :4 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :7 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 19 3c :4 a0 12a a0
f a0 7e b4 2e :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f :2 a0 6b a0
7e a0 6b b4 2e 5a :5 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f :2 a0 :2 51
a5 b 7e 6e b4 2e :5 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 :5 a0 12a :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 19 3c :9 a0 12a
a0 f a0 7e b4 2e :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f b7 :7 a0
12a a0 f a0 7e b4 2e :2 a0
6b 51 d b7 :2 a0 6b 51 d
b7 :2 19 3c b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f b7
:2 19 3c :3 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :5 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
a0 12a a0 b7 :2 a0 51 a5 b
7e 51 b4 2e :2 a0 e9 dd b3
:6 a0 e9 d3 5 :2 a0 f :2 a0 6b
51 d b7 :2 a0 6b 51 d b7
:2 19 3c :2 a0 6b a0 7e a0 6b
b4 2e 5a a0 2b b7 19 3c
:2 a0 :2 51 a5 b 7e 6e b4 2e
:5 a0 12a :2 a0 6b a0 d b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f b7 :5 a0 12a :2 a0 6b a0
d b7 :3 a0 6b a0 d b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e 7e :2 a0 :2 51
a5 b b4 2e a5 57 b7 19
3c b7 a4 b1 11 4f b7 a6
9 a4 b1 11 4f b7 :2 19 3c
:c a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:f a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
b7 a0 47 :2 a0 e9 c1 :2 a0 6b
a0 d b7 :3 a0 6b a0 d b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e a0
b4 2e 7e 6e b4 2e 7e :2 a0
:2 51 a5 b b4 2e a5 57 b7
19 3c b7 a4 b1 11 4f b7
a6 9 a4 b1 11 4f a0 12a
b7 :2 19 3c b7 a0 47 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b :2 a0 a5 57 b7 :2 a0 6b
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e :2 a0 6b b4 2e
7e 6e b4 2e 7e :2 a0 6b b4
2e a5 57 b7 19 3c :9 a0 12a
e9 dd :2 a0 65 b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c :7 a0 12a e9 dd
:2 a0 65 b7 a4 b1 11 4f b7
a6 9 a4 b1 11 68 4f 1d
17 b5 
a60
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 72 5d 61 64 65 6d
5c 8f 7d 59 81 82 8a 7c
ac 9a 79 9e 9f a7 99 c9
b7 96 bb bc c4 b6 e6 d4
b3 d8 d9 e1 d3 103 f1 d0
f5 f6 fe f0 120 10e ed 112
113 11b 10d 13d 12b 10a 12f 130
138 12a 159 148 14c 127 154 147
175 164 168 144 170 163 17c 180
160 191 194 198 19c 1a0 1a4 1a8
1ac 1b0 1b4 1b8 1bc 1c0 1c4 1c8
1cc 1d0 1d4 1e0 1e5 1e7 1f3 1f7
1f9 1fd 20e 20f 212 216 21a 21e
222 226 22a 22e 232 236 23a 246
24b 24d 259 25d 25f 263 274 275
278 27c 280 284 288 28c 290 294
298 29c 2a0 2a4 2a8 2ac 2b0 2b4
2b8 2bc 2c0 2c4 2c8 2cc 2d0 2dc
2e1 2e3 2ef 2f3 311 2f9 2fd 301
304 30c 2f8 318 31c 2f5 320 324
328 32b 330 331 1 333 338 33c
340 343 348 34c 350 353 358 359
35b 360 363 367 368 36d 372 375
37a 37b 380 383 387 388 38d 390
395 396 39b 39e 3a3 3a4 3a9 3ac
3b0 3b4 3b8 3b9 3bb 3c0 3c1 3c3
3c4 3c9 3cc 3d1 3d2 3d7 3d8 3dd
3df 3e3 3e6 3ea 3ee 3f1 3f5 3f9
3fc 3ff 404 407 40a 40d 40e 413
414 1 416 41b 41f 423 426 42b
430 433 437 438 43d 43e 443 445
449 44c 450 454 458 45c 460 464
468 46c 471 475 476 47a 47e 482
487 48c 490 494 499 49d 4a1 4a4
4a7 4ab 4ad 4b1 4b5 4b8 4bb 4bf
4c1 4c5 4c9 4cc 4d0 4d4 4d7 4db
4de 4e2 4e5 4e6 4eb 4ee 4f2 4f8
4fa 4fe 501 505 509 50c 50d 50f
512 515 516 51b 51f 523 528 52c
52d 531 535 539 53d 541 545 54a
54f 553 557 55b 560 564 568 56b
56e 572 574 578 57c 57f 582 586
588 58c 590 593 597 59b 59e 5a2
5a5 5a9 5ac 5ad 5b2 5b5 5b9 5bf
5c1 5c5 5c8 5cc 5cf 5d3 5d7 5db
5df 5e3 5e7 5eb 5ef 5f3 5ff 603
607 60a 60e 612 614 618 61c 620
623 627 62b 62d 62e 633 1 637
63b 63f 642 646 64a 64e 652 655
659 65d 660 663 668 66b 66e 671
672 677 678 1 67a 67f 683 687
68a 68f 694 697 69b 69c 6a1 6a4
6a9 6aa 6af 6b2 6b7 6b8 6bd 6c0
6c4 6c5 6ca 6cd 6d2 6d3 6d8 6db
6df 6e3 6e6 6e9 6ea 6ec 6ed 6f2
6f3 6f8 6fa 6fe 701 703 707 709
715 717 719 71a 71f 723 725 731
733 737 73b 73e 73f 741 744 747
748 74d 751 755 759 75d 769 76d
772 776 779 77a 77f 783 787 78a
78d 791 793 797 79b 79e 7a1 7a5
7a7 7ab 7af 7b2 7b4 7b8 7bc 7c0
7c3 7c7 7cb 7cd 7ce 7d3 1 7d7
7db 7df 7e2 7e6 7ea 7ee 7f2 7f5
7f9 7fd 800 803 808 80b 80e 811
812 817 818 1 81a 81f 823 827
82a 82f 834 837 83b 83c 841 844
849 84a 84f 852 857 858 85d 860
864 865 86a 86d 872 873 878 87b
87f 883 886 889 88a 88c 88d 892
893 898 89a 89e 8a1 8a3 8a7 8a9
8b5 8b7 8b9 8ba 8bf 8c3 8c5 8d1
8d3 8d7 8db 8df 8e3 8e7 8eb 8ef
8fb 8ff 904 908 90b 90c 911 915
919 91c 91f 923 925 929 92d 930
933 937 939 93d 941 944 946 94a
94e 952 955 959 95d 95f 960 965
1 969 96d 971 974 978 97c 980
984 987 98b 98f 992 995 99a 99d
9a0 9a3 9a4 9a9 9aa 1 9ac 9b1
9b5 9b9 9bc 9c1 9c6 9c9 9cd 9ce
9d3 9d6 9db 9dc 9e1 9e4 9e9 9ea
9ef 9f2 9f6 9f7 9fc 9ff a04 a05
a0a a0d a11 a15 a18 a1b a1c a1e
a1f a24 a25 a2a a2c a30 a33 a35
a39 a3b a47 a49 a4b a4c a51 a55
a57 a63 a65 a67 a6b a6e a72 a76
a7a a7e a8a a8e a93 a97 a9a a9b
aa0 aa4 aa8 aab aae ab2 ab4 ab8
abc abf ac2 ac6 ac8 acc ad0 ad3
ad5 ad9 add ae1 ae4 ae8 aec aee
aef af4 1 af8 afc b00 b03 b07
b0b b0f b13 b16 b1a b1e b21 b24
b29 b2c b2f b32 b33 b38 b39 1
b3b b40 b44 b48 b4b b50 b55 b58
b5c b5d b62 b65 b6a b6b b70 b73
b78 b79 b7e b81 b85 b86 b8b b8e
b93 b94 b99 b9c ba0 ba4 ba7 baa
bab bad bae bb3 bb4 bb9 bbb bbf
bc2 bc4 bc8 bca bd6 bd8 bda bdb
be0 be4 be6 bf2 bf4 bf8 bfc bff
c03 c06 c0a c0d c0e c13 c16 c1a
c1e c22 c26 c2a c36 c3a c3f c43
c46 c47 c4c c50 c54 c57 c5a c5e
c60 c64 c68 c6b c6e c72 c74 c78
c7c c7f c81 c85 c89 c8d c90 c94
c98 c9a c9b ca0 1 ca4 ca8 cac
caf cb3 cb7 cbb cbf cc2 cc6 cca
ccd cd0 cd5 cd8 cdb cde cdf ce4
ce5 1 ce7 cec cf0 cf4 cf7 cfc
d01 d04 d08 d09 d0e d11 d16 d17
d1c d1f d24 d25 d2a d2d d31 d32
d37 d3a d3f d40 d45 d48 d4c d50
d53 d56 d57 d59 d5a d5f d60 d65
d67 d6b d6e d70 d74 d76 d82 d84
d86 d87 d8c d90 d92 d9e da0 da4
da8 dab dae daf db1 db4 db9 dba
dbf dc3 dc7 dcb dcf dd3 ddf de3
de7 dea dee df2 df4 df8 dfc e00
e03 e07 e0b e0d e0e e13 1 e17
e1b e1f e22 e26 e2a e2e e32 e35
e39 e3d e40 e43 e48 e4b e4e e51
e52 e57 e58 1 e5a e5f e63 e67
e6a e6f e74 e77 e7b e7c e81 e84
e89 e8a e8f e92 e97 e98 e9d ea0
ea4 ea5 eaa ead eb2 eb3 eb8 ebb
ebf ec3 ec6 ec9 eca ecc ecd ed2
ed3 ed8 eda ede ee1 ee3 ee7 ee9
ef5 ef7 ef9 efa eff f03 f05 f11
f13 f15 f19 f1d f21 f25 f29 f35
f39 f3d f40 f44 f48 f4a f4e f52
f56 f59 f5d f61 f63 f64 f69 1
f6d f71 f75 f78 f7c f80 f84 f88
f8b f8f f93 f96 f99 f9e fa1 fa4
fa7 fa8 fad fae 1 fb0 fb5 fb9
fbd fc0 fc5 fca fcd fd1 fd2 fd7
fda fdf fe0 fe5 fe8 fed fee ff3
ff6 ffa ffb 1000 1003 1008 1009 100e
1011 1015 1019 101c 101f 1020 1022 1023
1028 1029 102e 1030 1034 1037 1039 103d
103f 104b 104d 104f 1050 1055 1059 105b
1067 1069 106b 106f 1073 1076 107a 107e
1082 1086 108a 108e 1092 1096 109a 10a6
10aa 10af 10b3 10b6 10b7 10bc 10c0 10c4
10c7 10ca 10ce 10d0 10d4 10d8 10db 10de
10e2 10e4 10e8 10ec 10ef 10f1 10f5 10f9
10fd 1100 1104 1108 110a 110b 1110 1
1114 1118 111c 111f 1123 1127 112b 112f
1132 1136 113a 113d 1140 1145 1148 114b
114e 114f 1154 1155 1 1157 115c 1160
1164 1167 116c 1171 1174 1178 1179 117e
1181 1186 1187 118c 118f 1194 1195 119a
119d 11a1 11a2 11a7 11aa 11af 11b0 11b5
11b8 11bc 11c0 11c3 11c6 11c7 11c9 11ca
11cf 11d0 11d5 11d7 11db 11de 11e0 11e4
11e6 11f2 11f4 11f6 11f7 11fc 1200 1202
120e 1210 1212 1216 121a 121e 1222 1226
122a 122e 123a 123e 1243 1247 124a 124b
1250 1254 1258 125b 125e 1262 1264 1268
126c 126f 1272 1276 1278 127c 1280 1283
1285 1289 128d 1291 1294 1298 129c 129e
129f 12a4 1 12a8 12ac 12b0 12b3 12b7
12bb 12bf 12c3 12c6 12ca 12ce 12d1 12d4
12d9 12dc 12df 12e2 12e3 12e8 12e9 1
12eb 12f0 12f4 12f8 12fb 1300 1305 1308
130c 130d 1312 1315 131a 131b 1320 1323
1328 1329 132e 1331 1335 1336 133b 133e
1343 1344 1349 134c 1350 1354 1357 135a
135b 135d 135e 1363 1364 1369 136b 136f
1372 1374 1378 137a 1386 1388 138a 138b
1390 1394 1396 13a2 13a4 13a6 13aa 13ae
13b1 13b5 13b9 13bd 13c9 13cd 13d2 13d6
13d9 13da 13df 13e3 13e7 13ea 13ed 13f1
13f3 13f7 13fb 13fe 1401 1405 1407 140b
140f 1412 1414 1418 141c 1420 1423 1427
142b 142d 142e 1433 1 1437 143b 143f
1442 1446 144a 144e 1452 1455 1459 145d
1460 1463 1468 146b 146e 1471 1472 1477
1478 1 147a 147f 1483 1487 148a 148f
1494 1497 149b 149c 14a1 14a4 14a9 14aa
14af 14b2 14b7 14b8 14bd 14c0 14c4 14c5
14ca 14cd 14d2 14d3 14d8 14db 14df 14e3
14e6 14e9 14ea 14ec 14ed 14f2 14f3 14f8
14fa 14fe 1501 1503 1507 1509 1515 1517
1519 151a 151f 1523 1525 1531 1533 1537
153b 153f 1543 1547 1553 1557 155c 1560
1563 1564 1569 156d 1571 1574 1577 157b
157d 1581 1585 1588 158b 158f 1591 1595
1599 159c 159e 15a2 15a6 15aa 15ad 15b1
15b5 15b7 15b8 15bd 1 15c1 15c5 15c9
15cc 15d0 15d4 15d8 15dc 15df 15e3 15e7
15ea 15ed 15f2 15f5 15f8 15fb 15fc 1601
1602 1 1604 1609 160d 1611 1614 1619
161e 1621 1625 1626 162b 162e 1633 1634
1639 163c 1641 1642 1647 164a 164e 164f
1654 1657 165c 165d 1662 1665 1669 166d
1670 1673 1674 1676 1677 167c 167d 1682
1684 1688 168b 168d 1691 1693 169f 16a1
16a3 16a4 16a9 16ad 16af 16bb 16bd 16bf
16c3 16ca 16ce 16d2 16d7 16d9 16dd 16e1
16e4 16e8 16ec 16ee 16f2 16f6 16fa 16fd
1701 1705 1707 1708 170d 1 1711 1715
1719 171c 1720 1724 1728 172c 172f 1733
1737 173a 173d 1742 1745 1748 174b 174c
1751 1752 1 1754 1759 175d 1761 1764
1769 176e 1771 1775 1776 177b 177e 1783
1784 1789 178c 1791 1792 1797 179a 179e
179f 17a4 17a7 17ac 17ad 17b2 17b5 17b9
17bd 17c0 17c3 17c4 17c6 17c7 17cc 17cd
17d2 17d4 17d8 17db 17dd 17e1 17e3 17ef
17f1 17f3 17f4 17f9 17fd 17ff 180b 180d
1811 181d 1821 1823 1827 182b 182e 182f
1831 1834 1837 1838 183d 1841 1845 184a
184e 184f 1853 1857 185b 185f 1863 1867
186c 1871 1875 1879 187d 1882 1886 188a
188d 1890 1894 1896 189a 189e 18a1 18a4
18a8 18aa 18ae 18b2 18b5 18b9 18bd 18c0
18c4 18c7 18cb 18ce 18cf 18d4 18d7 18db
18e1 18e3 18e7 18ea 18ee 18f2 18f5 18f8
18f9 18fb 18fe 1903 1904 1909 190d 1911
1915 1919 191d 1929 192d 1931 1934 1938
193c 193e 1942 1946 194a 194d 1951 1955
1957 1958 195d 1 1961 1965 1969 196c
1970 1974 1978 197c 197f 1983 1987 198a
198d 1992 1995 1998 199b 199c 19a1 19a2
1 19a4 19a9 19ad 19b1 19b4 19b9 19be
19c1 19c5 19c6 19cb 19ce 19d3 19d4 19d9
19dc 19e1 19e2 19e7 19ea 19ee 19ef 19f4
19f7 19fc 19fd 1a02 1a05 1a09 1a0d 1a10
1a13 1a14 1a16 1a17 1a1c 1a1d 1a22 1a24
1a28 1a2b 1a2d 1a31 1a33 1a3f 1a41 1a43
1a44 1a49 1a4d 1a4f 1a5b 1a5d 1a5f 1a63
1a67 1a6b 1a6f 1a73 1a7f 1a83 1a87 1a8a
1a8e 1a92 1a94 1a98 1a9c 1aa0 1aa3 1aa7
1aab 1aad 1aae 1ab3 1 1ab7 1abb 1abf
1ac2 1ac6 1aca 1ace 1ad2 1ad5 1ad9 1add
1ae0 1ae3 1ae8 1aeb 1aee 1af1 1af2 1af7
1af8 1 1afa 1aff 1b03 1b07 1b0a 1b0f
1b14 1b17 1b1b 1b1c 1b21 1b24 1b29 1b2a
1b2f 1b32 1b37 1b38 1b3d 1b40 1b44 1b45
1b4a 1b4d 1b52 1b53 1b58 1b5b 1b5f 1b63
1b66 1b69 1b6a 1b6c 1b6d 1b72 1b73 1b78
1b7a 1b7e 1b81 1b83 1b87 1b89 1b95 1b97
1b99 1b9a 1b9f 1ba3 1ba5 1bb1 1bb3 1bb5
1bb9 1bbd 1bc0 1bc4 1bc8 1bcc 1bd0 1bd4
1bd8 1bdc 1be0 1be4 1be8 1bec 1bf0 1bfc
1c00 1c05 1c09 1c0c 1c0d 1c12 1c16 1c1a
1c1d 1c20 1c24 1c26 1c2a 1c2e 1c31 1c34
1c38 1c3a 1c3e 1c42 1c45 1c47 1c4b 1c4f
1c53 1c56 1c5a 1c5e 1c60 1c61 1c66 1
1c6a 1c6e 1c72 1c75 1c79 1c7d 1c81 1c85
1c88 1c8c 1c90 1c93 1c96 1c9b 1c9e 1ca1
1ca4 1ca5 1caa 1cab 1 1cad 1cb2 1cb6
1cba 1cbd 1cc2 1cc7 1cca 1cce 1ccf 1cd4
1cd7 1cdc 1cdd 1ce2 1ce5 1cea 1ceb 1cf0
1cf3 1cf7 1cf8 1cfd 1d00 1d05 1d06 1d0b
1d0e 1d12 1d16 1d19 1d1c 1d1d 1d1f 1d20
1d25 1d26 1d2b 1d2d 1d31 1d34 1d36 1d3a
1d3c 1d48 1d4a 1d4c 1d4d 1d52 1d56 1d58
1d64 1d66 1d6a 1d6e 1d72 1d76 1d7a 1d7e
1d82 1d86 1d8a 1d8e 1d92 1d96 1d9a 1d9e
1da2 1dae 1db2 1db7 1dbb 1dbe 1dbf 1dc4
1dc8 1dcc 1dcf 1dd2 1dd6 1dd8 1ddc 1de0
1de3 1de6 1dea 1dec 1df0 1df4 1df7 1df9
1dfd 1e01 1e05 1e08 1e0c 1e10 1e12 1e13
1e18 1 1e1c 1e20 1e24 1e27 1e2b 1e2f
1e33 1e37 1e3a 1e3e 1e42 1e45 1e48 1e4d
1e50 1e53 1e56 1e57 1e5c 1e5d 1 1e5f
1e64 1e68 1e6c 1e6f 1e74 1e79 1e7c 1e80
1e81 1e86 1e89 1e8e 1e8f 1e94 1e97 1e9c
1e9d 1ea2 1ea5 1ea9 1eaa 1eaf 1eb2 1eb7
1eb8 1ebd 1ec0 1ec4 1ec8 1ecb 1ece 1ecf
1ed1 1ed2 1ed7 1ed8 1edd 1edf 1ee3 1ee6
1ee8 1eec 1eee 1efa 1efc 1efe 1eff 1f04
1f08 1f0a 1f16 1f18 1f1a 1f1e 1f25 1f29
1f2d 1f32 1f34 1f38 1f3c 1f3f 1f43 1f47
1f49 1f4d 1f51 1f55 1f58 1f5c 1f60 1f62
1f63 1f68 1 1f6c 1f70 1f74 1f77 1f7b
1f7f 1f83 1f87 1f8a 1f8e 1f92 1f95 1f98
1f9d 1fa0 1fa3 1fa6 1fa7 1fac 1fad 1
1faf 1fb4 1fb8 1fbc 1fbf 1fc4 1fc9 1fcc
1fd0 1fd1 1fd6 1fd9 1fde 1fdf 1fe4 1fe7
1fec 1fed 1ff2 1ff5 1ff9 1ffa 1fff 2002
2007 2008 200d 2010 2014 2018 201b 201e
201f 2021 2022 2027 2028 202d 202f 2033
2036 2038 203c 203e 204a 204c 204e 204f
2054 2058 205a 2066 2068 206c 2078 207a
207e 2082 2085 2087 208b 2092 2096 209a
209f 20a1 20a5 20a9 20ac 20b0 20b4 20b6
20ba 20be 20c2 20c5 20c9 20cd 20cf 20d0
20d5 1 20d9 20dd 20e1 20e4 20e8 20ec
20f0 20f4 20f7 20fb 20ff 2102 2105 210a
210d 2110 2113 2114 2119 211a 1 211c
2121 2125 2129 212c 2131 2136 2139 213d
213e 2143 2146 214b 214c 2151 2154 2159
215a 215f 2162 2166 2167 216c 216f 2174
2175 217a 217d 2181 2185 2188 218b 218c
218e 218f 2194 2195 219a 219c 21a0 21a3
21a5 21a9 21ab 21b7 21b9 21bb 21bc 21c1
21c5 21c7 21d3 21d5 21d9 21dd 21e0 21e4
21e8 21eb 21ee 21f3 21f6 21f9 21fc 21fd
2202 2203 1 2205 220a 220e 2212 2215
221a 221f 2222 2226 2227 222c 222f 2234
2235 223a 223d 2242 2243 2248 224b 224f
2253 2257 225b 225e 225f 2261 2266 2267
2269 226a 226f 2272 2277 2278 227d 2280
2285 2286 228b 228e 2292 2293 2298 229b
22a0 22a1 22a6 22a7 22ac 22ae 22b2 22b5
22b9 22bd 22c0 22c4 22c8 22cb 22cf 22d3
22d4 22d9 22db 22df 22e3 22e6 22ea 22ee
22f1 22f5 22f9 22fc 22ff 2304 2307 230a
230d 230e 2313 2314 1 2316 231b 231f
2323 2326 232b 2330 2333 2337 2338 233d
233e 2343 2347 234b 234e 2353 2358 235b
235f 2363 2366 2367 236c 236f 2374 2375
237a 237d 2381 2385 2388 2389 238e 238f
2394 2396 239a 239d 23a1 23a5 23a9 23ad
23b1 23b5 23b9 23bd 23c1 23cd 23d2 23d6
23da 23de 23e2 23e4 23e5 23ea 1 23ee
23f2 23f6 23f9 23fd 2401 2405 2409 240c
2410 2414 2417 241a 241f 2422 2425 2428
2429 242e 242f 1 2431 2436 243a 243e
2441 2446 244b 244e 2452 2453 2458 2459
245e 2462 2466 2469 246e 2473 2476 247a
247b 2480 2483 2488 2489 248e 2491 2495
2499 249c 249f 24a0 24a2 24a3 24a8 24a9
24ae 24b0 24b4 24b7 24bb 24bf 24c3 24c7
24cb 24cf 24d3 24df 24e4 24e8 24ec 24f0
24f4 24f6 24fa 24fc 2508 250a 250c 250d
2512 2516 2518 2524 2528 252a 252b 2534 
a60
2
0 1 a 6 e :3 6 11 :2 6
1 3 a 13 a :2 1 4 b
14 13 :2 b :2 4 10 19 18 :2 10
:2 4 11 1a 19 :2 11 :2 4 18 21
20 :2 18 :2 4 18 21 20 :2 18 :2 4
12 1b 1a :2 12 :2 4 d 16 15
:2 d :2 4 f 18 17 :2 f :2 4 :2 12
21 12 :2 4 :2 e 1d e 4 7
e 0 :2 7 11 21 10 1c 25
30 39 45 4e 5c 65 73 7c
8f 99 a :6 7 e 0 :2 7 11
24 37 44 f 10 1d 2e 38
a :6 7 e 0 :2 7 11 14 21
24 33 36 43 46 f 24 10
1d 1a 2e 37 3a 47 58 5b
69 6c a :5 7 4 e 17 :3 e
4 7 :2 11 23 :2 2d 3a :2 23 :3 7
:2 d 19 25 :2 2f 43 :2 25 56 5c
5f :2 56 6d 85 8 :2 6d d 10
:2 6d 18 1b :2 6d b e :2 6d 13
16 1f 27 :2 1f 34 :2 16 :2 6d 3c
3f :2 6d :2 7 4c :2 4 7 :2 11 23
:2 2d 39 3c 4e 50 51 :2 4e :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e :2 7
54 :3 4 e :2 4 11 :2 4 9 :4 4
d 19 :2 7 a 11 :2 a :2 13 1f
a 17 a :2 13 1f a :4 7 b
:2 14 20 1d :2 29 :2 1d :3 a 39 :2 7
a 13 1e :2 a 21 23 :2 21 a
f :4 a 13 1f 34 49 53 :3 d
10 17 :2 10 :2 19 25 10 1d 10
:2 19 25 10 :4 d 11 :2 1a 26 23
:2 2f :2 23 :3 10 3f :3 d 1a d 17
27 36 59 16 2e 46 54 :2 10
:2 19 25 10 d 15 13 :2 1c 28
13 23 :2 10 :2 15 13 :2 1c 28 13
16 :2 20 32 :2 3c 48 4c 5e 60
61 :2 5e :2 32 :3 16 :2 1c 21 2d 6e
71 :2 2d 7e 81 :2 2d 85 88 :2 2d
94 97 :2 2d 9f a2 :2 2d ae b1
b8 c1 c4 :2 b1 :2 2d :2 16 64 :2 13
:2 10 :4 1c :2 10 d :3 a 10 19 24
:2 10 27 2a :2 27 1a 2f 19 31
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 64 65 :2 61 :2 35 :3 19
:2 1f 24 30 72 75 :2 30 82 85
:2 30 89 8c :2 30 98 9b :2 30 a3
a6 :2 30 b2 b5 bc c5 c8 :2 b5
:2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13 10
:3 2c 1a 2f 3b 19 26 37 43
13 1a 16 22 :3 20 16 :2 1f 2b
16 27 16 :2 1f 2b 16 :4 13 10
18 16 :2 1f 2b 16 26 :2 13 :2 18
16 :2 1f 2b 16 19 :2 23 35 :2 3f
4b 4f 61 64 65 :2 61 :2 35 :3 19
:2 1f 24 30 72 75 :2 30 82 85
:2 30 89 8c :2 30 98 9b :2 30 a3
a6 :2 30 b2 b5 bc c5 c8 :2 b5
:2 30 :2 19 68 :2 16 :2 13 :4 1f :2 13 10
:4 2c :2 d 1c 16 2a 14 10 17
13 1f :3 1d 13 :2 1c 28 13 24
13 :2 1c 28 13 :4 10 d 15 13
:2 1c 28 13 23 :2 10 :2 15 13 :2 1c
28 13 16 :2 20 32 :2 3c 48 4c
5e 61 62 :2 5e :2 32 :3 16 :2 1c 21
2d 6f 72 :2 2d 7f 82 :2 2d 86
89 :2 2d 95 98 :2 2d a0 a3 :2 2d
af b2 b9 c2 c5 :2 b2 :2 2d :2 16
65 :2 13 :2 10 :4 1c :2 10 d :3 a 11
:2 1a 25 23 :2 2e :2 23 10 1f 39
46 57 65 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 64 65
:2 61 :2 35 :3 19 :2 1f 24 30 72 75
:2 30 82 85 :2 30 89 8c :2 30 98
9b :2 30 a3 a6 :2 30 b2 b5 bc
c5 c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13
:4 1f :2 13 10 :3 3e 13 1a 26 29
:2 13 2c 2e :2 2c 1d 33 1b 1c
2a :2 16 :2 1f 2b 16 13 1b 19
:2 22 2e 19 29 :2 16 :2 1b 19 :2 22
2e 19 1c :2 26 38 :2 42 4e 52
64 67 68 :2 64 :2 38 :3 1c :2 22 27
33 75 78 :2 33 85 88 :2 33 8c
8f :2 33 9b 9e :2 33 a6 a9 :2 33
b5 b8 bf c8 cb :2 b8 :2 33 :2 1c
6b :2 19 :2 16 :4 22 :2 16 13 :4 32 1d
36 1b 1c 29 :2 16 :2 1f 2b 16
13 1b 19 :2 22 2e 19 29 :2 16
:2 1b 19 :2 22 2e 19 1c :2 26 38
:2 42 4e 52 64 67 68 :2 64 :2 38
:3 1c :2 22 27 33 75 78 :2 33 85
88 :2 33 8c 8f :2 33 9b 9e :2 33
a6 a9 :2 33 b5 b8 bf c8 cb
:2 b8 :2 33 :2 1c 6b :2 19 :2 16 :4 22 :2 16
13 :7 10 1a 26 35 3e 4c 19
26 37 44 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 64 65
:2 61 :2 35 :3 19 :2 1f 24 30 72 75
:2 30 82 85 :2 30 89 8c :2 30 98
9b :2 30 a3 a6 :2 30 b2 b5 bc
c5 c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13
:4 1f :2 13 10 :4 3e 1a 33 41 4a
55 19 2d 13 1a 16 22 :3 20
16 :2 1f 2b 16 27 16 :2 1f 2b
16 :4 13 10 18 16 :2 1f 2b 16
26 :2 13 :2 18 16 :2 1f 2b 16 19
:2 23 35 :2 3f 4b 4f 61 64 65
:2 61 :2 35 :3 19 :2 1f 24 30 72 75
:2 30 82 85 :2 30 89 8c :2 30 98
9b :2 30 a3 a6 :2 30 b2 b5 bc
c5 c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13
:4 1f :2 13 10 :7 d 1c 33 47 10
17 13 1f :3 1d 13 :2 1c 28 13
24 13 :2 1c 28 13 :4 10 d 15
13 :2 1c 28 13 23 :2 10 :2 15 13
:2 1c 28 13 16 :2 20 32 :2 3c 48
4c 5e 61 62 :2 5e :2 32 :3 16 :2 1c
21 2d 6f 72 :2 2d 7f 82 :2 2d
86 89 :2 2d 95 98 :2 2d a0 a3
:2 2d af b2 b9 c2 c5 :2 b2 :2 2d
:2 16 65 :2 13 :2 10 :4 1c :2 10 d :3 a
1c 33 40 51 65 10 17 13
1f :3 1d 13 :2 1c 28 13 24 13
:2 1c 28 13 :4 10 d 15 13 :2 1c
28 13 23 :2 10 :2 15 13 :2 1c 28
13 16 :2 20 32 :2 3c 48 4c 5e
61 62 :2 5e :2 32 :3 16 :2 1c 21 2d
6f 72 :2 2d 7f 82 :2 2d 86 89
:2 2d 95 98 :2 2d a0 a3 :2 2d af
b2 b9 c2 c5 :2 b2 :2 2d :2 16 65
:2 13 :2 10 :4 1c :2 10 d :4 a e 25
d 13 :3 d :2 16 22 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 5b 5e 5f :2 5b :2 2f :3 13 :2 19
1e 2a 6c 6f :2 2a 7c 7f :2 2a
83 86 :2 2a 92 95 :2 2a 9d a0
:2 2a ac af b6 bf c2 :2 af :2 2a
:2 13 62 :2 10 :2 d :4 19 :2 d a :3 25
:2 a 7 25 d 16 21 :2 d 24
26 :2 24 a f :4 a 13 1f 29
35 44 :3 d 10 17 :2 10 :2 19 25
10 1d 10 :2 19 25 10 :4 d 11
:2 1a 26 23 :2 2f :2 23 :3 10 3f :2 d
10 17 23 26 :2 10 29 2b :2 29
1a 30 18 19 27 :2 13 :2 1c 28
13 10 18 16 :2 1f 2b 16 26
:2 13 :2 18 16 :2 1f 2b 16 19 :2 23
35 :2 3f 4b 4f 61 64 65 :2 61
:2 35 :3 19 :2 1f 24 30 72 75 :2 30
82 85 :2 30 89 8c :2 30 98 9b
:2 30 a3 a6 :2 30 b2 b5 bc c5
c8 :2 b5 :2 30 :2 19 68 :2 16 :2 13 :4 1f
:2 13 10 :4 2f 1a 33 18 19 26
:2 13 :2 1c 28 13 10 18 16 :2 1f
2b 16 26 :2 13 :2 18 16 :2 1f 2b
16 19 :2 23 35 :2 3f 4b 4f 61
64 65 :2 61 :2 35 :3 19 :2 1f 24 30
72 75 :2 30 82 85 :2 30 89 8c
:2 30 98 9b :2 30 a3 a6 :2 30 b2
b5 bc c5 c8 :2 b5 :2 30 :2 19 68
:2 16 :2 13 :4 1f :2 13 10 :7 d 17 23
15 1b 29 3f 15 25 16 23
34 41 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 61 62 :2 5e
:2 32 :3 16 :2 1c 21 2d 6f 72 :2 2d
7f 82 :2 2d 86 89 :2 2d 95 98
:2 2d a0 a3 :2 2d af b2 b9 c2
c5 :2 b2 :2 2d :2 16 65 :2 13 :2 10 :4 1c
:2 10 d :3 a 1c 31 3d 4a 57
64 73 85 17 25 2f 3e 4d
5c 65 10 17 13 1f :3 1d 13
:2 1c 28 13 24 13 :2 1c 28 13
:4 10 d 15 13 :2 1c 28 13 23
:2 10 :2 15 13 :2 1c 28 13 16 :2 20
32 :2 3c 48 4c 5e 61 62 :2 5e
:2 32 :3 16 :2 1c 21 2d 6f 72 :2 2d
7f 82 :2 2d 86 89 :2 2d 95 98
:2 2d a0 a3 :2 2d af b2 b9 c2
c5 :2 b2 :2 2d :2 16 65 :2 13 :2 10 :4 1c
:2 10 d :4 a e 28 d 13 :3 d
:2 16 22 d a 12 10 :2 19 25
10 20 :2 d :2 12 10 :2 19 25 10
13 :2 1d 2f :2 39 45 49 5b 5e
5f :2 5b :2 2f :3 13 :2 19 1e 2a 6c
6f :2 2a 7c 7f :2 2a 83 86 :2 2a
92 95 :2 2a 9d a0 :2 2a ac af
b6 bf c2 :2 af :2 2a :2 13 62 :2 10
:2 d :4 19 :2 d a :3 28 :2 a 28 25
:2 7 4 8 1 7 d :3 7 :2 10
1c 7 4 c a :2 13 1f a
1a :2 7 :2 c a :2 13 1f a d
:2 17 29 :2 33 3f 43 55 58 59
:2 55 :2 29 :3 d :2 13 18 24 66 69
:2 24 76 79 :2 24 7d 80 :2 24 8c
8f :2 24 97 9a :2 24 a6 a9 b0
b9 bc :2 a9 :2 24 :2 d 5c :2 a :2 7
:4 13 :2 7 4 :3 1 7 :2 11 23 :2 2d
39 3c 4e 51 52 :2 4e :2 23 :3 7
:2 d 12 1e 60 63 :2 1e 70 73
:2 1e 77 7a :2 1e 84 87 90 98
:2 a1 :2 90 ac :2 87 :2 1e b4 b7 :2 1e
bf c2 :2 1e c7 ca :2 1e d1 d4
:2 1e :2 7 55 :3 4 :2 f 21 :2 2a 34
3c :2 4 1 9 12 9 a :2 14
26 :2 30 3c 40 52 55 56 :2 52
:2 26 :3 a :2 10 15 21 63 66 :2 21
:3 a :2 10 15 39 5c 5f :2 68 :2 39
76 79 :2 39 81 84 :2 8d :2 39 :2 a
59 :3 7 c 15 1e 2c a 13
1e f e 7 e 7 e 7
29 :2 4 :2 9 7 :2 10 1c :2 7 :2 11
23 :2 2d 39 3d 4f 52 53 :2 4f
:2 23 :3 7 :2 d 12 1e 60 63 :2 1e
:3 7 :2 d 12 36 42 45 :2 36 4d
50 :2 36 5c 5f 66 6f 72 :2 5f
:2 36 :2 7 56 :2 4 7 c 1b a
13 1e f e 7 e 7 e
7 :2 4 :4 10 :2 4 :8 1 
a60
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :7 7
:7 8 :7 9 :7 a :7 b
:7 c :7 d :7 e :6 f
:6 10 :2 12 0 :2 12
:2 13 :d 14 13 :5 12
:2 16 0 :2 16 :4 17
18 :4 19 17 :5 16
:2 1b 0 :2 1b :8 1c
:2 1d :2 1e :9 1f 1c
:5 1b :7 21 :b 23 :11 24
25 :2 24 :2 25 :2 24
:2 25 :2 24 :2 26 :2 24
:9 26 :2 24 :2 26 :4 24
:3 23 :11 29 :b 2a :3 29
:3 2d :3 2e :5 30 32
:4 33 :3 34 :5 35 34
:5 37 36 :3 34 :a 39
:2 3a :3 39 :9 3e :5 3f
41 :8 42 :3 43 :5 44
43 :5 46 45 :3 43
:a 48 :2 49 :3 48 :3 4c
:4 4e :4 4f 4e :5 50
4d 52 :5 53 :3 52
:2 54 :5 56 :11 57 :24 58
:3 57 :2 55 :6 54 51
:3 41 :9 5d :2 5f :2 60
5f :6 61 :5 62 61
:5 64 63 :3 61 5e
67 :5 68 :3 67 :2 69
:5 6b :11 6c :24 6d :3 6c
:2 6a :6 69 66 :3 5d
:3 73 :4 74 73 :6 75
:5 76 75 :5 78 77
:3 75 72 7b :5 7c
:3 7b :2 7d :5 7f :11 80
:24 81 :3 80 :2 7e :6 7d
7a :6 5d 88 :2 89
8a 88 :6 8b :5 8c
8b :5 8e 8d :3 8b
87 91 :5 92 :3 91
:2 93 :5 95 :11 96 :24 97
:3 96 :2 94 :6 93 90
:3 41 :a 9c :6 9e :6 9f
:5 a0 9f :5 a2 a1
:3 9f 9d a5 :5 a6
:3 a5 :2 a7 :5 a9 :11 aa
:24 ab :3 aa :2 a8 :6 a7
a4 :3 9c :a b0 :2 b2
b3 :2 b4 b2 :5 b5
b1 b7 :5 b8 :3 b7
:2 b9 :5 bb :11 bc :24 bd
:3 bc :2 ba :6 b9 b6
:4 b0 :2 c3 c4 :2 c5
c3 :5 c6 c2 c8
:5 c9 :3 c8 :2 ca :5 cc
:11 cd :24 ce :3 cd :2 cb
:6 ca c7 :4 c1 :3 b0
:5 d5 :4 d6 d5 :6 d7
:5 d8 d7 :5 da d9
:3 d7 d4 dd :5 de
:3 dd :2 df :5 e1 :11 e2
:24 e3 :3 e2 :2 e0 :6 df
dc :4 9c :5 e9 :2 ea
e9 :6 eb :5 ec eb
:5 ee ed :3 eb e8
f1 :5 f2 :3 f1 :2 f3
:5 f5 :11 f6 :24 f7 :3 f6
:2 f4 :6 f3 f0 :4 e7
:3 9c :4 fe :6 ff :5 100
ff :5 102 101 :3 ff
fd 105 :5 106 :3 105
:2 107 :5 109 :11 10a :24 10b
:3 10a :2 108 :6 107 104
:3 41 :6 111 :6 112 :5 113
112 :5 115 114 :3 112
110 118 :5 119 :3 118
:2 11a :5 11c :11 11d :24 11e
:3 11d :2 11b :6 11a 117
:4 41 122 3e :4 125
:5 126 124 128 :5 129
:3 128 :2 12a :5 12c :11 12d
:24 12e :3 12d :2 12b :6 12a
127 :3 3e :2 133 134
3e :9 134 :5 135 137
:8 138 :3 139 :5 13a 139
:5 13c 13b :3 139 :a 13e
:2 13f :3 13e :a 142 :2 144
145 :2 146 144 :5 147
143 149 :5 14a :3 149
:2 14b :5 14d :11 14e :24 14f
:3 14e :2 14c :6 14b 148
:4 142 :2 155 156 :2 157
155 :5 158 154 15a
:5 15b :3 15a :2 15c :5 15e
:11 15f :24 160 :3 15f :2 15d
:6 15c 159 :4 153 :3 142
:2 167 :4 168 :2 169 :4 16a
167 :6 16b :5 16c 16b
:5 16e 16d :3 16b 166
171 :5 172 :3 171 :2 173
:5 175 :11 176 :24 177 :3 176
:2 174 :6 173 170 :3 137
:8 17d :7 17e 17d :6 17f
:5 180 17f :5 182 181
:3 17f 17c 185 :5 186
:3 185 :2 187 :5 189 :11 18a
:24 18b :3 18a :2 188 :6 187
184 :4 137 190 134
:4 193 :5 194 192 196
:5 197 :3 196 :2 198 :5 19a
:11 19b :24 19c :3 19b :2 199
:6 198 195 :3 134 :2 1a1
134 :3 3e 32 1a3
22 :4 1a6 :5 1a7 1a5
1a9 :5 1aa :3 1a9 :2 1ab
:5 1ad :11 1ae :24 1af :3 1ae
:2 1ac :6 1ab 1a8 :3 22
:11 1b4 :30 1b5 :3 1b4 :a 1b7
22 :3 1ba :11 1bb :b 1bc
:17 1bd :3 1bb :2 1bf :3 1c0
:3 1c1 1c2 1c0 1bf
1c0 :3 1c3 :3 1ba :2 1c4
:5 1c6 :11 1c7 :b 1c8 :18 1c9
:3 1c7 :2 1cb 1cc :3 1cd
1ce 1cc 1cb 1cc
:3 1cf :2 1c5 :6 1c4 1b9
:7 1 
2536
4
:3 0 1 :3 0 2
:a 0 a5b 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 6
:3 0 5 :7 0 9
8 :3 0 7 :3 0
8 :3 0 9 :2 0
4 b f 0
a5b 2 10 :2 0
d :2 0 c 4
:3 0 b :2 0 a
13 15 :6 0 18
16 0 a59 0
a :6 0 f :2 0
10 4 :3 0 e
1a 1c :6 0 1f
1d 0 a59 0
c :6 0 f :2 0
14 4 :3 0 12
21 23 :6 0 26
24 0 a59 0
e :6 0 f :2 0
18 4 :3 0 16
28 2a :6 0 2d
2b 0 a59 0
10 :6 0 f :2 0
1c 4 :3 0 1a
2f 31 :6 0 34
32 0 a59 0
11 :6 0 f :2 0
20 4 :3 0 1e
36 38 :6 0 3b
39 0 a59 0
12 :6 0 15 :2 0
24 4 :3 0 22
3d 3f :6 0 42
40 0 a59 0
13 :6 0 17 :2 0
28 4 :3 0 26
44 46 :6 0 49
47 0 a59 0
14 :6 0 17 :2 0
2a 6 :3 0 4b
:7 0 4f 4c 4d
a59 0 16 :9 0
2c 6 :3 0 51
:7 0 55 52 53
a59 0 18 :6 0
19 :3 0 1a :a 0
2 6b :4 0 57
5a 0 58 :3 0
1b :3 0 1c :3 0
1d :3 0 1e :3 0
1f :3 0 1e :3 0
20 :3 0 1e :3 0
21 :3 0 1e :3 0
22 :3 0 1e :3 0
23 :3 0 24 :3 0
a :4 0 25 1
:8 0 6c 57 5a
6d 0 a59 2e
6d 6f 6c 6e
:6 0 6b :7 0 6d
19 :3 0 26 :a 0
3 7f :5 0 71
74 0 72 :3 0
27 :3 0 28 :3 0
29 :3 0 2a :3 0
2b :3 0 2c :3 0
e :3 0 2d :3 0
e :4 0 2e 1
:8 0 80 71 74
81 0 a59 30
81 83 80 82
:6 0 7f :7 0 81
19 :3 0 2f :a 0
4 9f :5 0 85
88 0 86 :3 0
30 :3 0 29 :3 0
30 :3 0 2a :3 0
30 :3 0 31 :3 0
30 :3 0 32 :3 0
33 :3 0 30 :3 0
1b :3 0 e :3 0
34 :3 0 35 :3 0
35 :3 0 2c :3 0
e :3 0 35 :3 0
29 :3 0 30 :3 0
29 :4 0 36 1
:8 0 a0 85 88
a1 0 a59 32
a1 a3 a0 a2
:6 0 9f :7 0 a1
ab ac 0 34
8 :3 0 9 :2 0
4 a5 a6 0
a7 :7 0 aa a8
0 a59 0 37
:6 0 38 :3 0 39
:3 0 38 :3 0 3a
:3 0 ae af 0
2 :4 0 36 b0
b2 ad b4 b3
:2 0 3b :3 0 3c
:3 0 b6 b7 0
3d :4 0 38 :3 0
3e :3 0 ba bb
0 2 :4 0 38
bc be 3f :4 0
40 :2 0 41 :3 0
3a c1 c3 :3 0
42 :4 0 40 :2 0
43 :4 0 3d c6
c8 :3 0 40 :2 0
3 :3 0 40 ca
cc :3 0 40 :2 0
43 :4 0 43 ce
d0 :3 0 40 :2 0
44 :4 0 46 d2
d4 :3 0 40 :2 0
45 :3 0 46 :3 0
5 :3 0 49 d8
da 47 :4 0 4b
d7 dd 4e d6
df :3 0 40 :2 0
48 :4 0 51 e1
e3 :3 0 54 b8
e5 :2 0 e7 59
e8 b5 e7 0
e9 5b 0 9b9
38 :3 0 39 :3 0
ea eb 0 38
:3 0 49 :3 0 ed
ee 0 15 :2 0
2 :4 0 4a :2 0
4b :2 0 15 :2 0
5d f3 f5 :3 0
60 ef f7 ec
f9 f8 :2 0 3b
:3 0 4c :3 0 fb
fc 0 3d :4 0
4d :4 0 40 :2 0
41 :3 0 64 100
102 :3 0 67 fd
104 :2 0 106 6a
107 fa 106 0
108 6c 0 9b9
a :3 0 3 :3 0
109 10a 0 9b9
18 :3 0 5 :3 0
10c 10d 0 9b9
4e :3 0 1a :4 0
112 :2 0 9b9 110
113 :3 0 4f :3 0
1a :3 0 e :4 0
118 :2 0 90a 115
116 :3 0 1a :3 0
50 :3 0 119 11a
:3 0 8 :3 0 51
:3 0 11c 11d 0
17 :2 0 11e 11f
0 121 6e 128
8 :3 0 51 :3 0
122 123 0 52
:2 0 124 125 0
127 70 129 11b
121 0 12a 0
127 0 12a 72
0 90a 8 :3 0
51 :3 0 12b 12c
0 8 :3 0 53
:2 0 54 :3 0 12e
130 0 77 12f
132 :3 0 133 :2 0
55 :8 0 137 7a
138 134 137 0
139 7c 0 90a
45 :3 0 18 :3 0
17 :2 0 7e 13a
13d 56 :2 0 17
:2 0 83 13f 141
:3 0 4e :3 0 26
:4 0 146 :2 0 6aa
144 147 :3 0 4f
:3 0 26 :3 0 10
:3 0 11 :3 0 13
:3 0 14 :4 0 14f
:2 0 646 149 150
:3 0 86 :3 0 26
:3 0 50 :3 0 151
152 :3 0 8 :3 0
51 :3 0 154 155
0 17 :2 0 156
157 0 159 8b
160 8 :3 0 51
:3 0 15a 15b 0
52 :2 0 15c 15d
0 15f 8d 161
153 159 0 162
0 15f 0 162
8f 0 646 8
:3 0 51 :3 0 163
164 0 8 :3 0
53 :2 0 54 :3 0
166 168 0 94
167 16a :3 0 16b
:2 0 55 :8 0 16f
97 170 16c 16f
0 171 99 0
646 18 :3 0 17
:2 0 172 173 0
646 57 :3 0 18
:3 0 58 :3 0 2b
:3 0 59 :3 0 11
:3 0 29 :3 0 13
:4 0 5a 1 :8 0
183 8 :3 0 51
:3 0 17e 17f 0
5b :3 0 180 181
0 183 9b 1d6
5c :3 0 8 :3 0
51 :3 0 185 186
0 5b :3 0 187
188 0 18a 9e
18c a0 18b 18a
:2 0 1d4 5d :3 0
8 :3 0 51 :3 0
18f 190 0 5b
:3 0 191 192 0
1cc 38 :3 0 39
:3 0 194 195 0
38 :3 0 49 :3 0
197 198 0 5e
:2 0 2 :4 0 5f
:2 0 4b :2 0 15
:2 0 a2 19d 19f
:3 0 a5 199 1a1
196 1a3 1a2 :2 0
3b :3 0 4c :3 0
1a5 1a6 0 3d
:4 0 60 :4 0 40
:2 0 41 :3 0 a9
1aa 1ac :3 0 40
:2 0 61 :4 0 ac
1ae 1b0 :3 0 40
:2 0 62 :4 0 af
1b2 1b4 :3 0 40
:2 0 5b :3 0 b2
1b6 1b8 :3 0 40
:2 0 63 :4 0 b5
1ba 1bc :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 b8 1bf 1c3
bc 1be 1c5 :3 0
bf 1a7 1c7 :2 0
1c9 c2 1ca 1a4
1c9 0 1cb c4
0 1cc c6 1cf
:3 0 1cf 0 1cf
1ce 1cc 1cd :6 0
1d1 7 :3 0 c9
1d3 cb 1d2 1d1
:2 0 1d4 cd :2 0
1d6 0 1d6 1d5
183 1d4 :6 0 646
6 :3 0 45 :3 0
18 :3 0 17 :2 0
d0 1d8 1db 53
:2 0 17 :2 0 d5
1dd 1df :3 0 2b
:3 0 59 :3 0 59
:3 0 11 :4 0 67
1 :8 0 1fb 50
:4 0 1e6 :3 0 68
:3 0 56 :2 0 da
1e9 1ea :3 0 8
:3 0 51 :3 0 1ec
1ed 0 17 :2 0
1ee 1ef 0 1f1
dd 1f8 8 :3 0
51 :3 0 1f2 1f3
0 52 :2 0 1f4
1f5 0 1f7 df
1f9 1eb 1f1 0
1fa 0 1f7 0
1fa e1 0 1fb
e4 24e 5c :3 0
8 :3 0 51 :3 0
1fd 1fe 0 5b
:3 0 1ff 200 0
202 e7 204 e9
203 202 :2 0 24c
5d :3 0 8 :3 0
51 :3 0 207 208
0 5b :3 0 209
20a 0 244 38
:3 0 39 :3 0 20c
20d 0 38 :3 0
49 :3 0 20f 210
0 5e :2 0 2
:4 0 69 :2 0 4b
:2 0 15 :2 0 eb
215 217 :3 0 ee
211 219 20e 21b
21a :2 0 3b :3 0
4c :3 0 21d 21e
0 3d :4 0 6a
:4 0 40 :2 0 41
:3 0 f2 222 224
:3 0 40 :2 0 61
:4 0 f5 226 228
:3 0 40 :2 0 62
:4 0 f8 22a 22c
:3 0 40 :2 0 5b
:3 0 fb 22e 230
:3 0 40 :2 0 63
:4 0 fe 232 234
:3 0 40 :2 0 64
:3 0 65 :3 0 15
:2 0 66 :2 0 101
237 23b 105 236
23d :3 0 108 21f
23f :2 0 241 10b
242 21c 241 0
243 10d 0 244
10f 247 :3 0 247
0 247 246 244
245 :6 0 249 9
:3 0 112 24b 114
24a 249 :2 0 24c
116 :2 0 24e 0
24e 24d 1fb 24c
:6 0 2c2 6 :3 0
6b :3 0 6c :3 0
28 :3 0 2c :3 0
e :3 0 6c :3 0
11 :4 0 6d 1
:8 0 26d 50 :4 0
258 :3 0 68 :3 0
56 :2 0 11b 25b
25c :3 0 8 :3 0
51 :3 0 25e 25f
0 17 :2 0 260
261 0 263 11e
26a 8 :3 0 51
:3 0 264 265 0
52 :2 0 266 267
0 269 120 26b
25d 263 0 26c
0 269 0 26c
122 0 26d 125
2c0 5c :3 0 8
:3 0 51 :3 0 26f
270 0 5b :3 0
271 272 0 274
128 276 12a 275
274 :2 0 2be 5d
:3 0 8 :3 0 51
:3 0 279 27a 0
5b :3 0 27b 27c
0 2b6 38 :3 0
39 :3 0 27e 27f
0 38 :3 0 49
:3 0 281 282 0
5e :2 0 2 :4 0
6e :2 0 4b :2 0
15 :2 0 12c 287
289 :3 0 12f 283
28b 280 28d 28c
:2 0 3b :3 0 4c
:3 0 28f 290 0
3d :4 0 6f :4 0
40 :2 0 41 :3 0
133 294 296 :3 0
40 :2 0 61 :4 0
136 298 29a :3 0
40 :2 0 62 :4 0
139 29c 29e :3 0
40 :2 0 5b :3 0
13c 2a0 2a2 :3 0
40 :2 0 63 :4 0
13f 2a4 2a6 :3 0
40 :2 0 64 :3 0
65 :3 0 15 :2 0
66 :2 0 142 2a9
2ad 146 2a8 2af
:3 0 149 291 2b1
:2 0 2b3 14c 2b4
28e 2b3 0 2b5
14e 0 2b6 150
2b9 :3 0 2b9 0
2b9 2b8 2b6 2b7
:6 0 2bb b :3 0
153 2bd 155 2bc
2bb :2 0 2be 157
:2 0 2c0 0 2c0
2bf 26d 2be :6 0
2c2 6 :3 0 15a
2c3 1e0 2c2 0
2c4 15d 0 646
33 :3 0 27 :3 0
10 :3 0 32 :4 0
70 1 :8 0 2df
50 :4 0 2ca :3 0
68 :3 0 56 :2 0
161 2cd 2ce :3 0
8 :3 0 51 :3 0
2d0 2d1 0 17
:2 0 2d2 2d3 0
2d5 164 2dc 8
:3 0 51 :3 0 2d6
2d7 0 52 :2 0
2d8 2d9 0 2db
166 2dd 2cf 2d5
0 2de 0 2db
0 2de 168 0
2df 16b 332 5c
:3 0 8 :3 0 51
:3 0 2e1 2e2 0
5b :3 0 2e3 2e4
0 2e6 16e 2e8
170 2e7 2e6 :2 0
330 5d :3 0 8
:3 0 51 :3 0 2eb
2ec 0 5b :3 0
2ed 2ee 0 328
38 :3 0 39 :3 0
2f0 2f1 0 38
:3 0 49 :3 0 2f3
2f4 0 5e :2 0
2 :4 0 71 :2 0
4b :2 0 15 :2 0
172 2f9 2fb :3 0
175 2f5 2fd 2f2
2ff 2fe :2 0 3b
:3 0 4c :3 0 301
302 0 3d :4 0
72 :4 0 40 :2 0
41 :3 0 179 306
308 :3 0 40 :2 0
61 :4 0 17c 30a
30c :3 0 40 :2 0
62 :4 0 17f 30e
310 :3 0 40 :2 0
5b :3 0 182 312
314 :3 0 40 :2 0
63 :4 0 185 316
318 :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
188 31b 31f 18c
31a 321 :3 0 18f
303 323 :2 0 325
192 326 300 325
0 327 194 0
328 196 32b :3 0
32b 0 32b 32a
328 329 :6 0 32d
d :3 0 199 32f
19b 32e 32d :2 0
330 19d :2 0 332
0 332 331 2df
330 :6 0 646 6
:3 0 8 :3 0 51
:3 0 334 335 0
8 :3 0 56 :2 0
54 :3 0 337 339
0 1a2 338 33b
:3 0 33c :2 0 34
:3 0 2c :3 0 e
:3 0 29 :3 0 13
:4 0 73 1 :8 0
359 50 :4 0 344
:3 0 68 :3 0 56
:2 0 1a7 347 348
:3 0 8 :3 0 51
:3 0 34a 34b 0
17 :2 0 34c 34d
0 34f 1aa 356
8 :3 0 51 :3 0
350 351 0 52
:2 0 352 353 0
355 1ac 357 349
34f 0 358 0
355 0 358 1ae
0 359 1b1 3ac
5c :3 0 8 :3 0
51 :3 0 35b 35c
0 5b :3 0 35d
35e 0 360 1b4
362 1b6 361 360
:2 0 3aa 5d :3 0
8 :3 0 51 :3 0
365 366 0 5b
:3 0 367 368 0
3a2 38 :3 0 39
:3 0 36a 36b 0
38 :3 0 49 :3 0
36d 36e 0 5e
:2 0 2 :4 0 74
:2 0 4b :2 0 15
:2 0 1b8 373 375
:3 0 1bb 36f 377
36c 379 378 :2 0
3b :3 0 4c :3 0
37b 37c 0 3d
:4 0 75 :4 0 40
:2 0 41 :3 0 1bf
380 382 :3 0 40
:2 0 61 :4 0 1c2
384 386 :3 0 40
:2 0 62 :4 0 1c5
388 38a :3 0 40
:2 0 5b :3 0 1c8
38c 38e :3 0 40
:2 0 63 :4 0 1cb
390 392 :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 1ce 395 399
1d2 394 39b :3 0
1d5 37d 39d :2 0
39f 1d8 3a0 37a
39f 0 3a1 1da
0 3a2 1dc 3a5
:3 0 3a5 0 3a5
3a4 3a2 3a3 :6 0
3a7 f :3 0 1df
3a9 1e1 3a8 3a7
:2 0 3aa 1e3 :2 0
3ac 0 3ac 3ab
359 3aa :6 0 4f1
6 :3 0 64 :3 0
14 :3 0 15 :2 0
15 :2 0 1e6 3ae
3b2 56 :2 0 17
:4 0 1ec 3b4 3b6
:3 0 76 :3 0 c
:3 0 77 :3 0 29
:3 0 13 :4 0 78
1 :8 0 3c3 8
:3 0 51 :3 0 3be
3bf 0 5b :3 0
3c0 3c1 0 3c3
1ef 416 5c :3 0
8 :3 0 51 :3 0
3c5 3c6 0 5b
:3 0 3c7 3c8 0
3ca 1f2 3cc 1f4
3cb 3ca :2 0 414
5d :3 0 8 :3 0
51 :3 0 3cf 3d0
0 5b :3 0 3d1
3d2 0 40c 38
:3 0 39 :3 0 3d4
3d5 0 38 :3 0
49 :3 0 3d7 3d8
0 5e :2 0 2
:4 0 79 :2 0 4b
:2 0 15 :2 0 1f6
3dd 3df :3 0 1f9
3d9 3e1 3d6 3e3
3e2 :2 0 3b :3 0
4c :3 0 3e5 3e6
0 3d :4 0 7a
:4 0 40 :2 0 41
:3 0 1fd 3ea 3ec
:3 0 40 :2 0 61
:4 0 200 3ee 3f0
:3 0 40 :2 0 62
:4 0 203 3f2 3f4
:3 0 40 :2 0 5b
:3 0 206 3f6 3f8
:3 0 40 :2 0 63
:4 0 209 3fa 3fc
:3 0 40 :2 0 64
:3 0 65 :3 0 15
:2 0 66 :2 0 20c
3ff 403 210 3fe
405 :3 0 213 3e7
407 :2 0 409 216
40a 3e4 409 0
40b 218 0 40c
21a 40f :3 0 40f
0 40f 40e 40c
40d :6 0 411 11
:3 0 21d 413 21f
412 411 :2 0 414
221 :2 0 416 0
416 415 3c3 414
:6 0 418 6 :3 0
224 47a 7b :3 0
c :3 0 7c :3 0
7d :3 0 13 :4 0
7e 1 :8 0 424
8 :3 0 51 :3 0
41f 420 0 5b
:3 0 421 422 0
424 226 477 5c
:3 0 8 :3 0 51
:3 0 426 427 0
5b :3 0 428 429
0 42b 229 42d
22b 42c 42b :2 0
475 5d :3 0 8
:3 0 51 :3 0 430
431 0 5b :3 0
432 433 0 46d
38 :3 0 39 :3 0
435 436 0 38
:3 0 49 :3 0 438
439 0 5e :2 0
2 :4 0 7f :2 0
4b :2 0 15 :2 0
22d 43e 440 :3 0
230 43a 442 437
444 443 :2 0 3b
:3 0 4c :3 0 446
447 0 3d :4 0
80 :4 0 40 :2 0
41 :3 0 234 44b
44d :3 0 40 :2 0
61 :4 0 237 44f
451 :3 0 40 :2 0
62 :4 0 23a 453
455 :3 0 40 :2 0
5b :3 0 23d 457
459 :3 0 40 :2 0
63 :4 0 240 45b
45d :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
243 460 464 247
45f 466 :3 0 24a
448 468 :2 0 46a
24d 46b 445 46a
0 46c 24f 0
46d 251 470 :3 0
470 0 470 46f
46d 46e :6 0 472
13 :3 0 254 474
256 473 472 :2 0
475 258 :2 0 477
0 477 476 424
475 :6 0 479 6
:3 0 25b 47b 3b7
418 0 47c 0
479 0 47c 25d
0 4f1 1c :3 0
81 :3 0 82 :3 0
81 :3 0 c :3 0
2c :3 0 e :3 0
1b :3 0 e :4 0
83 1 :8 0 49c
50 :4 0 487 :3 0
68 :3 0 56 :2 0
262 48a 48b :3 0
8 :3 0 51 :3 0
48d 48e 0 17
:2 0 48f 490 0
492 265 499 8
:3 0 51 :3 0 493
494 0 52 :2 0
495 496 0 498
267 49a 48c 492
0 49b 0 498
0 49b 269 0
49c 26c 4ef 5c
:3 0 8 :3 0 51
:3 0 49e 49f 0
5b :3 0 4a0 4a1
0 4a3 26f 4a5
271 4a4 4a3 :2 0
4ed 5d :3 0 8
:3 0 51 :3 0 4a8
4a9 0 5b :3 0
4aa 4ab 0 4e5
38 :3 0 39 :3 0
4ad 4ae 0 38
:3 0 49 :3 0 4b0
4b1 0 5e :2 0
2 :4 0 84 :2 0
4b :2 0 15 :2 0
273 4b6 4b8 :3 0
276 4b2 4ba 4af
4bc 4bb :2 0 3b
:3 0 4c :3 0 4be
4bf 0 3d :4 0
85 :4 0 40 :2 0
41 :3 0 27a 4c3
4c5 :3 0 40 :2 0
61 :4 0 27d 4c7
4c9 :3 0 40 :2 0
62 :4 0 280 4cb
4cd :3 0 40 :2 0
5b :3 0 283 4cf
4d1 :3 0 40 :2 0
63 :4 0 286 4d3
4d5 :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
289 4d8 4dc 28d
4d7 4de :3 0 290
4c0 4e0 :2 0 4e2
293 4e3 4bd 4e2
0 4e4 295 0
4e5 297 4e8 :3 0
4e8 0 4e8 4e7
4e5 4e6 :6 0 4ea
15 :3 0 29a 4ec
29c 4eb 4ea :2 0
4ed 29e :2 0 4ef
0 4ef 4ee 49c
4ed :6 0 4f1 6
:3 0 2a1 565 33
:3 0 31 :3 0 86
:3 0 87 :3 0 31
:3 0 27 :3 0 10
:4 0 88 1 :8 0
50f 50 :4 0 4fa
:3 0 68 :3 0 56
:2 0 2a7 4fd 4fe
:3 0 8 :3 0 51
:3 0 500 501 0
17 :2 0 502 503
0 505 2aa 50c
8 :3 0 51 :3 0
506 507 0 52
:2 0 508 509 0
50b 2ac 50d 4ff
505 0 50e 0
50b 0 50e 2ae
0 50f 2b1 562
5c :3 0 8 :3 0
51 :3 0 511 512
0 5b :3 0 513
514 0 516 2b4
518 2b6 517 516
:2 0 560 5d :3 0
8 :3 0 51 :3 0
51b 51c 0 5b
:3 0 51d 51e 0
558 38 :3 0 39
:3 0 520 521 0
38 :3 0 49 :3 0
523 524 0 5e
:2 0 2 :4 0 89
:2 0 4b :2 0 15
:2 0 2b8 529 52b
:3 0 2bb 525 52d
522 52f 52e :2 0
3b :3 0 4c :3 0
531 532 0 3d
:4 0 8a :4 0 40
:2 0 41 :3 0 2bf
536 538 :3 0 40
:2 0 61 :4 0 2c2
53a 53c :3 0 40
:2 0 62 :4 0 2c5
53e 540 :3 0 40
:2 0 5b :3 0 2c8
542 544 :3 0 40
:2 0 63 :4 0 2cb
546 548 :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 2ce 54b 54f
2d2 54a 551 :3 0
2d5 533 553 :2 0
555 2d8 556 530
555 0 557 2da
0 558 2dc 55b
:3 0 55b 0 55b
55a 558 559 :6 0
55d 17 :3 0 2df
55f 2e1 55e 55d
:2 0 560 2e3 :2 0
562 0 562 561
50f 560 :6 0 564
6 :3 0 2e6 566
33d 4f1 0 567
0 564 0 567
2e8 0 646 2b
:3 0 28 :3 0 11
:4 0 8b 1 :8 0
581 50 :4 0 56c
:3 0 68 :3 0 56
:2 0 2ed 56f 570
:3 0 8 :3 0 51
:3 0 572 573 0
17 :2 0 574 575
0 577 2f0 57e
8 :3 0 51 :3 0
578 579 0 52
:2 0 57a 57b 0
57d 2f2 57f 571
577 0 580 0
57d 0 580 2f4
0 581 2f7 5d4
5c :3 0 8 :3 0
51 :3 0 583 584
0 5b :3 0 585
586 0 588 2fa
58a 2fc 589 588
:2 0 5d2 5d :3 0
8 :3 0 51 :3 0
58d 58e 0 5b
:3 0 58f 590 0
5ca 38 :3 0 39
:3 0 592 593 0
38 :3 0 49 :3 0
595 596 0 5e
:2 0 2 :4 0 8c
:2 0 4b :2 0 15
:2 0 2fe 59b 59d
:3 0 301 597 59f
594 5a1 5a0 :2 0
3b :3 0 4c :3 0
5a3 5a4 0 3d
:4 0 8d :4 0 40
:2 0 41 :3 0 305
5a8 5aa :3 0 40
:2 0 61 :4 0 308
5ac 5ae :3 0 40
:2 0 62 :4 0 30b
5b0 5b2 :3 0 40
:2 0 5b :3 0 30e
5b4 5b6 :3 0 40
:2 0 63 :4 0 311
5b8 5ba :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 314 5bd 5c1
318 5bc 5c3 :3 0
31b 5a5 5c5 :2 0
5c7 31e 5c8 5a2
5c7 0 5c9 320
0 5ca 322 5cd
:3 0 5cd 0 5cd
5cc 5ca 5cb :6 0
5cf 19 :3 0 325
5d1 327 5d0 5cf
:2 0 5d2 329 :2 0
5d4 0 5d4 5d3
581 5d2 :6 0 646
6 :3 0 6b :3 0
2c :3 0 e :3 0
28 :3 0 11 :4 0
8e 1 :8 0 5f1
50 :4 0 5dc :3 0
68 :3 0 56 :2 0
32e 5df 5e0 :3 0
8 :3 0 51 :3 0
5e2 5e3 0 17
:2 0 5e4 5e5 0
5e7 331 5ee 8
:3 0 51 :3 0 5e8
5e9 0 52 :2 0
5ea 5eb 0 5ed
333 5ef 5e1 5e7
0 5f0 0 5ed
0 5f0 335 0
5f1 338 644 5c
:3 0 8 :3 0 51
:3 0 5f3 5f4 0
5b :3 0 5f5 5f6
0 5f8 33b 5fa
33d 5f9 5f8 :2 0
642 5d :3 0 8
:3 0 51 :3 0 5fd
5fe 0 5b :3 0
5ff 600 0 63a
38 :3 0 39 :3 0
602 603 0 38
:3 0 49 :3 0 605
606 0 5e :2 0
2 :4 0 8f :2 0
4b :2 0 15 :2 0
33f 60b 60d :3 0
342 607 60f 604
611 610 :2 0 3b
:3 0 4c :3 0 613
614 0 3d :4 0
90 :4 0 40 :2 0
41 :3 0 346 618
61a :3 0 40 :2 0
61 :4 0 349 61c
61e :3 0 40 :2 0
62 :4 0 34c 620
622 :3 0 40 :2 0
5b :3 0 34f 624
626 :3 0 40 :2 0
63 :4 0 352 628
62a :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
355 62d 631 359
62c 633 :3 0 35c
615 635 :2 0 637
35f 638 612 637
0 639 361 0
63a 363 63d :3 0
63d 0 63d 63c
63a 63b :6 0 63f
1b :3 0 366 641
368 640 63f :2 0
642 36a :2 0 644
0 644 643 5f1
642 :6 0 646 6
:3 0 36d 648 4f
:4 0 646 :4 0 6aa
91 :3 0 26 :4 0
64c :2 0 652 64a
0 8 :3 0 51
:3 0 64d 64e 0
5b :3 0 64f 650
0 652 378 6a5
5c :3 0 8 :3 0
51 :3 0 654 655
0 5b :3 0 656
657 0 659 37b
65b 37d 65a 659
:2 0 6a3 5d :3 0
8 :3 0 51 :3 0
65e 65f 0 5b
:3 0 660 661 0
69b 38 :3 0 39
:3 0 663 664 0
38 :3 0 49 :3 0
666 667 0 5e
:2 0 2 :4 0 92
:2 0 4b :2 0 15
:2 0 37f 66c 66e
:3 0 382 668 670
665 672 671 :2 0
3b :3 0 4c :3 0
674 675 0 3d
:4 0 93 :4 0 40
:2 0 41 :3 0 386
679 67b :3 0 40
:2 0 61 :4 0 389
67d 67f :3 0 40
:2 0 62 :4 0 38c
681 683 :3 0 40
:2 0 5b :3 0 38f
685 687 :3 0 40
:2 0 63 :4 0 392
689 68b :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 395 68e 692
399 68d 694 :3 0
39c 676 696 :2 0
698 39f 699 673
698 0 69a 3a1
0 69b 3a3 69e
:3 0 69e 0 69e
69d 69b 69c :6 0
6a0 1d :3 0 3a6
6a2 3a8 6a1 6a0
:2 0 6a3 3aa :2 0
6a5 0 6a5 6a4
652 6a3 :6 0 6aa
5 :3 0 94 :4 0
94 1 :8 0 6aa
95 :3 0 3ad 908
45 :3 0 18 :3 0
17 :2 0 3b2 6ab
6ae 56 :2 0 15
:2 0 3b7 6b0 6b2
:3 0 4e :3 0 2f
:4 0 6b7 :2 0 906
6b5 6b8 :3 0 4f
:3 0 2f :3 0 13
:3 0 14 :3 0 16
:3 0 12 :4 0 6c0
:2 0 8a3 6ba 6c1
:3 0 3ba :3 0 2f
:3 0 50 :3 0 6c2
6c3 :3 0 8 :3 0
51 :3 0 6c5 6c6
0 17 :2 0 6c7
6c8 0 6ca 3bf
6d1 8 :3 0 51
:3 0 6cb 6cc 0
52 :2 0 6cd 6ce
0 6d0 3c1 6d2
6c4 6ca 0 6d3
0 6d0 0 6d3
3c3 0 8a3 8
:3 0 51 :3 0 6d4
6d5 0 8 :3 0
53 :2 0 54 :3 0
6d7 6d9 0 3c8
6d8 6db :3 0 6dc
:2 0 55 :8 0 6e0
3cb 6e1 6dd 6e0
0 6e2 3cd 0
8a3 64 :3 0 14
:3 0 15 :2 0 15
:2 0 3cf 6e3 6e7
56 :2 0 17 :4 0
3d5 6e9 6eb :3 0
76 :3 0 c :3 0
77 :3 0 29 :3 0
13 :4 0 96 1
:8 0 6f8 8 :3 0
51 :3 0 6f3 6f4
0 5b :3 0 6f5
6f6 0 6f8 3d8
74b 5c :3 0 8
:3 0 51 :3 0 6fa
6fb 0 5b :3 0
6fc 6fd 0 6ff
3db 701 3dd 700
6ff :2 0 749 5d
:3 0 8 :3 0 51
:3 0 704 705 0
5b :3 0 706 707
0 741 38 :3 0
39 :3 0 709 70a
0 38 :3 0 49
:3 0 70c 70d 0
5e :2 0 2 :4 0
97 :2 0 4b :2 0
15 :2 0 3df 712
714 :3 0 3e2 70e
716 70b 718 717
:2 0 3b :3 0 4c
:3 0 71a 71b 0
3d :4 0 98 :4 0
40 :2 0 41 :3 0
3e6 71f 721 :3 0
40 :2 0 61 :4 0
3e9 723 725 :3 0
40 :2 0 62 :4 0
3ec 727 729 :3 0
40 :2 0 5b :3 0
3ef 72b 72d :3 0
40 :2 0 63 :4 0
3f2 72f 731 :3 0
40 :2 0 64 :3 0
65 :3 0 15 :2 0
66 :2 0 3f5 734
738 3f9 733 73a
:3 0 3fc 71c 73c
:2 0 73e 3ff 73f
719 73e 0 740
401 0 741 403
744 :3 0 744 0
744 743 741 742
:6 0 746 20 :3 0
406 748 408 747
746 :2 0 749 40a
:2 0 74b 0 74b
74a 6f8 749 :6 0
74d 1f :3 0 40d
7af 7b :3 0 c
:3 0 7c :3 0 7d
:3 0 13 :4 0 99
1 :8 0 759 8
:3 0 51 :3 0 754
755 0 5b :3 0
756 757 0 759
40f 7ac 5c :3 0
8 :3 0 51 :3 0
75b 75c 0 5b
:3 0 75d 75e 0
760 412 762 414
761 760 :2 0 7aa
5d :3 0 8 :3 0
51 :3 0 765 766
0 5b :3 0 767
768 0 7a2 38
:3 0 39 :3 0 76a
76b 0 38 :3 0
49 :3 0 76d 76e
0 5e :2 0 2
:4 0 9a :2 0 4b
:2 0 15 :2 0 416
773 775 :3 0 419
76f 777 76c 779
778 :2 0 3b :3 0
4c :3 0 77b 77c
0 3d :4 0 9b
:4 0 40 :2 0 41
:3 0 41d 780 782
:3 0 40 :2 0 61
:4 0 420 784 786
:3 0 40 :2 0 62
:4 0 423 788 78a
:3 0 40 :2 0 5b
:3 0 426 78c 78e
:3 0 40 :2 0 63
:4 0 429 790 792
:3 0 40 :2 0 64
:3 0 65 :3 0 15
:2 0 66 :2 0 42c
795 799 430 794
79b :3 0 433 77d
79d :2 0 79f 436
7a0 77a 79f 0
7a1 438 0 7a2
43a 7a5 :3 0 7a5
0 7a5 7a4 7a2
7a3 :6 0 7a7 22
:3 0 43d 7a9 43f
7a8 7a7 :2 0 7aa
441 :2 0 7ac 0
7ac 7ab 759 7aa
:6 0 7ae 1f :3 0
444 7b0 6ec 74d
0 7b1 0 7ae
0 7b1 446 0
8a3 1c :3 0 81
:3 0 9c :3 0 81
:3 0 c :3 0 81
:3 0 81 :3 0 c
:3 0 2c :3 0 e
:3 0 1b :3 0 e
:4 0 9d 1 :8 0
7d4 50 :4 0 7bf
:3 0 68 :3 0 56
:2 0 44b 7c2 7c3
:3 0 8 :3 0 51
:3 0 7c5 7c6 0
17 :2 0 7c7 7c8
0 7ca 44e 7d1
8 :3 0 51 :3 0
7cb 7cc 0 52
:2 0 7cd 7ce 0
7d0 450 7d2 7c4
7ca 0 7d3 0
7d0 0 7d3 452
0 7d4 455 827
5c :3 0 8 :3 0
51 :3 0 7d6 7d7
0 5b :3 0 7d8
7d9 0 7db 458
7dd 45a 7dc 7db
:2 0 825 5d :3 0
8 :3 0 51 :3 0
7e0 7e1 0 5b
:3 0 7e2 7e3 0
81d 38 :3 0 39
:3 0 7e5 7e6 0
38 :3 0 49 :3 0
7e8 7e9 0 5e
:2 0 2 :4 0 9e
:2 0 4b :2 0 15
:2 0 45c 7ee 7f0
:3 0 45f 7ea 7f2
7e7 7f4 7f3 :2 0
3b :3 0 4c :3 0
7f6 7f7 0 3d
:4 0 9f :4 0 40
:2 0 41 :3 0 463
7fb 7fd :3 0 40
:2 0 61 :4 0 466
7ff 801 :3 0 40
:2 0 62 :4 0 469
803 805 :3 0 40
:2 0 5b :3 0 46c
807 809 :3 0 40
:2 0 63 :4 0 46f
80b 80d :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 472 810 814
476 80f 816 :3 0
479 7f8 818 :2 0
81a 47c 81b 7f5
81a 0 81c 47e
0 81d 480 820
:3 0 820 0 820
81f 81d 81e :6 0
822 24 :3 0 483
824 485 823 822
:2 0 825 487 :2 0
827 0 827 826
7d4 825 :6 0 8a3
1f :3 0 34 :3 0
2c :3 0 29 :3 0
31 :3 0 32 :3 0
2a :3 0 a0 :3 0
a1 :3 0 e :3 0
13 :3 0 16 :3 0
12 :3 0 14 :3 0
1e :3 0 a2 :4 0
a3 1 :8 0 84e
50 :4 0 839 :3 0
68 :3 0 56 :2 0
48c 83c 83d :3 0
8 :3 0 51 :3 0
83f 840 0 17
:2 0 841 842 0
844 48f 84b 8
:3 0 51 :3 0 845
846 0 52 :2 0
847 848 0 84a
491 84c 83e 844
0 84d 0 84a
0 84d 493 0
84e 496 8a1 5c
:3 0 8 :3 0 51
:3 0 850 851 0
5b :3 0 852 853
0 855 499 857
49b 856 855 :2 0
89f 5d :3 0 8
:3 0 51 :3 0 85a
85b 0 5b :3 0
85c 85d 0 897
38 :3 0 39 :3 0
85f 860 0 38
:3 0 49 :3 0 862
863 0 5e :2 0
2 :4 0 a4 :2 0
4b :2 0 15 :2 0
49d 868 86a :3 0
4a0 864 86c 861
86e 86d :2 0 3b
:3 0 4c :3 0 870
871 0 3d :4 0
a5 :4 0 40 :2 0
41 :3 0 4a4 875
877 :3 0 40 :2 0
61 :4 0 4a7 879
87b :3 0 40 :2 0
62 :4 0 4aa 87d
87f :3 0 40 :2 0
5b :3 0 4ad 881
883 :3 0 40 :2 0
63 :4 0 4b0 885
887 :3 0 40 :2 0
64 :3 0 65 :3 0
15 :2 0 66 :2 0
4b3 88a 88e 4b7
889 890 :3 0 4ba
872 892 :2 0 894
4bd 895 86f 894
0 896 4bf 0
897 4c1 89a :3 0
89a 0 89a 899
897 898 :6 0 89c
26 :3 0 4c4 89e
4c6 89d 89c :2 0
89f 4c8 :2 0 8a1
0 8a1 8a0 84e
89f :6 0 8a3 1f
:3 0 4cb 8a5 4f
:4 0 8a3 :4 0 906
91 :3 0 2f :4 0
8a9 :2 0 8af 8a7
0 8 :3 0 51
:3 0 8aa 8ab 0
5b :3 0 8ac 8ad
0 8af 4d2 902
5c :3 0 8 :3 0
51 :3 0 8b1 8b2
0 5b :3 0 8b3
8b4 0 8b6 4d5
8b8 4d7 8b7 8b6
:2 0 900 5d :3 0
8 :3 0 51 :3 0
8bb 8bc 0 5b
:3 0 8bd 8be 0
8f8 38 :3 0 39
:3 0 8c0 8c1 0
38 :3 0 49 :3 0
8c3 8c4 0 5e
:2 0 2 :4 0 a6
:2 0 4b :2 0 15
:2 0 4d9 8c9 8cb
:3 0 4dc 8c5 8cd
8c2 8cf 8ce :2 0
3b :3 0 4c :3 0
8d1 8d2 0 3d
:4 0 a7 :4 0 40
:2 0 41 :3 0 4e0
8d6 8d8 :3 0 40
:2 0 61 :4 0 4e3
8da 8dc :3 0 40
:2 0 62 :4 0 4e6
8de 8e0 :3 0 40
:2 0 5b :3 0 4e9
8e2 8e4 :3 0 40
:2 0 63 :4 0 4ec
8e6 8e8 :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 4ef 8eb 8ef
4f3 8ea 8f1 :3 0
4f6 8d3 8f3 :2 0
8f5 4f9 8f6 8d0
8f5 0 8f7 4fb
0 8f8 4fd 8fb
:3 0 8fb 0 8fb
8fa 8f8 8f9 :6 0
8fd 28 :3 0 500
8ff 502 8fe 8fd
:2 0 900 504 :2 0
902 0 902 901
8af 900 :6 0 906
5 :3 0 94 :4 0
94 1 :8 0 906
507 907 6b3 906
0 909 142 6aa
0 909 50c 0
90a 50f 90c 4f
:4 0 90a :4 0 9b9
91 :3 0 1a :4 0
910 :2 0 916 90e
0 8 :3 0 51
:3 0 911 912 0
5b :3 0 913 914
0 916 514 969
5c :3 0 8 :3 0
51 :3 0 918 919
0 5b :3 0 91a
91b 0 91d 517
91f 519 91e 91d
:2 0 967 5d :3 0
8 :3 0 51 :3 0
922 923 0 5b
:3 0 924 925 0
95f 38 :3 0 39
:3 0 927 928 0
38 :3 0 49 :3 0
92a 92b 0 5e
:2 0 2 :4 0 a8
:2 0 4b :2 0 15
:2 0 51b 930 932
:3 0 51e 92c 934
929 936 935 :2 0
3b :3 0 4c :3 0
938 939 0 3d
:4 0 a9 :4 0 40
:2 0 41 :3 0 522
93d 93f :3 0 40
:2 0 61 :4 0 525
941 943 :3 0 40
:2 0 62 :4 0 528
945 947 :3 0 40
:2 0 5b :3 0 52b
949 94b :3 0 40
:2 0 63 :4 0 52e
94d 94f :3 0 40
:2 0 64 :3 0 65
:3 0 15 :2 0 66
:2 0 531 952 956
535 951 958 :3 0
538 93a 95a :2 0
95c 53b 95d 937
95c 0 95e 53d
0 95f 53f 962
:3 0 962 0 962
961 95f 960 :6 0
964 2a :3 0 542
966 544 965 964
:2 0 967 546 :2 0
969 0 969 968
916 967 :6 0 9b9
1 :3 0 38 :3 0
39 :3 0 96b 96c
0 38 :3 0 49
:3 0 96e 96f 0
aa :2 0 2 :4 0
ab :2 0 4b :2 0
15 :2 0 549 974
976 :3 0 54c 970
978 96d 97a 979
:2 0 3b :3 0 4c
:3 0 97c 97d 0
3d :4 0 ac :4 0
40 :2 0 41 :3 0
550 981 983 :3 0
40 :2 0 61 :4 0
553 985 987 :3 0
40 :2 0 ad :4 0
556 989 98b :3 0
40 :2 0 45 :3 0
46 :3 0 8 :3 0
51 :3 0 990 991
0 559 98f 993
47 :4 0 55b 98e
996 55e 98d 998
:3 0 40 :2 0 ae
:4 0 561 99a 99c
:3 0 40 :2 0 43
:4 0 564 99e 9a0
:3 0 40 :2 0 a
:3 0 567 9a2 9a4
:3 0 40 :2 0 43
:4 0 56a 9a6 9a8
:3 0 56d 97e 9aa
:2 0 9ac 570 9ad
97b 9ac 0 9ae
572 0 9b9 af
:3 0 b0 :3 0 9af
9b0 0 8 :3 0
51 :3 0 9b2 9b3
0 a :3 0 68
:3 0 574 9b1 9b7
:2 0 9b9 578 a5a
8 :3 0 b1 :2 0
4 9ba 9bb 0
38 :3 0 39 :3 0
9bd 9be 0 38
:3 0 49 :3 0 9c0
9c1 0 5e :2 0
2 :4 0 b2 :2 0
4b :2 0 15 :2 0
582 9c6 9c8 :3 0
585 9c2 9ca 9bf
9cc 9cb :2 0 3b
:3 0 4c :3 0 9ce
9cf 0 3d :4 0
b3 :4 0 40 :2 0
41 :3 0 589 9d3
9d5 :3 0 58c 9d0
9d7 :2 0 9f0 3b
:3 0 4c :3 0 9d9
9da 0 3d :4 0
b4 :4 0 40 :2 0
8 :3 0 b5 :3 0
9df 9e0 0 58f
9de 9e2 :3 0 40
:2 0 ae :4 0 592
9e4 9e6 :3 0 40
:2 0 8 :3 0 b6
:3 0 9e9 9ea 0
595 9e8 9ec :3 0
598 9db 9ee :2 0
9f0 59b 9f1 9cd
9f0 0 9f2 59e
0 a02 4e :3 0
37 :3 0 8 :3 0
b5 :3 0 b7 :3 0
8 :3 0 b6 :3 0
b8 :3 0 58 :4 0
b9 1 :a 0 9fe
:2 0 a02 9f4 9fc
:2 0 7 :3 0 37
:3 0 a00 :2 0 a02
5a0 a04 5a4 a03
a02 :2 0 a58 5d
:3 0 8 :3 0 51
:3 0 a07 a08 0
5b :3 0 a09 a0a
0 a50 38 :3 0
39 :3 0 a0c a0d
0 38 :3 0 49
:3 0 a0f a10 0
5e :2 0 2 :4 0
ba :2 0 4b :2 0
15 :2 0 5a6 a15
a17 :3 0 5a9 a11
a19 a0e a1b a1a
:2 0 3b :3 0 4c
:3 0 a1d a1e 0
3d :4 0 bb :4 0
40 :2 0 41 :3 0
5ad a22 a24 :3 0
5b0 a1f a26 :2 0
a40 3b :3 0 4c
:3 0 a28 a29 0
3d :4 0 62 :4 0
40 :2 0 5b :3 0
5b3 a2d a2f :3 0
40 :2 0 63 :4 0
5b6 a31 a33 :3 0
40 :2 0 64 :3 0
65 :3 0 15 :2 0
66 :2 0 5b9 a36
a3a 5bd a35 a3c
:3 0 5c0 a2a a3e
:2 0 a40 5c3 a41
a1c a40 0 a42
5c6 0 a50 4e
:3 0 37 :3 0 b7
:3 0 8 :3 0 b6
:3 0 b8 :3 0 58
:4 0 bc 1 :a 0
a4c :2 0 a50 a44
a4a :2 0 7 :3 0
37 :3 0 a4e :2 0
a50 5c8 a53 :3 0
a53 0 a53 a52
a50 a51 :6 0 a55
1 :3 0 5cd a57
5cf a56 a55 :2 0
a58 5d1 :2 0 a5a
5d4 a5a a59 9b9
a58 :6 0 a5b :2 0
2 10 a5a a5e
:3 0 a5d a5b a5f
:8 0 
5e3
4
:3 0 1 3 1
7 2 6 a
1 14 1 12
1 1b 1 19
1 22 1 20
1 29 1 27
1 30 1 2e
1 37 1 35
1 3e 1 3c
1 45 1 43
1 4a 1 50
1 6a 1 7e
1 9e 1 a4
1 b1 1 bd
2 c0 c2 2
c5 c7 2 c9
cb 2 cd cf
2 d1 d3 1
d9 2 db dc
2 d5 de 2
e0 e2 4 b9
bf c4 e4 1
e6 1 e8 2
f2 f4 3 f0
f1 f6 2 ff
101 2 fe 103
1 105 1 107
1 120 1 126
2 128 129 1
131 2 12d 131
1 136 1 138
2 13b 13c 1
140 2 13e 140
4 14a 14b 14c
14d 1 158 1
15e 2 160 161
1 169 2 165
169 1 16e 1
170 2 17d 182
1 189 1 184
2 19c 19e 3
19a 19b 1a0 2
1a9 1ab 2 1ad
1af 2 1b1 1b3
2 1b5 1b7 2
1b9 1bb 3 1c0
1c1 1c2 2 1bd
1c4 2 1a8 1c6
1 1c8 1 1ca
2 193 1cb 1
1cf 1 18e 2
18c 1d3 2 1d9
1da 1 1de 2
1dc 1de 1 1e8
2 1e7 1e8 1
1f0 1 1f6 2
1f8 1f9 2 1e5
1fa 1 201 1
1fc 2 214 216
3 212 213 218
2 221 223 2
225 227 2 229
22b 2 22d 22f
2 231 233 3
238 239 23a 2
235 23c 2 220
23e 1 240 1
242 2 20b 243
1 247 1 206
2 204 24b 1
25a 2 259 25a
1 262 1 268
2 26a 26b 2
257 26c 1 273
1 26e 2 286
288 3 284 285
28a 2 293 295
2 297 299 2
29b 29d 2 29f
2a1 2 2a3 2a5
3 2aa 2ab 2ac
2 2a7 2ae 2
292 2b0 1 2b2
1 2b4 2 27d
2b5 1 2b9 1
278 2 276 2bd
2 24e 2c0 1
2c3 1 2cc 2
2cb 2cc 1 2d4
1 2da 2 2dc
2dd 2 2c9 2de
1 2e5 1 2e0
2 2f8 2fa 3
2f6 2f7 2fc 2
305 307 2 309
30b 2 30d 30f
2 311 313 2
315 317 3 31c
31d 31e 2 319
320 2 304 322
1 324 1 326
2 2ef 327 1
32b 1 2ea 2
2e8 32f 1 33a
2 336 33a 1
346 2 345 346
1 34e 1 354
2 356 357 2
343 358 1 35f
1 35a 2 372
374 3 370 371
376 2 37f 381
2 383 385 2
387 389 2 38b
38d 2 38f 391
3 396 397 398
2 393 39a 2
37e 39c 1 39e
1 3a0 2 369
3a1 1 3a5 1
364 2 362 3a9
3 3af 3b0 3b1
1 3b5 2 3b3
3b5 2 3bd 3c2
1 3c9 1 3c4
2 3dc 3de 3
3da 3db 3e0 2
3e9 3eb 2 3ed
3ef 2 3f1 3f3
2 3f5 3f7 2
3f9 3fb 3 400
401 402 2 3fd
404 2 3e8 406
1 408 1 40a
2 3d3 40b 1
40f 1 3ce 2
3cc 413 1 416
2 41e 423 1
42a 1 425 2
43d 43f 3 43b
43c 441 2 44a
44c 2 44e 450
2 452 454 2
456 458 2 45a
45c 3 461 462
463 2 45e 465
2 449 467 1
469 1 46b 2
434 46c 1 470
1 42f 2 42d
474 1 477 2
47a 47b 1 489
2 488 489 1
491 1 497 2
499 49a 2 486
49b 1 4a2 1
49d 2 4b5 4b7
3 4b3 4b4 4b9
2 4c2 4c4 2
4c6 4c8 2 4ca
4cc 2 4ce 4d0
2 4d2 4d4 3
4d9 4da 4db 2
4d6 4dd 2 4c1
4df 1 4e1 1
4e3 2 4ac 4e4
1 4e8 1 4a7
2 4a5 4ec 3
3ac 47c 4ef 1
4fc 2 4fb 4fc
1 504 1 50a
2 50c 50d 2
4f9 50e 1 515
1 510 2 528
52a 3 526 527
52c 2 535 537
2 539 53b 2
53d 53f 2 541
543 2 545 547
3 54c 54d 54e
2 549 550 2
534 552 1 554
1 556 2 51f
557 1 55b 1
51a 2 518 55f
1 562 2 565
566 1 56e 2
56d 56e 1 576
1 57c 2 57e
57f 2 56b 580
1 587 1 582
2 59a 59c 3
598 599 59e 2
5a7 5a9 2 5ab
5ad 2 5af 5b1
2 5b3 5b5 2
5b7 5b9 3 5be
5bf 5c0 2 5bb
5c2 2 5a6 5c4
1 5c6 1 5c8
2 591 5c9 1
5cd 1 58c 2
58a 5d1 1 5de
2 5dd 5de 1
5e6 1 5ec 2
5ee 5ef 2 5db
5f0 1 5f7 1
5f2 2 60a 60c
3 608 609 60e
2 617 619 2
61b 61d 2 61f
621 2 623 625
2 627 629 3
62e 62f 630 2
62b 632 2 616
634 1 636 1
638 2 601 639
1 63d 1 5fc
2 5fa 641 a
14e 162 171 174
1d6 2c4 332 567
5d4 644 2 64b
651 1 658 1
653 2 66b 66d
3 669 66a 66f
2 678 67a 2
67c 67e 2 680
682 2 684 686
2 688 68a 3
68f 690 691 2
68c 693 2 677
695 1 697 1
699 2 662 69a
1 69e 1 65d
2 65b 6a2 4
145 648 6a5 6a8
2 6ac 6ad 1
6b1 2 6af 6b1
4 6bb 6bc 6bd
6be 1 6c9 1
6cf 2 6d1 6d2
1 6da 2 6d6
6da 1 6df 1
6e1 3 6e4 6e5
6e6 1 6ea 2
6e8 6ea 2 6f2
6f7 1 6fe 1
6f9 2 711 713
3 70f 710 715
2 71e 720 2
722 724 2 726
728 2 72a 72c
2 72e 730 3
735 736 737 2
732 739 2 71d
73b 1 73d 1
73f 2 708 740
1 744 1 703
2 701 748 1
74b 2 753 758
1 75f 1 75a
2 772 774 3
770 771 776 2
77f 781 2 783
785 2 787 789
2 78b 78d 2
78f 791 3 796
797 798 2 793
79a 2 77e 79c
1 79e 1 7a0
2 769 7a1 1
7a5 1 764 2
762 7a9 1 7ac
2 7af 7b0 1
7c1 2 7c0 7c1
1 7c9 1 7cf
2 7d1 7d2 2
7be 7d3 1 7da
1 7d5 2 7ed
7ef 3 7eb 7ec
7f1 2 7fa 7fc
2 7fe 800 2
802 804 2 806
808 2 80a 80c
3 811 812 813
2 80e 815 2
7f9 817 1 819
1 81b 2 7e4
81c 1 820 1
7df 2 7dd 824
1 83b 2 83a
83b 1 843 1
849 2 84b 84c
2 838 84d 1
854 1 84f 2
867 869 3 865
866 86b 2 874
876 2 878 87a
2 87c 87e 2
880 882 2 884
886 3 88b 88c
88d 2 888 88f
2 873 891 1
893 1 895 2
85e 896 1 89a
1 859 2 857
89e 6 6bf 6d3
6e2 7b1 827 8a1
2 8a8 8ae 1
8b5 1 8b0 2
8c8 8ca 3 8c6
8c7 8cc 2 8d5
8d7 2 8d9 8db
2 8dd 8df 2
8e1 8e3 2 8e5
8e7 3 8ec 8ed
8ee 2 8e9 8f0
2 8d4 8f2 1
8f4 1 8f6 2
8bf 8f7 1 8fb
1 8ba 2 8b8
8ff 4 6b6 8a5
902 905 2 908
907 4 117 12a
139 909 2 90f
915 1 91c 1
917 2 92f 931
3 92d 92e 933
2 93c 93e 2
940 942 2 944
946 2 948 94a
2 94c 94e 3
953 954 955 2
950 957 2 93b
959 1 95b 1
95d 2 926 95e
1 962 1 921
2 91f 966 2
973 975 3 971
972 977 2 980
982 2 984 986
2 988 98a 1
992 2 994 995
2 98c 997 2
999 99b 2 99d
99f 2 9a1 9a3
2 9a5 9a7 2
97f 9a9 1 9ab
1 9ad 3 9b4
9b5 9b6 9 e9
108 10b 10e 111
90c 969 9ae 9b8
2 9c5 9c7 3
9c3 9c4 9c9 2
9d2 9d4 2 9d1
9d6 2 9dd 9e1
2 9e3 9e5 2
9e7 9eb 2 9dc
9ed 2 9d8 9ef
1 9f1 3 9f2
9fd a01 1 9bc
2 a14 a16 3
a12 a13 a18 2
a21 a23 2 a20
a25 2 a2c a2e
2 a30 a32 3
a37 a38 a39 2
a34 a3b 2 a2b
a3d 2 a27 a3f
1 a41 4 a0b
a42 a4b a4f 1
a53 1 a06 2
a04 a57 e 17
1e 25 2c 33
3a 41 48 4e
54 6b 7f 9f
a9 
1
4
0 
a5e
0
1
50
2c
11
0 1 1 1 1 5 6 7
6 9 6 b 6 d 6 f
6 11 6 13 6 15 6 17
6 19 6 1b 5 1d 5 1f
20 1f 22 1f 24 1f 26 5
28 1 2a 1 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0
0 0 0 0 0 0 0 0

3 1 0
57 1 2
2e 1 0
71 1 3
85 1 4
43 1 0
4a 1 0
35 1 0
50 1 0
27 1 0
12 1 0
3c 1 0
20 1 0
2 0 1
7 1 0
19 1 0
a4 1 0
0

/
SHOW ERRORS FUNCTION SP_TEST_ASSIGN;
ALTER FUNCTION SP_TEST_ASSIGN COMPILE DEBUG;
/*********************************************************************************************************************************************/
Prompt == FUNCTION FC_MIGRATION ==
CREATE OR REPLACE FUNCTION FC_MIGRATION wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
83
2 :e:
1FUNCTION:
1FC_MIGRATION:
1H_PROJECT_ID:
1OUT:
1NOCOPY:
1VARCHAR2:
1RETURN:
1PLS_INTEGER:
1H_LEVEL:
10:
1H_ROLLUP_BITS:
1H_TEMP_SC_STATE:
1CURSOR:
1C01:
1PROJECT_ID:
1LEVEL_ID:
1TMT_WBS:
1TYPE_ID:
1PMO_CNST:
1SC_PROJECT:
1SC_PROPOSAL:
1SC_PROJ_TYPE1:
1SC_PROJ_TYPE2:
1SC_PROJ_TYPE3:
1RANK:
1SELECT PROJECT_ID, LEVEL_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (pmo_cnst+
1.SC_PROJECT,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PROJ_TYPE+
12,pmo_cnst.SC_PROJ_TYPE3):n         ORDER BY RANK DESC:
1C02:
1C03:
1ELEMENT_ID:
1SELECT LEVEL_ID FROM TMT_WBS:n         WHERE TYPE_ID IN (pmo_cnst.SC_PROJECT,+
1pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cnst.SC_PROJ_TYPE2,pmo_cnst.S+
1C_PROJ_TYPE3) AND ELEMENT_ID = h_project_id:n         ORDER BY RANK DESC:
1C04:
1SELECT /*PROJECT_ID,*/ LEVEL_ID:n         FROM TMT_WBS:n         WHERE TYPE_I+
1D IN (pmo_cnst.SC_PROJECT,pmo_cnst.SC_PROPOSAL,pmo_cnst.SC_PROJ_TYPE1,pmo_cns+
1t.SC_PROJ_TYPE2,pmo_cnst.SC_PROJ_TYPE3) AND ELEMENT_ID = h_project_id:n      +
1   ORDER BY RANK DESC:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= FC_MIGRATION(:
1':
1);:
1CHECK_TRACE:
11:
137:
1+:
1FPUT:
1               ENTER:: FC_MIGRATION(38) :: cplan.sql(24709) :: :
1IS NULL:
1OPEN:
1LOOP:
1FOUND:
1PMO_DB2M:
1SC_STATE:
1100:
1!=:
1SC_SQL_SUCCESS:
1EXIT:
13269638:
1TASK_ASSIGNMENTS:
1ROLLUP_BITS:
1ACTUAL_START:
1SC_SET_ALL_BITS:
1UPDATE TASK_ASSIGNMENTS SET ROLLUP_BITS = CASE WHEN ACTUAL_START IS NuLL THEN+
1 pmo_cnst.SC_SET_ALL_BITS ELSE h_rollup_bits END:n            WHERE PROJECT_I+
1D = h_project_id:
1TRUE:
1=:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
174:
1           EXCEPTION:: FC_MIGRATION(75) :: cplan.sql(24746) :: :
1 :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1PMO_FUNC:
1BIT_OR:
1SC_PLANNED_BIT:
1SC_SCHED_BIT:
1PLANNED_FINISH:
1SCHED_FINISH:
1ACTUAL_FINISH:
1FORECAST_FINISH:
1FORECAST_START:
1PLANNED_EFFORT:
1SCHED_EFFORT:
1UPDATE TMT_WBS SET ROLLUP_BITS = pmo_cnst.SC_SET_ALL_BITS, PLANNED_FINISH = N+
1uLL, SCHED_FINISH = NuLL,:n            ACTUAL_FINISH = NuLL,:n            FOR+
1ECAST_FINISH = CASE WHEN FORECAST_START IS NuLL THEN FORECAST_FINISH ELSE NuL+
1L END:n            WHERE PROJECT_ID = h_project_id AND (PLANNED_EFFORT + SCHE+
1D_EFFORT > 0):
198:
1           EXCEPTION:: FC_MIGRATION(99) :: cplan.sql(24770) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = h_rollup_bits, PLANNED_FINISH = NuLL, SCHED_+
1FINISH = NuLL:n            WHERE PROJECT_ID = h_project_id AND ((PLANNED_EFFO+
1RT + SCHED_EFFORT) = 0):
1118:
1           EXCEPTION:: FC_MIGRATION(119) :: cplan.sql(24790) :: :
1TMT_CRI:
1UPDATE TMT_CRI SET ROLLUP_BITS = pmo_cnst.SC_SET_ALL_BITS, PLANNED_FINISH = N+
1uLL, SCHED_FINISH = NuLL:n            WHERE PROJECT_ID = h_project_id AND TYP+
1E_ID <> 14:
1138:
1           EXCEPTION:: FC_MIGRATION(139) :: cplan.sql(24810) :: :
1COALESCE:
1FC_ROLLUP:
1COMMIT:
1CLOSE:
1160:
1           EXCEPTION:: FC_MIGRATION(161) :: cplan.sql(24832) :: :
1UPDATE TMT_WBS SET ROLLUP_BITS = pmo_cnst.SC_SET_ALL_BITS, ACTUAL_FINISH = Nu+
1LL,:n            FORECAST_FINISH = CASE WHEN FORECAST_START IS NuLL THEN FORE+
1CAST_FINISH ELSE NuLL END:n            WHERE PROJECT_ID = h_project_id AND ((+
1PLANNED_EFFORT + SCHED_EFFORT) = 0):
1197:
1           EXCEPTION:: FC_MIGRATION(198) :: cplan.sql(24869) :: :
1219:
1           EXCEPTION:: FC_MIGRATION(220) :: cplan.sql(24891) :: :
1UPDATE TASK_ASSIGNMENTS SET ROLLUP_BITS = pmo_cnst.SC_SET_ALL_BITS WHERE PROJ+
1ECT_ID = h_project_id:
1256:
1           EXCEPTION:: FC_MIGRATION(257) :: cplan.sql(24928) :: :
1278:
1           EXCEPTION:: FC_MIGRATION(279) :: cplan.sql(24950) :: :
1298:
1           EXCEPTION:: FC_MIGRATION(299) :: cplan.sql(24970) :: :
1318:
1           EXCEPTION:: FC_MIGRATION(319) :: cplan.sql(24990) :: :
1340:
1           EXCEPTION:: FC_MIGRATION(341) :: cplan.sql(25012) :: :
1377:
1           EXCEPTION:: FC_MIGRATION(378) :: cplan.sql(25049) :: :
1399:
1           EXCEPTION:: FC_MIGRATION(400) :: cplan.sql(25071) :: :
1406:
1                EXIT:: FC_MIGRATION(407) :: cplan.sql(25078) :: :
1STATE:: :
0

0
0
853
2
0 a0 8d 90 :3 a0 b0 3f b4
:2 a0 2c 6a a3 a0 1c 51 81
b0 a3 a0 1c 51 81 b0 a3
a0 1c 51 81 b0 a0 f4 b4
bf c8 :f a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :f a0 12a
bd b7 11 a4 b1 a0 f4 b4
bf c8 :10 a0 12a bd b7 11 a4
b1 a0 f4 b4 bf c8 :10 a0 12a
bd b7 11 a4 b1 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
5a :2 a0 e9 dd b3 :4 a0 e9 d3
5 :2 a0 f :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c :2 a0
6b a0 7e a0 6b b4 2e 5a
a0 2b b7 19 3c a0 51 d
:8 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:3 a0 6b :2 a0 6b :2 a0 6b a5 b
d :e a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :9 a0 12a a0 f a0 7e b4
2e :2 a0 6b 51 d b7 :2 a0 6b
51 d b7 :2 19 3c b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :3 a0 a5 b d a0 12a b7
19 3c b7 a0 47 :2 a0 e9 c1
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 e9 dd b3 :4 a0 e9 d3 5
:2 a0 f :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c :2 a0 6b
a0 7e a0 6b b4 2e 5a a0
2b b7 19 3c :c a0 12a a0 f
a0 7e b4 2e :2 a0 6b 51 d
b7 :2 a0 6b 51 d b7 :2 19 3c
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 51 a5 b
7e 51 b4 2e :3 a0 a5 b d
a0 12a b7 19 3c b7 a0 47
:2 a0 e9 c1 :2 a0 6b a0 d b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f b7 :2 a0 e9 dd b3
:3 a0 e9 d3 :2 a0 f :2 a0 6b 51
d b7 :2 a0 6b 51 d b7 :2 19
3c :2 a0 6b a0 7e a0 6b b4
2e 5a a0 2b b7 19 3c :3 a0
6b :2 a0 6b :2 a0 6b a5 b d
:6 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:e a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:9 a0 12a a0 f a0 7e b4 2e
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:3 a0 a5 b d a0 12a b7 19
3c b7 a0 47 :2 a0 e9 c1 :2 a0
6b a0 d b7 :3 a0 6b a0 d
b7 a6 9 a0 53 :2 a0 6b a0
d :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
a0 b4 2e 7e 6e b4 2e 7e
:2 a0 :2 51 a5 b b4 2e a5 57
b7 19 3c b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 4f :2 a0
e9 dd b3 :3 a0 e9 d3 :2 a0 f
:2 a0 6b 51 d b7 :2 a0 6b 51
d b7 :2 19 3c :2 a0 6b a0 7e
a0 6b b4 2e 5a a0 2b b7
19 3c :c a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 51 a5 b 7e 51
b4 2e :3 a0 a5 b d a0 12a
b7 19 3c b7 a0 47 :2 a0 e9
c1 :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f b7 :2 19 3c :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :2 a0 6b b4 2e a5
57 b7 19 3c :3 a0 6b 65 b7
a4 b1 11 68 4f 1d 17 b5 
853
2
0 3 7 2b 1f 23 27 1e
32 1b 37 3b 3f 43 5f 4b
4f 57 5a 4a 7b 6a 6e 47
76 69 97 86 8a 66 92 85
9e a2 82 b3 b6 ba be c2
c6 ca ce d2 d6 da de e2
e6 ea ee f2 f6 102 107 109
115 119 11b 11f 130 131 134 138
13c 140 144 148 14c 150 154 158
15c 160 164 168 16c 170 174 180
185 187 193 197 199 19d 1ae 1af
1b2 1b6 1ba 1be 1c2 1c6 1ca 1ce
1d2 1d6 1da 1de 1e2 1e6 1ea 1ee
1f2 1f6 202 207 209 215 219 21b
21f 230 231 234 238 23c 240 244
248 24c 250 254 258 25c 260 264
268 26c 270 274 278 284 289 28b
297 29b 29d 2a1 2a5 2a8 2ac 2b0
2b3 2b8 2b9 1 2bb 2c0 2c4 2c8
2cb 2d0 2d4 2d8 2db 2e0 2e1 2e3
2e8 2eb 2ef 2f0 2f5 2fa 2fd 302
303 308 30b 30f 310 315 318 31d
31e 323 326 32b 32c 331 332 337
339 33d 340 344 348 34b 34f 353
356 359 35e 361 364 367 368 36d
36e 1 370 375 379 37d 380 385
38a 38d 391 392 397 398 39d 39f
3a3 3a6 3aa 3ad 3ae 3b3 3b6 3ba
3be 3c3 3c7 3c8 3cc 3d0 3d4 3d8
3dd 3e2 3e6 3ea 3ee 3f3 3f7 3fb
3fe 401 405 407 40b 40f 412 415
419 41b 41f 423 426 42a 42e 431
435 438 43c 43f 440 445 448 44c
452 454 458 45b 45f 462 466 46a
46e 472 476 47a 47e 482 486 492
496 49b 49f 4a2 4a3 4a8 4ac 4b0
4b3 4b6 4ba 4bc 4c0 4c4 4c7 4ca
4ce 4d0 4d4 4d8 4db 4dd 4e1 4e5
4e9 4ec 4f0 4f4 4f6 4f7 4fc 1
500 504 508 50b 50f 513 517 51b
51e 522 526 529 52c 531 534 537
53a 53b 540 541 1 543 548 54c
550 553 558 55d 560 564 565 56a
56d 572 573 578 57b 580 581 586
589 58d 58e 593 596 59b 59c 5a1
5a4 5a8 5ac 5af 5b2 5b3 5b5 5b6
5bb 5bc 5c1 5c3 5c7 5ca 5cc 5d0
5d2 5de 5e0 5e2 5e3 5e8 5ec 5ee
5fa 5fc 600 604 608 60b 60f 613
616 61a 61e 621 622 624 628 62c
630 634 638 63c 640 644 648 64c
650 654 658 65c 660 66c 670 675
679 67c 67d 682 686 68a 68d 690
694 696 69a 69e 6a1 6a4 6a8 6aa
6ae 6b2 6b5 6b7 6bb 6bf 6c3 6c6
6ca 6ce 6d0 6d1 6d6 1 6da 6de
6e2 6e5 6e9 6ed 6f1 6f5 6f8 6fc
700 703 706 70b 70e 711 714 715
71a 71b 1 71d 722 726 72a 72d
732 737 73a 73e 73f 744 747 74c
74d 752 755 75a 75b 760 763 767
768 76d 770 775 776 77b 77e 782
786 789 78c 78d 78f 790 795 796
79b 79d 7a1 7a4 7a6 7aa 7ac 7b8
7ba 7bc 7bd 7c2 7c6 7c8 7d4 7d6
7da 7de 7e2 7e6 7ea 7ee 7f2 7f6
7fa 806 80a 80f 813 816 817 81c
820 824 827 82a 82e 830 834 838
83b 83e 842 844 848 84c 84f 851
855 859 85d 860 864 868 86a 86b
870 1 874 878 87c 87f 883 887
88b 88f 892 896 89a 89d 8a0 8a5
8a8 8ab 8ae 8af 8b4 8b5 1 8b7
8bc 8c0 8c4 8c7 8cc 8d1 8d4 8d8
8d9 8de 8e1 8e6 8e7 8ec 8ef 8f4
8f5 8fa 8fd 901 902 907 90a 90f
910 915 918 91c 920 923 926 927
929 92a 92f 930 935 937 93b 93e
940 944 946 952 954 956 957 95c
960 962 96e 970 974 978 97c 980
984 988 98c 990 994 9a0 9a4 9a9
9ad 9b0 9b1 9b6 9ba 9be 9c1 9c4
9c8 9ca 9ce 9d2 9d5 9d8 9dc 9de
9e2 9e6 9e9 9eb 9ef 9f3 9f7 9fa
9fe a02 a04 a05 a0a 1 a0e a12
a16 a19 a1d a21 a25 a29 a2c a30
a34 a37 a3a a3f a42 a45 a48 a49
a4e a4f 1 a51 a56 a5a a5e a61
a66 a6b a6e a72 a73 a78 a7b a80
a81 a86 a89 a8e a8f a94 a97 a9b
a9c aa1 aa4 aa9 aaa aaf ab2 ab6
aba abd ac0 ac1 ac3 ac4 ac9 aca
acf ad1 ad5 ad8 ada ade ae0 aec
aee af0 af1 af6 afa afc b08 b0a
b0e b12 b15 b16 b18 b1b b1e b1f
b24 b28 b2c b30 b31 b33 b37 b3b
b47 b49 b4d b50 b52 b56 b5d b61
b65 b6a b6c b70 b74 b77 b7b b7f
b81 b85 b89 b8d b90 b94 b98 b9a
b9b ba0 1 ba4 ba8 bac baf bb3
bb7 bbb bbf bc2 bc6 bca bcd bd0
bd5 bd8 bdb bde bdf be4 be5 1
be7 bec bf0 bf4 bf7 bfc c01 c04
c08 c09 c0e c11 c16 c17 c1c c1f
c24 c25 c2a c2d c31 c32 c37 c3a
c3f c40 c45 c48 c4c c50 c53 c56
c57 c59 c5a c5f c60 c65 c67 c6b
c6e c70 c74 c76 c82 c84 c86 c87
c8c c90 c92 c9e ca0 ca4 ca8 cad
cb1 cb2 cb6 cba cbe cc2 cc7 ccc
cd0 cd4 cd8 cdd ce1 ce5 ce8 ceb
cef cf1 cf5 cf9 cfc cff d03 d05
d09 d0d d10 d14 d18 d1b d1f d22
d26 d29 d2a d2f d32 d36 d3c d3e
d42 d45 d49 d4d d51 d55 d59 d5d
d61 d65 d69 d6d d71 d75 d81 d85
d8a d8e d91 d92 d97 d9b d9f da2
da5 da9 dab daf db3 db6 db9 dbd
dbf dc3 dc7 dca dcc dd0 dd4 dd8
ddb ddf de3 de5 de6 deb 1 def
df3 df7 dfa dfe e02 e06 e0a e0d
e11 e15 e18 e1b e20 e23 e26 e29
e2a e2f e30 1 e32 e37 e3b e3f
e42 e47 e4c e4f e53 e54 e59 e5c
e61 e62 e67 e6a e6f e70 e75 e78
e7c e7d e82 e85 e8a e8b e90 e93
e97 e9b e9e ea1 ea2 ea4 ea5 eaa
eab eb0 eb2 eb6 eb9 ebb ebf ec1
ecd ecf ed1 ed2 ed7 edb edd ee9
eeb eef ef3 ef6 ef7 ef9 efc eff
f00 f05 f09 f0d f11 f12 f14 f18
f1c f28 f2a f2e f31 f33 f37 f3e
f42 f46 f4b f4d f51 f55 f58 f5c
f60 f62 f66 f6a f6e f71 f75 f79
f7b f7c f81 1 f85 f89 f8d f90
f94 f98 f9c fa0 fa3 fa7 fab fae
fb1 fb6 fb9 fbc fbf fc0 fc5 fc6
1 fc8 fcd fd1 fd5 fd8 fdd fe2
fe5 fe9 fea fef ff2 ff7 ff8 ffd
1000 1005 1006 100b 100e 1012 1013 1018
101b 1020 1021 1026 1029 102d 1031 1034
1037 1038 103a 103b 1040 1041 1046 1048
104c 104f 1051 1055 1057 1063 1065 1067
1068 106d 1071 1073 107f 1081 1083 1087
108b 1090 1094 1095 1099 109d 10a1 10a6
10ab 10af 10b3 10b8 10bc 10c0 10c3 10c6
10ca 10cc 10d0 10d4 10d7 10da 10de 10e0
10e4 10e8 10eb 10ef 10f3 10f6 10fa 10fd
1101 1104 1105 110a 110d 1111 1117 1119
111d 1120 1124 1128 112c 112f 1133 1137
113a 113e 1142 1145 1146 1148 114c 1150
1154 1158 115c 1160 1164 1170 1174 1179
117d 1180 1181 1186 118a 118e 1191 1194
1198 119a 119e 11a2 11a5 11a8 11ac 11ae
11b2 11b6 11b9 11bb 11bf 11c3 11c7 11ca
11ce 11d2 11d4 11d5 11da 1 11de 11e2
11e6 11e9 11ed 11f1 11f5 11f9 11fc 1200
1204 1207 120a 120f 1212 1215 1218 1219
121e 121f 1 1221 1226 122a 122e 1231
1236 123b 123e 1242 1243 1248 124b 1250
1251 1256 1259 125e 125f 1264 1267 126b
126c 1271 1274 1279 127a 127f 1282 1286
128a 128d 1290 1291 1293 1294 1299 129a
129f 12a1 12a5 12a8 12aa 12ae 12b0 12bc
12be 12c0 12c1 12c6 12ca 12cc 12d8 12da
12de 12e2 12e6 12ea 12ee 12f2 12f6 12fa
12fe 1302 1306 130a 130e 1312 131e 1322
1327 132b 132e 132f 1334 1338 133c 133f
1342 1346 1348 134c 1350 1353 1356 135a
135c 1360 1364 1367 1369 136d 1371 1375
1378 137c 1380 1382 1383 1388 1 138c
1390 1394 1397 139b 139f 13a3 13a7 13aa
13ae 13b2 13b5 13b8 13bd 13c0 13c3 13c6
13c7 13cc 13cd 1 13cf 13d4 13d8 13dc
13df 13e4 13e9 13ec 13f0 13f1 13f6 13f9
13fe 13ff 1404 1407 140c 140d 1412 1415
1419 141a 141f 1422 1427 1428 142d 1430
1434 1438 143b 143e 143f 1441 1442 1447
1448 144d 144f 1453 1456 1458 145c 145e
146a 146c 146e 146f 1474 1478 147a 1486
1488 148c 1490 1494 1498 149c 14a0 14a4
14a8 14ac 14b8 14bc 14c1 14c5 14c8 14c9
14ce 14d2 14d6 14d9 14dc 14e0 14e2 14e6
14ea 14ed 14f0 14f4 14f6 14fa 14fe 1501
1503 1507 150b 150f 1512 1516 151a 151c
151d 1522 1 1526 152a 152e 1531 1535
1539 153d 1541 1544 1548 154c 154f 1552
1557 155a 155d 1560 1561 1566 1567 1
1569 156e 1572 1576 1579 157e 1583 1586
158a 158b 1590 1593 1598 1599 159e 15a1
15a6 15a7 15ac 15af 15b3 15b4 15b9 15bc
15c1 15c2 15c7 15ca 15ce 15d2 15d5 15d8
15d9 15db 15dc 15e1 15e2 15e7 15e9 15ed
15f0 15f2 15f6 15f8 1604 1606 1608 1609
160e 1612 1614 1620 1622 1626 162a 162e
1632 1636 163a 163e 1642 1646 1652 1656
165b 165f 1662 1663 1668 166c 1670 1673
1676 167a 167c 1680 1684 1687 168a 168e
1690 1694 1698 169b 169d 16a1 16a5 16a9
16ac 16b0 16b4 16b6 16b7 16bc 1 16c0
16c4 16c8 16cb 16cf 16d3 16d7 16db 16de
16e2 16e6 16e9 16ec 16f1 16f4 16f7 16fa
16fb 1700 1701 1 1703 1708 170c 1710
1713 1718 171d 1720 1724 1725 172a 172d
1732 1733 1738 173b 1740 1741 1746 1749
174d 174e 1753 1756 175b 175c 1761 1764
1768 176c 176f 1772 1773 1775 1776 177b
177c 1781 1783 1787 178a 178c 1790 1792
179e 17a0 17a2 17a3 17a8 17ac 17ae 17ba
17bc 17c0 17c4 17c7 17c8 17ca 17cd 17d0
17d1 17d6 17da 17de 17e2 17e3 17e5 17e9
17ed 17f9 17fb 17ff 1802 1804 1808 180f
1813 1817 181c 181e 1822 1826 1829 182d
1831 1833 1837 183b 183f 1842 1846 184a
184c 184d 1852 1 1856 185a 185e 1861
1865 1869 186d 1871 1874 1878 187c 187f
1882 1887 188a 188d 1890 1891 1896 1897
1 1899 189e 18a2 18a6 18a9 18ae 18b3
18b6 18ba 18bb 18c0 18c3 18c8 18c9 18ce
18d1 18d6 18d7 18dc 18df 18e3 18e4 18e9
18ec 18f1 18f2 18f7 18fa 18fe 1902 1905
1908 1909 190b 190c 1911 1912 1917 1919
191d 1920 1922 1926 1928 1934 1936 1938
1939 193e 1942 1944 1950 1952 1956 195a
195f 1963 1964 1968 196c 1970 1975 197a
197e 1982 1987 198b 198f 1992 1995 1999
199b 199f 19a3 19a6 19a9 19ad 19af 19b3
19b7 19ba 19be 19c2 19c5 19c9 19cc 19d0
19d3 19d4 19d9 19dc 19e0 19e6 19e8 19ec
19ef 19f3 19f7 19fb 19ff 1a03 1a07 1a0b
1a0f 1a13 1a17 1a1b 1a1f 1a2b 1a2f 1a34
1a38 1a3b 1a3c 1a41 1a45 1a49 1a4c 1a4f
1a53 1a55 1a59 1a5d 1a60 1a63 1a67 1a69
1a6d 1a71 1a74 1a76 1a7a 1a7e 1a82 1a85
1a89 1a8d 1a8f 1a90 1a95 1 1a99 1a9d
1aa1 1aa4 1aa8 1aac 1ab0 1ab4 1ab7 1abb
1abf 1ac2 1ac5 1aca 1acd 1ad0 1ad3 1ad4
1ad9 1ada 1 1adc 1ae1 1ae5 1ae9 1aec
1af1 1af6 1af9 1afd 1afe 1b03 1b06 1b0b
1b0c 1b11 1b14 1b19 1b1a 1b1f 1b22 1b26
1b27 1b2c 1b2f 1b34 1b35 1b3a 1b3d 1b41
1b45 1b48 1b4b 1b4c 1b4e 1b4f 1b54 1b55
1b5a 1b5c 1b60 1b63 1b65 1b69 1b6b 1b77
1b79 1b7b 1b7c 1b81 1b85 1b87 1b93 1b95
1b99 1b9d 1ba0 1ba1 1ba3 1ba6 1ba9 1baa
1baf 1bb3 1bb7 1bbb 1bbc 1bbe 1bc2 1bc6
1bd2 1bd4 1bd8 1bdb 1bdd 1be1 1be8 1bec
1bf0 1bf5 1bf7 1bfb 1bff 1c02 1c06 1c0a
1c0c 1c10 1c14 1c18 1c1b 1c1f 1c23 1c25
1c26 1c2b 1 1c2f 1c33 1c37 1c3a 1c3e
1c42 1c46 1c4a 1c4d 1c51 1c55 1c58 1c5b
1c60 1c63 1c66 1c69 1c6a 1c6f 1c70 1
1c72 1c77 1c7b 1c7f 1c82 1c87 1c8c 1c8f
1c93 1c94 1c99 1c9c 1ca1 1ca2 1ca7 1caa
1caf 1cb0 1cb5 1cb8 1cbc 1cbd 1cc2 1cc5
1cca 1ccb 1cd0 1cd3 1cd7 1cdb 1cde 1ce1
1ce2 1ce4 1ce5 1cea 1ceb 1cf0 1cf2 1cf6
1cf9 1cfb 1cff 1d01 1d0d 1d0f 1d11 1d12
1d17 1d1b 1d1d 1d29 1d2b 1d2d 1d31 1d35
1d38 1d3c 1d40 1d43 1d47 1d4b 1d4e 1d51
1d56 1d59 1d5c 1d5f 1d60 1d65 1d66 1
1d68 1d6d 1d71 1d75 1d78 1d7d 1d82 1d85
1d89 1d8a 1d8f 1d92 1d97 1d98 1d9d 1da0
1da5 1da6 1dab 1dae 1db2 1db6 1db9 1dba
1dbf 1dc0 1dc5 1dc7 1dcb 1dce 1dd2 1dd6
1dda 1ddd 1de1 1de3 1de7 1de9 1df5 1df9
1dfb 1dfc 1e05 
853
2
0 1 a 6 16 1a 21 :2 6
1 3 a :2 1 4 :2 c 1b c
:2 4 :2 12 21 12 :2 4 :2 14 23 14
4 7 e 0 :2 7 11 1d 2b
10 1c 25 30 39 45 4e 5c
65 73 7c 13 a :6 7 e 0
:2 7 11 1d 2b 10 1c 25 30
39 45 4e 5c 65 73 7c 13
a :6 7 e 0 :2 7 11 1f 10
1c 25 30 39 45 4e 5c 65
73 7c 8f 9c 13 a :6 7 e
0 :2 7 21 f 10 1c 25 30
39 45 4e 5c 65 73 7c 8f
9c 13 a :6 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
54 5a 5d :2 54 6b 81 8 :2 6b
d 10 :2 6b 1d 20 :2 6b 25 28
:2 6b :2 7 4a :2 4 7 :2 11 23 :2 2d
39 3c 4c 4e 4f :2 4c :2 23 :3 7
:2 d 12 1e 5d 60 :2 1e :2 7 52
:2 4 :4 8 :2 7 c :4 7 10 19 27
:3 a d 11 :2 d :2 16 22 d 17
d :2 16 22 d :4 a e :2 17 23
20 :2 2c :2 20 :3 d 3c :3 a 1b a
14 29 41 5b 64 79 13 20
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5b 5c :2 59 :2 2f :3 13
:2 19 1e 2a 69 6c :2 2a 79 7c
:2 2a 80 83 :2 2a 8f 92 :2 2a 9a
9d :2 2a a9 ac b3 bc bf :2 ac
:2 2a :2 13 5f :2 10 :2 d :4 19 :2 d a
:3 7 a 1b :2 24 2b :2 34 44 :2 4d
:2 1b a 14 20 2e 37 48 5f
:2 d 29 45 13 20 32 43 d
14 10 1c :3 1a 10 :2 19 25 10
21 10 :2 19 25 10 :4 d a 12
10 :2 19 25 10 20 :2 d :2 12 10
:2 19 25 10 13 :2 1d 2f :2 39 45
49 59 5b 5c :2 59 :2 2f :3 13 :2 19
1e 2a 69 6c :2 2a 79 7c :2 2a
80 83 :2 2a 8f 92 :2 2a 9a 9d
:2 2a a9 ac b3 bc bf :2 ac :2 2a
:2 13 5f :2 10 :2 d :4 19 :2 d a :3 7
14 20 2e 3d 54 13 20 33
44 d 14 10 1c :3 1a 10 :2 19
25 10 21 10 :2 19 25 10 :4 d
a 12 10 :2 19 25 10 20 :2 d
:2 12 10 :2 19 25 10 13 :2 1d 2f
:2 39 45 49 59 5c 5d :2 59 :2 2f
:3 13 :2 19 1e 2a 6a 6d :2 2a 7a
7d :2 2a 81 84 :2 2a 90 93 :2 2a
9b 9e :2 2a aa ad b4 bd c0
:2 ad :2 2a :2 13 60 :2 10 :2 d :4 19 :2 d
a :3 7 14 20 2e 37 48 5f
13 20 31 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 59 5c 5d
:2 59 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 90
93 :2 2a 9b 9e :2 2a aa ad b4
bd c0 :2 ad :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :3 7 d 16 1f :2 d
22 24 :2 22 d 20 2a :2 20 :3 d
26 :2 a 7 b 1e a 10 :3 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :3 1e 7 c :4 7
10 19 27 :3 a d 11 :2 d :2 16
22 d 17 d :2 16 22 d :4 a
e :2 17 23 20 :2 2c :2 20 :3 d 3c
:2 a 14 20 2e 37 48 d 29
45 13 20 33 44 d 14 10
1c :3 1a 10 :2 19 25 10 21 10
:2 19 25 10 :4 d a 12 10 :2 19
25 10 20 :2 d :2 12 10 :2 19 25
10 13 :2 1d 2f :2 39 45 49 59
5c 5d :2 59 :2 2f :3 13 :2 19 1e 2a
6a 6d :2 2a 7a 7d :2 2a 81 84
:2 2a 90 93 :2 2a 9b 9e :2 2a aa
ad b4 bd c0 :2 ad :2 2a :2 13 60
:2 10 :2 d :4 19 :2 d a :3 7 d 16
1f :2 d 22 24 :2 22 d 20 2a
:2 20 :3 d 26 :2 a 7 b 1e a
10 :3 a :2 13 1f a 7 f d
:2 16 22 d 1d :2 a :2 f d :2 16
22 d 10 :2 1a 2c :2 36 42 46
56 59 5a :2 56 :2 2c :3 10 :2 16 1b
27 67 6a :2 27 77 7a :2 27 7e
81 :2 27 8d 90 :2 27 98 9b :2 27
a7 aa b1 ba bd :2 aa :2 27 :2 10
5d :2 d :2 a :4 16 :2 a 7 :4 1e 7
c :4 7 10 19 :2 a d 11 :2 d
:2 16 22 d 17 d :2 16 22 d
:4 a e :2 17 23 20 :2 2c :2 20 :3 d
3c :3 a 1b :2 24 2b :2 34 44 :2 4d
:2 1b a 14 29 37 40 56 63
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a 7a 7d
:2 2a 81 84 :2 2a 90 93 :2 2a 9b
9e :2 2a aa ad b4 bd c0 :2 ad
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 7 14 20 2e 37 48 5f :2 d
29 45 13 20 32 43 d 14
10 1c :3 1a 10 :2 19 25 10 21
10 :2 19 25 10 :4 d a 12 10
:2 19 25 10 20 :2 d :2 12 10 :2 19
25 10 13 :2 1d 2f :2 39 45 49
59 5c 5d :2 59 :2 2f :3 13 :2 19 1e
2a 6a 6d :2 2a 7a 7d :2 2a 81
84 :2 2a 90 93 :2 2a 9b 9e :2 2a
aa ad b4 bd c0 :2 ad :2 2a :2 13
60 :2 10 :2 d :4 19 :2 d a :3 7 14
20 2e 3d 54 13 20 33 44
d 14 10 1c :3 1a 10 :2 19 25
10 21 10 :2 19 25 10 :4 d a
12 10 :2 19 25 10 20 :2 d :2 12
10 :2 19 25 10 13 :2 1d 2f :2 39
45 49 59 5c 5d :2 59 :2 2f :3 13
:2 19 1e 2a 6a 6d :2 2a 7a 7d
:2 2a 81 84 :2 2a 90 93 :2 2a 9b
9e :2 2a aa ad b4 bd c0 :2 ad
:2 2a :2 13 60 :2 10 :2 d :4 19 :2 d a
:3 7 14 20 2e 37 48 5f 13
20 31 d 14 10 1c :3 1a 10
:2 19 25 10 21 10 :2 19 25 10
:4 d a 12 10 :2 19 25 10 20
:2 d :2 12 10 :2 19 25 10 13 :2 1d
2f :2 39 45 49 59 5c 5d :2 59
:2 2f :3 13 :2 19 1e 2a 6a 6d :2 2a
7a 7d :2 2a 81 84 :2 2a 90 93
:2 2a 9b 9e :2 2a aa ad b4 bd
c0 :2 ad :2 2a :2 13 60 :2 10 :2 d :4 19
:2 d a :3 7 d 16 1f :2 d 22
24 :2 22 d 20 2a :2 20 :3 d 26
:2 a 7 b 4 a 10 :3 a :2 13
1f a 7 f d :2 16 22 d
1d :2 a :2 f d :2 16 22 d 10
:2 1a 2c :2 36 42 46 56 59 5a
:2 56 :2 2c :3 10 :2 16 1b 27 67 6a
:2 27 77 7a :2 27 7e 81 :2 27 8d
90 :2 27 98 9b :2 27 a7 aa b1
ba bd :2 aa :2 27 :2 10 5d :2 d :2 a
:4 16 :2 a 7 :3 4 7 c :4 7 10
19 :2 a d 11 :2 d :2 16 22 d
17 d :2 16 22 d :4 a e :2 17
23 20 :2 2c :2 20 :3 d 3c :2 a 14
20 2e 37 48 d 29 45 13
20 33 44 d 14 10 1c :3 1a
10 :2 19 25 10 21 10 :2 19 25
10 :4 d a 12 10 :2 19 25 10
20 :2 d :2 12 10 :2 19 25 10 13
:2 1d 2f :2 39 45 49 59 5c 5d
:2 59 :2 2f :3 13 :2 19 1e 2a 6a 6d
:2 2a 7a 7d :2 2a 81 84 :2 2a 90
93 :2 2a 9b 9e :2 2a aa ad b4
bd c0 :2 ad :2 2a :2 13 60 :2 10 :2 d
:4 19 :2 d a :3 7 d 16 1f :2 d
22 24 :2 22 d 20 2a :2 20 :3 d
26 :2 a 7 b 4 a 10 :3 a
:2 13 1f a 7 f d :2 16 22
d 1d :2 a :2 f d :2 16 22 d
10 :2 1a 2c :2 36 42 46 56 59
5a :2 56 :2 2c :3 10 :2 16 1b 27 67
6a :2 27 77 7a :2 27 7e 81 :2 27
8d 90 :2 27 98 9b :2 27 a7 aa
b1 ba bd :2 aa :2 27 :2 10 5d :2 d
:2 a :4 16 :2 a 7 :7 4 7 :2 11 23
:2 2d 39 3c 4c 4f 50 :2 4c :2 23
:3 7 :2 d 12 1e 5e 61 :2 1e 6e
71 :2 1e 75 78 :2 1e 82 85 :2 8e
:2 1e :2 7 53 :3 4 b :2 14 4 :9 1

853
4
0 :2 1 :6 3 2
:2 4 :2 1 :6 6 :6 7
:6 8 :2 a 0 :2 a
:3 b :b c d b
:5 a :2 f 0 :2 f
:3 10 :b 11 12 10
:5 f :2 14 0 :2 14
:2 15 :d 16 17 15
:5 14 :2 19 0 :2 19
1a 1b :d 1c 1d
1a :5 19 :b 20 :11 21
22 :2 21 :2 22 :2 21
:2 22 :2 21 :2 22 :4 21
:3 20 :11 25 :b 26 :3 25
:5 29 :5 2c 2e :6 2f
:3 30 :5 31 30 :5 33
32 :3 30 :a 35 :2 36
:3 35 :3 39 :6 3d :2 3e
3d :6 3f :5 40 3f
:5 42 41 :3 3f 3c
45 :5 46 :3 45 :2 47
:5 49 :11 4a :24 4b :3 4a
:2 48 :6 47 44 :3 2e
:d 50 :6 53 54 :3 55
:4 56 53 :6 57 :5 58
57 :5 5a 59 :3 57
52 5d :5 5e :3 5d
:2 5f :5 61 :11 62 :24 63
:3 62 :2 60 :6 5f 5c
:3 2e :5 69 :4 6a 69
:6 6b :5 6c 6b :5 6e
6d :3 6b 68 71
:5 72 :3 71 :2 73 :5 75
:11 76 :24 77 :3 76 :2 74
:6 73 70 :3 2e :6 7d
:3 7e 7d :6 7f :5 80
7f :5 82 81 :3 7f
7c 85 :5 86 :3 85
:2 87 :5 89 :11 8a :24 8b
:3 8a :2 88 :6 87 84
:3 2e :9 90 :6 91 :2 93
:3 90 2e 95 29
:4 98 :5 99 97 9b
:5 9c :3 9b :2 9d :5 9f
:11 a0 :24 a1 :3 a0 :2 9e
:6 9d 9a :3 29 :5 a8
aa :6 ab :3 ac :5 ad
ac :5 af ae :3 ac
:a b2 :2 b3 :3 b2 :5 b7
:3 b8 :4 b9 b7 :6 ba
:5 bb ba :5 bd bc
:3 ba b6 c0 :5 c1
:3 c0 :2 c2 :5 c4 :11 c5
:24 c6 :3 c5 :2 c3 :6 c2
bf :3 aa :9 cb :6 cc
:2 ce :3 cb aa d0
29 :4 d3 :5 d4 d2
d6 :5 d7 :3 d6 :2 d8
:5 da :11 db :24 dc :3 db
:2 d9 :6 d8 d5 :4 29
:5 e3 e5 :4 e6 :3 e7
:5 e8 e7 :5 ea e9
:3 e7 :a ed :2 ee :3 ed
:d f1 :7 f4 :6 f5 :5 f6
f5 :5 f8 f7 :3 f5
f3 fb :5 fc :3 fb
:2 fd :5 ff :11 100 :24 101
:3 100 :2 fe :6 fd fa
:3 e5 :6 107 108 :3 109
:4 10a 107 :6 10b :5 10c
10b :5 10e 10d :3 10b
106 111 :5 112 :3 111
:2 113 :5 115 :11 116 :24 117
:3 116 :2 114 :6 113 110
:3 e5 :5 11d :4 11e 11d
:6 11f :5 120 11f :5 122
121 :3 11f 11c 125
:5 126 :3 125 :2 127 :5 129
:11 12a :24 12b :3 12a :2 128
:6 127 124 :3 e5 :6 131
:3 132 131 :6 133 :5 134
133 :5 136 135 :3 133
130 139 :5 13a :3 139
:2 13b :5 13d :11 13e :24 13f
:3 13e :2 13c :6 13b 138
:3 e5 :9 144 :6 145 :2 147
:3 144 e5 149 e0
:4 14c :5 14d 14b 14f
:5 150 :3 14f :2 151 :5 153
:11 154 :24 155 :3 154 :2 152
:6 151 14e :3 e0 :5 15c
15e :4 15f :3 160 :5 161
160 :5 163 162 :3 160
:a 166 :2 167 :3 166 :5 16b
:3 16c :4 16d 16b :6 16e
:5 16f 16e :5 171 170
:3 16e 16a 174 :5 175
:3 174 :2 176 :5 178 :11 179
:24 17a :3 179 :2 177 :6 176
173 :3 15e :9 17f :6 180
:2 182 :3 17f 15e 184
e0 :4 187 :5 188 186
18a :5 18b :3 18a :2 18c
:5 18e :11 18f :24 190 :3 18f
:2 18d :6 18c 189 :4 e0
:3 29 :11 196 :19 197 :3 196
:5 199 :2 1f :7 1 
1e07
4
:3 0 1 :3 0 2
:a 0 84e 1 :7 0
5 :2 0 3 4
:3 0 5 :3 0 6
:3 0 3 :5 0 1
7 6 :3 0 7
:3 0 8 :3 0 9
b 0 84e 2
c :2 0 a :2 0
7 8 :3 0 f
:7 0 a :2 0 13
10 11 84c 0
9 :6 0 a :2 0
9 8 :3 0 15
:7 0 19 16 17
84c 0 b :9 0
b 8 :3 0 1b
:7 0 1f 1c 1d
84c 0 c :6 0
d :3 0 e :a 0
2 35 :4 0 21
24 0 22 :3 0
f :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
19 :4 0 1a 1
:8 0 36 21 24
37 0 84c d
37 39 36 38
:6 0 35 :7 0 37
d :3 0 1b :a 0
3 4f :5 0 3b
3e 0 3c :3 0
f :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
19 :4 0 1a 1
:8 0 50 3b 3e
51 0 84c f
51 53 50 52
:6 0 4f :7 0 51
d :3 0 1c :a 0
4 6a :5 0 55
58 0 56 :3 0
10 :3 0 11 :3 0
12 :3 0 13 :3 0
14 :3 0 13 :3 0
15 :3 0 13 :3 0
16 :3 0 13 :3 0
17 :3 0 13 :3 0
18 :3 0 1d :3 0
3 :3 0 19 :4 0
1e 1 :8 0 6b
55 58 6c 0
84c 11 6c 6e
6b 6d :6 0 6a
:7 0 6c d :3 0
1f :a 0 5 85
:5 0 70 73 0
71 :3 0 10 :3 0
11 :3 0 12 :3 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
13 :3 0 16 :3 0
13 :3 0 17 :3 0
13 :3 0 18 :3 0
1d :3 0 3 :3 0
19 :4 0 20 1
:8 0 86 70 73
87 0 84c 13
87 89 86 88
:6 0 85 :7 0 87
21 :3 0 22 :3 0
8a 8b 0 21
:3 0 23 :3 0 8d
8e 0 2 :4 0
15 8f 91 8c
93 92 :2 0 24
:3 0 25 :3 0 95
96 0 26 :4 0
21 :3 0 27 :3 0
99 9a 0 2
:4 0 17 9b 9d
28 :4 0 29 :2 0
2a :3 0 19 a0
a2 :3 0 2b :4 0
29 :2 0 2c :4 0
1c a5 a7 :3 0
29 :2 0 3 :3 0
1f a9 ab :3 0
29 :2 0 2c :4 0
22 ad af :3 0
29 :2 0 2d :4 0
25 b1 b3 :3 0
28 97 b5 :2 0
b7 2d b8 94
b7 0 b9 2f
0 84a 21 :3 0
22 :3 0 ba bb
0 21 :3 0 2e
:3 0 bd be 0
2f :2 0 2 :4 0
30 :2 0 31 :2 0
2f :2 0 31 c3
c5 :3 0 34 bf
c7 bc c9 c8
:2 0 24 :3 0 32
:3 0 cb cc 0
26 :4 0 33 :4 0
29 :2 0 2a :3 0
38 d0 d2 :3 0
3b cd d4 :2 0
d6 3e d7 ca
d6 0 d8 40
0 84a 3 :3 0
34 :2 0 42 da
db :3 0 dc :2 0
35 :3 0 e :4 0
e1 :2 0 47d df
e2 :3 0 36 :3 0
e :3 0 3 :3 0
9 :4 0 e8 :2 0
303 e4 e9 :3 0
44 :3 0 e :3 0
37 :3 0 ea eb
:3 0 38 :3 0 39
:3 0 ed ee 0
a :2 0 ef f0
0 f2 47 f9
38 :3 0 39 :3 0
f3 f4 0 3a
:2 0 f5 f6 0
f8 49 fa ec
f2 0 fb 0
f8 0 fb 4b
0 303 38 :3 0
39 :3 0 fc fd
0 38 :3 0 3b
:2 0 3c :3 0 ff
101 0 50 100
103 :3 0 104 :2 0
3d :8 0 108 53
109 105 108 0
10a 55 0 303
b :3 0 3e :2 0
10b 10c 0 303
3f :3 0 40 :3 0
41 :3 0 13 :3 0
42 :3 0 b :3 0
f :3 0 3 :4 0
43 1 :8 0 12c
37 :4 0 117 :3 0
44 :3 0 45 :2 0
59 11a 11b :3 0
38 :3 0 39 :3 0
11d 11e 0 a
:2 0 11f 120 0
122 5c 129 38
:3 0 39 :3 0 123
124 0 3a :2 0
125 126 0 128
5e 12a 11c 122
0 12b 0 128
0 12b 60 0
12c 63 17f 46
:3 0 38 :3 0 39
:3 0 12e 12f 0
47 :3 0 130 131
0 133 66 135
68 134 133 :2 0
17d 48 :3 0 38
:3 0 39 :3 0 138
139 0 47 :3 0
13a 13b 0 175
21 :3 0 22 :3 0
13d 13e 0 21
:3 0 2e :3 0 140
141 0 49 :2 0
2 :4 0 4a :2 0
31 :2 0 2f :2 0
6a 146 148 :3 0
6d 142 14a 13f
14c 14b :2 0 24
:3 0 32 :3 0 14e
14f 0 26 :4 0
4b :4 0 29 :2 0
2a :3 0 71 153
155 :3 0 29 :2 0
4c :4 0 74 157
159 :3 0 29 :2 0
4d :4 0 77 15b
15d :3 0 29 :2 0
47 :3 0 7a 15f
161 :3 0 29 :2 0
4e :4 0 7d 163
165 :3 0 29 :2 0
4f :3 0 50 :3 0
2f :2 0 51 :2 0
80 168 16c 84
167 16e :3 0 87
150 170 :2 0 172
8a 173 14d 172
0 174 8c 0
175 8e 178 :3 0
178 0 178 177
175 176 :6 0 17a
7 :3 0 91 17c
93 17b 17a :2 0
17d 95 :2 0 17f
0 17f 17e 12c
17d :6 0 303 6
:3 0 b :3 0 52
:3 0 53 :3 0 182
183 0 13 :3 0
54 :3 0 185 186
0 13 :3 0 55
:3 0 188 189 0
98 184 18b 181
18c 0 303 11
:3 0 40 :3 0 13
:3 0 42 :3 0 56
:3 0 57 :3 0 58
:3 0 59 :3 0 5a
:3 0 59 :3 0 f
:3 0 3 :3 0 5b
:3 0 5c :4 0 5d
1 :8 0 1b2 37
:4 0 19d :3 0 44
:3 0 45 :2 0 9d
1a0 1a1 :3 0 38
:3 0 39 :3 0 1a3
1a4 0 a :2 0
1a5 1a6 0 1a8
a0 1af 38 :3 0
39 :3 0 1a9 1aa
0 3a :2 0 1ab
1ac 0 1ae a2
1b0 1a2 1a8 0
1b1 0 1ae 0
1b1 a4 0 1b2
a7 205 46 :3 0
38 :3 0 39 :3 0
1b4 1b5 0 47
:3 0 1b6 1b7 0
1b9 aa 1bb ac
1ba 1b9 :2 0 203
48 :3 0 38 :3 0
39 :3 0 1be 1bf
0 47 :3 0 1c0
1c1 0 1fb 21
:3 0 22 :3 0 1c3
1c4 0 21 :3 0
2e :3 0 1c6 1c7
0 49 :2 0 2
:4 0 5e :2 0 31
:2 0 2f :2 0 ae
1cc 1ce :3 0 b1
1c8 1d0 1c5 1d2
1d1 :2 0 24 :3 0
32 :3 0 1d4 1d5
0 26 :4 0 5f
:4 0 29 :2 0 2a
:3 0 b5 1d9 1db
:3 0 29 :2 0 4c
:4 0 b8 1dd 1df
:3 0 29 :2 0 4d
:4 0 bb 1e1 1e3
:3 0 29 :2 0 47
:3 0 be 1e5 1e7
:3 0 29 :2 0 4e
:4 0 c1 1e9 1eb
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 c4
1ee 1f2 c8 1ed
1f4 :3 0 cb 1d6
1f6 :2 0 1f8 ce
1f9 1d3 1f8 0
1fa d0 0 1fb
d2 1fe :3 0 1fe
0 1fe 1fd 1fb
1fc :6 0 200 9
:3 0 d5 202 d7
201 200 :2 0 203
d9 :2 0 205 0
205 204 1b2 203
:6 0 303 6 :3 0
11 :3 0 40 :3 0
b :3 0 56 :3 0
57 :3 0 f :3 0
3 :3 0 5b :3 0
5c :4 0 60 1
:8 0 226 37 :4 0
211 :3 0 44 :3 0
45 :2 0 de 214
215 :3 0 38 :3 0
39 :3 0 217 218
0 a :2 0 219
21a 0 21c e1
223 38 :3 0 39
:3 0 21d 21e 0
3a :2 0 21f 220
0 222 e3 224
216 21c 0 225
0 222 0 225
e5 0 226 e8
279 46 :3 0 38
:3 0 39 :3 0 228
229 0 47 :3 0
22a 22b 0 22d
eb 22f ed 22e
22d :2 0 277 48
:3 0 38 :3 0 39
:3 0 232 233 0
47 :3 0 234 235
0 26f 21 :3 0
22 :3 0 237 238
0 21 :3 0 2e
:3 0 23a 23b 0
49 :2 0 2 :4 0
61 :2 0 31 :2 0
2f :2 0 ef 240
242 :3 0 f2 23c
244 239 246 245
:2 0 24 :3 0 32
:3 0 248 249 0
26 :4 0 62 :4 0
29 :2 0 2a :3 0
f6 24d 24f :3 0
29 :2 0 4c :4 0
f9 251 253 :3 0
29 :2 0 4d :4 0
fc 255 257 :3 0
29 :2 0 47 :3 0
ff 259 25b :3 0
29 :2 0 4e :4 0
102 25d 25f :3 0
29 :2 0 4f :3 0
50 :3 0 2f :2 0
51 :2 0 105 262
266 109 261 268
:3 0 10c 24a 26a
:2 0 26c 10f 26d
247 26c 0 26e
111 0 26f 113
272 :3 0 272 0
272 271 26f 270
:6 0 274 b :3 0
116 276 118 275
274 :2 0 277 11a
:2 0 279 0 279
278 226 277 :6 0
303 6 :3 0 63
:3 0 40 :3 0 13
:3 0 42 :3 0 56
:3 0 57 :3 0 f
:3 0 3 :3 0 12
:4 0 64 1 :8 0
29a 37 :4 0 285
:3 0 44 :3 0 45
:2 0 11f 288 289
:3 0 38 :3 0 39
:3 0 28b 28c 0
a :2 0 28d 28e
0 290 122 297
38 :3 0 39 :3 0
291 292 0 3a
:2 0 293 294 0
296 124 298 28a
290 0 299 0
296 0 299 126
0 29a 129 2ed
46 :3 0 38 :3 0
39 :3 0 29c 29d
0 47 :3 0 29e
29f 0 2a1 12c
2a3 12e 2a2 2a1
:2 0 2eb 48 :3 0
38 :3 0 39 :3 0
2a6 2a7 0 47
:3 0 2a8 2a9 0
2e3 21 :3 0 22
:3 0 2ab 2ac 0
21 :3 0 2e :3 0
2ae 2af 0 49
:2 0 2 :4 0 65
:2 0 31 :2 0 2f
:2 0 130 2b4 2b6
:3 0 133 2b0 2b8
2ad 2ba 2b9 :2 0
24 :3 0 32 :3 0
2bc 2bd 0 26
:4 0 66 :4 0 29
:2 0 2a :3 0 137
2c1 2c3 :3 0 29
:2 0 4c :4 0 13a
2c5 2c7 :3 0 29
:2 0 4d :4 0 13d
2c9 2cb :3 0 29
:2 0 47 :3 0 140
2cd 2cf :3 0 29
:2 0 4e :4 0 143
2d1 2d3 :3 0 29
:2 0 4f :3 0 50
:3 0 2f :2 0 51
:2 0 146 2d6 2da
14a 2d5 2dc :3 0
14d 2be 2de :2 0
2e0 150 2e1 2bb
2e0 0 2e2 152
0 2e3 154 2e6
:3 0 2e6 0 2e6
2e5 2e3 2e4 :6 0
2e8 d :3 0 157
2ea 159 2e9 2e8
:2 0 2eb 15b :2 0
2ed 0 2ed 2ec
29a 2eb :6 0 303
6 :3 0 67 :3 0
9 :3 0 a :2 0
15e 2ef 2f2 45
:2 0 a :2 0 163
2f4 2f6 :3 0 c
:3 0 68 :3 0 3
:3 0 166 2f9 2fb
2f8 2fc 0 300
69 :4 0 69 1
:8 0 300 168 301
2f7 300 0 302
16b 0 303 16d
305 36 :4 0 303
:4 0 47d 6a :3 0
e :4 0 309 :2 0
30f 307 0 38
:3 0 39 :3 0 30a
30b 0 47 :3 0
30c 30d 0 30f
178 362 46 :3 0
38 :3 0 39 :3 0
311 312 0 47
:3 0 313 314 0
316 17b 318 17d
317 316 :2 0 360
48 :3 0 38 :3 0
39 :3 0 31b 31c
0 47 :3 0 31d
31e 0 358 21
:3 0 22 :3 0 320
321 0 21 :3 0
2e :3 0 323 324
0 49 :2 0 2
:4 0 6b :2 0 31
:2 0 2f :2 0 17f
329 32b :3 0 182
325 32d 322 32f
32e :2 0 24 :3 0
32 :3 0 331 332
0 26 :4 0 6c
:4 0 29 :2 0 2a
:3 0 186 336 338
:3 0 29 :2 0 4c
:4 0 189 33a 33c
:3 0 29 :2 0 4d
:4 0 18c 33e 340
:3 0 29 :2 0 47
:3 0 18f 342 344
:3 0 29 :2 0 4e
:4 0 192 346 348
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 195
34b 34f 199 34a
351 :3 0 19c 333
353 :2 0 355 19f
356 330 355 0
357 1a1 0 358
1a3 35b :3 0 35b
0 35b 35a 358
359 :6 0 35d f
:3 0 1a6 35f 1a8
35e 35d :2 0 360
1aa :2 0 362 0
362 361 30f 360
:6 0 47d 1 :3 0
35 :3 0 1b :4 0
367 :2 0 47d 365
368 :3 0 36 :3 0
1b :3 0 3 :3 0
9 :4 0 36e :2 0
41c 36a 36f :3 0
1ad :3 0 1b :3 0
37 :3 0 370 371
:3 0 38 :3 0 39
:3 0 373 374 0
a :2 0 375 376
0 378 1b0 37f
38 :3 0 39 :3 0
379 37a 0 3a
:2 0 37b 37c 0
37e 1b2 380 372
378 0 381 0
37e 0 381 1b4
0 41c 38 :3 0
39 :3 0 382 383
0 38 :3 0 3b
:2 0 3c :3 0 385
387 0 1b9 386
389 :3 0 38a :2 0
3d :8 0 38e 1bc
38f 38b 38e 0
390 1be 0 41c
11 :3 0 40 :3 0
13 :3 0 42 :3 0
58 :3 0 59 :3 0
5a :3 0 59 :3 0
f :3 0 3 :3 0
5b :3 0 5c :4 0
6d 1 :8 0 3b3
37 :4 0 39e :3 0
44 :3 0 45 :2 0
1c2 3a1 3a2 :3 0
38 :3 0 39 :3 0
3a4 3a5 0 a
:2 0 3a6 3a7 0
3a9 1c5 3b0 38
:3 0 39 :3 0 3aa
3ab 0 3a :2 0
3ac 3ad 0 3af
1c7 3b1 3a3 3a9
0 3b2 0 3af
0 3b2 1c9 0
3b3 1cc 406 46
:3 0 38 :3 0 39
:3 0 3b5 3b6 0
47 :3 0 3b7 3b8
0 3ba 1cf 3bc
1d1 3bb 3ba :2 0
404 48 :3 0 38
:3 0 39 :3 0 3bf
3c0 0 47 :3 0
3c1 3c2 0 3fc
21 :3 0 22 :3 0
3c4 3c5 0 21
:3 0 2e :3 0 3c7
3c8 0 49 :2 0
2 :4 0 6e :2 0
31 :2 0 2f :2 0
1d3 3cd 3cf :3 0
1d6 3c9 3d1 3c6
3d3 3d2 :2 0 24
:3 0 32 :3 0 3d5
3d6 0 26 :4 0
6f :4 0 29 :2 0
2a :3 0 1da 3da
3dc :3 0 29 :2 0
4c :4 0 1dd 3de
3e0 :3 0 29 :2 0
4d :4 0 1e0 3e2
3e4 :3 0 29 :2 0
47 :3 0 1e3 3e6
3e8 :3 0 29 :2 0
4e :4 0 1e6 3ea
3ec :3 0 29 :2 0
4f :3 0 50 :3 0
2f :2 0 51 :2 0
1e9 3ef 3f3 1ed
3ee 3f5 :3 0 1f0
3d7 3f7 :2 0 3f9
1f3 3fa 3d4 3f9
0 3fb 1f5 0
3fc 1f7 3ff :3 0
3ff 0 3ff 3fe
3fc 3fd :6 0 401
12 :3 0 1fa 403
1fc 402 401 :2 0
404 1fe :2 0 406
0 406 405 3b3
404 :6 0 41c 11
:3 0 67 :3 0 9
:3 0 a :2 0 201
408 40b 45 :2 0
a :2 0 206 40d
40f :3 0 c :3 0
68 :3 0 3 :3 0
209 412 414 411
415 0 419 69
:4 0 69 1 :8 0
419 20b 41a 410
419 0 41b 20e
0 41c 210 41e
36 :4 0 41c :4 0
47d 6a :3 0 1b
:4 0 422 :2 0 428
420 0 38 :3 0
39 :3 0 423 424
0 47 :3 0 425
426 0 428 216
47b 46 :3 0 38
:3 0 39 :3 0 42a
42b 0 47 :3 0
42c 42d 0 42f
219 431 21b 430
42f :2 0 479 48
:3 0 38 :3 0 39
:3 0 434 435 0
47 :3 0 436 437
0 471 21 :3 0
22 :3 0 439 43a
0 21 :3 0 2e
:3 0 43c 43d 0
49 :2 0 2 :4 0
70 :2 0 31 :2 0
2f :2 0 21d 442
444 :3 0 220 43e
446 43b 448 447
:2 0 24 :3 0 32
:3 0 44a 44b 0
26 :4 0 71 :4 0
29 :2 0 2a :3 0
224 44f 451 :3 0
29 :2 0 4c :4 0
227 453 455 :3 0
29 :2 0 4d :4 0
22a 457 459 :3 0
29 :2 0 47 :3 0
22d 45b 45d :3 0
29 :2 0 4e :4 0
230 45f 461 :3 0
29 :2 0 4f :3 0
50 :3 0 2f :2 0
51 :2 0 233 464
468 237 463 46a
:3 0 23a 44c 46c
:2 0 46e 23d 46f
449 46e 0 470
23f 0 471 241
474 :3 0 474 0
474 473 471 472
:6 0 476 14 :3 0
244 478 246 477
476 :2 0 479 248
:2 0 47b 0 47b
47a 428 479 :6 0
47d 1 :3 0 24b
815 35 :3 0 1c
:4 0 481 :2 0 814
47f 482 :3 0 36
:3 0 1c :3 0 9
:4 0 487 :2 0 69c
484 485 :3 0 1c
:3 0 37 :3 0 488
489 :3 0 38 :3 0
39 :3 0 48b 48c
0 a :2 0 48d
48e 0 490 252
497 38 :3 0 39
:3 0 491 492 0
3a :2 0 493 494
0 496 254 498
48a 490 0 499
0 496 0 499
256 0 69c 38
:3 0 39 :3 0 49a
49b 0 38 :3 0
3b :2 0 3c :3 0
49d 49f 0 25b
49e 4a1 :3 0 4a2
:2 0 3d :8 0 4a6
25e 4a7 4a3 4a6
0 4a8 260 0
69c b :3 0 52
:3 0 53 :3 0 4aa
4ab 0 13 :3 0
54 :3 0 4ad 4ae
0 13 :3 0 55
:3 0 4b0 4b1 0
262 4ac 4b3 4a9
4b4 0 69c 3f
:3 0 40 :3 0 13
:3 0 42 :3 0 f
:3 0 3 :4 0 72
1 :8 0 4d2 37
:4 0 4bd :3 0 44
:3 0 45 :2 0 267
4c0 4c1 :3 0 38
:3 0 39 :3 0 4c3
4c4 0 a :2 0
4c5 4c6 0 4c8
26a 4cf 38 :3 0
39 :3 0 4c9 4ca
0 3a :2 0 4cb
4cc 0 4ce 26c
4d0 4c2 4c8 0
4d1 0 4ce 0
4d1 26e 0 4d2
271 525 46 :3 0
38 :3 0 39 :3 0
4d4 4d5 0 47
:3 0 4d6 4d7 0
4d9 274 4db 276
4da 4d9 :2 0 523
48 :3 0 38 :3 0
39 :3 0 4de 4df
0 47 :3 0 4e0
4e1 0 51b 21
:3 0 22 :3 0 4e3
4e4 0 21 :3 0
2e :3 0 4e6 4e7
0 49 :2 0 2
:4 0 73 :2 0 31
:2 0 2f :2 0 278
4ec 4ee :3 0 27b
4e8 4f0 4e5 4f2
4f1 :2 0 24 :3 0
32 :3 0 4f4 4f5
0 26 :4 0 74
:4 0 29 :2 0 2a
:3 0 27f 4f9 4fb
:3 0 29 :2 0 4c
:4 0 282 4fd 4ff
:3 0 29 :2 0 4d
:4 0 285 501 503
:3 0 29 :2 0 47
:3 0 288 505 507
:3 0 29 :2 0 4e
:4 0 28b 509 50b
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 28e
50e 512 292 50d
514 :3 0 295 4f6
516 :2 0 518 298
519 4f3 518 0
51a 29a 0 51b
29c 51e :3 0 51e
0 51e 51d 51b
51c :6 0 520 17
:3 0 29f 522 2a1
521 520 :2 0 523
2a3 :2 0 525 0
525 524 4d2 523
:6 0 69c 16 :3 0
11 :3 0 40 :3 0
13 :3 0 42 :3 0
56 :3 0 57 :3 0
58 :3 0 59 :3 0
5a :3 0 59 :3 0
f :3 0 3 :3 0
5b :3 0 5c :4 0
5d 1 :8 0 54b
37 :4 0 536 :3 0
44 :3 0 45 :2 0
2a8 539 53a :3 0
38 :3 0 39 :3 0
53c 53d 0 a
:2 0 53e 53f 0
541 2ab 548 38
:3 0 39 :3 0 542
543 0 3a :2 0
544 545 0 547
2ad 549 53b 541
0 54a 0 547
0 54a 2af 0
54b 2b2 59e 46
:3 0 38 :3 0 39
:3 0 54d 54e 0
47 :3 0 54f 550
0 552 2b5 554
2b7 553 552 :2 0
59c 48 :3 0 38
:3 0 39 :3 0 557
558 0 47 :3 0
559 55a 0 594
21 :3 0 22 :3 0
55c 55d 0 21
:3 0 2e :3 0 55f
560 0 49 :2 0
2 :4 0 75 :2 0
31 :2 0 2f :2 0
2b9 565 567 :3 0
2bc 561 569 55e
56b 56a :2 0 24
:3 0 32 :3 0 56d
56e 0 26 :4 0
76 :4 0 29 :2 0
2a :3 0 2c0 572
574 :3 0 29 :2 0
4c :4 0 2c3 576
578 :3 0 29 :2 0
4d :4 0 2c6 57a
57c :3 0 29 :2 0
47 :3 0 2c9 57e
580 :3 0 29 :2 0
4e :4 0 2cc 582
584 :3 0 29 :2 0
4f :3 0 50 :3 0
2f :2 0 51 :2 0
2cf 587 58b 2d3
586 58d :3 0 2d6
56f 58f :2 0 591
2d9 592 56c 591
0 593 2db 0
594 2dd 597 :3 0
597 0 597 596
594 595 :6 0 599
19 :3 0 2e0 59b
2e2 59a 599 :2 0
59c 2e4 :2 0 59e
0 59e 59d 54b
59c :6 0 69c 16
:3 0 11 :3 0 40
:3 0 b :3 0 56
:3 0 57 :3 0 f
:3 0 3 :3 0 5b
:3 0 5c :4 0 60
1 :8 0 5bf 37
:4 0 5aa :3 0 44
:3 0 45 :2 0 2e9
5ad 5ae :3 0 38
:3 0 39 :3 0 5b0
5b1 0 a :2 0
5b2 5b3 0 5b5
2ec 5bc 38 :3 0
39 :3 0 5b6 5b7
0 3a :2 0 5b8
5b9 0 5bb 2ee
5bd 5af 5b5 0
5be 0 5bb 0
5be 2f0 0 5bf
2f3 612 46 :3 0
38 :3 0 39 :3 0
5c1 5c2 0 47
:3 0 5c3 5c4 0
5c6 2f6 5c8 2f8
5c7 5c6 :2 0 610
48 :3 0 38 :3 0
39 :3 0 5cb 5cc
0 47 :3 0 5cd
5ce 0 608 21
:3 0 22 :3 0 5d0
5d1 0 21 :3 0
2e :3 0 5d3 5d4
0 49 :2 0 2
:4 0 77 :2 0 31
:2 0 2f :2 0 2fa
5d9 5db :3 0 2fd
5d5 5dd 5d2 5df
5de :2 0 24 :3 0
32 :3 0 5e1 5e2
0 26 :4 0 78
:4 0 29 :2 0 2a
:3 0 301 5e6 5e8
:3 0 29 :2 0 4c
:4 0 304 5ea 5ec
:3 0 29 :2 0 4d
:4 0 307 5ee 5f0
:3 0 29 :2 0 47
:3 0 30a 5f2 5f4
:3 0 29 :2 0 4e
:4 0 30d 5f6 5f8
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 310
5fb 5ff 314 5fa
601 :3 0 317 5e3
603 :2 0 605 31a
606 5e0 605 0
607 31c 0 608
31e 60b :3 0 60b
0 60b 60a 608
609 :6 0 60d 1b
:3 0 321 60f 323
60e 60d :2 0 610
325 :2 0 612 0
612 611 5bf 610
:6 0 69c 16 :3 0
63 :3 0 40 :3 0
13 :3 0 42 :3 0
56 :3 0 57 :3 0
f :3 0 3 :3 0
12 :4 0 64 1
:8 0 633 37 :4 0
61e :3 0 44 :3 0
45 :2 0 32a 621
622 :3 0 38 :3 0
39 :3 0 624 625
0 a :2 0 626
627 0 629 32d
630 38 :3 0 39
:3 0 62a 62b 0
3a :2 0 62c 62d
0 62f 32f 631
623 629 0 632
0 62f 0 632
331 0 633 334
686 46 :3 0 38
:3 0 39 :3 0 635
636 0 47 :3 0
637 638 0 63a
337 63c 339 63b
63a :2 0 684 48
:3 0 38 :3 0 39
:3 0 63f 640 0
47 :3 0 641 642
0 67c 21 :3 0
22 :3 0 644 645
0 21 :3 0 2e
:3 0 647 648 0
49 :2 0 2 :4 0
79 :2 0 31 :2 0
2f :2 0 33b 64d
64f :3 0 33e 649
651 646 653 652
:2 0 24 :3 0 32
:3 0 655 656 0
26 :4 0 7a :4 0
29 :2 0 2a :3 0
342 65a 65c :3 0
29 :2 0 4c :4 0
345 65e 660 :3 0
29 :2 0 4d :4 0
348 662 664 :3 0
29 :2 0 47 :3 0
34b 666 668 :3 0
29 :2 0 4e :4 0
34e 66a 66c :3 0
29 :2 0 4f :3 0
50 :3 0 2f :2 0
51 :2 0 351 66f
673 355 66e 675
:3 0 358 657 677
:2 0 679 35b 67a
654 679 0 67b
35d 0 67c 35f
67f :3 0 67f 0
67f 67e 67c 67d
:6 0 681 1d :3 0
362 683 364 682
681 :2 0 684 366
:2 0 686 0 686
685 633 684 :6 0
69c 16 :3 0 67
:3 0 9 :3 0 a
:2 0 369 688 68b
45 :2 0 a :2 0
36e 68d 68f :3 0
c :3 0 68 :3 0
3 :3 0 371 692
694 691 695 0
699 69 :4 0 69
1 :8 0 699 373
69a 690 699 0
69b 376 0 69c
378 69e 36 :4 0
69c :4 0 814 6a
:3 0 1c :4 0 6a2
:2 0 6a8 6a0 0
38 :3 0 39 :3 0
6a3 6a4 0 47
:3 0 6a5 6a6 0
6a8 382 6fb 46
:3 0 38 :3 0 39
:3 0 6aa 6ab 0
47 :3 0 6ac 6ad
0 6af 385 6b1
387 6b0 6af :2 0
6f9 48 :3 0 38
:3 0 39 :3 0 6b4
6b5 0 47 :3 0
6b6 6b7 0 6f1
21 :3 0 22 :3 0
6b9 6ba 0 21
:3 0 2e :3 0 6bc
6bd 0 49 :2 0
2 :4 0 7b :2 0
31 :2 0 2f :2 0
389 6c2 6c4 :3 0
38c 6be 6c6 6bb
6c8 6c7 :2 0 24
:3 0 32 :3 0 6ca
6cb 0 26 :4 0
7c :4 0 29 :2 0
2a :3 0 390 6cf
6d1 :3 0 29 :2 0
4c :4 0 393 6d3
6d5 :3 0 29 :2 0
4d :4 0 396 6d7
6d9 :3 0 29 :2 0
47 :3 0 399 6db
6dd :3 0 29 :2 0
4e :4 0 39c 6df
6e1 :3 0 29 :2 0
4f :3 0 50 :3 0
2f :2 0 51 :2 0
39f 6e4 6e8 3a3
6e3 6ea :3 0 3a6
6cc 6ec :2 0 6ee
3a9 6ef 6c9 6ee
0 6f0 3ab 0
6f1 3ad 6f4 :3 0
6f4 0 6f4 6f3
6f1 6f2 :6 0 6f6
1f :3 0 3b0 6f8
3b2 6f7 6f6 :2 0
6f9 3b4 :2 0 6fb
0 6fb 6fa 6a8
6f9 :6 0 814 1
:3 0 35 :3 0 1f
:4 0 700 :2 0 814
6fe 701 :3 0 36
:3 0 1f :3 0 9
:4 0 706 :2 0 7b3
703 704 :3 0 1f
:3 0 37 :3 0 707
708 :3 0 38 :3 0
39 :3 0 70a 70b
0 a :2 0 70c
70d 0 70f 3b7
716 38 :3 0 39
:3 0 710 711 0
3a :2 0 712 713
0 715 3b9 717
709 70f 0 718
0 715 0 718
3bb 0 7b3 38
:3 0 39 :3 0 719
71a 0 38 :3 0
3b :2 0 3c :3 0
71c 71e 0 3c0
71d 720 :3 0 721
:2 0 3d :8 0 725
3c3 726 722 725
0 727 3c5 0
7b3 11 :3 0 40
:3 0 13 :3 0 42
:3 0 58 :3 0 59
:3 0 5a :3 0 59
:3 0 f :3 0 3
:3 0 5b :3 0 5c
:4 0 6d 1 :8 0
74a 37 :4 0 735
:3 0 44 :3 0 45
:2 0 3c9 738 739
:3 0 38 :3 0 39
:3 0 73b 73c 0
a :2 0 73d 73e
0 740 3cc 747
38 :3 0 39 :3 0
741 742 0 3a
:2 0 743 744 0
746 3ce 748 73a
740 0 749 0
746 0 749 3d0
0 74a 3d3 79d
46 :3 0 38 :3 0
39 :3 0 74c 74d
0 47 :3 0 74e
74f 0 751 3d6
753 3d8 752 751
:2 0 79b 48 :3 0
38 :3 0 39 :3 0
756 757 0 47
:3 0 758 759 0
793 21 :3 0 22
:3 0 75b 75c 0
21 :3 0 2e :3 0
75e 75f 0 49
:2 0 2 :4 0 7d
:2 0 31 :2 0 2f
:2 0 3da 764 766
:3 0 3dd 760 768
75d 76a 769 :2 0
24 :3 0 32 :3 0
76c 76d 0 26
:4 0 7e :4 0 29
:2 0 2a :3 0 3e1
771 773 :3 0 29
:2 0 4c :4 0 3e4
775 777 :3 0 29
:2 0 4d :4 0 3e7
779 77b :3 0 29
:2 0 47 :3 0 3ea
77d 77f :3 0 29
:2 0 4e :4 0 3ed
781 783 :3 0 29
:2 0 4f :3 0 50
:3 0 2f :2 0 51
:2 0 3f0 786 78a
3f4 785 78c :3 0
3f7 76e 78e :2 0
790 3fa 791 76b
790 0 792 3fc
0 793 3fe 796
:3 0 796 0 796
795 793 794 :6 0
798 22 :3 0 401
79a 403 799 798
:2 0 79b 405 :2 0
79d 0 79d 79c
74a 79b :6 0 7b3
21 :3 0 67 :3 0
9 :3 0 a :2 0
408 79f 7a2 45
:2 0 a :2 0 40d
7a4 7a6 :3 0 c
:3 0 68 :3 0 3
:3 0 410 7a9 7ab
7a8 7ac 0 7b0
69 :4 0 69 1
:8 0 7b0 412 7b1
7a7 7b0 0 7b2
415 0 7b3 417
7b5 36 :4 0 7b3
:4 0 814 6a :3 0
1f :4 0 7b9 :2 0
7bf 7b7 0 38
:3 0 39 :3 0 7ba
7bb 0 47 :3 0
7bc 7bd 0 7bf
41d 812 46 :3 0
38 :3 0 39 :3 0
7c1 7c2 0 47
:3 0 7c3 7c4 0
7c6 420 7c8 422
7c7 7c6 :2 0 810
48 :3 0 38 :3 0
39 :3 0 7cb 7cc
0 47 :3 0 7cd
7ce 0 808 21
:3 0 22 :3 0 7d0
7d1 0 21 :3 0
2e :3 0 7d3 7d4
0 49 :2 0 2
:4 0 7f :2 0 31
:2 0 2f :2 0 424
7d9 7db :3 0 427
7d5 7dd 7d2 7df
7de :2 0 24 :3 0
32 :3 0 7e1 7e2
0 26 :4 0 80
:4 0 29 :2 0 2a
:3 0 42b 7e6 7e8
:3 0 29 :2 0 4c
:4 0 42e 7ea 7ec
:3 0 29 :2 0 4d
:4 0 431 7ee 7f0
:3 0 29 :2 0 47
:3 0 434 7f2 7f4
:3 0 29 :2 0 4e
:4 0 437 7f6 7f8
:3 0 29 :2 0 4f
:3 0 50 :3 0 2f
:2 0 51 :2 0 43a
7fb 7ff 43e 7fa
801 :3 0 441 7e3
803 :2 0 805 444
806 7e0 805 0
807 446 0 808
448 80b :3 0 80b
0 80b 80a 808
809 :6 0 80d 24
:3 0 44b 80f 44d
80e 80d :2 0 810
44f :2 0 812 0
812 811 7bf 810
:6 0 814 1 :3 0
452 816 dd 47d
0 817 0 814
0 817 459 0
84a 21 :3 0 22
:3 0 818 819 0
21 :3 0 2e :3 0
81b 81c 0 2f
:2 0 2 :4 0 81
:2 0 31 :2 0 2f
:2 0 45c 821 823
:3 0 45f 81d 825
81a 827 826 :2 0
24 :3 0 32 :3 0
829 82a 0 26
:4 0 82 :4 0 29
:2 0 2a :3 0 463
82e 830 :3 0 29
:2 0 4c :4 0 466
832 834 :3 0 29
:2 0 83 :4 0 469
836 838 :3 0 29
:2 0 38 :3 0 39
:3 0 83b 83c 0
46c 83a 83e :3 0
46f 82b 840 :2 0
842 472 843 828
842 0 844 474
0 84a 7 :3 0
38 :3 0 39 :3 0
846 847 0 848
:2 0 84a 476 84d
:3 0 84d 47c 84d
84c 84a 84b :6 0
84e :2 0 2 c
84d 851 :3 0 850
84e 852 :8 0 
484
4
:3 0 1 3 1
8 1 e 1
14 1 1a 1
34 1 4e 1
69 1 84 1
90 1 9c 2
9f a1 2 a4
a6 2 a8 aa
2 ac ae 2
b0 b2 4 98
9e a3 b4 1
b6 1 b8 2
c2 c4 3 c0
c1 c6 2 cf
d1 2 ce d3
1 d5 1 d7
1 d9 2 e5
e6 1 f1 1
f7 2 f9 fa
1 102 2 fe
102 1 107 1
109 1 119 2
118 119 1 121
1 127 2 129
12a 2 116 12b
1 132 1 12d
2 145 147 3
143 144 149 2
152 154 2 156
158 2 15a 15c
2 15e 160 2
162 164 3 169
16a 16b 2 166
16d 2 151 16f
1 171 1 173
2 13c 174 1
178 1 137 2
135 17c 2 187
18a 1 19f 2
19e 19f 1 1a7
1 1ad 2 1af
1b0 2 19c 1b1
1 1b8 1 1b3
2 1cb 1cd 3
1c9 1ca 1cf 2
1d8 1da 2 1dc
1de 2 1e0 1e2
2 1e4 1e6 2
1e8 1ea 3 1ef
1f0 1f1 2 1ec
1f3 2 1d7 1f5
1 1f7 1 1f9
2 1c2 1fa 1
1fe 1 1bd 2
1bb 202 1 213
2 212 213 1
21b 1 221 2
223 224 2 210
225 1 22c 1
227 2 23f 241
3 23d 23e 243
2 24c 24e 2
250 252 2 254
256 2 258 25a
2 25c 25e 3
263 264 265 2
260 267 2 24b
269 1 26b 1
26d 2 236 26e
1 272 1 231
2 22f 276 1
287 2 286 287
1 28f 1 295
2 297 298 2
284 299 1 2a0
1 29b 2 2b3
2b5 3 2b1 2b2
2b7 2 2c0 2c2
2 2c4 2c6 2
2c8 2ca 2 2cc
2ce 2 2d0 2d2
3 2d7 2d8 2d9
2 2d4 2db 2
2bf 2dd 1 2df
1 2e1 2 2aa
2e2 1 2e6 1
2a5 2 2a3 2ea
2 2f0 2f1 1
2f5 2 2f3 2f5
1 2fa 2 2fd
2ff 1 301 a
e7 fb 10a 10d
17f 18d 205 279
2ed 302 2 308
30e 1 315 1
310 2 328 32a
3 326 327 32c
2 335 337 2
339 33b 2 33d
33f 2 341 343
2 345 347 3
34c 34d 34e 2
349 350 2 334
352 1 354 1
356 2 31f 357
1 35b 1 31a
2 318 35f 2
36b 36c 1 377
1 37d 2 37f
380 1 388 2
384 388 1 38d
1 38f 1 3a0
2 39f 3a0 1
3a8 1 3ae 2
3b0 3b1 2 39d
3b2 1 3b9 1
3b4 2 3cc 3ce
3 3ca 3cb 3d0
2 3d9 3db 2
3dd 3df 2 3e1
3e3 2 3e5 3e7
2 3e9 3eb 3
3f0 3f1 3f2 2
3ed 3f4 2 3d8
3f6 1 3f8 1
3fa 2 3c3 3fb
1 3ff 1 3be
2 3bc 403 2
409 40a 1 40e
2 40c 40e 1
413 2 416 418
1 41a 5 36d
381 390 406 41b
2 421 427 1
42e 1 429 2
441 443 3 43f
440 445 2 44e
450 2 452 454
2 456 458 2
45a 45c 2 45e
460 3 465 466
467 2 462 469
2 44d 46b 1
46d 1 46f 2
438 470 1 474
1 433 2 431
478 6 e0 305
362 366 41e 47b
1 48f 1 495
2 497 498 1
4a0 2 49c 4a0
1 4a5 1 4a7
2 4af 4b2 1
4bf 2 4be 4bf
1 4c7 1 4cd
2 4cf 4d0 2
4bc 4d1 1 4d8
1 4d3 2 4eb
4ed 3 4e9 4ea
4ef 2 4f8 4fa
2 4fc 4fe 2
500 502 2 504
506 2 508 50a
3 50f 510 511
2 50c 513 2
4f7 515 1 517
1 519 2 4e2
51a 1 51e 1
4dd 2 4db 522
1 538 2 537
538 1 540 1
546 2 548 549
2 535 54a 1
551 1 54c 2
564 566 3 562
563 568 2 571
573 2 575 577
2 579 57b 2
57d 57f 2 581
583 3 588 589
58a 2 585 58c
2 570 58e 1
590 1 592 2
55b 593 1 597
1 556 2 554
59b 1 5ac 2
5ab 5ac 1 5b4
1 5ba 2 5bc
5bd 2 5a9 5be
1 5c5 1 5c0
2 5d8 5da 3
5d6 5d7 5dc 2
5e5 5e7 2 5e9
5eb 2 5ed 5ef
2 5f1 5f3 2
5f5 5f7 3 5fc
5fd 5fe 2 5f9
600 2 5e4 602
1 604 1 606
2 5cf 607 1
60b 1 5ca 2
5c8 60f 1 620
2 61f 620 1
628 1 62e 2
630 631 2 61d
632 1 639 1
634 2 64c 64e
3 64a 64b 650
2 659 65b 2
65d 65f 2 661
663 2 665 667
2 669 66b 3
670 671 672 2
66d 674 2 658
676 1 678 1
67a 2 643 67b
1 67f 1 63e
2 63c 683 2
689 68a 1 68e
2 68c 68e 1
693 2 696 698
1 69a 9 486
499 4a8 4b5 525
59e 612 686 69b
2 6a1 6a7 1
6ae 1 6a9 2
6c1 6c3 3 6bf
6c0 6c5 2 6ce
6d0 2 6d2 6d4
2 6d6 6d8 2
6da 6dc 2 6de
6e0 3 6e5 6e6
6e7 2 6e2 6e9
2 6cd 6eb 1
6ed 1 6ef 2
6b8 6f0 1 6f4
1 6b3 2 6b1
6f8 1 70e 1
714 2 716 717
1 71f 2 71b
71f 1 724 1
726 1 737 2
736 737 1 73f
1 745 2 747
748 2 734 749
1 750 1 74b
2 763 765 3
761 762 767 2
770 772 2 774
776 2 778 77a
2 77c 77e 2
780 782 3 787
788 789 2 784
78b 2 76f 78d
1 78f 1 791
2 75a 792 1
796 1 755 2
753 79a 2 7a0
7a1 1 7a5 2
7a3 7a5 1 7aa
2 7ad 7af 1
7b1 5 705 718
727 79d 7b2 2
7b8 7be 1 7c5
1 7c0 2 7d8
7da 3 7d6 7d7
7dc 2 7e5 7e7
2 7e9 7eb 2
7ed 7ef 2 7f1
7f3 2 7f5 7f7
3 7fc 7fd 7fe
2 7f9 800 2
7e4 802 1 804
1 806 2 7cf
807 1 80b 1
7ca 2 7c8 80f
6 480 69e 6fb
6ff 7b5 812 2
815 816 2 820
822 3 81e 81f
824 2 82d 82f
2 831 833 2
835 837 2 839
83d 2 82c 83f
1 841 1 843
5 b9 d8 817
844 849 7 12
18 1e 35 4f
6a 85 
1
4
0 
851
0
1
28
25
9
0 1 1 1 1 1 6 7
6 9 6 b 6 d 1 f
1 11 12 1 14 1 16 17
16 19 16 1b 16 1d 1 1f
1 21 22 1 24 0 0 0

21 1 2
3b 1 3
55 1 4
70 1 5
1a 1 0
14 1 0
2 0 1
e 1 0
3 1 0
0

/
SHOW ERRORS FUNCTION FC_MIGRATION;
ALTER FUNCTION FC_MIGRATION COMPILE DEBUG;
/********************************************************************************/
/********************************************************************************************/
Prompt == FUNCTION SP_A_FAV_RES ==
CREATE OR REPLACE FUNCTION SP_A_FAV_RES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
76
2 :e:
1FUNCTION:
1SP_A_FAV_RES:
1P_RES_ID:
1VARCHAR2:
1P_PARENT_ID:
1P_REC_USER:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_RES_ID:
132:
1H_ACTIVE:
11:
1H_REC_USER:
1H_COUNT:
1PLS_INTEGER:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_A_FAV_RES(:
1':
1, :
1);:
1CHECK_TRACE:
122:
1+:
1FPUT:
1               ENTER:: SP_A_FAV_RES(23) :: cplan.sql(25129) :: :
1IS NULL:
18:
127:
1      RETURN_INVALID:: SP_A_FAV_RES(28) :: cplan.sql(25134) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1RESOURCE_ID_REQUIRED:
1NULL:
130:
1                EXIT:: SP_A_FAV_RES(31) :: cplan.sql(25137) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1COUNT:
1FAVORITE_RESOURCES:
1CREATED_BY:
1RESOURCE_ID:
1SELECT COUNT(*):n      INTO h_count:n      FROM FAVORITE_RESOURCES:n      WHE+
1RE CREATED_BY = h_rec_user:n      AND RESOURCE_ID = h_res_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
150:
1           EXCEPTION:: SP_A_FAV_RES(51) :: cplan.sql(25157) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1>:
158:
1        RETURN_ERROR:: SP_A_FAV_RES(59) :: cplan.sql(25165) :: :
1CANNOT_INSERT_RESOURCE:
1 ID:: :
161:
1                EXIT:: SP_A_FAV_RES(62) :: cplan.sql(25168) :: :
1PMO_RETURN_ERROR_SP:
1ACTIVE:
1RESOURCES:
1SELECT ACTIVE:n      INTO h_active:n      FROM RESOURCES:n      WHERE RESOURC+
1E_ID = h_res_id:
181:
1           EXCEPTION:: SP_A_FAV_RES(82) :: cplan.sql(25188) :: :
1=:
1SC_SQL_NO_DATA:
188:
1        RETURN_ERROR:: SP_A_FAV_RES(89) :: cplan.sql(25195) :: :
1RESOURCE_NOT_FOUND:
191:
1                EXIT:: SP_A_FAV_RES(92) :: cplan.sql(25198) :: :
198:
1        RETURN_ERROR:: SP_A_FAV_RES(99) :: cplan.sql(25205) :: :
1RESOURCE_NOT_ACTIVE:
1101:
1                EXIT:: SP_A_FAV_RES(102) :: cplan.sql(25208) :: :
1INSERT INTO FAVORITE_RESOURCES:n      VALUES(h_res_id, h_rec_user, SYSTIMESTA+
1MP):
1FOUND:
1100:
1122:
1           EXCEPTION:: SP_A_FAV_RES(123) :: cplan.sql(25229) :: :
14:
1128:
1       RETURN_STATUS:: SP_A_FAV_RES(129) :: cplan.sql(25235) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1135:
1           EXCEPTION:: SP_A_FAV_RES(136) :: cplan.sql(25242) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1147:
1           EXCEPTION:: SP_A_FAV_RES(148) :: cplan.sql(25254) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
4af
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 51 a5 1c 81
b0 a3 a0 1c 51 81 b0 a3
:2 a0 6b 1c 81 b0 :2 a0 6b :2 a0
6b 6e a5 b a 10 :2 a0 6b
6e :2 a0 6b 6e a5 b 6e 7e
a0 b4 2e 6e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 b7 19 3c a0 7e b4 2e
:2 5a a0 7e b4 2e :2 5a 52 10
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b a0 a5 57 b7
19 3c :2 a0 d :2 a0 d :7 a0 12a
:2 a0 6b a0 d b7 :3 a0 6b a0
d b7 a6 9 a0 53 :2 a0 6b
a0 d :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
7e :2 a0 :2 51 a5 b b4 2e a5
57 b7 19 3c b7 a4 b1 11
4f b7 a6 9 a4 b1 11 4f
:2 a0 51 a5 b 7e 51 b4 2e
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e 6e b4 2e 7e :4 a0
6b a5 b 6e a5 b b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e a0 b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
19 3c :5 a0 12a :2 a0 6b a0 d
b7 :3 a0 6b a0 d b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e :2 a0 :2 51 a5
b b4 2e a5 57 b7 19 3c
b7 a4 b1 11 4f b7 a6 9
a4 b1 11 4f :2 a0 6b a0 7e
a0 6b b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 :2 a0 :2 51 a5
b 7e 6e b4 2e :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c b7
:2 19 3c :4 a0 12a a0 f a0 7e
b4 2e :2 a0 6b 51 d b7 :2 a0
6b 51 d b7 :2 19 3c b7 :3 a0
6b a0 d b7 a6 9 a0 53
:2 a0 6b a0 d :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c b7 a4
b1 11 4f b7 a6 9 a4 b1
11 4f :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e :4 a0 6b a5 b 6e a5 b
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e a0 b4 2e 7e 6e
b4 2e a5 57 b7 19 3c :2 a0
6b :2 a0 6b :2 a0 a5 57 b7 :2 a0
6b :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e a5
57 :2 a0 6b :2 6e 7e :2 a0 6b b4
2e 7e 6e b4 2e 7e :2 a0 6b
b4 2e a5 57 b7 19 3c :9 a0
12a e9 dd :2 a0 65 b7 a6 9
a0 53 :2 a0 6b a0 d :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 :2 a0 6b
:2 6e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c :7 a0 12a e9
dd :2 a0 65 b7 a4 b1 11 4f
b7 a6 9 a4 b1 11 68 4f
1d 17 b5 
4af
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 c0 ae 8d b2
b3 bb ad dc cb cf aa d7
ca fc e7 eb c7 ef f7 e6
103 107 e3 10b 10f 113 116 11b
11c 1 11e 123 127 12b 12e 133
137 13b 13e 143 144 146 14b 14e
152 153 158 15d 160 165 166 16b
16e 172 173 178 17b 180 181 186
189 18e 18f 194 197 19c 19d 1a2
1a5 1a9 1aa 1af 1b2 1b7 1b8 1bd
1c0 1c5 1c6 1cb 1ce 1d3 1d4 1d9
1dc 1e0 1e1 1e6 1e9 1ee 1ef 1f4
1f7 1fc 1fd 202 203 208 20a 20e
211 215 219 21c 220 224 227 22a
22f 232 235 238 239 23e 23f 1
241 246 24a 24e 251 256 25b 25e
262 263 268 269 26e 270 274 277
27b 27e 27f 284 287 28a 28e 291
292 297 29a 1 29d 2a2 2a6 2aa
2ad 2b1 2b5 2b8 2bb 2c0 2c3 2c6
2c9 2ca 2cf 2d0 1 2d2 2d7 2db
2df 2e2 2e7 2ec 2ef 2f3 2f4 2f9
2fc 301 302 307 30a 30f 310 315
318 31c 320 324 328 32b 32c 32e
333 334 336 337 33c 33d 342 344
348 34b 34f 353 356 35a 35e 361
364 369 36c 36f 372 373 378 379
1 37b 380 384 388 38b 390 395
398 39c 39d 3a2 3a3 3a8 3aa 3ae
3b1 3b5 3b9 3bc 3c0 3c4 3c7 3cb
3cc 3d1 3d3 3d7 3da 3de 3e2 3e6
3ea 3ee 3f2 3f6 3fa 3fe 402 406
40a 40e 41a 41e 422 425 429 42d
42f 433 437 43b 43e 442 446 448
449 44e 1 452 456 45a 45d 461
465 469 46d 470 474 478 47b 47e
483 486 489 48c 48d 492 493 1
495 49a 49e 4a2 4a5 4aa 4af 4b2
4b6 4b7 4bc 4bf 4c4 4c5 4ca 4cd
4d2 4d3 4d8 4db 4df 4e0 4e5 4e8
4ed 4ee 4f3 4f6 4fa 4fe 501 504
505 507 508 50d 50e 513 515 519
51c 51e 522 524 530 532 534 535
53a 53e 540 54c 54e 552 556 559
55a 55c 55f 562 563 568 56c 570
573 577 57b 57e 581 586 589 58c
58f 590 595 596 1 598 59d 5a1
5a5 5a8 5ad 5b2 5b5 5b9 5ba 5bf
5c2 5c7 5c8 5cd 5d0 5d5 5d6 5db
5de 5e2 5e6 5ea 5ee 5f1 5f2 5f4
5f9 5fa 5fc 5fd 602 605 60a 60b
610 613 618 619 61e 621 625 626
62b 62e 633 634 639 63a 63f 641
645 648 64c 650 653 657 65b 65e
661 666 669 66c 66f 670 675 676
1 678 67d 681 685 688 68d 692
695 699 69a 69f 6a0 6a5 6a7 6ab
6ae 6b2 6b6 6b9 6bd 6c1 6c4 6c8
6cc 6cd 6d2 6d4 6d8 6db 6df 6e3
6e7 6eb 6ef 6fb 6ff 703 706 70a
70e 710 714 718 71c 71f 723 727
729 72a 72f 1 733 737 73b 73e
742 746 74a 74e 751 755 759 75c
75f 764 767 76a 76d 76e 773 774
1 776 77b 77f 783 786 78b 790
793 797 798 79d 7a0 7a5 7a6 7ab
7ae 7b3 7b4 7b9 7bc 7c0 7c1 7c6
7c9 7ce 7cf 7d4 7d7 7db 7df 7e2
7e5 7e6 7e8 7e9 7ee 7ef 7f4 7f6
7fa 7fd 7ff 803 805 811 813 815
816 81b 81f 821 82d 82f 833 837
83a 83e 841 845 848 849 84e 851
855 859 85c 860 864 867 86a 86f
872 875 878 879 87e 87f 1 881
886 88a 88e 891 896 89b 89e 8a2
8a3 8a8 8ab 8b0 8b1 8b6 8b9 8be
8bf 8c4 8c7 8cb 8cf 8d3 8d7 8da
8db 8dd 8e2 8e3 8e5 8e6 8eb 8ee
8f3 8f4 8f9 8fc 901 902 907 90a
90e 90f 914 917 91c 91d 922 923
928 92a 92e 931 935 939 93c 940
944 947 94a 94f 952 955 958 959
95e 95f 1 961 966 96a 96e 971
976 97b 97e 982 983 988 989 98e
990 994 997 99b 99f 9a2 9a6 9aa
9ad 9b1 9b5 9b6 9bb 9bd 9c1 9c5
9c8 9cb 9cc 9ce 9d1 9d6 9d7 9dc
9e0 9e4 9e7 9eb 9ef 9f2 9f5 9fa
9fd a00 a03 a04 a09 a0a 1 a0c
a11 a15 a19 a1c a21 a26 a29 a2d
a2e a33 a36 a3b a3c a41 a44 a49
a4a a4f a52 a56 a5a a5e a62 a65
a66 a68 a6d a6e a70 a71 a76 a79
a7e a7f a84 a87 a8c a8d a92 a95
a99 a9a a9f aa2 aa7 aa8 aad aae
ab3 ab5 ab9 abc ac0 ac4 ac7 acb
acf ad2 ad5 ada add ae0 ae3 ae4
ae9 aea 1 aec af1 af5 af9 afc
b01 b06 b09 b0d b0e b13 b14 b19
b1b b1f b22 b26 b2a b2d b31 b35
b38 b3c b40 b41 b46 b48 b4c b4f
b51 b55 b59 b5c b60 b64 b68 b6c
b78 b7c b81 b85 b88 b89 b8e b92
b96 b99 b9c ba0 ba2 ba6 baa bad
bb0 bb4 bb6 bba bbe bc1 bc3 bc7
bcb bcf bd2 bd6 bda bdc bdd be2
1 be6 bea bee bf1 bf5 bf9 bfd
c01 c04 c08 c0c c0f c12 c17 c1a
c1d c20 c21 c26 c27 1 c29 c2e
c32 c36 c39 c3e c43 c46 c4a c4b
c50 c53 c58 c59 c5e c61 c66 c67
c6c c6f c73 c74 c79 c7c c81 c82
c87 c8a c8e c92 c95 c98 c99 c9b
c9c ca1 ca2 ca7 ca9 cad cb0 cb2
cb6 cb8 cc4 cc6 cc8 cc9 cce cd2
cd4 ce0 ce2 ce6 cea ced cf1 cf5
cf8 cfb d00 d03 d06 d09 d0a d0f
d10 1 d12 d17 d1b d1f d22 d27
d2c d2f d33 d34 d39 d3c d41 d42
d47 d4a d4f d50 d55 d58 d5c d60
d64 d68 d6b d6c d6e d73 d74 d76
d77 d7c d7f d84 d85 d8a d8d d92
d93 d98 d9b d9f da0 da5 da8 dad
dae db3 db4 db9 dbb dbf dc2 dc6
dca dcd dd1 dd5 dd8 ddc de0 de1
de6 de8 dec df0 df3 df7 dfb dfe
e02 e06 e09 e0c e11 e14 e17 e1a
e1b e20 e21 1 e23 e28 e2c e30
e33 e38 e3d e40 e44 e45 e4a e4b
e50 e54 e58 e5b e60 e65 e68 e6c
e70 e73 e74 e79 e7c e81 e82 e87
e8a e8e e92 e95 e96 e9b e9c ea1
ea3 ea7 eaa eae eb2 eb6 eba ebe
ec2 ec6 eca ece eda edf ee3 ee7
eeb eef ef1 ef2 ef7 1 efb eff
f03 f06 f0a f0e f12 f16 f19 f1d
f21 f24 f27 f2c f2f f32 f35 f36
f3b f3c 1 f3e f43 f47 f4b f4e
f53 f58 f5b f5f f60 f65 f66 f6b
f6f f73 f76 f7b f80 f83 f87 f88
f8d f90 f95 f96 f9b f9e fa2 fa6
fa9 fac fad faf fb0 fb5 fb6 fbb
fbd fc1 fc4 fc8 fcc fd0 fd4 fd8
fdc fe0 fec ff1 ff5 ff9 ffd 1001
1003 1007 1009 1015 1017 1019 101a 101f
1023 1025 1031 1035 1037 1038 1041 
4af
2
0 1 a 6 f :3 6 12 :3 6
11 :2 6 1 3 a 13 a :2 1
4 d 16 15 :2 d :2 4 d 16
15 :2 d :2 4 f 18 17 :2 f :2 4
:2 c 1b c :2 4 e 17 :3 e 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 54 5a 5d
:2 54 6b 81 8 :2 6b d 10 :2 6b
19 1c :2 6b b e :2 6b 13 16
:2 6b 1b 1e :2 6b 2a 2d :2 6b b
e :2 6b 13 16 :2 6b 1b 1e :2 6b
29 2c :2 6b 31 34 :2 6b :2 7 4a
:2 4 7 :2 11 23 :2 2d 39 3c 4c
4e 4f :2 4c :2 23 :3 7 :2 d 12 1e
5d 60 :2 1e :2 7 52 :2 4 :4 9 8
7 :4 21 20 1f :2 7 a :2 14 26
:2 30 3c 3f 4f 51 52 :2 4f :2 26
:3 a :2 10 15 21 60 63 :2 21 70
73 :2 21 77 7a :2 21 84 87 90
98 :2 a1 :2 90 b8 :2 87 :2 21 :2 a 55
:2 7 a :2 14 26 :2 30 3c 3f 4f
51 52 :2 4f :2 26 :3 a :2 10 15 21
60 63 :2 21 :2 a 55 :3 7 :2 12 28
:2 31 47 :2 7 36 :3 4 10 :2 4 12
4 e :2 c d 1a b 19 :2 7
:2 10 1c 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 53 55
56 :2 53 :2 29 :3 d :2 13 18 24 63
66 :2 24 73 76 :2 24 7a 7d :2 24
89 8c :2 24 94 97 :2 24 a3 a6
ad b6 b9 :2 a6 :2 24 :2 d 59 :2 a
:2 7 :4 13 :2 7 4 :3 1 7 10 19
:2 7 1c 1e :2 1c a :2 14 26 :2 30
3c 40 50 52 53 :2 50 :2 26 :3 a
:2 10 15 21 60 63 :2 21 70 73
:2 21 77 7a :2 21 84 87 90 98
:2 a1 :2 90 ba :2 87 :2 21 c2 c5 :2 21
cd d0 :2 21 d5 d8 :2 21 e1 e4
:2 21 :2 a 56 :2 7 a :2 14 26 :2 30
3c 3f 4f 51 52 :2 4f :2 26 :3 a
:2 10 15 21 60 63 :2 21 :2 a 55
:3 7 :2 12 26 :2 2f 47 51 :2 7 20
:2 4 e :2 c d 1b :2 7 :2 10 1c
7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 53 55 56 :2 53
:2 29 :3 d :2 13 18 24 63 66 :2 24
73 76 :2 24 7a 7d :2 24 89 8c
:2 24 94 97 :2 24 a3 a6 ad b6
b9 :2 a6 :2 24 :2 d 59 :2 a :2 7 :4 13
:2 7 4 :3 1 8 :2 11 1c 1a :2 25
:2 1a 7 a :2 14 26 :2 30 3c 40
50 52 53 :2 50 :2 26 :3 a :2 10 15
21 60 63 :2 21 70 73 :2 21 77
7a :2 21 84 87 90 98 :2 a1 :2 90
b6 :2 87 :2 21 be c1 :2 21 c9 cc
:2 21 d1 d4 :2 21 dd e0 :2 21 :2 a
56 :2 7 a :2 14 26 :2 30 3c 3f
4f 51 52 :2 4f :2 26 :3 a :2 10 15
21 60 63 :2 21 :2 a 55 :3 7 :2 12
26 :2 2f 43 4d :2 7 35 a 11
1b 1e :2 a 21 23 :2 21 d :2 17
29 :2 33 3f 43 53 55 56 :2 53
:2 29 :3 d :2 13 18 24 63 66 :2 24
73 76 :2 24 7a 7d :2 24 87 8a
93 9b :2 a4 :2 93 ba :2 8a :2 24 c2
c5 :2 24 cd d0 :2 24 d5 d8 :2 24
e1 e4 :2 24 :2 d 59 :2 a d :2 17
29 :2 33 3f 42 52 55 56 :2 52
:2 29 :3 d :2 13 18 24 64 67 :2 24
:2 d 59 :3 a :2 15 29 :2 32 47 51
:2 a 27 :2 7 :4 4 13 e 18 24
7 e a 16 :3 14 a :2 13 1f
a 1b a :2 13 1f a :4 7 4
c a :2 13 1f a 1a :2 7 :2 c
a :2 13 1f a d :2 17 29 :2 33
3f 43 53 56 57 :2 53 :2 29 :3 d
:2 13 18 24 64 67 :2 24 74 77
:2 24 7b 7e :2 24 8a 8d :2 24 95
98 :2 24 a4 a7 ae b7 ba :2 a7
:2 24 :2 d 5a :2 a :2 7 :4 13 :2 7 4
:3 1 7 :2 11 23 :2 2d 39 3c 4c
4f 50 :2 4c :2 23 :3 7 :2 d 12 1e
5e 61 :2 1e 6e 71 :2 1e 75 78
:2 1e 82 85 8e 96 :2 9f :2 8e aa
:2 85 :2 1e b2 b5 :2 1e bd c0 :2 1e
c5 c8 :2 1e d3 d6 :2 1e :2 7 53
:3 4 :2 f 21 :2 2a 34 40 :2 4 1
9 12 9 a :2 14 26 :2 30 3c
40 50 53 54 :2 50 :2 26 :3 a :2 10
15 21 61 64 :2 21 :3 a :2 10 15
39 5c 5f :2 68 :2 39 76 79 :2 39
81 84 :2 8d :2 39 :2 a 57 :3 7 c
15 1e 2c a 13 1e f e
7 e 7 e 7 29 :2 4 :2 9
7 :2 10 1c :2 7 :2 11 23 :2 2d 39
3d 4d 50 51 :2 4d :2 23 :3 7 :2 d
12 1e 5e 61 :2 1e :3 7 :2 d 12
36 42 45 :2 36 4d 50 :2 36 5c
5f 66 6f 72 :2 5f :2 36 :2 7 54
:2 4 7 c 1b a 13 1e f
e 7 e 7 e 7 :2 4 :4 10
:2 4 :8 1 
4af
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :7 a :6 b
:7 d :b f :11 10 11
:2 10 :2 11 :2 10 :2 11
:2 10 :2 12 :2 10 :2 12
:2 10 :2 12 :2 10 :2 12
:2 10 :2 13 :2 10 :2 13
:2 10 :2 13 :2 10 :2 13
:2 10 :2 13 :4 10 :3 f
:11 16 :b 17 :3 16 :e 1a
:11 1b :20 1c :3 1b :11 1e
:b 1f :3 1e :9 21 :3 1a
:3 23 :3 24 26 27
28 :2 29 :2 2a 26
:5 2b 25 2d :5 2e
:3 2d :2 2f :5 31 :11 32
:24 33 :3 32 :2 30 :6 2f
2c :3 e :9 39 :11 3a
:30 3b :3 3a :11 3d :b 3e
:3 3d :a 40 :3 39 46
47 48 :2 49 46
:5 4a 45 4c :5 4d
:3 4c :2 4e :5 50 :11 51
:24 52 :3 51 :2 4f :6 4e
4b :3 e :a 57 :11 58
:30 59 :3 58 :11 5b :b 5c
:3 5b :a 5e 57 :a 61
:11 62 :30 63 :3 62 :11 65
:b 66 :3 65 :a 68 :3 61
5f :3 57 6d :3 6e
6d :6 6f :5 70 6f
:5 72 71 :3 6f 6c
75 :5 76 :3 75 :2 77
:5 79 :11 7a :24 7b :3 7a
:2 78 :6 77 74 :3 e
:11 80 :30 81 :3 80 :a 83
e :3 86 :11 87 :b 88
:17 89 :3 87 :2 8b :3 8c
:3 8d 8e 8c 8b
8c :3 8f :3 86 :2 90
:5 92 :11 93 :b 94 :18 95
:3 93 :2 97 98 :3 99
9a 98 97 98
:3 9b :2 91 :6 90 85
:7 1 
1043
4
:3 0 1 :3 0 2
:a 0 4aa 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 4aa 2 14
:2 0 d :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 4a8
0 a :6 0 b
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 4a8
0 c :6 0 11
:2 0 17 4 :3 0
15 25 27 :6 0
2a 28 0 4a8
0 e :6 0 32
33 0 19 10
:3 0 2c :7 0 30
2d 2e 4a8 0
f :6 0 38 39
0 1b 8 :3 0
9 :2 0 4 34
:7 0 37 35 0
4a8 0 12 :6 0
13 :3 0 14 :3 0
13 :3 0 15 :3 0
3b 3c 0 2
:4 0 1d 3d 3f
3a 41 40 :2 0
16 :3 0 17 :3 0
43 44 0 18
:4 0 13 :3 0 19
:3 0 47 48 0
2 :4 0 1f 49
4b 1a :4 0 1b
:2 0 1c :3 0 21
4e 50 :3 0 1d
:4 0 1b :2 0 1e
:4 0 24 53 55
:3 0 1b :2 0 3
:3 0 27 57 59
:3 0 1b :2 0 1e
:4 0 2a 5b 5d
:3 0 1b :2 0 1f
:4 0 2d 5f 61
:3 0 1b :2 0 1e
:4 0 30 63 65
:3 0 1b :2 0 5
:3 0 33 67 69
:3 0 1b :2 0 1e
:4 0 36 6b 6d
:3 0 1b :2 0 1f
:4 0 39 6f 71
:3 0 1b :2 0 1e
:4 0 3c 73 75
:3 0 1b :2 0 6
:3 0 3f 77 79
:3 0 1b :2 0 1e
:4 0 42 7b 7d
:3 0 1b :2 0 20
:4 0 45 7f 81
:3 0 48 45 83
:2 0 85 4d 86
42 85 0 87
4f 0 408 13
:3 0 14 :3 0 88
89 0 13 :3 0
21 :3 0 8b 8c
0 d :2 0 2
:4 0 22 :2 0 23
:2 0 d :2 0 51
91 93 :3 0 54
8d 95 8a 97
96 :2 0 16 :3 0
24 :3 0 99 9a
0 18 :4 0 25
:4 0 1b :2 0 1c
:3 0 58 9e a0
:3 0 5b 9b a2
:2 0 a4 5e a5
98 a4 0 a6
60 0 408 3
:3 0 26 :2 0 62
a8 a9 :3 0 aa
:2 0 ab :2 0 6
:3 0 26 :2 0 64
ae af :3 0 b0
:2 0 b1 :2 0 ac
b3 b2 :2 0 13
:3 0 14 :3 0 b5
b6 0 13 :3 0
21 :3 0 b8 b9
0 27 :2 0 2
:4 0 28 :2 0 23
:2 0 d :2 0 66
be c0 :3 0 69
ba c2 b7 c4
c3 :2 0 16 :3 0
24 :3 0 c6 c7
0 18 :4 0 29
:4 0 1b :2 0 1c
:3 0 6d cb cd
:3 0 1b :2 0 2a
:4 0 70 cf d1
:3 0 1b :2 0 2b
:4 0 73 d3 d5
:3 0 1b :2 0 2c
:3 0 2d :3 0 2e
:3 0 2f :3 0 da
db 0 76 d9
dd 30 :4 0 78
d8 e0 7b d7
e2 :3 0 7e c8
e4 :2 0 e6 81
e7 c5 e6 0
e8 83 0 111
13 :3 0 14 :3 0
e9 ea 0 13
:3 0 21 :3 0 ec
ed 0 d :2 0
2 :4 0 31 :2 0
23 :2 0 d :2 0
85 f2 f4 :3 0
88 ee f6 eb
f8 f7 :2 0 16
:3 0 24 :3 0 fa
fb 0 18 :4 0
32 :4 0 1b :2 0
1c :3 0 8c ff
101 :3 0 8f fc
103 :2 0 105 92
106 f9 105 0
107 94 0 111
33 :3 0 34 :3 0
108 109 0 2e
:3 0 2f :3 0 10b
10c 0 35 :3 0
96 10a 10f :2 0
111 99 112 b4
111 0 113 9d
0 408 a :3 0
3 :3 0 114 115
0 408 e :3 0
6 :3 0 117 118
0 408 36 :3 0
f :3 0 37 :3 0
38 :3 0 e :3 0
39 :3 0 a :4 0
3a 1 :8 0 127
8 :3 0 3b :3 0
122 123 0 3c
:3 0 124 125 0
127 9f 17a 3d
:3 0 8 :3 0 3b
:3 0 129 12a 0
3c :3 0 12b 12c
0 12e a2 130
a4 12f 12e :2 0
178 3e :3 0 8
:3 0 3b :3 0 133
134 0 3c :3 0
135 136 0 170
13 :3 0 14 :3 0
138 139 0 13
:3 0 21 :3 0 13b
13c 0 3f :2 0
2 :4 0 40 :2 0
23 :2 0 d :2 0
a6 141 143 :3 0
a9 13d 145 13a
147 146 :2 0 16
:3 0 24 :3 0 149
14a 0 18 :4 0
41 :4 0 1b :2 0
1c :3 0 ad 14e
150 :3 0 1b :2 0
2a :4 0 b0 152
154 :3 0 1b :2 0
42 :4 0 b3 156
158 :3 0 1b :2 0
3c :3 0 b6 15a
15c :3 0 1b :2 0
43 :4 0 b9 15e
160 :3 0 1b :2 0
44 :3 0 45 :3 0
d :2 0 46 :2 0
bc 163 167 c0
162 169 :3 0 c3
14b 16b :2 0 16d
c6 16e 148 16d
0 16f c8 0
170 ca 173 :3 0
173 0 173 172
170 171 :6 0 175
2 :3 0 cd 177
cf 176 175 :2 0
178 d1 :2 0 17a
0 17a 179 127
178 :6 0 408 1
:3 0 2c :3 0 f
:3 0 11 :2 0 d4
17c 17f 47 :2 0
11 :2 0 d9 181
183 :3 0 13 :3 0
14 :3 0 185 186
0 13 :3 0 21
:3 0 188 189 0
b :2 0 2 :4 0
48 :2 0 23 :2 0
d :2 0 dc 18e
190 :3 0 df 18a
192 187 194 193
:2 0 16 :3 0 24
:3 0 196 197 0
18 :4 0 49 :4 0
1b :2 0 1c :3 0
e3 19b 19d :3 0
1b :2 0 2a :4 0
e6 19f 1a1 :3 0
1b :2 0 2b :4 0
e9 1a3 1a5 :3 0
1b :2 0 2c :3 0
2d :3 0 2e :3 0
4a :3 0 1aa 1ab
0 ec 1a9 1ad
30 :4 0 ee 1a8
1b0 f1 1a7 1b2
:3 0 1b :2 0 4b
:4 0 f4 1b4 1b6
:3 0 1b :2 0 1e
:4 0 f7 1b8 1ba
:3 0 1b :2 0 a
:3 0 fa 1bc 1be
:3 0 1b :2 0 1e
:4 0 fd 1c0 1c2
:3 0 100 198 1c4
:2 0 1c6 103 1c7
195 1c6 0 1c8
105 0 1f2 13
:3 0 14 :3 0 1c9
1ca 0 13 :3 0
21 :3 0 1cc 1cd
0 d :2 0 2
:4 0 4c :2 0 23
:2 0 d :2 0 107
1d2 1d4 :3 0 10a
1ce 1d6 1cb 1d8
1d7 :2 0 16 :3 0
24 :3 0 1da 1db
0 18 :4 0 4d
:4 0 1b :2 0 1c
:3 0 10e 1df 1e1
:3 0 111 1dc 1e3
:2 0 1e5 114 1e6
1d9 1e5 0 1e7
116 0 1f2 33
:3 0 4e :3 0 1e8
1e9 0 2e :3 0
4a :3 0 1eb 1ec
0 a :3 0 35
:3 0 118 1ea 1f0
:2 0 1f2 11c 1f3
184 1f2 0 1f4
120 0 408 4f
:3 0 c :3 0 50
:3 0 39 :3 0 a
:4 0 51 1 :8 0
200 8 :3 0 3b
:3 0 1fb 1fc 0
3c :3 0 1fd 1fe
0 200 122 253
3d :3 0 8 :3 0
3b :3 0 202 203
0 3c :3 0 204
205 0 207 125
209 127 208 207
:2 0 251 3e :3 0
8 :3 0 3b :3 0
20c 20d 0 3c
:3 0 20e 20f 0
249 13 :3 0 14
:3 0 211 212 0
13 :3 0 21 :3 0
214 215 0 3f
:2 0 2 :4 0 52
:2 0 23 :2 0 d
:2 0 129 21a 21c
:3 0 12c 216 21e
213 220 21f :2 0
16 :3 0 24 :3 0
222 223 0 18
:4 0 53 :4 0 1b
:2 0 1c :3 0 130
227 229 :3 0 1b
:2 0 2a :4 0 133
22b 22d :3 0 1b
:2 0 42 :4 0 136
22f 231 :3 0 1b
:2 0 3c :3 0 139
233 235 :3 0 1b
:2 0 43 :4 0 13c
237 239 :3 0 1b
:2 0 44 :3 0 45
:3 0 d :2 0 46
:2 0 13f 23c 240
143 23b 242 :3 0
146 224 244 :2 0
246 149 247 221
246 0 248 14b
0 249 14d 24c
:3 0 24c 0 24c
24b 249 24a :6 0
24e 4 :3 0 150
250 152 24f 24e
:2 0 251 154 :2 0
253 0 253 252
200 251 :6 0 408
1 :3 0 8 :3 0
3b :3 0 255 256
0 8 :3 0 54
:2 0 55 :3 0 258
25a 0 159 259
25c :3 0 25d :2 0
13 :3 0 14 :3 0
25f 260 0 13
:3 0 21 :3 0 262
263 0 b :2 0
2 :4 0 56 :2 0
23 :2 0 d :2 0
15c 268 26a :3 0
15f 264 26c 261
26e 26d :2 0 16
:3 0 24 :3 0 270
271 0 18 :4 0
57 :4 0 1b :2 0
1c :3 0 163 275
277 :3 0 1b :2 0
2a :4 0 166 279
27b :3 0 1b :2 0
2b :4 0 169 27d
27f :3 0 1b :2 0
2c :3 0 2d :3 0
2e :3 0 58 :3 0
284 285 0 16c
283 287 30 :4 0
16e 282 28a 171
281 28c :3 0 1b
:2 0 4b :4 0 174
28e 290 :3 0 1b
:2 0 1e :4 0 177
292 294 :3 0 1b
:2 0 a :3 0 17a
296 298 :3 0 1b
:2 0 1e :4 0 17d
29a 29c :3 0 180
272 29e :2 0 2a0
183 2a1 26f 2a0
0 2a2 185 0
2cc 13 :3 0 14
:3 0 2a3 2a4 0
13 :3 0 21 :3 0
2a6 2a7 0 d
:2 0 2 :4 0 59
:2 0 23 :2 0 d
:2 0 187 2ac 2ae
:3 0 18a 2a8 2b0
2a5 2b2 2b1 :2 0
16 :3 0 24 :3 0
2b4 2b5 0 18
:4 0 5a :4 0 1b
:2 0 1c :3 0 18e
2b9 2bb :3 0 191
2b6 2bd :2 0 2bf
194 2c0 2b3 2bf
0 2c1 196 0
2cc 33 :3 0 4e
:3 0 2c2 2c3 0
2e :3 0 58 :3 0
2c5 2c6 0 a
:3 0 35 :3 0 198
2c4 2ca :2 0 2cc
19c 348 44 :3 0
c :3 0 d :2 0
d :2 0 1a0 2cd
2d1 54 :2 0 11
:4 0 1a6 2d3 2d5
:3 0 13 :3 0 14
:3 0 2d7 2d8 0
13 :3 0 21 :3 0
2da 2db 0 b
:2 0 2 :4 0 5b
:2 0 23 :2 0 d
:2 0 1a9 2e0 2e2
:3 0 1ac 2dc 2e4
2d9 2e6 2e5 :2 0
16 :3 0 24 :3 0
2e8 2e9 0 18
:4 0 5c :4 0 1b
:2 0 1c :3 0 1b0
2ed 2ef :3 0 1b
:2 0 2a :4 0 1b3
2f1 2f3 :3 0 1b
:2 0 2b :4 0 1b6
2f5 2f7 :3 0 1b
:2 0 2c :3 0 2d
:3 0 2e :3 0 5d
:3 0 2fc 2fd 0
1b9 2fb 2ff 30
:4 0 1bb 2fa 302
1be 2f9 304 :3 0
1b :2 0 4b :4 0
1c1 306 308 :3 0
1b :2 0 1e :4 0
1c4 30a 30c :3 0
1b :2 0 a :3 0
1c7 30e 310 :3 0
1b :2 0 1e :4 0
1ca 312 314 :3 0
1cd 2ea 316 :2 0
318 1d0 319 2e7
318 0 31a 1d2
0 344 13 :3 0
14 :3 0 31b 31c
0 13 :3 0 21
:3 0 31e 31f 0
d :2 0 2 :4 0
5e :2 0 23 :2 0
d :2 0 1d4 324
326 :3 0 1d7 320
328 31d 32a 329
:2 0 16 :3 0 24
:3 0 32c 32d 0
18 :4 0 5f :4 0
1b :2 0 1c :3 0
1db 331 333 :3 0
1de 32e 335 :2 0
337 1e1 338 32b
337 0 339 1e3
0 344 33 :3 0
4e :3 0 33a 33b
0 2e :3 0 5d
:3 0 33d 33e 0
a :3 0 35 :3 0
1e5 33c 342 :2 0
344 1e9 345 2d6
344 0 346 1ed
0 347 1ef 349
25e 2cc 0 34a
0 347 0 34a
1f1 0 408 37
:3 0 a :3 0 e
:3 0 1c :4 0 60
1 :8 0 365 61
:4 0 350 :3 0 35
:3 0 54 :2 0 1f6
353 354 :3 0 8
:3 0 3b :3 0 356
357 0 11 :2 0
358 359 0 35b
1f9 362 8 :3 0
3b :3 0 35c 35d
0 62 :2 0 35e
35f 0 361 1fb
363 355 35b 0
364 0 361 0
364 1fd 0 365
200 3b8 3d :3 0
8 :3 0 3b :3 0
367 368 0 3c
:3 0 369 36a 0
36c 203 36e 205
36d 36c :2 0 3b6
3e :3 0 8 :3 0
3b :3 0 371 372
0 3c :3 0 373
374 0 3ae 13
:3 0 14 :3 0 376
377 0 13 :3 0
21 :3 0 379 37a
0 3f :2 0 2
:4 0 63 :2 0 23
:2 0 d :2 0 207
37f 381 :3 0 20a
37b 383 378 385
384 :2 0 16 :3 0
24 :3 0 387 388
0 18 :4 0 64
:4 0 1b :2 0 1c
:3 0 20e 38c 38e
:3 0 1b :2 0 2a
:4 0 211 390 392
:3 0 1b :2 0 42
:4 0 214 394 396
:3 0 1b :2 0 3c
:3 0 217 398 39a
:3 0 1b :2 0 43
:4 0 21a 39c 39e
:3 0 1b :2 0 44
:3 0 45 :3 0 d
:2 0 46 :2 0 21d
3a1 3a5 221 3a0
3a7 :3 0 224 389
3a9 :2 0 3ab 227
3ac 386 3ab 0
3ad 229 0 3ae
22b 3b1 :3 0 3b1
0 3b1 3b0 3ae
3af :6 0 3b3 6
:3 0 22e 3b5 230
3b4 3b3 :2 0 3b6
232 :2 0 3b8 0
3b8 3b7 365 3b6
:6 0 408 1 :3 0
13 :3 0 14 :3 0
3ba 3bb 0 13
:3 0 21 :3 0 3bd
3be 0 65 :2 0
2 :4 0 66 :2 0
23 :2 0 d :2 0
235 3c3 3c5 :3 0
238 3bf 3c7 3bc
3c9 3c8 :2 0 16
:3 0 24 :3 0 3cb
3cc 0 18 :4 0
67 :4 0 1b :2 0
1c :3 0 23c 3d0
3d2 :3 0 1b :2 0
2a :4 0 23f 3d4
3d6 :3 0 1b :2 0
2b :4 0 242 3d8
3da :3 0 1b :2 0
2c :3 0 2d :3 0
8 :3 0 3b :3 0
3df 3e0 0 245
3de 3e2 30 :4 0
247 3dd 3e5 24a
3dc 3e7 :3 0 1b
:2 0 4b :4 0 24d
3e9 3eb :3 0 1b
:2 0 1e :4 0 250
3ed 3ef :3 0 1b
:2 0 e :3 0 253
3f1 3f3 :3 0 1b
:2 0 1e :4 0 256
3f5 3f7 :3 0 259
3cd 3f9 :2 0 3fb
25c 3fc 3ca 3fb
0 3fd 25e 0
408 33 :3 0 68
:3 0 3fe 3ff 0
8 :3 0 3b :3 0
401 402 0 e
:3 0 35 :3 0 260
400 406 :2 0 408
264 4a9 8 :3 0
69 :2 0 4 409
40a 0 13 :3 0
14 :3 0 40c 40d
0 13 :3 0 21
:3 0 40f 410 0
3f :2 0 2 :4 0
6a :2 0 23 :2 0
d :2 0 271 415
417 :3 0 274 411
419 40e 41b 41a
:2 0 16 :3 0 24
:3 0 41d 41e 0
18 :4 0 6b :4 0
1b :2 0 1c :3 0
278 422 424 :3 0
27b 41f 426 :2 0
43f 16 :3 0 24
:3 0 428 429 0
18 :4 0 6c :4 0
1b :2 0 8 :3 0
6d :3 0 42e 42f
0 27e 42d 431
:3 0 1b :2 0 4b
:4 0 281 433 435
:3 0 1b :2 0 8
:3 0 6e :3 0 438
439 0 284 437
43b :3 0 287 42a
43d :2 0 43f 28a
440 41c 43f 0
441 28d 0 451
6f :3 0 12 :3 0
8 :3 0 6d :3 0
70 :3 0 8 :3 0
6e :3 0 71 :3 0
72 :4 0 73 1
:a 0 44d :2 0 451
443 44b :2 0 7
:3 0 12 :3 0 44f
:2 0 451 28f 453
293 452 451 :2 0
4a7 3e :3 0 8
:3 0 3b :3 0 456
457 0 3c :3 0
458 459 0 49f
13 :3 0 14 :3 0
45b 45c 0 13
:3 0 21 :3 0 45e
45f 0 3f :2 0
2 :4 0 74 :2 0
23 :2 0 d :2 0
295 464 466 :3 0
298 460 468 45d
46a 469 :2 0 16
:3 0 24 :3 0 46c
46d 0 18 :4 0
75 :4 0 1b :2 0
1c :3 0 29c 471
473 :3 0 29f 46e
475 :2 0 48f 16
:3 0 24 :3 0 477
478 0 18 :4 0
42 :4 0 1b :2 0
3c :3 0 2a2 47c
47e :3 0 1b :2 0
43 :4 0 2a5 480
482 :3 0 1b :2 0
44 :3 0 45 :3 0
d :2 0 46 :2 0
2a8 485 489 2ac
484 48b :3 0 2af
479 48d :2 0 48f
2b2 490 46b 48f
0 491 2b5 0
49f 6f :3 0 12
:3 0 70 :3 0 8
:3 0 6e :3 0 71
:3 0 72 :4 0 76
1 :a 0 49b :2 0
49f 493 499 :2 0
7 :3 0 12 :3 0
49d :2 0 49f 2b7
4a2 :3 0 4a2 0
4a2 4a1 49f 4a0
:6 0 4a4 1 :3 0
2bc 4a6 2be 4a5
4a4 :2 0 4a7 2c0
:2 0 4a9 2c3 4a9
4a8 408 4a7 :6 0
4aa :2 0 2 14
4a9 4ad :3 0 4ac
4aa 4ae :8 0 
2c9
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
26 1 24 1
2b 1 31 1
3e 1 4a 2
4d 4f 2 52
54 2 56 58
2 5a 5c 2
5e 60 2 62
64 2 66 68
2 6a 6c 2
6e 70 2 72
74 2 76 78
2 7a 7c 2
7e 80 4 46
4c 51 82 1
84 1 86 2
90 92 3 8e
8f 94 2 9d
9f 2 9c a1
1 a3 1 a5
1 a7 1 ad
2 bd bf 3
bb bc c1 2
ca cc 2 ce
d0 2 d2 d4
1 dc 2 de
df 2 d6 e1
2 c9 e3 1
e5 1 e7 2
f1 f3 3 ef
f0 f5 2 fe
100 2 fd 102
1 104 1 106
2 10d 10e 3
e8 107 110 1
112 2 121 126
1 12d 1 128
2 140 142 3
13e 13f 144 2
14d 14f 2 151
153 2 155 157
2 159 15b 2
15d 15f 3 164
165 166 2 161
168 2 14c 16a
1 16c 1 16e
2 137 16f 1
173 1 132 2
130 177 2 17d
17e 1 182 2
180 182 2 18d
18f 3 18b 18c
191 2 19a 19c
2 19e 1a0 2
1a2 1a4 1 1ac
2 1ae 1af 2
1a6 1b1 2 1b3
1b5 2 1b7 1b9
2 1bb 1bd 2
1bf 1c1 2 199
1c3 1 1c5 1
1c7 2 1d1 1d3
3 1cf 1d0 1d5
2 1de 1e0 2
1dd 1e2 1 1e4
1 1e6 3 1ed
1ee 1ef 3 1c8
1e7 1f1 1 1f3
2 1fa 1ff 1
206 1 201 2
219 21b 3 217
218 21d 2 226
228 2 22a 22c
2 22e 230 2
232 234 2 236
238 3 23d 23e
23f 2 23a 241
2 225 243 1
245 1 247 2
210 248 1 24c
1 20b 2 209
250 1 25b 2
257 25b 2 267
269 3 265 266
26b 2 274 276
2 278 27a 2
27c 27e 1 286
2 288 289 2
280 28b 2 28d
28f 2 291 293
2 295 297 2
299 29b 2 273
29d 1 29f 1
2a1 2 2ab 2ad
3 2a9 2aa 2af
2 2b8 2ba 2
2b7 2bc 1 2be
1 2c0 3 2c7
2c8 2c9 3 2a2
2c1 2cb 3 2ce
2cf 2d0 1 2d4
2 2d2 2d4 2
2df 2e1 3 2dd
2de 2e3 2 2ec
2ee 2 2f0 2f2
2 2f4 2f6 1
2fe 2 300 301
2 2f8 303 2
305 307 2 309
30b 2 30d 30f
2 311 313 2
2eb 315 1 317
1 319 2 323
325 3 321 322
327 2 330 332
2 32f 334 1
336 1 338 3
33f 340 341 3
31a 339 343 1
345 1 346 2
348 349 1 352
2 351 352 1
35a 1 360 2
362 363 2 34f
364 1 36b 1
366 2 37e 380
3 37c 37d 382
2 38b 38d 2
38f 391 2 393
395 2 397 399
2 39b 39d 3
3a2 3a3 3a4 2
39f 3a6 2 38a
3a8 1 3aa 1
3ac 2 375 3ad
1 3b1 1 370
2 36e 3b5 2
3c2 3c4 3 3c0
3c1 3c6 2 3cf
3d1 2 3d3 3d5
2 3d7 3d9 1
3e1 2 3e3 3e4
2 3db 3e6 2
3e8 3ea 2 3ec
3ee 2 3f0 3f2
2 3f4 3f6 2
3ce 3f8 1 3fa
1 3fc 3 403
404 405 c 87
a6 113 116 119
17a 1f4 253 34a
3b8 3fd 407 2
414 416 3 412
413 418 2 421
423 2 420 425
2 42c 430 2
432 434 2 436
43a 2 42b 43c
2 427 43e 1
440 3 441 44c
450 1 40b 2
463 465 3 461
462 467 2 470
472 2 46f 474
2 47b 47d 2
47f 481 3 486
487 488 2 483
48a 2 47a 48c
2 476 48e 1
490 4 45a 491
49a 49e 1 4a2
1 455 2 453
4a6 5 1b 22
29 2f 36 
1
4
0 
4ad
0
1
14
8
9
0 1 2 1 4 1 6 1
0 0 0 0 0 0 0 0
0 0 0 0 
3 1 0
7 1 0
2b 1 0
1d 1 0
16 1 0
b 1 0
2 0 1
24 1 0
31 1 0
0

/
SHOW ERRORS FUNCTION SP_A_FAV_RES;
ALTER FUNCTION SP_A_FAV_RES COMPILE DEBUG;
/************************************************************************************/
/********************************************************************************************/
Prompt == FUNCTION SP_UA_FAV_RES ==
CREATE OR REPLACE FUNCTION SP_UA_FAV_RES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
62
2 :e:
1FUNCTION:
1SP_UA_FAV_RES:
1P_RES_ID:
1VARCHAR2:
1P_PARENT_ID:
1P_REC_USER:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_RES_ID:
132:
1H_REC_USER:
1H_COUNT:
1PLS_INTEGER:
10:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_UA_FAV_RES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
121:
1+:
1FPUT:
1               ENTER:: SP_UA_FAV_RES(22) :: cplan.sql(25312) :: :
1IS NULL:
18:
126:
1      RETURN_INVALID:: SP_UA_FAV_RES(27) :: cplan.sql(25317) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
129:
1                EXIT:: SP_UA_FAV_RES(30) :: cplan.sql(25320) :: :
1PMODEFINES:
1PMO_RETURN_INVALID_SP:
1TRUE:
1COUNT:
1FAVORITE_RESOURCES:
1CREATED_BY:
1RESOURCE_ID:
1SELECT COUNT(*):n      INTO h_count:n      FROM FAVORITE_RESOURCES:n      WHE+
1RE CREATED_BY = h_rec_user:n      AND RESOURCE_ID = h_res_id:
1SC_STATE:
1SQLCODE:
1NO_DATA_FOUND:
1OTHERS:
116:
149:
1           EXCEPTION:: SP_UA_FAV_RES(50) :: cplan.sql(25340) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1=:
156:
1      RETURN_INVALID:: SP_UA_FAV_RES(57) :: cplan.sql(25347) :: :
159:
1                EXIT:: SP_UA_FAV_RES(60) :: cplan.sql(25350) :: :
1DELETE FROM FAVORITE_RESOURCES:n      WHERE CREATED_BY = h_rec_user:n      AN+
1D RESOURCE_ID = h_res_id:
1FOUND:
1100:
179:
1           EXCEPTION:: SP_UA_FAV_RES(80) :: cplan.sql(25370) :: :
14:
185:
1       RETURN_STATUS:: SP_UA_FAV_RES(86) :: cplan.sql(25376) :: :
1 ID:: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
192:
1           EXCEPTION:: SP_UA_FAV_RES(93) :: cplan.sql(25383) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1OPEN:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1104:
1           EXCEPTION:: SP_UA_FAV_RES(105) :: cplan.sql(25395) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
340
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d 8f a0 b0 3d b4
:3 a0 6b 2c 6a a3 a0 51 a5
1c 81 b0 a3 a0 51 a5 1c
81 b0 a3 a0 1c 51 81 b0
a3 :2 a0 6b 1c 81 b0 :2 a0 6b
:2 a0 6b 6e a5 b a 10 :2 a0
6b 6e :2 a0 6b 6e a5 b 6e
7e a0 b4 2e 6e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c a0 7e b4
2e 5a a0 7e b4 2e 5a 52
10 :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :2 a0 d :2 a0 d :7 a0
12a :2 a0 6b a0 d b7 :3 a0 6b
a0 d b7 a6 9 a0 53 :2 a0
6b a0 d :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e a0 b4 2e 7e 6e b4
2e 7e :2 a0 :2 51 a5 b b4 2e
a5 57 b7 19 3c b7 a4 b1
11 4f b7 a6 9 a4 b1 11
4f :2 a0 51 a5 b 7e 51 b4
2e :2 a0 6b :2 a0 6b 51 6e 51
7e 51 b4 2e a5 b a 10
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e 6e b4 2e 7e
:4 a0 6b a5 b 6e a5 b b4
2e a5 57 b7 19 3c :2 a0 6b
:2 a0 6b 51 6e 51 7e 51 b4
2e a5 b a 10 :2 a0 6b :2 6e
7e a0 b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b a0 a5 57
b7 19 3c :5 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e 7e 6e b4 2e 7e 6e b4
2e 7e :4 a0 6b a5 b 6e a5
b b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e a5 57 b7 19 3c
:2 a0 6b :2 a0 6b :2 a0 a5 57 b7
:2 a0 6b :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 :2 a0 6b :2 6e 7e :2 a0 6b
b4 2e 7e 6e b4 2e 7e :2 a0
6b b4 2e a5 57 b7 19 3c
:9 a0 12a e9 dd :2 a0 65 b7 a6
9 a0 53 :2 a0 6b a0 d :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 :2 a0
6b :2 6e 7e a0 b4 2e 7e 6e
b4 2e 7e :2 a0 :2 51 a5 b b4
2e a5 57 b7 19 3c :7 a0 12a
e9 dd :2 a0 65 b7 a4 b1 11
4f b7 a6 9 a4 b1 11 68
4f 1d 17 b5 
340
2
0 3 7 23 1f 1e 2b 38
34 1b 40 49 45 33 51 30
56 5a 5e 62 65 69 86 71
75 78 79 81 70 a3 91 6d
95 96 9e 90 bf ae b2 8d
ba ad df ca ce aa d2 da
c9 e6 ea c6 ee f2 f6 f9
fe ff 1 101 106 10a 10e 111
116 11a 11e 121 126 127 129 12e
131 135 136 13b 140 143 148 149
14e 151 155 156 15b 15e 163 164
169 16c 171 172 177 17a 17f 180
185 188 18c 18d 192 195 19a 19b
1a0 1a3 1a8 1a9 1ae 1b1 1b6 1b7
1bc 1bf 1c3 1c4 1c9 1cc 1d1 1d2
1d7 1da 1df 1e0 1e5 1e6 1eb 1ed
1f1 1f4 1f8 1fc 1ff 203 207 20a
20d 212 215 218 21b 21c 221 222
1 224 229 22d 231 234 239 23e
241 245 246 24b 24c 251 253 257
25a 25e 261 262 267 26a 26e 271
272 277 1 27a 27f 283 287 28a
28e 292 295 298 29d 2a0 2a3 2a6
2a7 2ac 2ad 1 2af 2b4 2b8 2bc
2bf 2c4 2c9 2cc 2d0 2d1 2d6 2d9
2de 2df 2e4 2e7 2ec 2ed 2f2 2f5
2f9 2fd 301 305 308 309 30b 310
311 313 314 319 31a 31f 321 325
328 32c 330 333 337 33b 33e 341
346 349 34c 34f 350 355 356 1
358 35d 361 365 368 36d 372 375
379 37a 37f 380 385 387 38b 38e
392 396 399 39d 3a1 3a4 3a8 3a9
3ae 3b0 3b4 3b7 3bb 3bf 3c3 3c7
3cb 3cf 3d3 3d7 3db 3df 3e3 3e7
3eb 3f7 3fb 3ff 402 406 40a 40c
410 414 418 41b 41f 423 425 426
42b 1 42f 433 437 43a 43e 442
446 44a 44d 451 455 458 45b 460
463 466 469 46a 46f 470 1 472
477 47b 47f 482 487 48c 48f 493
494 499 49c 4a1 4a2 4a7 4aa 4af
4b0 4b5 4b8 4bc 4bd 4c2 4c5 4ca
4cb 4d0 4d3 4d7 4db 4de 4e1 4e2
4e4 4e5 4ea 4eb 4f0 4f2 4f6 4f9
4fb 4ff 501 50d 50f 511 512 517
51b 51d 529 52b 52f 533 536 537
539 53c 53f 540 545 549 54d 550
554 558 55b 55e 563 566 569 56c
56d 572 573 1 575 57a 57e 582
585 58a 58f 592 596 597 59c 59f
5a4 5a5 5aa 5ad 5b2 5b3 5b8 5bb
5bf 5c3 5c7 5cb 5ce 5cf 5d1 5d6
5d7 5d9 5da 5df 5e0 5e5 5e7 5eb
5ee 5f2 5f6 5f9 5fd 601 604 607
60c 60f 612 615 616 61b 61c 1
61e 623 627 62b 62e 633 638 63b
63f 640 645 646 64b 64d 651 654
658 65c 65f 663 667 66a 66e 66f
674 676 67a 67d 681 685 689 68d
691 69d 6a1 6a6 6aa 6ad 6ae 6b3
6b7 6bb 6be 6c1 6c5 6c7 6cb 6cf
6d2 6d5 6d9 6db 6df 6e3 6e6 6e8
6ec 6f0 6f4 6f7 6fb 6ff 701 702
707 1 70b 70f 713 716 71a 71e
722 726 729 72d 731 734 737 73c
73f 742 745 746 74b 74c 1 74e
753 757 75b 75e 763 768 76b 76f
770 775 778 77d 77e 783 786 78b
78c 791 794 798 799 79e 7a1 7a6
7a7 7ac 7af 7b3 7b7 7ba 7bd 7be
7c0 7c1 7c6 7c7 7cc 7ce 7d2 7d5
7d7 7db 7dd 7e9 7eb 7ed 7ee 7f3
7f7 7f9 805 807 80b 80f 812 816
81a 81d 820 825 828 82b 82e 82f
834 835 1 837 83c 840 844 847
84c 851 854 858 859 85e 861 866
867 86c 86f 874 875 87a 87d 881
885 889 88d 890 891 893 898 899
89b 89c 8a1 8a4 8a9 8aa 8af 8b2
8b7 8b8 8bd 8c0 8c4 8c5 8ca 8cd
8d2 8d3 8d8 8d9 8de 8e0 8e4 8e7
8eb 8ef 8f2 8f6 8fa 8fd 901 905
906 90b 90d 911 915 918 91c 920
923 927 92b 92e 931 936 939 93c
93f 940 945 946 1 948 94d 951
955 958 95d 962 965 969 96a 96f
970 975 979 97d 980 985 98a 98d
991 995 998 999 99e 9a1 9a6 9a7
9ac 9af 9b3 9b7 9ba 9bb 9c0 9c1
9c6 9c8 9cc 9cf 9d3 9d7 9db 9df
9e3 9e7 9eb 9ef 9f3 9ff a04 a08
a0c a10 a14 a16 a17 a1c 1 a20
a24 a28 a2b a2f a33 a37 a3b a3e
a42 a46 a49 a4c a51 a54 a57 a5a
a5b a60 a61 1 a63 a68 a6c a70
a73 a78 a7d a80 a84 a85 a8a a8b
a90 a94 a98 a9b aa0 aa5 aa8 aac
aad ab2 ab5 aba abb ac0 ac3 ac7
acb ace ad1 ad2 ad4 ad5 ada adb
ae0 ae2 ae6 ae9 aed af1 af5 af9
afd b01 b05 b11 b16 b1a b1e b22
b26 b28 b2c b2e b3a b3c b3e b3f
b44 b48 b4a b56 b5a b5c b5d b66 
340
2
0 1 a 6 f :3 6 12 :3 6
11 :2 6 1 3 a 13 a :2 1
4 d 16 15 :2 d :2 4 f 18
17 :2 f :2 4 :2 c 1b c :2 4 e
17 :3 e 4 7 :2 11 23 :2 2d 3a
:2 23 :3 7 :2 d 19 25 :2 2f 43 :2 25
55 5b 5e :2 55 6c 83 8 :2 6c
d 10 :2 6c 19 1c :2 6c b e
:2 6c 13 16 :2 6c 1b 1e :2 6c 2a
2d :2 6c b e :2 6c 13 16 :2 6c
1b 1e :2 6c 29 2c :2 6c 31 34
:2 6c :2 7 4b :2 4 7 :2 11 23 :2 2d
39 3c 4d 4f 50 :2 4d :2 23 :3 7
:2 d 12 1e 5e 61 :2 1e :2 7 53
:2 4 :4 8 7 :4 1e 1d :2 7 a :2 14
26 :2 30 3c 3f 50 52 53 :2 50
:2 26 :3 a :2 10 15 21 61 64 :2 21
71 74 :2 21 78 7b :2 21 85 88
91 99 :2 a2 :2 91 b3 :2 88 :2 21 :2 a
56 :2 7 a :2 14 26 :2 30 3c 3f
50 52 53 :2 50 :2 26 :3 a :2 10 15
21 61 64 :2 21 :2 a 56 :3 7 :2 12
28 :2 31 41 :2 7 32 :3 4 10 :2 4
12 4 e :2 c d 1a b 19
:2 7 :2 10 1c 7 4 c a :2 13
1f a 1a :2 7 :2 c a :2 13 1f
a d :2 17 29 :2 33 3f 43 54
56 57 :2 54 :2 29 :3 d :2 13 18 24
64 67 :2 24 74 77 :2 24 7b 7e
:2 24 8a 8d :2 24 95 98 :2 24 a4
a7 ae b7 ba :2 a7 :2 24 :2 d 5a
:2 a :2 7 :4 13 :2 7 4 :3 1 7 10
19 :2 7 1c 1e :2 1c a :2 14 26
:2 30 3c 3f 50 52 53 :2 50 :2 26
:3 a :2 10 15 21 61 64 :2 21 71
74 :2 21 78 7b :2 21 85 88 91
99 :2 a2 :2 91 b3 :2 88 :2 21 :2 a 56
:2 7 a :2 14 26 :2 30 3c 3f 50
52 53 :2 50 :2 26 :3 a :2 10 15 21
61 64 :2 21 :2 a 56 :3 7 :2 12 28
:2 31 41 :2 7 20 :2 4 13 d 1a
b 19 7 e a 16 :3 14 a
:2 13 1f a 1b a :2 13 1f a
:4 7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 54 56 57 :2 54
:2 29 :3 d :2 13 18 24 64 67 :2 24
74 77 :2 24 7b 7e :2 24 8a 8d
:2 24 95 98 :2 24 a4 a7 ae b7
ba :2 a7 :2 24 :2 d 5a :2 a :2 7 :4 13
:2 7 4 :3 1 7 :2 11 23 :2 2d 39
3c 4d 4f 50 :2 4d :2 23 :3 7 :2 d
12 1e 5e 61 :2 1e 6e 71 :2 1e
75 78 :2 1e 82 85 8e 96 :2 9f
:2 8e aa :2 85 :2 1e b2 b5 :2 1e bd
c0 :2 1e c5 c8 :2 1e d3 d6 :2 1e
:2 7 53 :3 4 :2 f 21 :2 2a 34 40
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 51 53 54 :2 51 :2 26
:3 a :2 10 15 21 61 64 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 57
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 4e 51 52 :2 4e :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 55 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
340
4
0 :2 1 :4 3 :4 4
:4 5 2 :4 6 :2 1
:7 8 :7 9 :6 a :7 c
:b e :11 f 10 :2 f
:2 10 :2 f :2 10 :2 f
:2 11 :2 f :2 11 :2 f
:2 11 :2 f :2 11 :2 f
:2 12 :2 f :2 12 :2 f
:2 12 :2 f :2 12 :2 f
:2 12 :4 f :3 e :11 15
:b 16 :3 15 :c 19 :11 1a
:20 1b :3 1a :11 1d :b 1e
:3 1d :9 20 :3 19 :3 22
:3 23 25 26 27
:2 28 :2 29 25 :5 2a
24 2c :5 2d :3 2c
:2 2e :5 30 :11 31 :24 32
:3 31 :2 2f :6 2e 2b
:3 d :9 37 :11 38 :20 39
:3 38 :11 3b :b 3c :3 3b
:9 3e :3 37 41 :2 42
:2 43 41 :6 44 :5 45
44 :5 47 46 :3 44
40 4a :5 4b :3 4a
:2 4c :5 4e :11 4f :24 50
:3 4f :2 4d :6 4c 49
:3 d :11 55 :30 56 :3 55
:a 58 d :3 5b :11 5c
:b 5d :17 5e :3 5c :2 60
:3 61 :3 62 63 61
60 61 :3 64 :3 5b
:2 65 :5 67 :11 68 :b 69
:18 6a :3 68 :2 6c 6d
:3 6e 6f 6d 6c
6d :3 70 :2 66 :6 65
5a :7 1 
b68
4
:3 0 1 :3 0 2
:a 0 33b 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 9
:2 0 7 4 :3 0
5 :7 0 9 8
:3 0 4 :3 0 6
:7 0 d c :3 0
7 :3 0 8 :3 0
9 :2 0 4 11
12 0 f 13
0 33b 2 14
:2 0 b :2 0 f
4 :3 0 b :2 0
d 17 19 :6 0
1c 1a 0 339
0 a :6 0 f
:2 0 13 4 :3 0
11 1e 20 :6 0
23 21 0 339
0 c :6 0 2b
2c 0 15 e
:3 0 25 :7 0 29
26 27 339 0
d :6 0 31 32
0 17 8 :3 0
9 :2 0 4 2d
:7 0 30 2e 0
339 0 10 :6 0
11 :3 0 12 :3 0
11 :3 0 13 :3 0
34 35 0 2
:4 0 19 36 38
33 3a 39 :2 0
14 :3 0 15 :3 0
3c 3d 0 16
:4 0 11 :3 0 17
:3 0 40 41 0
2 :4 0 1b 42
44 18 :4 0 19
:2 0 1a :3 0 1d
47 49 :3 0 1b
:4 0 19 :2 0 1c
:4 0 20 4c 4e
:3 0 19 :2 0 3
:3 0 23 50 52
:3 0 19 :2 0 1c
:4 0 26 54 56
:3 0 19 :2 0 1d
:4 0 29 58 5a
:3 0 19 :2 0 1c
:4 0 2c 5c 5e
:3 0 19 :2 0 5
:3 0 2f 60 62
:3 0 19 :2 0 1c
:4 0 32 64 66
:3 0 19 :2 0 1d
:4 0 35 68 6a
:3 0 19 :2 0 1c
:4 0 38 6c 6e
:3 0 19 :2 0 6
:3 0 3b 70 72
:3 0 19 :2 0 1c
:4 0 3e 74 76
:3 0 19 :2 0 1e
:4 0 41 78 7a
:3 0 44 3e 7c
:2 0 7e 49 7f
3b 7e 0 80
4b 0 299 11
:3 0 12 :3 0 81
82 0 11 :3 0
1f :3 0 84 85
0 20 :2 0 2
:4 0 21 :2 0 22
:2 0 20 :2 0 4d
8a 8c :3 0 50
86 8e 83 90
8f :2 0 14 :3 0
23 :3 0 92 93
0 16 :4 0 24
:4 0 19 :2 0 1a
:3 0 54 97 99
:3 0 57 94 9b
:2 0 9d 5a 9e
91 9d 0 9f
5c 0 299 3
:3 0 25 :2 0 5e
a1 a2 :3 0 a3
:2 0 6 :3 0 25
:2 0 60 a6 a7
:3 0 a8 :2 0 a4
aa a9 :2 0 11
:3 0 12 :3 0 ac
ad 0 11 :3 0
1f :3 0 af b0
0 26 :2 0 2
:4 0 27 :2 0 22
:2 0 20 :2 0 62
b5 b7 :3 0 65
b1 b9 ae bb
ba :2 0 14 :3 0
23 :3 0 bd be
0 16 :4 0 28
:4 0 19 :2 0 1a
:3 0 69 c2 c4
:3 0 19 :2 0 29
:4 0 6c c6 c8
:3 0 19 :2 0 2a
:4 0 6f ca cc
:3 0 19 :2 0 2b
:3 0 2c :3 0 2d
:3 0 2e :3 0 d1
d2 0 72 d0
d4 2f :4 0 74
cf d7 77 ce
d9 :3 0 7a bf
db :2 0 dd 7d
de bc dd 0
df 7f 0 108
11 :3 0 12 :3 0
e0 e1 0 11
:3 0 1f :3 0 e3
e4 0 20 :2 0
2 :4 0 30 :2 0
22 :2 0 20 :2 0
81 e9 eb :3 0
84 e5 ed e2
ef ee :2 0 14
:3 0 23 :3 0 f1
f2 0 16 :4 0
31 :4 0 19 :2 0
1a :3 0 88 f6
f8 :3 0 8b f3
fa :2 0 fc 8e
fd f0 fc 0
fe 90 0 108
32 :3 0 33 :3 0
ff 100 0 2d
:3 0 2e :3 0 102
103 0 34 :3 0
92 101 106 :2 0
108 95 109 ab
108 0 10a 99
0 299 a :3 0
3 :3 0 10b 10c
0 299 c :3 0
6 :3 0 10e 10f
0 299 35 :3 0
d :3 0 36 :3 0
37 :3 0 c :3 0
38 :3 0 a :4 0
39 1 :8 0 11e
8 :3 0 3a :3 0
119 11a 0 3b
:3 0 11b 11c 0
11e 9b 171 3c
:3 0 8 :3 0 3a
:3 0 120 121 0
3b :3 0 122 123
0 125 9e 127
a0 126 125 :2 0
16f 3d :3 0 8
:3 0 3a :3 0 12a
12b 0 3b :3 0
12c 12d 0 167
11 :3 0 12 :3 0
12f 130 0 11
:3 0 1f :3 0 132
133 0 3e :2 0
2 :4 0 3f :2 0
22 :2 0 20 :2 0
a2 138 13a :3 0
a5 134 13c 131
13e 13d :2 0 14
:3 0 23 :3 0 140
141 0 16 :4 0
40 :4 0 19 :2 0
1a :3 0 a9 145
147 :3 0 19 :2 0
29 :4 0 ac 149
14b :3 0 19 :2 0
41 :4 0 af 14d
14f :3 0 19 :2 0
3b :3 0 b2 151
153 :3 0 19 :2 0
42 :4 0 b5 155
157 :3 0 19 :2 0
43 :3 0 44 :3 0
20 :2 0 45 :2 0
b8 15a 15e bc
159 160 :3 0 bf
142 162 :2 0 164
c2 165 13f 164
0 166 c4 0
167 c6 16a :3 0
16a 0 16a 169
167 168 :6 0 16c
2 :3 0 c9 16e
cb 16d 16c :2 0
16f cd :2 0 171
0 171 170 11e
16f :6 0 299 1
:3 0 2b :3 0 d
:3 0 f :2 0 d0
173 176 46 :2 0
f :2 0 d5 178
17a :3 0 11 :3 0
12 :3 0 17c 17d
0 11 :3 0 1f
:3 0 17f 180 0
26 :2 0 2 :4 0
47 :2 0 22 :2 0
20 :2 0 d8 185
187 :3 0 db 181
189 17e 18b 18a
:2 0 14 :3 0 23
:3 0 18d 18e 0
16 :4 0 48 :4 0
19 :2 0 1a :3 0
df 192 194 :3 0
19 :2 0 29 :4 0
e2 196 198 :3 0
19 :2 0 2a :4 0
e5 19a 19c :3 0
19 :2 0 2b :3 0
2c :3 0 2d :3 0
2e :3 0 1a1 1a2
0 e8 1a0 1a4
2f :4 0 ea 19f
1a7 ed 19e 1a9
:3 0 f0 18f 1ab
:2 0 1ad f3 1ae
18c 1ad 0 1af
f5 0 1d8 11
:3 0 12 :3 0 1b0
1b1 0 11 :3 0
1f :3 0 1b3 1b4
0 20 :2 0 2
:4 0 49 :2 0 22
:2 0 20 :2 0 f7
1b9 1bb :3 0 fa
1b5 1bd 1b2 1bf
1be :2 0 14 :3 0
23 :3 0 1c1 1c2
0 16 :4 0 4a
:4 0 19 :2 0 1a
:3 0 fe 1c6 1c8
:3 0 101 1c3 1ca
:2 0 1cc 104 1cd
1c0 1cc 0 1ce
106 0 1d8 32
:3 0 33 :3 0 1cf
1d0 0 2d :3 0
2e :3 0 1d2 1d3
0 34 :3 0 108
1d1 1d6 :2 0 1d8
10b 1d9 17b 1d8
0 1da 10f 0
299 36 :3 0 37
:3 0 c :3 0 38
:3 0 a :4 0 4b
1 :8 0 1f6 4c
:4 0 1e1 :3 0 34
:3 0 46 :2 0 113
1e4 1e5 :3 0 8
:3 0 3a :3 0 1e7
1e8 0 f :2 0
1e9 1ea 0 1ec
116 1f3 8 :3 0
3a :3 0 1ed 1ee
0 4d :2 0 1ef
1f0 0 1f2 118
1f4 1e6 1ec 0
1f5 0 1f2 0
1f5 11a 0 1f6
11d 249 3c :3 0
8 :3 0 3a :3 0
1f8 1f9 0 3b
:3 0 1fa 1fb 0
1fd 120 1ff 122
1fe 1fd :2 0 247
3d :3 0 8 :3 0
3a :3 0 202 203
0 3b :3 0 204
205 0 23f 11
:3 0 12 :3 0 207
208 0 11 :3 0
1f :3 0 20a 20b
0 3e :2 0 2
:4 0 4e :2 0 22
:2 0 20 :2 0 124
210 212 :3 0 127
20c 214 209 216
215 :2 0 14 :3 0
23 :3 0 218 219
0 16 :4 0 4f
:4 0 19 :2 0 1a
:3 0 12b 21d 21f
:3 0 19 :2 0 29
:4 0 12e 221 223
:3 0 19 :2 0 41
:4 0 131 225 227
:3 0 19 :2 0 3b
:3 0 134 229 22b
:3 0 19 :2 0 42
:4 0 137 22d 22f
:3 0 19 :2 0 43
:3 0 44 :3 0 20
:2 0 45 :2 0 13a
232 236 13e 231
238 :3 0 141 21a
23a :2 0 23c 144
23d 217 23c 0
23e 146 0 23f
148 242 :3 0 242
0 242 241 23f
240 :6 0 244 4
:3 0 14b 246 14d
245 244 :2 0 247
14f :2 0 249 0
249 248 1f6 247
:6 0 299 1 :3 0
11 :3 0 12 :3 0
24b 24c 0 11
:3 0 1f :3 0 24e
24f 0 50 :2 0
2 :4 0 51 :2 0
22 :2 0 20 :2 0
152 254 256 :3 0
155 250 258 24d
25a 259 :2 0 14
:3 0 23 :3 0 25c
25d 0 16 :4 0
52 :4 0 19 :2 0
1a :3 0 159 261
263 :3 0 19 :2 0
29 :4 0 15c 265
267 :3 0 19 :2 0
2a :4 0 15f 269
26b :3 0 19 :2 0
2b :3 0 2c :3 0
8 :3 0 3a :3 0
270 271 0 162
26f 273 2f :4 0
164 26e 276 167
26d 278 :3 0 19
:2 0 53 :4 0 16a
27a 27c :3 0 19
:2 0 1c :4 0 16d
27e 280 :3 0 19
:2 0 c :3 0 170
282 284 :3 0 19
:2 0 1c :4 0 173
286 288 :3 0 176
25e 28a :2 0 28c
179 28d 25b 28c
0 28e 17b 0
299 32 :3 0 54
:3 0 28f 290 0
8 :3 0 3a :3 0
292 293 0 c
:3 0 34 :3 0 17d
291 297 :2 0 299
181 33a 8 :3 0
55 :2 0 4 29a
29b 0 11 :3 0
12 :3 0 29d 29e
0 11 :3 0 1f
:3 0 2a0 2a1 0
3e :2 0 2 :4 0
56 :2 0 22 :2 0
20 :2 0 18c 2a6
2a8 :3 0 18f 2a2
2aa 29f 2ac 2ab
:2 0 14 :3 0 23
:3 0 2ae 2af 0
16 :4 0 57 :4 0
19 :2 0 1a :3 0
193 2b3 2b5 :3 0
196 2b0 2b7 :2 0
2d0 14 :3 0 23
:3 0 2b9 2ba 0
16 :4 0 58 :4 0
19 :2 0 8 :3 0
59 :3 0 2bf 2c0
0 199 2be 2c2
:3 0 19 :2 0 53
:4 0 19c 2c4 2c6
:3 0 19 :2 0 8
:3 0 5a :3 0 2c9
2ca 0 19f 2c8
2cc :3 0 1a2 2bb
2ce :2 0 2d0 1a5
2d1 2ad 2d0 0
2d2 1a8 0 2e2
5b :3 0 10 :3 0
8 :3 0 59 :3 0
5c :3 0 8 :3 0
5a :3 0 5d :3 0
5e :4 0 5f 1
:a 0 2de :2 0 2e2
2d4 2dc :2 0 7
:3 0 10 :3 0 2e0
:2 0 2e2 1aa 2e4
1ae 2e3 2e2 :2 0
338 3d :3 0 8
:3 0 3a :3 0 2e7
2e8 0 3b :3 0
2e9 2ea 0 330
11 :3 0 12 :3 0
2ec 2ed 0 11
:3 0 1f :3 0 2ef
2f0 0 3e :2 0
2 :4 0 60 :2 0
22 :2 0 20 :2 0
1b0 2f5 2f7 :3 0
1b3 2f1 2f9 2ee
2fb 2fa :2 0 14
:3 0 23 :3 0 2fd
2fe 0 16 :4 0
61 :4 0 19 :2 0
1a :3 0 1b7 302
304 :3 0 1ba 2ff
306 :2 0 320 14
:3 0 23 :3 0 308
309 0 16 :4 0
41 :4 0 19 :2 0
3b :3 0 1bd 30d
30f :3 0 19 :2 0
42 :4 0 1c0 311
313 :3 0 19 :2 0
43 :3 0 44 :3 0
20 :2 0 45 :2 0
1c3 316 31a 1c7
315 31c :3 0 1ca
30a 31e :2 0 320
1cd 321 2fc 320
0 322 1d0 0
330 5b :3 0 10
:3 0 5c :3 0 8
:3 0 5a :3 0 5d
:3 0 5e :4 0 62
1 :a 0 32c :2 0
330 324 32a :2 0
7 :3 0 10 :3 0
32e :2 0 330 1d2
333 :3 0 333 0
333 332 330 331
:6 0 335 1 :3 0
1d7 337 1d9 336
335 :2 0 338 1db
:2 0 33a 1de 33a
339 299 338 :6 0
33b :2 0 2 14
33a 33e :3 0 33d
33b 33f :8 0 
1e3
4
:3 0 1 3 1
7 1 b 3
6 a e 1
18 1 16 1
1f 1 1d 1
24 1 2a 1
37 1 43 2
46 48 2 4b
4d 2 4f 51
2 53 55 2
57 59 2 5b
5d 2 5f 61
2 63 65 2
67 69 2 6b
6d 2 6f 71
2 73 75 2
77 79 4 3f
45 4a 7b 1
7d 1 7f 2
89 8b 3 87
88 8d 2 96
98 2 95 9a
1 9c 1 9e
1 a0 1 a5
2 b4 b6 3
b2 b3 b8 2
c1 c3 2 c5
c7 2 c9 cb
1 d3 2 d5
d6 2 cd d8
2 c0 da 1
dc 1 de 2
e8 ea 3 e6
e7 ec 2 f5
f7 2 f4 f9
1 fb 1 fd
2 104 105 3
df fe 107 1
109 2 118 11d
1 124 1 11f
2 137 139 3
135 136 13b 2
144 146 2 148
14a 2 14c 14e
2 150 152 2
154 156 3 15b
15c 15d 2 158
15f 2 143 161
1 163 1 165
2 12e 166 1
16a 1 129 2
127 16e 2 174
175 1 179 2
177 179 2 184
186 3 182 183
188 2 191 193
2 195 197 2
199 19b 1 1a3
2 1a5 1a6 2
19d 1a8 2 190
1aa 1 1ac 1
1ae 2 1b8 1ba
3 1b6 1b7 1bc
2 1c5 1c7 2
1c4 1c9 1 1cb
1 1cd 2 1d4
1d5 3 1af 1ce
1d7 1 1d9 1
1e3 2 1e2 1e3
1 1eb 1 1f1
2 1f3 1f4 2
1e0 1f5 1 1fc
1 1f7 2 20f
211 3 20d 20e
213 2 21c 21e
2 220 222 2
224 226 2 228
22a 2 22c 22e
3 233 234 235
2 230 237 2
21b 239 1 23b
1 23d 2 206
23e 1 242 1
201 2 1ff 246
2 253 255 3
251 252 257 2
260 262 2 264
266 2 268 26a
1 272 2 274
275 2 26c 277
2 279 27b 2
27d 27f 2 281
283 2 285 287
2 25f 289 1
28b 1 28d 3
294 295 296 a
80 9f 10a 10d
110 171 1da 249
28e 298 2 2a5
2a7 3 2a3 2a4
2a9 2 2b2 2b4
2 2b1 2b6 2
2bd 2c1 2 2c3
2c5 2 2c7 2cb
2 2bc 2cd 2
2b8 2cf 1 2d1
3 2d2 2dd 2e1
1 29c 2 2f4
2f6 3 2f2 2f3
2f8 2 301 303
2 300 305 2
30c 30e 2 310
312 3 317 318
319 2 314 31b
2 30b 31d 2
307 31f 1 321
4 2eb 322 32b
32f 1 333 1
2e6 2 2e4 337
4 1b 22 28
2f 
1
4
0 
33e
0
1
14
6
8
0 1 2 1 4 1 0 0
0 0 0 0 0 0 0 0
0 0 0 0 
3 1 0
7 1 0
24 1 0
2 0 1
16 1 0
b 1 0
1d 1 0
2a 1 0
0

/
SHOW ERRORS FUNCTION SP_UA_FAV_RES;
ALTER FUNCTION SP_UA_FAV_RES COMPILE DEBUG;
/********************************************************************************************/
/********************************************************************************************/
Prompt == FUNCTION SP_S_A_FAV_RES ==
CREATE OR REPLACE FUNCTION SP_S_A_FAV_RES wrapped 
0
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
abcd
3
8
9200000
1
4
0 
bc
2 :e:
1FUNCTION:
1SP_S_A_FAV_RES:
1P_ID:
1VARCHAR2:
1P_REC_USER:
1RETURN:
1PMO_DB2M:
1REF_CURSOR:
1H_ID:
132:
1H_REC_USER:
1H_PROJECT_ID:
1C_FAV_RES:
1RESULTSET:
1ALLTRACES:
1TRACE_ENABLED:
1CHECK_PARAMS:
1LFILE:
1FPUT_PARAMS:
1AllTrace:
1LINES_BEFORE_PARAMS:
1-- :
1||:
1SYSTIMESTAMP:
1::r ::= SP_S_A_FAV_RES(:
1':
1, :
1);:
1CHECK_TRACE:
11:
122:
1+:
1FPUT:
1               ENTER:: SP_S_A_FAV_RES(23) :: cplan.sql(25452) :: :
1IS NULL:
127:
1        RETURN_ERROR:: SP_S_A_FAV_RES(28) :: cplan.sql(25457) :: :
1 :
1STATE:: :
1COALESCE:
1TO_CHAR:
1PMO_CNST:
1INVALID_PARAMS:
1NULL:
1 ID:: :
130:
1                EXIT:: SP_S_A_FAV_RES(31) :: cplan.sql(25460) :: :
1PMODEFINES:
1PMO_RETURN_ERROR_SP:
1TRUE:
1EXECUTE:
1IMMEDIATE:
1DELETE FROM TMP_FAV_PRJ_INFO:
1SC_STATE:
10:
1TMP_FAV_PRJ_INFO:
1F:
1RESOURCE_ID:
1TA:
1RESOURCE_TYPE:
1PROJECT_ID:
1MIN:
1PLANNED_START:
1PRJ_PLANNED_START:
1MAX:
1PLANNED_FINISH:
1PRJ_PLANNED_FINISH:
1SUM:
1PLANNED_WORK:
1PLANNED_REMAINING:
1BIT_FLAG:
1BEST:
1PLANNED_EFFORT:
1SCHED_START:
1PRJ_SCHED_START:
1SCHED_FINISH:
1PRJ_SCHED_FINISH:
1SCHED_WORK:
1SCHED_REMAINING:
1WORK:
1SC_RESOURCE:
1FAVORITE_RESOURCES:
1LEFT:
1JOIN:
1TASK_ASSIGNMENTS:
1TASK_ID:
1CREATED_BY:
1INSERT INTO TMP_FAV_PRJ_INFO:n      SELECT  F.RESOURCE_ID,:n      TA.RESOURCE+
1_TYPE,:n      TA.PROJECT_ID,:n      MIN(TA.PLANNED_START)  AS PRJ_PLANNED_STA+
1RT,:n      MAX(TA.PLANNED_FINISH) AS PRJ_PLANNED_FINISH,:n      SUM(TA.PLANNE+
1D_WORK)   AS PLANNED_REMAINING,:n      SUM(CASE WHEN TA.BIT_FLAG ='0' THEN TA+
1.BEST ELSE 0 END) AS PLANNED_EFFORT,:n      MIN(TA.SCHED_START)    AS PRJ_SCH+
1ED_START,:n      MAX(TA.SCHED_FINISH)   AS PRJ_SCHED_FINISH,:n      SUM(TA.SC+
1HED_WORK)     AS SCHED_REMAINING,:n      SUM(CASE WHEN TA.BIT_FLAG='2' THEN T+
1A.BEST ELSE 0 END) AS WORK,:n      pmo_cnst.SC_RESOURCE -- 13:n      FROM FAV+
1ORITE_RESOURCES F:n      LEFT JOIN TASK_ASSIGNMENTS TA ON F.RESOURCE_ID = TA.+
1RESOURCE_ID :n      AND TA.PROJECT_ID = TA.TASK_ID:n      AND TA.PROJECT_ID =+
1 h_id:n      WHERE F.CREATED_BY = h_rec_user :n      GROUP BY TA.PROJECT_ID, +
1F.RESOURCE_ID, TA.RESOURCE_TYPE:
1FOUND:
1=:
1100:
1NO_DATA_FOUND:
1SQLCODE:
1OTHERS:
116:
176:
1           EXCEPTION:: SP_S_A_FAV_RES(77) :: cplan.sql(25506) :: :
1SQLCODE:: :
1 SQLERR:: :
1SUBSTR:
1SQLERRM:
1500:
1DELETE FROM TMP_FAV_RES_INFO:
1TMP_FAV_RES_INFO:
1START_DATE:
1FINISH_DATE:
1REMAINING:
1LEVEL_PLANNED_START:
1LEVEL_PLANNED_FINISH:
1LEVEL_SCHED_START:
1LEVEL_SCHED_FINISH:
1ESTIMATED_BASELINE1_START:
1ESTIMATED_BASELINE1_FINISH:
1ESTIMATED_BASELINE1_EFFORT:
1ESTIMATED_BASELINE3_START:
1ESTIMATED_BASELINE3_FINISH:
1ESTIMATED_BASELINE3_EFFORT:
1REGULAR_COST:
1REGULAR_RATE:
1SPECIAL_COST:
1SPECIAL_RATE:
1TYPE_ID:
1DESCRIPTION:
1MINUTE_PER_DAY:
1B:
1A:
1ETC:
1W:
1PROJECT_ASSIGNMENTS:
1RIGHT:
1TMT_WBS:
1ELEMENT_ID:
1INSERT INTO TMP_FAV_RES_INFO:n      (:n      RESOURCE_ID,:n      RESOURCE_TYP+
1E,:n      PROJECT_ID,:n      PLANNED_START,:n      PLANNED_FINISH,:n      PLA+
1NNED_EFFORT,:n      START_DATE,:n      FINISH_DATE,:n      WORK,:n      REMAI+
1NING,:n      PRJ_PLANNED_START,:n      PRJ_PLANNED_FINISH,:n      PLANNED_REM+
1AINING,:n      PRJ_SCHED_START,:n      PRJ_SCHED_FINISH,:n      SCHED_REMAINI+
1NG,:n      LEVEL_PLANNED_START,:n      LEVEL_PLANNED_FINISH,:n      LEVEL_SCH+
1ED_START,:n      LEVEL_SCHED_FINISH,:n      ESTIMATED_BASELINE1_START,:n     +
1 ESTIMATED_BASELINE1_FINISH,:n      ESTIMATED_BASELINE1_EFFORT,:n      ESTIMA+
1TED_BASELINE3_START,:n      ESTIMATED_BASELINE3_FINISH,:n      ESTIMATED_BASE+
1LINE3_EFFORT,:n      REGULAR_COST,:n      REGULAR_RATE,:n      SPECIAL_COST,+
1:n      SPECIAL_RATE,:n      TYPE_ID,:n      DESCRIPTION,:n      MINUTE_PER_D+
1AY:n      ):n      :n      SELECT	b.RESOURCE_ID,:n      COALESCE(a.RESOURCE_T+
1YPE, '0'),        :n      A.PROJECT_ID,:n      a.PLANNED_START,        :n    +
1  a.PLANNED_FINISH,:n      COALESCE(a.PLANNED_WORK, 0),     :n      a.SCHED_S+
1TART,          :n      a.SCHED_FINISH,         :n      COALESCE(a.SCHED_WORK,+
1 0),:n      COALESCE(a.ETC, 0),              :n      b.PRJ_PLANNED_START,    +
1:n      b.PRJ_PLANNED_FINISH,   :n      COALESCE(b.PLANNED_REMAINING, 0),:n  +
1    b.PRJ_SCHED_START,  :n      b.PRJ_SCHED_FINISH,     :n      COALESCE(b.SC+
1HED_REMAINING, 0),:n      a.LEVEL_PLANNED_START, :n      a.LEVEL_PLANNED_FINI+
1SH, :n      a.LEVEL_SCHED_START, :n      a.LEVEL_SCHED_FINISH,:n      a.ESTIM+
1ATED_BASELINE1_START, :n      a.ESTIMATED_BASELINE1_FINISH, :n      COALESCE(+
1a.ESTIMATED_BASELINE1_EFFORT, 0),:n      a.ESTIMATED_BASELINE3_START, :n     +
1 a.ESTIMATED_BASELINE3_FINISH, :n      COALESCE(a.ESTIMATED_BASELINE3_EFFORT,+
1 0),:n      COALESCE(a.REGULAR_COST, 0),     :n      COALESCE(a.REGULAR_RATE,+
1 0),         :n      COALESCE(a.SPECIAL_COST, 0),         :n      COALESCE(a.+
1SPECIAL_RATE, 0),:n      COALESCE(b.TYPE_ID, CASE WHEN (a.PLANNED_WORK + a.SC+
1HED_WORK) = 0 THEN 185 ELSE 13 END), :n      a.DESCRIPTION,:n      COALESCE(w+
1.minute_per_day, 480):n      FROM PROJECT_ASSIGNMENTS a :n      RIGHT JOIN TM+
1P_FAV_PRJ_INFO b :n      ON a.RESOURCE_ID = b.RESOURCE_ID:n      AND a.PROJEC+
1T_ID = B.PROJECT_ID:n      LEFT JOIN TMT_WBS w on w.ELEMENT_ID = b.PROJECT_ID+
1:n      WHERE a.PROJECT_ID = h_id:
1173:
1           EXCEPTION:: SP_S_A_FAV_RES(174) :: cplan.sql(25603) :: :
1RI:
1T:
1UPDATE TMP_FAV_RES_INFO RI :n      SET TYPE_ID = pmo_cnst.SC_RESOURCE	--13 :n+
1      WHERE TYPE_ID = 185 :n      AND EXISTS(	SELECT TASK_ID :n      FROM TAS+
1K_ASSIGNMENTS T :n      WHERE T.PROJECT_ID = h_id:n      AND T.RESOURCE_ID = +
1RI.RESOURCE_ID :n      AND T.RESOURCE_TYPE = '0'):
1199:
1           EXCEPTION:: SP_S_A_FAV_RES(200) :: cplan.sql(25629) :: :
1OPEN:
1RES_ASSIGNMENT_ID:
1P:
1FULL_NAME:
1ELEMENT_NAME:
1E_MAIL_ADDRESS:
1T_UNIT:
1BEST_START:
1BEST_FINISH:
1CALENDAR:
1PERIOD_AVAILABILITY:
1ASSIGN_STRING:
1FS_LABOR_CODE:
1OBJECTIVES:
1RANK:
1PROJECT_ASSIGNMENT_ID:
1RT:
1REGULAR_SALE:
1SPECIAL_SALE:
1EXTERNAL_ID:
1LOGON_NAME:
1RPM_LOGON_NAME:
1NICK_NAME:
1WORK_LOCATION:
1WORK_PHONE:
1RESOURCES:
1RATES:
1RATE_ID:
1SELECT	F.RESOURCE_ID AS ELEMENT_ID,:n   '' AS RES_ASSIGNMENT_ID, :n   P.FULL_+
1NAME AS ELEMENT_NAME, :n   COALESCE(A.TYPE_ID, pmo_cnst.SC_RESOURCE) AS TYPE_+
1ID, :n   P.E_MAIL_ADDRESS,:n   A.PLANNED_START, :n   A.PLANNED_FINISH,:n   A.+
1PLANNED_EFFORT, :n   A.START_DATE, :n   A.FINISH_DATE, :n   A.WORK, :n   A.RE+
1MAINING,:n   0 AS T_UNIT,:n   A.MINUTE_PER_DAY, :n   '' AS BEST_START,:n   ''+
1 AS BEST_FINISH, :n   0 AS CALENDAR, :n   0 AS PLANNED_WORK, :n   0 AS PERIOD+
1_AVAILABILITY, :n   '' AS ASSIGN_STRING,:n   P.FS_LABOR_CODE, :n   '' AS OBJE+
1CTIVES,:n   '' AS RANK,:n   CASE WHEN A.PRJ_PLANNED_START IS NOT NuLL OR A.PR+
1J_SCHED_START IS NOT NuLL THEN A.RESOURCE_ID :n   ELSE '' END AS PROJECT_ASSI+
1GNMENT_ID, :n   A.PRJ_PLANNED_START, :n   A.PRJ_PLANNED_FINISH, :n   A.PLANNE+
1D_REMAINING, :n   A.PRJ_SCHED_START, :n   A.PRJ_SCHED_FINISH, :n   A.SCHED_RE+
1MAINING,:n   A.PROJECT_ID,:n   A.LEVEL_PLANNED_START, :n   A.LEVEL_PLANNED_FI+
1NISH, :n   A.LEVEL_SCHED_START, :n   A.LEVEL_SCHED_FINISH,:n   A.ESTIMATED_BA+
1SELINE1_START, :n   A.ESTIMATED_BASELINE1_FINISH, :n   A.ESTIMATED_BASELINE1_+
1EFFORT,:n   A.ESTIMATED_BASELINE3_START, :n   A.ESTIMATED_BASELINE3_FINISH, +
1:n   A.ESTIMATED_BASELINE3_EFFORT,:n   COALESCE(RT.REGULAR_COST, 0) AS REGULA+
1R_COST, :n   COALESCE(RT.REGULAR_SALE, 0) AS REGULAR_RATE, :n   COALESCE(RT.S+
1PECIAL_COST, 0) AS SPECIAL_COST, :n   COALESCE(RT.SPECIAL_SALE, 0) AS SPECIAL+
1_RATE, :n   A.DESCRIPTION, :n   P.EXTERNAL_ID,:n   P.LOGON_NAME AS RPM_LOGON_+
1NAME , :n   P.NICK_NAME, :n   P.WORK_LOCATION, :n   P.WORK_PHONE:n   FROM FAV+
1ORITE_RESOURCES F:n   JOIN RESOURCES P ON F.RESOURCE_ID = P.RESOURCE_ID:n   L+
1EFT JOIN RATES RT ON RT.RATE_ID = P.RATE_ID:n   LEFT JOIN TMP_FAV_RES_INFO A +
1ON F.RESOURCE_ID = A.RESOURCE_ID AND A.RESOURCE_TYPE = '0':n   WHERE F.CREATE+
1D_BY = h_rec_user:
1262:
1                EXIT:: SP_S_A_FAV_RES(263) :: cplan.sql(25692) :: :
14:
1267:
1       RETURN_STATUS:: SP_S_A_FAV_RES(268) :: cplan.sql(25697) :: :
1PMO_RETURN_STATUS:
1RETURN_ERROR_EXCEPTION:
1274:
1           EXCEPTION:: SP_S_A_FAV_RES(275) :: cplan.sql(25704) :: :
1RETURN_ERROR_EXCEPTION :: STATE:: :
1CURRENT_STATE:
1CURRENT_ID:
1ERROR:
1ID:
1DUAL:
1SELECT PMO_DB2M.CURRENT_STATE "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n +
1        FROM DUAL:
1286:
1           EXCEPTION:: SP_S_A_FAV_RES(287) :: cplan.sql(25716) :: :
1SELECT -9999 "ERROR" ,:n         PMO_DB2M.CURRENT_ID "ID":n         FROM DUAL:
0

0
0
4f6
2
0 a0 8d 8f a0 b0 3d 8f
a0 b0 3d b4 :3 a0 6b 2c 6a
a3 a0 51 a5 1c 81 b0 a3
a0 51 a5 1c 81 b0 a3 a0
51 a5 1c 81 b0 a3 :2 a0 6b
1c 81 b0 a3 :2 a0 6b 1c 81
b0 :2 a0 6b :2 a0 6b 6e a5 b
a 10 :2 a0 6b 6e :2 a0 6b 6e
a5 b 6e 7e a0 b4 2e 6e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e 7e 6e b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e a5 57 b7 19 3c
a0 7e b4 2e 5a :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e :4 a0 6b a5 b
6e a5 b b4 2e 7e 6e b4
2e 7e 6e b4 2e 7e a0 b4
2e 7e 6e b4 2e a5 57 b7
19 3c :2 a0 6b :2 a0 6b 51 6e
51 7e 51 b4 2e a5 b a
10 :2 a0 6b :2 6e 7e a0 b4 2e
a5 57 b7 19 3c :2 a0 6b :2 a0
6b :2 a0 a5 57 b7 19 3c :2 a0
d :2 a0 d :2 a0 6e 11e 11d :2 a0
6b 51 d :47 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :2 a0 6e 11e 11d :2 a0
6b 51 d :8f a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :12 a0 12a a0 f a0
7e b4 2e :2 a0 6b 51 d b7
:2 a0 6b 51 d b7 :2 19 3c b7
:3 a0 6b a0 d b7 a6 9 a0
53 :2 a0 6b a0 d :2 a0 6b :2 a0
6b 51 6e 51 7e 51 b4 2e
a5 b a 10 :2 a0 6b :2 6e 7e
a0 b4 2e 7e 6e b4 2e 7e
6e b4 2e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c b7
a4 b1 11 4f b7 a6 9 a4
b1 11 4f :90 a0 12a e9 dd :2 a0
6b :2 a0 6b 51 6e 51 7e 51
b4 2e a5 b a 10 :2 a0 6b
:2 6e 7e a0 b4 2e a5 57 b7
19 3c :2 a0 65 :2 a0 6b :2 a0 6b
51 6e 51 7e 51 b4 2e a5
b a 10 :2 a0 6b :2 6e 7e a0
b4 2e 7e 6e b4 2e 7e 6e
b4 2e 7e :4 a0 6b a5 b 6e
a5 b b4 2e 7e 6e b4 2e
7e 6e b4 2e 7e a0 b4 2e
7e 6e b4 2e a5 57 b7 19
3c :2 a0 6b :2 a0 6b :2 a0 a5 57
b7 :2 a0 6b :2 a0 6b :2 a0 6b 51
6e 51 7e 51 b4 2e a5 b
a 10 :2 a0 6b :2 6e 7e a0 b4
2e a5 57 :2 a0 6b :2 6e 7e :2 a0
6b b4 2e 7e 6e b4 2e 7e
:2 a0 6b b4 2e a5 57 b7 19
3c :9 a0 12a e9 dd :2 a0 65 b7
a6 9 a0 53 :2 a0 6b a0 d
:2 a0 6b :2 a0 6b 51 6e 51 7e
51 b4 2e a5 b a 10 :2 a0
6b :2 6e 7e a0 b4 2e a5 57
:2 a0 6b :2 6e 7e a0 b4 2e 7e
6e b4 2e 7e :2 a0 :2 51 a5 b
b4 2e a5 57 b7 19 3c :7 a0
12a e9 dd :2 a0 65 b7 a4 b1
11 4f b7 a6 9 a4 b1 11
68 4f 1d 17 b5 
4f6
2
0 3 7 23 1f 1e 2b 38
34 1b 40 33 45 49 4d 30
51 55 72 5d 61 64 65 6d
5c 8f 7d 59 81 82 8a 7c
ac 9a 79 9e 9f a7 99 cc
b7 bb 96 bf c7 b6 ec d7
db b3 df e7 d6 f3 f7 d3
fb ff 103 106 10b 10c 1 10e
113 117 11b 11e 123 127 12b 12e
133 134 136 13b 13e 142 143 148
14d 150 155 156 15b 15e 162 163
168 16b 170 171 176 179 17e 17f
184 187 18c 18d 192 195 199 19a
19f 1a2 1a7 1a8 1ad 1b0 1b5 1b6
1bb 1bc 1c1 1c3 1c7 1ca 1ce 1d2
1d5 1d9 1dd 1e0 1e3 1e8 1eb 1ee
1f1 1f2 1f7 1f8 1 1fa 1ff 203
207 20a 20f 214 217 21b 21c 221
222 227 229 22d 230 234 237 238
23d 240 244 248 24b 24f 253 256
259 25e 261 264 267 268 26d 26e
1 270 275 279 27d 280 285 28a
28d 291 292 297 29a 29f 2a0 2a5
2a8 2ad 2ae 2b3 2b6 2ba 2be 2c2
2c6 2c9 2ca 2cc 2d1 2d2 2d4 2d5
2da 2dd 2e2 2e3 2e8 2eb 2f0 2f1
2f6 2f9 2fd 2fe 303 306 30b 30c
311 312 317 319 31d 320 324 328
32b 32f 333 336 339 33e 341 344
347 348 34d 34e 1 350 355 359
35d 360 365 36a 36d 371 372 377
378 37d 37f 383 386 38a 38e 391
395 399 39c 3a0 3a4 3a5 3aa 3ac
3b0 3b3 3b7 3bb 3bf 3c3 3c7 3cb
3cf 3d3 3d8 3dd 3e1 3e5 3e9 3ec
3ef 3f3 3f7 3fb 3ff 403 407 40b
40f 413 417 41b 41f 423 427 42b
42f 433 437 43b 43f 443 447 44b
44f 453 457 45b 45f 463 467 46b
46f 473 477 47b 47f 483 487 48b
48f 493 497 49b 49f 4a3 4a7 4ab
4af 4b3 4b7 4bb 4bf 4c3 4c7 4cb
4cf 4d3 4d7 4db 4df 4e3 4e7 4eb
4ef 4f3 4f7 4fb 4ff 503 507 50b
50f 51b 51f 524 528 52b 52c 531
535 539 53c 53f 543 545 549 54d
550 553 557 559 55d 561 564 566
56a 56e 572 575 579 57d 57f 580
585 1 589 58d 591 594 598 59c
5a0 5a4 5a7 5ab 5af 5b2 5b5 5ba
5bd 5c0 5c3 5c4 5c9 5ca 1 5cc
5d1 5d5 5d9 5dc 5e1 5e6 5e9 5ed
5ee 5f3 5f6 5fb 5fc 601 604 609
60a 60f 612 616 617 61c 61f 624
625 62a 62d 631 635 638 63b 63c
63e 63f 644 645 64a 64c 650 653
655 659 65b 667 669 66b 66c 671
675 677 683 685 689 68d 692 697
69b 69f 6a3 6a6 6a9 6ad 6b1 6b5
6b9 6bd 6c1 6c5 6c9 6cd 6d1 6d5
6d9 6dd 6e1 6e5 6e9 6ed 6f1 6f5
6f9 6fd 701 705 709 70d 711 715
719 71d 721 725 729 72d 731 735
739 73d 741 745 749 74d 751 755
759 75d 761 765 769 76d 771 775
779 77d 781 785 789 78d 791 795
799 79d 7a1 7a5 7a9 7ad 7b1 7b5
7b9 7bd 7c1 7c5 7c9 7cd 7d1 7d5
7d9 7dd 7e1 7e5 7e9 7ed 7f1 7f5
7f9 7fd 801 805 809 80d 811 815
819 81d 821 825 829 82d 831 835
839 83d 841 845 849 84d 851 855
859 85d 861 865 869 86d 871 875
879 87d 881 885 889 88d 891 895
899 89d 8a1 8a5 8a9 8ad 8b1 8b5
8b9 8bd 8c1 8c5 8c9 8cd 8d1 8d5
8d9 8dd 8e1 8e5 8e9 8f5 8f9 8fe
902 905 906 90b 90f 913 916 919
91d 91f 923 927 92a 92d 931 933
937 93b 93e 940 944 948 94c 94f
953 957 959 95a 95f 1 963 967
96b 96e 972 976 97a 97e 981 985
989 98c 98f 994 997 99a 99d 99e
9a3 9a4 1 9a6 9ab 9af 9b3 9b6
9bb 9c0 9c3 9c7 9c8 9cd 9d0 9d5
9d6 9db 9de 9e3 9e4 9e9 9ec 9f0
9f1 9f6 9f9 9fe 9ff a04 a07 a0b
a0f a12 a15 a16 a18 a19 a1e a1f
a24 a26 a2a a2d a2f a33 a35 a41
a43 a45 a46 a4b a4f a51 a5d a5f
a63 a67 a6b a6f a73 a77 a7b a7f
a83 a87 a8b a8f a93 a97 a9b a9f
aa3 aa7 ab3 ab7 abc ac0 ac3 ac4
ac9 acd ad1 ad4 ad7 adb add ae1
ae5 ae8 aeb aef af1 af5 af9 afc
afe b02 b06 b0a b0d b11 b15 b17
b18 b1d 1 b21 b25 b29 b2c b30
b34 b38 b3c b3f b43 b47 b4a b4d
b52 b55 b58 b5b b5c b61 b62 1
b64 b69 b6d b71 b74 b79 b7e b81
b85 b86 b8b b8e b93 b94 b99 b9c
ba1 ba2 ba7 baa bae baf bb4 bb7
bbc bbd bc2 bc5 bc9 bcd bd0 bd3
bd4 bd6 bd7 bdc bdd be2 be4 be8
beb bed bf1 bf3 bff c01 c03 c04
c09 c0d c0f c1b c1d c21 c25 c29
c2d c31 c35 c39 c3d c41 c45 c49
c4d c51 c55 c59 c5d c61 c65 c69
c6d c71 c75 c79 c7d c81 c85 c89
c8d c91 c95 c99 c9d ca1 ca5 ca9
cad cb1 cb5 cb9 cbd cc1 cc5 cc9
ccd cd1 cd5 cd9 cdd ce1 ce5 ce9
ced cf1 cf5 cf9 cfd d01 d05 d09
d0d d11 d15 d19 d1d d21 d25 d29
d2d d31 d35 d39 d3d d41 d45 d49
d4d d51 d55 d59 d5d d61 d65 d69
d6d d71 d75 d79 d7d d81 d85 d89
d8d d91 d95 d99 d9d da1 da5 da9
dad db1 db5 db9 dbd dc1 dc5 dc9
dcd dd1 dd5 dd9 ddd de1 de5 de9
ded df1 df5 df9 dfd e01 e05 e09
e0d e11 e15 e19 e1d e21 e25 e29
e2d e31 e35 e39 e3d e41 e45 e49
e4d e51 e55 e59 e5d e69 e6e e72
e76 e7a e7d e81 e85 e88 e8b e90
e93 e96 e99 e9a e9f ea0 1 ea2
ea7 eab eaf eb2 eb7 ebc ebf ec3
ec4 ec9 eca ecf ed1 ed5 ed8 edc
ee0 ee4 ee8 eec eef ef3 ef7 efa
efd f02 f05 f08 f0b f0c f11 f12
1 f14 f19 f1d f21 f24 f29 f2e
f31 f35 f36 f3b f3e f43 f44 f49
f4c f51 f52 f57 f5a f5e f62 f66
f6a f6d f6e f70 f75 f76 f78 f79
f7e f81 f86 f87 f8c f8f f94 f95
f9a f9d fa1 fa2 fa7 faa faf fb0
fb5 fb6 fbb fbd fc1 fc4 fc8 fcc
fcf fd3 fd7 fda fde fe2 fe3 fe8
fea fee ff2 ff5 ff9 ffd 1000 1004
1008 100b 100e 1013 1016 1019 101c 101d
1022 1023 1 1025 102a 102e 1032 1035
103a 103f 1042 1046 1047 104c 104d 1052
1056 105a 105d 1062 1067 106a 106e 1072
1075 1076 107b 107e 1083 1084 1089 108c
1090 1094 1097 1098 109d 109e 10a3 10a5
10a9 10ac 10b0 10b4 10b8 10bc 10c0 10c4
10c8 10cc 10d0 10dc 10e1 10e5 10e9 10ed
10f1 10f3 10f4 10f9 1 10fd 1101 1105
1108 110c 1110 1114 1118 111b 111f 1123
1126 1129 112e 1131 1134 1137 1138 113d
113e 1 1140 1145 1149 114d 1150 1155
115a 115d 1161 1162 1167 1168 116d 1171
1175 1178 117d 1182 1185 1189 118a 118f
1192 1197 1198 119d 11a0 11a4 11a8 11ab
11ae 11af 11b1 11b2 11b7 11b8 11bd 11bf
11c3 11c6 11ca 11ce 11d2 11d6 11da 11de
11e2 11ee 11f3 11f7 11fb 11ff 1203 1205
1209 120b 1217 1219 121b 121c 1221 1225
1227 1233 1237 1239 123a 1243 
4f6
2
0 1 a 6 b :3 6 11 :2 6
1 3 a 13 a :2 1 4 9
12 11 :2 9 :2 4 f 18 17 :2 f
:2 4 11 1a 19 :2 11 4 7 11
1a :3 11 7 4 e 17 :3 e 4
7 :2 11 23 :2 2d 3a :2 23 :3 7 :2 d
19 25 :2 2f 43 :2 25 56 5c 5f
:2 56 6d 85 8 :2 6d d 10 :2 6d
15 18 :2 6d b e :2 6d 13 16
:2 6d 1b 1e :2 6d 29 2c :2 6d 31
34 :2 6d :2 7 4c :2 4 7 :2 11 23
:2 2d 39 3c 4e 50 51 :2 4e :2 23
:3 7 :2 d 12 1e 5f 62 :2 1e :2 7
54 :2 4 :4 8 7 a :2 14 26 :2 30
3c 40 52 54 55 :2 52 :2 26 :3 a
:2 10 15 21 62 65 :2 21 72 75
:2 21 79 7c :2 21 86 89 92 9a
:2 a3 :2 92 b4 :2 89 :2 21 bc bf :2 21
c7 ca :2 21 cf d2 :2 21 dd e0
:2 21 :2 a 58 :2 7 a :2 14 26 :2 30
3c 3f 51 53 54 :2 51 :2 26 :3 a
:2 10 15 21 62 65 :2 21 :2 a 57
:3 7 :2 12 26 :2 2f 3f 4b :2 7 1c
:3 4 c :2 4 12 :2 4 c 16 :3 4
:2 d 19 4 13 f 11 7 a
7 a 7 b e 21 7 b
e 21 7 b e 21 7 15
18 2b 2e 42 7 b e 21
7 b e 21 7 b e 21
7 15 18 2a 2d 41 7 10
c 1f 7 c 11 22 28 2a
38 3b b e 1b 1e b e
1b d f 1c 10 13 1f 21
2e 31 7 e a 16 :3 14 a
:2 13 1f a 1b a :2 13 1f a
:4 7 4 c a :2 13 1f a 1a
:2 7 :2 c a :2 13 1f a d :2 17
29 :2 33 3f 43 55 57 58 :2 55
:2 29 :3 d :2 13 18 24 65 68 :2 24
75 78 :2 24 7c 7f :2 24 8b 8e
:2 24 96 99 :2 24 a5 a8 af b8
bb :2 a8 :2 24 :2 d 5b :2 a :2 7 :4 13
:2 7 4 :3 1 4 c 16 :3 4 :2 d
19 4 13 :21 7 e 10 7 10
12 7 9 7 9 7 9 7
10 12 7 9 7 9 7 10
12 7 10 12 7 9 7 9
7 10 12 7 9 7 9 7
10 12 7 9 7 9 7 9
7 9 7 9 7 9 7 10
12 7 9 7 9 7 10 12
7 10 12 7 10 12 7 10
12 7 10 12 7 10 12 26
28 37 39 7 9 7 10 12
c 20 7 d 12 23 a c
1a 1c b d 1a 1c 7 c
11 19 1e 20 2d 2f d f
1c 7 e a 16 :3 14 a :2 13
1f a 1b a :2 13 1f a :4 7
4 c a :2 13 1f a 1a :2 7
:2 c a :2 13 1f a d :2 17 29
:2 33 3f 43 55 58 59 :2 55 :2 29
:3 d :2 13 18 24 66 69 :2 24 76
79 :2 24 7d 80 :2 24 8c 8f :2 24
97 9a :2 24 a6 a9 b0 b9 bc
:2 a9 :2 24 :2 d 5c :2 a :2 7 :4 13 :2 7
4 :3 1 e 1f b 15 1e d
1a c 1d d f 1c b d
1b 1e b d 7 e a 16
:3 14 a :2 13 1f a 1b a :2 13
1f a :4 7 4 c a :2 13 1f
a 1a :2 7 :2 c a :2 13 1f a
d :2 17 29 :2 33 3f 43 55 58
59 :2 55 :2 29 :3 d :2 13 18 24 66
69 :2 24 76 79 :2 24 7d 80 :2 24
8c 8f :2 24 97 9a :2 24 a6 a9
b0 b9 bc :2 a9 :2 24 :2 d 5c :2 a
:2 7 :4 13 :2 7 4 :3 1 4 9 1e
20 2f a 4 6 13 4 d
f 18 21 31 4 6 4 6
4 6 4 6 4 6 4 6
4 6 4 6 9 4 6 :2 a
:3 9 a 4 6 :2 a e 10 31
33 54 56 13 4 6 4 6
4 6 4 6 4 6 4 6
4 6 4 6 4 6 4 6
4 6 4 6 4 6 4 6
4 6 4 6 4 6 4 d
10 24 4 d 10 24 4 d
10 24 4 d 10 24 4 6
4 6 4 6 14 4 6 4
6 4 6 9 1c 4 9 13
18 1a 28 2a 4 9 e 14
1a 1d 27 29 4 9 e 1f
24 26 34 36 46 48 a c
19 17 4 17 7 :2 11 23 :2 2d
39 3c 4e 51 52 :2 4e :2 23 :3 7
:2 d 12 1e 60 63 :2 1e :2 7 55
:3 4 b 4 7 :2 11 23 :2 2d 39
3c 4e 51 52 :2 4e :2 23 :3 7 :2 d
12 1e 60 63 :2 1e 70 73 :2 1e
77 7a :2 1e 84 87 90 98 :2 a1
:2 90 ac :2 87 :2 1e b4 b7 :2 1e bf
c2 :2 1e c7 ca :2 1e cf d2 :2 1e
:2 7 55 :3 4 :2 f 21 :2 2a 34 3a
:2 4 1 9 12 9 a :2 14 26
:2 30 3c 40 52 55 56 :2 52 :2 26
:3 a :2 10 15 21 63 66 :2 21 :3 a
:2 10 15 39 5c 5f :2 68 :2 39 76
79 :2 39 81 84 :2 8d :2 39 :2 a 59
:3 7 c 15 1e 2c a 13 1e
f e 7 e 7 e 7 29
:2 4 :2 9 7 :2 10 1c :2 7 :2 11 23
:2 2d 39 3d 4f 52 53 :2 4f :2 23
:3 7 :2 d 12 1e 60 63 :2 1e :3 7
:2 d 12 36 42 45 :2 36 4d 50
:2 36 5c 5f 66 6f 72 :2 5f :2 36
:2 7 56 :2 4 7 c 1b a 13
1e f e 7 e 7 e 7
:2 4 :4 10 :2 4 :8 1 
4f6
4
0 :2 1 :4 3 :4 4
2 :4 5 :2 1 :7 7
:7 8 :7 9 :7 c :7 e
:b 10 :11 11 12 :2 11
:2 12 :2 11 :2 12 :2 11
:2 13 :2 11 :2 13 :2 11
:2 13 :2 11 :2 13 :2 11
:2 13 :4 11 :3 10 :11 16
:b 17 :3 16 :5 1a :11 1b
:30 1c :3 1b :11 1e :b 1f
:3 1e :a 21 :3 1a :3 24
:3 25 :5 2a :5 2b 2e
:2 2f :2 30 :2 31 :4 32
:4 33 :4 34 :6 35 :4 36
:4 37 :4 38 :6 39 :2 3a
:2 3b :8 3c :4 3d :3 3e
:3 3f :6 40 2e :6 41
:5 42 41 :5 44 43
:3 41 2d 47 :5 48
:3 47 :2 49 :5 4b :11 4c
:24 4d :3 4c :2 4a :6 49
46 :3 f :5 52 :5 53
56 58 59 5a
5b 5c 5d 5e
5f 60 61 62
63 64 65 66
67 68 69 6a
6b 6c 6d 6e
6f 70 71 72
73 74 75 76
77 78 :2 7b :3 7c
:2 7d :2 7e :2 7f :3 80
:2 81 :2 82 :3 83 :3 84
:2 85 :2 86 :3 87 :2 88
:2 89 :3 8a :2 8b :2 8c
:2 8d :2 8e :2 8f :2 90
:3 91 :2 92 :2 93 :3 94
:3 95 :3 96 :3 97 :3 98
:7 99 :2 9a :3 9b :2 9c
:4 9d :4 9e :4 9f :8 a0
:3 a1 56 :6 a2 :5 a3
a2 :5 a5 a4 :3 a2
55 a8 :5 a9 :3 a8
:2 aa :5 ac :11 ad :24 ae
:3 ad :2 ab :6 aa a7
:3 f :2 b4 :3 b5 b6
b7 :2 b8 :3 b9 :4 ba
:2 bb b4 :6 bc :5 bd
bc :5 bf be :3 bc
b3 c2 :5 c3 :3 c2
:2 c4 :5 c6 :11 c7 :24 c8
:3 c7 :2 c5 :6 c4 c1
:3 f :5 cd ce :3 cf
:6 d0 :2 d1 :2 d2 :2 d3
:2 d4 :2 d5 :2 d6 :2 d7
:2 d8 d9 :2 da db
dc dd de df
e0 :2 e1 e2 e3
:6 e4 e5 :2 e6 :2 e7
:2 e8 :2 e9 :2 ea :2 eb
:2 ec :2 ed :2 ee :2 ef
:2 f0 :2 f1 :2 f2 :2 f3
:2 f4 :2 f5 :2 f6 :4 f7
:4 f8 :4 f9 :4 fa :2 fb
:2 fc :3 fd :2 fe :2 ff
:2 100 :2 101 :7 102 :8 103
:a 104 :3 105 :3 cd :11 106
:b 107 :3 106 :3 109 :11 10b
:30 10c :3 10b :a 10e f
:3 111 :11 112 :b 113 :17 114
:3 112 :2 116 :3 117 :3 118
119 117 116 117
:3 11a :3 111 :2 11b :5 11d
:11 11e :b 11f :18 120 :3 11e
:2 122 123 :3 124 125
123 122 123 :3 126
:2 11c :6 11b 110 :7 1

1245
4
:3 0 1 :3 0 2
:a 0 4f1 1 :7 0
5 30 0 3
4 :3 0 3 :7 0
5 4 :3 0 d
e 0 7 4
:3 0 5 :7 0 9
8 :3 0 6 :3 0
7 :3 0 8 :2 0
4 b f 0
4f1 2 10 :2 0
a :2 0 c 4
:3 0 a :2 0 a
13 15 :6 0 18
16 0 4ef 0
9 :6 0 a :2 0
10 4 :3 0 e
1a 1c :6 0 1f
1d 0 4ef 0
b :6 0 28 29
0 14 4 :3 0
12 21 23 :6 0
26 24 0 4ef
0 c :6 0 2f
30 0 16 7
:3 0 8 :2 0 4
2a :7 0 2d 2b
0 4ef 0 d
:6 0 35 36 0
18 7 :3 0 8
:2 0 4 31 :7 0
34 32 0 4ef
0 e :6 0 f
:3 0 10 :3 0 f
:3 0 11 :3 0 38
39 0 2 :4 0
1a 3a 3c 37
3e 3d :2 0 12
:3 0 13 :3 0 40
41 0 14 :4 0
f :3 0 15 :3 0
44 45 0 2
:4 0 1c 46 48
16 :4 0 17 :2 0
18 :3 0 1e 4b
4d :3 0 19 :4 0
17 :2 0 1a :4 0
21 50 52 :3 0
17 :2 0 3 :3 0
24 54 56 :3 0
17 :2 0 1a :4 0
27 58 5a :3 0
17 :2 0 1b :4 0
2a 5c 5e :3 0
17 :2 0 1a :4 0
2d 60 62 :3 0
17 :2 0 5 :3 0
30 64 66 :3 0
17 :2 0 1a :4 0
33 68 6a :3 0
17 :2 0 1c :4 0
36 6c 6e :3 0
39 42 70 :2 0
72 3e 73 3f
72 0 74 40
0 44f f :3 0
10 :3 0 75 76
0 f :3 0 1d
:3 0 78 79 0
1e :2 0 2 :4 0
1f :2 0 20 :2 0
1e :2 0 42 7e
80 :3 0 45 7a
82 77 84 83
:2 0 12 :3 0 21
:3 0 86 87 0
14 :4 0 22 :4 0
17 :2 0 18 :3 0
49 8b 8d :3 0
4c 88 8f :2 0
91 4f 92 85
91 0 93 51
0 44f 5 :3 0
23 :2 0 53 95
96 :3 0 97 :2 0
f :3 0 10 :3 0
99 9a 0 f
:3 0 1d :3 0 9c
9d 0 a :2 0
2 :4 0 24 :2 0
20 :2 0 1e :2 0
55 a2 a4 :3 0
58 9e a6 9b
a8 a7 :2 0 12
:3 0 21 :3 0 aa
ab 0 14 :4 0
25 :4 0 17 :2 0
18 :3 0 5c af
b1 :3 0 17 :2 0
26 :4 0 5f b3
b5 :3 0 17 :2 0
27 :4 0 62 b7
b9 :3 0 17 :2 0
28 :3 0 29 :3 0
2a :3 0 2b :3 0
be bf 0 65
bd c1 2c :4 0
67 bc c4 6a
bb c6 :3 0 17
:2 0 2d :4 0 6d
c8 ca :3 0 17
:2 0 1a :4 0 70
cc ce :3 0 17
:2 0 5 :3 0 73
d0 d2 :3 0 17
:2 0 1a :4 0 76
d4 d6 :3 0 79
ac d8 :2 0 da
7c db a9 da
0 dc 7e 0
106 f :3 0 10
:3 0 dd de 0
f :3 0 1d :3 0
e0 e1 0 1e
:2 0 2 :4 0 2e
:2 0 20 :2 0 1e
:2 0 80 e6 e8
:3 0 83 e2 ea
df ec eb :2 0
12 :3 0 21 :3 0
ee ef 0 14
:4 0 2f :4 0 17
:2 0 18 :3 0 87
f3 f5 :3 0 8a
f0 f7 :2 0 f9
8d fa ed f9
0 fb 8f 0
106 30 :3 0 31
:3 0 fc fd 0
2a :3 0 2b :3 0
ff 100 0 5
:3 0 32 :3 0 91
fe 104 :2 0 106
95 107 98 106
0 108 99 0
44f 9 :3 0 3
:3 0 109 10a 0
44f b :3 0 5
:3 0 10c 10d 0
44f 33 :3 0 34
:3 0 35 :4 0 111
:4 0 112 :2 0 44f
7 :3 0 36 :3 0
114 115 0 37
:2 0 116 117 0
44f 38 :3 0 39
:3 0 3a :3 0 3b
:3 0 3c :3 0 3b
:3 0 3d :3 0 3e
:3 0 3b :3 0 3f
:3 0 40 :3 0 41
:3 0 3b :3 0 42
:3 0 43 :3 0 44
:3 0 3b :3 0 45
:3 0 46 :3 0 44
:3 0 3b :3 0 47
:3 0 3b :3 0 48
:3 0 49 :3 0 3e
:3 0 3b :3 0 4a
:3 0 4b :3 0 41
:3 0 3b :3 0 4c
:3 0 4d :3 0 44
:3 0 3b :3 0 4e
:3 0 4f :3 0 44
:3 0 3b :3 0 47
:3 0 3b :3 0 48
:3 0 50 :3 0 2a
:3 0 51 :3 0 52
:3 0 39 :3 0 53
:3 0 54 :3 0 55
:3 0 3b :3 0 39
:3 0 3a :3 0 3b
:3 0 3a :3 0 3b
:3 0 3d :3 0 3b
:3 0 56 :3 0 3b
:3 0 3d :3 0 9
:3 0 39 :3 0 57
:3 0 b :3 0 3b
:3 0 3d :3 0 39
:3 0 3a :3 0 3b
:3 0 3c :4 0 58
1 :8 0 176 59
:4 0 161 :3 0 32
:3 0 5a :2 0 9d
164 165 :3 0 7
:3 0 36 :3 0 167
168 0 37 :2 0
169 16a 0 16c
a0 173 7 :3 0
36 :3 0 16d 16e
0 5b :2 0 16f
170 0 172 a2
174 166 16c 0
175 0 172 0
175 a4 0 176
a7 1c9 5c :3 0
7 :3 0 36 :3 0
178 179 0 5d
:3 0 17a 17b 0
17d aa 17f ac
17e 17d :2 0 1c7
5e :3 0 7 :3 0
36 :3 0 182 183
0 5d :3 0 184
185 0 1bf f
:3 0 10 :3 0 187
188 0 f :3 0
1d :3 0 18a 18b
0 5f :2 0 2
:4 0 60 :2 0 20
:2 0 1e :2 0 ae
190 192 :3 0 b1
18c 194 189 196
195 :2 0 12 :3 0
21 :3 0 198 199
0 14 :4 0 61
:4 0 17 :2 0 18
:3 0 b5 19d 19f
:3 0 17 :2 0 26
:4 0 b8 1a1 1a3
:3 0 17 :2 0 62
:4 0 bb 1a5 1a7
:3 0 17 :2 0 5d
:3 0 be 1a9 1ab
:3 0 17 :2 0 63
:4 0 c1 1ad 1af
:3 0 17 :2 0 64
:3 0 65 :3 0 1e
:2 0 66 :2 0 c4
1b2 1b6 c8 1b1
1b8 :3 0 cb 19a
1ba :2 0 1bc ce
1bd 197 1bc 0
1be d0 0 1bf
d2 1c2 :3 0 1c2
0 1c2 1c1 1bf
1c0 :6 0 1c4 2
:3 0 d5 1c6 d7
1c5 1c4 :2 0 1c7
d9 :2 0 1c9 0
1c9 1c8 176 1c7
:6 0 44f 1 :3 0
33 :3 0 34 :3 0
67 :4 0 1cd :4 0
1ce :2 0 44f 7
:3 0 36 :3 0 1d0
1d1 0 37 :2 0
1d2 1d3 0 44f
68 :3 0 3a :3 0
3c :3 0 3d :3 0
3f :3 0 42 :3 0
49 :3 0 69 :3 0
6a :3 0 50 :3 0
6b :3 0 40 :3 0
43 :3 0 46 :3 0
4b :3 0 4d :3 0
4f :3 0 6c :3 0
6d :3 0 6e :3 0
6f :3 0 70 :3 0
71 :3 0 72 :3 0
73 :3 0 74 :3 0
75 :3 0 76 :3 0
77 :3 0 78 :3 0
79 :3 0 7a :3 0
7b :3 0 7c :3 0
7d :3 0 3a :3 0
28 :3 0 7e :3 0
3c :3 0 7e :3 0
3d :3 0 7e :3 0
3f :3 0 7e :3 0
42 :3 0 28 :3 0
7e :3 0 45 :3 0
7e :3 0 4a :3 0
7e :3 0 4c :3 0
28 :3 0 7e :3 0
4e :3 0 28 :3 0
7e :3 0 7f :3 0
7d :3 0 40 :3 0
7d :3 0 43 :3 0
28 :3 0 7d :3 0
46 :3 0 7d :3 0
4b :3 0 7d :3 0
4d :3 0 28 :3 0
7d :3 0 4f :3 0
7e :3 0 6c :3 0
7e :3 0 6d :3 0
7e :3 0 6e :3 0
7e :3 0 6f :3 0
7e :3 0 70 :3 0
7e :3 0 71 :3 0
28 :3 0 7e :3 0
72 :3 0 7e :3 0
73 :3 0 7e :3 0
74 :3 0 28 :3 0
7e :3 0 75 :3 0
28 :3 0 7e :3 0
76 :3 0 28 :3 0
7e :3 0 77 :3 0
28 :3 0 7e :3 0
78 :3 0 28 :3 0
7e :3 0 79 :3 0
28 :3 0 7d :3 0
7a :3 0 7e :3 0
45 :3 0 7e :3 0
4e :3 0 7e :3 0
7b :3 0 28 :3 0
80 :3 0 7c :3 0
81 :3 0 7e :3 0
82 :3 0 54 :3 0
38 :3 0 7d :3 0
7e :3 0 3a :3 0
7d :3 0 3a :3 0
7e :3 0 3d :3 0
7d :3 0 3d :3 0
53 :3 0 54 :3 0
83 :3 0 80 :3 0
80 :3 0 84 :3 0
7d :3 0 3d :3 0
7e :3 0 3d :3 0
9 :4 0 85 1
:8 0 27a 59 :4 0
265 :3 0 32 :3 0
5a :2 0 de 268
269 :3 0 7 :3 0
36 :3 0 26b 26c
0 37 :2 0 26d
26e 0 270 e1
277 7 :3 0 36
:3 0 271 272 0
5b :2 0 273 274
0 276 e3 278
26a 270 0 279
0 276 0 279
e5 0 27a e8
2cd 5c :3 0 7
:3 0 36 :3 0 27c
27d 0 5d :3 0
27e 27f 0 281
eb 283 ed 282
281 :2 0 2cb 5e
:3 0 7 :3 0 36
:3 0 286 287 0
5d :3 0 288 289
0 2c3 f :3 0
10 :3 0 28b 28c
0 f :3 0 1d
:3 0 28e 28f 0
5f :2 0 2 :4 0
86 :2 0 20 :2 0
1e :2 0 ef 294
296 :3 0 f2 290
298 28d 29a 299
:2 0 12 :3 0 21
:3 0 29c 29d 0
14 :4 0 87 :4 0
17 :2 0 18 :3 0
f6 2a1 2a3 :3 0
17 :2 0 26 :4 0
f9 2a5 2a7 :3 0
17 :2 0 62 :4 0
fc 2a9 2ab :3 0
17 :2 0 5d :3 0
ff 2ad 2af :3 0
17 :2 0 63 :4 0
102 2b1 2b3 :3 0
17 :2 0 64 :3 0
65 :3 0 1e :2 0
66 :2 0 105 2b6
2ba 109 2b5 2bc
:3 0 10c 29e 2be
:2 0 2c0 10f 2c1
29b 2c0 0 2c2
111 0 2c3 113
2c6 :3 0 2c6 0
2c6 2c5 2c3 2c4
:6 0 2c8 4 :3 0
116 2ca 118 2c9
2c8 :2 0 2cb 11a
:2 0 2cd 0 2cd
2cc 27a 2cb :6 0
44f 1 :3 0 68
:3 0 88 :3 0 7a
:3 0 2a :3 0 51
:3 0 7a :3 0 56
:3 0 55 :3 0 89
:3 0 89 :3 0 3d
:3 0 9 :3 0 89
:3 0 3a :3 0 88
:3 0 3a :3 0 89
:3 0 3c :4 0 8a
1 :8 0 2f7 59
:4 0 2e2 :3 0 32
:3 0 5a :2 0 11f
2e5 2e6 :3 0 7
:3 0 36 :3 0 2e8
2e9 0 37 :2 0
2ea 2eb 0 2ed
122 2f4 7 :3 0
36 :3 0 2ee 2ef
0 5b :2 0 2f0
2f1 0 2f3 124
2f5 2e7 2ed 0
2f6 0 2f3 0
2f6 126 0 2f7
129 34a 5c :3 0
7 :3 0 36 :3 0
2f9 2fa 0 5d
:3 0 2fb 2fc 0
2fe 12c 300 12e
2ff 2fe :2 0 348
5e :3 0 7 :3 0
36 :3 0 303 304
0 5d :3 0 305
306 0 340 f
:3 0 10 :3 0 308
309 0 f :3 0
1d :3 0 30b 30c
0 5f :2 0 2
:4 0 8b :2 0 20
:2 0 1e :2 0 130
311 313 :3 0 133
30d 315 30a 317
316 :2 0 12 :3 0
21 :3 0 319 31a
0 14 :4 0 8c
:4 0 17 :2 0 18
:3 0 137 31e 320
:3 0 17 :2 0 26
:4 0 13a 322 324
:3 0 17 :2 0 62
:4 0 13d 326 328
:3 0 17 :2 0 5d
:3 0 140 32a 32c
:3 0 17 :2 0 63
:4 0 143 32e 330
:3 0 17 :2 0 64
:3 0 65 :3 0 1e
:2 0 66 :2 0 146
333 337 14a 332
339 :3 0 14d 31b
33b :2 0 33d 150
33e 318 33d 0
33f 152 0 340
154 343 :3 0 343
0 343 342 340
341 :6 0 345 6
:3 0 157 347 159
346 345 :2 0 348
15b :2 0 34a 0
34a 349 2f7 348
:6 0 44f 1 :3 0
8d :3 0 d :3 0
39 :3 0 3a :3 0
84 :3 0 8e :3 0
8f :3 0 90 :3 0
91 :3 0 28 :3 0
7e :3 0 7a :3 0
2a :3 0 51 :3 0
7a :3 0 8f :3 0
92 :3 0 7e :3 0
3f :3 0 7e :3 0
42 :3 0 7e :3 0
49 :3 0 7e :3 0
69 :3 0 7e :3 0
6a :3 0 7e :3 0
50 :3 0 7e :3 0
6b :3 0 93 :3 0
7e :3 0 7c :3 0
94 :3 0 95 :3 0
96 :3 0 45 :3 0
97 :3 0 98 :3 0
8f :3 0 99 :3 0
9a :3 0 9b :3 0
7e :3 0 40 :3 0
7e :3 0 4b :3 0
7e :3 0 3a :3 0
9c :3 0 7e :3 0
40 :3 0 7e :3 0
43 :3 0 7e :3 0
46 :3 0 7e :3 0
4b :3 0 7e :3 0
4d :3 0 7e :3 0
4f :3 0 7e :3 0
3d :3 0 7e :3 0
6c :3 0 7e :3 0
6d :3 0 7e :3 0
6e :3 0 7e :3 0
6f :3 0 7e :3 0
70 :3 0 7e :3 0
71 :3 0 7e :3 0
72 :3 0 7e :3 0
73 :3 0 7e :3 0
74 :3 0 7e :3 0
75 :3 0 28 :3 0
9d :3 0 76 :3 0
76 :3 0 28 :3 0
9d :3 0 9e :3 0
77 :3 0 28 :3 0
9d :3 0 78 :3 0
78 :3 0 28 :3 0
9d :3 0 9f :3 0
79 :3 0 7e :3 0
7b :3 0 8f :3 0
a0 :3 0 8f :3 0
a1 :3 0 a2 :3 0
8f :3 0 a3 :3 0
8f :3 0 a4 :3 0
8f :3 0 a5 :3 0
52 :3 0 39 :3 0
54 :3 0 a6 :3 0
8f :3 0 39 :3 0
3a :3 0 8f :3 0
3a :3 0 53 :3 0
54 :3 0 a7 :3 0
9d :3 0 9d :3 0
a8 :3 0 8f :3 0
a8 :3 0 53 :3 0
54 :3 0 68 :3 0
7e :3 0 39 :3 0
3a :3 0 7e :3 0
3a :3 0 7e :3 0
3c :3 0 39 :3 0
57 :3 0 b :4 0
a9 1 :a 0 3de
:2 0 44f 34d 3dc
:2 0 f :3 0 10
:3 0 3df 3e0 0
f :3 0 1d :3 0
3e2 3e3 0 1e
:2 0 2 :4 0 aa
:2 0 20 :2 0 1e
:2 0 15e 3e8 3ea
:3 0 161 3e4 3ec
3e1 3ee 3ed :2 0
12 :3 0 21 :3 0
3f0 3f1 0 14
:4 0 ab :4 0 17
:2 0 18 :3 0 165
3f5 3f7 :3 0 168
3f2 3f9 :2 0 3fb
16b 3fc 3ef 3fb
0 3fd 16d 0
44f 6 :3 0 d
:3 0 3ff :2 0 44f
f :3 0 10 :3 0
401 402 0 f
:3 0 1d :3 0 404
405 0 ac :2 0
2 :4 0 ad :2 0
20 :2 0 1e :2 0
16f 40a 40c :3 0
172 406 40e 403
410 40f :2 0 12
:3 0 21 :3 0 412
413 0 14 :4 0
ae :4 0 17 :2 0
18 :3 0 176 417
419 :3 0 17 :2 0
26 :4 0 179 41b
41d :3 0 17 :2 0
27 :4 0 17c 41f
421 :3 0 17 :2 0
28 :3 0 29 :3 0
7 :3 0 36 :3 0
426 427 0 17f
425 429 2c :4 0
181 424 42c 184
423 42e :3 0 17
:2 0 2d :4 0 187
430 432 :3 0 17
:2 0 1a :4 0 18a
434 436 :3 0 17
:2 0 9 :3 0 18d
438 43a :3 0 17
:2 0 1a :4 0 190
43c 43e :3 0 193
414 440 :2 0 442
196 443 411 442
0 444 198 0
44f 30 :3 0 af
:3 0 445 446 0
7 :3 0 36 :3 0
448 449 0 9
:3 0 32 :3 0 19a
447 44d :2 0 44f
19e 4f0 7 :3 0
b0 :2 0 4 450
451 0 f :3 0
10 :3 0 453 454
0 f :3 0 1d
:3 0 456 457 0
5f :2 0 2 :4 0
b1 :2 0 20 :2 0
1e :2 0 1b0 45c
45e :3 0 1b3 458
460 455 462 461
:2 0 12 :3 0 21
:3 0 464 465 0
14 :4 0 b2 :4 0
17 :2 0 18 :3 0
1b7 469 46b :3 0
1ba 466 46d :2 0
486 12 :3 0 21
:3 0 46f 470 0
14 :4 0 b3 :4 0
17 :2 0 7 :3 0
b4 :3 0 475 476
0 1bd 474 478
:3 0 17 :2 0 2d
:4 0 1c0 47a 47c
:3 0 17 :2 0 7
:3 0 b5 :3 0 47f
480 0 1c3 47e
482 :3 0 1c6 471
484 :2 0 486 1c9
487 463 486 0
488 1cc 0 498
8d :3 0 e :3 0
7 :3 0 b4 :3 0
b6 :3 0 7 :3 0
b5 :3 0 b7 :3 0
b8 :4 0 b9 1
:a 0 494 :2 0 498
48a 492 :2 0 6
:3 0 e :3 0 496
:2 0 498 1ce 49a
1d2 499 498 :2 0
4ee 5e :3 0 7
:3 0 36 :3 0 49d
49e 0 5d :3 0
49f 4a0 0 4e6
f :3 0 10 :3 0
4a2 4a3 0 f
:3 0 1d :3 0 4a5
4a6 0 5f :2 0
2 :4 0 ba :2 0
20 :2 0 1e :2 0
1d4 4ab 4ad :3 0
1d7 4a7 4af 4a4
4b1 4b0 :2 0 12
:3 0 21 :3 0 4b3
4b4 0 14 :4 0
bb :4 0 17 :2 0
18 :3 0 1db 4b8
4ba :3 0 1de 4b5
4bc :2 0 4d6 12
:3 0 21 :3 0 4be
4bf 0 14 :4 0
62 :4 0 17 :2 0
5d :3 0 1e1 4c3
4c5 :3 0 17 :2 0
63 :4 0 1e4 4c7
4c9 :3 0 17 :2 0
64 :3 0 65 :3 0
1e :2 0 66 :2 0
1e7 4cc 4d0 1eb
4cb 4d2 :3 0 1ee
4c0 4d4 :2 0 4d6
1f1 4d7 4b2 4d6
0 4d8 1f4 0
4e6 8d :3 0 e
:3 0 b6 :3 0 7
:3 0 b5 :3 0 b7
:3 0 b8 :4 0 bc
1 :a 0 4e2 :2 0
4e6 4da 4e0 :2 0
6 :3 0 e :3 0
4e4 :2 0 4e6 1f6
4e9 :3 0 4e9 0
4e9 4e8 4e6 4e7
:6 0 4eb 1 :3 0
1fb 4ed 1fd 4ec
4eb :2 0 4ee 1ff
:2 0 4f0 202 4f0
4ef 44f 4ee :6 0
4f1 :2 0 2 10
4f0 4f4 :3 0 4f3
4f1 4f5 :8 0 
208
4
:3 0 1 3 1
7 2 6 a
1 14 1 12
1 1b 1 19
1 22 1 20
1 27 1 2e
1 3b 1 47
2 4a 4c 2
4f 51 2 53
55 2 57 59
2 5b 5d 2
5f 61 2 63
65 2 67 69
2 6b 6d 4
43 49 4e 6f
1 71 1 73
2 7d 7f 3
7b 7c 81 2
8a 8c 2 89
8e 1 90 1
92 1 94 2
a1 a3 3 9f
a0 a5 2 ae
b0 2 b2 b4
2 b6 b8 1
c0 2 c2 c3
2 ba c5 2
c7 c9 2 cb
cd 2 cf d1
2 d3 d5 2
ad d7 1 d9
1 db 2 e5
e7 3 e3 e4
e9 2 f2 f4
2 f1 f6 1
f8 1 fa 3
101 102 103 3
dc fb 105 1
107 1 163 2
162 163 1 16b
1 171 2 173
174 2 160 175
1 17c 1 177
2 18f 191 3
18d 18e 193 2
19c 19e 2 1a0
1a2 2 1a4 1a6
2 1a8 1aa 2
1ac 1ae 3 1b3
1b4 1b5 2 1b0
1b7 2 19b 1b9
1 1bb 1 1bd
2 186 1be 1
1c2 1 181 2
17f 1c6 1 267
2 266 267 1
26f 1 275 2
277 278 2 264
279 1 280 1
27b 2 293 295
3 291 292 297
2 2a0 2a2 2
2a4 2a6 2 2a8
2aa 2 2ac 2ae
2 2b0 2b2 3
2b7 2b8 2b9 2
2b4 2bb 2 29f
2bd 1 2bf 1
2c1 2 28a 2c2
1 2c6 1 285
2 283 2ca 1
2e4 2 2e3 2e4
1 2ec 1 2f2
2 2f4 2f5 2
2e1 2f6 1 2fd
1 2f8 2 310
312 3 30e 30f
314 2 31d 31f
2 321 323 2
325 327 2 329
32b 2 32d 32f
3 334 335 336
2 331 338 2
31c 33a 1 33c
1 33e 2 307
33f 1 343 1
302 2 300 347
2 3e7 3e9 3
3e5 3e6 3eb 2
3f4 3f6 2 3f3
3f8 1 3fa 1
3fc 2 409 40b
3 407 408 40d
2 416 418 2
41a 41c 2 41e
420 1 428 2
42a 42b 2 422
42d 2 42f 431
2 433 435 2
437 439 2 43b
43d 2 415 43f
1 441 1 443
3 44a 44b 44c
11 74 93 108
10b 10e 113 118
1c9 1cf 1d4 2cd
34a 3dd 3fd 400
444 44e 2 45b
45d 3 459 45a
45f 2 468 46a
2 467 46c 2
473 477 2 479
47b 2 47d 481
2 472 483 2
46e 485 1 487
3 488 493 497
1 452 2 4aa
4ac 3 4a8 4a9
4ae 2 4b7 4b9
2 4b6 4bb 2
4c2 4c4 2 4c6
4c8 3 4cd 4ce
4cf 2 4ca 4d1
2 4c1 4d3 2
4bd 4d5 1 4d7
4 4a1 4d8 4e1
4e5 1 4e9 1
49c 2 49a 4ed
5 17 1e 25
2c 33 
1
4
0 
4f4
0
1
14
8
8
0 1 2 1 4 1 6 1
0 0 0 0 0 0 0 0
0 0 0 0 
3 1 0
2 0 1
27 1 0
12 1 0
20 1 0
7 1 0
19 1 0
2e 1 0
0

/
SHOW ERRORS FUNCTION SP_S_A_FAV_RES;
ALTER FUNCTION SP_S_A_FAV_RES COMPILE DEBUG;
/***************************************************************************************/
